// The Module object: Our interface to the outside world. We import
// and export values on it, and do the work to get that through
// closure compiler if necessary. There are various ways Module can be used:
// 1. Not defined. We create it here
// 2. A function parameter, function(Module) { ..generated code.. }
// 3. pre-run appended it, var Module = {}; ..generated code..
// 4. External script tag defines var Module.
// We need to do an eval in order to handle the closure compiler
// case, where this code here is minified but Module was defined
// elsewhere (e.g. case 4 above). We also need to check if Module
// already exists (e.g. case 3 above).
// Note that if you want to run closure, and also to use Module
// after the generated code, you will need to define   var Module = {};
// before the code. Then that object will be used in the code, and you
// can continue to use Module afterwards as well.
var Module;
if (!Module) Module = (typeof Module !== 'undefined' ? Module : null) || {};

// Sometimes an existing Module object exists with properties
// meant to overwrite the default module functionality. Here
// we collect those properties and reapply _after_ we configure
// the current environment's defaults to avoid having to be so
// defensive during initialization.
var moduleOverrides = {};
for (var key in Module) {
  if (Module.hasOwnProperty(key)) {
    moduleOverrides[key] = Module[key];
  }
}

// The environment setup code below is customized to use Module.
// *** Environment setup code ***
var ENVIRONMENT_IS_WEB = false;
var ENVIRONMENT_IS_WORKER = false;
var ENVIRONMENT_IS_NODE = false;
var ENVIRONMENT_IS_SHELL = false;

// Three configurations we can be running in:
// 1) We could be the application main() thread running in the main JS UI thread. (ENVIRONMENT_IS_WORKER == false and ENVIRONMENT_IS_PTHREAD == false)
// 2) We could be the application main() thread proxied to worker. (with Emscripten -s PROXY_TO_WORKER=1) (ENVIRONMENT_IS_WORKER == true, ENVIRONMENT_IS_PTHREAD == false)
// 3) We could be an application pthread running in a worker. (ENVIRONMENT_IS_WORKER == true and ENVIRONMENT_IS_PTHREAD == true)

if (Module['ENVIRONMENT']) {
  if (Module['ENVIRONMENT'] === 'WEB') {
    ENVIRONMENT_IS_WEB = true;
  } else if (Module['ENVIRONMENT'] === 'WORKER') {
    ENVIRONMENT_IS_WORKER = true;
  } else if (Module['ENVIRONMENT'] === 'NODE') {
    ENVIRONMENT_IS_NODE = true;
  } else if (Module['ENVIRONMENT'] === 'SHELL') {
    ENVIRONMENT_IS_SHELL = true;
  } else {
    throw new Error('The provided Module[\'ENVIRONMENT\'] value is not valid. It must be one of: WEB|WORKER|NODE|SHELL.');
  }
} else {
  ENVIRONMENT_IS_WEB = typeof window === 'object';
  ENVIRONMENT_IS_WORKER = typeof importScripts === 'function';
  ENVIRONMENT_IS_NODE = typeof process === 'object' && typeof require === 'function' && !ENVIRONMENT_IS_WEB && !ENVIRONMENT_IS_WORKER;
  ENVIRONMENT_IS_SHELL = !ENVIRONMENT_IS_WEB && !ENVIRONMENT_IS_NODE && !ENVIRONMENT_IS_WORKER;
}


if (ENVIRONMENT_IS_NODE) {
  // Expose functionality in the same simple way that the shells work
  // Note that we pollute the global namespace here, otherwise we break in node
  if (!Module['print']) Module['print'] = console.log;
  if (!Module['printErr']) Module['printErr'] = console.warn;

  var nodeFS;
  var nodePath;

  Module['read'] = function shell_read(filename, binary) {
    if (!nodeFS) nodeFS = require('fs');
    if (!nodePath) nodePath = require('path');
    filename = nodePath['normalize'](filename);
    var ret = nodeFS['readFileSync'](filename);
    return binary ? ret : ret.toString();
  };

  Module['readBinary'] = function readBinary(filename) {
    var ret = Module['read'](filename, true);
    if (!ret.buffer) {
      ret = new Uint8Array(ret);
    }
    assert(ret.buffer);
    return ret;
  };

  Module['load'] = function load(f) {
    globalEval(read(f));
  };

  if (!Module['thisProgram']) {
    if (process['argv'].length > 1) {
      Module['thisProgram'] = process['argv'][1].replace(/\\/g, '/');
    } else {
      Module['thisProgram'] = 'unknown-program';
    }
  }

  Module['arguments'] = process['argv'].slice(2);

  if (typeof module !== 'undefined') {
    module['exports'] = Module;
  }

  process['on']('uncaughtException', function(ex) {
    // suppress ExitStatus exceptions from showing an error
    if (!(ex instanceof ExitStatus)) {
      throw ex;
    }
  });

  Module['inspect'] = function () { return '[Emscripten Module object]'; };
}
else if (ENVIRONMENT_IS_SHELL) {
  if (!Module['print']) Module['print'] = print;
  if (typeof printErr != 'undefined') Module['printErr'] = printErr; // not present in v8 or older sm

  if (typeof read != 'undefined') {
    Module['read'] = read;
  } else {
    Module['read'] = function shell_read() { throw 'no read() available' };
  }

  Module['readBinary'] = function readBinary(f) {
    if (typeof readbuffer === 'function') {
      return new Uint8Array(readbuffer(f));
    }
    var data = read(f, 'binary');
    assert(typeof data === 'object');
    return data;
  };

  if (typeof scriptArgs != 'undefined') {
    Module['arguments'] = scriptArgs;
  } else if (typeof arguments != 'undefined') {
    Module['arguments'] = arguments;
  }

  if (typeof quit === 'function') {
    Module['quit'] = function(status, toThrow) {
      quit(status);
    }
  }

}
else if (ENVIRONMENT_IS_WEB || ENVIRONMENT_IS_WORKER) {
  Module['read'] = function shell_read(url) {
    var xhr = new XMLHttpRequest();
    xhr.open('GET', url, false);
    xhr.send(null);
    return xhr.responseText;
  };

  if (ENVIRONMENT_IS_WORKER) {
    Module['readBinary'] = function readBinary(url) {
      var xhr = new XMLHttpRequest();
      xhr.open('GET', url, false);
      xhr.responseType = 'arraybuffer';
      xhr.send(null);
      return new Uint8Array(xhr.response);
    };
  }

  Module['readAsync'] = function readAsync(url, onload, onerror) {
    var xhr = new XMLHttpRequest();
    xhr.open('GET', url, true);
    xhr.responseType = 'arraybuffer';
    xhr.onload = function xhr_onload() {
      if (xhr.status == 200 || (xhr.status == 0 && xhr.response)) { // file URLs can return 0
        onload(xhr.response);
      } else {
        onerror();
      }
    };
    xhr.onerror = onerror;
    xhr.send(null);
  };

  if (typeof arguments != 'undefined') {
    Module['arguments'] = arguments;
  }

  if (typeof console !== 'undefined') {
    if (!Module['print']) Module['print'] = function shell_print(x) {
      console.log(x);
    };
    if (!Module['printErr']) Module['printErr'] = function shell_printErr(x) {
      console.warn(x);
    };
  } else {
    // Probably a worker, and without console.log. We can do very little here...
    var TRY_USE_DUMP = false;
    if (!Module['print']) Module['print'] = (TRY_USE_DUMP && (typeof(dump) !== "undefined") ? (function(x) {
      dump(x);
    }) : (function(x) {
      // self.postMessage(x); // enable this if you want stdout to be sent as messages
    }));
  }

  if (ENVIRONMENT_IS_WORKER) {
    Module['load'] = importScripts;
  }

  if (typeof Module['setWindowTitle'] === 'undefined') {
    Module['setWindowTitle'] = function(title) { document.title = title };
  }
}
else {
  // Unreachable because SHELL is dependant on the others
  throw 'Unknown runtime environment. Where are we?';
}

function globalEval(x) {
  eval.call(null, x);
}
if (!Module['load'] && Module['read']) {
  Module['load'] = function load(f) {
    globalEval(Module['read'](f));
  };
}
if (!Module['print']) {
  Module['print'] = function(){};
}
if (!Module['printErr']) {
  Module['printErr'] = Module['print'];
}
if (!Module['arguments']) {
  Module['arguments'] = [];
}
if (!Module['thisProgram']) {
  Module['thisProgram'] = './this.program';
}
if (!Module['quit']) {
  Module['quit'] = function(status, toThrow) {
    throw toThrow;
  }
}

// *** Environment setup code ***

// Closure helpers
Module.print = Module['print'];
Module.printErr = Module['printErr'];

// Callbacks
Module['preRun'] = [];
Module['postRun'] = [];

// Merge back in the overrides
for (var key in moduleOverrides) {
  if (moduleOverrides.hasOwnProperty(key)) {
    Module[key] = moduleOverrides[key];
  }
}
// Free the object hierarchy contained in the overrides, this lets the GC
// reclaim data used e.g. in memoryInitializerRequest, which is a large typed array.
moduleOverrides = undefined;



// {{PREAMBLE_ADDITIONS}}

// === Preamble library stuff ===

// Documentation for the public APIs defined in this file must be updated in:
//    site/source/docs/api_reference/preamble.js.rst
// A prebuilt local version of the documentation is available at:
//    site/build/text/docs/api_reference/preamble.js.txt
// You can also build docs locally as HTML or other formats in site/
// An online HTML version (which may be of a different version of Emscripten)
//    is up at http://kripken.github.io/emscripten-site/docs/api_reference/preamble.js.html

//========================================
// Runtime code shared with compiler
//========================================

var Runtime = {
  setTempRet0: function (value) {
    tempRet0 = value;
    return value;
  },
  getTempRet0: function () {
    return tempRet0;
  },
  stackSave: function () {
    return STACKTOP;
  },
  stackRestore: function (stackTop) {
    STACKTOP = stackTop;
  },
  getNativeTypeSize: function (type) {
    switch (type) {
      case 'i1': case 'i8': return 1;
      case 'i16': return 2;
      case 'i32': return 4;
      case 'i64': return 8;
      case 'float': return 4;
      case 'double': return 8;
      default: {
        if (type[type.length-1] === '*') {
          return Runtime.QUANTUM_SIZE; // A pointer
        } else if (type[0] === 'i') {
          var bits = parseInt(type.substr(1));
          assert(bits % 8 === 0);
          return bits/8;
        } else {
          return 0;
        }
      }
    }
  },
  getNativeFieldSize: function (type) {
    return Math.max(Runtime.getNativeTypeSize(type), Runtime.QUANTUM_SIZE);
  },
  STACK_ALIGN: 16,
  prepVararg: function (ptr, type) {
    if (type === 'double' || type === 'i64') {
      // move so the load is aligned
      if (ptr & 7) {
        assert((ptr & 7) === 4);
        ptr += 4;
      }
    } else {
      assert((ptr & 3) === 0);
    }
    return ptr;
  },
  getAlignSize: function (type, size, vararg) {
    // we align i64s and doubles on 64-bit boundaries, unlike x86
    if (!vararg && (type == 'i64' || type == 'double')) return 8;
    if (!type) return Math.min(size, 8); // align structures internally to 64 bits
    return Math.min(size || (type ? Runtime.getNativeFieldSize(type) : 0), Runtime.QUANTUM_SIZE);
  },
  dynCall: function (sig, ptr, args) {
    if (args && args.length) {
      assert(args.length == sig.length-1);
      assert(('dynCall_' + sig) in Module, 'bad function pointer type - no table for sig \'' + sig + '\'');
      return Module['dynCall_' + sig].apply(null, [ptr].concat(args));
    } else {
      assert(sig.length == 1);
      assert(('dynCall_' + sig) in Module, 'bad function pointer type - no table for sig \'' + sig + '\'');
      return Module['dynCall_' + sig].call(null, ptr);
    }
  },
  functionPointers: [],
  addFunction: function (func) {
    for (var i = 0; i < Runtime.functionPointers.length; i++) {
      if (!Runtime.functionPointers[i]) {
        Runtime.functionPointers[i] = func;
        return 2*(1 + i);
      }
    }
    throw 'Finished up all reserved function pointers. Use a higher value for RESERVED_FUNCTION_POINTERS.';
  },
  removeFunction: function (index) {
    Runtime.functionPointers[(index-2)/2] = null;
  },
  warnOnce: function (text) {
    if (!Runtime.warnOnce.shown) Runtime.warnOnce.shown = {};
    if (!Runtime.warnOnce.shown[text]) {
      Runtime.warnOnce.shown[text] = 1;
      Module.printErr(text);
    }
  },
  funcWrappers: {},
  getFuncWrapper: function (func, sig) {
    assert(sig);
    if (!Runtime.funcWrappers[sig]) {
      Runtime.funcWrappers[sig] = {};
    }
    var sigCache = Runtime.funcWrappers[sig];
    if (!sigCache[func]) {
      // optimize away arguments usage in common cases
      if (sig.length === 1) {
        sigCache[func] = function dynCall_wrapper() {
          return Runtime.dynCall(sig, func);
        };
      } else if (sig.length === 2) {
        sigCache[func] = function dynCall_wrapper(arg) {
          return Runtime.dynCall(sig, func, [arg]);
        };
      } else {
        // general case
        sigCache[func] = function dynCall_wrapper() {
          return Runtime.dynCall(sig, func, Array.prototype.slice.call(arguments));
        };
      }
    }
    return sigCache[func];
  },
  getCompilerSetting: function (name) {
    throw 'You must build with -s RETAIN_COMPILER_SETTINGS=1 for Runtime.getCompilerSetting or emscripten_get_compiler_setting to work';
  },
  stackAlloc: function (size) { var ret = STACKTOP;STACKTOP = (STACKTOP + size)|0;STACKTOP = (((STACKTOP)+15)&-16);(assert((((STACKTOP|0) < (STACK_MAX|0))|0))|0); return ret; },
  staticAlloc: function (size) { var ret = STATICTOP;STATICTOP = (STATICTOP + (assert(!staticSealed),size))|0;STATICTOP = (((STATICTOP)+15)&-16); return ret; },
  dynamicAlloc: function (size) { assert(DYNAMICTOP_PTR);var ret = HEAP32[DYNAMICTOP_PTR>>2];var end = (((ret + size + 15)|0) & -16);HEAP32[DYNAMICTOP_PTR>>2] = end;if (end >= TOTAL_MEMORY) {var success = enlargeMemory();if (!success) {HEAP32[DYNAMICTOP_PTR>>2] = ret;return 0;}}return ret;},
  alignMemory: function (size,quantum) { var ret = size = Math.ceil((size)/(quantum ? quantum : 16))*(quantum ? quantum : 16); return ret; },
  makeBigInt: function (low,high,unsigned) { var ret = (unsigned ? ((+((low>>>0)))+((+((high>>>0)))*4294967296.0)) : ((+((low>>>0)))+((+((high|0)))*4294967296.0))); return ret; },
  GLOBAL_BASE: 8,
  QUANTUM_SIZE: 4,
  __dummy__: 0
}



Module["Runtime"] = Runtime;



//========================================
// Runtime essentials
//========================================

var ABORT = 0; // whether we are quitting the application. no code should run after this. set in exit() and abort()
var EXITSTATUS = 0;

/** @type {function(*, string=)} */
function assert(condition, text) {
  if (!condition) {
    abort('Assertion failed: ' + text);
  }
}

var globalScope = this;

// Returns the C function with a specified identifier (for C++, you need to do manual name mangling)
function getCFunc(ident) {
  var func = Module['_' + ident]; // closure exported function
  if (!func) {
    try { func = eval('_' + ident); } catch(e) {}
  }
  assert(func, 'Cannot call unknown function ' + ident + ' (perhaps LLVM optimizations or closure removed it?)');
  return func;
}

var cwrap, ccall;
(function(){
  var JSfuncs = {
    // Helpers for cwrap -- it can't refer to Runtime directly because it might
    // be renamed by closure, instead it calls JSfuncs['stackSave'].body to find
    // out what the minified function name is.
    'stackSave': function() {
      Runtime.stackSave()
    },
    'stackRestore': function() {
      Runtime.stackRestore()
    },
    // type conversion from js to c
    'arrayToC' : function(arr) {
      var ret = Runtime.stackAlloc(arr.length);
      writeArrayToMemory(arr, ret);
      return ret;
    },
    'stringToC' : function(str) {
      var ret = 0;
      if (str !== null && str !== undefined && str !== 0) { // null string
        // at most 4 bytes per UTF-8 code point, +1 for the trailing '\0'
        var len = (str.length << 2) + 1;
        ret = Runtime.stackAlloc(len);
        stringToUTF8(str, ret, len);
      }
      return ret;
    }
  };
  // For fast lookup of conversion functions
  var toC = {'string' : JSfuncs['stringToC'], 'array' : JSfuncs['arrayToC']};

  // C calling interface.
  ccall = function ccallFunc(ident, returnType, argTypes, args, opts) {
    var func = getCFunc(ident);
    var cArgs = [];
    var stack = 0;
    assert(returnType !== 'array', 'Return type should not be "array".');
    if (args) {
      for (var i = 0; i < args.length; i++) {
        var converter = toC[argTypes[i]];
        if (converter) {
          if (stack === 0) stack = Runtime.stackSave();
          cArgs[i] = converter(args[i]);
        } else {
          cArgs[i] = args[i];
        }
      }
    }
    var ret = func.apply(null, cArgs);
    if ((!opts || !opts.async) && typeof EmterpreterAsync === 'object') {
      assert(!EmterpreterAsync.state, 'cannot start async op with normal JS calling ccall');
    }
    if (opts && opts.async) assert(!returnType, 'async ccalls cannot return values');
    if (returnType === 'string') ret = Pointer_stringify(ret);
    if (stack !== 0) {
      if (opts && opts.async) {
        EmterpreterAsync.asyncFinalizers.push(function() {
          Runtime.stackRestore(stack);
        });
        return;
      }
      Runtime.stackRestore(stack);
    }
    return ret;
  }

  var sourceRegex = /^function\s*[a-zA-Z$_0-9]*\s*\(([^)]*)\)\s*{\s*([^*]*?)[\s;]*(?:return\s*(.*?)[;\s]*)?}$/;
  function parseJSFunc(jsfunc) {
    // Match the body and the return value of a javascript function source
    var parsed = jsfunc.toString().match(sourceRegex).slice(1);
    return {arguments : parsed[0], body : parsed[1], returnValue: parsed[2]}
  }

  // sources of useful functions. we create this lazily as it can trigger a source decompression on this entire file
  var JSsource = null;
  function ensureJSsource() {
    if (!JSsource) {
      JSsource = {};
      for (var fun in JSfuncs) {
        if (JSfuncs.hasOwnProperty(fun)) {
          // Elements of toCsource are arrays of three items:
          // the code, and the return value
          JSsource[fun] = parseJSFunc(JSfuncs[fun]);
        }
      }
    }
  }

  cwrap = function cwrap(ident, returnType, argTypes) {
    argTypes = argTypes || [];
    var cfunc = getCFunc(ident);
    // When the function takes numbers and returns a number, we can just return
    // the original function
    var numericArgs = argTypes.every(function(type){ return type === 'number'});
    var numericRet = (returnType !== 'string');
    if ( numericRet && numericArgs) {
      return cfunc;
    }
    // Creation of the arguments list (["$1","$2",...,"$nargs"])
    var argNames = argTypes.map(function(x,i){return '$'+i});
    var funcstr = "(function(" + argNames.join(',') + ") {";
    var nargs = argTypes.length;
    if (!numericArgs) {
      // Generate the code needed to convert the arguments from javascript
      // values to pointers
      ensureJSsource();
      funcstr += 'var stack = ' + JSsource['stackSave'].body + ';';
      for (var i = 0; i < nargs; i++) {
        var arg = argNames[i], type = argTypes[i];
        if (type === 'number') continue;
        var convertCode = JSsource[type + 'ToC']; // [code, return]
        funcstr += 'var ' + convertCode.arguments + ' = ' + arg + ';';
        funcstr += convertCode.body + ';';
        funcstr += arg + '=(' + convertCode.returnValue + ');';
      }
    }

    // When the code is compressed, the name of cfunc is not literally 'cfunc' anymore
    var cfuncname = parseJSFunc(function(){return cfunc}).returnValue;
    // Call the function
    funcstr += 'var ret = ' + cfuncname + '(' + argNames.join(',') + ');';
    if (!numericRet) { // Return type can only by 'string' or 'number'
      // Convert the result to a string
      var strgfy = parseJSFunc(function(){return Pointer_stringify}).returnValue;
      funcstr += 'ret = ' + strgfy + '(ret);';
    }
    funcstr += "if (typeof EmterpreterAsync === 'object') { assert(!EmterpreterAsync.state, 'cannot start async op with normal JS calling cwrap') }";
    if (!numericArgs) {
      // If we had a stack, restore it
      ensureJSsource();
      funcstr += JSsource['stackRestore'].body.replace('()', '(stack)') + ';';
    }
    funcstr += 'return ret})';
    return eval(funcstr);
  };
})();
Module["ccall"] = ccall;
Module["cwrap"] = cwrap;

/** @type {function(number, number, string, boolean=)} */
function setValue(ptr, value, type, noSafe) {
  type = type || 'i8';
  if (type.charAt(type.length-1) === '*') type = 'i32'; // pointers are 32-bit
    switch(type) {
      case 'i1': HEAP8[((ptr)>>0)]=value; break;
      case 'i8': HEAP8[((ptr)>>0)]=value; break;
      case 'i16': HEAP16[((ptr)>>1)]=value; break;
      case 'i32': HEAP32[((ptr)>>2)]=value; break;
      case 'i64': (tempI64 = [value>>>0,(tempDouble=value,(+(Math_abs(tempDouble))) >= 1.0 ? (tempDouble > 0.0 ? ((Math_min((+(Math_floor((tempDouble)/4294967296.0))), 4294967295.0))|0)>>>0 : (~~((+(Math_ceil((tempDouble - +(((~~(tempDouble)))>>>0))/4294967296.0)))))>>>0) : 0)],HEAP32[((ptr)>>2)]=tempI64[0],HEAP32[(((ptr)+(4))>>2)]=tempI64[1]); break;
      case 'float': HEAPF32[((ptr)>>2)]=value; break;
      case 'double': HEAPF64[((ptr)>>3)]=value; break;
      default: abort('invalid type for setValue: ' + type);
    }
}
Module["setValue"] = setValue;

/** @type {function(number, string, boolean=)} */
function getValue(ptr, type, noSafe) {
  type = type || 'i8';
  if (type.charAt(type.length-1) === '*') type = 'i32'; // pointers are 32-bit
    switch(type) {
      case 'i1': return HEAP8[((ptr)>>0)];
      case 'i8': return HEAP8[((ptr)>>0)];
      case 'i16': return HEAP16[((ptr)>>1)];
      case 'i32': return HEAP32[((ptr)>>2)];
      case 'i64': return HEAP32[((ptr)>>2)];
      case 'float': return HEAPF32[((ptr)>>2)];
      case 'double': return HEAPF64[((ptr)>>3)];
      default: abort('invalid type for setValue: ' + type);
    }
  return null;
}
Module["getValue"] = getValue;

var ALLOC_NORMAL = 0; // Tries to use _malloc()
var ALLOC_STACK = 1; // Lives for the duration of the current function call
var ALLOC_STATIC = 2; // Cannot be freed
var ALLOC_DYNAMIC = 3; // Cannot be freed except through sbrk
var ALLOC_NONE = 4; // Do not allocate
Module["ALLOC_NORMAL"] = ALLOC_NORMAL;
Module["ALLOC_STACK"] = ALLOC_STACK;
Module["ALLOC_STATIC"] = ALLOC_STATIC;
Module["ALLOC_DYNAMIC"] = ALLOC_DYNAMIC;
Module["ALLOC_NONE"] = ALLOC_NONE;

// allocate(): This is for internal use. You can use it yourself as well, but the interface
//             is a little tricky (see docs right below). The reason is that it is optimized
//             for multiple syntaxes to save space in generated code. So you should
//             normally not use allocate(), and instead allocate memory using _malloc(),
//             initialize it with setValue(), and so forth.
// @slab: An array of data, or a number. If a number, then the size of the block to allocate,
//        in *bytes* (note that this is sometimes confusing: the next parameter does not
//        affect this!)
// @types: Either an array of types, one for each byte (or 0 if no type at that position),
//         or a single type which is used for the entire block. This only matters if there
//         is initial data - if @slab is a number, then this does not matter at all and is
//         ignored.
// @allocator: How to allocate memory, see ALLOC_*
/** @type {function((TypedArray|Array<number>|number), string, number, number=)} */
function allocate(slab, types, allocator, ptr) {
  var zeroinit, size;
  if (typeof slab === 'number') {
    zeroinit = true;
    size = slab;
  } else {
    zeroinit = false;
    size = slab.length;
  }

  var singleType = typeof types === 'string' ? types : null;

  var ret;
  if (allocator == ALLOC_NONE) {
    ret = ptr;
  } else {
    ret = [typeof _malloc === 'function' ? _malloc : Runtime.staticAlloc, Runtime.stackAlloc, Runtime.staticAlloc, Runtime.dynamicAlloc][allocator === undefined ? ALLOC_STATIC : allocator](Math.max(size, singleType ? 1 : types.length));
  }

  if (zeroinit) {
    var ptr = ret, stop;
    assert((ret & 3) == 0);
    stop = ret + (size & ~3);
    for (; ptr < stop; ptr += 4) {
      HEAP32[((ptr)>>2)]=0;
    }
    stop = ret + size;
    while (ptr < stop) {
      HEAP8[((ptr++)>>0)]=0;
    }
    return ret;
  }

  if (singleType === 'i8') {
    if (slab.subarray || slab.slice) {
      HEAPU8.set(/** @type {!Uint8Array} */ (slab), ret);
    } else {
      HEAPU8.set(new Uint8Array(slab), ret);
    }
    return ret;
  }

  var i = 0, type, typeSize, previousType;
  while (i < size) {
    var curr = slab[i];

    if (typeof curr === 'function') {
      curr = Runtime.getFunctionIndex(curr);
    }

    type = singleType || types[i];
    if (type === 0) {
      i++;
      continue;
    }
    assert(type, 'Must know what type to store in allocate!');

    if (type == 'i64') type = 'i32'; // special case: we have one i32 here, and one i32 later

    setValue(ret+i, curr, type);

    // no need to look up size unless type changes, so cache it
    if (previousType !== type) {
      typeSize = Runtime.getNativeTypeSize(type);
      previousType = type;
    }
    i += typeSize;
  }

  return ret;
}
Module["allocate"] = allocate;

// Allocate memory during any stage of startup - static memory early on, dynamic memory later, malloc when ready
function getMemory(size) {
  if (!staticSealed) return Runtime.staticAlloc(size);
  if (!runtimeInitialized) return Runtime.dynamicAlloc(size);
  return _malloc(size);
}
Module["getMemory"] = getMemory;

/** @type {function(number, number=)} */
function Pointer_stringify(ptr, length) {
  if (length === 0 || !ptr) return '';
  // TODO: use TextDecoder
  // Find the length, and check for UTF while doing so
  var hasUtf = 0;
  var t;
  var i = 0;
  while (1) {
    assert(ptr + i < TOTAL_MEMORY);
    t = HEAPU8[(((ptr)+(i))>>0)];
    hasUtf |= t;
    if (t == 0 && !length) break;
    i++;
    if (length && i == length) break;
  }
  if (!length) length = i;

  var ret = '';

  if (hasUtf < 128) {
    var MAX_CHUNK = 1024; // split up into chunks, because .apply on a huge string can overflow the stack
    var curr;
    while (length > 0) {
      curr = String.fromCharCode.apply(String, HEAPU8.subarray(ptr, ptr + Math.min(length, MAX_CHUNK)));
      ret = ret ? ret + curr : curr;
      ptr += MAX_CHUNK;
      length -= MAX_CHUNK;
    }
    return ret;
  }
  return Module['UTF8ToString'](ptr);
}
Module["Pointer_stringify"] = Pointer_stringify;

// Given a pointer 'ptr' to a null-terminated ASCII-encoded string in the emscripten HEAP, returns
// a copy of that string as a Javascript String object.

function AsciiToString(ptr) {
  var str = '';
  while (1) {
    var ch = HEAP8[((ptr++)>>0)];
    if (!ch) return str;
    str += String.fromCharCode(ch);
  }
}
Module["AsciiToString"] = AsciiToString;

// Copies the given Javascript String object 'str' to the emscripten HEAP at address 'outPtr',
// null-terminated and encoded in ASCII form. The copy will require at most str.length+1 bytes of space in the HEAP.

function stringToAscii(str, outPtr) {
  return writeAsciiToMemory(str, outPtr, false);
}
Module["stringToAscii"] = stringToAscii;

// Given a pointer 'ptr' to a null-terminated UTF8-encoded string in the given array that contains uint8 values, returns
// a copy of that string as a Javascript String object.

var UTF8Decoder = typeof TextDecoder !== 'undefined' ? new TextDecoder('utf8') : undefined;
function UTF8ArrayToString(u8Array, idx) {
  var endPtr = idx;
  // TextDecoder needs to know the byte length in advance, it doesn't stop on null terminator by itself.
  // Also, use the length info to avoid running tiny strings through TextDecoder, since .subarray() allocates garbage.
  while (u8Array[endPtr]) ++endPtr;

  if (endPtr - idx > 16 && u8Array.subarray && UTF8Decoder) {
    return UTF8Decoder.decode(u8Array.subarray(idx, endPtr));
  } else {
    var u0, u1, u2, u3, u4, u5;

    var str = '';
    while (1) {
      // For UTF8 byte structure, see http://en.wikipedia.org/wiki/UTF-8#Description and https://www.ietf.org/rfc/rfc2279.txt and https://tools.ietf.org/html/rfc3629
      u0 = u8Array[idx++];
      if (!u0) return str;
      if (!(u0 & 0x80)) { str += String.fromCharCode(u0); continue; }
      u1 = u8Array[idx++] & 63;
      if ((u0 & 0xE0) == 0xC0) { str += String.fromCharCode(((u0 & 31) << 6) | u1); continue; }
      u2 = u8Array[idx++] & 63;
      if ((u0 & 0xF0) == 0xE0) {
        u0 = ((u0 & 15) << 12) | (u1 << 6) | u2;
      } else {
        u3 = u8Array[idx++] & 63;
        if ((u0 & 0xF8) == 0xF0) {
          u0 = ((u0 & 7) << 18) | (u1 << 12) | (u2 << 6) | u3;
        } else {
          u4 = u8Array[idx++] & 63;
          if ((u0 & 0xFC) == 0xF8) {
            u0 = ((u0 & 3) << 24) | (u1 << 18) | (u2 << 12) | (u3 << 6) | u4;
          } else {
            u5 = u8Array[idx++] & 63;
            u0 = ((u0 & 1) << 30) | (u1 << 24) | (u2 << 18) | (u3 << 12) | (u4 << 6) | u5;
          }
        }
      }
      if (u0 < 0x10000) {
        str += String.fromCharCode(u0);
      } else {
        var ch = u0 - 0x10000;
        str += String.fromCharCode(0xD800 | (ch >> 10), 0xDC00 | (ch & 0x3FF));
      }
    }
  }
}
Module["UTF8ArrayToString"] = UTF8ArrayToString;

// Given a pointer 'ptr' to a null-terminated UTF8-encoded string in the emscripten HEAP, returns
// a copy of that string as a Javascript String object.

function UTF8ToString(ptr) {
  return UTF8ArrayToString(HEAPU8,ptr);
}
Module["UTF8ToString"] = UTF8ToString;

// Copies the given Javascript String object 'str' to the given byte array at address 'outIdx',
// encoded in UTF8 form and null-terminated. The copy will require at most str.length*4+1 bytes of space in the HEAP.
// Use the function lengthBytesUTF8 to compute the exact number of bytes (excluding null terminator) that this function will write.
// Parameters:
//   str: the Javascript string to copy.
//   outU8Array: the array to copy to. Each index in this array is assumed to be one 8-byte element.
//   outIdx: The starting offset in the array to begin the copying.
//   maxBytesToWrite: The maximum number of bytes this function can write to the array. This count should include the null
//                    terminator, i.e. if maxBytesToWrite=1, only the null terminator will be written and nothing else.
//                    maxBytesToWrite=0 does not write any bytes to the output, not even the null terminator.
// Returns the number of bytes written, EXCLUDING the null terminator.

function stringToUTF8Array(str, outU8Array, outIdx, maxBytesToWrite) {
  if (!(maxBytesToWrite > 0)) // Parameter maxBytesToWrite is not optional. Negative values, 0, null, undefined and false each don't write out any bytes.
    return 0;

  var startIdx = outIdx;
  var endIdx = outIdx + maxBytesToWrite - 1; // -1 for string null terminator.
  for (var i = 0; i < str.length; ++i) {
    // Gotcha: charCodeAt returns a 16-bit word that is a UTF-16 encoded code unit, not a Unicode code point of the character! So decode UTF16->UTF32->UTF8.
    // See http://unicode.org/faq/utf_bom.html#utf16-3
    // For UTF8 byte structure, see http://en.wikipedia.org/wiki/UTF-8#Description and https://www.ietf.org/rfc/rfc2279.txt and https://tools.ietf.org/html/rfc3629
    var u = str.charCodeAt(i); // possibly a lead surrogate
    if (u >= 0xD800 && u <= 0xDFFF) u = 0x10000 + ((u & 0x3FF) << 10) | (str.charCodeAt(++i) & 0x3FF);
    if (u <= 0x7F) {
      if (outIdx >= endIdx) break;
      outU8Array[outIdx++] = u;
    } else if (u <= 0x7FF) {
      if (outIdx + 1 >= endIdx) break;
      outU8Array[outIdx++] = 0xC0 | (u >> 6);
      outU8Array[outIdx++] = 0x80 | (u & 63);
    } else if (u <= 0xFFFF) {
      if (outIdx + 2 >= endIdx) break;
      outU8Array[outIdx++] = 0xE0 | (u >> 12);
      outU8Array[outIdx++] = 0x80 | ((u >> 6) & 63);
      outU8Array[outIdx++] = 0x80 | (u & 63);
    } else if (u <= 0x1FFFFF) {
      if (outIdx + 3 >= endIdx) break;
      outU8Array[outIdx++] = 0xF0 | (u >> 18);
      outU8Array[outIdx++] = 0x80 | ((u >> 12) & 63);
      outU8Array[outIdx++] = 0x80 | ((u >> 6) & 63);
      outU8Array[outIdx++] = 0x80 | (u & 63);
    } else if (u <= 0x3FFFFFF) {
      if (outIdx + 4 >= endIdx) break;
      outU8Array[outIdx++] = 0xF8 | (u >> 24);
      outU8Array[outIdx++] = 0x80 | ((u >> 18) & 63);
      outU8Array[outIdx++] = 0x80 | ((u >> 12) & 63);
      outU8Array[outIdx++] = 0x80 | ((u >> 6) & 63);
      outU8Array[outIdx++] = 0x80 | (u & 63);
    } else {
      if (outIdx + 5 >= endIdx) break;
      outU8Array[outIdx++] = 0xFC | (u >> 30);
      outU8Array[outIdx++] = 0x80 | ((u >> 24) & 63);
      outU8Array[outIdx++] = 0x80 | ((u >> 18) & 63);
      outU8Array[outIdx++] = 0x80 | ((u >> 12) & 63);
      outU8Array[outIdx++] = 0x80 | ((u >> 6) & 63);
      outU8Array[outIdx++] = 0x80 | (u & 63);
    }
  }
  // Null-terminate the pointer to the buffer.
  outU8Array[outIdx] = 0;
  return outIdx - startIdx;
}
Module["stringToUTF8Array"] = stringToUTF8Array;

// Copies the given Javascript String object 'str' to the emscripten HEAP at address 'outPtr',
// null-terminated and encoded in UTF8 form. The copy will require at most str.length*4+1 bytes of space in the HEAP.
// Use the function lengthBytesUTF8 to compute the exact number of bytes (excluding null terminator) that this function will write.
// Returns the number of bytes written, EXCLUDING the null terminator.

function stringToUTF8(str, outPtr, maxBytesToWrite) {
  assert(typeof maxBytesToWrite == 'number', 'stringToUTF8(str, outPtr, maxBytesToWrite) is missing the third parameter that specifies the length of the output buffer!');
  return stringToUTF8Array(str, HEAPU8,outPtr, maxBytesToWrite);
}
Module["stringToUTF8"] = stringToUTF8;

// Returns the number of bytes the given Javascript string takes if encoded as a UTF8 byte array, EXCLUDING the null terminator byte.

function lengthBytesUTF8(str) {
  var len = 0;
  for (var i = 0; i < str.length; ++i) {
    // Gotcha: charCodeAt returns a 16-bit word that is a UTF-16 encoded code unit, not a Unicode code point of the character! So decode UTF16->UTF32->UTF8.
    // See http://unicode.org/faq/utf_bom.html#utf16-3
    var u = str.charCodeAt(i); // possibly a lead surrogate
    if (u >= 0xD800 && u <= 0xDFFF) u = 0x10000 + ((u & 0x3FF) << 10) | (str.charCodeAt(++i) & 0x3FF);
    if (u <= 0x7F) {
      ++len;
    } else if (u <= 0x7FF) {
      len += 2;
    } else if (u <= 0xFFFF) {
      len += 3;
    } else if (u <= 0x1FFFFF) {
      len += 4;
    } else if (u <= 0x3FFFFFF) {
      len += 5;
    } else {
      len += 6;
    }
  }
  return len;
}
Module["lengthBytesUTF8"] = lengthBytesUTF8;

// Given a pointer 'ptr' to a null-terminated UTF16LE-encoded string in the emscripten HEAP, returns
// a copy of that string as a Javascript String object.

var UTF16Decoder = typeof TextDecoder !== 'undefined' ? new TextDecoder('utf-16le') : undefined;
function UTF16ToString(ptr) {
  assert(ptr % 2 == 0, 'Pointer passed to UTF16ToString must be aligned to two bytes!');
  var endPtr = ptr;
  // TextDecoder needs to know the byte length in advance, it doesn't stop on null terminator by itself.
  // Also, use the length info to avoid running tiny strings through TextDecoder, since .subarray() allocates garbage.
  var idx = endPtr >> 1;
  while (HEAP16[idx]) ++idx;
  endPtr = idx << 1;

  if (endPtr - ptr > 32 && UTF16Decoder) {
    return UTF16Decoder.decode(HEAPU8.subarray(ptr, endPtr));
  } else {
    var i = 0;

    var str = '';
    while (1) {
      var codeUnit = HEAP16[(((ptr)+(i*2))>>1)];
      if (codeUnit == 0) return str;
      ++i;
      // fromCharCode constructs a character from a UTF-16 code unit, so we can pass the UTF16 string right through.
      str += String.fromCharCode(codeUnit);
    }
  }
}


// Copies the given Javascript String object 'str' to the emscripten HEAP at address 'outPtr',
// null-terminated and encoded in UTF16 form. The copy will require at most str.length*4+2 bytes of space in the HEAP.
// Use the function lengthBytesUTF16() to compute the exact number of bytes (excluding null terminator) that this function will write.
// Parameters:
//   str: the Javascript string to copy.
//   outPtr: Byte address in Emscripten HEAP where to write the string to.
//   maxBytesToWrite: The maximum number of bytes this function can write to the array. This count should include the null
//                    terminator, i.e. if maxBytesToWrite=2, only the null terminator will be written and nothing else.
//                    maxBytesToWrite<2 does not write any bytes to the output, not even the null terminator.
// Returns the number of bytes written, EXCLUDING the null terminator.

function stringToUTF16(str, outPtr, maxBytesToWrite) {
  assert(outPtr % 2 == 0, 'Pointer passed to stringToUTF16 must be aligned to two bytes!');
  assert(typeof maxBytesToWrite == 'number', 'stringToUTF16(str, outPtr, maxBytesToWrite) is missing the third parameter that specifies the length of the output buffer!');
  // Backwards compatibility: if max bytes is not specified, assume unsafe unbounded write is allowed.
  if (maxBytesToWrite === undefined) {
    maxBytesToWrite = 0x7FFFFFFF;
  }
  if (maxBytesToWrite < 2) return 0;
  maxBytesToWrite -= 2; // Null terminator.
  var startPtr = outPtr;
  var numCharsToWrite = (maxBytesToWrite < str.length*2) ? (maxBytesToWrite / 2) : str.length;
  for (var i = 0; i < numCharsToWrite; ++i) {
    // charCodeAt returns a UTF-16 encoded code unit, so it can be directly written to the HEAP.
    var codeUnit = str.charCodeAt(i); // possibly a lead surrogate
    HEAP16[((outPtr)>>1)]=codeUnit;
    outPtr += 2;
  }
  // Null-terminate the pointer to the HEAP.
  HEAP16[((outPtr)>>1)]=0;
  return outPtr - startPtr;
}


// Returns the number of bytes the given Javascript string takes if encoded as a UTF16 byte array, EXCLUDING the null terminator byte.

function lengthBytesUTF16(str) {
  return str.length*2;
}


function UTF32ToString(ptr) {
  assert(ptr % 4 == 0, 'Pointer passed to UTF32ToString must be aligned to four bytes!');
  var i = 0;

  var str = '';
  while (1) {
    var utf32 = HEAP32[(((ptr)+(i*4))>>2)];
    if (utf32 == 0)
      return str;
    ++i;
    // Gotcha: fromCharCode constructs a character from a UTF-16 encoded code (pair), not from a Unicode code point! So encode the code point to UTF-16 for constructing.
    // See http://unicode.org/faq/utf_bom.html#utf16-3
    if (utf32 >= 0x10000) {
      var ch = utf32 - 0x10000;
      str += String.fromCharCode(0xD800 | (ch >> 10), 0xDC00 | (ch & 0x3FF));
    } else {
      str += String.fromCharCode(utf32);
    }
  }
}


// Copies the given Javascript String object 'str' to the emscripten HEAP at address 'outPtr',
// null-terminated and encoded in UTF32 form. The copy will require at most str.length*4+4 bytes of space in the HEAP.
// Use the function lengthBytesUTF32() to compute the exact number of bytes (excluding null terminator) that this function will write.
// Parameters:
//   str: the Javascript string to copy.
//   outPtr: Byte address in Emscripten HEAP where to write the string to.
//   maxBytesToWrite: The maximum number of bytes this function can write to the array. This count should include the null
//                    terminator, i.e. if maxBytesToWrite=4, only the null terminator will be written and nothing else.
//                    maxBytesToWrite<4 does not write any bytes to the output, not even the null terminator.
// Returns the number of bytes written, EXCLUDING the null terminator.

function stringToUTF32(str, outPtr, maxBytesToWrite) {
  assert(outPtr % 4 == 0, 'Pointer passed to stringToUTF32 must be aligned to four bytes!');
  assert(typeof maxBytesToWrite == 'number', 'stringToUTF32(str, outPtr, maxBytesToWrite) is missing the third parameter that specifies the length of the output buffer!');
  // Backwards compatibility: if max bytes is not specified, assume unsafe unbounded write is allowed.
  if (maxBytesToWrite === undefined) {
    maxBytesToWrite = 0x7FFFFFFF;
  }
  if (maxBytesToWrite < 4) return 0;
  var startPtr = outPtr;
  var endPtr = startPtr + maxBytesToWrite - 4;
  for (var i = 0; i < str.length; ++i) {
    // Gotcha: charCodeAt returns a 16-bit word that is a UTF-16 encoded code unit, not a Unicode code point of the character! We must decode the string to UTF-32 to the heap.
    // See http://unicode.org/faq/utf_bom.html#utf16-3
    var codeUnit = str.charCodeAt(i); // possibly a lead surrogate
    if (codeUnit >= 0xD800 && codeUnit <= 0xDFFF) {
      var trailSurrogate = str.charCodeAt(++i);
      codeUnit = 0x10000 + ((codeUnit & 0x3FF) << 10) | (trailSurrogate & 0x3FF);
    }
    HEAP32[((outPtr)>>2)]=codeUnit;
    outPtr += 4;
    if (outPtr + 4 > endPtr) break;
  }
  // Null-terminate the pointer to the HEAP.
  HEAP32[((outPtr)>>2)]=0;
  return outPtr - startPtr;
}


// Returns the number of bytes the given Javascript string takes if encoded as a UTF16 byte array, EXCLUDING the null terminator byte.

function lengthBytesUTF32(str) {
  var len = 0;
  for (var i = 0; i < str.length; ++i) {
    // Gotcha: charCodeAt returns a 16-bit word that is a UTF-16 encoded code unit, not a Unicode code point of the character! We must decode the string to UTF-32 to the heap.
    // See http://unicode.org/faq/utf_bom.html#utf16-3
    var codeUnit = str.charCodeAt(i);
    if (codeUnit >= 0xD800 && codeUnit <= 0xDFFF) ++i; // possibly a lead surrogate, so skip over the tail surrogate.
    len += 4;
  }

  return len;
}


function demangle(func) {
  var __cxa_demangle_func = Module['___cxa_demangle'] || Module['__cxa_demangle'];
  if (__cxa_demangle_func) {
    try {
      var s =
        func.substr(1);
      var len = lengthBytesUTF8(s)+1;
      var buf = _malloc(len);
      stringToUTF8(s, buf, len);
      var status = _malloc(4);
      var ret = __cxa_demangle_func(buf, 0, 0, status);
      if (getValue(status, 'i32') === 0 && ret) {
        return Pointer_stringify(ret);
      }
      // otherwise, libcxxabi failed
    } catch(e) {
      // ignore problems here
    } finally {
      if (buf) _free(buf);
      if (status) _free(status);
      if (ret) _free(ret);
    }
    // failure when using libcxxabi, don't demangle
    return func;
  }
  Runtime.warnOnce('warning: build with  -s DEMANGLE_SUPPORT=1  to link in libcxxabi demangling');
  return func;
}

function demangleAll(text) {
  var regex =
    /__Z[\w\d_]+/g;
  return text.replace(regex,
    function(x) {
      var y = demangle(x);
      return x === y ? x : (x + ' [' + y + ']');
    });
}

function jsStackTrace() {
  var err = new Error();
  if (!err.stack) {
    // IE10+ special cases: It does have callstack info, but it is only populated if an Error object is thrown,
    // so try that as a special-case.
    try {
      throw new Error(0);
    } catch(e) {
      err = e;
    }
    if (!err.stack) {
      return '(no stack trace available)';
    }
  }
  return err.stack.toString();
}

function stackTrace() {
  var js = jsStackTrace();
  if (Module['extraStackTrace']) js += '\n' + Module['extraStackTrace']();
  return demangleAll(js);
}
Module["stackTrace"] = stackTrace;

// Memory management

var PAGE_SIZE = 16384;
var WASM_PAGE_SIZE = 65536;
var ASMJS_PAGE_SIZE = 16777216;
var MIN_TOTAL_MEMORY = 16777216;

function alignUp(x, multiple) {
  if (x % multiple > 0) {
    x += multiple - (x % multiple);
  }
  return x;
}

var HEAP,
/** @type {ArrayBuffer} */
  buffer,
/** @type {Int8Array} */
  HEAP8,
/** @type {Uint8Array} */
  HEAPU8,
/** @type {Int16Array} */
  HEAP16,
/** @type {Uint16Array} */
  HEAPU16,
/** @type {Int32Array} */
  HEAP32,
/** @type {Uint32Array} */
  HEAPU32,
/** @type {Float32Array} */
  HEAPF32,
/** @type {Float64Array} */
  HEAPF64;

function updateGlobalBuffer(buf) {
  Module['buffer'] = buffer = buf;
}

function updateGlobalBufferViews() {
  Module['HEAP8'] = HEAP8 = new Int8Array(buffer);
  Module['HEAP16'] = HEAP16 = new Int16Array(buffer);
  Module['HEAP32'] = HEAP32 = new Int32Array(buffer);
  Module['HEAPU8'] = HEAPU8 = new Uint8Array(buffer);
  Module['HEAPU16'] = HEAPU16 = new Uint16Array(buffer);
  Module['HEAPU32'] = HEAPU32 = new Uint32Array(buffer);
  Module['HEAPF32'] = HEAPF32 = new Float32Array(buffer);
  Module['HEAPF64'] = HEAPF64 = new Float64Array(buffer);
}

var STATIC_BASE, STATICTOP, staticSealed; // static area
var STACK_BASE, STACKTOP, STACK_MAX; // stack area
var DYNAMIC_BASE, DYNAMICTOP_PTR; // dynamic area handled by sbrk

  STATIC_BASE = STATICTOP = STACK_BASE = STACKTOP = STACK_MAX = DYNAMIC_BASE = DYNAMICTOP_PTR = 0;
  staticSealed = false;


// Initializes the stack cookie. Called at the startup of main and at the startup of each thread in pthreads mode.
function writeStackCookie() {
  assert((STACK_MAX & 3) == 0);
  HEAPU32[(STACK_MAX >> 2)-1] = 0x02135467;
  HEAPU32[(STACK_MAX >> 2)-2] = 0x89BACDFE;
}

function checkStackCookie() {
  if (HEAPU32[(STACK_MAX >> 2)-1] != 0x02135467 || HEAPU32[(STACK_MAX >> 2)-2] != 0x89BACDFE) {
    abort('Stack overflow! Stack cookie has been overwritten, expected hex dwords 0x89BACDFE and 0x02135467, but received 0x' + HEAPU32[(STACK_MAX >> 2)-2].toString(16) + ' ' + HEAPU32[(STACK_MAX >> 2)-1].toString(16));
  }
  // Also test the global address 0 for integrity. This check is not compatible with SAFE_SPLIT_MEMORY though, since that mode already tests all address 0 accesses on its own.
  if (HEAP32[0] !== 0x63736d65 /* 'emsc' */) throw 'Runtime error: The application has corrupted its heap memory area (address zero)!';
}

function abortStackOverflow(allocSize) {
  abort('Stack overflow! Attempted to allocate ' + allocSize + ' bytes on the stack, but stack has only ' + (STACK_MAX - Module['asm'].stackSave() + allocSize) + ' bytes available!');
}

function abortOnCannotGrowMemory() {
  abort('Cannot enlarge memory arrays. Either (1) compile with  -s TOTAL_MEMORY=X  with X higher than the current value ' + TOTAL_MEMORY + ', (2) compile with  -s ALLOW_MEMORY_GROWTH=1  which allows increasing the size at runtime but prevents some optimizations, (3) set Module.TOTAL_MEMORY to a higher value before the program runs, or (4) if you want malloc to return NULL (0) instead of this abort, compile with  -s ABORTING_MALLOC=0 ');
}


function enlargeMemory() {
  abortOnCannotGrowMemory();
}


var TOTAL_STACK = Module['TOTAL_STACK'] || 5242880;
var TOTAL_MEMORY = Module['TOTAL_MEMORY'] || 16777216;
if (TOTAL_MEMORY < TOTAL_STACK) Module.printErr('TOTAL_MEMORY should be larger than TOTAL_STACK, was ' + TOTAL_MEMORY + '! (TOTAL_STACK=' + TOTAL_STACK + ')');

// Initialize the runtime's memory
// check for full engine support (use string 'subarray' to avoid closure compiler confusion)
assert(typeof Int32Array !== 'undefined' && typeof Float64Array !== 'undefined' && Int32Array.prototype.subarray !== undefined && Int32Array.prototype.set !== undefined,
       'JS engine does not provide full typed array support');



// Use a provided buffer, if there is one, or else allocate a new one
if (Module['buffer']) {
  buffer = Module['buffer'];
  assert(buffer.byteLength === TOTAL_MEMORY, 'provided buffer should be ' + TOTAL_MEMORY + ' bytes, but it is ' + buffer.byteLength);
} else {
  // Use a WebAssembly memory where available
  {
    buffer = new ArrayBuffer(TOTAL_MEMORY);
  }
  assert(buffer.byteLength === TOTAL_MEMORY);
}
updateGlobalBufferViews();


function getTotalMemory() {
  return TOTAL_MEMORY;
}

// Endianness check (note: assumes compiler arch was little-endian)
  HEAP32[0] = 0x63736d65; /* 'emsc' */
HEAP16[1] = 0x6373;
if (HEAPU8[2] !== 0x73 || HEAPU8[3] !== 0x63) throw 'Runtime error: expected the system to be little-endian!';

Module['HEAP'] = HEAP;
Module['buffer'] = buffer;
Module['HEAP8'] = HEAP8;
Module['HEAP16'] = HEAP16;
Module['HEAP32'] = HEAP32;
Module['HEAPU8'] = HEAPU8;
Module['HEAPU16'] = HEAPU16;
Module['HEAPU32'] = HEAPU32;
Module['HEAPF32'] = HEAPF32;
Module['HEAPF64'] = HEAPF64;

function callRuntimeCallbacks(callbacks) {
  while(callbacks.length > 0) {
    var callback = callbacks.shift();
    if (typeof callback == 'function') {
      callback();
      continue;
    }
    var func = callback.func;
    if (typeof func === 'number') {
      if (callback.arg === undefined) {
        Module['dynCall_v'](func);
      } else {
        Module['dynCall_vi'](func, callback.arg);
      }
    } else {
      func(callback.arg === undefined ? null : callback.arg);
    }
  }
}

var __ATPRERUN__  = []; // functions called before the runtime is initialized
var __ATINIT__    = []; // functions called during startup
var __ATMAIN__    = []; // functions called when main() is to be run
var __ATEXIT__    = []; // functions called during shutdown
var __ATPOSTRUN__ = []; // functions called after the runtime has exited

var runtimeInitialized = false;
var runtimeExited = false;


function preRun() {
  // compatibility - merge in anything from Module['preRun'] at this time
  if (Module['preRun']) {
    if (typeof Module['preRun'] == 'function') Module['preRun'] = [Module['preRun']];
    while (Module['preRun'].length) {
      addOnPreRun(Module['preRun'].shift());
    }
  }
  callRuntimeCallbacks(__ATPRERUN__);
}

function ensureInitRuntime() {
  checkStackCookie();
  if (runtimeInitialized) return;
  runtimeInitialized = true;
  callRuntimeCallbacks(__ATINIT__);
}

function preMain() {
  checkStackCookie();
  callRuntimeCallbacks(__ATMAIN__);
}

function exitRuntime() {
  checkStackCookie();
  callRuntimeCallbacks(__ATEXIT__);
  runtimeExited = true;
}

function postRun() {
  checkStackCookie();
  // compatibility - merge in anything from Module['postRun'] at this time
  if (Module['postRun']) {
    if (typeof Module['postRun'] == 'function') Module['postRun'] = [Module['postRun']];
    while (Module['postRun'].length) {
      addOnPostRun(Module['postRun'].shift());
    }
  }
  callRuntimeCallbacks(__ATPOSTRUN__);
}

function addOnPreRun(cb) {
  __ATPRERUN__.unshift(cb);
}
Module["addOnPreRun"] = addOnPreRun;

function addOnInit(cb) {
  __ATINIT__.unshift(cb);
}
Module["addOnInit"] = addOnInit;

function addOnPreMain(cb) {
  __ATMAIN__.unshift(cb);
}
Module["addOnPreMain"] = addOnPreMain;

function addOnExit(cb) {
  __ATEXIT__.unshift(cb);
}
Module["addOnExit"] = addOnExit;

function addOnPostRun(cb) {
  __ATPOSTRUN__.unshift(cb);
}
Module["addOnPostRun"] = addOnPostRun;

// Tools

/** @type {function(string, boolean=, number=)} */
function intArrayFromString(stringy, dontAddNull, length) {
  var len = length > 0 ? length : lengthBytesUTF8(stringy)+1;
  var u8array = new Array(len);
  var numBytesWritten = stringToUTF8Array(stringy, u8array, 0, u8array.length);
  if (dontAddNull) u8array.length = numBytesWritten;
  return u8array;
}
Module["intArrayFromString"] = intArrayFromString;

function intArrayToString(array) {
  var ret = [];
  for (var i = 0; i < array.length; i++) {
    var chr = array[i];
    if (chr > 0xFF) {
      assert(false, 'Character code ' + chr + ' (' + String.fromCharCode(chr) + ')  at offset ' + i + ' not in 0x00-0xFF.');
      chr &= 0xFF;
    }
    ret.push(String.fromCharCode(chr));
  }
  return ret.join('');
}
Module["intArrayToString"] = intArrayToString;

// Deprecated: This function should not be called because it is unsafe and does not provide
// a maximum length limit of how many bytes it is allowed to write. Prefer calling the
// function stringToUTF8Array() instead, which takes in a maximum length that can be used
// to be secure from out of bounds writes.
/** @deprecated */
function writeStringToMemory(string, buffer, dontAddNull) {
  Runtime.warnOnce('writeStringToMemory is deprecated and should not be called! Use stringToUTF8() instead!');

  var /** @type {number} */ lastChar, /** @type {number} */ end;
  if (dontAddNull) {
    // stringToUTF8Array always appends null. If we don't want to do that, remember the
    // character that existed at the location where the null will be placed, and restore
    // that after the write (below).
    end = buffer + lengthBytesUTF8(string);
    lastChar = HEAP8[end];
  }
  stringToUTF8(string, buffer, Infinity);
  if (dontAddNull) HEAP8[end] = lastChar; // Restore the value under the null character.
}
Module["writeStringToMemory"] = writeStringToMemory;

function writeArrayToMemory(array, buffer) {
  assert(array.length >= 0, 'writeArrayToMemory array must have a length (should be an array or typed array)')
  HEAP8.set(array, buffer);
}
Module["writeArrayToMemory"] = writeArrayToMemory;

function writeAsciiToMemory(str, buffer, dontAddNull) {
  for (var i = 0; i < str.length; ++i) {
    assert(str.charCodeAt(i) === str.charCodeAt(i)&0xff);
    HEAP8[((buffer++)>>0)]=str.charCodeAt(i);
  }
  // Null-terminate the pointer to the HEAP.
  if (!dontAddNull) HEAP8[((buffer)>>0)]=0;
}
Module["writeAsciiToMemory"] = writeAsciiToMemory;

function unSign(value, bits, ignore) {
  if (value >= 0) {
    return value;
  }
  return bits <= 32 ? 2*Math.abs(1 << (bits-1)) + value // Need some trickery, since if bits == 32, we are right at the limit of the bits JS uses in bitshifts
                    : Math.pow(2, bits)         + value;
}
function reSign(value, bits, ignore) {
  if (value <= 0) {
    return value;
  }
  var half = bits <= 32 ? Math.abs(1 << (bits-1)) // abs is needed if bits == 32
                        : Math.pow(2, bits-1);
  if (value >= half && (bits <= 32 || value > half)) { // for huge values, we can hit the precision limit and always get true here. so don't do that
                                                       // but, in general there is no perfect solution here. With 64-bit ints, we get rounding and errors
                                                       // TODO: In i64 mode 1, resign the two parts separately and safely
    value = -2*half + value; // Cannot bitshift half, as it may be at the limit of the bits JS uses in bitshifts
  }
  return value;
}

// check for imul support, and also for correctness ( https://bugs.webkit.org/show_bug.cgi?id=126345 )
if (!Math['imul'] || Math['imul'](0xffffffff, 5) !== -5) Math['imul'] = function imul(a, b) {
  var ah  = a >>> 16;
  var al = a & 0xffff;
  var bh  = b >>> 16;
  var bl = b & 0xffff;
  return (al*bl + ((ah*bl + al*bh) << 16))|0;
};
Math.imul = Math['imul'];


if (!Math['clz32']) Math['clz32'] = function(x) {
  x = x >>> 0;
  for (var i = 0; i < 32; i++) {
    if (x & (1 << (31 - i))) return i;
  }
  return 32;
};
Math.clz32 = Math['clz32']

if (!Math['trunc']) Math['trunc'] = function(x) {
  return x < 0 ? Math.ceil(x) : Math.floor(x);
};
Math.trunc = Math['trunc'];

var Math_abs = Math.abs;
var Math_cos = Math.cos;
var Math_sin = Math.sin;
var Math_tan = Math.tan;
var Math_acos = Math.acos;
var Math_asin = Math.asin;
var Math_atan = Math.atan;
var Math_atan2 = Math.atan2;
var Math_exp = Math.exp;
var Math_log = Math.log;
var Math_sqrt = Math.sqrt;
var Math_ceil = Math.ceil;
var Math_floor = Math.floor;
var Math_pow = Math.pow;
var Math_imul = Math.imul;
var Math_fround = Math.fround;
var Math_round = Math.round;
var Math_min = Math.min;
var Math_clz32 = Math.clz32;
var Math_trunc = Math.trunc;

// A counter of dependencies for calling run(). If we need to
// do asynchronous work before running, increment this and
// decrement it. Incrementing must happen in a place like
// PRE_RUN_ADDITIONS (used by emcc to add file preloading).
// Note that you can add dependencies in preRun, even though
// it happens right before run - run will be postponed until
// the dependencies are met.
var runDependencies = 0;
var runDependencyWatcher = null;
var dependenciesFulfilled = null; // overridden to take different actions when all run dependencies are fulfilled
var runDependencyTracking = {};

function getUniqueRunDependency(id) {
  var orig = id;
  while (1) {
    if (!runDependencyTracking[id]) return id;
    id = orig + Math.random();
  }
  return id;
}

function addRunDependency(id) {
  runDependencies++;
  if (Module['monitorRunDependencies']) {
    Module['monitorRunDependencies'](runDependencies);
  }
  if (id) {
    assert(!runDependencyTracking[id]);
    runDependencyTracking[id] = 1;
    if (runDependencyWatcher === null && typeof setInterval !== 'undefined') {
      // Check for missing dependencies every few seconds
      runDependencyWatcher = setInterval(function() {
        if (ABORT) {
          clearInterval(runDependencyWatcher);
          runDependencyWatcher = null;
          return;
        }
        var shown = false;
        for (var dep in runDependencyTracking) {
          if (!shown) {
            shown = true;
            Module.printErr('still waiting on run dependencies:');
          }
          Module.printErr('dependency: ' + dep);
        }
        if (shown) {
          Module.printErr('(end of list)');
        }
      }, 10000);
    }
  } else {
    Module.printErr('warning: run dependency added without ID');
  }
}
Module["addRunDependency"] = addRunDependency;

function removeRunDependency(id) {
  runDependencies--;
  if (Module['monitorRunDependencies']) {
    Module['monitorRunDependencies'](runDependencies);
  }
  if (id) {
    assert(runDependencyTracking[id]);
    delete runDependencyTracking[id];
  } else {
    Module.printErr('warning: run dependency removed without ID');
  }
  if (runDependencies == 0) {
    if (runDependencyWatcher !== null) {
      clearInterval(runDependencyWatcher);
      runDependencyWatcher = null;
    }
    if (dependenciesFulfilled) {
      var callback = dependenciesFulfilled;
      dependenciesFulfilled = null;
      callback(); // can add another dependenciesFulfilled
    }
  }
}
Module["removeRunDependency"] = removeRunDependency;

Module["preloadedImages"] = {}; // maps url to image data
Module["preloadedAudios"] = {}; // maps url to audio data



var memoryInitializer = null;






// === Body ===

var ASM_CONSTS = [function() { return screen.width; },
 function() { return screen.height; },
 function($0) { if (typeof Module['setWindowTitle'] !== 'undefined') { Module['setWindowTitle'](Module['Pointer_stringify']($0)); } return 0; },
 function($0, $1, $2) { var w = $0; var h = $1; var pixels = $2; if (!Module['SDL2']) Module['SDL2'] = {}; var SDL2 = Module['SDL2']; if (SDL2.ctxCanvas !== Module['canvas']) { SDL2.ctx = Module['createContext'](Module['canvas'], false, true); SDL2.ctxCanvas = Module['canvas']; } if (SDL2.w !== w || SDL2.h !== h || SDL2.imageCtx !== SDL2.ctx) { SDL2.image = SDL2.ctx.createImageData(w, h); SDL2.w = w; SDL2.h = h; SDL2.imageCtx = SDL2.ctx; } var data = SDL2.image.data; var src = pixels >> 2; var dst = 0; var num; if (typeof CanvasPixelArray !== 'undefined' && data instanceof CanvasPixelArray) { num = data.length; while (dst < num) { var val = HEAP32[src]; data[dst ] = val & 0xff; data[dst+1] = (val >> 8) & 0xff; data[dst+2] = (val >> 16) & 0xff; data[dst+3] = 0xff; src++; dst += 4; } } else { if (SDL2.data32Data !== data) { SDL2.data32 = new Int32Array(data.buffer); SDL2.data8 = new Uint8Array(data.buffer); } var data32 = SDL2.data32; num = data32.length; data32.set(HEAP32.subarray(src, src + num)); var data8 = SDL2.data8; var i = 3; var j = i + 4*num; if (num % 8 == 0) { while (i < j) { data8[i] = 0xff; i = i + 4 | 0; data8[i] = 0xff; i = i + 4 | 0; data8[i] = 0xff; i = i + 4 | 0; data8[i] = 0xff; i = i + 4 | 0; data8[i] = 0xff; i = i + 4 | 0; data8[i] = 0xff; i = i + 4 | 0; data8[i] = 0xff; i = i + 4 | 0; data8[i] = 0xff; i = i + 4 | 0; } } else { while (i < j) { data8[i] = 0xff; i = i + 4 | 0; } } } SDL2.ctx.putImageData(SDL2.image, 0, 0); return 0; },
 function($0, $1, $2) { var w = $0; var h = $1; var pixels = $2; var canvas = document.createElement("canvas"); canvas.width = w; canvas.height = h; var ctx = canvas.getContext("2d"); var image = ctx.createImageData(w, h); var data = image.data; var src = pixels >> 2; var dst = 0; var num; if (typeof CanvasPixelArray !== 'undefined' && data instanceof CanvasPixelArray) { num = data.length; while (dst < num) { var val = HEAP32[src]; data[dst ] = val & 0xff; data[dst+1] = (val >> 8) & 0xff; data[dst+2] = (val >> 16) & 0xff; data[dst+3] = (val >> 24) & 0xff; src++; dst += 4; } } else { var data32 = new Int32Array(data.buffer); num = data32.length; data32.set(HEAP32.subarray(src, src + num)); } ctx.putImageData(image, 0, 0); var url = "url(" + canvas.toDataURL() + "), auto"; var urlBuf = _malloc(url.length + 1); stringToUTF8(url, urlBuf, url.length + 1); return urlBuf; },
 function($0) { if (Module['canvas']) { Module['canvas'].style['cursor'] = Module['Pointer_stringify']($0); } return 0; },
 function() { if (Module['canvas']) { Module['canvas'].style['cursor'] = 'none'; } },
 function() { if (typeof(AudioContext) !== 'undefined') { return 1; } else if (typeof(webkitAudioContext) !== 'undefined') { return 1; } return 0; },
 function() { if ((typeof(navigator.mediaDevices) !== 'undefined') && (typeof(navigator.mediaDevices.getUserMedia) !== 'undefined')) { return 1; } else if (typeof(navigator.webkitGetUserMedia) !== 'undefined') { return 1; } return 0; },
 function($0) { if(typeof(SDL2) === 'undefined') { SDL2 = {}; } if (!$0) { SDL2.audio = {}; } else { SDL2.capture = {}; } if (!SDL2.audioContext) { if (typeof(AudioContext) !== 'undefined') { SDL2.audioContext = new AudioContext(); } else if (typeof(webkitAudioContext) !== 'undefined') { SDL2.audioContext = new webkitAudioContext(); } } return SDL2.audioContext === undefined ? -1 : 0; },
 function() { return SDL2.audioContext.sampleRate; },
 function($0, $1, $2, $3) { var have_microphone = function(stream) { if (SDL2.capture.silenceTimer !== undefined) { clearTimeout(SDL2.capture.silenceTimer); SDL2.capture.silenceTimer = undefined; } SDL2.capture.mediaStreamNode = SDL2.audioContext.createMediaStreamSource(stream); SDL2.capture.scriptProcessorNode = SDL2.audioContext.createScriptProcessor($1, $0, 1); SDL2.capture.scriptProcessorNode.onaudioprocess = function(audioProcessingEvent) { if ((SDL2 === undefined) || (SDL2.capture === undefined)) { return; } audioProcessingEvent.outputBuffer.getChannelData(0).fill(0.0); SDL2.capture.currentCaptureBuffer = audioProcessingEvent.inputBuffer; Runtime.dynCall('vi', $2, [$3]); }; SDL2.capture.mediaStreamNode.connect(SDL2.capture.scriptProcessorNode); SDL2.capture.scriptProcessorNode.connect(SDL2.audioContext.destination); SDL2.capture.stream = stream; }; var no_microphone = function(error) { }; SDL2.capture.silenceBuffer = SDL2.audioContext.createBuffer($0, $1, SDL2.audioContext.sampleRate); SDL2.capture.silenceBuffer.getChannelData(0).fill(0.0); var silence_callback = function() { SDL2.capture.currentCaptureBuffer = SDL2.capture.silenceBuffer; Runtime.dynCall('vi', $2, [$3]); }; SDL2.capture.silenceTimer = setTimeout(silence_callback, ($1 / SDL2.audioContext.sampleRate) * 1000); if ((navigator.mediaDevices !== undefined) && (navigator.mediaDevices.getUserMedia !== undefined)) { navigator.mediaDevices.getUserMedia({ audio: true, video: false }).then(have_microphone).catch(no_microphone); } else if (navigator.webkitGetUserMedia !== undefined) { navigator.webkitGetUserMedia({ audio: true, video: false }, have_microphone, no_microphone); } },
 function($0, $1, $2, $3) { SDL2.audio.scriptProcessorNode = SDL2.audioContext['createScriptProcessor']($1, 0, $0); SDL2.audio.scriptProcessorNode['onaudioprocess'] = function (e) { if ((SDL2 === undefined) || (SDL2.audio === undefined)) { return; } SDL2.audio.currentOutputBuffer = e['outputBuffer']; Runtime.dynCall('vi', $2, [$3]); }; SDL2.audio.scriptProcessorNode['connect'](SDL2.audioContext['destination']); },
 function($0) { if ($0) { if (SDL2.capture.silenceTimer !== undefined) { clearTimeout(SDL2.capture.silenceTimer); } if (SDL2.capture.stream !== undefined) { var tracks = SDL2.capture.stream.getAudioTracks(); for (var i = 0; i < tracks.length; i++) { SDL2.capture.stream.removeTrack(tracks[i]); } SDL2.capture.stream = undefined; } if (SDL2.capture.scriptProcessorNode !== undefined) { SDL2.capture.scriptProcessorNode.onaudioprocess = function(audioProcessingEvent) {}; SDL2.capture.scriptProcessorNode.disconnect(); SDL2.capture.scriptProcessorNode = undefined; } if (SDL2.capture.mediaStreamNode !== undefined) { SDL2.capture.mediaStreamNode.disconnect(); SDL2.capture.mediaStreamNode = undefined; } if (SDL2.capture.silenceBuffer !== undefined) { SDL2.capture.silenceBuffer = undefined } SDL2.capture = undefined; } else { if (SDL2.audio.scriptProcessorNode != undefined) { SDL2.audio.scriptProcessorNode.disconnect(); SDL2.audio.scriptProcessorNode = undefined; } SDL2.audio = undefined; } if ((SDL2.audioContext !== undefined) && (SDL2.audio === undefined) && (SDL2.capture === undefined)) { SDL2.audioContext.close(); SDL2.audioContext = undefined; } },
 function($0, $1) { var numChannels = SDL2.capture.currentCaptureBuffer.numberOfChannels; if (numChannels == 1) { var channelData = SDL2.capture.currentCaptureBuffer.getChannelData(0); if (channelData.length != $1) { throw 'Web Audio capture buffer length mismatch! Destination size: ' + channelData.length + ' samples vs expected ' + $1 + ' samples!'; } for (var j = 0; j < $1; ++j) { setValue($0 + (j * 4), channelData[j], 'float'); } } else { for (var c = 0; c < numChannels; ++c) { var channelData = SDL2.capture.currentCaptureBuffer.getChannelData(c); if (channelData.length != $1) { throw 'Web Audio capture buffer length mismatch! Destination size: ' + channelData.length + ' samples vs expected ' + $1 + ' samples!'; } for (var j = 0; j < $1; ++j) { setValue($0 + (((j * numChannels) + c) * 4), channelData[j], 'float'); } } } },
 function($0, $1) { var numChannels = SDL2.audio.currentOutputBuffer['numberOfChannels']; for (var c = 0; c < numChannels; ++c) { var channelData = SDL2.audio.currentOutputBuffer['getChannelData'](c); if (channelData.length != $1) { throw 'Web Audio output buffer length mismatch! Destination size: ' + channelData.length + ' samples vs expected ' + $1 + ' samples!'; } for (var j = 0; j < $1; ++j) { channelData[j] = HEAPF32[$0 + ((j*numChannels + c) << 2) >> 2]; } } },
 function($0, $1) { Module.printErr('bad name in getProcAddress: ' + [Pointer_stringify($0), Pointer_stringify($1)]) }];

function _emscripten_asm_const_iiiii(code, a0, a1, a2, a3) {
  return ASM_CONSTS[code](a0, a1, a2, a3);
}

function _emscripten_asm_const_i(code) {
  return ASM_CONSTS[code]();
}

function _emscripten_asm_const_ii(code, a0) {
  return ASM_CONSTS[code](a0);
}

function _emscripten_asm_const_iiii(code, a0, a1, a2) {
  return ASM_CONSTS[code](a0, a1, a2);
}

function _emscripten_asm_const_iii(code, a0, a1) {
  return ASM_CONSTS[code](a0, a1);
}



STATIC_BASE = Runtime.GLOBAL_BASE;

STATICTOP = STATIC_BASE + 221536;
/* global initializers */  __ATINIT__.push({ func: function() { __GLOBAL__I_000101() } }, { func: function() { __GLOBAL__sub_I_selection_cpp() } }, { func: function() { __GLOBAL__sub_I_Uniform_cpp() } }, { func: function() { __GLOBAL__sub_I_application_cpp() } }, { func: function() { __GLOBAL__sub_I_memory_cpp() } }, { func: function() { __GLOBAL__sub_I_Coordinator_cpp() } }, { func: function() { __GLOBAL__sub_I_Game_cpp() } }, { func: function() { __GLOBAL__sub_I_common_cpp() } }, { func: function() { __GLOBAL__sub_I_Pool_cpp() } }, { func: function() { __GLOBAL__sub_I_render_cpp() } }, { func: function() { __GLOBAL__sub_I_Texture_cpp() } }, { func: function() { __GLOBAL__sub_I_Mouse_cpp() } }, { func: function() { __GLOBAL__sub_I_render_cpp_4401() } }, { func: function() { __GLOBAL__sub_I_render_platform_web_cpp() } }, { func: function() { __GLOBAL__sub_I_DatabasePager_cpp() } }, { func: function() { __GLOBAL__sub_I_Registry_cpp() } }, { func: function() { __GLOBAL__sub_I_InputStream_cpp() } }, { func: function() { __GLOBAL__sub_I_iostream_cpp() } }, { func: function() { __GLOBAL__sub_I_ContextData_cpp() } }, { func: function() { __GLOBAL__sub_I_ViewerBase_cpp() } }, { func: function() { __GLOBAL__sub_I_Renderer_cpp() } }, { func: function() { __GLOBAL__sub_I_Scene_cpp() } }, { func: function() { __GLOBAL__sub_I_OrbitManipulator_cpp() } }, { func: function() { __GLOBAL__sub_I_IncrementalCompileOperation_cpp() } }, { func: function() { __GLOBAL__sub_I_Optimizer_cpp() } }, { func: function() { __GLOBAL__sub_I_RenderBin_cpp() } }, { func: function() { __GLOBAL__sub_I_ApplicationUsage_cpp() } }, { func: function() { __GLOBAL__sub_I_main_cpp() } }, { func: function() { __GLOBAL__sub_I_CullSettings_cpp() } }, { func: function() { __GLOBAL__sub_I_DisplaySettings_cpp() } }, { func: function() { __GLOBAL__sub_I_GLExtensions_cpp() } }, { func: function() { __GLOBAL__sub_I_GraphicsContext_cpp() } }, { func: function() { __GLOBAL__sub_I_Node_cpp() } }, { func: function() { __GLOBAL__sub_I_Notify_cpp() } }, { func: function() { __GLOBAL__sub_I_Referenced_cpp() } }, { func: function() { __GLOBAL__sub_I_State_cpp() } });


/* memory initializer */ allocate([0,0,0,0,0,0,0,0,16,0,0,0,8,0,0,0,0,0,0,0,192,32,0,0,253,1,0,0,254,1,0,0,255,1,0,0,0,2,0,0,1,2,0,0,160,1,0,0,161,1,0,0,162,1,0,0,163,1,0,0,2,2,0,0,3,2,0,0,166,1,0,0,167,1,0,0,168,1,0,0,169,1,0,0,170,1,0,0,4,2,0,0,172,1,0,0,12,0,0,0,4,0,0,0,252,255,255,255,192,32,0,0,5,2,0,0,6,2,0,0,7,2,0,0,8,2,0,0,9,2,0,0,180,1,0,0,181,1,0,0,182,1,0,0,183,1,0,0,10,2,0,0,11,2,0,0,248,255,255,255,248,255,255,255,248,255,255,255,248,255,255,255,0,0,0,0,0,0,0,0,248,255,255,255,248,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,255,255,255,248,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,255,255,255,248,255,255,255,248,255,255,255,248,255,255,255,248,255,255,255,8,0,0,0,248,255,255,255,192,32,0,0,12,2,0,0,13,2,0,0,14,2,0,0,15,2,0,0,16,2,0,0,191,1,0,0,192,1,0,0,193,1,0,0,194,1,0,0,195,1,0,0,196,1,0,0,197,1,0,0,198,1,0,0,199,1,0,0,200,1,0,0,201,1,0,0,202,1,0,0,203,1,0,0,204,1,0,0,205,1,0,0,206,1,0,0,207,1,0,0,208,1,0,0,209,1,0,0,17,2,0,0,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,255,255,255,248,255,255,255,248,255,255,255,248,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,255,255,255,240,255,255,255,240,255,255,255,240,255,255,255,240,255,255,255,240,255,255,255,0,0,0,0,240,255,255,255,192,32,0,0,8,0,0,0,19,2,0,0,20,2,0,0,21,2,0,0,22,2,0,0,23,2,0,0,24,2,0,0,25,2,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,219,1,0,0,220,1,0,0,221,1,0,0,222,1,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,248,0,0,0,0,0,0,0,24,47,0,0,118,3,0,0,119,3,0,0,120,3,0,0,121,3,0,0,122,3,0,0,160,1,0,0,161,1,0,0,162,1,0,0,163,1,0,0,123,3,0,0,124,3,0,0,166,1,0,0,167,1,0,0,168,1,0,0,169,1,0,0,170,1,0,0,4,3,0,0,5,3,0,0,246,1,0,0,6,3,0,0,7,3,0,0,8,3,0,0,9,3,0,0,10,3,0,0,11,3,0,0,12,3,0,0,13,3,0,0,14,3,0,0,15,3,0,0,16,3,0,0,17,3,0,0,18,3,0,0,19,3,0,0,20,3,0,0,21,3,0,0,22,3,0,0,23,3,0,0,24,3,0,0,25,3,0,0,26,3,0,0,27,3,0,0,28,3,0,0,29,3,0,0,30,3,0,0,31,3,0,0,32,3,0,0,33,3,0,0,34,3,0,0,35,3,0,0,36,3,0,0,37,3,0,0,38,3,0,0,39,3,0,0,40,3,0,0,41,3,0,0,42,3,0,0,43,3,0,0,44,3,0,0,45,3,0,0,46,3,0,0,47,3,0,0,48,3,0,0,49,3,0,0,50,3,0,0,51,3,0,0,52,3,0,0,53,3,0,0,54,3,0,0,55,3,0,0,56,3,0,0,57,3,0,0,58,3,0,0,59,3,0,0,60,3,0,0,61,3,0,0,62,3,0,0,63,3,0,0,64,3,0,0,65,3,0,0,252,0,0,0,244,0,0,0,252,255,255,255,24,47,0,0,125,3,0,0,126,3,0,0,127,3,0,0,128,3,0,0,129,3,0,0,180,1,0,0,181,1,0,0,182,1,0,0,183,1,0,0,130,3,0,0,131,3,0,0,8,255,255,255,8,255,255,255,8,255,255,255,8,255,255,255,0,0,0,0,0,0,0,0,8,255,255,255,8,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,255,255,255,8,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,255,255,255,8,255,255,255,8,255,255,255,8,255,255,255,8,255,255,255,8,0,0,0,8,255,255,255,24,47,0,0,132,3,0,0,133,3,0,0,134,3,0,0,135,3,0,0,136,3,0,0,191,1,0,0,192,1,0,0,193,1,0,0,194,1,0,0,195,1,0,0,196,1,0,0,197,1,0,0,198,1,0,0,199,1,0,0,200,1,0,0,201,1,0,0,202,1,0,0,203,1,0,0,204,1,0,0,205,1,0,0,206,1,0,0,207,1,0,0,208,1,0,0,209,1,0,0,137,3,0,0,138,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,255,255,255,248,255,255,255,248,255,255,255,248,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,0,255,255,255,0,255,255,255,0,255,255,255,0,255,255,255,0,255,255,255,0,0,0,0,0,255,255,255,24,47,0,0,8,0,0,0,139,3,0,0,140,3,0,0,141,3,0,0,142,3,0,0,143,3,0,0,144,3,0,0,145,3,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,219,1,0,0,220,1,0,0,221,1,0,0,222,1,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,128,82,0,0,33,4,0,0,34,4,0,0,116,0,0,0,117,0,0,0,118,0,0,0,235,2,0,0,236,2,0,0,121,0,0,0,122,0,0,0,123,0,0,0,124,0,0,0,125,0,0,0,126,0,0,0,127,0,0,0,128,0,0,0,129,0,0,0,130,0,0,0,131,0,0,0,132,0,0,0,133,0,0,0,134,0,0,0,135,0,0,0,136,0,0,0,137,0,0,0,138,0,0,0,139,0,0,0,140,0,0,0,237,2,0,0,142,0,0,0,143,0,0,0,144,0,0,0,145,0,0,0,146,0,0,0,223,2,0,0,148,0,0,0,149,0,0,0,150,0,0,0,151,0,0,0,152,0,0,0,153,0,0,0,154,0,0,0,155,0,0,0,156,0,0,0,157,0,0,0,158,0,0,0,159,0,0,0,160,0,0,0,161,0,0,0,162,0,0,0,163,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,192,255,255,255,0,0,0,0,0,0,0,0,192,255,255,255,192,255,255,255,192,255,255,255,192,255,255,255,192,255,255,255,192,255,255,255,0,0,0,0,192,255,255,255,128,82,0,0,8,0,0,0,35,4,0,0,36,4,0,0,166,0,0,0,167,0,0,0,168,0,0,0,240,2,0,0,241,2,0,0,16,0,0,0,17,0,0,0,171,0,0,0,172,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,12,0,0,0,4,0,0,0,0,0,0,0,216,90,0,0,54,2,0,0,55,2,0,0,56,2,0,0,57,2,0,0,58,2,0,0,59,2,0,0,60,2,0,0,61,2,0,0,62,2,0,0,63,2,0,0,64,2,0,0,252,255,255,255,252,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,252,255,255,255,252,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,252,255,255,255,252,255,255,255,252,255,255,255,252,255,255,255,252,255,255,255,8,0,0,0,252,255,255,255,216,90,0,0,65,2,0,0,66,2,0,0,67,2,0,0,68,2,0,0,69,2,0,0,191,1,0,0,192,1,0,0,193,1,0,0,194,1,0,0,228,1,0,0,229,1,0,0,197,1,0,0,198,1,0,0,199,1,0,0,200,1,0,0,201,1,0,0,202,1,0,0,70,2,0,0,71,2,0,0,205,1,0,0,206,1,0,0,232,1,0,0,233,1,0,0,72,2,0,0,73,2,0,0,74,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,255,255,255,248,255,255,255,248,255,255,255,248,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,244,255,255,255,244,255,255,255,244,255,255,255,244,255,255,255,244,255,255,255,244,255,255,255,0,0,0,0,244,255,255,255,216,90,0,0,8,0,0,0,75,2,0,0,76,2,0,0,77,2,0,0,78,2,0,0,79,2,0,0,80,2,0,0,81,2,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,219,1,0,0,220,1,0,0,221,1,0,0,222,1,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,20,0,0,0,0,0,0,0,104,32,0,0,179,2,0,0,7,0,0,0,185,2,0,0,186,2,0,0,236,255,255,255,0,0,0,0,236,255,255,255,104,32,0,0,1,0,0,0,187,2,0,0,188,2,0,0,0,0,0,0,0,0,0,0,20,0,0,0,0,0,0,0,216,97,0,0,179,2,0,0,180,2,0,0,181,2,0,0,182,2,0,0,7,0,0,0,236,255,255,255,0,0,0,0,236,255,255,255,216,97,0,0,1,0,0,0,183,2,0,0,184,2,0,0,0,0,0,0,12,0,0,0,4,0,0,0,0,0,0,0,144,90,0,0,166,7,0,0,167,7,0,0,168,7,0,0,169,7,0,0,170,7,0,0,171,7,0,0,172,7,0,0,173,7,0,0,194,7,0,0,195,7,0,0,196,7,0,0,252,255,255,255,252,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,252,255,255,255,252,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,252,255,255,255,252,255,255,255,252,255,255,255,252,255,255,255,252,255,255,255,8,0,0,0,252,255,255,255,144,90,0,0,177,7,0,0,178,7,0,0,179,7,0,0,180,7,0,0,181,7,0,0,191,1,0,0,192,1,0,0,193,1,0,0,194,1,0,0,228,1,0,0,229,1,0,0,182,7,0,0,183,7,0,0,199,1,0,0,200,1,0,0,201,1,0,0,202,1,0,0,230,1,0,0,231,1,0,0,205,1,0,0,206,1,0,0,232,1,0,0,233,1,0,0,184,7,0,0,197,7,0,0,198,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,255,255,255,248,255,255,255,248,255,255,255,248,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,244,255,255,255,244,255,255,255,244,255,255,255,244,255,255,255,244,255,255,255,244,255,255,255,0,0,0,0,244,255,255,255,144,90,0,0,8,0,0,0,199,7,0,0,200,7,0,0,189,7,0,0,190,7,0,0,191,7,0,0,192,7,0,0,193,7,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,219,1,0,0,220,1,0,0,221,1,0,0,222,1,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,56,0,0,0,0,0,0,0,112,101,0,0,233,2,0,0,234,2,0,0,116,0,0,0,117,0,0,0,118,0,0,0,235,2,0,0,236,2,0,0,121,0,0,0,122,0,0,0,123,0,0,0,124,0,0,0,125,0,0,0,126,0,0,0,127,0,0,0,128,0,0,0,129,0,0,0,130,0,0,0,131,0,0,0,132,0,0,0,133,0,0,0,134,0,0,0,135,0,0,0,136,0,0,0,137,0,0,0,138,0,0,0,139,0,0,0,140,0,0,0,237,2,0,0,142,0,0,0,143,0,0,0,144,0,0,0,145,0,0,0,146,0,0,0,223,2,0,0,148,0,0,0,149,0,0,0,150,0,0,0,151,0,0,0,152,0,0,0,153,0,0,0,154,0,0,0,155,0,0,0,156,0,0,0,157,0,0,0,158,0,0,0,159,0,0,0,160,0,0,0,161,0,0,0,162,0,0,0,163,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,255,255,255,200,255,255,255,0,0,0,0,0,0,0,0,200,255,255,255,200,255,255,255,200,255,255,255,200,255,255,255,200,255,255,255,200,255,255,255,0,0,0,0,200,255,255,255,112,101,0,0,8,0,0,0,238,2,0,0,239,2,0,0,166,0,0,0,167,0,0,0,168,0,0,0,240,2,0,0,241,2,0,0,16,0,0,0,17,0,0,0,171,0,0,0,172,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,4,0,0,0,0,0,0,0,72,129,0,0,85,4,0,0,86,4,0,0,252,255,255,255,252,255,255,255,72,129,0,0,87,4,0,0,88,4,0,0,0,0,0,0,0,0,0,0,100,133,1,0,1,139,1,0,32,15,0,0,0,0,0,0,100,133,1,0,20,139,1,0,120,103,0,0,0,0,0,0,64,134,1,0,114,143,1,0,0,0,0,0,2,0,0,0,240,96,0,0,2,0,0,0,80,15,0,0,2,132,0,0,60,133,1,0,143,143,1,0,64,134,1,0,60,146,1,0,0,0,0,0,2,0,0,0,192,105,0,0,2,0,0,0,80,15,0,0,2,36,0,0,100,133,1,0,8,146,1,0,112,101,0,0,0,0,0,0,100,133,1,0,78,146,1,0,0,102,0,0,0,0,0,0,100,133,1,0,103,146,1,0,168,15,0,0,0,0,0,0,64,134,1,0,142,146,1,0,0,0,0,0,1,0,0,0,120,103,0,0,3,244,255,255,100,133,1,0,162,147,1,0,224,15,0,0,0,0,0,0,100,133,1,0,133,147,1,0,216,98,0,0,0,0,0,0,100,133,1,0,194,147,1,0,120,103,0,0,0,0,0,0,100,133,1,0,205,149,1,0,0,102,0,0,0,0,0,0,64,134,1,0,130,153,1,0,3,0,0,0,2,0,0,0,16,21,0,0,2,0,0,0,88,15,0,0,2,104,0,0,236,0,0,0,0,0,0,0,16,21,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,189,0,0,0,190,0,0,0,191,0,0,0,192,0,0,0,193,0,0,0,194,0,0,0,195,0,0,0,245,0,0,0,7,0,0,0,7,0,0,0,199,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,203,0,0,0,7,0,0,0,7,0,0,0,206,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,246,0,0,0,247,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,255,255,255,0,0,0,0,20,255,255,255,16,21,0,0,8,0,0,0,248,0,0,0,249,0,0,0,7,0,0,0,7,0,0,0,250,0,0,0,7,0,0,0,7,0,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,132,0,0,0,0,0,0,0,88,15,0,0,80,0,0,0,81,0,0,0,82,0,0,0,83,0,0,0,84,0,0,0,85,0,0,0,86,0,0,0,87,0,0,0,88,0,0,0,89,0,0,0,90,0,0,0,91,0,0,0,92,0,0,0,93,0,0,0,94,0,0,0,95,0,0,0,96,0,0,0,97,0,0,0,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,124,255,255,255,124,255,255,255,124,255,255,255,124,255,255,255,124,255,255,255,124,255,255,255,0,0,0,0,124,255,255,255,88,15,0,0,8,0,0,0,107,0,0,0,108,0,0,0,109,0,0,0,110,0,0,0,111,0,0,0,112,0,0,0,113,0,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,0,0,0,0,132,0,0,0,0,0,0,0,192,105,0,0,251,0,0,0,252,0,0,0,253,0,0,0,254,0,0,0,255,0,0,0,0,1,0,0,1,1,0,0,2,1,0,0,3,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,124,255,255,255,124,255,255,255,124,255,255,255,124,255,255,255,124,255,255,255,124,255,255,255,0,0,0,0,124,255,255,255,192,105,0,0,8,0,0,0,4,1,0,0,5,1,0,0,6,1,0,0,7,1,0,0,8,1,0,0,9,1,0,0,10,1,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,0,0,0,0,100,133,1,0,99,150,1,0,48,15,0,0,0,0,0,0,100,133,1,0,83,151,1,0,120,103,0,0,0,0,0,0,60,0,0,0,0,0,0,0,24,129,0,0,29,1,0,0,30,1,0,0,196,255,255,255,196,255,255,255,24,129,0,0,31,1,0,0,32,1,0,0,100,133,1,0,69,152,1,0,8,129,0,0,0,0,0,0,100,133,1,0,135,152,1,0,24,129,0,0,0,0,0,0,100,133,1,0,164,153,1,0,0,102,0,0,0,0,0,0,64,134,1,0,152,158,1,0,0,0,0,0,1,0,0,0,0,102,0,0,3,244,255,255,64,134,1,0,141,161,1,0,0,0,0,0,2,0,0,0,232,89,0,0,2,0,0,0,72,21,0,0,2,72,0,0,60,133,1,0,109,161,1,0,64,134,1,0,237,161,1,0,0,0,0,0,2,0,0,0,232,89,0,0,2,0,0,0,112,21,0,0,2,72,0,0,60,133,1,0,205,161,1,0,64,134,1,0,77,162,1,0,0,0,0,0,2,0,0,0,232,89,0,0,2,0,0,0,152,21,0,0,2,72,0,0,60,133,1,0,45,162,1,0,100,133,1,0,70,163,1,0,136,15,0,0,0,0,0,0,100,133,1,0,110,163,1,0,136,15,0,0,0,0,0,0,100,133,1,0,96,164,1,0,136,15,0,0,0,0,0,0,100,133,1,0,127,164,1,0,16,21,0,0,0,0,0,0,100,133,1,0,106,165,1,0,32,35,0,0,0,0,0,0,64,134,1,0,42,165,1,0,0,0,0,0,1,0,0,0,0,102,0,0,3,244,255,255,116,0,0,0,108,0,0,0,0,0,0,0,32,35,0,0,155,1,0,0,156,1,0,0,157,1,0,0,158,1,0,0,159,1,0,0,160,1,0,0,161,1,0,0,162,1,0,0,163,1,0,0,244,1,0,0,245,1,0,0,166,1,0,0,167,1,0,0,168,1,0,0,169,1,0,0,170,1,0,0,171,1,0,0,172,1,0,0,246,1,0,0,174,1,0,0,112,0,0,0,104,0,0,0,252,255,255,255,32,35,0,0,175,1,0,0,176,1,0,0,177,1,0,0,178,1,0,0,179,1,0,0,180,1,0,0,181,1,0,0,182,1,0,0,183,1,0,0,247,1,0,0,248,1,0,0,148,255,255,255,148,255,255,255,148,255,255,255,148,255,255,255,0,0,0,0,0,0,0,0,148,255,255,255,148,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,148,255,255,255,148,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,148,255,255,255,148,255,255,255,148,255,255,255,148,255,255,255,148,255,255,255,8,0,0,0,148,255,255,255,32,35,0,0,186,1,0,0,187,1,0,0,188,1,0,0,189,1,0,0,190,1,0,0,191,1,0,0,192,1,0,0,193,1,0,0,194,1,0,0,195,1,0,0,196,1,0,0,197,1,0,0,198,1,0,0,199,1,0,0,200,1,0,0,201,1,0,0,202,1,0,0,203,1,0,0,204,1,0,0,205,1,0,0,206,1,0,0,207,1,0,0,208,1,0,0,209,1,0,0,249,1,0,0,250,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,255,255,255,248,255,255,255,248,255,255,255,248,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,140,255,255,255,140,255,255,255,140,255,255,255,140,255,255,255,140,255,255,255,140,255,255,255,0,0,0,0,140,255,255,255,32,35,0,0,8,0,0,0,251,1,0,0,252,1,0,0,214,1,0,0,215,1,0,0,216,1,0,0,217,1,0,0,218,1,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,219,1,0,0,220,1,0,0,221,1,0,0,222,1,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,116,0,0,0,108,0,0,0,0,0,0,0,192,32,0,0,253,1,0,0,254,1,0,0,255,1,0,0,0,2,0,0,1,2,0,0,160,1,0,0,161,1,0,0,162,1,0,0,163,1,0,0,2,2,0,0,3,2,0,0,166,1,0,0,167,1,0,0,168,1,0,0,169,1,0,0,170,1,0,0,4,2,0,0,172,1,0,0,112,0,0,0,104,0,0,0,252,255,255,255,192,32,0,0,5,2,0,0,6,2,0,0,7,2,0,0,8,2,0,0,9,2,0,0,180,1,0,0,181,1,0,0,182,1,0,0,183,1,0,0,10,2,0,0,11,2,0,0,148,255,255,255,148,255,255,255,148,255,255,255,148,255,255,255,0,0,0,0,0,0,0,0,148,255,255,255,148,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,148,255,255,255,148,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,148,255,255,255,148,255,255,255,148,255,255,255,148,255,255,255,148,255,255,255,8,0,0,0,148,255,255,255,192,32,0,0,12,2,0,0,13,2,0,0,14,2,0,0,15,2,0,0,16,2,0,0,191,1,0,0,192,1,0,0,193,1,0,0,194,1,0,0,195,1,0,0,196,1,0,0,197,1,0,0,198,1,0,0,199,1,0,0,200,1,0,0,201,1,0,0,202,1,0,0,203,1,0,0,204,1,0,0,205,1,0,0,206,1,0,0,207,1,0,0,208,1,0,0,209,1,0,0,17,2,0,0,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,255,255,255,248,255,255,255,248,255,255,255,248,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,140,255,255,255,140,255,255,255,140,255,255,255,140,255,255,255,140,255,255,255,140,255,255,255,0,0,0,0,140,255,255,255,192,32,0,0,8,0,0,0,19,2,0,0,20,2,0,0,21,2,0,0,22,2,0,0,23,2,0,0,24,2,0,0,25,2,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,219,1,0,0,220,1,0,0,221,1,0,0,222,1,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,116,0,0,0,108,0,0,0,0,0,0,0,120,90,0,0,26,2,0,0,27,2,0,0,28,2,0,0,29,2,0,0,30,2,0,0,31,2,0,0,32,2,0,0,33,2,0,0,34,2,0,0,35,2,0,0,36,2,0,0,148,255,255,255,148,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,148,255,255,255,148,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,148,255,255,255,148,255,255,255,148,255,255,255,148,255,255,255,148,255,255,255,8,0,0,0,148,255,255,255,120,90,0,0,37,2,0,0,38,2,0,0,39,2,0,0,40,2,0,0,41,2,0,0,191,1,0,0,192,1,0,0,193,1,0,0,194,1,0,0,42,2,0,0,43,2,0,0,197,1,0,0,198,1,0,0,199,1,0,0,200,1,0,0,201,1,0,0,202,1,0,0,230,1,0,0,231,1,0,0,205,1,0,0,206,1,0,0,232,1,0,0,233,1,0,0,44,2,0,0,45,2,0,0,46,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,255,255,255,248,255,255,255,248,255,255,255,248,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,140,255,255,255,140,255,255,255,140,255,255,255,140,255,255,255,140,255,255,255,140,255,255,255,0,0,0,0,140,255,255,255,120,90,0,0,8,0,0,0,47,2,0,0,48,2,0,0,49,2,0,0,50,2,0,0,51,2,0,0,52,2,0,0,53,2,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,219,1,0,0,220,1,0,0,221,1,0,0,222,1,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,112,0,0,0,104,0,0,0,0,0,0,0,216,90,0,0,54,2,0,0,55,2,0,0,56,2,0,0,57,2,0,0,58,2,0,0,59,2,0,0,60,2,0,0,61,2,0,0,62,2,0,0,63,2,0,0,64,2,0,0,152,255,255,255,152,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,255,255,255,152,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,255,255,255,152,255,255,255,152,255,255,255,152,255,255,255,152,255,255,255,8,0,0,0,152,255,255,255,216,90,0,0,65,2,0,0,66,2,0,0,67,2,0,0,68,2,0,0,69,2,0,0,191,1,0,0,192,1,0,0,193,1,0,0,194,1,0,0,228,1,0,0,229,1,0,0,197,1,0,0,198,1,0,0,199,1,0,0,200,1,0,0,201,1,0,0,202,1,0,0,70,2,0,0,71,2,0,0,205,1,0,0,206,1,0,0,232,1,0,0,233,1,0,0,72,2,0,0,73,2,0,0,74,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,255,255,255,248,255,255,255,248,255,255,255,248,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,255,255,255,144,255,255,255,144,255,255,255,144,255,255,255,144,255,255,255,144,255,255,255,0,0,0,0,144,255,255,255,216,90,0,0,8,0,0,0,75,2,0,0,76,2,0,0,77,2,0,0,78,2,0,0,79,2,0,0,80,2,0,0,81,2,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,219,1,0,0,220,1,0,0,221,1,0,0,222,1,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,100,133,1,0,178,165,1,0,192,90,0,0,0,0,0,0,100,133,1,0,224,165,1,0,240,90,0,0,0,0,0,0,100,133,1,0,173,164,1,0,176,31,0,0,0,0,0,0,100,133,1,0,48,166,1,0,0,102,0,0,0,0,0,0,100,133,1,0,80,166,1,0,120,103,0,0,0,0,0,0,100,133,1,0,171,166,1,0,192,31,0,0,0,0,0,0,100,133,1,0,51,171,1,0,216,97,0,0,0,0,0,0,128,0,0,0,0,0,0,0,216,97,0,0,179,2,0,0,180,2,0,0,181,2,0,0,182,2,0,0,7,0,0,0,128,255,255,255,0,0,0,0,128,255,255,255,216,97,0,0,1,0,0,0,183,2,0,0,184,2,0,0,0,0,0,0,128,0,0,0,0,0,0,0,104,32,0,0,179,2,0,0,7,0,0,0,185,2,0,0,186,2,0,0,128,255,255,255,0,0,0,0,128,255,255,255,104,32,0,0,1,0,0,0,187,2,0,0,188,2,0,0,64,134,1,0,208,166,1,0,0,0,0,0,1,0,0,0,120,103,0,0,3,244,255,255,100,133,1,0,64,170,1,0,192,31,0,0,0,0,0,0,100,133,1,0,73,171,1,0,128,106,0,0,0,0,0,0,100,133,1,0,147,171,1,0,120,103,0,0,0,0,0,0,100,133,1,0,189,171,1,0,120,103,0,0,0,0,0,0,64,134,1,0,222,171,1,0,3,0,0,0,2,0,0,0,120,90,0,0,2,0,0,0,216,90,0,0,2,4,0,0,100,133,1,0,245,171,1,0,120,103,0,0,0,0,0,0,100,133,1,0,46,172,1,0,112,101,0,0,0,0,0,0,80,0,0,0,0,0,0,0,112,101,0,0,233,2,0,0,234,2,0,0,116,0,0,0,117,0,0,0,118,0,0,0,235,2,0,0,236,2,0,0,121,0,0,0,122,0,0,0,123,0,0,0,124,0,0,0,125,0,0,0,126,0,0,0,127,0,0,0,128,0,0,0,129,0,0,0,130,0,0,0,131,0,0,0,132,0,0,0,133,0,0,0,134,0,0,0,135,0,0,0,136,0,0,0,137,0,0,0,138,0,0,0,139,0,0,0,140,0,0,0,237,2,0,0,142,0,0,0,143,0,0,0,144,0,0,0,145,0,0,0,146,0,0,0,223,2,0,0,148,0,0,0,149,0,0,0,150,0,0,0,151,0,0,0,152,0,0,0,153,0,0,0,154,0,0,0,155,0,0,0,156,0,0,0,157,0,0,0,158,0,0,0,159,0,0,0,160,0,0,0,161,0,0,0,162,0,0,0,163,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,255,255,255,176,255,255,255,0,0,0,0,0,0,0,0,176,255,255,255,176,255,255,255,176,255,255,255,176,255,255,255,176,255,255,255,176,255,255,255,0,0,0,0,176,255,255,255,112,101,0,0,8,0,0,0,238,2,0,0,239,2,0,0,166,0,0,0,167,0,0,0,168,0,0,0,240,2,0,0,241,2,0,0,16,0,0,0,17,0,0,0,171,0,0,0,172,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,100,133,1,0,121,172,1,0,16,35,0,0,0,0,0,0,100,133,1,0,85,172,1,0,0,102,0,0,0,0,0,0,100,133,1,0,147,172,1,0,0,102,0,0,0,0,0,0,100,133,1,0,162,172,1,0,192,32,0,0,0,0,0,0,16,0,0,0,8,0,0,0,0,0,0,0,120,90,0,0,26,2,0,0,27,2,0,0,28,2,0,0,29,2,0,0,30,2,0,0,31,2,0,0,32,2,0,0,33,2,0,0,34,2,0,0,35,2,0,0,36,2,0,0,248,255,255,255,248,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,255,255,255,248,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,255,255,255,248,255,255,255,248,255,255,255,248,255,255,255,248,255,255,255,8,0,0,0,248,255,255,255,120,90,0,0,37,2,0,0,38,2,0,0,39,2,0,0,40,2,0,0,41,2,0,0,191,1,0,0,192,1,0,0,193,1,0,0,194,1,0,0,42,2,0,0,43,2,0,0,197,1,0,0,198,1,0,0,199,1,0,0,200,1,0,0,201,1,0,0,202,1,0,0,230,1,0,0,231,1,0,0,205,1,0,0,206,1,0,0,232,1,0,0,233,1,0,0,44,2,0,0,45,2,0,0,46,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,255,255,255,248,255,255,255,248,255,255,255,248,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,255,255,255,240,255,255,255,240,255,255,255,240,255,255,255,240,255,255,255,240,255,255,255,0,0,0,0,240,255,255,255,120,90,0,0,8,0,0,0,47,2,0,0,48,2,0,0,49,2,0,0,50,2,0,0,51,2,0,0,52,2,0,0,53,2,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,219,1,0,0,220,1,0,0,221,1,0,0,222,1,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,100,133,1,0,45,173,1,0,24,47,0,0,0,0,0,0,100,133,1,0,209,172,1,0,128,37,0,0,0,0,0,0,100,133,1,0,0,173,1,0,120,103,0,0,0,0,0,0,100,133,1,0,247,173,1,0,32,35,0,0,0,0,0,0,100,0,0,0,92,0,0,0,0,0,0,0,32,35,0,0,155,1,0,0,156,1,0,0,157,1,0,0,158,1,0,0,159,1,0,0,160,1,0,0,161,1,0,0,162,1,0,0,163,1,0,0,244,1,0,0,245,1,0,0,166,1,0,0,167,1,0,0,168,1,0,0,169,1,0,0,170,1,0,0,171,1,0,0,172,1,0,0,246,1,0,0,174,1,0,0,96,0,0,0,88,0,0,0,252,255,255,255,32,35,0,0,175,1,0,0,176,1,0,0,177,1,0,0,178,1,0,0,179,1,0,0,180,1,0,0,181,1,0,0,182,1,0,0,183,1,0,0,247,1,0,0,248,1,0,0,164,255,255,255,164,255,255,255,164,255,255,255,164,255,255,255,0,0,0,0,0,0,0,0,164,255,255,255,164,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,164,255,255,255,164,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,164,255,255,255,164,255,255,255,164,255,255,255,164,255,255,255,164,255,255,255,8,0,0,0,164,255,255,255,32,35,0,0,186,1,0,0,187,1,0,0,188,1,0,0,189,1,0,0,190,1,0,0,191,1,0,0,192,1,0,0,193,1,0,0,194,1,0,0,195,1,0,0,196,1,0,0,197,1,0,0,198,1,0,0,199,1,0,0,200,1,0,0,201,1,0,0,202,1,0,0,203,1,0,0,204,1,0,0,205,1,0,0,206,1,0,0,207,1,0,0,208,1,0,0,209,1,0,0,249,1,0,0,250,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,255,255,255,248,255,255,255,248,255,255,255,248,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,156,255,255,255,156,255,255,255,156,255,255,255,156,255,255,255,156,255,255,255,156,255,255,255,0,0,0,0,156,255,255,255,32,35,0,0,8,0,0,0,251,1,0,0,252,1,0,0,214,1,0,0,215,1,0,0,216,1,0,0,217,1,0,0,218,1,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,219,1,0,0,220,1,0,0,221,1], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE);
/* memory initializer */ allocate([222,1,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,100,0,0,0,92,0,0,0,0,0,0,0,192,32,0,0,253,1,0,0,254,1,0,0,255,1,0,0,0,2,0,0,1,2,0,0,160,1,0,0,161,1,0,0,162,1,0,0,163,1,0,0,2,2,0,0,3,2,0,0,166,1,0,0,167,1,0,0,168,1,0,0,169,1,0,0,170,1,0,0,4,2,0,0,172,1,0,0,96,0,0,0,88,0,0,0,252,255,255,255,192,32,0,0,5,2,0,0,6,2,0,0,7,2,0,0,8,2,0,0,9,2,0,0,180,1,0,0,181,1,0,0,182,1,0,0,183,1,0,0,10,2,0,0,11,2,0,0,164,255,255,255,164,255,255,255,164,255,255,255,164,255,255,255,0,0,0,0,0,0,0,0,164,255,255,255,164,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,164,255,255,255,164,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,164,255,255,255,164,255,255,255,164,255,255,255,164,255,255,255,164,255,255,255,8,0,0,0,164,255,255,255,192,32,0,0,12,2,0,0,13,2,0,0,14,2,0,0,15,2,0,0,16,2,0,0,191,1,0,0,192,1,0,0,193,1,0,0,194,1,0,0,195,1,0,0,196,1,0,0,197,1,0,0,198,1,0,0,199,1,0,0,200,1,0,0,201,1,0,0,202,1,0,0,203,1,0,0,204,1,0,0,205,1,0,0,206,1,0,0,207,1,0,0,208,1,0,0,209,1,0,0,17,2,0,0,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,255,255,255,248,255,255,255,248,255,255,255,248,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,156,255,255,255,156,255,255,255,156,255,255,255,156,255,255,255,156,255,255,255,156,255,255,255,0,0,0,0,156,255,255,255,192,32,0,0,8,0,0,0,19,2,0,0,20,2,0,0,21,2,0,0,22,2,0,0,23,2,0,0,24,2,0,0,25,2,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,219,1,0,0,220,1,0,0,221,1,0,0,222,1,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,100,0,0,0,92,0,0,0,0,0,0,0,120,90,0,0,26,2,0,0,27,2,0,0,28,2,0,0,29,2,0,0,30,2,0,0,31,2,0,0,32,2,0,0,33,2,0,0,34,2,0,0,35,2,0,0,36,2,0,0,164,255,255,255,164,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,164,255,255,255,164,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,164,255,255,255,164,255,255,255,164,255,255,255,164,255,255,255,164,255,255,255,8,0,0,0,164,255,255,255,120,90,0,0,37,2,0,0,38,2,0,0,39,2,0,0,40,2,0,0,41,2,0,0,191,1,0,0,192,1,0,0,193,1,0,0,194,1,0,0,42,2,0,0,43,2,0,0,197,1,0,0,198,1,0,0,199,1,0,0,200,1,0,0,201,1,0,0,202,1,0,0,230,1,0,0,231,1,0,0,205,1,0,0,206,1,0,0,232,1,0,0,233,1,0,0,44,2,0,0,45,2,0,0,46,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,255,255,255,248,255,255,255,248,255,255,255,248,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,156,255,255,255,156,255,255,255,156,255,255,255,156,255,255,255,156,255,255,255,156,255,255,255,0,0,0,0,156,255,255,255,120,90,0,0,8,0,0,0,47,2,0,0,48,2,0,0,49,2,0,0,50,2,0,0,51,2,0,0,52,2,0,0,53,2,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,219,1,0,0,220,1,0,0,221,1,0,0,222,1,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,96,0,0,0,88,0,0,0,0,0,0,0,216,90,0,0,54,2,0,0,55,2,0,0,56,2,0,0,57,2,0,0,58,2,0,0,59,2,0,0,60,2,0,0,61,2,0,0,62,2,0,0,63,2,0,0,64,2,0,0,168,255,255,255,168,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,255,255,255,168,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,255,255,255,168,255,255,255,168,255,255,255,168,255,255,255,168,255,255,255,8,0,0,0,168,255,255,255,216,90,0,0,65,2,0,0,66,2,0,0,67,2,0,0,68,2,0,0,69,2,0,0,191,1,0,0,192,1,0,0,193,1,0,0,194,1,0,0,228,1,0,0,229,1,0,0,197,1,0,0,198,1,0,0,199,1,0,0,200,1,0,0,201,1,0,0,202,1,0,0,70,2,0,0,71,2,0,0,205,1,0,0,206,1,0,0,232,1,0,0,233,1,0,0,72,2,0,0,73,2,0,0,74,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,255,255,255,248,255,255,255,248,255,255,255,248,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,255,255,255,160,255,255,255,160,255,255,255,160,255,255,255,160,255,255,255,160,255,255,255,0,0,0,0,160,255,255,255,216,90,0,0,8,0,0,0,75,2,0,0,76,2,0,0,77,2,0,0,78,2,0,0,79,2,0,0,80,2,0,0,81,2,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,219,1,0,0,220,1,0,0,221,1,0,0,222,1,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,100,133,1,0,176,174,1,0,208,62,0,0,0,0,0,0,0,1,0,0,248,0,0,0,0,0,0,0,208,62,0,0,155,1,0,0,156,1,0,0,157,1,0,0,158,1,0,0,146,3,0,0,160,1,0,0,161,1,0,0,162,1,0,0,163,1,0,0,147,3,0,0,148,3,0,0,166,1,0,0,167,1,0,0,168,1,0,0,169,1,0,0,170,1,0,0,4,3,0,0,5,3,0,0,246,1,0,0,6,3,0,0,7,3,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,12,3,0,0,100,3,0,0,101,3,0,0,15,3,0,0,16,3,0,0,17,3,0,0,18,3,0,0,19,3,0,0,20,3,0,0,21,3,0,0,22,3,0,0,23,3,0,0,24,3,0,0,25,3,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,30,3,0,0,31,3,0,0,32,3,0,0,33,3,0,0,34,3,0,0,35,3,0,0,36,3,0,0,37,3,0,0,38,3,0,0,39,3,0,0,40,3,0,0,149,3,0,0,42,3,0,0,43,3,0,0,150,3,0,0,151,3,0,0,152,3,0,0,153,3,0,0,48,3,0,0,154,3,0,0,50,3,0,0,51,3,0,0,52,3,0,0,155,3,0,0,156,3,0,0,252,0,0,0,244,0,0,0,252,255,255,255,208,62,0,0,175,1,0,0,176,1,0,0,177,1,0,0,178,1,0,0,157,3,0,0,180,1,0,0,181,1,0,0,182,1,0,0,183,1,0,0,158,3,0,0,159,3,0,0,8,255,255,255,8,255,255,255,8,255,255,255,8,255,255,255,0,0,0,0,0,0,0,0,8,255,255,255,8,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,255,255,255,8,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,255,255,255,8,255,255,255,8,255,255,255,8,255,255,255,8,255,255,255,8,0,0,0,8,255,255,255,208,62,0,0,186,1,0,0,187,1,0,0,188,1,0,0,189,1,0,0,160,3,0,0,191,1,0,0,192,1,0,0,193,1,0,0,194,1,0,0,195,1,0,0,196,1,0,0,197,1,0,0,198,1,0,0,199,1,0,0,200,1,0,0,201,1,0,0,202,1,0,0,203,1,0,0,204,1,0,0,205,1,0,0,206,1,0,0,207,1,0,0,208,1,0,0,209,1,0,0,161,3,0,0,162,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,255,255,255,248,255,255,255,248,255,255,255,248,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,0,255,255,255,0,255,255,255,0,255,255,255,0,255,255,255,0,255,255,255,0,0,0,0,0,255,255,255,208,62,0,0,8,0,0,0,163,3,0,0,164,3,0,0,214,1,0,0,215,1,0,0,216,1,0,0,217,1,0,0,165,3,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,219,1,0,0,220,1,0,0,221,1,0,0,222,1,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,0,1,0,0,248,0,0,0,0,0,0,0,144,37,0,0,155,1,0,0,156,1,0,0,157,1,0,0,158,1,0,0,96,3,0,0,160,1,0,0,161,1,0,0,162,1,0,0,163,1,0,0,97,3,0,0,98,3,0,0,166,1,0,0,167,1,0,0,168,1,0,0,169,1,0,0,170,1,0,0,4,3,0,0,172,1,0,0,246,1,0,0,99,3,0,0,7,3,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,12,3,0,0,100,3,0,0,101,3,0,0,102,3,0,0,103,3,0,0,104,3,0,0,18,3,0,0,19,3,0,0,20,3,0,0,21,3,0,0,105,3,0,0,106,3,0,0,107,3,0,0,108,3,0,0,252,0,0,0,244,0,0,0,252,255,255,255,144,37,0,0,175,1,0,0,176,1,0,0,177,1,0,0,178,1,0,0,109,3,0,0,180,1,0,0,181,1,0,0,182,1,0,0,183,1,0,0,110,3,0,0,111,3,0,0,8,255,255,255,8,255,255,255,8,255,255,255,8,255,255,255,0,0,0,0,0,0,0,0,8,255,255,255,8,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,255,255,255,8,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,255,255,255,8,255,255,255,8,255,255,255,8,255,255,255,8,255,255,255,8,0,0,0,8,255,255,255,144,37,0,0,186,1,0,0,187,1,0,0,188,1,0,0,189,1,0,0,112,3,0,0,191,1,0,0,192,1,0,0,193,1,0,0,194,1,0,0,195,1,0,0,196,1,0,0,197,1,0,0,198,1,0,0,199,1,0,0,200,1,0,0,201,1,0,0,202,1,0,0,203,1,0,0,204,1,0,0,205,1,0,0,206,1,0,0,207,1,0,0,208,1,0,0,209,1,0,0,113,3,0,0,114,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,255,255,255,248,255,255,255,248,255,255,255,248,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,0,255,255,255,0,255,255,255,0,255,255,255,0,255,255,255,0,255,255,255,0,0,0,0,0,255,255,255,144,37,0,0,8,0,0,0,115,3,0,0,116,3,0,0,214,1,0,0,215,1,0,0,216,1,0,0,217,1,0,0,117,3,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,219,1,0,0,220,1,0,0,221,1,0,0,222,1,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,0,0,0,0,0,1,0,0,248,0,0,0,0,0,0,0,32,35,0,0,155,1,0,0,156,1,0,0,157,1,0,0,158,1,0,0,159,1,0,0,160,1,0,0,161,1,0,0,162,1,0,0,163,1,0,0,244,1,0,0,245,1,0,0,166,1,0,0,167,1,0,0,168,1,0,0,169,1,0,0,170,1,0,0,171,1,0,0,172,1,0,0,246,1,0,0,174,1,0,0,252,0,0,0,244,0,0,0,252,255,255,255,32,35,0,0,175,1,0,0,176,1,0,0,177,1,0,0,178,1,0,0,179,1,0,0,180,1,0,0,181,1,0,0,182,1,0,0,183,1,0,0,247,1,0,0,248,1,0,0,8,255,255,255,8,255,255,255,8,255,255,255,8,255,255,255,0,0,0,0,0,0,0,0,8,255,255,255,8,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,255,255,255,8,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,255,255,255,8,255,255,255,8,255,255,255,8,255,255,255,8,255,255,255,8,0,0,0,8,255,255,255,32,35,0,0,186,1,0,0,187,1,0,0,188,1,0,0,189,1,0,0,190,1,0,0,191,1,0,0,192,1,0,0,193,1,0,0,194,1,0,0,195,1,0,0,196,1,0,0,197,1,0,0,198,1,0,0,199,1,0,0,200,1,0,0,201,1,0,0,202,1,0,0,203,1,0,0,204,1,0,0,205,1,0,0,206,1,0,0,207,1,0,0,208,1,0,0,209,1,0,0,249,1,0,0,250,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,255,255,255,248,255,255,255,248,255,255,255,248,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,0,255,255,255,0,255,255,255,0,255,255,255,0,255,255,255,0,255,255,255,0,0,0,0,0,255,255,255,32,35,0,0,8,0,0,0,251,1,0,0,252,1,0,0,214,1,0,0,215,1,0,0,216,1,0,0,217,1,0,0,218,1,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,219,1,0,0,220,1,0,0,221,1,0,0,222,1,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,0,1,0,0,248,0,0,0,0,0,0,0,192,32,0,0,253,1,0,0,254,1,0,0,255,1,0,0,0,2,0,0,1,2,0,0,160,1,0,0,161,1,0,0,162,1,0,0,163,1,0,0,2,2,0,0,3,2,0,0,166,1,0,0,167,1,0,0,168,1,0,0,169,1,0,0,170,1,0,0,4,2,0,0,172,1,0,0,252,0,0,0,244,0,0,0,252,255,255,255,192,32,0,0,5,2,0,0,6,2,0,0,7,2,0,0,8,2,0,0,9,2,0,0,180,1,0,0,181,1,0,0,182,1,0,0,183,1,0,0,10,2,0,0,11,2,0,0,8,255,255,255,8,255,255,255,8,255,255,255,8,255,255,255,0,0,0,0,0,0,0,0,8,255,255,255,8,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,255,255,255,8,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,255,255,255,8,255,255,255,8,255,255,255,8,255,255,255,8,255,255,255,8,0,0,0,8,255,255,255,192,32,0,0,12,2,0,0,13,2,0,0,14,2,0,0,15,2,0,0,16,2,0,0,191,1,0,0,192,1,0,0,193,1,0,0,194,1,0,0,195,1,0,0,196,1,0,0,197,1,0,0,198,1,0,0,199,1,0,0,200,1,0,0,201,1,0,0,202,1,0,0,203,1,0,0,204,1,0,0,205,1,0,0,206,1,0,0,207,1,0,0,208,1,0,0,209,1,0,0,17,2,0,0,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,255,255,255,248,255,255,255,248,255,255,255,248,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,0,255,255,255,0,255,255,255,0,255,255,255,0,255,255,255,0,255,255,255,0,0,0,0,0,255,255,255,192,32,0,0,8,0,0,0,19,2,0,0,20,2,0,0,21,2,0,0,22,2,0,0,23,2,0,0,24,2,0,0,25,2,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,219,1,0,0,220,1,0,0,221,1,0,0,222,1,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,0,1,0,0,248,0,0,0,0,0,0,0,120,90,0,0,26,2,0,0,27,2,0,0,28,2,0,0,29,2,0,0,30,2,0,0,31,2,0,0,32,2,0,0,33,2,0,0,34,2,0,0,35,2,0,0,36,2,0,0,8,255,255,255,8,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,255,255,255,8,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,255,255,255,8,255,255,255,8,255,255,255,8,255,255,255,8,255,255,255,8,0,0,0,8,255,255,255,120,90,0,0,37,2,0,0,38,2,0,0,39,2,0,0,40,2,0,0,41,2,0,0,191,1,0,0,192,1,0,0,193,1,0,0,194,1,0,0,42,2,0,0,43,2,0,0,197,1,0,0,198,1,0,0,199,1,0,0,200,1,0,0,201,1,0,0,202,1,0,0,230,1,0,0,231,1,0,0,205,1,0,0,206,1,0,0,232,1,0,0,233,1,0,0,44,2,0,0,45,2,0,0,46,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,255,255,255,248,255,255,255,248,255,255,255,248,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,0,255,255,255,0,255,255,255,0,255,255,255,0,255,255,255,0,255,255,255,0,0,0,0,0,255,255,255,120,90,0,0,8,0,0,0,47,2,0,0,48,2,0,0,49,2,0,0,50,2,0,0,51,2,0,0,52,2,0,0,53,2,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,219,1,0,0,220,1,0,0,221,1,0,0,222,1,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,252,0,0,0,244,0,0,0,0,0,0,0,216,90,0,0,54,2,0,0,55,2,0,0,56,2,0,0,57,2,0,0,58,2,0,0,59,2,0,0,60,2,0,0,61,2,0,0,62,2,0,0,63,2,0,0,64,2,0,0,12,255,255,255,12,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,255,255,255,12,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,255,255,255,12,255,255,255,12,255,255,255,12,255,255,255,12,255,255,255,8,0,0,0,12,255,255,255,216,90,0,0,65,2,0,0,66,2,0,0,67,2,0,0,68,2,0,0,69,2,0,0,191,1,0,0,192,1,0,0,193,1,0,0,194,1,0,0,228,1,0,0,229,1,0,0,197,1,0,0,198,1,0,0,199,1,0,0,200,1,0,0,201,1,0,0,202,1,0,0,70,2,0,0,71,2,0,0,205,1,0,0,206,1,0,0,232,1,0,0,233,1,0,0,72,2,0,0,73,2,0,0,74,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,255,255,255,248,255,255,255,248,255,255,255,248,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,255,255,255,4,255,255,255,4,255,255,255,4,255,255,255,4,255,255,255,4,255,255,255,0,0,0,0,4,255,255,255,216,90,0,0,8,0,0,0,75,2,0,0,76,2,0,0,77,2,0,0,78,2,0,0,79,2,0,0,80,2,0,0,81,2,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,219,1,0,0,220,1,0,0,221,1,0,0,222,1,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,100,133,1,0,105,175,1,0,144,37,0,0,0,0,0,0,168,0,0,0,160,0,0,0,0,0,0,0,144,37,0,0,155,1,0,0,156,1,0,0,157,1,0,0,158,1,0,0,96,3,0,0,160,1,0,0,161,1,0,0,162,1,0,0,163,1,0,0,97,3,0,0,98,3,0,0,166,1,0,0,167,1,0,0,168,1,0,0,169,1,0,0,170,1,0,0,4,3,0,0,172,1,0,0,246,1,0,0,99,3,0,0,7,3,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,12,3,0,0,100,3,0,0,101,3,0,0,102,3,0,0,103,3,0,0,104,3,0,0,18,3,0,0,19,3,0,0,20,3,0,0,21,3,0,0,105,3,0,0,106,3,0,0,107,3,0,0,108,3,0,0,164,0,0,0,156,0,0,0,252,255,255,255,144,37,0,0,175,1,0,0,176,1,0,0,177,1,0,0,178,1,0,0,109,3,0,0,180,1,0,0,181,1,0,0,182,1,0,0,183,1,0,0,110,3,0,0,111,3,0,0,96,255,255,255,96,255,255,255,96,255,255,255,96,255,255,255,0,0,0,0,0,0,0,0,96,255,255,255,96,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,255,255,255,96,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,255,255,255,96,255,255,255,96,255,255,255,96,255,255,255,96,255,255,255,8,0,0,0,96,255,255,255,144,37,0,0,186,1,0,0,187,1,0,0,188,1,0,0,189,1,0,0,112,3,0,0,191,1,0,0,192,1,0,0,193,1,0,0,194,1,0,0,195,1,0,0,196,1,0,0,197,1,0,0,198,1,0,0,199,1,0,0,200,1,0,0,201,1,0,0,202,1,0,0,203,1,0,0,204,1,0,0,205,1,0,0,206,1,0,0,207,1,0,0,208,1,0,0,209,1,0,0,113,3,0,0,114,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,255,255,255,248,255,255,255,248,255,255,255,248,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,255,255,255,88,255,255,255,88,255,255,255,88,255,255,255,88,255,255,255,88,255,255,255,0,0,0,0,88,255,255,255,144,37,0,0,8,0,0,0,115,3,0,0,116,3,0,0,214,1,0,0,215,1,0,0,216,1,0,0,217,1,0,0,117,3,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,219,1,0,0,220,1,0,0,221,1,0,0,222,1,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,0,0,0,0,168,0,0,0,160,0,0,0,0,0,0,0,32,35,0,0,155,1,0,0,156,1,0,0,157,1,0,0,158,1,0,0,159,1,0,0,160,1,0,0,161,1,0,0,162,1,0,0,163,1,0,0,244,1,0,0,245,1,0,0,166,1,0,0,167,1,0,0,168,1,0,0,169,1,0,0,170,1,0,0,171,1,0,0,172,1,0,0,246,1,0,0,174,1,0,0,164,0,0,0,156,0,0,0,252,255,255,255,32,35,0,0,175,1,0,0,176,1,0,0,177,1,0,0,178,1,0,0,179,1,0,0,180,1,0,0,181,1,0,0,182,1,0,0,183,1,0,0,247,1,0,0,248,1,0,0,96,255,255,255,96,255,255,255,96,255,255,255,96,255,255,255,0,0,0,0,0,0,0,0,96,255,255,255,96,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,255,255,255,96,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,255,255,255,96,255,255,255,96,255,255,255,96,255,255,255,96,255,255,255,8,0,0,0,96,255,255,255,32,35,0,0,186,1,0,0,187,1,0,0,188,1,0,0,189,1,0,0,190,1,0,0,191,1,0,0,192,1,0,0,193,1,0,0,194,1,0,0,195,1,0,0,196,1,0,0,197,1,0,0,198,1,0,0,199,1,0,0,200,1,0,0,201,1,0,0,202,1,0,0,203,1,0,0,204,1,0,0,205,1,0,0,206,1,0,0,207,1,0,0,208,1,0,0,209,1,0,0,249,1,0,0,250,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,255,255,255,248,255,255,255,248,255,255,255,248,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,255,255,255,88,255,255,255,88,255,255,255,88,255,255,255,88,255,255,255,88,255,255,255,0,0,0,0,88,255,255,255,32,35,0,0,8,0,0,0,251,1,0,0,252,1,0,0,214,1,0,0,215,1,0,0,216,1,0,0,217,1,0,0,218,1,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,219,1,0,0,220,1,0,0,221,1,0,0,222,1,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,168,0,0,0,160,0,0,0,0,0,0,0,192,32,0,0,253,1,0,0,254,1,0,0,255,1,0,0,0,2,0,0,1,2,0,0,160,1,0,0,161,1,0,0,162,1,0,0,163,1,0,0,2,2,0,0,3,2,0,0,166,1,0,0,167,1,0,0,168,1,0,0,169,1,0,0,170,1,0,0,4,2,0,0,172,1,0,0,164,0,0,0,156,0,0,0,252,255,255,255,192,32,0,0,5,2,0,0,6,2,0,0,7,2,0,0,8,2,0,0,9,2,0,0,180,1,0,0,181,1,0,0,182,1,0,0,183,1,0,0,10,2,0,0,11,2,0,0,96,255,255,255,96,255,255,255,96,255,255,255,96,255,255,255,0,0,0,0,0,0,0,0,96,255,255,255,96,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,255,255,255,96,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,255,255,255,96,255,255,255,96,255,255,255,96,255,255,255,96,255,255,255,8,0,0,0,96,255,255,255,192,32,0,0,12,2,0,0,13,2,0,0,14,2,0,0,15,2,0,0,16,2,0,0,191,1,0,0,192,1,0,0,193,1,0,0,194,1,0,0,195,1,0,0,196,1,0,0,197,1,0,0,198,1,0,0,199,1,0,0,200,1,0,0,201,1,0,0,202,1,0,0,203,1,0,0,204,1,0,0,205,1,0,0,206,1,0,0,207,1,0,0,208,1,0,0,209,1,0,0,17,2,0,0,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,255,255,255,248,255,255,255,248,255,255,255,248,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,255,255,255,88,255,255,255,88,255,255,255,88,255,255,255,88,255,255,255,88,255,255,255,0,0,0,0,88,255,255,255,192,32,0,0,8,0,0,0,19,2,0,0,20,2,0,0,21,2,0,0,22,2,0,0,23,2,0,0,24,2,0,0,25,2,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,219,1,0,0,220,1,0,0,221,1,0,0,222,1,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,168,0,0,0,160,0,0,0,0,0,0,0,120,90,0,0,26,2,0,0,27,2,0,0,28,2,0,0,29,2,0,0,30,2,0,0,31,2,0,0,32,2,0,0,33,2,0,0,34,2,0,0,35,2,0,0,36,2,0,0,96,255,255,255,96,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,255,255,255,96,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,255,255,255,96,255,255,255,96,255,255,255,96,255,255,255,96,255,255,255,8,0,0,0,96,255,255,255,120,90,0,0,37,2,0,0,38,2,0,0,39,2,0,0,40,2,0,0,41,2,0,0,191,1,0,0,192,1,0,0,193,1,0,0,194,1,0,0,42,2,0,0,43,2,0,0,197,1,0,0,198,1,0,0,199,1,0,0,200,1,0,0,201,1,0,0,202,1,0,0,230,1,0,0,231,1,0,0,205,1,0,0,206,1,0,0,232,1,0,0,233,1,0,0,44,2,0,0,45,2,0,0,46,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,255,255,255,248,255,255,255,248,255,255,255,248,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,255,255,255,88,255,255,255,88,255,255,255,88,255,255,255,88,255,255,255,88,255,255,255,0,0,0,0,88,255,255,255,120,90,0,0,8,0,0,0,47,2,0,0,48,2,0,0,49,2,0,0,50,2,0,0,51,2,0,0,52,2,0,0,53,2,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,219,1,0,0,220,1,0,0,221,1,0,0,222,1,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,164,0,0,0,156,0,0,0,0,0,0,0,216,90,0,0,54,2,0,0,55,2,0,0,56,2,0,0,57,2,0,0,58,2,0,0,59,2,0,0,60,2,0,0,61,2,0,0,62,2,0,0,63,2,0,0,64,2,0,0,100,255,255,255,100,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,100,255,255,255,100,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,100,255,255,255,100,255,255,255,100,255,255,255,100,255,255,255,100,255,255,255,8,0,0,0,100,255,255,255,216,90,0,0,65,2,0,0,66,2,0,0,67,2,0,0,68,2,0,0,69,2,0,0,191,1,0,0,192,1,0,0,193,1,0,0,194,1,0,0,228,1,0,0,229,1,0,0,197,1,0,0,198,1,0,0,199,1,0,0,200,1,0,0,201,1,0,0,202,1,0,0,70,2,0,0,71,2,0,0,205,1,0,0,206,1,0,0,232,1,0,0,233,1,0,0,72,2,0,0,73,2,0,0,74,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,255,255,255,248,255,255,255,248,255,255,255,248,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,92,255,255,255,92,255,255,255,92,255,255,255,92,255,255,255,92,255,255,255,92,255,255,255,0,0,0,0,92,255,255,255,216,90,0,0,8,0,0,0,75,2,0,0,76,2,0,0,77,2,0,0,78,2,0,0,79,2,0,0,80,2,0,0,81,2,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,219,1,0,0,220,1,0,0,221,1,0,0,222,1,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,100,133,1,0,175,175,1,0,112,101,0,0,0,0,0,0,124,0,0,0,0,0,0,0,112,101,0,0,233,2,0,0,234,2,0,0,116,0,0,0,117,0,0,0,118,0,0,0,235,2,0,0,236,2,0,0,121,0,0,0,122,0,0,0,123,0,0,0,124,0,0,0,125,0,0,0,126,0,0,0,127,0,0,0,128,0,0,0,129,0,0,0,130,0,0,0,131,0,0,0,132,0,0,0,133,0,0,0,134,0,0,0,135,0,0,0,136,0,0,0,137,0,0,0,138,0,0,0,139,0,0,0,140,0,0,0,237,2,0,0,142,0,0,0,143,0,0,0,144,0,0,0,145,0,0,0,146,0,0,0,223,2,0,0,148,0,0,0,149,0,0,0,150,0,0,0,151,0,0,0,152,0,0,0,153,0,0,0,154,0,0,0,155,0,0,0,156,0,0,0,157,0,0,0,158,0,0,0,159,0,0,0,160,0,0,0,161,0,0,0,162,0,0,0,163,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,132,255,255,255,132,255,255,255,0,0,0,0,0,0,0,0,132,255,255,255,132,255,255,255,132,255,255,255,132,255,255,255,132,255,255,255,132,255,255,255,0,0,0,0,132,255,255,255,112,101,0,0,8,0,0,0,238,2,0,0,239,2,0,0,166,0,0,0,167,0,0,0,168,0,0,0,240,2,0,0,241,2,0,0,16,0,0,0,17,0,0,0,171,0,0,0,172,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,100,133,1,0,152,175,1,0,0,102,0,0,0,0,0,0,100,133,1,0,204,175,1,0,120,103,0,0,0,0,0,0,100,133,1,0,33,176,1,0,112,101,0,0,0,0,0,0,160,0,0,0,0,0,0,0,112,101,0,0,233,2,0,0,234,2,0,0,116,0,0,0,117,0,0,0,118,0,0,0,235,2,0,0,236,2,0,0,121,0,0,0,122,0,0,0,123,0,0,0,124,0,0,0,125,0,0,0,126,0,0,0,127,0,0,0,128,0,0,0,129,0,0,0,130,0,0,0,131,0,0,0,132,0,0,0,133,0,0,0,134,0,0,0,135,0,0,0,136,0,0,0,137,0,0,0,138,0,0,0,139,0,0,0,140,0,0,0,237,2,0,0,142,0,0,0,143,0,0,0,144,0,0,0,145,0,0,0,146,0,0,0,223,2,0,0,148,0,0,0,149,0,0,0,150,0,0,0,151,0,0,0,152,0,0,0,153,0,0,0,154,0,0,0,155,0,0,0,156,0,0,0,157,0,0,0,158,0,0,0,159,0,0,0,160,0,0,0,161,0,0,0,162,0,0,0,163,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,255,255,255,96,255,255,255,0,0,0,0,0,0,0,0,96,255,255,255,96,255,255,255,96,255,255,255,96,255,255,255,96,255,255,255,96,255,255,255,0,0,0,0,96,255,255,255,112,101,0,0,8,0,0,0,238,2,0,0,239,2,0,0,166,0,0,0,167,0,0,0,168,0,0,0,240,2,0,0,241,2,0,0,16,0,0,0,17,0,0,0,171,0,0,0,172,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,64,134,1,0,255,175,1,0,0,0,0,0,2,0,0,0,0,102,0,0,2,0,0,0,120,79,0,0,2,32,0,0,60,133,1,0,18,176,1,0,100,133,1,0,65,176,1,0,112,101,0,0,0,0,0,0,132,0,0,0,0,0,0,0,112,101,0,0,233,2,0,0,234,2,0,0,116,0,0,0,117,0,0,0,118,0,0,0,235,2,0,0,236,2,0,0,121,0,0,0,122,0,0,0,123,0,0,0,124,0,0,0,125,0,0,0,126,0,0,0,127,0,0,0,128,0,0,0,129,0,0,0,130,0,0,0,131,0,0,0,132,0,0,0,133,0,0,0,134,0,0,0,135,0,0,0,136,0,0,0,137,0,0,0,138,0,0,0,139,0,0,0,140], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+10240);
/* memory initializer */ allocate([237,2,0,0,142,0,0,0,143,0,0,0,144,0,0,0,145,0,0,0,146,0,0,0,223,2,0,0,148,0,0,0,149,0,0,0,150,0,0,0,151,0,0,0,152,0,0,0,153,0,0,0,154,0,0,0,155,0,0,0,156,0,0,0,157,0,0,0,158,0,0,0,159,0,0,0,160,0,0,0,161,0,0,0,162,0,0,0,163,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,124,255,255,255,124,255,255,255,0,0,0,0,0,0,0,0,124,255,255,255,124,255,255,255,124,255,255,255,124,255,255,255,124,255,255,255,124,255,255,255,0,0,0,0,124,255,255,255,112,101,0,0,8,0,0,0,238,2,0,0,239,2,0,0,166,0,0,0,167,0,0,0,168,0,0,0,240,2,0,0,241,2,0,0,16,0,0,0,17,0,0,0,171,0,0,0,172,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,100,133,1,0,92,176,1,0,144,81,0,0,0,0,0,0,100,133,1,0,151,176,1,0,120,103,0,0,0,0,0,0,100,133,1,0,201,176,1,0,144,81,0,0,0,0,0,0,100,133,1,0,3,177,1,0,144,81,0,0,0,0,0,0,100,133,1,0,176,178,1,0,0,102,0,0,0,0,0,0,100,133,1,0,243,178,1,0,120,103,0,0,0,0,0,0,100,133,1,0,243,180,1,0,72,77,0,0,0,0,0,0,64,134,1,0,109,179,1,0,0,0,0,0,2,0,0,0,16,82,0,0,2,0,0,0,24,82,0,0,2,4,0,0,60,133,1,0,15,180,1,0,60,133,1,0,206,179,1,0,64,134,1,0,40,180,1,0,0,0,0,0,2,0,0,0,16,82,0,0,2,0,0,0,64,82,0,0,2,8,0,0,60,133,1,0,137,180,1,0,100,133,1,0,202,180,1,0,120,103,0,0,0,0,0,0,64,134,1,0,22,181,1,0,0,0,0,0,2,0,0,0,232,89,0,0,2,0,0,0,120,82,0,0,2,72,0,0,60,133,1,0,76,181,1,0,100,133,1,0,99,181,1,0,112,101,0,0,0,0,0,0,60,133,1,0,132,181,1,0,64,0,0,0,0,0,0,0,24,129,0,0,29,1,0,0,30,1,0,0,192,255,255,255,192,255,255,255,24,129,0,0,31,1,0,0,32,1,0,0,64,0,0,0,0,0,0,0,120,129,0,0,27,4,0,0,28,4,0,0,56,0,0,0,248,255,255,255,120,129,0,0,29,4,0,0,30,4,0,0,192,255,255,255,192,255,255,255,120,129,0,0,31,4,0,0,32,4,0,0,0,0,0,0,100,133,1,0,153,181,1,0,120,129,0,0,0,0,0,0,100,133,1,0,222,181,1,0,128,82,0,0,0,0,0,0,100,133,1,0,53,184,1,0,72,77,0,0,0,0,0,0,64,134,1,0,159,187,1,0,0,0,0,0,2,0,0,0,0,102,0,0,2,0,0,0,112,95,0,0,2,32,0,0,100,133,1,0,121,184,1,0,120,103,0,0,0,0,0,0,100,133,1,0,98,192,1,0,112,101,0,0,0,0,0,0,56,0,0,0,0,0,0,0,72,129,0,0,85,4,0,0,86,4,0,0,200,255,255,255,200,255,255,255,72,129,0,0,87,4,0,0,88,4,0,0,100,133,1,0,28,192,1,0,72,129,0,0,0,0,0,0,100,133,1,0,127,192,1,0,8,104,0,0,0,0,0,0,100,133,1,0,146,192,1,0,120,103,0,0,0,0,0,0,100,133,1,0,173,192,1,0,16,82,0,0,0,0,0,0,100,133,1,0,175,193,1,0,112,101,0,0,0,0,0,0,120,1,0,0,0,0,0,0,112,101,0,0,233,2,0,0,234,2,0,0,116,0,0,0,117,0,0,0,118,0,0,0,235,2,0,0,236,2,0,0,121,0,0,0,122,0,0,0,123,0,0,0,124,0,0,0,125,0,0,0,126,0,0,0,127,0,0,0,128,0,0,0,129,0,0,0,130,0,0,0,131,0,0,0,132,0,0,0,133,0,0,0,134,0,0,0,135,0,0,0,136,0,0,0,137,0,0,0,138,0,0,0,139,0,0,0,140,0,0,0,237,2,0,0,142,0,0,0,143,0,0,0,144,0,0,0,145,0,0,0,146,0,0,0,223,2,0,0,148,0,0,0,149,0,0,0,150,0,0,0,151,0,0,0,152,0,0,0,153,0,0,0,154,0,0,0,155,0,0,0,156,0,0,0,157,0,0,0,158,0,0,0,159,0,0,0,160,0,0,0,161,0,0,0,162,0,0,0,163,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,254,255,255,136,254,255,255,0,0,0,0,0,0,0,0,136,254,255,255,136,254,255,255,136,254,255,255,136,254,255,255,136,254,255,255,136,254,255,255,0,0,0,0,136,254,255,255,112,101,0,0,8,0,0,0,238,2,0,0,239,2,0,0,166,0,0,0,167,0,0,0,168,0,0,0,240,2,0,0,241,2,0,0,16,0,0,0,17,0,0,0,171,0,0,0,172,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,60,133,1,0,200,193,1,0,100,133,1,0,244,193,1,0,112,101,0,0,0,0,0,0,64,134,1,0,20,198,1,0,0,0,0,0,2,0,0,0,112,101,0,0,2,0,0,0,120,95,0,0,2,56,0,0,252,1,0,0,0,0,0,0,112,101,0,0,233,2,0,0,234,2,0,0,116,0,0,0,117,0,0,0,118,0,0,0,235,2,0,0,236,2,0,0,121,0,0,0,122,0,0,0,123,0,0,0,124,0,0,0,125,0,0,0,126,0,0,0,127,0,0,0,128,0,0,0,129,0,0,0,130,0,0,0,131,0,0,0,132,0,0,0,133,0,0,0,134,0,0,0,135,0,0,0,136,0,0,0,137,0,0,0,138,0,0,0,139,0,0,0,140,0,0,0,237,2,0,0,142,0,0,0,143,0,0,0,144,0,0,0,145,0,0,0,146,0,0,0,223,2,0,0,148,0,0,0,149,0,0,0,150,0,0,0,151,0,0,0,152,0,0,0,153,0,0,0,154,0,0,0,155,0,0,0,156,0,0,0,157,0,0,0,158,0,0,0,159,0,0,0,160,0,0,0,161,0,0,0,162,0,0,0,163,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,254,255,255,4,254,255,255,0,0,0,0,0,0,0,0,4,254,255,255,4,254,255,255,4,254,255,255,4,254,255,255,4,254,255,255,4,254,255,255,0,0,0,0,4,254,255,255,112,101,0,0,8,0,0,0,238,2,0,0,239,2,0,0,166,0,0,0,167,0,0,0,168,0,0,0,240,2,0,0,241,2,0,0,16,0,0,0,17,0,0,0,171,0,0,0,172,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,64,134,1,0,119,195,1,0,0,0,0,0,2,0,0,0,16,82,0,0,2,0,0,0,32,88,0,0,2,8,0,0,60,133,1,0,198,195,1,0,64,134,1,0,243,195,1,0,0,0,0,0,2,0,0,0,16,82,0,0,2,0,0,0,72,88,0,0,2,8,0,0,60,133,1,0,63,196,1,0,64,134,1,0,122,196,1,0,0,0,0,0,2,0,0,0,0,102,0,0,2,0,0,0,16,102,0,0,2,32,0,0,60,133,1,0,44,198,1,0,100,133,1,0,80,198,1,0,248,102,0,0,0,0,0,0,64,134,1,0,101,198,1,0,0,0,0,0,2,0,0,0,232,89,0,0,2,0,0,0,168,88,0,0,2,72,0,0,60,133,1,0,155,198,1,0,64,134,1,0,197,198,1,0,0,0,0,0,2,0,0,0,208,88,0,0,2,0,0,0,112,88,0,0,2,72,0,0,100,133,1,0,178,198,1,0,232,89,0,0,0,0,0,0,60,133,1,0,0,199,1,0,60,133,1,0,23,199,1,0,64,134,1,0,46,199,1,0,0,0,0,0,2,0,0,0,208,88,0,0,2,0,0,0,16,89,0,0,2,72,0,0,60,133,1,0,105,199,1,0,100,133,1,0,153,199,1,0,0,102,0,0,0,0,0,0,100,133,1,0,200,200,1,0,0,102,0,0,0,0,0,0,64,134,1,0,137,201,1,0,0,0,0,0,3,0,0,0,96,89,0,0,0,0,0,0,120,103,0,0,2,0,0,0,104,89,0,0,2,12,0,0,60,133,1,0,54,202,1,0,60,133,1,0,162,201,1,0,100,133,1,0,236,202,1,0,120,103,0,0,0,0,0,0,100,133,1,0,82,207,1,0,40,89,0,0,0,0,0,0,60,0,0,0,0,0,0,0,104,32,0,0,179,2,0,0,7,0,0,0,185,2,0,0,186,2,0,0,196,255,255,255,0,0,0,0,196,255,255,255,104,32,0,0,1,0,0,0,187,2,0,0,188,2,0,0,100,133,1,0,255,203,1,0,104,32,0,0,0,0,0,0,100,133,1,0,106,207,1,0,120,103,0,0,0,0,0,0,100,133,1,0,22,208,1,0,56,90,0,0,0,0,0,0,100,133,1,0,35,208,1,0,112,96,0,0,0,0,0,0,100,133,1,0,58,208,1,0,120,103,0,0,0,0,0,0,100,133,1,0,44,210,1,0,128,96,0,0,0,0,0,0,100,133,1,0,119,210,1,0,0,102,0,0,0,0,0,0,100,133,1,0,224,210,1,0,0,102,0,0,0,0,0,0,100,133,1,0,6,211,1,0,40,90,0,0,0,0,0,0,100,133,1,0,53,211,1,0,40,90,0,0,0,0,0,0,100,133,1,0,141,211,1,0,40,90,0,0,0,0,0,0,64,134,1,0,118,213,1,0,0,0,0,0,1,0,0,0,240,21,0,0,3,244,255,255,64,134,1,0,162,213,1,0,0,0,0,0,1,0,0,0,240,21,0,0,3,244,255,255,64,134,1,0,193,213,1,0,0,0,0,0,1,0,0,0,240,21,0,0,3,244,255,255,64,134,1,0,217,213,1,0,0,0,0,0,1,0,0,0,240,21,0,0,3,244,255,255,64,134,1,0,248,213,1,0,0,0,0,0,1,0,0,0,240,21,0,0,3,244,255,255,64,134,1,0,22,214,1,0,0,0,0,0,1,0,0,0,240,21,0,0,3,244,255,255,64,134,1,0,58,214,1,0,0,0,0,0,2,0,0,0,48,105,0,0,2,0,0,0,112,95,0,0,2,144,0,0,64,134,1,0,96,214,1,0,0,0,0,0,2,0,0,0,112,101,0,0,2,0,0,0,120,95,0,0,2,56,0,0,140,1,0,0,0,0,0,0,112,101,0,0,233,2,0,0,234,2,0,0,116,0,0,0,117,0,0,0,118,0,0,0,235,2,0,0,236,2,0,0,121,0,0,0,122,0,0,0,123,0,0,0,124,0,0,0,125,0,0,0,126,0,0,0,127,0,0,0,128,0,0,0,129,0,0,0,130,0,0,0,131,0,0,0,132,0,0,0,133,0,0,0,134,0,0,0,135,0,0,0,136,0,0,0,137,0,0,0,138,0,0,0,139,0,0,0,140,0,0,0,237,2,0,0,142,0,0,0,143,0,0,0,144,0,0,0,145,0,0,0,146,0,0,0,223,2,0,0,148,0,0,0,149,0,0,0,150,0,0,0,151,0,0,0,152,0,0,0,153,0,0,0,154,0,0,0,155,0,0,0,156,0,0,0,157,0,0,0,158,0,0,0,159,0,0,0,160,0,0,0,161,0,0,0,162,0,0,0,163,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,116,254,255,255,116,254,255,255,0,0,0,0,0,0,0,0,116,254,255,255,116,254,255,255,116,254,255,255,116,254,255,255,116,254,255,255,116,254,255,255,0,0,0,0,116,254,255,255,112,101,0,0,8,0,0,0,238,2,0,0,239,2,0,0,166,0,0,0,167,0,0,0,168,0,0,0,240,2,0,0,241,2,0,0,16,0,0,0,17,0,0,0,171,0,0,0,172,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,100,133,1,0,153,214,1,0,56,77,0,0,0,0,0,0,100,133,1,0,191,214,1,0,112,101,0,0,0,0,0,0,92,0,0,0,0,0,0,0,112,101,0,0,233,2,0,0,234,2,0,0,116,0,0,0,117,0,0,0,118,0,0,0,235,2,0,0,236,2,0,0,121,0,0,0,122,0,0,0,123,0,0,0,124,0,0,0,125,0,0,0,126,0,0,0,127,0,0,0,128,0,0,0,129,0,0,0,130,0,0,0,131,0,0,0,132,0,0,0,133,0,0,0,134,0,0,0,135,0,0,0,136,0,0,0,137,0,0,0,138,0,0,0,139,0,0,0,140,0,0,0,237,2,0,0,142,0,0,0,143,0,0,0,144,0,0,0,145,0,0,0,146,0,0,0,223,2,0,0,148,0,0,0,149,0,0,0,150,0,0,0,151,0,0,0,152,0,0,0,153,0,0,0,154,0,0,0,155,0,0,0,156,0,0,0,157,0,0,0,158,0,0,0,159,0,0,0,160,0,0,0,161,0,0,0,162,0,0,0,163,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,164,255,255,255,164,255,255,255,0,0,0,0,0,0,0,0,164,255,255,255,164,255,255,255,164,255,255,255,164,255,255,255,164,255,255,255,164,255,255,255,0,0,0,0,164,255,255,255,112,101,0,0,8,0,0,0,238,2,0,0,239,2,0,0,166,0,0,0,167,0,0,0,168,0,0,0,240,2,0,0,241,2,0,0,16,0,0,0,17,0,0,0,171,0,0,0,172,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,100,133,1,0,220,214,1,0,128,96,0,0,0,0,0,0,60,133,1,0,166,216,1,0,100,133,1,0,180,216,1,0,120,103,0,0,0,0,0,0,60,133,1,0,199,216,1,0,100,133,1,0,194,218,1,0,112,95,0,0,0,0,0,0,100,133,1,0,211,218,1,0,120,103,0,0,0,0,0,0,100,133,1,0,253,238,1,0,96,101,0,0,0,0,0,0,100,133,1,0,253,237,1,0,16,82,0,0,0,0,0,0,100,133,1,0,223,238,1,0,128,96,0,0,0,0,0,0,100,133,1,0,13,239,1,0,144,96,0,0,0,0,0,0,100,133,1,0,43,239,1,0,144,96,0,0,0,0,0,0,100,133,1,0,91,239,1,0,0,102,0,0,0,0,0,0,100,133,1,0,39,241,1,0,56,77,0,0,0,0,0,0,100,133,1,0,100,242,1,0,120,103,0,0,0,0,0,0,100,133,1,0,125,242,1,0,216,98,0,0,0,0,0,0,100,133,1,0,134,246,1,0,152,95,0,0,0,0,0,0,100,133,1,0,216,244,1,0,72,96,0,0,0,0,0,0,60,133,1,0,2,245,1,0,100,133,1,0,99,245,1,0,144,82,0,0,0,0,0,0,100,133,1,0,119,43,2,0,120,103,0,0,0,0,0,0,100,133,1,0,140,43,2,0,120,103,0,0,0,0,0,0,100,133,1,0,170,43,2,0,120,103,0,0,0,0,0,0,100,133,1,0,32,44,2,0,128,96,0,0,0,0,0,0,100,133,1,0,59,44,2,0,120,103,0,0,0,0,0,0,100,133,1,0,89,44,2,0,120,103,0,0,0,0,0,0,100,133,1,0,119,44,2,0,120,103,0,0,0,0,0,0,100,133,1,0,199,44,2,0,120,103,0,0,0,0,0,0,100,133,1,0,9,45,2,0,120,103,0,0,0,0,0,0,100,133,1,0,93,46,2,0,0,102,0,0,0,0,0,0,100,133,1,0,117,46,2,0,16,97,0,0,0,0,0,0,100,133,1,0,149,46,2,0,120,103,0,0,0,0,0,0,64,134,1,0,17,48,2,0,0,0,0,0,2,0,0,0,120,103,0,0,2,0,0,0,64,97,0,0,2,12,0,0,60,133,1,0,48,48,2,0,64,134,1,0,90,48,2,0,0,0,0,0,2,0,0,0,120,103,0,0,3,244,255,255,104,97,0,0,2,4,0,0,60,133,1,0,106,48,2,0,100,133,1,0,161,48,2,0,72,102,0,0,0,0,0,0,64,134,1,0,184,48,2,0,0,0,0,0,2,0,0,0,216,97,0,0,2,0,0,0,104,97,0,0,2,20,0,0,44,0,0,0,0,0,0,0,104,32,0,0,179,2,0,0,7,0,0,0,185,2,0,0,186,2,0,0,212,255,255,255,0,0,0,0,212,255,255,255,104,32,0,0,1,0,0,0,187,2,0,0,188,2,0,0,100,133,1,0,215,48,2,0,104,32,0,0,0,0,0,0,44,0,0,0,0,0,0,0,216,97,0,0,179,2,0,0,180,2,0,0,181,2,0,0,182,2,0,0,7,0,0,0,212,255,255,255,0,0,0,0,212,255,255,255,216,97,0,0,1,0,0,0,183,2,0,0,184,2,0,0,0,0,0,0,64,134,1,0,241,48,2,0,0,0,0,0,2,0,0,0,72,98,0,0,2,12,0,0,80,98,0,0,2,0,0,0,60,133,1,0,69,49,2,0,100,133,1,0,15,49,2,0,120,103,0,0,0,0,0,0,100,133,1,0,97,49,2,0,216,97,0,0,0,0,0,0,64,134,1,0,126,49,2,0,0,0,0,0,2,0,0,0,104,32,0,0,2,0,0,0,96,106,0,0,2,20,0,0,36,0,0,0,0,0,0,0,104,32,0,0,179,2,0,0,7,0,0,0,185,2,0,0,186,2,0,0,220,255,255,255,0,0,0,0,220,255,255,255,104,32,0,0,1,0,0,0,187,2,0,0,188,2,0,0,100,133,1,0,151,49,2,0,216,97,0,0,0,0,0,0,100,133,1,0,83,50,2,0,96,101,0,0,0,0,0,0,100,133,1,0,84,53,2,0,56,90,0,0,0,0,0,0,100,133,1,0,97,53,2,0,144,90,0,0,0,0,0,0,100,133,1,0,126,53,2,0,232,98,0,0,0,0,0,0,100,133,1,0,27,55,2,0,192,103,0,0,0,0,0,0,64,134,1,0,181,54,2,0,0,0,0,0,2,0,0,0,216,85,0,0,2,0,0,0,72,99,0,0,2,4,0,0,60,133,1,0,248,54,2,0,100,133,1,0,55,55,2,0,112,101,0,0,0,0,0,0,72,0,0,0,0,0,0,0,112,101,0,0,233,2,0,0,234,2,0,0,116,0,0,0,117,0,0,0,118,0,0,0,235,2,0,0,236,2,0,0,121,0,0,0,122,0,0,0,123,0,0,0,124,0,0,0,125,0,0,0,126,0,0,0,127,0,0,0,128,0,0,0,129,0,0,0,130,0,0,0,131,0,0,0,132,0,0,0,133,0,0,0,134,0,0,0,135,0,0,0,136,0,0,0,137,0,0,0,138,0,0,0,139,0,0,0,140,0,0,0,237,2,0,0,142,0,0,0,143,0,0,0,144,0,0,0,145,0,0,0,146,0,0,0,223,2,0,0,148,0,0,0,149,0,0,0,150,0,0,0,151,0,0,0,152,0,0,0,153,0,0,0,154,0,0,0,155,0,0,0,156,0,0,0,157,0,0,0,158,0,0,0,159,0,0,0,160,0,0,0,161,0,0,0,162,0,0,0,163,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,255,255,255,184,255,255,255,0,0,0,0,0,0,0,0,184,255,255,255,184,255,255,255,184,255,255,255,184,255,255,255,184,255,255,255,184,255,255,255,0,0,0,0,184,255,255,255,112,101,0,0,8,0,0,0,238,2,0,0,239,2,0,0,166,0,0,0,167,0,0,0,168,0,0,0,240,2,0,0,241,2,0,0,16,0,0,0,17,0,0,0,171,0,0,0,172,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,100,133,1,0,77,55,2,0,216,98,0,0,0,0,0,0,100,133,1,0,96,55,2,0,0,102,0,0,0,0,0,0,64,134,1,0,108,55,2,0,0,0,0,0,1,0,0,0,0,102,0,0,3,244,255,255,100,133,1,0,128,55,2,0,32,15,0,0,0,0,0,0,100,133,1,0,252,55,2,0,72,129,0,0,0,0,0,0,8,0,0,0,0,0,0,0,72,129,0,0,85,4,0,0,86,4,0,0,248,255,255,255,248,255,255,255,72,129,0,0,87,4,0,0,88,4,0,0,100,133,1,0,15,56,2,0,72,129,0,0,0,0,0,0,100,133,1,0,141,56,2,0,224,20,0,0,0,0,0,0,100,133,1,0,168,56,2,0,8,129,0,0,0,0,0,0,100,133,1,0,193,56,2,0,120,103,0,0,0,0,0,0,60,133,1,0,207,56,2,0,100,133,1,0,223,56,2,0,120,103,0,0,0,0,0,0,100,133,1,0,45,57,2,0,216,98,0,0,0,0,0,0,100,133,1,0,66,57,2,0,120,103,0,0,0,0,0,0,64,134,1,0,2,58,2,0,0,0,0,0,2,0,0,0,120,103,0,0,2,0,0,0,80,106,0,0,2,12,0,0,100,133,1,0,36,58,2,0,80,101,0,0,0,0,0,0,100,133,1,0,120,58,2,0,56,77,0,0,0,0,0,0,100,133,1,0,83,59,2,0,56,77,0,0,0,0,0,0,64,134,1,0,106,59,2,0,0,0,0,0,2,0,0,0,120,88,0,0,2,0,0,0,232,88,0,0,2,64,0,0,64,134,1,0,132,59,2,0,0,0,0,0,2,0,0,0,120,88,0,0,2,0,0,0,224,88,0,0,2,64,0,0,64,134,1,0,159,59,2,0,0,0,0,0,2,0,0,0,120,88,0,0,2,0,0,0,112,88,0,0,2,64,0,0,100,133,1,0,184,59,2,0,56,90,0,0,0,0,0,0,100,133,1,0,205,59,2,0,248,102,0,0,0,0,0,0,100,133,1,0,32,62,2,0,56,77,0,0,0,0,0,0,100,133,1,0,215,61,2,0,120,103,0,0,0,0,0,0,100,133,1,0,238,59,2,0,0,102,0,0,0,0,0,0,100,133,1,0,196,61,2,0,144,96,0,0,0,0,0,0,100,133,1,0,249,61,2,0,112,96,0,0,0,0,0,0,100,133,1,0,47,62,2,0,216,98,0,0,0,0,0,0,60,133,1,0,30,63,2,0,100,133,1,0,33,66,2,0,120,103,0,0,0,0,0,0,100,133,1,0,15,66,2,0,144,96,0,0,0,0,0,0,100,133,1,0,65,66,2,0,120,103,0,0,0,0,0,0,100,133,1,0,101,66,2,0,0,102,0,0,0,0,0,0,100,133,1,0,51,67,2,0,0,102,0,0,0,0,0,0,100,133,1,0,64,67,2,0,192,103,0,0,0,0,0,0,100,133,1,0,176,67,2,0,240,103,0,0,0,0,0,0,60,133,1,0,210,67,2,0,100,133,1,0,249,67,2,0,192,103,0,0,0,0,0,0,100,133,1,0,214,68,2,0,120,103,0,0,0,0,0,0,100,133,1,0,228,75,2,0,0,102,0,0,0,0,0,0,100,133,1,0,203,83,2,0,56,104,0,0,0,0,0,0,60,133,1,0,229,83,2,0,100,133,1,0,11,87,2,0,56,104,0,0,0,0,0,0,100,133,1,0,40,87,2,0,120,103,0,0,0,0,0,0,100,133,1,0,115,87,2,0,56,77,0,0,0,0,0,0,100,133,1,0,185,87,2,0,56,77,0,0,0,0,0,0,100,133,1,0,199,87,2,0,240,104,0,0,0,0,0,0,100,133,1,0,17,88,2,0,240,104,0,0,0,0,0,0,100,133,1,0,50,88,2,0,240,104,0,0,0,0,0,0,100,133,1,0,166,88,2,0,240,104,0,0,0,0,0,0,100,133,1,0,195,88,2,0,240,104,0,0,0,0,0,0,100,133,1,0,49,89,2,0,120,103,0,0,0,0,0,0,100,133,1,0,255,91,2,0,128,96,0,0,0,0,0,0,100,133,1,0,36,92,2,0,56,77,0,0,0,0,0,0,100,133,1,0,51,92,2,0,112,96,0,0,0,0,0,0,100,133,1,0,78,97,2,0,240,104,0,0,0,0,0,0,100,133,1,0,24,99,2,0,240,104,0,0,0,0,0,0,100,133,1,0,59,99,2,0,216,98,0,0,0,0,0,0,100,133,1,0,76,99,2,0,112,101,0,0,0,0,0,0,100,133,1,0,130,99,2,0,0,102,0,0,0,0,0,0,100,133,1,0,140,105,2,0,0,102,0,0,0,0,0,0,100,133,1,0,191,105,2,0,96,105,0,0,0,0,0,0,100,133,1,0,224,105,2,0,120,103,0,0,0,0,0,0,100,133,1,0,124,106,2,0,160,105,0,0,0,0,0,0,100,133,1,0,152,106,2,0,120,103,0,0,0,0,0,0,100,133,1,0,221,108,2,0,128,96,0,0,0,0,0,0,64,134,1,0,58,109,2,0,0,0,0,0,1,0,0,0,0,102,0,0,3,244,255,255,60,133,1,0,40,109,2,0,100,133,1,0,79,109,2,0,56,77,0,0,0,0,0,0,100,133,1,0,33,111,2,0,120,103,0,0,0,0,0,0,100,133,1,0,62,111,2,0,16,106,0,0,0,0,0,0,100,133,1,0,106,111,2,0,120,103,0,0,0,0,0,0,100,133,1,0,2,112,2,0,56,77,0,0,0,0,0,0,100,133,1,0,72,112,2,0,56,77,0,0,0,0,0,0,100,133,1,0,168,114,2,0,0,102,0,0,0,0,0,0,60,133,1,0,235,114,2,0,60,133,1,0,67,115,2,0,60,133,1,0,169,115,2,0,60,133,1,0,193,115,2,0,60,133,1,0,47,116,2,0,60,133,1,0,137,116,2,0,60,133,1,0,182,116,2,0,60,133,1,0,204,116,2,0,100,133,1,0,246,116,2,0,176,134,0,0,0,0,0,0,100,133,1,0,82,117,2,0,184,106,0,0,0,0,0,0,60,133,1,0,18,117,2,0,60,133,1,0,200,117,2,0,100,133,1,0,40,118,2,0,216,106,0,0,0,0,0,0,60,133,1,0,236,117,2,0,60,133,1,0,152,118,2,0,100,133,1,0,13,119,2,0,248,106,0,0,0,0,0,0,60,133,1,0,186,118,2,0,60,133,1,0,144,119,2,0,100,133,1,0,238,119,2,0,216,106,0,0,0,0,0,0,60,133,1,0,178,119,2,0,100,133,1,0,169,122,2,0,0,102,0,0,0,0,0,0,100,133,1,0,1,123,2,0,32,35,0,0,0,0,0,0,92,0,0,0,84,0,0,0,0,0,0,0,32,35,0,0,155,1,0,0,156,1,0,0,157,1,0,0,158,1,0,0,159,1,0,0,160,1,0,0,161,1,0,0,162,1,0,0,163,1,0,0,244,1,0,0,245,1,0,0,166,1,0,0,167,1,0,0,168,1,0,0,169,1,0,0,170,1,0,0,171,1,0,0,172,1,0,0,246,1,0,0,174,1,0,0,88,0,0,0,80,0,0,0,252,255,255,255,32,35,0,0,175,1,0,0,176,1,0,0,177,1,0,0,178,1,0,0,179,1,0,0,180,1,0,0,181,1,0,0,182,1,0,0,183,1,0,0,247,1,0,0,248,1,0,0,172,255,255,255,172,255,255,255,172,255,255,255,172,255,255,255,0,0,0,0,0,0,0,0,172,255,255,255,172,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,172,255,255,255,172,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,172,255,255,255,172,255,255,255,172,255,255,255,172,255,255,255,172,255,255,255,8,0,0,0,172,255,255,255,32,35,0,0,186,1,0,0,187,1,0,0,188,1,0,0,189,1,0,0,190,1,0,0,191,1,0,0,192,1,0,0,193,1,0,0,194,1,0,0,195,1,0,0,196,1,0,0,197,1,0,0,198,1,0,0,199,1,0,0,200,1,0,0,201,1,0,0,202,1,0,0,203,1,0,0,204,1,0,0,205,1,0,0,206,1,0,0,207,1,0,0,208,1,0,0,209,1,0,0,249,1,0,0,250,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,255,255,255,248,255,255,255,248,255,255,255,248,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,164,255,255,255,164,255,255,255,164,255,255,255,164,255,255,255,164,255,255,255,164,255,255,255,0,0,0,0,164,255,255,255,32,35,0,0,8,0,0,0,251,1,0,0,252,1,0,0,214,1,0,0,215,1,0,0,216,1,0,0,217,1,0,0,218,1,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,219,1,0,0,220,1,0,0,221,1,0,0,222,1,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,92,0,0,0,84,0,0,0,0,0,0,0,192,32,0,0,253,1,0,0,254,1,0,0,255,1,0,0,0,2,0,0,1,2,0,0,160,1,0,0,161,1,0,0,162,1,0,0,163,1,0,0,2,2,0,0,3,2,0,0,166,1,0,0,167,1,0,0,168,1,0,0,169,1,0,0,170,1,0,0,4,2,0,0,172,1,0,0,88,0,0,0,80,0,0,0,252,255,255,255,192,32,0,0,5,2,0,0,6,2,0,0,7,2,0,0,8,2,0,0,9,2,0,0,180,1,0,0,181,1,0,0,182,1,0,0,183,1,0,0,10,2,0,0,11,2,0,0,172,255,255,255,172,255,255,255,172,255,255,255,172,255,255,255,0,0,0,0,0,0,0,0,172,255,255,255,172,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,172,255,255,255,172,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,172,255,255,255,172,255,255,255,172,255,255,255,172,255,255,255,172,255,255,255,8,0,0,0,172,255,255,255,192,32,0,0,12,2,0,0,13,2,0,0,14,2,0,0,15,2,0,0,16,2,0,0,191,1,0,0,192,1,0,0,193,1,0,0,194,1,0,0,195,1,0,0,196,1,0,0,197,1,0,0,198,1,0,0,199,1,0,0,200,1,0,0,201,1,0,0,202,1,0,0,203,1,0,0,204,1,0,0,205,1,0,0,206,1,0,0,207,1,0,0,208,1,0,0,209,1,0,0,17,2,0,0,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,255,255,255,248,255,255,255,248,255,255,255,248,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,164,255,255,255,164,255,255,255,164,255,255,255,164,255,255,255,164,255,255,255,164,255,255,255,0,0,0,0,164,255,255,255,192,32,0,0,8,0,0,0,19,2,0,0,20,2,0,0,21,2,0,0,22,2,0,0,23,2,0,0,24,2,0,0,25,2,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,219,1,0,0,220,1,0,0,221,1,0,0,222,1,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,92,0,0,0,84,0,0,0,0,0,0,0,120,90,0,0,26,2,0,0,27,2,0,0,28,2,0,0,29,2,0,0,30,2,0,0,31,2,0,0,32,2,0,0,33,2,0,0,34,2,0,0,35,2,0,0,36,2,0,0,172,255,255,255,172,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,172,255,255,255,172,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,172,255,255,255,172,255,255,255,172,255,255,255,172,255,255,255,172,255,255,255,8,0,0,0,172,255,255,255,120,90,0,0,37,2,0,0,38,2,0,0,39,2,0,0,40,2,0,0,41,2,0,0,191,1,0,0,192,1,0,0,193,1,0,0,194,1,0,0,42,2,0,0,43,2,0,0,197,1,0,0,198,1,0,0,199,1,0,0,200,1,0,0,201,1,0,0,202,1,0,0,230,1,0,0,231,1,0,0,205,1,0,0,206,1,0,0,232,1,0,0,233,1,0,0,44,2,0,0,45,2,0,0,46,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,255,255,255,248,255,255,255,248,255,255,255,248,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,164,255,255,255,164,255,255,255,164,255,255,255,164,255,255,255,164,255,255,255,164,255,255,255,0,0,0,0,164,255,255,255,120,90,0,0,8,0,0,0,47,2,0,0,48,2,0,0,49,2,0,0,50,2,0,0,51,2,0,0,52,2,0,0,53,2,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,219,1,0,0,220,1,0,0,221,1,0,0,222,1,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,88,0,0,0,80,0,0,0,0,0,0,0,216,90,0,0,54,2,0,0,55,2,0,0,56,2,0,0,57,2,0,0,58,2,0,0,59,2,0,0,60,2,0,0,61,2,0,0,62,2,0,0,63,2,0,0,64,2,0,0,176,255,255,255,176,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,255,255,255,176,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,255,255,255,176,255,255,255,176,255,255,255,176,255,255,255,176,255,255,255,8,0,0,0,176,255,255,255,216,90,0,0,65,2,0,0,66,2,0,0,67,2,0,0,68,2,0,0,69,2,0,0,191,1,0,0,192,1,0,0,193,1,0,0,194,1,0,0,228,1,0,0,229,1,0,0,197,1,0,0,198,1,0,0,199,1,0,0,200,1,0,0,201,1,0,0,202,1,0,0,70,2,0,0,71,2,0,0,205,1,0,0,206,1,0,0,232,1,0,0,233,1,0,0,72,2,0,0,73,2,0,0,74,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,255,255,255,248,255,255,255,248,255,255,255,248,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,255,255,255,168,255,255,255,168,255,255,255,168,255,255,255,168,255,255,255,168,255,255,255,0,0,0,0,168,255,255,255,216,90,0,0,8,0,0,0,75,2,0,0,76,2,0,0,77,2,0,0,78,2,0,0,79,2,0,0,80,2,0,0,81,2,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,219,1,0,0,220,1,0,0,221,1,0,0,222,1,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,240,21,0,0,223,1,0,0,224,1,0,0,225,1,0,0,226,1,0,0,227,1,0,0,191,1,0,0,192,1,0,0,193,1,0,0,194,1,0,0,228,1,0,0,229,1,0,0,197,1,0,0,198,1,0,0,199,1,0,0,200,1,0,0,201,1,0,0,202,1,0,0,230,1,0,0,231,1,0,0,205,1,0,0,206,1,0,0,232,1,0,0,233,1,0,0,234,1,0,0,235,1,0,0,236,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,255,255,255,248,255,255,255,248,255,255,255,248,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,255,255,255,248,255,255,255,248,255,255,255,248,255,255,255,248,255,255,255,248,255,255,255,0,0,0,0,248,255,255,255,240,21,0,0,8,0,0,0,237,1,0,0,238,1,0,0,239,1,0,0,240,1,0,0,241,1,0,0,242,1,0,0,243,1,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,219,1,0,0,220,1,0,0,221,1,0,0,222,1,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,0,0,0,0,100,133,1,0,41,123,2,0,112,101,0,0,0,0,0,0,100,133,1,0,186,123,2,0,120,103,0,0,0,0,0,0,100,133,1,0,224,123,2,0,184,118,0,0,0,0,0,0,64,134,1,0,121,126,2,0,0,0,0,0,2,0,0,0,120,103,0,0,2,0,0,0,80,106,0,0,2,12,0,0,148,0,0,0,0,0,0,0,128,79,0,0,208,3,0,0,209,3,0,0,116,0,0,0,117,0,0,0,118,0,0,0,235,2,0,0,236,2,0,0,121,0,0,0,122,0,0,0,123,0,0,0,124,0,0,0,125,0,0,0,126,0,0,0,127,0,0,0,128,0,0,0,129,0,0,0,130,0,0,0,131,0,0,0,132,0,0,0,133,0,0,0,134,0,0,0,135,0,0,0,136,0,0,0,137,0,0,0,138,0,0,0,210,3,0,0,140,0,0,0,211,3,0,0,142,0,0,0,143,0,0,0,144,0,0,0,145,0,0,0,146,0,0,0,223,2,0,0,148,0,0,0,149,0,0,0,150,0,0,0,151,0,0,0,152,0,0,0,153,0,0,0,154,0,0,0,155,0,0,0,156,0,0,0,157,0,0,0,158,0,0,0,159,0,0,0,160,0,0,0,161,0,0,0,162,0,0,0,163,0,0,0,212,3,0,0,213,3], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+20480);
/* memory initializer */ allocate([108,255,255,255,108,255,255,255,0,0,0,0,0,0,0,0,108,255,255,255,108,255,255,255,108,255,255,255,108,255,255,255,108,255,255,255,108,255,255,255,0,0,0,0,108,255,255,255,128,79,0,0,8,0,0,0,214,3,0,0,215,3,0,0,166,0,0,0,167,0,0,0,168,0,0,0,240,2,0,0,241,2,0,0,16,0,0,0,17,0,0,0,171,0,0,0,172,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,148,0,0,0,0,0,0,0,112,101,0,0,233,2,0,0,234,2,0,0,116,0,0,0,117,0,0,0,118,0,0,0,235,2,0,0,236,2,0,0,121,0,0,0,122,0,0,0,123,0,0,0,124,0,0,0,125,0,0,0,126,0,0,0,127,0,0,0,128,0,0,0,129,0,0,0,130,0,0,0,131,0,0,0,132,0,0,0,133,0,0,0,134,0,0,0,135,0,0,0,136,0,0,0,137,0,0,0,138,0,0,0,139,0,0,0,140,0,0,0,237,2,0,0,142,0,0,0,143,0,0,0,144,0,0,0,145,0,0,0,146,0,0,0,223,2,0,0,148,0,0,0,149,0,0,0,150,0,0,0,151,0,0,0,152,0,0,0,153,0,0,0,154,0,0,0,155,0,0,0,156,0,0,0,157,0,0,0,158,0,0,0,159,0,0,0,160,0,0,0,161,0,0,0,162,0,0,0,163,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,108,255,255,255,108,255,255,255,0,0,0,0,0,0,0,0,108,255,255,255,108,255,255,255,108,255,255,255,108,255,255,255,108,255,255,255,108,255,255,255,0,0,0,0,108,255,255,255,112,101,0,0,8,0,0,0,238,2,0,0,239,2,0,0,166,0,0,0,167,0,0,0,168,0,0,0,240,2,0,0,241,2,0,0,16,0,0,0,17,0,0,0,171,0,0,0,172,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,100,133,1,0,240,124,2,0,128,79,0,0,0,0,0,0,100,133,1,0,41,125,2,0,0,123,0,0,0,0,0,0,64,134,1,0,104,125,2,0,0,0,0,0,1,0,0,0,120,103,0,0,3,244,255,255,100,133,1,0,177,130,2,0,56,125,0,0,0,0,0,0,100,133,1,0,133,127,2,0,112,101,0,0,0,0,0,0,64,0,0,0,0,0,0,0,112,101,0,0,233,2,0,0,234,2,0,0,116,0,0,0,117,0,0,0,118,0,0,0,235,2,0,0,236,2,0,0,121,0,0,0,122,0,0,0,123,0,0,0,124,0,0,0,125,0,0,0,126,0,0,0,127,0,0,0,128,0,0,0,129,0,0,0,130,0,0,0,131,0,0,0,132,0,0,0,133,0,0,0,134,0,0,0,135,0,0,0,136,0,0,0,137,0,0,0,138,0,0,0,139,0,0,0,140,0,0,0,237,2,0,0,142,0,0,0,143,0,0,0,144,0,0,0,145,0,0,0,146,0,0,0,223,2,0,0,148,0,0,0,149,0,0,0,150,0,0,0,151,0,0,0,152,0,0,0,153,0,0,0,154,0,0,0,155,0,0,0,156,0,0,0,157,0,0,0,158,0,0,0,159,0,0,0,160,0,0,0,161,0,0,0,162,0,0,0,163,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,192,255,255,255,0,0,0,0,0,0,0,0,192,255,255,255,192,255,255,255,192,255,255,255,192,255,255,255,192,255,255,255,192,255,255,255,0,0,0,0,192,255,255,255,112,101,0,0,8,0,0,0,238,2,0,0,239,2,0,0,166,0,0,0,167,0,0,0,168,0,0,0,240,2,0,0,241,2,0,0,16,0,0,0,17,0,0,0,171,0,0,0,172,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,100,133,1,0,136,130,2,0,120,103,0,0,0,0,0,0,100,133,1,0,201,130,2,0,120,103,0,0,0,0,0,0,100,133,1,0,134,135,2,0,88,127,0,0,0,0,0,0,100,133,1,0,86,135,2,0,112,101,0,0,0,0,0,0,68,0,0,0,0,0,0,0,112,101,0,0,233,2,0,0,234,2,0,0,116,0,0,0,117,0,0,0,118,0,0,0,235,2,0,0,236,2,0,0,121,0,0,0,122,0,0,0,123,0,0,0,124,0,0,0,125,0,0,0,126,0,0,0,127,0,0,0,128,0,0,0,129,0,0,0,130,0,0,0,131,0,0,0,132,0,0,0,133,0,0,0,134,0,0,0,135,0,0,0,136,0,0,0,137,0,0,0,138,0,0,0,139,0,0,0,140,0,0,0,237,2,0,0,142,0,0,0,143,0,0,0,144,0,0,0,145,0,0,0,146,0,0,0,223,2,0,0,148,0,0,0,149,0,0,0,150,0,0,0,151,0,0,0,152,0,0,0,153,0,0,0,154,0,0,0,155,0,0,0,156,0,0,0,157,0,0,0,158,0,0,0,159,0,0,0,160,0,0,0,161,0,0,0,162,0,0,0,163,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,188,255,255,255,188,255,255,255,0,0,0,0,0,0,0,0,188,255,255,255,188,255,255,255,188,255,255,255,188,255,255,255,188,255,255,255,188,255,255,255,0,0,0,0,188,255,255,255,112,101,0,0,8,0,0,0,238,2,0,0,239,2,0,0,166,0,0,0,167,0,0,0,168,0,0,0,240,2,0,0,241,2,0,0,16,0,0,0,17,0,0,0,171,0,0,0,172,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,100,133,1,0,157,135,2,0,120,103,0,0,0,0,0,0,64,134,1,0,49,136,2,0,0,0,0,0,2,0,0,0,120,103,0,0,2,0,0,0,80,106,0,0,2,12,0,0,100,133,1,0,244,136,2,0,168,127,0,0,0,0,0,0,100,133,1,0,209,136,2,0,120,103,0,0,0,0,0,0,100,133,1,0,9,137,2,0,120,103,0,0,0,0,0,0,100,133,1,0,50,137,2,0,120,103,0,0,0,0,0,0,100,133,1,0,85,137,2,0,184,127,0,0,0,0,0,0,100,133,1,0,173,137,2,0,120,103,0,0,0,0,0,0,100,133,1,0,240,138,2,0,0,102,0,0,0,0,0,0,100,133,1,0,190,139,2,0,120,103,0,0,0,0,0,0,100,133,1,0,241,141,2,0,120,103,0,0,0,0,0,0,100,133,1,0,209,143,2,0,40,128,0,0,0,0,0,0,60,133,1,0,247,143,2,0,100,133,1,0,22,144,2,0,40,128,0,0,0,0,0,0,100,133,1,0,108,144,2,0,40,128,0,0,0,0,0,0,100,133,1,0,191,144,2,0,40,128,0,0,0,0,0,0,100,133,1,0,30,145,2,0,40,128,0,0,0,0,0,0,100,133,1,0,112,145,2,0,40,128,0,0,0,0,0,0,100,133,1,0,217,145,2,0,120,103,0,0,0,0,0,0,100,133,1,0,129,159,2,0,232,127,0,0,0,0,0,0,100,133,1,0,170,159,2,0,120,103,0,0,0,0,0,0,100,133,1,0,26,162,2,0,120,103,0,0,0,0,0,0,100,133,1,0,229,171,2,0,8,99,0,0,0,0,0,0,100,133,1,0,13,172,2,0,40,96,0,0,0,0,0,0,100,133,1,0,153,20,3,0,240,128,0,0,0,0,0,0,60,133,1,0,135,20,3,0,100,133,1,0,195,20,3,0,240,128,0,0,0,0,0,0,60,133,1,0,237,20,3,0,60,133,1,0,30,21,3,0,64,134,1,0,79,21,3,0,0,0,0,0,1,0,0,0,224,128,0,0,3,244,255,255,64,134,1,0,126,21,3,0,0,0,0,0,1,0,0,0,248,128,0,0,3,244,255,255,64,134,1,0,173,21,3,0,0,0,0,0,1,0,0,0,224,128,0,0,3,244,255,255,64,134,1,0,220,21,3,0,0,0,0,0,1,0,0,0,248,128,0,0,3,244,255,255,64,134,1,0,11,22,3,0,3,0,0,0,2,0,0,0,24,129,0,0,2,0,0,0,72,129,0,0,2,8,0,0,12,0,0,0,0,0,0,0,24,129,0,0,29,1,0,0,30,1,0,0,244,255,255,255,244,255,255,255,24,129,0,0,31,1,0,0,32,1,0,0,100,133,1,0,104,22,3,0,136,134,0,0,0,0,0,0,100,133,1,0,134,22,3,0,160,134,0,0,0,0,0,0,100,133,1,0,176,22,3,0,16,129,0,0,0,0,0,0,100,133,1,0,201,22,3,0,8,129,0,0,0,0,0,0,100,133,1,0,8,23,3,0,16,129,0,0,0,0,0,0,100,133,1,0,32,23,3,0,8,129,0,0,0,0,0,0,100,133,1,0,56,23,3,0,48,130,0,0,0,0,0,0,100,133,1,0,76,23,3,0,128,134,0,0,0,0,0,0,100,133,1,0,98,23,3,0,48,130,0,0,0,0,0,0,64,134,1,0,156,23,3,0,0,0,0,0,2,0,0,0,48,130,0,0,2,0,0,0,112,130,0,0,0,0,0,0,64,134,1,0,224,23,3,0,0,0,0,0,1,0,0,0,136,130,0,0,0,0,0,0,60,133,1,0,246,23,3,0,64,134,1,0,15,24,3,0,0,0,0,0,2,0,0,0,48,130,0,0,2,0,0,0,176,130,0,0,0,0,0,0,64,134,1,0,83,24,3,0,0,0,0,0,1,0,0,0,136,130,0,0,0,0,0,0,64,134,1,0,124,24,3,0,0,0,0,0,2,0,0,0,48,130,0,0,2,0,0,0,232,130,0,0,0,0,0,0,64,134,1,0,192,24,3,0,0,0,0,0,1,0,0,0,0,131,0,0,0,0,0,0,60,133,1,0,214,24,3,0,64,134,1,0,239,24,3,0,0,0,0,0,2,0,0,0,48,130,0,0,2,0,0,0,40,131,0,0,0,0,0,0,64,134,1,0,51,25,3,0,0,0,0,0,1,0,0,0,0,131,0,0,0,0,0,0,64,134,1,0,137,26,3,0,0,0,0,0,3,0,0,0,48,130,0,0,2,0,0,0,104,131,0,0,2,0,0,0,112,131,0,0,0,8,0,0,60,133,1,0,240,26,3,0,60,133,1,0,206,26,3,0,64,134,1,0,3,27,3,0,0,0,0,0,3,0,0,0,48,130,0,0,2,0,0,0,104,131,0,0,2,0,0,0,160,131,0,0,0,8,0,0,60,133,1,0,72,27,3,0,64,134,1,0,106,27,3,0,0,0,0,0,2,0,0,0,48,130,0,0,2,0,0,0,200,131,0,0,0,8,0,0,60,133,1,0,175,27,3,0,64,134,1,0,217,27,3,0,0,0,0,0,2,0,0,0,48,130,0,0,2,0,0,0,200,131,0,0,0,8,0,0,64,134,1,0,30,28,3,0,0,0,0,0,2,0,0,0,48,130,0,0,2,0,0,0,16,132,0,0,2,0,0,0,60,133,1,0,58,28,3,0,64,134,1,0,79,28,3,0,0,0,0,0,2,0,0,0,48,130,0,0,2,0,0,0,16,132,0,0,2,0,0,0,64,134,1,0,107,28,3,0,0,0,0,0,2,0,0,0,48,130,0,0,2,0,0,0,16,132,0,0,2,0,0,0,64,134,1,0,135,28,3,0,0,0,0,0,2,0,0,0,48,130,0,0,2,0,0,0,16,132,0,0,2,0,0,0,64,134,1,0,194,28,3,0,0,0,0,0,2,0,0,0,48,130,0,0,2,0,0,0,152,132,0,0,0,0,0,0,60,133,1,0,8,29,3,0,64,134,1,0,44,29,3,0,0,0,0,0,2,0,0,0,48,130,0,0,2,0,0,0,192,132,0,0,0,0,0,0,60,133,1,0,114,29,3,0,64,134,1,0,145,29,3,0,0,0,0,0,2,0,0,0,48,130,0,0,2,0,0,0,232,132,0,0,0,0,0,0,60,133,1,0,215,29,3,0,64,134,1,0,240,29,3,0,0,0,0,0,2,0,0,0,48,130,0,0,2,0,0,0,16,133,0,0,0,0,0,0,60,133,1,0,54,30,3,0,64,134,1,0,79,30,3,0,0,0,0,0,2,0,0,0,48,130,0,0,2,0,0,0,56,133,0,0,2,0,0,0,60,133,1,0,100,30,3,0,64,134,1,0,251,30,3,0,0,0,0,0,2,0,0,0,48,130,0,0,2,0,0,0,56,133,0,0,2,0,0,0,100,133,1,0,124,30,3,0,112,133,0,0,0,0,0,0,64,134,1,0,159,30,3,0,0,0,0,0,2,0,0,0,48,130,0,0,2,0,0,0,144,133,0,0,2,0,0,0,60,133,1,0,194,30,3,0,100,133,1,0,217,30,3,0,112,133,0,0,0,0,0,0,64,134,1,0,16,31,3,0,0,0,0,0,2,0,0,0,48,130,0,0,2,0,0,0,144,133,0,0,2,0,0,0,64,134,1,0,50,31,3,0,0,0,0,0,2,0,0,0,48,130,0,0,2,0,0,0,144,133,0,0,2,0,0,0,64,134,1,0,84,31,3,0,0,0,0,0,2,0,0,0,48,130,0,0,2,0,0,0,144,133,0,0,2,0,0,0,100,133,1,0,119,31,3,0,48,130,0,0,0,0,0,0,64,134,1,0,141,31,3,0,0,0,0,0,2,0,0,0,48,130,0,0,2,0,0,0,56,134,0,0,2,0,0,0,60,133,1,0,159,31,3,0,64,134,1,0,180,31,3,0,0,0,0,0,2,0,0,0,48,130,0,0,2,0,0,0,56,134,0,0,2,0,0,0,100,133,1,0,209,31,3,0,48,130,0,0,0,0,0,0,100,133,1,0,230,31,3,0,48,130,0,0,0,0,0,0,60,133,1,0,2,32,3,0,100,133,1,0,25,33,3,0,152,134,0,0,0,0,0,0,60,133,1,0,48,33,3,0,100,133,1,0,73,33,3,0,16,135,0,0,0,0,0,0,60,133,1,0,244,33,3,0,100,133,1,0,84,34,3,0,200,134,0,0,0,0,0,0,100,133,1,0,1,34,3,0,216,134,0,0,0,0,0,0,60,133,1,0,34,34,3,0,100,133,1,0,47,34,3,0,184,134,0,0,0,0,0,0,100,133,1,0,119,35,3,0,176,134,0,0,0,0,0,0,100,133,1,0,147,35,3,0,176,134,0,0,0,0,0,0,100,133,1,0,163,35,3,0,176,134,0,0,0,0,0,0,100,133,1,0,181,35,3,0,0,135,0,0,0,0,0,0,100,133,1,0,202,35,3,0,0,135,0,0,0,0,0,0,100,133,1,0,219,35,3,0,0,135,0,0,0,0,0,0,100,133,1,0,250,35,3,0,176,134,0,0,0,0,0,0,100,133,1,0,22,36,3,0,176,134,0,0,0,0,0,0,100,133,1,0,73,36,3,0,200,134,0,0,0,0,0,0,100,133,1,0,37,36,3,0,112,135,0,0,0,0,0,0,100,133,1,0,107,36,3,0,184,134,0,0,0,0,0,0,0,0,0,0,16,15,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,0,0,0,0,32,15,0,0,1,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,0,0,0,0,48,15,0,0,8,0,0,0,9,0,0,0,10,0,0,0,11,0,0,0,12,0,0,0,13,0,0,0,14,0,0,0,15,0,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,43,0,0,0,44,0,0,0,45,0,0,0,46,0,0,0,47,0,0,0,48,0,0,0,49,0,0,0,50,0,0,0,51,0,0,0,52,0,0,0,53,0,0,0,54,0,0,0,55,0,0,0,56,0,0,0,57,0,0,0,58,0,0,0,59,0,0,0,60,0,0,0,61,0,0,0,62,0,0,0,63,0,0,0,64,0,0,0,65,0,0,0,66,0,0,0,67,0,0,0,68,0,0,0,69,0,0,0,70,0,0,0,71,0,0,0,124,255,255,255,48,15,0,0,72,0,0,0,73,0,0,0,74,0,0,0,75,0,0,0,76,0,0,0,77,0,0,0,78,0,0,0,79,0,0,0,132,0,0,0,0,0,0,0,88,15,0,0,80,0,0,0,81,0,0,0,82,0,0,0,83,0,0,0,84,0,0,0,85,0,0,0,86,0,0,0,87,0,0,0,88,0,0,0,89,0,0,0,90,0,0,0,91,0,0,0,92,0,0,0,93,0,0,0,94,0,0,0,95,0,0,0,96,0,0,0,97,0,0,0,98,0,0,0,220,255,255,255,88,15,0,0,99,0,0,0,100,0,0,0,101,0,0,0,102,0,0,0,103,0,0,0,104,0,0,0,105,0,0,0,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,124,255,255,255,124,255,255,255,124,255,255,255,124,255,255,255,124,255,255,255,124,255,255,255,0,0,0,0,124,255,255,255,88,15,0,0,8,0,0,0,107,0,0,0,108,0,0,0,109,0,0,0,110,0,0,0,111,0,0,0,112,0,0,0,113,0,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,12,137,0,0,84,19,0,0,8,20,0,0,16,138,0,0,200,138,0,0,116,125,0,0,204,126,0,0,32,140,0,0,68,0,0,0,0,0,0,0,120,15,0,0,114,0,0,0,115,0,0,0,116,0,0,0,117,0,0,0,118,0,0,0,119,0,0,0,120,0,0,0,121,0,0,0,122,0,0,0,123,0,0,0,124,0,0,0,125,0,0,0,126,0,0,0,127,0,0,0,128,0,0,0,129,0,0,0,130,0,0,0,131,0,0,0,132,0,0,0,133,0,0,0,134,0,0,0,135,0,0,0,136,0,0,0,137,0,0,0,138,0,0,0,139,0,0,0,140,0,0,0,141,0,0,0,142,0,0,0,143,0,0,0,144,0,0,0,145,0,0,0,146,0,0,0,147,0,0,0,148,0,0,0,149,0,0,0,150,0,0,0,151,0,0,0,152,0,0,0,153,0,0,0,154,0,0,0,155,0,0,0,156,0,0,0,157,0,0,0,158,0,0,0,159,0,0,0,160,0,0,0,161,0,0,0,162,0,0,0,163,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,188,255,255,255,188,255,255,255,0,0,0,0,0,0,0,0,188,255,255,255,188,255,255,255,188,255,255,255,188,255,255,255,188,255,255,255,188,255,255,255,0,0,0,0,188,255,255,255,120,15,0,0,8,0,0,0,164,0,0,0,165,0,0,0,166,0,0,0,167,0,0,0,168,0,0,0,169,0,0,0,170,0,0,0,16,0,0,0,17,0,0,0,171,0,0,0,172,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,16,0,0,0,0,0,0,0,152,15,0,0,173,0,0,0,174,0,0,0,175,0,0,0,240,255,255,255,0,0,0,0,240,255,255,255,152,15,0,0,1,0,0,0,176,0,0,0,177,0,0,0,0,0,0,0,80,15,0,0,178,0,0,0,179,0,0,0,74,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,78,0,0,0,79,0,0,0,0,0,0,0,192,15,0,0,1,0,0,0,180,0,0,0,181,0,0,0,182,0,0,0,236,0,0,0,0,0,0,0,0,16,0,0,183,0,0,0,184,0,0,0,185,0,0,0,186,0,0,0,187,0,0,0,188,0,0,0,189,0,0,0,190,0,0,0,191,0,0,0,192,0,0,0,193,0,0,0,194,0,0,0,195,0,0,0,196,0,0,0,197,0,0,0,198,0,0,0,199,0,0,0,200,0,0,0,201,0,0,0,202,0,0,0,203,0,0,0,204,0,0,0,205,0,0,0,206,0,0,0,207,0,0,0,208,0,0,0,209,0,0,0,210,0,0,0,211,0,0,0,212,0,0,0,213,0,0,0,214,0,0,0,215,0,0,0,216,0,0,0,217,0,0,0,218,0,0,0,219,0,0,0,220,0,0,0,221,0,0,0,222,0,0,0,223,0,0,0,224,0,0,0,225,0,0,0,132,0,0,0,152,255,255,255,0,16,0,0,226,0,0,0,227,0,0,0,228,0,0,0,229,0,0,0,230,0,0,0,231,0,0,0,232,0,0,0,233,0,0,0,88,0,0,0,89,0,0,0,234,0,0,0,235,0,0,0,92,0,0,0,93,0,0,0,94,0,0,0,95,0,0,0,96,0,0,0,97,0,0,0,98,0,0,0,116,255,255,255,0,16,0,0,236,0,0,0,237,0,0,0,101,0,0,0,102,0,0,0,103,0,0,0,104,0,0,0,105,0,0,0,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,255,255,255,20,255,255,255,20,255,255,255,20,255,255,255,20,255,255,255,20,255,255,255,0,0,0,0,20,255,255,255,0,16,0,0,8,0,0,0,238,0,0,0,239,0,0,0,240,0,0,0,241,0,0,0,242,0,0,0,243,0,0,0,244,0,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,44,141,0,0,44,16,0,0,68,17,0,0,220,17,0,0,84,19,0,0,8,20,0,0,184,18,0,0,232,142,0,0,228,141,0,0,0,0,0,0,152,20,0,0,8,0,0,0,9,0,0,0,11,1,0,0,11,0,0,0,12,0,0,0,12,1,0,0,13,1,0,0,14,1,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,43,0,0,0,15,1,0,0,45,0,0,0,16,1,0,0,17,1,0,0,18,1,0,0,19,1,0,0,50,0,0,0,20,1,0,0,52,0,0,0,21,1,0,0,54,0,0,0,55,0,0,0,56,0,0,0,57,0,0,0,58,0,0,0,59,0,0,0,22,1,0,0,23,1,0,0,24,1,0,0,63,0,0,0,64,0,0,0,65,0,0,0,66,0,0,0,67,0,0,0,68,0,0,0,69,0,0,0,70,0,0,0,71,0,0,0,124,255,255,255,152,20,0,0,25,1,0,0,26,1,0,0,74,0,0,0,75,0,0,0,76,0,0,0,77,0,0,0,78,0,0,0,79,0,0,0,0,0,0,0,168,20,0,0,1,0,0,0,27,1,0,0,28,1,0,0,60,0,0,0,0,0,0,0,240,20,0,0,33,1,0,0,34,1,0,0,196,255,255,255,196,255,255,255,240,20,0,0,35,1,0,0,36,1,0,0,0,0,0,0,224,20,0,0,37,1,0,0,38,1,0,0,39,1,0,0,40,1,0,0,41,1,0,0,42,1,0,0,43,1,0,0,44,1,0,0,45,1,0,0,46,1,0,0,47,1,0,0,48,1,0,0,49,1,0,0,50,1,0,0,232,144,0,0,196,20,0,0,216,20,0,0,252,144,0,0,0,0,0,0,0,21,0,0,8,0,0,0,51,1,0,0,52,1,0,0,53,1,0,0,54,1,0,0,55,1,0,0,56,1,0,0,57,1,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,100,0,0,0,0,0,0,0,16,21,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,189,0,0,0,190,0,0,0,191,0,0,0,192,0,0,0,193,0,0,0,194,0,0,0,195,0,0,0,245,0,0,0,7,0,0,0,7,0,0,0,199,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,203,0,0,0,7,0,0,0,7,0,0,0,206,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,246,0,0,0,247,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,156,255,255,255,0,0,0,0,156,255,255,255,16,21,0,0,8,0,0,0,248,0,0,0,249,0,0,0,7,0,0,0,7,0,0,0,250,0,0,0,7,0,0,0,7,0,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,244,145,0,0,12,147,0,0,0,0,0,0,120,21,0,0,8,0,0,0,58,1,0,0,59,1,0,0,60,1,0,0,61,1,0,0,62,1,0,0,63,1,0,0,64,1,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,65,1,0,0,66,1,0,0,67,1,0,0,68,1,0,0,69,1,0,0,70,1,0,0,71,1,0,0,72,1,0,0,73,1,0,0,74,1,0,0,75,1,0,0,76,1,0,0,77,1,0,0,78,1,0,0,79,1,0,0,80,1,0,0,81,1,0,0,82,1,0,0,83,1,0,0,84,1,0,0,85,1,0,0,184,255,255,255,120,21,0,0,86,1,0,0,87,1,0,0,0,0,0,0,80,21,0,0,8,0,0,0,88,1,0,0,89,1,0,0,90,1,0,0,91,1,0,0,62,1,0,0,63,1,0,0,64,1,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,65,1,0,0,66,1,0,0,92,1,0,0,93,1,0,0,69,1,0,0,70,1,0,0,71,1,0,0,72,1,0,0,73,1,0,0,74,1,0,0,94,1,0,0,95,1,0,0,96,1,0,0,97,1,0,0,98,1,0,0,99,1,0,0,100,1,0,0,101,1,0,0,102,1,0,0,103,1,0,0,104,1,0,0,184,255,255,255,80,21,0,0,105,1,0,0,106,1,0,0,0,0,0,0,40,21,0,0,8,0,0,0,107,1,0,0,108,1,0,0,109,1,0,0,110,1,0,0,62,1,0,0,63,1,0,0,64,1,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,65,1,0,0,66,1,0,0,111,1,0,0,112,1,0,0,69,1,0,0,70,1,0,0,71,1,0,0,72,1,0,0,73,1,0,0,74,1,0,0,113,1,0,0,114,1,0,0,115,1,0,0,116,1,0,0,117,1,0,0,118,1,0,0,119,1,0,0,120,1,0,0,121,1,0,0,122,1,0,0,123,1,0,0,184,255,255,255,40,21,0,0,124,1,0,0,125,1,0,0,0,0,0,0,72,21,0,0,126,1,0,0,127,1,0,0,0,0,0,0,112,21,0,0,128,1,0,0,129,1,0,0,0,0,0,0,152,21,0,0,130,1,0,0,131,1,0,0,0,0,0,0,160,21,0,0,8,0,0,0,132,1,0,0,133,1,0,0,134,1,0,0,135,1,0,0,136,1,0,0,137,1,0,0,138,1,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,139,1,0,0,140,1,0,0,0,0,0,0,176,21,0,0,8,0,0,0,132,1,0,0,141,1,0,0,142,1,0,0,143,1,0,0,144,1,0,0,145,1,0,0,146,1,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,147,1,0,0,140,1,0,0,0,0,0,0,192,21,0,0,8,0,0,0,132,1,0,0,148,1,0,0,149,1,0,0,150,1,0,0,151,1,0,0,152,1,0,0,153,1,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,154,1,0,0,140,1,0,0,116,0,0,0,108,0,0,0,0,0,0,0,224,21,0,0,155,1,0,0,156,1,0,0,157,1,0,0,158,1,0,0,159,1,0,0,160,1,0,0,161,1,0,0,162,1,0,0,163,1,0,0,164,1,0,0,165,1,0,0,166,1,0,0,167,1,0,0,168,1,0,0,169,1,0,0,170,1,0,0,171,1,0,0,172,1,0,0,173,1,0,0,174,1,0,0,112,0,0,0,104,0,0,0,252,255,255,255,224,21,0,0,175,1,0,0,176,1,0,0,177,1,0,0,178,1,0,0,179,1,0,0,180,1,0,0,181,1,0,0,182,1,0,0,183,1,0,0,184,1,0,0,185,1,0,0,148,255,255,255,148,255,255,255,148,255,255,255,148,255,255,255,0,0,0,0,0,0,0,0,148,255,255,255,148,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,148,255,255,255,148,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,148,255,255,255,148,255,255,255,148,255,255,255,148,255,255,255,148,255,255,255,8,0,0,0,148,255,255,255,224,21,0,0,186,1,0,0,187,1,0,0,188,1,0,0,189,1,0,0,190,1,0,0,191,1,0,0,192,1,0,0,193,1,0,0,194,1,0,0,195,1,0,0,196,1,0,0,197,1,0,0,198,1,0,0,199,1,0,0,200,1,0,0,201,1,0,0,202,1,0,0,203,1,0,0,204,1,0,0,205,1,0,0,206,1,0,0,207,1,0,0,208,1,0,0,209,1,0,0,210,1,0,0,211,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,255,255,255,248,255,255,255,248,255,255,255,248,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,140,255,255,255,140,255,255,255,140,255,255,255,140,255,255,255,140,255,255,255,140,255,255,255,0,0,0,0,140,255,255,255,224,21,0,0,8,0,0,0,212,1,0,0,213,1,0,0,214,1,0,0,215,1,0,0,216,1,0,0,217,1,0,0,218,1,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,219,1,0,0,220,1,0,0,221,1,0,0,222,1,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,132,152,0,0,24,22,0,0,168,24,0,0,48,27,0,0,204,27,0,0,196,28,0,0,96,29,0,0,252,29,0,0,244,30,0,0,156,25,0,0,148,26,0,0,0,25,0,0,20,23,0,0,12,24,0,0,120,22,0,0,128,153,0,0,120,154,0,0,228,152,0,0,32,117,0,0,24,118,0,0,8,0,0,0,0,0,0,0,240,21,0,0,223,1,0,0,224,1,0,0,225,1,0,0,226,1,0,0,227,1,0,0,191,1,0,0,192,1,0,0,193,1,0,0,194,1,0,0,228,1,0,0,229,1,0,0,197,1,0,0,198,1,0,0,199,1,0,0,200,1,0,0,201,1,0,0,202,1,0,0,230,1,0,0,231,1,0,0,205,1,0,0,206,1,0,0,232,1,0,0,233,1,0,0,234,1,0,0,235,1,0,0,236,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,255,255,255,248,255,255,255,248,255,255,255,248,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,255,255,255,248,255,255,255,248,255,255,255,248,255,255,255,248,255,255,255,248,255,255,255,0,0,0,0,248,255,255,255,240,21,0,0,8,0,0,0,237,1,0,0,238,1,0,0,239,1,0,0,240,1,0,0,241,1,0,0,242,1,0,0,243,1,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,219,1,0,0,220,1,0,0,221,1,0,0,222,1,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,0,0,0,0,240,15,0,0,8,0,0,0,132,1,0,0,82,2,0,0,83,2,0,0,84,2,0,0,85,2,0,0,86,2,0,0,87,2,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,16,0,0,0,8,0,0,0,0,0,0,0,128,31,0,0,88,2,0,0,89,2,0,0,90,2,0,0,91,2,0,0,92,2,0,0,93,2,0,0,94,2,0,0,95,2,0,0,96,2,0,0,97,2,0,0,98,2,0,0,248,255,255,255,248,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,255,255,255,248,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,255,255,255,248,255,255,255,248,255,255,255,248,255,255,255,248,255,255,255,8,0,0,0,248,255,255,255,128,31,0,0,99,2,0,0,100,2,0,0,101,2,0,0,102,2,0,0,103,2,0,0,191,1,0,0,192,1,0,0,193,1,0,0,194,1,0,0,228,1,0,0,229,1,0,0,197,1,0,0,198,1,0,0,199,1,0,0,200,1,0,0,104,2,0,0,105,2,0,0,230,1,0,0,231,1,0,0,205,1,0,0,206,1,0,0,232,1,0,0,233,1,0,0,106,2,0,0,107,2,0,0,108,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,255,255,255,248,255,255,255,248,255,255,255,248,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,255,255,255,240,255,255,255,240,255,255,255,240,255,255,255,240,255,255,255,240,255,255,255,0,0,0,0,240,255,255,255,128,31,0,0,8,0,0,0,109,2,0,0,110,2,0,0,111,2,0,0,112,2,0,0,113,2,0,0,114,2,0,0,115,2,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,219,1,0,0,220,1,0,0,221,1,0,0,222,1,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,16,0,0,0,8,0,0,0,0,0,0,0,144,31,0,0,116,2,0,0,117,2,0,0,118,2,0,0,119,2,0,0,120,2,0,0,121,2,0,0,122,2,0,0,123,2,0,0,124,2,0,0,125,2,0,0,126,2,0,0,248,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,248,255,255,255,248,255,255,255], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+30760);
/* memory initializer */ allocate([248,255,255,255,248,255,255,255,248,255,255,255,248,255,255,255,248,255,255,255,8,0,0,0,248,255,255,255,144,31,0,0,127,2,0,0,128,2,0,0,129,2,0,0,130,2,0,0,131,2,0,0,191,1,0,0,192,1,0,0,193,1,0,0,194,1,0,0,228,1,0,0,229,1,0,0,197,1,0,0,198,1,0,0,199,1,0,0,200,1,0,0,201,1,0,0,202,1,0,0,230,1,0,0,231,1,0,0,132,2,0,0,133,2,0,0,232,1,0,0,233,1,0,0,234,1,0,0,134,2,0,0,135,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,255,255,255,248,255,255,255,248,255,255,255,248,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,255,255,255,240,255,255,255,240,255,255,255,240,255,255,255,240,255,255,255,240,255,255,255,0,0,0,0,240,255,255,255,144,31,0,0,8,0,0,0,136,2,0,0,137,2,0,0,138,2,0,0,139,2,0,0,140,2,0,0,141,2,0,0,142,2,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,219,1,0,0,220,1,0,0,221,1,0,0,222,1,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,0,0,0,0,176,31,0,0,8,0,0,0,132,1,0,0,143,2,0,0,144,2,0,0,145,2,0,0,146,2,0,0,147,2,0,0,148,2,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,149,2,0,0,150,2,0,0,0,0,0,0,160,31,0,0,8,0,0,0,151,2,0,0,152,2,0,0,153,2,0,0,154,2,0,0,155,2,0,0,156,2,0,0,157,2,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,158,2,0,0,159,2,0,0,0,0,0,0,208,31,0,0,1,0,0,0,160,2,0,0,161,2,0,0,162,2,0,0,163,2,0,0,164,2,0,0,165,2,0,0,128,0,0,0,0,0,0,0,224,31,0,0,166,2,0,0,167,2,0,0,168,2,0,0,169,2,0,0,170,2,0,0,171,2,0,0,172,2,0,0,173,2,0,0,174,2,0,0,175,2,0,0,176,2,0,0,128,255,255,255,0,0,0,0,128,255,255,255,224,31,0,0,1,0,0,0,177,2,0,0,178,2,0,0,64,163,0,0,252,31,0,0,60,32,0,0,92,32,0,0,32,32,0,0,124,163,0,0,0,0,0,0,128,32,0,0,1,0,0,0,189,2,0,0,190,2,0,0,191,2,0,0,192,2,0,0,193,2,0,0,194,2,0,0,0,0,0,0,144,32,0,0,195,2,0,0,196,2,0,0,197,2,0,0,198,2,0,0,199,2,0,0,0,0,0,0,160,32,0,0,1,0,0,0,200,2,0,0,201,2,0,0,0,0,0,0,176,32,0,0,1,0,0,0,202,2,0,0,203,2,0,0,204,2,0,0,205,2,0,0,206,2,0,0,207,2,0,0,32,0,0,0,64,35,0,0,220,35,0,0,212,36,0,0,32,8,0,0,188,8,0,0,180,9,0,0,20,1,0,0,12,2,0,0,120,0,0,0,32,117,0,0,24,118,0,0,0,0,0,0,224,32,0,0,1,0,0,0,208,2,0,0,209,2,0,0,80,0,0,0,0,0,0,0,240,32,0,0,210,2,0,0,211,2,0,0,116,0,0,0,117,0,0,0,118,0,0,0,212,2,0,0,213,2,0,0,121,0,0,0,122,0,0,0,123,0,0,0,124,0,0,0,125,0,0,0,126,0,0,0,214,2,0,0,215,2,0,0,129,0,0,0,130,0,0,0,131,0,0,0,132,0,0,0,216,2,0,0,134,0,0,0,135,0,0,0,136,0,0,0,137,0,0,0,138,0,0,0,217,2,0,0,140,0,0,0,218,2,0,0,219,2,0,0,220,2,0,0,221,2,0,0,145,0,0,0,222,2,0,0,223,2,0,0,148,0,0,0,149,0,0,0,224,2,0,0,225,2,0,0,152,0,0,0,153,0,0,0,154,0,0,0,155,0,0,0,156,0,0,0,226,2,0,0,158,0,0,0,227,2,0,0,160,0,0,0,161,0,0,0,228,2,0,0,163,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,255,255,255,176,255,255,255,0,0,0,0,0,0,0,0,176,255,255,255,176,255,255,255,176,255,255,255,176,255,255,255,176,255,255,255,176,255,255,255,0,0,0,0,176,255,255,255,240,32,0,0,8,0,0,0,229,2,0,0,230,2,0,0,166,0,0,0,167,0,0,0,168,0,0,0,231,2,0,0,232,2,0,0,16,0,0,0,17,0,0,0,171,0,0,0,172,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,104,164,0,0,12,33,0,0,100,34,0,0,192,165,0,0,0,0,0,0,240,34,0,0,8,0,0,0,242,2,0,0,243,2,0,0,244,2,0,0,245,2,0,0,246,2,0,0,247,2,0,0,248,2,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,249,2,0,0,250,2,0,0,251,2,0,0,252,2,0,0,16,0,0,0,8,0,0,0,0,0,0,0,32,35,0,0,155,1,0,0,156,1,0,0,157,1,0,0,158,1,0,0,159,1,0,0,160,1,0,0,161,1,0,0,162,1,0,0,163,1,0,0,244,1,0,0,245,1,0,0,166,1,0,0,167,1,0,0,168,1,0,0,169,1,0,0,170,1,0,0,171,1,0,0,172,1,0,0,246,1,0,0,174,1,0,0,12,0,0,0,4,0,0,0,252,255,255,255,32,35,0,0,175,1,0,0,176,1,0,0,177,1,0,0,178,1,0,0,179,1,0,0,180,1,0,0,181,1,0,0,182,1,0,0,183,1,0,0,247,1,0,0,248,1,0,0,248,255,255,255,248,255,255,255,248,255,255,255,248,255,255,255,0,0,0,0,0,0,0,0,248,255,255,255,248,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,255,255,255,248,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,255,255,255,248,255,255,255,248,255,255,255,248,255,255,255,248,255,255,255,8,0,0,0,248,255,255,255,32,35,0,0,186,1,0,0,187,1,0,0,188,1,0,0,189,1,0,0,190,1,0,0,191,1,0,0,192,1,0,0,193,1,0,0,194,1,0,0,195,1,0,0,196,1,0,0,197,1,0,0,198,1,0,0,199,1,0,0,200,1,0,0,201,1,0,0,202,1,0,0,203,1,0,0,204,1,0,0,205,1,0,0,206,1,0,0,207,1,0,0,208,1,0,0,209,1,0,0,249,1,0,0,250,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,255,255,255,248,255,255,255,248,255,255,255,248,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,255,255,255,240,255,255,255,240,255,255,255,240,255,255,255,240,255,255,255,240,255,255,255,0,0,0,0,240,255,255,255,32,35,0,0,8,0,0,0,251,1,0,0,252,1,0,0,214,1,0,0,215,1,0,0,216,1,0,0,217,1,0,0,218,1,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,219,1,0,0,220,1,0,0,221,1,0,0,222,1,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,16,167,0,0,32,0,0,0,64,35,0,0,220,35,0,0,212,36,0,0,32,8,0,0,188,8,0,0,180,9,0,0,20,1,0,0,12,2,0,0,120,0,0,0,12,168,0,0,4,169,0,0,112,167,0,0,32,117,0,0,24,118,0,0,96,170,0,0,176,2,0,0,56,47,0,0,136,50,0,0,104,53,0,0,248,55,0,0,128,58,0,0,28,59,0,0,20,60,0,0,176,60,0,0,76,61,0,0,68,62,0,0,236,56,0,0,228,57,0,0,80,56,0,0,100,54,0,0,92,55,0,0,200,53,0,0,208,51,0,0,200,52,0,0,52,51,0,0,244,48,0,0,236,49,0,0,88,48,0,0,152,4,0,0,144,5,0,0,252,3,0,0,72,172,0,0,64,173,0,0,172,171,0,0,32,117,0,0,24,118,0,0,0,1,0,0,248,0,0,0,0,0,0,0,96,37,0,0,253,2,0,0,254,2,0,0,255,2,0,0,0,3,0,0,1,3,0,0,160,1,0,0,161,1,0,0,162,1,0,0,163,1,0,0,2,3,0,0,3,3,0,0,166,1,0,0,167,1,0,0,168,1,0,0,169,1,0,0,170,1,0,0,4,3,0,0,5,3,0,0,246,1,0,0,6,3,0,0,7,3,0,0,8,3,0,0,9,3,0,0,10,3,0,0,11,3,0,0,12,3,0,0,13,3,0,0,14,3,0,0,15,3,0,0,16,3,0,0,17,3,0,0,18,3,0,0,19,3,0,0,20,3,0,0,21,3,0,0,22,3,0,0,23,3,0,0,24,3,0,0,25,3,0,0,26,3,0,0,27,3,0,0,28,3,0,0,29,3,0,0,30,3,0,0,31,3,0,0,32,3,0,0,33,3,0,0,34,3,0,0,35,3,0,0,36,3,0,0,37,3,0,0,38,3,0,0,39,3,0,0,40,3,0,0,41,3,0,0,42,3,0,0,43,3,0,0,44,3,0,0,45,3,0,0,46,3,0,0,47,3,0,0,48,3,0,0,49,3,0,0,50,3,0,0,51,3,0,0,52,3,0,0,53,3,0,0,54,3,0,0,55,3,0,0,56,3,0,0,57,3,0,0,58,3,0,0,59,3,0,0,60,3,0,0,61,3,0,0,62,3,0,0,63,3,0,0,64,3,0,0,65,3,0,0,252,0,0,0,244,0,0,0,252,255,255,255,96,37,0,0,66,3,0,0,67,3,0,0,68,3,0,0,69,3,0,0,70,3,0,0,180,1,0,0,181,1,0,0,182,1,0,0,183,1,0,0,71,3,0,0,72,3,0,0,8,255,255,255,8,255,255,255,8,255,255,255,8,255,255,255,0,0,0,0,0,0,0,0,8,255,255,255,8,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,255,255,255,8,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,255,255,255,8,255,255,255,8,255,255,255,8,255,255,255,8,255,255,255,8,0,0,0,8,255,255,255,96,37,0,0,73,3,0,0,74,3,0,0,75,3,0,0,76,3,0,0,77,3,0,0,191,1,0,0,192,1,0,0,193,1,0,0,194,1,0,0,195,1,0,0,196,1,0,0,197,1,0,0,198,1,0,0,199,1,0,0,200,1,0,0,201,1,0,0,202,1,0,0,203,1,0,0,204,1,0,0,205,1,0,0,206,1,0,0,207,1,0,0,208,1,0,0,209,1,0,0,78,3,0,0,79,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,255,255,255,248,255,255,255,248,255,255,255,248,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,0,255,255,255,0,255,255,255,0,255,255,255,0,255,255,255,0,255,255,255,0,0,0,0,0,255,255,255,96,37,0,0,8,0,0,0,80,3,0,0,81,3,0,0,82,3,0,0,83,3,0,0,84,3,0,0,85,3,0,0,86,3,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,219,1,0,0,220,1,0,0,221,1,0,0,222,1,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,0,0,0,0,112,37,0,0,1,0,0,0,200,2,0,0,87,3,0,0,0,0,0,0,16,35,0,0,8,0,0,0,132,1,0,0,88,3,0,0,89,3,0,0,90,3,0,0,91,3,0,0,92,3,0,0,93,3,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,94,3,0,0,95,3,0,0,100,0,0,0,92,0,0,0,0,0,0,0,144,37,0,0,155,1,0,0,156,1,0,0,157,1,0,0,158,1,0,0,96,3,0,0,160,1,0,0,161,1,0,0,162,1,0,0,163,1,0,0,97,3,0,0,98,3,0,0,166,1,0,0,167,1,0,0,168,1,0,0,169,1,0,0,170,1,0,0,4,3,0,0,172,1,0,0,246,1,0,0,99,3,0,0,7,3,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,12,3,0,0,100,3,0,0,101,3,0,0,102,3,0,0,103,3,0,0,104,3,0,0,18,3,0,0,19,3,0,0,20,3,0,0,21,3,0,0,105,3,0,0,106,3,0,0,107,3,0,0,108,3,0,0,96,0,0,0,88,0,0,0,252,255,255,255,144,37,0,0,175,1,0,0,176,1,0,0,177,1,0,0,178,1,0,0,109,3,0,0,180,1,0,0,181,1,0,0,182,1,0,0,183,1,0,0,110,3,0,0,111,3,0,0,164,255,255,255,164,255,255,255,164,255,255,255,164,255,255,255,0,0,0,0,0,0,0,0,164,255,255,255,164,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,164,255,255,255,164,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,164,255,255,255,164,255,255,255,164,255,255,255,164,255,255,255,164,255,255,255,8,0,0,0,164,255,255,255,144,37,0,0,186,1,0,0,187,1,0,0,188,1,0,0,189,1,0,0,112,3,0,0,191,1,0,0,192,1,0,0,193,1,0,0,194,1,0,0,195,1,0,0,196,1,0,0,197,1,0,0,198,1,0,0,199,1,0,0,200,1,0,0,201,1,0,0,202,1,0,0,203,1,0,0,204,1,0,0,205,1,0,0,206,1,0,0,207,1,0,0,208,1,0,0,209,1,0,0,113,3,0,0,114,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,255,255,255,248,255,255,255,248,255,255,255,248,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,156,255,255,255,156,255,255,255,156,255,255,255,156,255,255,255,156,255,255,255,156,255,255,255,0,0,0,0,156,255,255,255,144,37,0,0,8,0,0,0,115,3,0,0,116,3,0,0,214,1,0,0,215,1,0,0,216,1,0,0,217,1,0,0,117,3,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,219,1,0,0,220,1,0,0,221,1,0,0,222,1,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,140,174,0,0,176,37,0,0,64,40,0,0,200,42,0,0,100,43,0,0,92,44,0,0,248,44,0,0,148,45,0,0,140,46,0,0,52,41,0,0,44,42,0,0,152,40,0,0,172,38,0,0,164,39,0,0,16,38,0,0,212,175,0,0,204,176,0,0,56,175,0,0,32,117,0,0,24,118,0,0,176,2,0,0,56,47,0,0,136,50,0,0,104,53,0,0,248,55,0,0,128,58,0,0,28,59,0,0,20,60,0,0,176,60,0,0,76,61,0,0,68,62,0,0,236,56,0,0,228,57,0,0,80,56,0,0,100,54,0,0,92,55,0,0,200,53,0,0,208,51,0,0,200,52,0,0,52,51,0,0,244,48,0,0,236,49,0,0,88,48,0,0,152,4,0,0,144,5,0,0,252,3,0,0,32,117,0,0,24,118,0,0,168,0,0,0,160,0,0,0,0,0,0,0,208,62,0,0,155,1,0,0,156,1,0,0,157,1,0,0,158,1,0,0,146,3,0,0,160,1,0,0,161,1,0,0,162,1,0,0,163,1,0,0,147,3,0,0,148,3,0,0,166,1,0,0,167,1,0,0,168,1,0,0,169,1,0,0,170,1,0,0,4,3,0,0,5,3,0,0,246,1,0,0,6,3,0,0,7,3,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,12,3,0,0,100,3,0,0,101,3,0,0,15,3,0,0,16,3,0,0,17,3,0,0,18,3,0,0,19,3,0,0,20,3,0,0,21,3,0,0,22,3,0,0,23,3,0,0,24,3,0,0,25,3,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,30,3,0,0,31,3,0,0,32,3,0,0,33,3,0,0,34,3,0,0,35,3,0,0,36,3,0,0,37,3,0,0,38,3,0,0,39,3,0,0,40,3,0,0,149,3,0,0,42,3,0,0,43,3,0,0,150,3,0,0,151,3,0,0,152,3,0,0,153,3,0,0,48,3,0,0,154,3,0,0,50,3,0,0,51,3,0,0,52,3,0,0,155,3,0,0,156,3,0,0,164,0,0,0,156,0,0,0,252,255,255,255,208,62,0,0,175,1,0,0,176,1,0,0,177,1,0,0,178,1,0,0,157,3,0,0,180,1,0,0,181,1,0,0,182,1,0,0,183,1,0,0,158,3,0,0,159,3,0,0,96,255,255,255,96,255,255,255,96,255,255,255,96,255,255,255,0,0,0,0,0,0,0,0,96,255,255,255,96,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,255,255,255,96,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,255,255,255,96,255,255,255,96,255,255,255,96,255,255,255,96,255,255,255,8,0,0,0,96,255,255,255,208,62,0,0,186,1,0,0,187,1,0,0,188,1,0,0,189,1,0,0,160,3,0,0,191,1,0,0,192,1,0,0,193,1,0,0,194,1,0,0,195,1,0,0,196,1,0,0,197,1,0,0,198,1,0,0,199,1,0,0,200,1,0,0,201,1,0,0,202,1,0,0,203,1,0,0,204,1,0,0,205,1,0,0,206,1,0,0,207,1,0,0,208,1,0,0,209,1,0,0,161,3,0,0,162,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,255,255,255,248,255,255,255,248,255,255,255,248,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,255,255,255,88,255,255,255,88,255,255,255,88,255,255,255,88,255,255,255,88,255,255,255,0,0,0,0,88,255,255,255,208,62,0,0,8,0,0,0,163,3,0,0,164,3,0,0,214,1,0,0,215,1,0,0,216,1,0,0,217,1,0,0,165,3,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,219,1,0,0,220,1,0,0,221,1,0,0,222,1,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,40,178,0,0,240,62,0,0,208,65,0,0,96,68,0,0,232,70,0,0,132,71,0,0,124,72,0,0,24,73,0,0,180,73,0,0,172,74,0,0,84,69,0,0,76,70,0,0,184,68,0,0,204,66,0,0,196,67,0,0,48,66,0,0,56,64,0,0,48,65,0,0,156,63,0,0,228,179,0,0,220,180,0,0,72,179,0,0,32,117,0,0,24,118,0,0,0,0,0,0,128,37,0,0,1,0,0,0,200,2,0,0,166,3,0,0,124,0,0,0,0,0,0,0,56,75,0,0,167,3,0,0,168,3,0,0,116,0,0,0,117,0,0,0,118,0,0,0,169,3,0,0,170,3,0,0,121,0,0,0,122,0,0,0,123,0,0,0,124,0,0,0,125,0,0,0,126,0,0,0,127,0,0,0,128,0,0,0,129,0,0,0,130,0,0,0,131,0,0,0,132,0,0,0,171,3,0,0,134,0,0,0,135,0,0,0,136,0,0,0,137,0,0,0,138,0,0,0,172,3,0,0,140,0,0,0,173,3,0,0,142,0,0,0,143,0,0,0,144,0,0,0,145,0,0,0,146,0,0,0,223,2,0,0,148,0,0,0,149,0,0,0,150,0,0,0,151,0,0,0,152,0,0,0,153,0,0,0,154,0,0,0,155,0,0,0,156,0,0,0,157,0,0,0,158,0,0,0,159,0,0,0,160,0,0,0,161,0,0,0,162,0,0,0,163,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,132,255,255,255,132,255,255,255,0,0,0,0,0,0,0,0,132,255,255,255,132,255,255,255,132,255,255,255,132,255,255,255,132,255,255,255,132,255,255,255,0,0,0,0,132,255,255,255,56,75,0,0,8,0,0,0,174,3,0,0,175,3,0,0,166,0,0,0,167,0,0,0,168,0,0,0,176,3,0,0,177,3,0,0,16,0,0,0,17,0,0,0,171,0,0,0,172,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,232,181,0,0,84,75,0,0,172,76,0,0,64,183,0,0,160,0,0,0,0,0,0,0,88,77,0,0,178,3,0,0,179,3,0,0,116,0,0,0,117,0,0,0,118,0,0,0,180,3,0,0,181,3,0,0,121,0,0,0,122,0,0,0,123,0,0,0,124,0,0,0,125,0,0,0,126,0,0,0,127,0,0,0,128,0,0,0,182,3,0,0,183,3,0,0,131,0,0,0,132,0,0,0,184,3,0,0,185,3,0,0,135,0,0,0,186,3,0,0,137,0,0,0,138,0,0,0,187,3,0,0,140,0,0,0,188,3,0,0,189,3,0,0,190,3,0,0,191,3,0,0,145,0,0,0,192,3,0,0,223,2,0,0,148,0,0,0,149,0,0,0,150,0,0,0,193,3,0,0,194,3,0,0,153,0,0,0,154,0,0,0,155,0,0,0,156,0,0,0,157,0,0,0,158,0,0,0,195,3,0,0,196,3,0,0,161,0,0,0,162,0,0,0,163,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,255,255,255,96,255,255,255,0,0,0,0,0,0,0,0,96,255,255,255,96,255,255,255,96,255,255,255,96,255,255,255,96,255,255,255,96,255,255,255,0,0,0,0,96,255,255,255,88,77,0,0,8,0,0,0,197,3,0,0,198,3,0,0,166,0,0,0,167,0,0,0,168,0,0,0,199,3,0,0,200,3,0,0,16,0,0,0,17,0,0,0,171,0,0,0,172,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,232,183,0,0,116,77,0,0,204,78,0,0,64,185,0,0,0,0,0,0,88,79,0,0,8,0,0,0,201,3,0,0,202,3,0,0,203,3,0,0,204,3,0,0,205,3,0,0,206,3,0,0,207,3,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,132,0,0,0,0,0,0,0,128,79,0,0,208,3,0,0,209,3,0,0,116,0,0,0,117,0,0,0,118,0,0,0,235,2,0,0,236,2,0,0,121,0,0,0,122,0,0,0,123,0,0,0,124,0,0,0,125,0,0,0,126,0,0,0,127,0,0,0,128,0,0,0,129,0,0,0,130,0,0,0,131,0,0,0,132,0,0,0,133,0,0,0,134,0,0,0,135,0,0,0,136,0,0,0,137,0,0,0,138,0,0,0,210,3,0,0,140,0,0,0,211,3,0,0,142,0,0,0,143,0,0,0,144,0,0,0,145,0,0,0,146,0,0,0,223,2,0,0,148,0,0,0,149,0,0,0,150,0,0,0,151,0,0,0,152,0,0,0,153,0,0,0,154,0,0,0,155,0,0,0,156,0,0,0,157,0,0,0,158,0,0,0,159,0,0,0,160,0,0,0,161,0,0,0,162,0,0,0,163,0,0,0,212,3,0,0,213,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,124,255,255,255,124,255,255,255,0,0,0,0,0,0,0,0,124,255,255,255,124,255,255,255,124,255,255,255,124,255,255,255,124,255,255,255,124,255,255,255,0,0,0,0,124,255,255,255,128,79,0,0,8,0,0,0,214,3,0,0,215,3,0,0,166,0,0,0,167,0,0,0,168,0,0,0,240,2,0,0,241,2,0,0,16,0,0,0,17,0,0,0,171,0,0,0,172,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,124,186,0,0,156,79,0,0,244,80,0,0,220,187,0,0,0,0,0,0,128,81,0,0,1,0,0,0,216,3,0,0,217,3,0,0,218,3,0,0,219,3,0,0,0,0,0,0,160,81,0,0,1,0,0,0,220,3,0,0,221,3,0,0,222,3,0,0,223,3,0,0,0,0,0,0,176,81,0,0,1,0,0,0,224,3,0,0,225,3,0,0,226,3,0,0,227,3,0,0,0,0,0,0,192,81,0,0,8,0,0,0,132,1,0,0,228,3,0,0,229,3,0,0,230,3,0,0,231,3,0,0,232,3,0,0,233,3,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,0,0,0,0,208,81,0,0,1,0,0,0,234,3,0,0,235,3,0,0,0,0,0,0,224,81,0,0,1,0,0,0,236,3,0,0,237,3,0,0,238,3,0,0,239,3,0,0,240,3,0,0,241,3,0,0,242,3,0,0,243,3,0,0,244,3,0,0,0,0,0,0,72,82,0,0,1,0,0,0,245,3,0,0,246,3,0,0,0,0,0,0,32,82,0,0,247,3,0,0,248,3,0,0,249,3,0,0,250,3,0,0,251,3,0,0,252,3,0,0,253,3,0,0,254,3,0,0,255,3,0,0,0,4,0,0,1,4,0,0,2,4,0,0,0,0,0,0,240,81,0,0,3,4,0,0,4,4,0,0,5,4,0,0,6,4,0,0,7,4,0,0,8,4,0,0,9,4,0,0,10,4,0,0,11,4,0,0,12,4,0,0,13,4,0,0,14,4,0,0,76,190,0,0,44,6,0,0,68,123,0,0,156,124,0,0,132,7,0,0,164,191,0,0,64,0,0,0,0,0,0,0,16,83,0,0,15,4,0,0,16,4,0,0,116,0,0,0,117,0,0,0,118,0,0,0,235,2,0,0,236,2,0,0,121,0,0,0,122,0,0,0,123,0,0,0,124,0,0,0,125,0,0,0,126,0,0,0,127,0,0,0,128,0,0,0,129,0,0,0,130,0,0,0,131,0,0,0,132,0,0,0,133,0,0,0,134,0,0,0,135,0,0,0,136,0,0,0,137,0,0,0,138,0,0,0,17,4,0,0,140,0,0,0,18,4,0,0,142,0,0,0,143,0,0,0,144,0,0,0,145,0,0,0,146,0,0,0,223,2,0,0,148,0,0,0,149,0,0,0,150,0,0,0,151,0,0,0,152,0,0,0,153,0,0,0,154,0,0,0,155,0,0,0,156,0,0,0,157,0,0,0,158,0,0,0,159,0,0,0,160,0,0,0,161,0,0,0,162,0,0,0,163,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,192,255,255,255,0,0,0,0,0,0,0,0,192,255,255,255,192,255,255,255,192,255,255,255,192,255,255,255,192,255,255,255,192,255,255,255,0,0,0,0,192,255,255,255,16,83,0,0,8,0,0,0,19,4,0,0,20,4,0,0,166,0,0,0,167,0,0,0,168,0,0,0,240,2,0,0,241,2,0,0,16,0,0,0,17,0,0,0,171,0,0,0,172,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,44,6,0,0,68,123,0,0,156,124,0,0,132,7,0,0,64,0,0,0,0,0,0,0,0,83,0,0,21,4,0,0,22,4,0,0,56,0,0,0,248,255,255,255,0,83,0,0,23,4,0,0,24,4,0,0,192,255,255,255,192,255,255,255,0,83,0,0,25,4,0,0,26,4,0,0,76,192,0,0,204,82,0,0,164,82,0,0,184,82,0,0,124,83,0,0,144,83,0,0,244,82,0,0,224,82,0,0,116,192,0,0,96,192,0,0,0,0,0,0,32,83,0,0,1,0,0,0,37,4,0,0,38,4,0,0,39,4,0,0,40,4,0,0,41,4,0,0,42,4,0,0,43,4,0,0,44,4,0,0,45,4,0,0,46,4,0,0,47,4,0,0,0,0,0,0,48,83,0,0,8,0,0,0,48,4,0,0,49,4,0,0,50,4,0,0,51,4,0,0,52,4,0,0,53,4,0,0,54,4,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,55,4,0,0,56,4,0,0,57,4,0,0,58,4,0,0,59,4,0,0,60,4,0,0,61,4,0,0,62,4,0,0,63,4,0,0,64,4,0,0,65,4,0,0,66,4,0,0,67,4,0,0,68,4,0,0,69,4,0,0,70,4,0,0,224,255,255,255,48,83,0,0,71,4,0,0,72,4,0,0,73,4,0,0,74,4,0,0,75,4,0,0,0,0,0,0,80,83,0,0,1,0,0,0,76,4,0,0,77,4,0,0,68,0,0,0,0,0,0,0,96,83,0,0,78,4,0,0,79,4,0,0,116,0,0,0,117,0,0,0,118,0,0,0,235,2,0,0,236,2,0,0,121,0,0,0,122,0,0,0,123,0,0,0,124,0,0,0,125,0,0,0,126,0,0,0,127,0,0,0,128,0,0,0,129,0,0,0,130,0,0,0,131,0,0,0,132,0,0,0,80,4,0,0,134,0,0,0,135,0,0,0,136,0,0,0,137,0,0,0,138,0,0,0,81,4,0,0,140,0,0,0,82,4,0,0,142,0,0,0,143,0,0,0,144,0,0,0,145,0,0,0,146,0,0,0,223,2,0,0,148,0,0,0,149,0,0,0,150,0,0,0,151,0,0,0,152,0,0,0,153,0,0,0,154,0,0,0,155,0,0,0,156,0,0,0,157,0,0,0,158,0,0,0,159,0,0,0,160,0,0,0,161,0,0,0,162,0,0,0,163,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,188,255,255,255,188,255,255,255,0,0,0,0,0,0,0,0,188,255,255,255,188,255,255,255,188,255,255,255,188,255,255,255,188,255,255,255,188,255,255,255,0,0,0,0,188,255,255,255,96,83,0,0,8,0,0,0,83,4,0,0,84,4,0,0,166,0,0,0,167,0,0,0,168,0,0,0,240,2,0,0,241,2,0,0,16,0,0,0,17,0,0,0,171,0,0,0,172,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,236,193,0,0,116,125,0,0,204,126,0,0,68,195,0,0,56,0,0,0,0,0,0,0,152,83,0,0,89,4,0,0,90,4,0,0,200,255,255,255,200,255,255,255,152,83,0,0,91,4,0,0,92,4,0,0,236,195,0,0,124,83,0,0,144,83,0,0,0,196,0,0,0,0,0,0,184,83,0,0,1,0,0,0,93,4,0,0,94,4,0,0,0,0,0,0,168,83,0,0,1,0,0,0,95,4,0,0,96,4,0,0,97,4,0,0,0,0,0,0,200,83,0,0,98,4,0,0,99,4,0,0,100,4,0,0,101,4,0,0,102,4,0,0,103,4,0,0,104,4,0,0,105,4,0,0,106,4,0,0,107,4,0,0,108,4,0,0,109,4,0,0,110,4,0,0,111,4,0,0,112,4,0,0,113,4,0,0,114,4,0,0,115,4,0,0,116,4,0,0,117,4,0,0,120,1,0,0,0,0,0,0,216,83,0,0,118,4,0,0,119,4,0,0,116,0,0,0,117,0,0,0,118,0,0,0,120,4,0,0,121,4,0,0,121,0,0,0,122,0,0,0,123,0,0,0,124,0,0,0,125,0,0,0,126,0,0,0,127,0,0,0,128,0,0,0,129,0,0,0,130,0,0,0,131,0,0,0,132,0,0,0,122,4,0,0,134,0,0,0,135,0,0,0,136,0,0,0,137,0,0,0,138,0,0,0,123,4,0,0,140,0,0,0,124,4,0,0,125,4,0,0,143,0,0,0,126,4,0,0,145,0,0,0,146,0,0,0,223,2,0,0,148,0,0,0,149,0,0,0,150,0,0,0,127,4,0,0,152,0,0,0,153,0,0,0,154,0,0,0,155,0,0,0,156,0,0,0,128,4,0,0,158,0,0,0,129,4,0,0,160,0,0,0,161,0,0,0,162,0,0,0,163,0,0,0,130,4,0,0,131,4,0,0,132,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,254,255,255,136,254,255,255,0,0,0,0,0,0,0,0,136,254,255,255,136,254,255,255,136,254,255,255,136,254,255,255,136,254,255,255,136,254,255,255,0,0,0,0,136,254,255,255,216,83,0,0,8,0,0,0,133,4,0,0,134,4,0,0,166,0,0,0,167,0,0,0,168,0,0,0,135,4,0,0,136,4,0,0,16,0,0,0,17,0,0,0,171,0,0,0,172,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,168,196,0,0,244,83,0,0,76,85,0,0,12,198,0,0,56,0,0,0,0,0,0,0,224,85,0,0,137,4,0,0,138,4,0,0,116,0,0,0,117,0,0,0,118,0,0,0,139,4,0,0,140,4,0,0,121,0,0,0,122,0,0,0,141,4,0,0,142,4,0,0,125,0,0,0,126,0,0,0,127,0,0,0,128,0,0,0,129,0,0,0,130,0,0,0,131,0,0,0,132,0,0,0,143,4,0,0,134,0,0,0,135,0,0,0,136,0,0,0,137,0,0,0,138,0,0,0,144,4,0,0,140,0,0,0,145,4,0,0,146,4,0,0,147,4,0,0,148,4,0,0,145,0,0,0,149,4,0,0,223,2,0,0,148,0,0,0,149,0,0,0,150,4,0,0,151,4,0,0,152,0,0,0,153,0,0,0,154,0,0,0,155,0,0,0,156,0,0,0,152,4,0,0,158,0,0,0,153,4,0,0,160,0,0,0,161,0,0,0,154,4,0,0,163,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,255,255,255,200,255,255,255,0,0,0,0,0,0,0,0,200,255,255,255,200,255,255,255,200,255,255,255,200,255,255,255,200,255,255,255,200,255,255,255,0,0,0,0,200,255,255,255,224,85,0,0,8,0,0,0,155,4,0,0,156,4,0,0,166,0,0,0,167,0,0,0,168,0,0,0,157,4,0,0,158,4,0,0,16,0,0,0,17], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+41004);
/* memory initializer */ allocate([171,0,0,0,172,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,180,198,0,0,252,12,0,0,84,14,0,0,12,200,0,0,252,1,0,0,0,0,0,0,240,85,0,0,159,4,0,0,160,4,0,0,116,0,0,0,117,0,0,0,118,0,0,0,161,4,0,0,162,4,0,0,121,0,0,0,122,0,0,0,123,0,0,0,124,0,0,0,163,4,0,0,164,4,0,0,127,0,0,0,128,0,0,0,129,0,0,0,130,0,0,0,165,4,0,0,166,4,0,0,167,4,0,0,168,4,0,0,169,4,0,0,170,4,0,0,171,4,0,0,172,4,0,0,173,4,0,0,140,0,0,0,174,4,0,0,175,4,0,0,176,4,0,0,177,4,0,0,145,0,0,0,178,4,0,0,223,2,0,0,179,4,0,0,180,4,0,0,181,4,0,0,182,4,0,0,183,4,0,0,153,0,0,0,154,0,0,0,155,0,0,0,156,0,0,0,184,4,0,0,158,0,0,0,185,4,0,0,160,0,0,0,186,4,0,0,187,4,0,0,188,4,0,0,189,4,0,0,190,4,0,0,191,4,0,0,192,4,0,0,200,255,255,255,240,85,0,0,193,4,0,0,194,4,0,0,195,4,0,0,196,4,0,0,197,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,254,255,255,4,254,255,255,0,0,0,0,0,0,0,0,4,254,255,255,4,254,255,255,4,254,255,255,4,254,255,255,4,254,255,255,4,254,255,255,0,0,0,0,4,254,255,255,240,85,0,0,8,0,0,0,198,4,0,0,199,4,0,0,166,0,0,0,167,0,0,0,168,0,0,0,200,4,0,0,201,4,0,0,16,0,0,0,17,0,0,0,171,0,0,0,172,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,180,200,0,0,28,86,0,0,116,87,0,0,56,202,0,0,0,0,0,0,16,82,0,0,202,4,0,0,203,4,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,0,0,0,0,0,88,0,0,204,4,0,0,205,4,0,0,206,4,0,0,207,4,0,0,208,4,0,0,209,4,0,0,210,4,0,0,211,4,0,0,212,4,0,0,213,4,0,0,214,4,0,0,215,4,0,0,0,0,0,0,40,88,0,0,216,4,0,0,217,4,0,0,218,4,0,0,219,4,0,0,220,4,0,0,221,4,0,0,222,4,0,0,223,4,0,0,224,4,0,0,225,4,0,0,226,4,0,0,227,4,0,0,0,0,0,0,80,88,0,0,8,0,0,0,228,4,0,0,229,4,0,0,230,4,0,0,231,4,0,0,232,4,0,0,233,4,0,0,234,4,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,235,4,0,0,236,4,0,0,237,4,0,0,224,255,255,255,80,88,0,0,238,4,0,0,239,4,0,0,240,4,0,0,0,0,0,0,120,88,0,0,8,0,0,0,241,4,0,0,242,4,0,0,7,0,0,0,7,0,0,0,243,4,0,0,244,4,0,0,245,4,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,65,1,0,0,66,1,0,0,246,4,0,0,247,4,0,0,248,4,0,0,249,4,0,0,250,4,0,0,251,4,0,0,73,1,0,0,74,1,0,0,252,4,0,0,253,4,0,0,254,4,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,255,4,0,0,0,5,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,0,0,0,0,112,88,0,0,1,5,0,0,2,5,0,0,0,0,0,0,168,88,0,0,3,5,0,0,4,5,0,0,0,0,0,0,136,88,0,0,8,0,0,0,5,5,0,0,6,5,0,0,7,5,0,0,8,5,0,0,62,1,0,0,63,1,0,0,64,1,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,65,1,0,0,66,1,0,0,9,5,0,0,10,5,0,0,69,1,0,0,70,1,0,0,71,1,0,0,72,1,0,0,73,1,0,0,74,1,0,0,11,5,0,0,12,5,0,0,13,5,0,0,14,5,0,0,15,5,0,0,16,5,0,0,17,5,0,0,18,5,0,0,19,5,0,0,20,5,0,0,21,5,0,0,184,255,255,255,136,88,0,0,22,5,0,0,23,5,0,0,0,0,0,0,120,82,0,0,24,5,0,0,25,5,0,0,0,0,0,0,88,82,0,0,8,0,0,0,26,5,0,0,27,5,0,0,28,5,0,0,29,5,0,0,62,1,0,0,63,1,0,0,64,1,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,65,1,0,0,66,1,0,0,30,5,0,0,31,5,0,0,69,1,0,0,70,1,0,0,71,1,0,0,72,1,0,0,73,1,0,0,74,1,0,0,32,5,0,0,33,5,0,0,34,5,0,0,35,5,0,0,36,5,0,0,37,5,0,0,38,5,0,0,39,5,0,0,40,5,0,0,41,5,0,0,42,5,0,0,184,255,255,255,88,82,0,0,43,5,0,0,44,5,0,0,0,0,0,0,208,88,0,0,8,0,0,0,241,4,0,0,45,5,0,0,7,0,0,0,7,0,0,0,46,5,0,0,63,1,0,0,64,1,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,65,1,0,0,66,1,0,0,7,0,0,0,7,0,0,0,69,1,0,0,70,1,0,0,71,1,0,0,72,1,0,0,73,1,0,0,74,1,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,47,5,0,0,7,0,0,0,0,0,0,0,176,88,0,0,8,0,0,0,48,5,0,0,49,5,0,0,50,5,0,0,51,5,0,0,46,5,0,0,63,1,0,0,64,1,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,65,1,0,0,66,1,0,0,52,5,0,0,53,5,0,0,69,1,0,0,70,1,0,0,71,1,0,0,72,1,0,0,73,1,0,0,74,1,0,0,54,5,0,0,55,5,0,0,56,5,0,0,57,5,0,0,58,5,0,0,59,5,0,0,60,5,0,0,61,5,0,0,62,5,0,0,63,5,0,0,64,5,0,0,65,5,0,0,184,255,255,255,176,88,0,0,66,5,0,0,67,5,0,0,0,0,0,0,224,88,0,0,68,5,0,0,69,5,0,0,0,0,0,0,232,88,0,0,70,5,0,0,71,5,0,0,0,0,0,0,16,89,0,0,72,5,0,0,73,5,0,0,0,0,0,0,240,88,0,0,8,0,0,0,74,5,0,0,75,5,0,0,76,5,0,0,77,5,0,0,46,5,0,0,63,1,0,0,64,1,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,65,1,0,0,66,1,0,0,78,5,0,0,79,5,0,0,69,1,0,0,70,1,0,0,71,1,0,0,72,1,0,0,73,1,0,0,74,1,0,0,80,5,0,0,81,5,0,0,82,5,0,0,83,5,0,0,84,5,0,0,85,5,0,0,86,5,0,0,87,5,0,0,88,5,0,0,89,5,0,0,90,5,0,0,91,5,0,0,184,255,255,255,240,88,0,0,92,5,0,0,93,5,0,0,0,0,0,0,24,89,0,0,8,0,0,0,94,5,0,0,95,5,0,0,96,5,0,0,97,5,0,0,98,5,0,0,99,5,0,0,100,5,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,101,5,0,0,102,5,0,0,103,5,0,0,104,5,0,0,0,0,0,0,40,89,0,0,8,0,0,0,105,5,0,0,106,5,0,0,107,5,0,0,108,5,0,0,109,5,0,0,110,5,0,0,111,5,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,112,5,0,0,113,5,0,0,114,5,0,0,115,5,0,0,116,5,0,0,117,5,0,0,118,5,0,0,119,5,0,0,120,5,0,0,121,5,0,0,122,5,0,0,123,5,0,0,0,0,0,0,56,89,0,0,1,0,0,0,124,5,0,0,125,5,0,0,0,0,0,0,112,89,0,0,1,0,0,0,126,5,0,0,127,5,0,0,128,5,0,0,0,0,0,0,128,89,0,0,8,0,0,0,129,5,0,0,130,5,0,0,131,5,0,0,132,5,0,0,133,5,0,0,110,5,0,0,134,5,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,135,5,0,0,136,5,0,0,137,5,0,0,115,5,0,0,116,5,0,0,117,5,0,0,118,5,0,0,119,5,0,0,120,5,0,0,138,5,0,0,139,5,0,0,140,5,0,0,141,5,0,0,142,5,0,0,143,5,0,0,144,5,0,0,145,5,0,0,60,0,0,0,0,0,0,0,200,89,0,0,179,2,0,0,146,5,0,0,147,5,0,0,148,5,0,0,196,255,255,255,0,0,0,0,196,255,255,255,200,89,0,0,1,0,0,0,149,5,0,0,150,5,0,0,0,0,0,0,216,89,0,0,1,0,0,0,151,5,0,0,152,5,0,0,0,0,0,0,232,89,0,0,8,0,0,0,241,4,0,0,153,5,0,0,7,0,0,0,7,0,0,0,62,1,0,0,63,1,0,0,64,1,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,65,1,0,0,66,1,0,0,7,0,0,0,7,0,0,0,69,1,0,0,70,1,0,0,71,1,0,0,72,1,0,0,73,1,0,0,74,1,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,47,5,0,0,184,207,1,0,16,156,2,0,37,156,2,0,60,156,2,0,26,156,2,0,48,156,2,0,69,156,2,0,79,156,2,0,90,156,2,0,102,156,2,0,113,156,2,0,124,156,2,0,171,156,2,0,182,156,2,0,193,156,2,0,50,157,2,0,61,157,2,0,72,157,2,0,135,156,2,0,147,156,2,0,159,156,2,0,204,156,2,0,216,156,2,0,228,156,2,0,83,157,2,0,95,157,2,0,107,157,2,0,190,207,1,0,200,207,1,0,210,207,1,0,17,157,2,0,28,157,2,0,39,157,2,0,220,207,1,0,232,207,1,0,245,207,1,0,255,207,1,0,11,208,1,0,0,0,0,0,248,89,0,0,1,0,0,0,154,5,0,0,155,5,0,0,0,0,0,0,8,90,0,0,1,0,0,0,156,5,0,0,157,5,0,0,0,0,0,0,24,90,0,0,1,0,0,0,158,5,0,0,159,5,0,0,160,5,0,0,161,5,0,0,162,5,0,0,163,5,0,0,164,5,0,0,165,5,0,0,166,5,0,0,167,5,0,0,0,0,0,0,40,90,0,0,8,0,0,0,168,5,0,0,169,5,0,0,7,0,0,0,7,0,0,0,170,5,0,0,171,5,0,0,172,5,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,173,5,0,0,174,5,0,0,0,0,0,0,56,90,0,0,8,0,0,0,241,4,0,0,175,5,0,0,7,0,0,0,7,0,0,0,176,5,0,0,177,5,0,0,178,5,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,65,1,0,0,66,1,0,0,7,0,0,0,7,0,0,0,248,4,0,0,249,4,0,0,71,1,0,0,72,1,0,0,73,1,0,0,74,1,0,0,0,0,0,0,72,90,0,0,8,0,0,0,168,5,0,0,179,5,0,0,180,5,0,0,181,5,0,0,182,5,0,0,183,5,0,0,184,5,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,173,5,0,0,174,5,0,0,0,0,0,0,88,90,0,0,8,0,0,0,168,5,0,0,185,5,0,0,186,5,0,0,187,5,0,0,188,5,0,0,189,5,0,0,190,5,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,173,5,0,0,174,5,0,0,0,0,0,0,104,90,0,0,8,0,0,0,168,5,0,0,191,5,0,0,192,5,0,0,193,5,0,0,194,5,0,0,195,5,0,0,196,5,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,173,5,0,0,174,5,0,0,12,0,0,0,4,0,0,0,0,0,0,0,120,90,0,0,26,2,0,0,27,2,0,0,28,2,0,0,29,2,0,0,30,2,0,0,31,2,0,0,32,2,0,0,33,2,0,0,34,2,0,0,35,2,0,0,36,2,0,0,252,255,255,255,252,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,252,255,255,255,252,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,252,255,255,255,252,255,255,255,252,255,255,255,252,255,255,255,252,255,255,255,8,0,0,0,252,255,255,255,120,90,0,0,37,2,0,0,38,2,0,0,39,2,0,0,40,2,0,0,41,2,0,0,191,1,0,0,192,1,0,0,193,1,0,0,194,1,0,0,42,2,0,0,43,2,0,0,197,1,0,0,198,1,0,0,199,1,0,0,200,1,0,0,201,1,0,0,202,1,0,0,230,1,0,0,231,1,0,0,205,1,0,0,206,1,0,0,232,1,0,0,233,1,0,0,44,2,0,0,45,2,0,0,46,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,255,255,255,248,255,255,255,248,255,255,255,248,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,244,255,255,255,244,255,255,255,244,255,255,255,244,255,255,255,244,255,255,255,244,255,255,255,0,0,0,0,244,255,255,255,120,90,0,0,8,0,0,0,47,2,0,0,48,2,0,0,49,2,0,0,50,2,0,0,51,2,0,0,52,2,0,0,53,2,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,219,1,0,0,220,1,0,0,221,1,0,0,222,1,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,196,217,0,0,96,218,0,0,88,219,0,0,32,117,0,0,24,118,0,0,32,8,0,0,188,8,0,0,180,9,0,0,32,117,0,0,24,118,0,0,255,255,255,255,0,0,0,0,8,91,0,0,197,5,0,0,198,5,0,0,199,5,0,0,200,5,0,0,201,5,0,0,202,5,0,0,203,5,0,0,204,5,0,0,205,5,0,0,206,5,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,207,5,0,0,208,5,0,0,209,5,0,0,210,5,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,211,5,0,0,212,5,0,0,213,5,0,0,214,5,0,0,215,5,0,0,216,5,0,0,217,5,0,0,218,5,0,0,219,5,0,0,220,5,0,0,221,5,0,0,222,5,0,0,223,5,0,0,224,5,0,0,225,5,0,0,226,5,0,0,227,5,0,0,228,5,0,0,229,5,0,0,230,5,0,0,231,5,0,0,232,5,0,0,233,5,0,0,234,5,0,0,235,5,0,0,236,5,0,0,237,5,0,0,238,5,0,0,239,5,0,0,240,5,0,0,241,5,0,0,242,5,0,0,243,5,0,0,244,5,0,0,245,5,0,0,246,5,0,0,112,255,255,255,8,91,0,0,247,5,0,0,248,5,0,0,195,4,0,0,196,4,0,0,249,5,0,0,140,1,0,0,0,0,0,0,40,91,0,0,250,5,0,0,251,5,0,0,252,5,0,0,117,0,0,0,118,0,0,0,253,5,0,0,254,5,0,0,121,0,0,0,122,0,0,0,123,0,0,0,124,0,0,0,125,0,0,0,126,0,0,0,127,0,0,0,128,0,0,0,129,0,0,0,130,0,0,0,131,0,0,0,132,0,0,0,255,5,0,0,134,0,0,0,135,0,0,0,0,6,0,0,1,6,0,0,2,6,0,0,139,0,0,0,140,0,0,0,3,6,0,0,142,0,0,0,143,0,0,0,144,0,0,0,145,0,0,0,4,6,0,0,223,2,0,0,148,0,0,0,149,0,0,0,150,0,0,0,5,6,0,0,152,0,0,0,153,0,0,0,154,0,0,0,155,0,0,0,156,0,0,0,6,6,0,0,158,0,0,0,7,6,0,0,160,0,0,0,161,0,0,0,8,6,0,0,163,0,0,0,200,255,255,255,40,91,0,0,9,6,0,0,10,6,0,0,195,4,0,0,196,4,0,0,197,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,116,254,255,255,116,254,255,255,0,0,0,0,0,0,0,0,116,254,255,255,116,254,255,255,116,254,255,255,116,254,255,255,116,254,255,255,116,254,255,255,0,0,0,0,116,254,255,255,40,91,0,0,8,0,0,0,11,6,0,0,12,6,0,0,13,6,0,0,167,0,0,0,168,0,0,0,14,6,0,0,15,6,0,0,16,0,0,0,17,0,0,0,171,0,0,0,172,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,84,221,0,0,84,91,0,0,172,92,0,0,200,222,0,0,0,0,0,0,56,93,0,0,8,0,0,0,16,6,0,0,17,6,0,0,18,6,0,0,19,6,0,0,20,6,0,0,21,6,0,0,22,6,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,23,6,0,0,24,6,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,25,6,0,0,26,6,0,0,27,6,0,0,28,6,0,0,29,6,0,0,30,6,0,0,31,6,0,0,32,6,0,0,33,6,0,0,34,6,0,0,35,6,0,0,36,6,0,0,0,0,0,0,56,77,0,0,8,0,0,0,37,6,0,0,38,6,0,0,7,0,0,0,7,0,0,0,39,6,0,0,40,6,0,0,41,6,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,23,6,0,0,24,6,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,25,6,0,0,26,6,0,0,27,6,0,0,28,6,0,0,7,0,0,0,30,6,0,0,31,6,0,0,7,0,0,0,33,6,0,0,34,6,0,0,42,6,0,0,36,6,0,0,92,0,0,0,0,0,0,0,72,93,0,0,43,6,0,0,44,6,0,0,116,0,0,0,117,0,0,0,118,0,0,0,45,6,0,0,46,6,0,0,121,0,0,0,122,0,0,0,123,0,0,0,124,0,0,0,125,0,0,0,126,0,0,0,127,0,0,0,128,0,0,0,129,0,0,0,130,0,0,0,131,0,0,0,132,0,0,0,47,6,0,0,134,0,0,0,135,0,0,0,136,0,0,0,137,0,0,0,138,0,0,0,48,6,0,0,140,0,0,0,237,2,0,0,142,0,0,0,143,0,0,0,144,0,0,0,145,0,0,0,146,0,0,0,223,2,0,0,148,0,0,0,149,0,0,0,150,0,0,0,49,6,0,0,152,0,0,0,153,0,0,0,154,0,0,0,155,0,0,0,156,0,0,0,157,0,0,0,158,0,0,0,159,0,0,0,160,0,0,0,161,0,0,0,162,0,0,0,163,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,164,255,255,255,164,255,255,255,0,0,0,0,0,0,0,0,164,255,255,255,164,255,255,255,164,255,255,255,164,255,255,255,164,255,255,255,164,255,255,255,0,0,0,0,164,255,255,255,72,93,0,0,8,0,0,0,50,6,0,0,51,6,0,0,166,0,0,0,167,0,0,0,168,0,0,0,52,6,0,0,53,6,0,0,16,0,0,0,17,0,0,0,171,0,0,0,172,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,232,224,0,0,100,93,0,0,188,94,0,0,64,226,0,0,0,0,0,0,72,95,0,0,1,0,0,0,54,6,0,0,55,6,0,0,56,6,0,0,57,6,0,0,58,6,0,0,59,6,0,0,60,6,0,0,61,6,0,0,62,6,0,0,63,6,0,0,0,0,0,0,88,95,0,0,64,6,0,0,65,6,0,0,66,6,0,0,67,6,0,0,68,6,0,0,69,6,0,0,70,6,0,0,71,6,0,0,72,6,0,0,73,6,0,0,74,6,0,0,75,6,0,0,76,6,0,0,77,6,0,0,78,6,0,0,79,6,0,0,80,6,0,0,0,0,0,0,96,95,0,0,1,0,0,0,81,6,0,0,82,6,0,0,0,0,0,0,112,95,0,0,83,6,0,0,84,6,0,0,195,4,0,0,196,4,0,0,197,4,0,0,0,0,0,0,120,95,0,0,85,6,0,0,86,6,0,0,195,4,0,0,196,4,0,0,197,4,0,0,1,0,0,0,0,0,0,0,136,95,0,0,1,0,0,0,87,6,0,0,88,6,0,0,89,6,0,0,90,6,0,0,91,6,0,0,92,6,0,0,84,227,1,0,231,227,1,0,0,0,0,0,152,95,0,0,93,6,0,0,94,6,0,0,95,6,0,0,96,6,0,0,97,6,0,0,98,6,0,0,99,6,0,0,100,6,0,0,205,5,0,0,206,5,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,101,6,0,0,102,6,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,103,6,0,0,38,0,0,0,39,0,0,0,40,0,0,0,104,6,0,0,105,6,0,0,213,5,0,0,214,5,0,0,106,6,0,0,107,6,0,0,108,6,0,0,109,6,0,0,219,5,0,0,220,5,0,0,221,5,0,0,222,5,0,0,223,5,0,0,224,5,0,0,110,6,0,0,226,5,0,0,111,6,0,0,112,6,0,0,113,6,0,0,114,6,0,0,115,6,0,0,116,6,0,0,117,6,0,0,118,6,0,0,119,6,0,0,120,6,0,0,121,6,0,0,122,6,0,0,123,6,0,0,124,6,0,0,125,6,0,0,126,6,0,0,127,6,0,0,128,6,0,0,129,6,0,0,130,6,0,0,0,0,0,0,168,95,0,0,202,4,0,0,131,6,0,0,132,6,0,0,133,6,0,0,134,6,0,0,135,6,0,0,136,6,0,0,137,6,0,0,138,6,0,0,139,6,0,0,140,6,0,0,141,6,0,0,142,6,0,0,143,6,0,0,144,6,0,0,145,6,0,0,146,6,0,0,147,6,0,0,148,6,0,0,149,6,0,0,150,6,0,0,151,6,0,0,152,6,0,0,153,6,0,0,154,6,0,0,155,6,0,0,0,0,0,0,184,95,0,0,1,0,0,0,156,6,0,0,157,6,0,0,158,6,0,0,159,6,0,0,160,6,0,0,161,6,0,0,162,6,0,0,163,6,0,0,164,6,0,0,165,6,0,0,0,0,0,0,200,95,0,0,1,0,0,0,166,6,0,0,167,6,0,0,158,6,0,0,159,6,0,0,160,6,0,0,161,6,0,0,168,6,0,0,169,6,0,0,170,6,0,0,171,6,0,0,172,6,0,0,173,6,0,0,174,6,0,0,0,0,0,0,216,95,0,0,1,0,0,0,166,6,0,0,175,6,0,0,158,6,0,0,159,6,0,0,160,6,0,0,161,6,0,0,168,6,0,0,169,6,0,0,170,6,0,0,171,6,0,0,172,6,0,0,173,6,0,0,176,6,0,0,0,0,0,0,232,95,0,0,8,0,0,0,177,6,0,0,178,6,0,0,179,6,0,0,180,6,0,0,181,6,0,0,182,6,0,0,183,6,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,184,6,0,0,185,6,0,0,0,0,0,0,248,95,0,0,8,0,0,0,186,6,0,0,187,6,0,0,188,6,0,0,189,6,0,0,190,6,0,0,191,6,0,0,192,6,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,23,6,0,0,24,6,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,193,6,0,0,194,6,0,0,27,6,0,0,28,6,0,0,195,6,0,0,30,6,0,0,31,6,0,0,196,6,0,0,33,6,0,0,34,6,0,0,197,6,0,0,36,6,0,0,0,0,0,0,8,96,0,0,1,0,0,0,198,6,0,0,199,6,0,0,0,0,0,0,24,96,0,0,197,5,0,0,200,6,0,0,201,6,0,0,202,6,0,0,203,6,0,0,204,6,0,0,205,6,0,0,206,6,0,0,205,5,0,0,206,5,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,209,5,0,0,210,5,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,207,6,0,0,208,6,0,0,213,5,0,0,214,5,0,0,215,5,0,0,216,5,0,0,108,6,0,0,109,6,0,0,219,5,0,0,220,5,0,0,209,6,0,0,210,6,0,0,223,5,0,0,224,5,0,0,211,6,0,0,226,5,0,0,227,5,0,0,212,6,0,0,229,5,0,0,230,5,0,0,231,5,0,0,232,5,0,0,233,5,0,0,234,5,0,0,235,5,0,0,236,5,0,0,237,5,0,0,213,6,0,0,214,6,0,0,215,6,0,0,216,6,0,0,217,6,0,0,0,0,0,0,40,96,0,0,93,6,0,0,218,6,0,0,219,6,0,0,220,6,0,0,221,6,0,0,222,6,0,0,223,6,0,0,224,6,0,0,205,5,0,0,206,5,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,101,6,0,0,102,6,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,103,6,0,0,38,0,0,0,39,0,0,0,40,0,0,0,225,6,0,0,226,6,0,0,227,6,0,0,228,6,0,0,106,6,0,0,107,6,0,0,108,6,0,0,109,6,0,0,219,5,0,0,220,5,0,0,221,5,0,0,222,5,0,0,223,5,0,0,224,5,0,0,229,6,0,0,226,5,0,0,111,6,0,0,112,6,0,0,113,6,0,0,114,6,0,0,230,6,0,0,116,6,0,0,231,6,0,0,232,6,0,0,233,6,0,0,234,6,0,0,121,6,0,0,235,6,0,0,236,6,0,0,237,6,0,0,238,6,0,0,239,6,0,0,240,6,0,0,241,6,0,0,242,6,0,0,243,6,0,0,0,0,0,0,56,96,0,0,244,6,0,0,245,6,0,0,246,6,0,0,247,6,0,0,248,6,0,0,249,6,0,0,250,6,0,0,251,6,0,0,252,6,0,0,253,6,0,0,254,6,0,0,255,6,0,0,0,7,0,0,1,7,0,0,2,7,0,0,3,7,0,0,4,7,0,0,5,7,0,0,6,7,0,0,7,7,0,0,8,7,0,0,9,7,0,0,10,7,0,0,11,7,0,0,12,7,0,0,13,7,0,0,14,7,0,0,15,7,0,0,16,7,0,0,17,7,0,0,18,7,0,0,19,7,0,0,20,7,0,0,21,7,0,0,22,7,0,0,23,7,0,0,24,7,0,0,25,7,0,0,26,7,0,0,0,0,0,0,80,96,0,0,27,7,0,0,28,7,0,0,29,7,0,0,30,7,0,0,31,7,0,0,32,7,0,0,33,7,0,0,34,7,0,0,35,7,0,0,36,7,0,0,37,7,0,0,38,7,0,0,39,7,0,0,40,7,0,0,41,7,0,0,42,7,0,0,43,7,0,0,44,7,0,0,45,7,0,0,46,7,0,0,47,7,0,0,48,7,0,0,49,7,0,0,50,7,0,0,51,7,0,0,52,7,0,0,53,7,0,0,54,7,0,0,55,7,0,0,56,7,0,0,57,7,0,0,58,7,0,0,59,7,0,0,60,7,0,0,61,7,0,0,62,7,0,0,63,7,0,0,64,7,0,0,65,7,0,0,0,0,0,0,96,96,0,0,1,0,0,0,200,2,0,0,66,7,0,0,0,0,0,0,112,96,0,0,1,0,0,0,67,7,0,0,68,7,0,0,0,0,0,0,128,96,0,0,1,0,0,0,69,7,0,0,70,7,0,0,158,6,0,0,159,6,0,0,160,6,0,0,161,6,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,0,0,0,0,144,96,0,0,1,0,0,0,166,6,0,0,71,7,0,0,158,6,0,0,159,6,0,0,160,6,0,0,161,6,0,0,168,6,0,0,169,6,0,0,170,6,0,0,171,6,0,0,172,6,0,0,173,6,0,0,7,0,0,0,0,0,0,0,160,96,0,0,1,0,0,0,72,7,0,0,73,7,0,0,0,0,0,0,176,96,0,0,1,0,0,0,200,2,0,0,74,7,0,0,0,0,0,0,192,96,0,0,1,0,0,0,200,2,0,0,75,7,0,0,0,0,0,0,208,96,0,0,1,0,0,0,200,2,0,0,76,7,0,0,0,0,0,0,224,96,0,0,1,0,0,0,77,7,0,0,78,7,0,0,0,0,0,0,240,96,0,0,8,0,0,0,79,7,0,0,80,7,0,0,11,0,0,0,12,0,0,0,81,7,0,0,82,7,0,0,83,7,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,43,0,0,0,7,0,0,0,45,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,54,0,0,0,0,0,0,0,0,97,0,0,1,0,0,0,200,2,0,0,84,7,0,0,85,7,0,0,0,0,0,0,32,97,0,0,1,0,0,0,86,7,0,0,87,7,0,0,28,0,0,0,0,0,0,0,72,97,0,0,88,7,0,0,89,7,0,0,228,255,255,255,0,0,0,0,228,255,255,255,72,97,0,0,1,0,0,0,90,7,0,0,91,7,0,0,0,0,0,0,112,97,0,0,1,0,0,0,92,7,0,0,93,7,0,0,94,7,0,0,95,7,0,0,244,255,255,255,112,97,0,0,96,7,0,0,97,7,0,0,98,7,0,0,99,7,0,0,100,7,0,0,44,0,0,0,0,0,0,0,128,97,0,0,101,7,0,0,180,2,0,0,102,7,0,0,103,7,0,0,104,7,0,0,212,255,255,255,0,0,0,0,212,255,255,255,128,97,0,0,1,0,0,0,105,7,0,0,106,7,0,0,0,0,0,0,40,98,0,0,1,0,0,0,107,7,0,0,108,7,0,0,109,7,0,0,140,10,0,0,76,10,0,0,108,10,0,0,176,10,0,0,20,0,0,0,0,0,0,0,96,98,0,0,179,2,0,0,180,2,0,0,110,7,0,0,111,7,0,0,112,7,0,0,236,255,255,255,0,0,0,0,236,255,255,255,96,98,0,0,1,0,0,0,113,7,0,0,114,7,0,0,180,237,0,0,140,10,0,0,76,10,0,0,108,10,0,0,176,10,0,0,216,237,0,0,36,0,0,0,0,0,0,0,112,98,0,0,115,7,0,0,116,7,0,0,117,7,0,0,118,7,0,0,236,255,255,255,112,98,0,0,119,7,0,0,120,7,0,0,121,7,0,0,122,7,0,0,123,7,0,0,124,7,0,0,220,255,255,255,0,0,0,0,220,255,255,255,112,98,0,0,1,0,0,0,125,7,0,0,126,7,0,0,8,238,0,0,156,98,0,0,188,98,0,0,72,238,0,0,20,0,0,0,0,0,0,0,200,98,0,0,179,2,0,0,180,2,0,0,127,7,0,0,128,7,0,0,129,7,0,0,236,255,255,255,0,0,0,0,236,255,255,255,200,98,0,0,1,0,0,0,130,7,0,0,131,7,0,0,112,238,0,0,140,10,0,0,76,10,0,0,108,10,0,0,176,10,0,0,148,238,0,0,0,0,0,0,216,98,0,0,197,5,0,0,132,7,0,0,133,7,0,0,134,7,0,0,135,7,0,0,136,7,0,0,137,7,0,0,138,7,0,0,205,5,0,0,206,5,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,209,5,0,0,210,5,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,207,6,0,0,208,6,0,0,213,5,0,0,214,5,0,0,215,5,0,0,216,5,0,0,108,6,0,0,109,6,0,0,219,5,0,0,220,5,0,0,221,5,0,0,222,5,0,0,223,5,0,0,224,5,0,0,139,7,0,0,226,5,0,0,227,5,0,0,140,7,0,0,229,5,0,0,230,5,0,0,231,5,0,0,232,5,0,0,233,5,0,0,234,5,0,0,235,5,0,0,236,5,0,0,237,5,0,0,0,0,0,0,232,98,0,0,8,0,0,0,141,7,0,0,142,7,0,0,143,7,0,0,144,7,0,0,145,7,0,0,146,7,0,0,147,7,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+51244);
/* memory initializer */ allocate([39,0,0,0,40,0,0,0,65,1,0,0,66,1,0,0,148,7,0,0,149,7,0,0,248,4,0,0,249,4,0,0,71,1,0,0,72,1,0,0,150,7,0,0,151,7,0,0,152,7,0,0,153,7,0,0,154,7,0,0,155,7,0,0,156,7,0,0,157,7,0,0,158,7,0,0,159,7,0,0,160,7,0,0,161,7,0,0,162,7,0,0,163,7,0,0,164,7,0,0,165,7,0,0,12,0,0,0,4,0,0,0,0,0,0,0,248,98,0,0,166,7,0,0,167,7,0,0,168,7,0,0,169,7,0,0,170,7,0,0,171,7,0,0,172,7,0,0,173,7,0,0,174,7,0,0,175,7,0,0,176,7,0,0,252,255,255,255,252,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,252,255,255,255,252,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,252,255,255,255,252,255,255,255,252,255,255,255,252,255,255,255,252,255,255,255,8,0,0,0,252,255,255,255,248,98,0,0,177,7,0,0,178,7,0,0,179,7,0,0,180,7,0,0,181,7,0,0,191,1,0,0,192,1,0,0,193,1,0,0,194,1,0,0,228,1,0,0,229,1,0,0,182,7,0,0,183,7,0,0,199,1,0,0,200,1,0,0,201,1,0,0,202,1,0,0,230,1,0,0,231,1,0,0,205,1,0,0,206,1,0,0,232,1,0,0,233,1,0,0,184,7,0,0,185,7,0,0,186,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,255,255,255,248,255,255,255,248,255,255,255,248,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,244,255,255,255,244,255,255,255,244,255,255,255,244,255,255,255,244,255,255,255,244,255,255,255,0,0,0,0,244,255,255,255,248,98,0,0,8,0,0,0,187,7,0,0,188,7,0,0,189,7,0,0,190,7,0,0,191,7,0,0,192,7,0,0,193,7,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,219,1,0,0,220,1,0,0,221,1,0,0,222,1,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,172,240,0,0,208,10,0,0,108,11,0,0,100,12,0,0,72,241,0,0,64,242,0,0,32,117,0,0,24,118,0,0,0,0,0,0,24,99,0,0,8,0,0,0,201,7,0,0,202,7,0,0,203,7,0,0,204,7,0,0,205,7,0,0,206,7,0,0,207,7,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,208,7,0,0,209,7,0,0,210,7,0,0,0,0,0,0,40,99,0,0,211,7,0,0,212,7,0,0,213,7,0,0,214,7,0,0,215,7,0,0,216,7,0,0,217,7,0,0,218,7,0,0,219,7,0,0,220,7,0,0,221,7,0,0,222,7,0,0,72,0,0,0,0,0,0,0,80,99,0,0,223,7,0,0,224,7,0,0,116,0,0,0,117,0,0,0,118,0,0,0,225,7,0,0,226,7,0,0,121,0,0,0,122,0,0,0,123,0,0,0,124,0,0,0,125,0,0,0,126,0,0,0,127,0,0,0,128,0,0,0,129,0,0,0,130,0,0,0,131,0,0,0,132,0,0,0,133,0,0,0,134,0,0,0,135,0,0,0,136,0,0,0,137,0,0,0,138,0,0,0,139,0,0,0,227,7,0,0,237,2,0,0,142,0,0,0,143,0,0,0,144,0,0,0,145,0,0,0,146,0,0,0,223,2,0,0,148,0,0,0,149,0,0,0,150,0,0,0,151,0,0,0,152,0,0,0,153,0,0,0,154,0,0,0,155,0,0,0,156,0,0,0,157,0,0,0,158,0,0,0,159,0,0,0,160,0,0,0,161,0,0,0,162,0,0,0,163,0,0,0,228,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,255,255,255,184,255,255,255,0,0,0,0,0,0,0,0,184,255,255,255,184,255,255,255,184,255,255,255,184,255,255,255,184,255,255,255,184,255,255,255,0,0,0,0,184,255,255,255,80,99,0,0,8,0,0,0,229,7,0,0,230,7,0,0,166,0,0,0,167,0,0,0,168,0,0,0,231,7,0,0,232,7,0,0,16,0,0,0,17,0,0,0,171,0,0,0,172,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,208,243,0,0,108,99,0,0,196,100,0,0,44,245,0,0,0,0,0,0,96,101,0,0,233,7,0,0,234,7,0,0,235,7,0,0,236,7,0,0,237,7,0,0,238,7,0,0,239,7,0,0,240,7,0,0,205,5,0,0,206,5,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,209,5,0,0,210,5,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,241,7,0,0,242,7,0,0,213,5,0,0,214,5,0,0,106,6,0,0,107,6,0,0,108,6,0,0,109,6,0,0,219,5,0,0,220,5,0,0,221,5,0,0,222,5,0,0,223,5,0,0,224,5,0,0,243,7,0,0,226,5,0,0,111,6,0,0,244,7,0,0,252,12,0,0,84,14,0,0,0,0,0,0,136,101,0,0,1,0,0,0,200,2,0,0,245,7,0,0,246,7,0,0,8,0,0,0,0,0,0,0,152,101,0,0,247,7,0,0,248,7,0,0,248,255,255,255,248,255,255,255,152,101,0,0,249,7,0,0,250,7,0,0,200,246,0,0,180,101,0,0,200,101,0,0,220,246,0,0,8,0,0,0,0,0,0,0,208,101,0,0,251,7,0,0,252,7,0,0,248,255,255,255,248,255,255,255,208,101,0,0,253,7,0,0,254,7,0,0,0,247,0,0,180,101,0,0,200,101,0,0,20,247,0,0,0,0,0,0,224,101,0,0,255,7,0,0,0,8,0,0,39,1,0,0,40,1,0,0,41,1,0,0,42,1,0,0,1,8,0,0,44,1,0,0,45,1,0,0,46,1,0,0,47,1,0,0,48,1,0,0,49,1,0,0,50,1,0,0,0,0,0,0,240,101,0,0,2,8,0,0,3,8,0,0,39,1,0,0,40,1,0,0,4,8,0,0,5,8,0,0,43,1,0,0,44,1,0,0,45,1,0,0,6,8,0,0,47,1,0,0,7,8,0,0,8,8,0,0,9,8,0,0,0,0,0,0,0,102,0,0,8,0,0,0,132,1,0,0,10,8,0,0,7,0,0,0,7,0,0,0,250,0,0,0,7,0,0,0,7,0,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,0,0,0,0,16,102,0,0,11,8,0,0,12,8,0,0,13,8,0,0,0,0,0,0,24,102,0,0,1,0,0,0,14,8,0,0,15,8,0,0,0,0,0,0,56,102,0,0,1,0,0,0,16,8,0,0,17,8,0,0,0,0,0,0,72,102,0,0,1,0,0,0,92,7,0,0,18,8,0,0,19,8,0,0,95,7,0,0,244,255,255,255,72,102,0,0,20,8,0,0,21,8,0,0,98,7,0,0,22,8,0,0,100,7,0,0,0,0,0,0,120,102,0,0,8,0,0,0,23,8,0,0,24,8,0,0,25,8,0,0,26,8,0,0,27,8,0,0,28,8,0,0,29,8,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,23,6,0,0,24,6,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,25,6,0,0,26,6,0,0,27,6,0,0,28,6,0,0,30,8,0,0,30,6,0,0,31,6,0,0,31,8,0,0,33,6,0,0,34,6,0,0,32,8,0,0,36,6,0,0,0,0,0,0,136,102,0,0,8,0,0,0,33,8,0,0,34,8,0,0,35,8,0,0,36,8,0,0,37,8,0,0,38,8,0,0,39,8,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,23,6,0,0,24,6,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,25,6,0,0,26,6,0,0,27,6,0,0,28,6,0,0,40,8,0,0,30,6,0,0,31,6,0,0,41,8,0,0,42,8,0,0,34,6,0,0,43,8,0,0,36,6,0,0,0,0,0,0,152,102,0,0,8,0,0,0,44,8,0,0,45,8,0,0,46,8,0,0,47,8,0,0,48,8,0,0,49,8,0,0,50,8,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,65,1,0,0,66,1,0,0,51,8,0,0,52,8,0,0,248,4,0,0,249,4,0,0,250,4,0,0,251,4,0,0,73,1,0,0,74,1,0,0,53,8,0,0,253,4,0,0,254,4,0,0,54,8,0,0,55,8,0,0,56,8,0,0,57,8,0,0,58,8,0,0,59,8,0,0,255,4,0,0,0,5,0,0,60,8,0,0,61,8,0,0,62,8,0,0,63,8,0,0,64,8,0,0,65,8,0,0,192,255,255,255,152,102,0,0,66,8,0,0,67,8,0,0,0,0,0,0,184,102,0,0,8,0,0,0,68,8,0,0,69,8,0,0,70,8,0,0,71,8,0,0,72,8,0,0,73,8,0,0,74,8,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,65,1,0,0,66,1,0,0,75,8,0,0,76,8,0,0,248,4,0,0,249,4,0,0,250,4,0,0,251,4,0,0,73,1,0,0,74,1,0,0,77,8,0,0,253,4,0,0,254,4,0,0,78,8,0,0,79,8,0,0,80,8,0,0,81,8,0,0,82,8,0,0,83,8,0,0,255,4,0,0,0,5,0,0,84,8,0,0,85,8,0,0,86,8,0,0,87,8,0,0,88,8,0,0,89,8,0,0,192,255,255,255,184,102,0,0,90,8,0,0,91,8,0,0,0,0,0,0,216,102,0,0,8,0,0,0,92,8,0,0,93,8,0,0,94,8,0,0,95,8,0,0,96,8,0,0,97,8,0,0,98,8,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,65,1,0,0,66,1,0,0,99,8,0,0,100,8,0,0,248,4,0,0,249,4,0,0,250,4,0,0,251,4,0,0,73,1,0,0,74,1,0,0,101,8,0,0,253,4,0,0,254,4,0,0,102,8,0,0,103,8,0,0,104,8,0,0,105,8,0,0,106,8,0,0,107,8,0,0,255,4,0,0,0,5,0,0,108,8,0,0,109,8,0,0,110,8,0,0,111,8,0,0,112,8,0,0,113,8,0,0,192,255,255,255,216,102,0,0,114,8,0,0,115,8,0,0,0,0,0,0,8,103,0,0,8,0,0,0,241,4,0,0,116,8,0,0,117,8,0,0,118,8,0,0,119,8,0,0,120,8,0,0,121,8,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,65,1,0,0,66,1,0,0,246,4,0,0,247,4,0,0,248,4,0,0,249,4,0,0,250,4,0,0,251,4,0,0,73,1,0,0,74,1,0,0,252,4,0,0,122,8,0,0,123,8,0,0,124,8,0,0,125,8,0,0,126,8,0,0,127,8,0,0,128,8,0,0,129,8,0,0,255,4,0,0,0,5,0,0,0,0,0,0,24,103,0,0,130,8,0,0,131,8,0,0,132,8,0,0,133,8,0,0,134,8,0,0,135,8,0,0,136,8,0,0,137,8,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,23,6,0,0,24,6,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,138,8,0,0,139,8,0,0,27,6,0,0,28,6,0,0,140,8,0,0,30,6,0,0,31,6,0,0,141,8,0,0,33,6,0,0,34,6,0,0,142,8,0,0,143,8,0,0,0,0,0,0,88,103,0,0,1,0,0,0,144,8,0,0,145,8,0,0,0,0,0,0,40,103,0,0,1,0,0,0,146,8,0,0,147,8,0,0,148,8,0,0,149,8,0,0,150,8,0,0,151,8,0,0,152,8,0,0,0,0,0,0,56,103,0,0,8,0,0,0,153,8,0,0,154,8,0,0,155,8,0,0,156,8,0,0,157,8,0,0,158,8,0,0,159,8,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,0,0,0,0,72,103,0,0,1,0,0,0,166,6,0,0,160,8,0,0,158,6,0,0,159,6,0,0,160,6,0,0,161,6,0,0,168,6,0,0,169,6,0,0,170,6,0,0,171,6,0,0,172,6,0,0,173,6,0,0,161,8,0,0,0,0,0,0,120,103,0,0,1,0,0,0,200,2,0,0,162,8,0,0,0,0,0,0,160,103,0,0,1,0,0,0,163,8,0,0,164,8,0,0,0,0,0,0,128,103,0,0,1,0,0,0,165,8,0,0,166,8,0,0,0,0,0,0,144,103,0,0,1,0,0,0,166,6,0,0,167,8,0,0,158,6,0,0,159,6,0,0,160,6,0,0,161,6,0,0,168,6,0,0,169,6,0,0,170,6,0,0,171,6,0,0,172,6,0,0,173,6,0,0,168,8,0,0,0,0,0,0,176,103,0,0,8,0,0,0,169,8,0,0,170,8,0,0,171,8,0,0,172,8,0,0,173,8,0,0,174,8,0,0,175,8,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,176,8,0,0,177,8,0,0,0,0,0,0,224,103,0,0,178,8,0,0,179,8,0,0,180,8,0,0,181,8,0,0,182,8,0,0,183,8,0,0,184,8,0,0,185,8,0,0,186,8,0,0,187,8,0,0,188,8,0,0,189,8,0,0,190,8,0,0,0,0,0,0,192,103,0,0,8,0,0,0,191,8,0,0,192,8,0,0,7,0,0,0,7,0,0,0,193,8,0,0,194,8,0,0,195,8,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,7,0,0,0,7,0,0,0,0,0,0,0,248,103,0,0,8,0,0,0,191,8,0,0,196,8,0,0,197,8,0,0,198,8,0,0,199,8,0,0,200,8,0,0,201,8,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,202,8,0,0,203,8,0,0,0,0,0,0,8,104,0,0,1,0,0,0,95,4,0,0,204,8,0,0,97,4,0,0,0,0,0,0,24,104,0,0,205,8,0,0,206,8,0,0,207,8,0,0,208,8,0,0,209,8,0,0,210,8,0,0,211,8,0,0,212,8,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,213,8,0,0,214,8,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,215,8,0,0,38,0,0,0,39,0,0,0,40,0,0,0,216,8,0,0,217,8,0,0,0,0,0,0,40,104,0,0,218,8,0,0,219,8,0,0,220,8,0,0,221,8,0,0,0,0,0,0,64,104,0,0,218,8,0,0,222,8,0,0,223,8,0,0,224,8,0,0,0,0,0,0,80,104,0,0,1,0,0,0,225,8,0,0,226,8,0,0,0,0,0,0,96,104,0,0,8,0,0,0,227,8,0,0,228,8,0,0,229,8,0,0,230,8,0,0,231,8,0,0,232,8,0,0,233,8,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,23,6,0,0,24,6,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,25,6,0,0,26,6,0,0,27,6,0,0,28,6,0,0,234,8,0,0,30,6,0,0,31,6,0,0,235,8,0,0,236,8,0,0,34,6,0,0,237,8,0,0,36,6,0,0,0,0,0,0,112,104,0,0,8,0,0,0,238,8,0,0,239,8,0,0,240,8,0,0,241,8,0,0,242,8,0,0,243,8,0,0,244,8,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,23,6,0,0,24,6,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,25,6,0,0,26,6,0,0,27,6,0,0,28,6,0,0,245,8,0,0,30,6,0,0,246,8,0,0,247,8,0,0,33,6,0,0,34,6,0,0,248,8,0,0,36,6,0,0,0,0,0,0,160,104,0,0,8,0,0,0,249,8,0,0,250,8,0,0,251,8,0,0,252,8,0,0,253,8,0,0,254,8,0,0,255,8,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,23,6,0,0,24,6,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,0,9,0,0,1,9,0,0,2,9,0,0,3,9,0,0,4,9,0,0,30,6,0,0,5,9,0,0,6,9,0,0,33,6,0,0,34,6,0,0,7,9,0,0,8,9,0,0,9,9,0,0,10,9,0,0,11,9,0,0,12,9,0,0,13,9,0,0,14,9,0,0,15,9,0,0,16,9,0,0,17,9,0,0,18,9,0,0,50,130,0,0,148,141,0,0,1,20,0,0,49,130,0,0,148,141,0,0,0,20,0,0,52,130,0,0,148,141,0,0,3,20,0,0,51,130,0,0,148,141,0,0,2,20,0,0,54,130,0,0,148,141,0,0,5,20,0,0,53,130,0,0,148,141,0,0,4,20,0,0,56,130,0,0,40,130,0,0,1,20,0,0,55,130,0,0,40,130,0,0,0,20,0,0,58,130,0,0,40,130,0,0,3,20,0,0,57,130,0,0,40,130,0,0,2,20,0,0,60,130,0,0,40,130,0,0,5,20,0,0,59,130,0,0,40,130,0,0,4,20,0,0,125,141,0,0,152,141,0,0,1,20,0,0,143,141,0,0,152,141,0,0,0,20,0,0,119,141,0,0,152,141,0,0,3,20,0,0,137,141,0,0,152,141,0,0,2,20,0,0,113,141,0,0,152,141,0,0,5,20,0,0,131,141,0,0,152,141,0,0,4,20,0,0,124,141,0,0,153,141,0,0,1,20,0,0,142,141,0,0,153,141,0,0,0,20,0,0,118,141,0,0,153,141,0,0,3,20,0,0,136,141,0,0,153,141,0,0,2,20,0,0,130,141,0,0,153,141,0,0,4,20,0,0,112,141,0,0,153,141,0,0,5,20,0,0,41,130,0,0,3,25,0,0,1,20,0,0,45,130,0,0,3,25,0,0,11,20,0,0,46,130,0,0,3,25,0,0,6,20,0,0,45,130,0,0,3,25,0,0,6,20,0,0,43,130,0,0,39,130,0,0,1,20,0,0,47,130,0,0,39,130,0,0,11,20,0,0,47,130,0,0,39,130,0,0,6,20,0,0,48,130,0,0,39,130,0,0,6,20,0,0,16,42,0,0,7,25,0,0,50,128,0,0,16,42,0,0,7,25,0,0,98,131,0,0,79,128,0,0,7,25,0,0,51,128,0,0,79,128,0,0,7,25,0,0,101,131,0,0,80,128,0,0,7,25,0,0,52,128,0,0,80,128,0,0,7,25,0,0,102,131,0,0,81,128,0,0,7,25,0,0,1,20,0,0,98,141,0,0,7,25,0,0,1,20,0,0,98,141,0,0,7,25,0,0,99,131,0,0,98,141,0,0,7,25,0,0,100,131,0,0,82,128,0,0,7,25,0,0,104,131,0,0,82,128,0,0,7,25,0,0,54,128,0,0,83,128,0,0,7,25,0,0,3,20,0,0,27,136,0,0,7,25,0,0,11,20,0,0,21,136,0,0,7,25,0,0,6,20,0,0,27,136,0,0,7,25,0,0,6,20,0,0,88,128,0,0,8,25,0,0,1,20,0,0,89,128,0,0,8,25,0,0,54,128,0,0,89,128,0,0,8,25,0,0,104,131,0,0,90,128,0,0,8,25,0,0,3,20,0,0,86,128,0,0,8,25,0,0,1,20,0,0,86,128,0,0,8,25,0,0,51,128,0,0,86,128,0,0,8,25,0,0,101,131,0,0,87,128,0,0,8,25,0,0,1,20,0,0,87,128,0,0,8,25,0,0,52,128,0,0,87,128,0,0,8,25,0,0,102,131,0,0,87,128,0,0,8,25,0,0,54,128,0,0,87,128,0,0,8,25,0,0,104,131,0,0,65,140,0,0,7,25,0,0,1,20,0,0,67,140,0,0,8,25,0,0,1,20,0,0,148,143,0,0,3,25,0,0,0,20,0,0,152,143,0,0,3,25,0,0,2,20,0,0,149,143,0,0,39,130,0,0,0,20,0,0,153,143,0,0,39,130,0,0,2,20,0,0,150,143,0,0,7,25,0,0,0,20,0,0,154,143,0,0,7,25,0,0,2,20,0,0,151,143,0,0,8,25,0,0,0,20,0,0,237,132,0,0,7,25,0,0,237,132,0,0,238,132,0,0,8,25,0,0,238,132,0,0,72,140,0,0,7,25,0,0,72,140,0,0,73,140,0,0,8,25,0,0,73,140,0,0,187,141,0,0,3,25,0,0,187,141,0,0,188,141,0,0,3,25,0,0,188,141,0,0,240,131,0,0,7,25,0,0,240,131,0,0,241,131,0,0,8,25,0,0,241,131,0,0,242,131,0,0,8,25,0,0,242,131,0,0,243,131,0,0,8,25,0,0,243,131,0,0,0,0,0,0,208,104,0,0,1,0,0,0,19,9,0,0,20,9,0,0,0,0,0,0,224,104,0,0,1,0,0,0,21,9,0,0,22,9,0,0,23,9,0,0,24,9,0,0,25,9,0,0,26,9,0,0,27,9,0,0,28,9,0,0,29,9,0,0,30,9,0,0,0,0,0,0,240,104,0,0,8,0,0,0,31,9,0,0,32,9,0,0,7,0,0,0,7,0,0,0,33,9,0,0,34,9,0,0,35,9,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,23,6,0,0,24,6,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,0,9,0,0,1,9,0,0,2,9,0,0,3,9,0,0,36,9,0,0,30,6,0,0,5,9,0,0,7,0,0,0,33,6,0,0,34,6,0,0,7,0,0,0,8,9,0,0,7,0,0,0,37,9,0,0,38,9,0,0,39,9,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,0,0,0,0,0,105,0,0,1,0,0,0,40,9,0,0,41,9,0,0,21,133,0,0,22,133,0,0,23,133,0,0,24,133,0,0,25,133,0,0,26,133,0,0,0,0,0,0,32,105,0,0,8,0,0,0,42,9,0,0,43,9,0,0,44,9,0,0,45,9,0,0,46,9,0,0,47,9,0,0,48,9,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,23,6,0,0,24,6,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,0,9,0,0,1,9,0,0,2,9,0,0,3,9,0,0,49,9,0,0,30,6,0,0,5,9,0,0,50,9,0,0,33,6,0,0,34,6,0,0,51,9,0,0,8,9,0,0,52,9,0,0,53,9,0,0,54,9,0,0,55,9,0,0,56,9,0,0,57,9,0,0,58,9,0,0,59,9,0,0,60,9,0,0,61,9,0,0,0,0,0,0,48,105,0,0,197,5,0,0,62,9,0,0,63,9,0,0,64,9,0,0,65,9,0,0,66,9,0,0,67,9,0,0,68,9,0,0,205,5,0,0,206,5,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,209,5,0,0,210,5,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,207,6,0,0,208,6,0,0,213,5,0,0,214,5,0,0,215,5,0,0,216,5,0,0,217,5,0,0,218,5,0,0,219,5,0,0,220,5,0,0,221,5,0,0,222,5,0,0,223,5,0,0,224,5,0,0,69,9,0,0,226,5,0,0,227,5,0,0,228,5,0,0,229,5,0,0,230,5,0,0,231,5,0,0,232,5,0,0,233,5,0,0,234,5,0,0,235,5,0,0,236,5,0,0,237,5,0,0,238,5,0,0,239,5,0,0,240,5,0,0,241,5,0,0,242,5,0,0,243,5,0,0,70,9,0,0,71,9,0,0,228,12,1,0,116,125,0,0,204,126,0,0,60,14,1,0,68,0,0,0,0,0,0,0,64,105,0,0,72,9,0,0,73,9,0,0,116,0,0,0,117,0,0,0,118,0,0,0,235,2,0,0,236,2,0,0,121,0,0,0,122,0,0,0,123,0,0,0,124,0,0,0,125,0,0,0,126,0,0,0,127,0,0,0,128,0,0,0,129,0,0,0,130,0,0,0,131,0,0,0,132,0,0,0,133,0,0,0,134,0,0,0,135,0,0,0,136,0,0,0,137,0,0,0,138,0,0,0,139,0,0,0,140,0,0,0,237,2,0,0,142,0,0,0,143,0,0,0,144,0,0,0,145,0,0,0,146,0,0,0,223,2,0,0,148,0,0,0,149,0,0,0,150,0,0,0,74,9,0,0,152,0,0,0,153,0,0,0,154,0,0,0,155,0,0,0,156,0,0,0,157,0,0,0,158,0,0,0,159,0,0,0,160,0,0,0,161,0,0,0,162,0,0,0,163,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,188,255,255,255,188,255,255,255,0,0,0,0,0,0,0,0,188,255,255,255,188,255,255,255,188,255,255,255,188,255,255,255,188,255,255,255,188,255,255,255,0,0,0,0,188,255,255,255,64,105,0,0,8,0,0,0,75,9,0,0,76,9,0,0,166,0,0,0,167,0,0,0,168,0,0,0,240,2,0,0,241,2,0,0,16,0,0,0,17,0,0,0,171,0,0,0,172,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,0,0,0,0,80,105,0,0,8,0,0,0,77,9,0,0,78,9,0,0,79,9,0,0,80,9,0,0,81,9,0,0,82,9,0,0,83,9,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,84,9,0,0,85,9,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,86,9,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,87,9,0,0,88,9,0,0,0,0,0,0,112,105,0,0,89,9,0,0,90,9,0,0,91,9,0,0,92,9,0,0,93,9,0,0,94,9,0,0,95,9,0,0,96,9,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,97,9,0,0,98,9,0,0,36,0,0,0,37,0,0,0,99,9,0,0,100,9,0,0,101,9,0,0,41,0,0,0,42,0,0,0,102,9,0,0,103,9,0,0,104,9,0,0,105,9,0,0,106,9,0,0,107,9,0,0,108,9,0,0,109,9,0,0,110,9,0,0,111,9,0,0,112,9,0,0,113,9,0,0,114,9,0,0,115,9,0,0,116,9,0,0,0,0,0,0,128,105,0,0,1,0,0,0,117,9,0,0,118,9,0,0,0,0,0,0,144,105,0,0,1,0,0,0,200,2,0,0,119,9,0,0,120,9,0,0,121,9,0,0,122,9,0,0,123,9,0,0,124,9,0,0,125,9,0,0,126,9,0,0,0,0,0,0,176,105,0,0,1,0,0,0,127,9,0,0,128,9,0,0,158,6,0,0,159,6,0,0,160,6,0,0,161,6,0,0,129,9,0,0,130,9,0,0,131,9,0,0,132,9,0,0,36,0,0,0,0,0,0,0,192,105,0,0,251,0,0,0,252,0,0,0,253,0,0,0,254,0,0,0,255,0,0,0,0,1,0,0,1,1,0,0,2,1,0,0,3,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,255,255,255,220,255,255,255,220,255,255,255,220,255,255,255,220,255,255,255,220,255,255,255,0,0,0,0,220,255,255,255,192,105,0,0,8,0,0,0,4,1,0,0,5,1,0,0,6,1,0,0,7,1,0,0,8,1,0,0,9,1,0,0,10,1,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,184,16,1,0,108,17,1,0,0,0,0,0,216,105,0,0,133,9,0,0,134,9,0,0,135,9,0,0,0,0,0,0,224,105,0,0,8,0,0,0,136,9,0,0,137,9,0,0,138,9,0,0,139,9,0,0,140,9,0,0,141,9,0,0,142,9,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,23,6,0,0,24,6,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,25,6,0,0,26,6,0,0,27,6,0,0,28,6,0,0,143,9,0,0,30,6,0,0,31,6,0,0,144,9,0,0,33,6,0,0,34,6,0,0,145,9,0,0,36,6,0,0,95,109,2,0,97,109,2,0,154,109,2,0,211,109,2,0,11,110,2,0,67,110,2,0,93,110,2,0,0,0,0,0,115,110,2,0,0,5,0,0,124,110,2,0,1,5,0,0,142,110,2,0,2,5,0,0,156,110,2,0,3,5,0,0,174,110,2,0,4,5,0,0,189,110,2,0,5,5,0,0,205,110,2,0,49,128,0,0,219,110,2,0,6,5,0,0,235,110,2,0,36,138,1,0,124,110,2,0,37,138,1,0,142,110,2,0,38,138,1,0,205,110,2,0,39,138,1,0,9,111,2,0,40,138,1,0,156,110,2,0,255,255,255,255,0,0,0,0,0,0,0,0,240,105,0,0,1,0,0,0,146,9,0,0,147,9,0,0,0,0,0,0,0,106,0,0,1,0,0,0,200,2,0,0,148,9,0,0,149,9,0,0,150,9,0,0,0,0,0,0,32,106,0,0,8,0,0,0,151,9,0,0,152,9,0,0,153,9,0,0,154,9,0,0,155,9,0,0,156,9,0,0,157,9,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,23,6,0,0,24,6,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,25,6,0,0,26,6,0,0,27,6,0,0,28,6,0,0,158,9,0,0,30,6,0,0,31,6,0,0,159,9,0,0,160,9,0,0,34,6,0,0,161,9,0,0,36,6,0,0,0,0,0,0,48,106,0,0,8,0,0,0,162,9,0,0,163,9,0,0,164,9,0,0,165,9,0,0,166,9,0,0,167,9,0,0,168,9,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,23,6,0,0,24,6,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,25,6,0,0,26,6,0,0,27,6,0,0,28,6,0,0,169,9,0,0,170,9,0,0,31,6,0,0,171,9,0,0,172,9,0,0,34,6,0,0,173,9,0,0,36,6,0,0,0,0,0,0,64,106,0,0,8,0,0,0,174,9,0,0,175,9,0,0,176,9,0,0,177,9,0,0,178,9,0,0,179,9,0,0,180,9,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,181,9,0,0,182,9,0,0,183,9,0,0,184,9,0,0,0,0,0,0,80,106,0,0,185,9,0,0,186,9,0,0,187,9,0,0,7,0,0,0,100,7,0,0,0,0,0,0,88,106,0,0,188,9,0,0,189,9,0,0,0,0,0,0,96,106,0,0,190,9,0,0,191,9,0,0,121,7,0,0,122,7,0,0,192,9,0,0,124,7,0,0,0,0,0,0,104,106,0,0,193,9,0,0,194,9,0,0,0,0,0,0,112,106,0,0,195,9,0,0,196,9,0,0,197,9,0,0,198,9,0,0,199,9,0,0,200,9,0,0,0,0,0,0,120,106,0,0,201,9,0,0,202,9,0,0,0,0,0,0,128,106,0,0,195,2,0,0,203,9,0,0,197,2,0,0,198,2,0,0,199,2,0,0,0,0,0,0,136,106,0,0,204,9,0,0,205,9,0,0,0,0,0,0,144,106,0,0,206,9,0,0,207,9,0,0,208,9,0,0,0,0,0,0,184,106,0,0,209,9,0,0,210,9,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,0,0,0,0,160,106,0,0,211,9,0,0,212,9,0,0,213,9,0,0,214,9,0,0,215,9,0,0,216,9,0,0,217,9,0,0,218,9,0,0,219,9,0,0,0,0,0,0,216,106,0,0,220,9,0,0,221,9,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,0,0,0,0,192,106,0,0,222,9,0,0,223,9,0,0,224,9,0,0,225,9,0,0,226,9,0,0,227,9,0,0,228,9,0,0,229,9,0,0,230,9,0,0,0,0,0,0,248,106,0,0,231,9,0,0,232,9,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,0,0,0,0,224,106,0,0,233,9,0,0,234,9,0,0,235,9,0,0,236,9,0,0,237,9,0,0,238,9,0,0,239,9,0,0,240,9,0,0,241,9,0,0,0,0,0,0,0,107,0,0,242,9,0,0,243,9,0,0,244,9,0,0,245,9,0,0,246,9,0,0,247,9,0,0,248,9,0,0,249,9,0,0,250,9,0,0,0,0,0,0,24,107,0,0,8,0,0,0,251,9,0,0,252,9,0,0,253,9,0,0,254,9,0,0,255,9,0,0,0,10,0,0,1,10,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+61484);
/* memory initializer */ allocate([40,0,0,0,41,0,0,0,42,0,0,0,92,0,0,0,84,0,0,0,0,0,0,0,40,107,0,0,155,1,0,0,156,1,0,0,157,1,0,0,158,1,0,0,159,1,0,0,160,1,0,0,161,1,0,0,162,1,0,0,163,1,0,0,2,10,0,0,3,10,0,0,166,1,0,0,167,1,0,0,168,1,0,0,169,1,0,0,170,1,0,0,171,1,0,0,172,1,0,0,4,10,0,0,174,1,0,0,88,0,0,0,80,0,0,0,252,255,255,255,40,107,0,0,175,1,0,0,176,1,0,0,177,1,0,0,178,1,0,0,179,1,0,0,180,1,0,0,181,1,0,0,182,1,0,0,183,1,0,0,5,10,0,0,6,10,0,0,172,255,255,255,172,255,255,255,172,255,255,255,172,255,255,255,0,0,0,0,0,0,0,0,172,255,255,255,172,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,172,255,255,255,172,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,172,255,255,255,172,255,255,255,172,255,255,255,172,255,255,255,172,255,255,255,8,0,0,0,172,255,255,255,40,107,0,0,186,1,0,0,187,1,0,0,188,1,0,0,189,1,0,0,190,1,0,0,191,1,0,0,192,1,0,0,193,1,0,0,194,1,0,0,195,1,0,0,196,1,0,0,197,1,0,0,198,1,0,0,199,1,0,0,200,1,0,0,201,1,0,0,202,1,0,0,203,1,0,0,204,1,0,0,205,1,0,0,206,1,0,0,207,1,0,0,208,1,0,0,209,1,0,0,7,10,0,0,8,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,255,255,255,248,255,255,255,248,255,255,255,248,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,164,255,255,255,164,255,255,255,164,255,255,255,164,255,255,255,164,255,255,255,164,255,255,255,0,0,0,0,164,255,255,255,40,107,0,0,8,0,0,0,9,10,0,0,10,10,0,0,214,1,0,0,215,1,0,0,216,1,0,0,217,1,0,0,218,1,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,219,1,0,0,220,1,0,0,221,1,0,0,222,1,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,80,24,1,0,72,107,0,0,216,109,0,0,96,112,0,0,252,112,0,0,244,113,0,0,144,114,0,0,44,115,0,0,36,116,0,0,204,110,0,0,196,111,0,0,48,110,0,0,68,108,0,0,60,109,0,0,168,107,0,0,76,25,1,0,68,26,1,0,176,24,1,0,32,117,0,0,24,118,0,0,60,27,1,0,252,12,0,0,84,14,0,0,148,28,1,0,56,0,0,0,0,0,0,0,168,118,0,0,11,10,0,0,12,10,0,0,116,0,0,0,117,0,0,0,118,0,0,0,235,2,0,0,236,2,0,0,121,0,0,0,122,0,0,0,123,0,0,0,124,0,0,0,125,0,0,0,126,0,0,0,127,0,0,0,128,0,0,0,129,0,0,0,130,0,0,0,131,0,0,0,132,0,0,0,133,0,0,0,134,0,0,0,135,0,0,0,136,0,0,0,137,0,0,0,138,0,0,0,139,0,0,0,140,0,0,0,237,2,0,0,13,10,0,0,143,0,0,0,144,0,0,0,145,0,0,0,146,0,0,0,223,2,0,0,148,0,0,0,149,0,0,0,150,0,0,0,151,0,0,0,152,0,0,0,153,0,0,0,154,0,0,0,155,0,0,0,156,0,0,0,157,0,0,0,158,0,0,0,159,0,0,0,160,0,0,0,161,0,0,0,162,0,0,0,163,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,255,255,255,200,255,255,255,0,0,0,0,0,0,0,0,200,255,255,255,200,255,255,255,200,255,255,255,200,255,255,255,200,255,255,255,200,255,255,255,0,0,0,0,200,255,255,255,168,118,0,0,8,0,0,0,14,10,0,0,15,10,0,0,166,0,0,0,167,0,0,0,168,0,0,0,240,2,0,0,241,2,0,0,16,0,0,0,17,0,0,0,171,0,0,0,172,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,0,0,0,0,184,118,0,0,1,0,0,0,16,10,0,0,17,10,0,0,18,10,0,0,0,0,0,0,200,118,0,0,1,0,0,0,19,10,0,0,20,10,0,0,21,10,0,0,0,0,0,0,216,118,0,0,1,0,0,0,22,10,0,0,23,10,0,0,24,10,0,0,25,10,0,0,244,255,255,255,216,118,0,0,26,10,0,0,27,10,0,0,28,10,0,0,29,10,0,0,100,7,0,0,12,0,0,0,0,0,0,0,240,122,0,0,30,10,0,0,31,10,0,0,32,10,0,0,244,255,255,255,0,0,0,0,244,255,255,255,240,122,0,0,1,0,0,0,33,10,0,0,34,10,0,0,148,0,0,0,0,0,0,0,224,122,0,0,35,10,0,0,36,10,0,0,116,0,0,0,117,0,0,0,118,0,0,0,37,10,0,0,38,10,0,0,121,0,0,0,122,0,0,0,123,0,0,0,124,0,0,0,125,0,0,0,126,0,0,0,127,0,0,0,128,0,0,0,129,0,0,0,130,0,0,0,131,0,0,0,132,0,0,0,133,0,0,0,134,0,0,0,135,0,0,0,136,0,0,0,137,0,0,0,138,0,0,0,39,10,0,0,140,0,0,0,211,3,0,0,142,0,0,0,143,0,0,0,144,0,0,0,145,0,0,0,146,0,0,0,223,2,0,0,148,0,0,0,149,0,0,0,150,0,0,0,151,0,0,0,152,0,0,0,153,0,0,0,154,0,0,0,155,0,0,0,156,0,0,0,157,0,0,0,158,0,0,0,159,0,0,0,160,0,0,0,161,0,0,0,162,0,0,0,163,0,0,0,212,3,0,0,40,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,108,255,255,255,108,255,255,255,0,0,0,0,0,0,0,0,108,255,255,255,108,255,255,255,108,255,255,255,108,255,255,255,108,255,255,255,108,255,255,255,0,0,0,0,108,255,255,255,224,122,0,0,8,0,0,0,41,10,0,0,42,10,0,0,166,0,0,0,167,0,0,0,168,0,0,0,43,10,0,0,44,10,0,0,16,0,0,0,17,0,0,0,171,0,0,0,172,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,200,29,1,0,4,119,0,0,252,120,0,0,84,122,0,0,100,120,0,0,40,31,1,0,0,0,0,0,24,123,0,0,1,0,0,0,45,10,0,0,46,10,0,0,47,10,0,0,48,10,0,0,49,10,0,0,50,10,0,0,51,10,0,0,52,10,0,0,53,10,0,0,54,10,0,0,55,10,0,0,56,10,0,0,57,10,0,0,58,10,0,0,59,10,0,0,48,32,1,0,68,123,0,0,156,124,0,0,136,33,1,0,64,0,0,0,0,0,0,0,40,123,0,0,60,10,0,0,61,10,0,0,116,0,0,0,117,0,0,0,118,0,0,0,62,10,0,0,63,10,0,0,121,0,0,0,122,0,0,0,123,0,0,0,124,0,0,0,125,0,0,0,126,0,0,0,127,0,0,0,128,0,0,0,129,0,0,0,130,0,0,0,131,0,0,0,132,0,0,0,133,0,0,0,134,0,0,0,135,0,0,0,136,0,0,0,137,0,0,0,138,0,0,0,139,0,0,0,140,0,0,0,237,2,0,0,142,0,0,0,143,0,0,0,144,0,0,0,145,0,0,0,146,0,0,0,223,2,0,0,148,0,0,0,149,0,0,0,150,0,0,0,151,0,0,0,152,0,0,0,153,0,0,0,154,0,0,0,155,0,0,0,156,0,0,0,157,0,0,0,158,0,0,0,159,0,0,0,64,10,0,0,161,0,0,0,162,0,0,0,163,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,192,255,255,255,0,0,0,0,0,0,0,0,192,255,255,255,192,255,255,255,192,255,255,255,192,255,255,255,192,255,255,255,192,255,255,255,0,0,0,0,192,255,255,255,40,123,0,0,8,0,0,0,65,10,0,0,66,10,0,0,166,0,0,0,167,0,0,0,168,0,0,0,67,10,0,0,68,10,0,0,16,0,0,0,17,0,0,0,171,0,0,0,172,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,0,0,0,0,40,125,0,0,1,0,0,0,69,10,0,0,70,10,0,0,0,0,0,0,72,125,0,0,1,0,0,0,71,10,0,0,72,10,0,0,73,10,0,0,74,10,0,0,75,10,0,0,76,10,0,0,77,10,0,0,78,10,0,0,79,10,0,0,116,34,1,0,116,125,0,0,204,126,0,0,204,35,1,0,68,0,0,0,0,0,0,0,88,125,0,0,80,10,0,0,81,10,0,0,116,0,0,0,117,0,0,0,118,0,0,0,82,10,0,0,83,10,0,0,121,0,0,0,122,0,0,0,123,0,0,0,124,0,0,0,125,0,0,0,126,0,0,0,127,0,0,0,128,0,0,0,129,0,0,0,130,0,0,0,131,0,0,0,132,0,0,0,133,0,0,0,134,0,0,0,135,0,0,0,136,0,0,0,137,0,0,0,138,0,0,0,139,0,0,0,140,0,0,0,237,2,0,0,142,0,0,0,143,0,0,0,144,0,0,0,145,0,0,0,146,0,0,0,223,2,0,0,148,0,0,0,149,0,0,0,150,0,0,0,151,0,0,0,152,0,0,0,153,0,0,0,154,0,0,0,155,0,0,0,156,0,0,0,157,0,0,0,158,0,0,0,159,0,0,0,84,10,0,0,161,0,0,0,162,0,0,0,163,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,188,255,255,255,188,255,255,255,0,0,0,0,0,0,0,0,188,255,255,255,188,255,255,255,188,255,255,255,188,255,255,255,188,255,255,255,188,255,255,255,0,0,0,0,188,255,255,255,88,125,0,0,8,0,0,0,85,10,0,0,86,10,0,0,166,0,0,0,167,0,0,0,168,0,0,0,87,10,0,0,88,10,0,0,16,0,0,0,17,0,0,0,171,0,0,0,172,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,0,0,0,0,104,127,0,0,1,0,0,0,89,10,0,0,90,10,0,0,91,10,0,0,92,10,0,0,244,255,255,255,104,127,0,0,93,10,0,0,94,10,0,0,95,10,0,0,96,10,0,0,100,7,0,0,0,0,0,0,136,127,0,0,1,0,0,0,97,10,0,0,98,10,0,0,99,10,0,0,100,10,0,0,101,10,0,0,102,10,0,0,103,10,0,0,104,10,0,0,105,10,0,0,0,0,0,0,152,127,0,0,1,0,0,0,106,10,0,0,107,10,0,0,0,0,0,0,200,127,0,0,1,0,0,0,108,10,0,0,109,10,0,0,0,0,0,0,184,127,0,0,1,0,0,0,110,10,0,0,111,10,0,0,0,0,0,0,216,127,0,0,1,0,0,0,112,10,0,0,113,10,0,0,0,0,0,0,248,127,0,0,1,0,0,0,114,10,0,0,115,10,0,0,0,0,0,0,8,128,0,0,1,0,0,0,116,10,0,0,117,10,0,0,0,0,0,0,40,128,0,0,118,10,0,0,119,10,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,0,0,0,0,24,128,0,0,118,10,0,0,120,10,0,0,121,10,0,0,122,10,0,0,123,10,0,0,124,10,0,0,0,0,0,0,48,128,0,0,118,10,0,0,125,10,0,0,126,10,0,0,127,10,0,0,128,10,0,0,129,10,0,0,0,0,0,0,64,128,0,0,118,10,0,0,130,10,0,0,131,10,0,0,132,10,0,0,133,10,0,0,134,10,0,0,0,0,0,0,80,128,0,0,118,10,0,0,135,10,0,0,136,10,0,0,137,10,0,0,138,10,0,0,139,10,0,0,0,0,0,0,96,128,0,0,118,10,0,0,140,10,0,0,141,10,0,0,142,10,0,0,143,10,0,0,144,10,0,0,0,0,0,0,112,128,0,0,118,10,0,0,145,10,0,0,146,10,0,0,147,10,0,0,148,10,0,0,149,10,0,0,0,0,0,0,128,128,0,0,1,0,0,0,150,10,0,0,151,10,0,0,0,0,0,0,160,128,0,0,1,0,0,0,152,10,0,0,153,10,0,0,0,0,0,0,176,128,0,0,1,0,0,0,154,10,0,0,155,10,0,0,156,10,0,0,157,10,0,0,158,10,0,0,159,10,0,0,160,10,0,0,161,10,0,0,162,10,0,0,163,10,0,0,164,10,0,0,165,10,0,0,166,10,0,0,167,10,0,0,168,10,0,0,108,163,2,0,124,163,2,0,128,163,2,0,147,163,2,0,151,163,2,0,167,163,2,0,171,163,2,0,94,215,2,0,189,163,2,0,212,163,2,0,215,163,2,0,234,163,2,0,237,163,2,0,1,164,2,0,5,164,2,0,30,164,2,0,34,164,2,0,53,164,2,0,56,164,2,0,79,164,2,0,82,164,2,0,107,164,2,0,110,164,2,0,126,164,2,0,130,164,2,0,148,164,2,0,152,164,2,0,171,164,2,0,175,164,2,0,171,164,2,0,195,164,2,0,30,164,2,0,224,164,2,0,30,164,2,0,240,164,2,0,3,165,2,0,7,165,2,0,17,165,2,0,21,165,2,0,38,165,2,0,42,165,2,0,52,165,2,0,56,165,2,0,70,165,2,0,74,165,2,0,86,165,2,0,89,165,2,0,99,165,2,0,103,165,2,0,113,165,2,0,117,165,2,0,128,165,2,0,132,165,2,0,148,165,2,0,152,165,2,0,165,165,2,0,152,165,2,0,169,165,2,0,176,165,2,0,187,165,2,0,191,165,2,0,128,165,2,0,203,165,2,0,213,165,2,0,217,165,2,0,228,165,2,0,232,165,2,0,243,165,2,0,247,165,2,0,124,163,2,0,5,166,2,0,19,166,2,0,23,166,2,0,19,166,2,0,41,166,2,0,64,166,2,0,67,166,2,0,88,166,2,0,91,166,2,0,110,166,2,0,115,166,2,0,130,166,2,0,134,166,2,0,144,166,2,0,148,166,2,0,38,165,2,0,167,166,2,0,124,163,2,0,179,166,2,0,192,166,2,0,196,166,2,0,207,166,2,0,211,166,2,0,223,166,2,0,227,166,2,0,240,166,2,0,244,166,2,0,0,167,2,0,4,167,2,0,17,167,2,0,21,167,2,0,31,167,2,0,35,167,2,0,59,167,2,0,63,167,2,0,87,167,2,0,91,167,2,0,116,167,2,0,120,167,2,0,116,167,2,0,145,167,2,0,169,167,2,0,173,167,2,0,191,167,2,0,195,167,2,0,207,167,2,0,211,167,2,0,228,165,2,0,224,167,2,0,17,165,2,0,244,167,2,0,144,166,2,0,4,168,2,0,144,166,2,0,16,168,2,0,31,167,2,0,32,168,2,0,44,168,2,0,48,168,2,0,44,168,2,0,68,168,2,0,83,168,2,0,87,168,2,0,98,168,2,0,102,168,2,0,3,165,2,0,116,168,2,0,171,164,2,0,127,168,2,0,139,168,2,0,143,168,2,0,160,168,2,0,165,168,2,0,183,168,2,0,189,168,2,0,30,164,2,0,205,168,2,0,221,168,2,0,225,168,2,0,235,168,2,0,239,168,2,0,255,168,2,0,3,169,2,0,12,169,2,0,15,169,2,0,25,169,2,0,29,169,2,0,38,169,2,0,41,169,2,0,52,169,2,0,56,169,2,0,235,168,2,0,70,169,2,0,86,169,2,0,89,169,2,0,99,169,2,0,103,169,2,0,114,169,2,0,118,169,2,0,141,169,2,0,144,169,2,0,114,169,2,0,159,169,2,0,172,169,2,0,176,169,2,0,196,169,2,0,200,169,2,0,220,169,2,0,224,169,2,0,249,169,2,0,253,169,2,0,12,169,2,0,8,170,2,0,19,170,2,0,22,170,2,0,25,169,2,0,34,170,2,0,38,169,2,0,45,170,2,0,61,170,2,0,65,170,2,0,85,170,2,0,90,170,2,0,103,170,2,0,107,170,2,0,122,170,2,0,126,170,2,0,141,170,2,0,145,170,2,0,167,170,2,0,171,170,2,0,235,168,2,0,187,170,2,0,199,170,2,0,203,170,2,0,215,170,2,0,219,170,2,0,237,170,2,0,243,170,2,0,4,171,2,0,8,171,2,0,20,171,2,0,24,171,2,0,34,171,2,0,38,171,2,0,53,171,2,0,57,171,2,0,71,171,2,0,75,171,2,0,171,164,2,0,90,171,2,0,104,171,2,0,91,97,3,0,0,0,0,0,208,128,0,0,93,6,0,0,169,10,0,0,170,10,0,0,171,10,0,0,172,10,0,0,173,10,0,0,174,10,0,0,175,10,0,0,205,5,0,0,206,5,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,101,6,0,0,102,6,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,103,6,0,0,38,0,0,0,39,0,0,0,40,0,0,0,225,6,0,0,226,6,0,0,227,6,0,0,228,6,0,0,106,6,0,0,107,6,0,0,108,6,0,0,109,6,0,0,219,5,0,0,220,5,0,0,221,5,0,0,222,5,0,0,223,5,0,0,224,5,0,0,229,6,0,0,226,5,0,0,111,6,0,0,112,6,0,0,113,6,0,0,176,10,0,0,230,6,0,0,116,6,0,0,231,6,0,0,232,6,0,0,233,6,0,0,234,6,0,0,121,6,0,0,235,6,0,0,236,6,0,0,237,6,0,0,238,6,0,0,239,6,0,0,240,6,0,0,241,6,0,0,242,6,0,0,243,6,0,0,1,0,0,0,177,10,0,0,44,172,2,0,14,0,0,0,4,0,0,0,4,32,54,22,4,32,118,22,4,24,22,22,4,24,86,22,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,4,24,22,22,4,24,22,22,0,2,0,0,0,0,0,0,178,10,0,0,4,24,22,22,4,24,22,22,112,0,0,0,0,0,0,0,179,10,0,0,4,24,22,22,4,24,22,22,112,2,0,0,0,0,0,0,180,10,0,0,4,24,22,22,4,24,22,22,3,0,0,0,0,0,0,0,181,10,0,0,4,24,22,22,4,24,22,22,3,2,0,0,0,0,0,0,182,10,0,0,4,24,22,22,4,24,22,22,115,0,0,0,0,0,0,0,183,10,0,0,4,24,22,22,4,24,22,22,115,2,0,0,0,0,0,0,184,10,0,0,4,24,22,22,4,24,86,22,0,2,0,0,0,0,0,0,185,10,0,0,4,24,22,22,4,24,86,22,112,0,0,0,0,0,0,0,186,10,0,0,4,24,22,22,4,24,86,22,112,2,0,0,0,0,0,0,187,10,0,0,4,24,22,22,4,24,86,22,3,0,0,0,0,0,0,0,188,10,0,0,4,24,22,22,4,24,86,22,3,2,0,0,0,0,0,0,189,10,0,0,4,24,22,22,4,24,86,22,115,0,0,0,0,0,0,0,190,10,0,0,4,24,22,22,4,24,86,22,115,2,0,0,0,0,0,0,191,10,0,0,4,24,22,22,4,32,54,22,0,2,0,0,0,0,0,0,192,10,0,0,4,24,22,22,4,32,54,22,112,0,0,0,0,0,0,0,193,10,0,0,4,24,22,22,4,32,54,22,112,2,0,0,0,0,0,0,194,10,0,0,4,24,22,22,4,32,54,22,3,0,0,0,0,0,0,0,195,10,0,0,4,24,22,22,4,32,54,22,3,2,0,0,0,0,0,0,196,10,0,0,4,24,22,22,4,32,54,22,115,0,0,0,0,0,0,0,197,10,0,0,4,24,22,22,4,32,54,22,115,2,0,0,0,0,0,0,198,10,0,0,4,24,86,22,4,24,22,22,0,2,0,0,0,0,0,0,199,10,0,0,4,24,86,22,4,24,22,22,112,0,0,0,0,0,0,0,200,10,0,0,4,24,86,22,4,24,22,22,112,2,0,0,0,0,0,0,201,10,0,0,4,24,86,22,4,24,22,22,3,0,0,0,0,0,0,0,202,10,0,0,4,24,86,22,4,24,22,22,3,2,0,0,0,0,0,0,203,10,0,0,4,24,86,22,4,24,22,22,115,0,0,0,0,0,0,0,204,10,0,0,4,24,86,22,4,24,22,22,115,2,0,0,0,0,0,0,205,10,0,0,4,24,86,22,4,24,86,22,0,2,0,0,0,0,0,0,206,10,0,0,4,24,86,22,4,24,86,22,112,0,0,0,0,0,0,0,207,10,0,0,4,24,86,22,4,24,86,22,112,2,0,0,0,0,0,0,208,10,0,0,4,24,86,22,4,24,86,22,3,0,0,0,0,0,0,0,209,10,0,0,4,24,86,22,4,24,86,22,3,2,0,0,0,0,0,0,210,10,0,0,4,24,86,22,4,24,86,22,115,0,0,0,0,0,0,0,211,10,0,0,4,24,86,22,4,24,86,22,115,2,0,0,0,0,0,0,212,10,0,0,4,24,86,22,4,32,54,22,0,2,0,0,0,0,0,0,213,10,0,0,4,24,86,22,4,32,54,22,112,0,0,0,0,0,0,0,214,10,0,0,4,24,86,22,4,32,54,22,112,2,0,0,0,0,0,0,215,10,0,0,4,24,86,22,4,32,54,22,3,0,0,0,0,0,0,0,216,10,0,0,4,24,86,22,4,32,54,22,3,2,0,0,0,0,0,0,217,10,0,0,4,24,86,22,4,32,54,22,115,0,0,0,0,0,0,0,218,10,0,0,4,24,86,22,4,32,54,22,115,2,0,0,0,0,0,0,219,10,0,0,4,32,54,22,4,24,22,22,0,2,0,0,0,0,0,0,220,10,0,0,4,32,54,22,4,24,22,22,112,0,0,0,0,0,0,0,221,10,0,0,4,32,54,22,4,24,22,22,112,2,0,0,0,0,0,0,222,10,0,0,4,32,54,22,4,24,22,22,3,0,0,0,0,0,0,0,223,10,0,0,4,32,54,22,4,24,22,22,3,2,0,0,0,0,0,0,224,10,0,0,4,32,54,22,4,24,22,22,115,0,0,0,0,0,0,0,225,10,0,0,4,32,54,22,4,24,22,22,115,2,0,0,0,0,0,0,226,10,0,0,4,32,54,22,4,24,86,22,0,2,0,0,0,0,0,0,227,10,0,0,4,32,54,22,4,24,86,22,112,0,0,0,0,0,0,0,228,10,0,0,4,32,54,22,4,24,86,22,112,2,0,0,0,0,0,0,229,10,0,0,4,32,54,22,4,24,86,22,3,0,0,0,0,0,0,0,230,10,0,0,4,32,54,22,4,24,86,22,3,2,0,0,0,0,0,0,231,10,0,0,4,32,54,22,4,24,86,22,115,0,0,0,0,0,0,0,232,10,0,0,4,32,54,22,4,24,86,22,115,2,0,0,0,0,0,0,233,10,0,0,4,32,54,22,4,32,54,22,0,2,0,0,0,0,0,0,234,10,0,0,4,32,54,22,4,32,54,22,112,0,0,0,0,0,0,0,235,10,0,0,4,32,54,22,4,32,54,22,112,2,0,0,0,0,0,0,236,10,0,0,4,32,54,22,4,32,54,22,3,0,0,0,0,0,0,0,237,10,0,0,4,32,54,22,4,32,54,22,3,2,0,0,0,0,0,0,238,10,0,0,4,32,54,22,4,32,54,22,115,0,0,0,0,0,0,0,239,10,0,0,4,32,54,22,4,32,54,22,115,2,0,0,0,0,0,0,240,10,0,0,4,32,70,22,4,24,22,22,0,2,0,0,0,0,0,0,241,10,0,0,4,32,70,22,4,24,22,22,112,0,0,0,0,0,0,0,242,10,0,0,4,32,70,22,4,24,22,22,112,2,0,0,0,0,0,0,243,10,0,0,4,32,70,22,4,24,22,22,3,0,0,0,0,0,0,0,244,10,0,0,4,32,70,22,4,24,22,22,3,2,0,0,0,0,0,0,245,10,0,0,4,32,70,22,4,24,22,22,115,0,0,0,0,0,0,0,246,10,0,0,4,32,70,22,4,24,22,22,115,2,0,0,0,0,0,0,247,10,0,0,4,32,70,22,4,24,86,22,0,2,0,0,0,0,0,0,248,10,0,0,4,32,70,22,4,24,86,22,112,0,0,0,0,0,0,0,249,10,0,0,4,32,70,22,4,24,86,22,112,2,0,0,0,0,0,0,250,10,0,0,4,32,70,22,4,24,86,22,3,0,0,0,0,0,0,0,251,10,0,0,4,32,70,22,4,24,86,22,3,2,0,0,0,0,0,0,252,10,0,0,4,32,70,22,4,24,86,22,115,0,0,0,0,0,0,0,253,10,0,0,4,32,70,22,4,24,86,22,115,2,0,0,0,0,0,0,254,10,0,0,4,32,70,22,4,32,54,22,0,2,0,0,0,0,0,0,255,10,0,0,4,32,70,22,4,32,54,22,112,0,0,0,0,0,0,0,0,11,0,0,4,32,70,22,4,32,54,22,112,2,0,0,0,0,0,0,1,11,0,0,4,32,70,22,4,32,54,22,3,0,0,0,0,0,0,0,2,11,0,0,4,32,70,22,4,32,54,22,3,2,0,0,0,0,0,0,3,11,0,0,4,32,70,22,4,32,54,22,115,0,0,0,0,0,0,0,4,11,0,0,4,32,70,22,4,32,54,22,115,2,0,0,0,0,0,0,5,11,0,0,4,32,118,22,4,24,22,22,0,2,0,0,0,0,0,0,6,11,0,0,4,32,118,22,4,24,22,22,112,0,0,0,0,0,0,0,7,11,0,0,4,32,118,22,4,24,22,22,112,2,0,0,0,0,0,0,8,11,0,0,4,32,118,22,4,24,22,22,3,0,0,0,0,0,0,0,9,11,0,0,4,32,118,22,4,24,22,22,3,2,0,0,0,0,0,0,10,11,0,0,4,32,118,22,4,24,22,22,115,0,0,0,0,0,0,0,11,11,0,0,4,32,118,22,4,24,22,22,115,2,0,0,0,0,0,0,12,11,0,0,4,32,118,22,4,24,86,22,0,2,0,0,0,0,0,0,13,11,0,0,4,32,118,22,4,24,86,22,112,0,0,0,0,0,0,0,14,11,0,0,4,32,118,22,4,24,86,22,112,2,0,0,0,0,0,0,15,11,0,0,4,32,118,22,4,24,86,22,3,0,0,0,0,0,0,0,16,11,0,0,4,32,118,22,4,24,86,22,3,2,0,0,0,0,0,0,17,11,0,0,4,32,118,22,4,24,86,22,115,0,0,0,0,0,0,0,18,11,0,0,4,32,118,22,4,24,86,22,115,2,0,0,0,0,0,0,19,11,0,0,4,32,118,22,4,32,54,22,0,2,0,0,0,0,0,0,20,11,0,0,4,32,118,22,4,32,54,22,112,0,0,0,0,0,0,0,21,11,0,0,4,32,118,22,4,32,54,22,112,2,0,0,0,0,0,0,22,11,0,0,4,32,118,22,4,32,54,22,3,0,0,0,0,0,0,0,23,11,0,0,4,32,118,22,4,32,54,22,3,2,0,0,0,0,0,0,24,11,0,0,4,32,118,22,4,32,54,22,115,0,0,0,0,0,0,0,25,11,0,0,4,32,118,22,4,32,54,22,115,2,0,0,0,0,0,0,26,11,0,0,4,32,134,22,4,24,22,22,0,2,0,0,0,0,0,0,27,11,0,0,4,32,134,22,4,24,22,22,112,0,0,0,0,0,0,0,28,11,0,0,4,32,134,22,4,24,22,22,112,2,0,0,0,0,0,0,29,11,0,0,4,32,134,22,4,24,22,22,3,0,0,0,0,0,0,0,30,11,0,0,4,32,134,22,4,24,22,22,3,2,0,0,0,0,0,0,31,11,0,0,4,32,134,22,4,24,22,22,115,0,0,0,0,0,0,0,32,11,0,0,4,32,134,22,4,24,22,22,115,2,0,0,0,0,0,0,33,11,0,0,4,32,134,22,4,24,86,22,0,2,0,0,0,0,0,0,34,11,0,0,4,32,134,22,4,24,86,22,112,0,0,0,0,0,0,0,35,11,0,0,4,32,134,22,4,24,86,22,112,2,0,0,0,0,0,0,36,11,0,0,4,32,134,22,4,24,86,22,3,0,0,0,0,0,0,0,37,11,0,0,4,32,134,22,4,24,86,22,3,2,0,0,0,0,0,0,38,11,0,0,4,32,134,22,4,24,86,22,115,0,0,0,0,0,0,0,39,11,0,0,4,32,134,22,4,24,86,22,115,2,0,0,0,0,0,0,40,11,0,0,4,32,134,22,4,32,54,22,0,2,0,0,0,0,0,0,41,11,0,0,4,32,134,22,4,32,54,22,112,0,0,0,0,0,0,0,42,11,0,0,4,32,134,22,4,32,54,22,112,2,0,0,0,0,0,0,43,11,0,0,4,32,134,22,4,32,54,22,3,0,0,0,0,0,0,0,44,11,0,0,4,32,134,22,4,32,54,22,3,2,0,0,0,0,0,0,45,11,0,0,4,32,134,22,4,32,54,22,115,0,0,0,0,0,0,0,46,11,0,0,4,32,134,22,4,32,54,22,115,2,0,0,0,0,0,0,47,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,183,174,2,0,183,175,2,0,55,176,2,0,119,176,2,0,151,176,2,0,167,176,2,0,175,176,2,0,179,176,2,0,181,176,2,0,255,255,255,255,164,53,1,0,204,53,1,0,148,54,1,0,188,54,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,11,0,0,0,0,0,0,0,248,0,0,224,7,0,0,31,0,0,0,4,0,0,0,0,0,255,0,0,255,0,0,255,0,0,0,0,0,0,0,49,11,0,0,7,0,0,0,0,248,0,0,224,7,0,0,31,0,0,0,4,0,0,0,255,0,0,0,0,255,0,0,0,0,255,0,0,0,0,0,50,11,0,0,7,0,0,0,0,248,0,0,224,7,0,0,31,0,0,0,4,0,0,0,0,0,0,255,0,0,255,0,0,255,0,0,0,0,0,0,51,11,0,0,7,0,0,0,0,248,0,0,224,7,0,0,31,0,0,0,4,0,0,0,0,255,0,0,0,0,255,0,0,0,0,255,0,0,0,0,52,11,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,11,0,0,0,0,0,0,0,0,255,0,0,255,0,0,255,0,0,0,2,0,0,0,0,248,0,0,224,7,0,0,31,0,0,0,0,0,0,0,53,11,0,0,1,0,0,0,0,0,255,0,0,255,0,0,255,0,0,0,2,0,0,0,0,124,0,0,224,3,0,0,31,0,0,0,0,0,0,0,54,11,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,11,0,0,0,0,0,0,0,0,0,0,255,0,0,0,0,0,0,8,255,0,32,0,0,0,0,16,255,0,64,0,0,0,0,24,255,0,97,0,0,0,0,32,255,0,129,0,0,0,0,41,255,0,161,0,0,0,0,49,255,0,194,0,0,0,0,57,255,0,226,0,0,0,0,65,255,8,0,0,0,0,0,74,255,8,32,0,0,0,0,82,255,8,64,0,0,0,0,90,255,8,97,0,0,0,0,98,255,8,129,0,0,0,0,106,255,8,161,0,0,0,0,115,255,8,194,0,0,0,0,123,255,8,226,0,0,0,0,131,255,16,0,0,0,0,0,139,255,16,32,0,0,0,0,148,255,16,64,0,0,0,0,156,255,16,97,0,0,0,0,164,255,16,129,0,0,0,0,172,255,16,161,0,0,0,0,180,255,16,194,0,0,0,0,189,255,16,226,0,0,0,0,197,255,24,0,0,0,0,0,205,255,24,32,0,0,0,0,213,255,24,64,0,0,0,0,222,255,24,97,0,0,0,0,230,255,24,129,0,0,0,0,238,255,24,161,0,0,0,0,246,255,24,194,0,0,0,0,255,255,24,226,0,0,0,4,0,255,32,0,0,0,0,4,8,255,32,32,0,0,0,4,16,255,32,64,0,0,0,4,24,255,32,97,0,0,0,4,32,255,32,129,0,0,0,4,41,255,32,161,0,0,0,4,49,255,32,194,0,0,0,4,57,255,32,226,0,0,0,4,65,255,41,0,0,0,0,4,74,255,41,32,0,0,0,4,82,255,41,64,0,0,0,4,90,255,41,97,0,0,0,4,98,255,41,129,0,0,0,4,106,255,41,161,0,0,0,4,115,255,41,194,0,0,0,4,123,255,41,226,0,0,0,4,131,255,49,0,0,0,0,4,139,255,49,32,0,0,0,4,148,255,49,64,0,0,0,4,156,255,49,97,0,0,0,4,164,255,49,129,0,0,0,4,172,255,49,161,0,0,0,4,180,255,49,194,0,0,0,4,189,255,49,226,0,0,0,4,197,255,57,0,0,0,0,4,205,255,57,32,0,0,0,4,213,255,57,64,0,0,0,4,222,255,57,97,0,0,0,4,230,255,57,129,0,0,0,4,238,255,57,161,0,0,0,4,246,255,57,194,0,0,0,4,255,255,57,226,0,0,0,8,0,255,65,0,0,0,0,8,8,255,65,32,0,0,0,8,16,255,65,64,0,0,0,8,24,255,65,97,0,0,0,8,32,255,65,129,0,0,0,8,41,255,65,161,0,0,0,8,49,255,65,194,0,0,0,8,57,255,65,226,0,0,0,8,65,255,74,0,0,0,0,8,74,255,74,32,0,0,0,8,82,255,74,64,0,0,0,8,90,255,74,97,0,0,0,8,98,255,74,129,0,0,0,8,106,255,74,161,0,0,0,8,115,255,74,194,0,0,0,8,123,255,74,226,0,0,0,8,131,255,82,0,0,0,0,8,139,255,82,32,0,0,0,8,148,255,82,64,0,0,0,8,156,255,82,97,0,0,0,8,164,255,82,129,0,0,0,8,172,255,82,161,0,0,0,8,180,255,82,194,0,0,0,8,189,255,82,226,0,0,0,8,197,255,90,0,0,0,0,8,205,255,90,32,0,0,0,8,213,255,90,64,0,0,0,8,222,255,90,97,0,0,0,8,230,255,90,129,0,0,0,8,238,255,90,161,0,0,0,8,246,255,90,194,0,0,0,8,255,255,90,226,0,0,0,12,0,255,98,0,0,0,0,12,8,255,98,32,0,0,0,12,16,255,98,64,0,0,0,12,24,255,98,97,0,0,0,12,32,255,98,129,0,0,0,12,41,255,98,161,0,0,0,12,49,255,98,194,0,0,0,12,57,255,98,226,0,0,0,12,65,255,106,0,0,0,0,12,74,255,106,32,0,0,0,12,82,255,106,64,0,0,0,12,90,255,106,97,0,0,0,12,98,255,106,129,0,0,0,12,106,255,106,161,0,0,0,12,115,255,106,194,0,0,0,12,123,255,106,226,0,0,0,12,131,255,115,0,0,0,0,12,139,255,115,32,0,0,0,12,148,255,115,64,0,0,0,12,156,255,115,97,0,0,0,12,164,255,115,129,0,0,0,12,172,255,115,161,0,0,0,12,180,255,115,194,0,0,0,12,189,255,115,226,0,0,0,12,197,255,123,0,0,0,0,12,205,255,123,32,0,0,0,12,213,255,123,64,0,0,0,12,222,255,123,97,0,0,0,12,230,255,123,129,0,0,0,12,238,255,123,161,0,0,0,12,246,255,123,194,0,0,0,12,255,255,123,226,0,0,0,16,0,255,131,0,0,0,0,16,8,255,131,32,0,0,0,16,16,255,131,64,0,0,0,16,24,255,131,97,0,0,0,16,32,255,131,129,0,0,0,16,41,255,131,161,0,0,0,16,49,255,131,194,0,0,0,16,57,255,131,226,0,0,0,16,65,255,139,0,0,0,0,16,74,255,139,32,0,0,0,16,82,255,139,64,0,0,0,16,90,255,139,97,0,0,0,16,98,255,139,129,0,0,0,16,106,255,139,161,0,0,0,16,115,255,139,194,0,0,0,16,123,255,139,226,0,0,0,16,131,255,148,0,0,0,0,16,139,255,148,32,0,0,0,16,148,255,148,64,0,0,0,16,156,255,148,97,0,0,0,16,164,255,148,129,0,0,0,16,172,255,148,161,0,0,0,16,180,255,148,194,0,0,0,16,189,255,148,226,0,0,0,16,197,255,156,0,0,0,0,16,205,255,156,32,0,0,0,16,213,255,156,64,0,0,0,16,222,255,156,97,0,0,0,16,230,255,156,129,0,0,0,16,238,255,156,161,0,0,0,16,246,255,156,194,0,0,0,16,255,255,156,226,0,0,0,20,0,255,164,0,0,0,0,20,8,255,164,32,0,0,0,20,16,255,164,64,0,0,0,20,24,255,164,97,0,0,0,20,32,255,164,129,0,0,0,20,41,255,164,161,0,0,0,20,49,255,164,194,0,0,0,20,57,255,164,226,0,0,0,20,65,255,172,0,0,0,0,20,74,255,172,32,0,0,0,20,82,255,172,64,0,0,0,20,90,255,172,97,0,0,0,20,98,255,172,129,0,0,0,20,106,255,172,161,0,0,0,20,115,255,172,194,0,0,0,20,123,255,172,226,0,0,0,20,131,255,180,0,0,0,0,20,139,255,180,32,0,0,0,20,148,255,180,64,0,0,0,20,156,255,180,97,0,0,0,20,164,255,180,129,0,0,0,20,172,255,180,161,0,0,0,20,180,255,180,194,0,0,0,20,189,255,180,226,0,0,0,20,197,255,189,0,0,0,0,20,205,255,189,32,0,0,0,20,213,255,189,64,0,0,0,20,222,255,189,97,0,0,0,20,230,255,189,129,0,0,0,20,238,255,189,161,0,0,0,20,246,255,189,194,0,0,0,20,255,255,189,226,0,0,0,24,0,255,197,0,0,0,0,24,8,255,197,32,0,0,0,24,16,255,197,64,0,0,0,24,24,255,197,97,0,0,0,24,32,255,197,129,0,0,0,24,41,255,197,161,0,0,0,24,49,255,197,194,0,0,0,24,57,255,197,226,0,0,0,24,65,255,205,0,0,0,0,24,74,255,205,32,0,0,0,24,82,255,205,64,0,0,0,24,90,255,205,97,0,0,0,24,98,255,205,129,0,0,0,24,106,255,205,161,0,0,0,24,115,255,205,194,0,0,0,24,123,255,205,226,0,0,0,24,131,255,213,0,0,0,0,24,139,255,213,32,0,0,0,24,148,255,213,64,0,0,0,24,156,255,213,97,0,0,0,24,164,255,213,129,0,0,0,24,172,255,213,161,0,0,0,24,180,255,213,194,0,0,0,24,189,255,213,226,0,0,0,24,197,255,222,0,0,0,0,24,205,255,222,32,0,0,0,24,213,255,222,64,0,0,0,24,222,255,222,97,0,0,0,24,230,255,222,129,0,0,0,24,238,255,222,161,0,0,0,24,246,255,222,194,0,0,0,24,255,255,222,226,0,0,0,28,0,255,230,0,0,0,0,28,8,255,230,32,0,0,0,28,16,255,230,64,0,0,0,28,24,255,230,97,0,0,0,28,32,255,230,129,0,0,0,28,41,255,230,161,0,0,0,28,49,255,230,194,0,0,0,28,57,255,230,226,0,0,0,28,65,255,238,0,0,0,0,28,74,255,238,32,0,0,0,28,82,255,238,64,0,0,0,28,90,255,238,97,0,0,0,28,98,255,238,129,0,0,0,28,106,255,238,161,0,0,0,28,115,255,238,194,0,0,0,28,123,255,238,226,0,0,0,28,131,255,246,0,0,0,0,28,139,255,246,32,0,0,0,28,148,255,246,64,0,0,0,28,156,255,246,97,0,0,0,28,164,255,246,129,0,0,0,28,172,255,246,161,0,0,0,28,180,255,246,194,0,0,0,28,189,255,246,226,0,0,0,28,197,255,255,0,0,0,0,28,205,255,255,32,0,0,0,28,213,255,255,64,0,0,0,28,222,255,255,97,0,0,0,28,230,255,255,129,0,0,0,28,238,255,255,161,0,0,0,28,246,255,255,194,0,0,0,28,255,255,255,226,0,255,0,0,0,0,0,0,0,255,8,0,0,0,0,32,0,255,16,0,0,0,0,64,0,255,24,0,0,0,0,97,0,255,32,0,0,0,0,129,0,255,41,0,0,0,0,161,0,255,49,0,0,0,0,194,0,255,57,0,0,0,0,226,0,255,65,0,0,0,0,0,8,255,74,0,0,0,0,32,8,255,82,0,0,0,0,64,8,255,90,0,0,0,0,97,8,255,98,0,0,0,0,129,8,255,106,0,0,0,0,161,8,255,115,0,0,0,0,194,8,255,123,0,0,0,0,226,8,255,131,0,0,0,0,0,16,255,139,0,0,0,0,32,16,255,148,0,0,0,0,64,16,255,156,0,0,0,0,97,16,255,164,0,0,0,0,129,16,255,172,0,0,0,0,161,16,255,180,0,0,0,0,194,16,255,189,0,0,0,0,226,16,255,197,0,0,0,0,0,24,255,205,0,0,0,0,32,24,255,213,0,0,0,0,64,24,255,222,0,0,0,0,97,24,255,230,0,0,0,0,129,24,255,238,0,0,0,0,161,24,255,246,0,0,0,0,194,24,255,255,0,0,0,0,226,24], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+71724);
/* memory initializer */ allocate([255,0,4,0,0,0,0,32,255,8,4,0,0,0,32,32,255,16,4,0,0,0,64,32,255,24,4,0,0,0,97,32,255,32,4,0,0,0,129,32,255,41,4,0,0,0,161,32,255,49,4,0,0,0,194,32,255,57,4,0,0,0,226,32,255,65,4,0,0,0,0,41,255,74,4,0,0,0,32,41,255,82,4,0,0,0,64,41,255,90,4,0,0,0,97,41,255,98,4,0,0,0,129,41,255,106,4,0,0,0,161,41,255,115,4,0,0,0,194,41,255,123,4,0,0,0,226,41,255,131,4,0,0,0,0,49,255,139,4,0,0,0,32,49,255,148,4,0,0,0,64,49,255,156,4,0,0,0,97,49,255,164,4,0,0,0,129,49,255,172,4,0,0,0,161,49,255,180,4,0,0,0,194,49,255,189,4,0,0,0,226,49,255,197,4,0,0,0,0,57,255,205,4,0,0,0,32,57,255,213,4,0,0,0,64,57,255,222,4,0,0,0,97,57,255,230,4,0,0,0,129,57,255,238,4,0,0,0,161,57,255,246,4,0,0,0,194,57,255,255,4,0,0,0,226,57,255,0,8,0,0,0,0,65,255,8,8,0,0,0,32,65,255,16,8,0,0,0,64,65,255,24,8,0,0,0,97,65,255,32,8,0,0,0,129,65,255,41,8,0,0,0,161,65,255,49,8,0,0,0,194,65,255,57,8,0,0,0,226,65,255,65,8,0,0,0,0,74,255,74,8,0,0,0,32,74,255,82,8,0,0,0,64,74,255,90,8,0,0,0,97,74,255,98,8,0,0,0,129,74,255,106,8,0,0,0,161,74,255,115,8,0,0,0,194,74,255,123,8,0,0,0,226,74,255,131,8,0,0,0,0,82,255,139,8,0,0,0,32,82,255,148,8,0,0,0,64,82,255,156,8,0,0,0,97,82,255,164,8,0,0,0,129,82,255,172,8,0,0,0,161,82,255,180,8,0,0,0,194,82,255,189,8,0,0,0,226,82,255,197,8,0,0,0,0,90,255,205,8,0,0,0,32,90,255,213,8,0,0,0,64,90,255,222,8,0,0,0,97,90,255,230,8,0,0,0,129,90,255,238,8,0,0,0,161,90,255,246,8,0,0,0,194,90,255,255,8,0,0,0,226,90,255,0,12,0,0,0,0,98,255,8,12,0,0,0,32,98,255,16,12,0,0,0,64,98,255,24,12,0,0,0,97,98,255,32,12,0,0,0,129,98,255,41,12,0,0,0,161,98,255,49,12,0,0,0,194,98,255,57,12,0,0,0,226,98,255,65,12,0,0,0,0,106,255,74,12,0,0,0,32,106,255,82,12,0,0,0,64,106,255,90,12,0,0,0,97,106,255,98,12,0,0,0,129,106,255,106,12,0,0,0,161,106,255,115,12,0,0,0,194,106,255,123,12,0,0,0,226,106,255,131,12,0,0,0,0,115,255,139,12,0,0,0,32,115,255,148,12,0,0,0,64,115,255,156,12,0,0,0,97,115,255,164,12,0,0,0,129,115,255,172,12,0,0,0,161,115,255,180,12,0,0,0,194,115,255,189,12,0,0,0,226,115,255,197,12,0,0,0,0,123,255,205,12,0,0,0,32,123,255,213,12,0,0,0,64,123,255,222,12,0,0,0,97,123,255,230,12,0,0,0,129,123,255,238,12,0,0,0,161,123,255,246,12,0,0,0,194,123,255,255,12,0,0,0,226,123,255,0,16,0,0,0,0,131,255,8,16,0,0,0,32,131,255,16,16,0,0,0,64,131,255,24,16,0,0,0,97,131,255,32,16,0,0,0,129,131,255,41,16,0,0,0,161,131,255,49,16,0,0,0,194,131,255,57,16,0,0,0,226,131,255,65,16,0,0,0,0,139,255,74,16,0,0,0,32,139,255,82,16,0,0,0,64,139,255,90,16,0,0,0,97,139,255,98,16,0,0,0,129,139,255,106,16,0,0,0,161,139,255,115,16,0,0,0,194,139,255,123,16,0,0,0,226,139,255,131,16,0,0,0,0,148,255,139,16,0,0,0,32,148,255,148,16,0,0,0,64,148,255,156,16,0,0,0,97,148,255,164,16,0,0,0,129,148,255,172,16,0,0,0,161,148,255,180,16,0,0,0,194,148,255,189,16,0,0,0,226,148,255,197,16,0,0,0,0,156,255,205,16,0,0,0,32,156,255,213,16,0,0,0,64,156,255,222,16,0,0,0,97,156,255,230,16,0,0,0,129,156,255,238,16,0,0,0,161,156,255,246,16,0,0,0,194,156,255,255,16,0,0,0,226,156,255,0,20,0,0,0,0,164,255,8,20,0,0,0,32,164,255,16,20,0,0,0,64,164,255,24,20,0,0,0,97,164,255,32,20,0,0,0,129,164,255,41,20,0,0,0,161,164,255,49,20,0,0,0,194,164,255,57,20,0,0,0,226,164,255,65,20,0,0,0,0,172,255,74,20,0,0,0,32,172,255,82,20,0,0,0,64,172,255,90,20,0,0,0,97,172,255,98,20,0,0,0,129,172,255,106,20,0,0,0,161,172,255,115,20,0,0,0,194,172,255,123,20,0,0,0,226,172,255,131,20,0,0,0,0,180,255,139,20,0,0,0,32,180,255,148,20,0,0,0,64,180,255,156,20,0,0,0,97,180,255,164,20,0,0,0,129,180,255,172,20,0,0,0,161,180,255,180,20,0,0,0,194,180,255,189,20,0,0,0,226,180,255,197,20,0,0,0,0,189,255,205,20,0,0,0,32,189,255,213,20,0,0,0,64,189,255,222,20,0,0,0,97,189,255,230,20,0,0,0,129,189,255,238,20,0,0,0,161,189,255,246,20,0,0,0,194,189,255,255,20,0,0,0,226,189,255,0,24,0,0,0,0,197,255,8,24,0,0,0,32,197,255,16,24,0,0,0,64,197,255,24,24,0,0,0,97,197,255,32,24,0,0,0,129,197,255,41,24,0,0,0,161,197,255,49,24,0,0,0,194,197,255,57,24,0,0,0,226,197,255,65,24,0,0,0,0,205,255,74,24,0,0,0,32,205,255,82,24,0,0,0,64,205,255,90,24,0,0,0,97,205,255,98,24,0,0,0,129,205,255,106,24,0,0,0,161,205,255,115,24,0,0,0,194,205,255,123,24,0,0,0,226,205,255,131,24,0,0,0,0,213,255,139,24,0,0,0,32,213,255,148,24,0,0,0,64,213,255,156,24,0,0,0,97,213,255,164,24,0,0,0,129,213,255,172,24,0,0,0,161,213,255,180,24,0,0,0,194,213,255,189,24,0,0,0,226,213,255,197,24,0,0,0,0,222,255,205,24,0,0,0,32,222,255,213,24,0,0,0,64,222,255,222,24,0,0,0,97,222,255,230,24,0,0,0,129,222,255,238,24,0,0,0,161,222,255,246,24,0,0,0,194,222,255,255,24,0,0,0,226,222,255,0,28,0,0,0,0,230,255,8,28,0,0,0,32,230,255,16,28,0,0,0,64,230,255,24,28,0,0,0,97,230,255,32,28,0,0,0,129,230,255,41,28,0,0,0,161,230,255,49,28,0,0,0,194,230,255,57,28,0,0,0,226,230,255,65,28,0,0,0,0,238,255,74,28,0,0,0,32,238,255,82,28,0,0,0,64,238,255,90,28,0,0,0,97,238,255,98,28,0,0,0,129,238,255,106,28,0,0,0,161,238,255,115,28,0,0,0,194,238,255,123,28,0,0,0,226,238,255,131,28,0,0,0,0,246,255,139,28,0,0,0,32,246,255,148,28,0,0,0,64,246,255,156,28,0,0,0,97,246,255,164,28,0,0,0,129,246,255,172,28,0,0,0,161,246,255,180,28,0,0,0,194,246,255,189,28,0,0,0,226,246,255,197,28,0,0,0,0,255,255,205,28,0,0,0,32,255,255,213,28,0,0,0,64,255,255,222,28,0,0,0,97,255,255,230,28,0,0,0,129,255,255,238,28,0,0,0,161,255,255,246,28,0,0,0,194,255,255,255,28,0,0,0,226,255,0,0,0,255,0,0,0,0,0,0,8,255,0,32,0,0,0,0,16,255,0,64,0,0,0,0,24,255,0,97,0,0,0,0,32,255,0,129,0,0,0,0,41,255,0,161,0,0,0,0,49,255,0,194,0,0,0,0,57,255,0,226,0,0,0,0,65,255,8,0,0,0,0,0,74,255,8,32,0,0,0,0,82,255,8,64,0,0,0,0,90,255,8,97,0,0,0,0,98,255,8,129,0,0,0,0,106,255,8,161,0,0,0,0,115,255,8,194,0,0,0,0,123,255,8,226,0,0,0,0,131,255,16,0,0,0,0,0,139,255,16,32,0,0,0,0,148,255,16,64,0,0,0,0,156,255,16,97,0,0,0,0,164,255,16,129,0,0,0,0,172,255,16,161,0,0,0,0,180,255,16,194,0,0,0,0,189,255,16,226,0,0,0,0,197,255,24,0,0,0,0,0,205,255,24,32,0,0,0,0,213,255,24,64,0,0,0,0,222,255,24,97,0,0,0,0,230,255,24,129,0,0,0,0,238,255,24,161,0,0,0,0,246,255,24,194,0,0,0,0,255,255,24,226,0,0,0,4,0,255,32,0,0,0,0,4,8,255,32,32,0,0,0,4,16,255,32,64,0,0,0,4,24,255,32,97,0,0,0,4,32,255,32,129,0,0,0,4,41,255,32,161,0,0,0,4,49,255,32,194,0,0,0,4,57,255,32,226,0,0,0,4,65,255,41,0,0,0,0,4,74,255,41,32,0,0,0,4,82,255,41,64,0,0,0,4,90,255,41,97,0,0,0,4,98,255,41,129,0,0,0,4,106,255,41,161,0,0,0,4,115,255,41,194,0,0,0,4,123,255,41,226,0,0,0,4,131,255,49,0,0,0,0,4,139,255,49,32,0,0,0,4,148,255,49,64,0,0,0,4,156,255,49,97,0,0,0,4,164,255,49,129,0,0,0,4,172,255,49,161,0,0,0,4,180,255,49,194,0,0,0,4,189,255,49,226,0,0,0,4,197,255,57,0,0,0,0,4,205,255,57,32,0,0,0,4,213,255,57,64,0,0,0,4,222,255,57,97,0,0,0,4,230,255,57,129,0,0,0,4,238,255,57,161,0,0,0,4,246,255,57,194,0,0,0,4,255,255,57,226,0,0,0,8,0,255,65,0,0,0,0,8,8,255,65,32,0,0,0,8,16,255,65,64,0,0,0,8,24,255,65,97,0,0,0,8,32,255,65,129,0,0,0,8,41,255,65,161,0,0,0,8,49,255,65,194,0,0,0,8,57,255,65,226,0,0,0,8,65,255,74,0,0,0,0,8,74,255,74,32,0,0,0,8,82,255,74,64,0,0,0,8,90,255,74,97,0,0,0,8,98,255,74,129,0,0,0,8,106,255,74,161,0,0,0,8,115,255,74,194,0,0,0,8,123,255,74,226,0,0,0,8,131,255,82,0,0,0,0,8,139,255,82,32,0,0,0,8,148,255,82,64,0,0,0,8,156,255,82,97,0,0,0,8,164,255,82,129,0,0,0,8,172,255,82,161,0,0,0,8,180,255,82,194,0,0,0,8,189,255,82,226,0,0,0,8,197,255,90,0,0,0,0,8,205,255,90,32,0,0,0,8,213,255,90,64,0,0,0,8,222,255,90,97,0,0,0,8,230,255,90,129,0,0,0,8,238,255,90,161,0,0,0,8,246,255,90,194,0,0,0,8,255,255,90,226,0,0,0,12,0,255,98,0,0,0,0,12,8,255,98,32,0,0,0,12,16,255,98,64,0,0,0,12,24,255,98,97,0,0,0,12,32,255,98,129,0,0,0,12,41,255,98,161,0,0,0,12,49,255,98,194,0,0,0,12,57,255,98,226,0,0,0,12,65,255,106,0,0,0,0,12,74,255,106,32,0,0,0,12,82,255,106,64,0,0,0,12,90,255,106,97,0,0,0,12,98,255,106,129,0,0,0,12,106,255,106,161,0,0,0,12,115,255,106,194,0,0,0,12,123,255,106,226,0,0,0,12,131,255,115,0,0,0,0,12,139,255,115,32,0,0,0,12,148,255,115,64,0,0,0,12,156,255,115,97,0,0,0,12,164,255,115,129,0,0,0,12,172,255,115,161,0,0,0,12,180,255,115,194,0,0,0,12,189,255,115,226,0,0,0,12,197,255,123,0,0,0,0,12,205,255,123,32,0,0,0,12,213,255,123,64,0,0,0,12,222,255,123,97,0,0,0,12,230,255,123,129,0,0,0,12,238,255,123,161,0,0,0,12,246,255,123,194,0,0,0,12,255,255,123,226,0,0,0,16,0,255,131,0,0,0,0,16,8,255,131,32,0,0,0,16,16,255,131,64,0,0,0,16,24,255,131,97,0,0,0,16,32,255,131,129,0,0,0,16,41,255,131,161,0,0,0,16,49,255,131,194,0,0,0,16,57,255,131,226,0,0,0,16,65,255,139,0,0,0,0,16,74,255,139,32,0,0,0,16,82,255,139,64,0,0,0,16,90,255,139,97,0,0,0,16,98,255,139,129,0,0,0,16,106,255,139,161,0,0,0,16,115,255,139,194,0,0,0,16,123,255,139,226,0,0,0,16,131,255,148,0,0,0,0,16,139,255,148,32,0,0,0,16,148,255,148,64,0,0,0,16,156,255,148,97,0,0,0,16,164,255,148,129,0,0,0,16,172,255,148,161,0,0,0,16,180,255,148,194,0,0,0,16,189,255,148,226,0,0,0,16,197,255,156,0,0,0,0,16,205,255,156,32,0,0,0,16,213,255,156,64,0,0,0,16,222,255,156,97,0,0,0,16,230,255,156,129,0,0,0,16,238,255,156,161,0,0,0,16,246,255,156,194,0,0,0,16,255,255,156,226,0,0,0,20,0,255,164,0,0,0,0,20,8,255,164,32,0,0,0,20,16,255,164,64,0,0,0,20,24,255,164,97,0,0,0,20,32,255,164,129,0,0,0,20,41,255,164,161,0,0,0,20,49,255,164,194,0,0,0,20,57,255,164,226,0,0,0,20,65,255,172,0,0,0,0,20,74,255,172,32,0,0,0,20,82,255,172,64,0,0,0,20,90,255,172,97,0,0,0,20,98,255,172,129,0,0,0,20,106,255,172,161,0,0,0,20,115,255,172,194,0,0,0,20,123,255,172,226,0,0,0,20,131,255,180,0,0,0,0,20,139,255,180,32,0,0,0,20,148,255,180,64,0,0,0,20,156,255,180,97,0,0,0,20,164,255,180,129,0,0,0,20,172,255,180,161,0,0,0,20,180,255,180,194,0,0,0,20,189,255,180,226,0,0,0,20,197,255,189,0,0,0,0,20,205,255,189,32,0,0,0,20,213,255,189,64,0,0,0,20,222,255,189,97,0,0,0,20,230,255,189,129,0,0,0,20,238,255,189,161,0,0,0,20,246,255,189,194,0,0,0,20,255,255,189,226,0,0,0,24,0,255,197,0,0,0,0,24,8,255,197,32,0,0,0,24,16,255,197,64,0,0,0,24,24,255,197,97,0,0,0,24,32,255,197,129,0,0,0,24,41,255,197,161,0,0,0,24,49,255,197,194,0,0,0,24,57,255,197,226,0,0,0,24,65,255,205,0,0,0,0,24,74,255,205,32,0,0,0,24,82,255,205,64,0,0,0,24,90,255,205,97,0,0,0,24,98,255,205,129,0,0,0,24,106,255,205,161,0,0,0,24,115,255,205,194,0,0,0,24,123,255,205,226,0,0,0,24,131,255,213,0,0,0,0,24,139,255,213,32,0,0,0,24,148,255,213,64,0,0,0,24,156,255,213,97,0,0,0,24,164,255,213,129,0,0,0,24,172,255,213,161,0,0,0,24,180,255,213,194,0,0,0,24,189,255,213,226,0,0,0,24,197,255,222,0,0,0,0,24,205,255,222,32,0,0,0,24,213,255,222,64,0,0,0,24,222,255,222,97,0,0,0,24,230,255,222,129,0,0,0,24,238,255,222,161,0,0,0,24,246,255,222,194,0,0,0,24,255,255,222,226,0,0,0,28,0,255,230,0,0,0,0,28,8,255,230,32,0,0,0,28,16,255,230,64,0,0,0,28,24,255,230,97,0,0,0,28,32,255,230,129,0,0,0,28,41,255,230,161,0,0,0,28,49,255,230,194,0,0,0,28,57,255,230,226,0,0,0,28,65,255,238,0,0,0,0,28,74,255,238,32,0,0,0,28,82,255,238,64,0,0,0,28,90,255,238,97,0,0,0,28,98,255,238,129,0,0,0,28,106,255,238,161,0,0,0,28,115,255,238,194,0,0,0,28,123,255,238,226,0,0,0,28,131,255,246,0,0,0,0,28,139,255,246,32,0,0,0,28,148,255,246,64,0,0,0,28,156,255,246,97,0,0,0,28,164,255,246,129,0,0,0,28,172,255,246,161,0,0,0,28,180,255,246,194,0,0,0,28,189,255,246,226,0,0,0,28,197,255,255,0,0,0,0,28,205,255,255,32,0,0,0,28,213,255,255,64,0,0,0,28,222,255,255,97,0,0,0,28,230,255,255,129,0,0,0,28,238,255,255,161,0,0,0,28,246,255,255,194,0,0,0,28,255,255,255,226,0,0,0,0,0,0,0,0,0,255,8,0,0,0,0,32,0,255,16,0,0,0,0,64,0,255,24,0,0,0,0,97,0,255,32,0,0,0,0,129,0,255,41,0,0,0,0,161,0,255,49,0,0,0,0,194,0,255,57,0,0,0,0,226,0,255,65,0,0,0,0,0,8,255,74,0,0,0,0,32,8,255,82,0,0,0,0,64,8,255,90,0,0,0,0,97,8,255,98,0,0,0,0,129,8,255,106,0,0,0,0,161,8,255,115,0,0,0,0,194,8,255,123,0,0,0,0,226,8,255,131,0,0,0,0,0,16,255,139,0,0,0,0,32,16,255,148,0,0,0,0,64,16,255,156,0,0,0,0,97,16,255,164,0,0,0,0,129,16,255,172,0,0,0,0,161,16,255,180,0,0,0,0,194,16,255,189,0,0,0,0,226,16,255,197,0,0,0,0,0,24,255,205,0,0,0,0,32,24,255,213,0,0,0,0,64,24,255,222,0,0,0,0,97,24,255,230,0,0,0,0,129,24,255,238,0,0,0,0,161,24,255,246,0,0,0,0,194,24,255,255,0,0,0,0,226,24,255,0,4,0,0,0,0,32,255,8,4,0,0,0,32,32,255,16,4,0,0,0,64,32,255,24,4,0,0,0,97,32,255,32,4,0,0,0,129,32,255,41,4,0,0,0,161,32,255,49,4,0,0,0,194,32,255,57,4,0,0,0,226,32,255,65,4,0,0,0,0,41,255,74,4,0,0,0,32,41,255,82,4,0,0,0,64,41,255,90,4,0,0,0,97,41,255,98,4,0,0,0,129,41,255,106,4,0,0,0,161,41,255,115,4,0,0,0,194,41,255,123,4,0,0,0,226,41,255,131,4,0,0,0,0,49,255,139,4,0,0,0,32,49,255,148,4,0,0,0,64,49,255,156,4,0,0,0,97,49,255,164,4,0,0,0,129,49,255,172,4,0,0,0,161,49,255,180,4,0,0,0,194,49,255,189,4,0,0,0,226,49,255,197,4,0,0,0,0,57,255,205,4,0,0,0,32,57,255,213,4,0,0,0,64,57,255,222,4,0,0,0,97,57,255,230,4,0,0,0,129,57,255,238,4,0,0,0,161,57,255,246,4,0,0,0,194,57,255,255,4,0,0,0,226,57,255,0,8,0,0,0,0,65,255,8,8,0,0,0,32,65,255,16,8,0,0,0,64,65,255,24,8,0,0,0,97,65,255,32,8,0,0,0,129,65,255,41,8,0,0,0,161,65,255,49,8,0,0,0,194,65,255,57,8,0,0,0,226,65,255,65,8,0,0,0,0,74,255,74,8,0,0,0,32,74,255,82,8,0,0,0,64,74,255,90,8,0,0,0,97,74,255,98,8,0,0,0,129,74,255,106,8,0,0,0,161,74,255,115,8,0,0,0,194,74,255,123,8,0,0,0,226,74,255,131,8,0,0,0,0,82,255,139,8,0,0,0,32,82,255,148,8,0,0,0,64,82,255,156,8,0,0,0,97,82,255,164,8,0,0,0,129,82,255,172,8,0,0,0,161,82,255,180,8,0,0,0,194,82,255,189,8,0,0,0,226,82,255,197,8,0,0,0,0,90,255,205,8,0,0,0,32,90,255,213,8,0,0,0,64,90,255,222,8,0,0,0,97,90,255,230,8,0,0,0,129,90,255,238,8,0,0,0,161,90,255,246,8,0,0,0,194,90,255,255,8,0,0,0,226,90,255,0,12,0,0,0,0,98,255,8,12,0,0,0,32,98,255,16,12,0,0,0,64,98,255,24,12,0,0,0,97,98,255,32,12,0,0,0,129,98,255,41,12,0,0,0,161,98,255,49,12,0,0,0,194,98,255,57,12,0,0,0,226,98,255,65,12,0,0,0,0,106,255,74,12,0,0,0,32,106,255,82,12,0,0,0,64,106,255,90,12,0,0,0,97,106,255,98,12,0,0,0,129,106,255,106,12,0,0,0,161,106,255,115,12,0,0,0,194,106,255,123,12,0,0,0,226,106,255,131,12,0,0,0,0,115,255,139,12,0,0,0,32,115,255,148,12,0,0,0,64,115,255,156,12,0,0,0,97,115,255,164,12,0,0,0,129,115,255,172,12,0,0,0,161,115,255,180,12,0,0,0,194,115,255,189,12,0,0,0,226,115,255,197,12,0,0,0,0,123,255,205,12,0,0,0,32,123,255,213,12,0,0,0,64,123,255,222,12,0,0,0,97,123,255,230,12,0,0,0,129,123,255,238,12,0,0,0,161,123,255,246,12,0,0,0,194,123,255,255,12,0,0,0,226,123,255,0,16,0,0,0,0,131,255,8,16,0,0,0,32,131,255,16,16,0,0,0,64,131,255,24,16,0,0,0,97,131,255,32,16,0,0,0,129,131,255,41,16,0,0,0,161,131,255,49,16,0,0,0,194,131,255,57,16,0,0,0,226,131,255,65,16,0,0,0,0,139,255,74,16,0,0,0,32,139,255,82,16,0,0,0,64,139,255,90,16,0,0,0,97,139,255,98,16,0,0,0,129,139,255,106,16,0,0,0,161,139,255,115,16,0,0,0,194,139,255,123,16,0,0,0,226,139,255,131,16,0,0,0,0,148,255,139,16,0,0,0,32,148,255,148,16,0,0,0,64,148,255,156,16,0,0,0,97,148,255,164,16,0,0,0,129,148,255,172,16,0,0,0,161,148,255,180,16,0,0,0,194,148,255,189,16,0,0,0,226,148,255,197,16,0,0,0,0,156,255,205,16,0,0,0,32,156,255,213,16,0,0,0,64,156,255,222,16,0,0,0,97,156,255,230,16,0,0,0,129,156,255,238,16,0,0,0,161,156,255,246,16,0,0,0,194,156,255,255,16,0,0,0,226,156,255,0,20,0,0,0,0,164,255,8,20,0,0,0,32,164,255,16,20,0,0,0,64,164,255,24,20,0,0,0,97,164,255,32,20,0,0,0,129,164,255,41,20,0,0,0,161,164,255,49,20,0,0,0,194,164,255,57,20,0,0,0,226,164,255,65,20,0,0,0,0,172,255,74,20,0,0,0,32,172,255,82,20,0,0,0,64,172,255,90,20,0,0,0,97,172,255,98,20,0,0,0,129,172,255,106,20,0,0,0,161,172,255,115,20,0,0,0,194,172,255,123,20,0,0,0,226,172,255,131,20,0,0,0,0,180,255,139,20,0,0,0,32,180,255,148,20,0,0,0,64,180,255,156,20,0,0,0,97,180,255,164,20,0,0,0,129,180,255,172,20,0,0,0,161,180,255,180,20,0,0,0,194,180,255,189,20,0,0,0,226,180,255,197,20,0,0,0,0,189,255,205,20,0,0,0,32,189,255,213,20,0,0,0,64,189,255,222,20,0,0,0,97,189,255,230,20,0,0,0,129,189,255,238,20,0,0,0,161,189,255,246,20,0,0,0,194,189,255,255,20,0,0,0,226,189,255,0,24,0,0,0,0,197,255,8,24,0,0,0,32,197,255,16,24,0,0,0,64,197,255,24,24,0,0,0,97,197,255,32,24,0,0,0,129,197,255,41,24,0,0,0,161,197,255,49,24,0,0,0,194,197,255,57,24,0,0,0,226,197,255,65,24,0,0,0,0,205,255,74,24,0,0,0,32,205,255,82,24,0,0,0,64,205,255,90,24,0,0,0,97,205,255,98,24,0,0,0,129,205,255,106,24,0,0,0,161,205,255,115,24,0,0,0,194,205,255,123,24,0,0,0,226,205,255,131,24,0,0,0,0,213,255,139,24,0,0,0,32,213,255,148,24,0,0,0,64,213,255,156,24,0,0,0,97,213,255,164,24,0,0,0,129,213,255,172,24,0,0,0,161,213,255,180,24,0,0,0,194,213,255,189,24,0,0,0,226,213,255,197,24,0,0,0,0,222,255,205,24,0,0,0,32,222,255,213,24,0,0,0,64,222,255,222,24,0,0,0,97,222,255,230,24,0,0,0,129,222,255,238,24,0,0,0,161,222,255,246,24,0,0,0,194,222,255,255,24,0,0,0,226,222,255,0,28,0,0,0,0,230,255,8,28,0,0,0,32,230,255,16,28,0,0,0,64,230,255,24,28,0,0,0,97,230,255,32,28,0,0,0,129,230,255,41,28,0,0,0,161,230,255,49,28,0,0,0,194,230,255,57,28,0,0,0,226,230,255,65,28,0,0,0,0,238,255,74,28,0,0,0,32,238,255,82,28,0,0,0,64,238,255,90,28,0,0,0,97,238,255,98,28,0,0,0,129,238,255,106,28,0,0,0,161,238,255,115,28,0,0,0,194,238,255,123,28,0,0,0,226,238,255,131,28,0,0,0,0,246,255,139,28,0,0,0,32,246,255,148,28,0,0,0,64,246,255,156,28,0,0,0,97,246,255,164,28,0,0,0,129,246,255,172,28,0,0,0,161,246,255,180,28,0,0,0,194,246,255,189,28,0,0,0,226,246,255,197,28,0,0,0,0,255,255,205,28,0,0,0,32,255,255,213,28,0,0,0,64,255,255,222,28,0,0,0,97,255,255,230,28,0,0,0,129,255,255,238,28,0,0,0,161,255,255,246,28,0,0,0,194,255,255,255,28,0,0,0,226,255,255,0,0,0,0,55,11,0,0,56,11,0,0,57,11,0,0,58,11,0,0,0,0,0,0,59,11,0,0,60,11,0,0,61,11,0,0,62,11,0,0,0,0,0,0,63,11,0,0,64,11,0,0,65,11,0,0,66,11,0,0,0,0,0,0,67,11,0,0,68,11,0,0,69,11,0,0,70,11,0,0,71,11,0,0,72,11,0,0,73,11,0,0,74,11,0,0,1,0,0,0,244,89,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,228,89,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,212,89,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,116,89,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,116,89,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,116,89,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,132,89,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,132,89,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,132,89,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,148,89,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,148,89,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,148,89,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,164,89,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,164,89,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,164,89,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,180,89,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,180,89,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,180,89,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,196,89,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,180,89,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,164,89,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,148,89,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,132,89,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,116,89,1,0,0,0,0,0,0,0,0,0,0,0,0,0,48,139,0,0,255,255,255,255,51,1,0,0,245,179,2,0,48,139,0,0,255,255,255,255,117,1,0,0,40,181,2,0,48,139,0,0,255,255,255,255,87,1,0,0,157,182,2,0,48,139,0,0,255,255,255,255,251,0,0,0,244,183,2,0,48,139,0,0,255,255,255,255,121,0,0,0,239,184,2,0,49,139,0,0,255,255,255,255,51,2,0,0,104,185,2,0,48,139,0,0,255,255,255,255,151,2,0,0,155,187,2,0,48,139,0,0,255,255,255,255,58,2,0,0,50,190,2,0,48,139,0,0,255,255,255,255,58,2,0,0,108,192,2,0,75,11,0,0,4,0,0,0,6,0,0,0,3,0,0,0,0,0,0,0,147,197,2,0,155,197,2,0,161,197,2,0,166,197,2,0,171,197,2,0,177,197,2,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,76,11,0,0,209,247,2,0,9,0,0,0,8,0,0,0,4,32,54,22,4,32,118,22,4,32,70,22,4,32,134,22,4,24,22,22,4,24,86,22,2,16,21,21,2,15,19,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,217,244,2,0,234,205,2,0,77,11,0,0,78,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,155,0,0,0,0,0,0,0,0,0,0,0,117,0,0,0,0,0,0,0,42,0,0,0,43,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,0,0,0,0,0,0,0,0,0,0,0,225,0,0,0,224,0,0,0,226,0,0,0,72,0,0,0,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,44,0,0,0,75,0,0,0,78,0,0,0,77,0,0,0,74,0,0,0,80,0,0,0,82,0,0,0,79,0,0,0,81,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,73,0,0,0,76,0,0,0,0,0,0,0,39,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,0,0,0,0,51,0,0,0,0,0,0,0,46,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,9,0,0,0,10,0,0,0,11,0,0,0,12,0,0,0,13,0,0,0,14,0,0,0,15,0,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,227,0,0,0,0,0,0,0,101,0,0,0,0,0,0,0,0,0,0,0,98,0,0,0,89,0,0,0,90,0,0,0,91,0,0,0,92,0,0,0,93,0,0,0,94,0,0,0,95,0,0,0,96,0,0,0,97,0,0,0,85,0,0,0,87,0,0,0,0,0,0,0,86,0,0,0,99,0,0,0,84,0,0,0,58,0,0,0,59,0,0,0,60,0,0,0,61,0,0,0,62,0,0,0,63,0,0,0,64,0,0,0,65,0,0,0,66,0,0,0,67,0,0,0,68,0,0,0,69,0,0,0,104,0,0,0,105,0,0,0,106,0,0,0,107,0,0,0,108,0,0,0,109,0,0,0,110,0,0,0,111,0,0,0,112,0,0,0,113,0,0,0,114,0,0,0,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,83,0,0,0,71,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,45,0,0,0,129,0,0,0,128,0,0,0,2,1,0,0,3,1,0,0,0,0,0,0,5,1,0,0,0,0,0,0,6,1,0,0,129,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,51,0,0,0,46,0,0,0,54,0,0,0,45,0,0,0,55,0,0,0,56,0,0,0,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,47,0,0,0,49,0,0,0,48,0,0,0,52,0,0,0,244,1,0,0,217,244,2,0,146,219,2,0,79,11,0,0,0,0,0,0,133,242,2,0,147,240,2,0,80,11,0,0,81,11,0,0,177,241,2,0,182,241,2,0,82,11,0,0,1,0,0,0,133,242,2,0,139,242,2,0,83,11,0,0,1,0,0,0,92,94,1,0,108,94,1,0,60,94,1,0,0,0,0,0,172,90,1,0,76,94,1,0,0,0,0,0,36,43,1,0,84,90,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,97,0,0,0,98,0,0,0,99,0,0,0,100,0,0,0,101,0,0,0,102,0,0,0,103,0,0,0,104,0,0,0,105,0,0,0,106,0,0,0,107,0,0,0,108,0,0,0,109,0,0,0,110,0,0,0,111,0,0,0,112,0,0,0,113,0,0,0,114,0,0,0,115,0,0,0,116,0,0,0,117,0,0,0,118,0,0,0,119,0,0,0,120,0,0,0,121,0,0,0,122,0,0,0,49,0,0,0,50,0,0,0,51,0,0,0,52,0,0,0,53,0,0,0,54,0,0,0,55,0,0,0,56,0,0,0,57,0,0,0,48,0,0,0,13,0,0,0,27,0,0,0,8,0,0,0,9,0,0,0,32,0,0,0,45,0,0,0,61,0,0,0,91,0,0,0,93,0,0,0,92,0,0,0,35,0,0,0,59,0,0,0,39,0,0,0,96,0,0,0,44,0,0,0,46,0,0,0,47,0,0,0,57,0,0,64,58,0,0,64,59,0,0,64,60,0,0,64,61,0,0,64,62,0,0,64,63,0,0,64,64,0,0,64,65,0,0,64,66,0,0,64,67,0,0,64,68,0,0,64,69,0,0,64,70,0,0,64,71,0,0,64,72,0,0,64,73,0,0,64,74,0,0,64,75,0,0,64,127,0,0,0,77,0,0,64,78,0,0,64,79,0,0,64,80,0,0,64,81,0,0,64,82,0,0,64,83,0,0,64,84,0,0,64,85,0,0,64,86,0,0,64,87,0,0,64,88,0,0,64,89,0,0,64,90,0,0,64,91,0,0,64,92,0,0,64,93,0,0,64,94,0,0,64,95,0,0,64,96,0,0,64,97,0,0,64,98,0,0,64,99,0,0,64,0,0,0,0,101,0,0,64,102,0,0,64,103,0,0,64,104,0,0,64,105,0,0,64,106,0,0,64,107,0,0,64,108,0,0,64,109,0,0,64,110,0,0,64,111,0,0,64,112,0,0,64,113,0,0,64,114,0,0,64,115,0,0,64,116,0,0,64,117,0,0,64,118,0,0,64,119,0,0,64,120,0,0,64,121,0,0,64,122,0,0,64,123,0,0,64,124,0,0,64,125,0,0,64,126,0,0,64,127,0,0,64,128,0,0,64,129,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,133,0,0,64,134,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,153,0,0,64,154,0,0,64,155,0,0,64,156,0,0,64,157,0,0,64,158,0,0,64,159,0,0,64,160,0,0,64,161,0,0,64,162,0,0,64,163,0,0,64,164,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,0,0,64,177,0,0,64,178,0,0,64,179,0,0,64,180,0,0,64,181,0,0,64,182,0,0,64,183,0,0,64,184,0,0,64,185,0,0,64,186,0,0,64,187,0,0,64,188,0,0,64,189,0,0,64,190,0,0,64,191,0,0,64,192,0,0,64,193,0,0,64,194,0,0,64,195,0,0,64,196,0,0,64,197,0,0,64,198,0,0,64,199,0,0,64,200,0,0,64,201,0,0,64,202,0,0,64,203,0,0,64,204,0,0,64,205,0,0,64,206,0,0,64,207,0,0,64,208,0,0,64,209,0,0,64,210,0,0,64,211,0,0,64,212,0,0,64,213,0,0,64,214,0,0,64,215,0,0,64,216,0,0,64,217,0,0,64,218,0,0,64,219,0,0,64,220,0,0,64,221,0,0,64,0,0,0,0,0,0,0,0,224,0,0,64,225,0,0,64,226,0,0,64,227,0,0,64,228,0,0,64,229,0,0,64,230,0,0,64,231,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,64,2,1,0,64,3,1,0,64,4,1,0,64,5,1,0,64,6,1,0,64,7,1,0,64,8,1,0,64,9,1,0,64,10,1,0,64,11,1,0,64,12,1,0,64,13,1,0,64,14,1,0,64,15,1,0,64,16,1,0,64,17,1,0,64,18,1,0,64,19,1,0,64,20,1,0,64,21,1,0,64,22,1,0,64,23,1,0,64,24,1,0,64,25,1,0,64,26,1,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,11,0,0,0,0,0,0,0,0,0,0,119,253,2,0,0,0,0,0,1,0,0,0,125,253,2,0,0,0,0,0,2,0,0,0,131,253,2,0,2,0,0,0,3,0,0,0,137,253,2,0,1,0,0,0,4,0,0,0,144,253,2,0,0,6,0,0,1,6,0,0,2,6,0,0,3,6,0,0,4,6,0,0,5,6,0,0,6,6,0,0,2,0,0,192,3,0,0,192,4,0,0,192,5,0,0,192,6,0,0,192,7,0,0,192,8,0,0,192,9,0,0,192,10,0,0,192,11,0,0,192,12,0,0,192,13,0,0,192,14,0,0,192,15,0,0,192,16,0,0,192,17,0,0,192,18,0,0,192,19,0,0,192,20,0,0,192,21,0,0,192,22,0,0,192,23,0,0,192,24,0,0,192,25,0,0,192,26,0,0,192,27,0,0,192,28,0,0,192,29,0,0,192,30,0,0,192,31,0,0,192,0,0,0,179,1,0,0,195,2,0,0,195,3,0,0,195,4,0,0,195,5,0,0,195,6,0,0,195,7,0,0,195,8,0,0,195,9,0,0,195,10,0,0,195,11,0,0,195,12,0,0,195,13,0,0,211,14,0,0,195,15,0,0,195,0,0,12,187,1,0,12,195,2,0,12,195,3,0,12,195,4,0,12,211,204,103,1,0,5,0,0,0,0,0,0,0,0,0,0,0,85,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,86,11,0,0,87,11,0,0,74,89,3,0,0,4,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,255,255,255,255], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+81964);
/* memory initializer */ allocate([44,68,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,204,103,1,0,68,105,1,0,9,0,0,0,0,0,0,0,0,0,0,0,85,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,11,0,0,0,0,0,0,87,11,0,0,82,93,3,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,196,105,1,0,5,0,0,0,0,0,0,0,0,0,0,0,85,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,89,11,0,0,87,11,0,0,90,97,3,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,92,106,1,0,20,0,0,0,67,46,85,84,70,45,56,0,0,0,0,0,0,0,0,0,0,0,0,0,222,18,4,149,0,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,64,106,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,0,0,100,0,0,0,232,3,0,0,16,39,0,0,160,134,1,0,64,66,15,0,128,150,152,0,0,225,245,5,95,112,137,0,255,9,47,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,90,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,136,1,0,52,109,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,9,0,0,0,10,0,0,0,11,0,0,0,12,0,0,0,13,0,0,0,14,0,0,0,15,0,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,43,0,0,0,44,0,0,0,45,0,0,0,46,0,0,0,47,0,0,0,48,0,0,0,49,0,0,0,50,0,0,0,51,0,0,0,52,0,0,0,53,0,0,0,54,0,0,0,55,0,0,0,56,0,0,0,57,0,0,0,58,0,0,0,59,0,0,0,60,0,0,0,61,0,0,0,62,0,0,0,63,0,0,0,64,0,0,0,97,0,0,0,98,0,0,0,99,0,0,0,100,0,0,0,101,0,0,0,102,0,0,0,103,0,0,0,104,0,0,0,105,0,0,0,106,0,0,0,107,0,0,0,108,0,0,0,109,0,0,0,110,0,0,0,111,0,0,0,112,0,0,0,113,0,0,0,114,0,0,0,115,0,0,0,116,0,0,0,117,0,0,0,118,0,0,0,119,0,0,0,120,0,0,0,121,0,0,0,122,0,0,0,91,0,0,0,92,0,0,0,93,0,0,0,94,0,0,0,95,0,0,0,96,0,0,0,97,0,0,0,98,0,0,0,99,0,0,0,100,0,0,0,101,0,0,0,102,0,0,0,103,0,0,0,104,0,0,0,105,0,0,0,106,0,0,0,107,0,0,0,108,0,0,0,109,0,0,0,110,0,0,0,111,0,0,0,112,0,0,0,113,0,0,0,114,0,0,0,115,0,0,0,116,0,0,0,117,0,0,0,118,0,0,0,119,0,0,0,120,0,0,0,121,0,0,0,122,0,0,0,123,0,0,0,124,0,0,0,125,0,0,0,126,0,0,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,115,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,9,0,0,0,10,0,0,0,11,0,0,0,12,0,0,0,13,0,0,0,14,0,0,0,15,0,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,43,0,0,0,44,0,0,0,45,0,0,0,46,0,0,0,47,0,0,0,48,0,0,0,49,0,0,0,50,0,0,0,51,0,0,0,52,0,0,0,53,0,0,0,54,0,0,0,55,0,0,0,56,0,0,0,57,0,0,0,58,0,0,0,59,0,0,0,60,0,0,0,61,0,0,0,62,0,0,0,63,0,0,0,64,0,0,0,65,0,0,0,66,0,0,0,67,0,0,0,68,0,0,0,69,0,0,0,70,0,0,0,71,0,0,0,72,0,0,0,73,0,0,0,74,0,0,0,75,0,0,0,76,0,0,0,77,0,0,0,78,0,0,0,79,0,0,0,80,0,0,0,81,0,0,0,82,0,0,0,83,0,0,0,84,0,0,0,85,0,0,0,86,0,0,0,87,0,0,0,88,0,0,0,89,0,0,0,90,0,0,0,91,0,0,0,92,0,0,0,93,0,0,0,94,0,0,0,95,0,0,0,96,0,0,0,65,0,0,0,66,0,0,0,67,0,0,0,68,0,0,0,69,0,0,0,70,0,0,0,71,0,0,0,72,0,0,0,73,0,0,0,74,0,0,0,75,0,0,0,76,0,0,0,77,0,0,0,78,0,0,0,79,0,0,0,80,0,0,0,81,0,0,0,82,0,0,0,83,0,0,0,84,0,0,0,85,0,0,0,86,0,0,0,87,0,0,0,88,0,0,0,89,0,0,0,90,0,0,0,123,0,0,0,124,0,0,0,125,0,0,0,126,0,0,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,128,0,0,91,11,0,0,92,11,0,0,0,0,0,0,240,128,0,0,93,11,0,0,94,11,0,0,0,0,0,0,8,129,0,0,95,11,0,0,96,11,0,0,39,1,0,0,40,1,0,0,4,8,0,0,5,8,0,0,43,1,0,0,44,1,0,0,45,1,0,0,6,8,0,0,47,1,0,0,7,8,0,0,49,1,0,0,9,8,0,0,0,0,0,0,16,129,0,0,97,11,0,0,98,11,0,0,99,11,0,0,100,11,0,0,101,11,0,0,102,11,0,0,103,11,0,0,104,11,0,0,105,11,0,0,106,11,0,0,107,11,0,0,108,11,0,0,109,11,0,0,110,11,0,0,8,0,0,0,0,0,0,0,24,129,0,0,29,1,0,0,30,1,0,0,248,255,255,255,248,255,255,255,24,129,0,0,31,1,0,0,32,1,0,0,228,119,1,0,248,119,1,0,8,0,0,0,0,0,0,0,48,129,0,0,111,11,0,0,112,11,0,0,248,255,255,255,248,255,255,255,48,129,0,0,113,11,0,0,114,11,0,0,20,120,1,0,40,120,1,0,236,14,0,0,0,15,0,0,4,0,0,0,0,0,0,0,96,129,0,0,115,11,0,0,116,11,0,0,252,255,255,255,252,255,255,255,96,129,0,0,117,11,0,0,118,11,0,0,76,120,1,0,96,120,1,0,12,0,0,0,0,0,0,0,120,129,0,0,27,4,0,0,28,4,0,0,4,0,0,0,248,255,255,255,120,129,0,0,29,4,0,0,30,4,0,0,244,255,255,255,244,255,255,255,120,129,0,0,31,4,0,0,32,4,0,0,124,120,1,0,164,129,0,0,184,129,0,0,236,14,0,0,0,15,0,0,164,120,1,0,144,120,1,0,0,0,0,0,192,129,0,0,119,11,0,0,120,11,0,0,121,11,0,0,122,11,0,0,123,11,0,0,124,11,0,0,125,11,0,0,0,0,0,0,208,129,0,0,126,11,0,0,127,11,0,0,128,11,0,0,208,120,1,0,0,0,0,0,224,129,0,0,129,11,0,0,130,11,0,0,131,11,0,0,100,11,0,0,101,11,0,0,102,11,0,0,132,11,0,0,104,11,0,0,105,11,0,0,106,11,0,0,107,11,0,0,108,11,0,0,133,11,0,0,134,11,0,0,0,0,0,0,240,129,0,0,135,11,0,0,136,11,0,0,137,11,0,0,40,1,0,0,4,8,0,0,5,8,0,0,138,11,0,0,44,1,0,0,45,1,0,0,6,8,0,0,47,1,0,0,7,8,0,0,139,11,0,0,140,11,0,0,0,0,0,0,0,130,0,0,141,11,0,0,142,11,0,0,143,11,0,0,100,11,0,0,101,11,0,0,102,11,0,0,103,11,0,0,104,11,0,0,105,11,0,0,144,11,0,0,145,11,0,0,146,11,0,0,109,11,0,0,110,11,0,0,0,0,0,0,16,130,0,0,147,11,0,0,148,11,0,0,149,11,0,0,40,1,0,0,4,8,0,0,5,8,0,0,43,1,0,0,44,1,0,0,45,1,0,0,150,11,0,0,151,11,0,0,152,11,0,0,49,1,0,0,9,8,0,0,0,0,0,0,32,130,0,0,153,11,0,0,154,11,0,0,155,11,0,0,156,11,0,0,157,11,0,0,158,11,0,0,0,0,0,0,64,130,0,0,159,11,0,0,160,11,0,0,155,11,0,0,161,11,0,0,162,11,0,0,163,11,0,0,0,0,0,0,80,130,0,0,164,11,0,0,165,11,0,0,155,11,0,0,166,11,0,0,167,11,0,0,168,11,0,0,169,11,0,0,170,11,0,0,171,11,0,0,172,11,0,0,173,11,0,0,174,11,0,0,175,11,0,0,176,11,0,0,0,0,0,0,144,130,0,0,177,11,0,0,178,11,0,0,155,11,0,0,179,11,0,0,180,11,0,0,181,11,0,0,182,11,0,0,183,11,0,0,184,11,0,0,185,11,0,0,186,11,0,0,187,11,0,0,188,11,0,0,189,11,0,0,0,0,0,0,200,130,0,0,190,11,0,0,191,11,0,0,155,11,0,0,192,11,0,0,193,11,0,0,194,11,0,0,195,11,0,0,196,11,0,0,197,11,0,0,198,11,0,0,199,11,0,0,0,0,0,0,8,131,0,0,200,11,0,0,201,11,0,0,155,11,0,0,202,11,0,0,203,11,0,0,204,11,0,0,205,11,0,0,206,11,0,0,207,11,0,0,208,11,0,0,209,11,0,0,0,0,0,0,64,131,0,0,210,11,0,0,211,11,0,0,155,11,0,0,212,11,0,0,213,11,0,0,214,11,0,0,215,11,0,0,216,11,0,0,217,11,0,0,218,11,0,0,248,255,255,255,64,131,0,0,219,11,0,0,220,11,0,0,221,11,0,0,222,11,0,0,223,11,0,0,224,11,0,0,225,11,0,0,0,0,0,0,120,131,0,0,226,11,0,0,227,11,0,0,155,11,0,0,228,11,0,0,229,11,0,0,230,11,0,0,231,11,0,0,232,11,0,0,233,11,0,0,234,11,0,0,248,255,255,255,120,131,0,0,235,11,0,0,236,11,0,0,237,11,0,0,238,11,0,0,239,11,0,0,240,11,0,0,241,11,0,0,37,0,0,0,72,0,0,0,58,0,0,0,37,0,0,0,77,0,0,0,58,0,0,0,37,0,0,0,83,0,0,0,0,0,0,0,37,0,0,0,109,0,0,0,47,0,0,0,37,0,0,0,100,0,0,0,47,0,0,0,37,0,0,0,121,0,0,0,0,0,0,0,37,0,0,0,73,0,0,0,58,0,0,0,37,0,0,0,77,0,0,0,58,0,0,0,37,0,0,0,83,0,0,0,32,0,0,0,37,0,0,0,112,0,0,0,0,0,0,0,37,0,0,0,97,0,0,0,32,0,0,0,37,0,0,0,98,0,0,0,32,0,0,0,37,0,0,0,100,0,0,0,32,0,0,0,37,0,0,0,72,0,0,0,58,0,0,0,37,0,0,0,77,0,0,0,58,0,0,0,37,0,0,0,83,0,0,0,32,0,0,0,37,0,0,0,89,0,0,0,0,0,0,0,65,0,0,0,77,0,0,0,0,0,0,0,80,0,0,0,77,0,0,0,0,0,0,0,74,0,0,0,97,0,0,0,110,0,0,0,117,0,0,0,97,0,0,0,114,0,0,0,121,0,0,0,0,0,0,0,70,0,0,0,101,0,0,0,98,0,0,0,114,0,0,0,117,0,0,0,97,0,0,0,114,0,0,0,121,0,0,0,0,0,0,0,77,0,0,0,97,0,0,0,114,0,0,0,99,0,0,0,104,0,0,0,0,0,0,0,65,0,0,0,112,0,0,0,114,0,0,0,105,0,0,0,108,0,0,0,0,0,0,0,77,0,0,0,97,0,0,0,121,0,0,0,0,0,0,0,74,0,0,0,117,0,0,0,110,0,0,0,101,0,0,0,0,0,0,0,74,0,0,0,117,0,0,0,108,0,0,0,121,0,0,0,0,0,0,0,65,0,0,0,117,0,0,0,103,0,0,0,117,0,0,0,115,0,0,0,116,0,0,0,0,0,0,0,83,0,0,0,101,0,0,0,112,0,0,0,116,0,0,0,101,0,0,0,109,0,0,0,98,0,0,0,101,0,0,0,114,0,0,0,0,0,0,0,79,0,0,0,99,0,0,0,116,0,0,0,111,0,0,0,98,0,0,0,101,0,0,0,114,0,0,0,0,0,0,0,78,0,0,0,111,0,0,0,118,0,0,0,101,0,0,0,109,0,0,0,98,0,0,0,101,0,0,0,114,0,0,0,0,0,0,0,68,0,0,0,101,0,0,0,99,0,0,0,101,0,0,0,109,0,0,0,98,0,0,0,101,0,0,0,114,0,0,0,0,0,0,0,74,0,0,0,97,0,0,0,110,0,0,0,0,0,0,0,70,0,0,0,101,0,0,0,98,0,0,0,0,0,0,0,77,0,0,0,97,0,0,0,114,0,0,0,0,0,0,0,65,0,0,0,112,0,0,0,114,0,0,0,0,0,0,0,74,0,0,0,117,0,0,0,110,0,0,0,0,0,0,0,74,0,0,0,117,0,0,0,108,0,0,0,0,0,0,0,65,0,0,0,117,0,0,0,103,0,0,0,0,0,0,0,83,0,0,0,101,0,0,0,112,0,0,0,0,0,0,0,79,0,0,0,99,0,0,0,116,0,0,0,0,0,0,0,78,0,0,0,111,0,0,0,118,0,0,0,0,0,0,0,68,0,0,0,101,0,0,0,99,0,0,0,0,0,0,0,83,0,0,0,117,0,0,0,110,0,0,0,100,0,0,0,97,0,0,0,121,0,0,0,0,0,0,0,77,0,0,0,111,0,0,0,110,0,0,0,100,0,0,0,97,0,0,0,121,0,0,0,0,0,0,0,84,0,0,0,117,0,0,0,101,0,0,0,115,0,0,0,100,0,0,0,97,0,0,0,121,0,0,0,0,0,0,0,87,0,0,0,101,0,0,0,100,0,0,0,110,0,0,0,101,0,0,0,115,0,0,0,100,0,0,0,97,0,0,0,121,0,0,0,0,0,0,0,84,0,0,0,104,0,0,0,117,0,0,0,114,0,0,0,115,0,0,0,100,0,0,0,97,0,0,0,121,0,0,0,0,0,0,0,70,0,0,0,114,0,0,0,105,0,0,0,100,0,0,0,97,0,0,0,121,0,0,0,0,0,0,0,83,0,0,0,97,0,0,0,116,0,0,0,117,0,0,0,114,0,0,0,100,0,0,0,97,0,0,0,121,0,0,0,0,0,0,0,83,0,0,0,117,0,0,0,110,0,0,0,0,0,0,0,77,0,0,0,111,0,0,0,110,0,0,0,0,0,0,0,84,0,0,0,117,0,0,0,101,0,0,0,0,0,0,0,87,0,0,0,101,0,0,0,100,0,0,0,0,0,0,0,84,0,0,0,104,0,0,0,117,0,0,0,0,0,0,0,70,0,0,0,114,0,0,0,105,0,0,0,0,0,0,0,83,0,0,0,97,0,0,0,116,0,0,0,0,0,0,0,37,0,0,0,109,0,0,0,47,0,0,0,37,0,0,0,100,0,0,0,47,0,0,0,37,0,0,0,121,0,0,0,37,0,0,0,89,0,0,0,45,0,0,0,37,0,0,0,109,0,0,0,45,0,0,0,37,0,0,0,100,0,0,0,37,0,0,0,73,0,0,0,58,0,0,0,37,0,0,0,77,0,0,0,58,0,0,0,37,0,0,0,83,0,0,0,32,0,0,0,37,0,0,0,112,0,0,0,37,0,0,0,72,0,0,0,58,0,0,0,37,0,0,0,77,0,0,0,37,0,0,0,72,0,0,0,58,0,0,0,37,0,0,0,77,0,0,0,58,0,0,0,37,0,0,0,83,0,0,0,37,0,0,0,72,0,0,0,58,0,0,0,37,0,0,0,77,0,0,0,58,0,0,0,37,0,0,0,83,0,0,0,0,0,0,0,168,131,0,0,242,11,0,0,243,11,0,0,155,11,0,0,244,11,0,0,0,0,0,0,208,131,0,0,245,11,0,0,246,11,0,0,155,11,0,0,247,11,0,0,0,0,0,0,240,131,0,0,248,11,0,0,249,11,0,0,155,11,0,0,250,11,0,0,251,11,0,0,252,11,0,0,253,11,0,0,254,11,0,0,255,11,0,0,0,12,0,0,1,12,0,0,2,12,0,0,0,0,0,0,24,132,0,0,3,12,0,0,4,12,0,0,155,11,0,0,5,12,0,0,6,12,0,0,7,12,0,0,8,12,0,0,9,12,0,0,10,12,0,0,11,12,0,0,12,12,0,0,13,12,0,0,0,0,0,0,56,132,0,0,14,12,0,0,15,12,0,0,155,11,0,0,16,12,0,0,17,12,0,0,18,12,0,0,19,12,0,0,20,12,0,0,21,12,0,0,22,12,0,0,23,12,0,0,24,12,0,0,0,0,0,0,88,132,0,0,25,12,0,0,26,12,0,0,155,11,0,0,27,12,0,0,28,12,0,0,29,12,0,0,30,12,0,0,31,12,0,0,32,12,0,0,33,12,0,0,34,12,0,0,35,12,0,0,0,0,0,0,120,132,0,0,36,12,0,0,37,12,0,0,155,11,0,0,38,12,0,0,39,12,0,0,0,0,0,0,160,132,0,0,40,12,0,0,41,12,0,0,155,11,0,0,42,12,0,0,43,12,0,0,0,0,0,0,200,132,0,0,44,12,0,0,45,12,0,0,155,11,0,0,46,12,0,0,47,12,0,0,0,0,0,0,240,132,0,0,48,12,0,0,49,12,0,0,155,11,0,0,50,12,0,0,51,12,0,0,0,0,0,0,24,133,0,0,52,12,0,0,53,12,0,0,155,11,0,0,54,12,0,0,55,12,0,0,56,12,0,0,0,0,0,0,64,133,0,0,57,12,0,0,58,12,0,0,155,11,0,0,59,12,0,0,60,12,0,0,61,12,0,0,0,0,0,0,152,133,0,0,62,12,0,0,63,12,0,0,155,11,0,0,64,12,0,0,65,12,0,0,66,12,0,0,67,12,0,0,68,12,0,0,69,12,0,0,70,12,0,0,0,0,0,0,96,133,0,0,62,12,0,0,71,12,0,0,155,11,0,0,64,12,0,0,65,12,0,0,66,12,0,0,67,12,0,0,68,12,0,0,69,12,0,0,70,12,0,0,0,0,0,0,200,133,0,0,72,12,0,0,73,12,0,0,155,11,0,0,74,12,0,0,75,12,0,0,76,12,0,0,77,12,0,0,78,12,0,0,79,12,0,0,80,12,0,0,0,0,0,0,8,134,0,0,81,12,0,0,82,12,0,0,155,11,0,0,0,0,0,0,24,134,0,0,83,12,0,0,84,12,0,0,155,11,0,0,85,12,0,0,86,12,0,0,87,12,0,0,88,12,0,0,89,12,0,0,90,12,0,0,91,12,0,0,92,12,0,0,0,0,0,0,96,134,0,0,93,12,0,0,94,12,0,0,155,11,0,0,95,12,0,0,96,12,0,0,97,12,0,0,98,12,0,0,99,12,0,0,0,0,0,0,112,134,0,0,100,12,0,0,101,12,0,0,155,11,0,0,102,12,0,0,103,12,0,0,104,12,0,0,105,12,0,0,106,12,0,0,102,0,0,0,97,0,0,0,108,0,0,0,115,0,0,0,101,0,0,0,0,0,0,0,116,0,0,0,114,0,0,0,117,0,0,0,101,0,0,0,0,0,0,0,0,0,0,0,48,130,0,0,62,12,0,0,107,12,0,0,155,11,0,0,0,0,0,0,64,134,0,0,62,12,0,0,108,12,0,0,155,11,0,0,109,12,0,0,110,12,0,0,111,12,0,0,112,12,0,0,113,12,0,0,114,12,0,0,115,12,0,0,116,12,0,0,117,12,0,0,118,12,0,0,119,12,0,0,120,12,0,0,0,0,0,0,168,133,0,0,62,12,0,0,121,12,0,0,155,11,0,0,122,12,0,0,123,12,0,0,124,12,0,0,125,12,0,0,126,12,0,0,127,12,0,0,128,12,0,0,0,0,0,0,232,133,0,0,62,12,0,0,129,12,0,0,155,11,0,0,130,12,0,0,131,12,0,0,132,12,0,0,133,12,0,0,134,12,0,0,135,12,0,0,136,12,0,0,0,0,0,0,112,133,0,0,62,12,0,0,137,12,0,0,155,11,0,0,64,12,0,0,65,12,0,0,66,12,0,0,67,12,0,0,68,12,0,0,69,12,0,0,70,12,0,0,0,0,0,0,112,131,0,0,219,11,0,0,220,11,0,0,221,11,0,0,222,11,0,0,223,11,0,0,224,11,0,0,225,11,0,0,0,0,0,0,160,131,0,0,235,11,0,0,236,11,0,0,237,11,0,0,238,11,0,0,239,11,0,0,240,11,0,0,241,11,0,0,0,0,0,0,160,134,0,0,138,12,0,0,139,12,0,0,128,11,0,0,140,12,0,0,235,33,3,0,0,0,0,0,184,134,0,0,141,12,0,0,142,12,0,0,143,12,0,0,144,12,0,0,145,12,0,0,146,12,0,0,147,12,0,0,148,12,0,0,0,0,0,0,224,134,0,0,141,12,0,0,149,12,0,0,143,12,0,0,144,12,0,0,145,12,0,0,150,12,0,0,151,12,0,0,152,12,0,0,0,0,0,0,240,134,0,0,153,12,0,0,154,12,0,0,155,12,0,0,0,0,0,0,176,134,0,0,156,12,0,0,157,12,0,0,208,9,0,0,0,0,0,0,0,135,0,0,158,12,0,0,159,12,0,0,160,12,0,0,0,0,0,0,16,135,0,0,161,12,0,0,162,12,0,0,128,11,0,0,0,0,0,0,32,135,0,0,158,12,0,0,163,12,0,0,160,12,0,0,0,0,0,0,48,135,0,0,158,12,0,0,164,12,0,0,160,12,0,0,0,0,0,0,64,135,0,0,158,12,0,0,165,12,0,0,160,12,0,0,0,0,0,0,80,135,0,0,166,12,0,0,167,12,0,0,168,12,0,0,0,0,0,0,96,135,0,0,169,12,0,0,170,12,0,0,171,12,0,0,0,0,0,0,144,135,0,0,141,12,0,0,172,12,0,0,143,12,0,0,144,12,0,0,145,12,0,0,173,12,0,0,174,12,0,0,175,12,0,0,8,0,8,128,16,128,16,144,16,0,16,16,32,128,32,144,32,129,32,145,8,128,8,0,16,128,16,144,16,0,16,16,32,128,32,144,32,129,32,145,16,128,16,144,16,0,16,16,32,128,32,144,32,129,32,145,8,0,8,128,16,144,16,128,16,16,16,0,32,144,32,128,32,145,32,129,8,0,8,128,16,0,16,16,16,128,16,144,32,128,32,144,32,129,32,145,8,0,8,128,16,16,16,0,16,144,16,128,32,144,32,128,32,145,32,129,8,0,8,128,32,128,32,144,32,129,32,145,16,128,16,144,16,0,16,16,8,0,8,128,32,144,32,128,32,145,32,129,16,144,16,128,16,16,16,0,8,0,8,128,32,129,32,145,32,128,32,144,16,128,16,144,16,0,16,16,8,0,8,128,32,145,32,129,32,144,32,128,16,144,16,128,16,16,16,0,8,0,8,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,3,32,2,32,2,32,2,32,2,32,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,1,96,4,192,4,192,4,192,4,192,4,192,4,192,4,192,4,192,4,192,4,192,4,192,4,192,4,192,4,192,4,192,8,216,8,216,8,216,8,216,8,216,8,216,8,216,8,216,8,216,8,216,4,192,4,192,4,192,4,192,4,192,4,192,4,192,8,213,8,213,8,213,8,213,8,213,8,213,8,197,8,197,8,197,8,197,8,197,8,197,8,197,8,197,8,197,8,197,8,197,8,197,8,197,8,197,8,197,8,197,8,197,8,197,8,197,8,197,4,192,4,192,4,192,4,192,4,192,4,192,8,214,8,214,8,214,8,214,8,214,8,214,8,198,8,198,8,198,8,198,8,198,8,198,8,198,8,198,8,198,8,198,8,198,8,198,8,198,8,198,8,198,8,198,8,198,8,198,8,198,8,198,4,192,4,192,4,192,4,192,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,109,106,105,110,45,112,108,97,121,101,114,46,32,83,104,117,116,32,100,111,119,110,0,109,106,105,110,45,112,108,97,121,101,114,0,109,106,105,110,45,112,108,97,121,101,114,46,32,67,111,117,108,100,32,110,111,116,32,99,114,101,97,116,101,32,119,105,110,100,111,119,46,32,69,114,114,111,114,58,32,39,37,115,39,0,109,106,105,110,45,112,108,97,121,101,114,46,32,67,111,117,108,100,32,110,111,116,32,105,110,105,116,105,97,108,105,122,101,32,83,68,76,46,32,69,114,114,111,114,58,32,39,37,115,39,0,109,106,105,110,45,112,108,97,121,101,114,32,79,83,71,47,37,115,32,37,115,0,86,0,68,0,73,0,87,0,69,0,109,106,105,110,45,112,108,97,121,101,114,32,73,71,78,79,82,69,68,32,39,37,100,39,32,100,117,112,108,105,99,97,116,101,100,32,79,83,71,32,109,101,115,115,97,103,101,115,0,78,52,109,106,105,110,51,108,111,103,54,76,111,103,103,101,114,69,0,78,51,111,115,103,49,51,78,111,116,105,102,121,72,97,110,100,108,101,114,69,0,71,114,97,112,104,105,99,115,87,105,110,100,111,119,58,58,114,101,113,117,101,115,116,82,101,100,114,97,119,40,41,58,32,78,111,32,118,105,101,119,115,32,97,115,115,105,103,110,101,100,32,121,101,116,46,0,71,114,97,112,104,105,99,115,87,105,110,100,111,119,58,58,115,101,116,83,119,97,112,71,114,111,117,112,40,0,41,32,110,111,116,32,105,109,112,108,101,109,101,110,116,101,100,46,0,71,114,97,112,104,105,99,115,87,105,110,100,111,119,58,58,115,101,116,83,121,110,99,84,111,86,66,108,97,110,107,40,0,71,114,97,112,104,105,99,115,87,105,110,100,111,119,58,58,115,101,116,67,117,114,115,111,114,40,46,46,41,32,110,111,116,32,105,109,112,108,101,109,101,110,116,101,100,46,0,71,114,97,112,104,105,99,115,87,105,110,100,111,119,58,58,115,101,116,87,105,110,100,111,119,78,97,109,101,40,46,46,41,32,110,111,116,32,105,109,112,108,101,109,101,110,116,101,100,46,0,71,114,97,112,104,105,99,115,87,105,110,100,111,119,58,58,114,97,105,115,101,87,105,110,100,111,119,40,46,46,41,32,110,111,116,32,105,109,112,108,101,109,101,110,116,101,100,46,0,71,114,97,112,104,105,99,115,87,105,110,100,111,119,58,58,103,114,97,98,70,111,99,117,115,73,102,80,111,105,110,116,101,114,73,110,87,105,110,100,111,119,40,46,46,41,32,110,111,116,32,105,109,112,108,101,109,101,110,116,101,100,46,0,71,114,97,112,104,105,99,115,87,105,110,100,111,119,58,58,103,114,97,98,70,111,99,117,115,40,46,46,41,32,110,111,116,32,105,109,112,108,101,109,101,110,116,101,100,46,0,71,114,97,112,104,105,99,115,87,105,110,100,111,119,58,58,115,101,116,87,105,110,100,111,119,68,101,99,111,114,97,116,105,111,110,73,109,112,108,101,109,101,110,116,97,116,105,111,110,40,46,46,41,32,110,111,116,32,105,109,112,108,101,109,101,110,116,101,100,46,0,71,114,97,112,104,105,99,115,87,105,110,100,111,119,58,58,115,101,116,87,105,110,100,111,119,82,101,99,116,97,110,103,108,101,73,109,112,108,101,109,101,110,116,97,116,105,111,110,40,46,46,41,32,110,111,116,32,105,109,112,108,101,109,101,110,116,101,100,46,0,71,114,97,112,104,105,99,115,87,105,110,100,111,119,58,58,32,115,119,97,112,66,117,102,102,101,114,115,73,109,112,108,101,109,101,110,116,97,116,105,111,110,40,41,32,110,111,116,32,105,109,112,108,101,109,101,110,116,101,100,46,0,71,114,97,112,104,105,99,115,87,105,110,100,111,119,58,58,98,105,110,100,80,66,117,102,102,101,114,84,111,84,101,120,116,117,114,101,73,109,112,108,101,109,101,110,116,97,116,105,111,110,40,46,46,41,32,110,111,116,32,105,109,112,108,101,109,101,110,116,101,100,46,0,71,114,97,112,104,105,99,115,87,105,110,100,111,119,58,58,114,101,108,101,97,115,101,67,111,110,116,101,120,116,73,109,112,108,101,109,101,110,116,97,116,105,111,110,40,46,46,41,32,110,111,116,32,105,109,112,108,101,109,101,110,116,101,100,46,0,71,114,97,112,104,105,99,115,87,105,110,100,111,119,58,58,109,97,107,101,67,111,110,116,101,120,116,67,117,114,114,101,110,116,73,109,112,108,101,109,101,110,116,97,116,105,111,110,40,46,46,41,32,110,111,116,32,105,109,112,108,101,109,101,110,116,101,100,46,0,71,114,97,112,104,105,99,115,87,105,110,100,111,119,58,58,109,97,107,101,67,117,114,114,101,110,116,73,109,112,108,101,109,101,110,116,97,116,105,111,110,40,41,32,110,111,116,32,105,109,112,108,101,109,101,110,116,101,100,46,0,71,114,97,112,104,105,99,115,87,105,110,100,111,119,58,58,99,108,111,115,101,73,109,112,108,101,109,101,110,116,97,116,105,111,110,40,41,32,110,111,116,32,105,109,112,108,101,109,101,110,116,101,100,46,0,71,114,97,112,104,105,99,115,87,105,110,100,111,119,58,58,105,115,82,101,97,108,105,122,101,100,73,109,112,108,101,109,101,110,116,97,116,105,111,110,40,41,32,110,111,116,32,105,109,112,108,101,109,101,110,116,101,100,46,0,71,114,97,112,104,105,99,115,87,105,110,100,111,119,58,58,114,101,97,108,105,122,101,73,109,112,108,101,109,101,110,116,97,116,105,111,110,40,41,32,110,111,116,32,105,109,112,108,101,109,101,110,116,101,100,46,0,71,114,97,112,104,105,99,115,87,105,110,100,111,119,58,58,118,97,108,105,100,40,41,32,110,111,116,32,105,109,112,108,101,109,101,110,116,101,100,46,0,71,114,97,112,104,105,99,115,87,105,110,100,111,119,0,78,57,111,115,103,86,105,101,119,101,114,49,52,71,114,97,112,104,105,99,115,87,105,110,100,111,119,69,0,78,53,111,115,103,71,65,49,54,71,85,73,65,99,116,105,111,110,65,100,97,112,116,101,114,69,0,86,105,101,119,0,68,101,115,116,114,117,99,116,105,110,103,32,111,115,103,86,105,101,119,101,114,58,58,86,105,101,119,0,86,105,101,119,58,58,114,101,113,117,101,115,116,87,97,114,112,80,111,105,110,116,101,114,40,0,86,105,101,119,58,58,114,101,113,117,101,115,116,87,97,114,112,80,111,105,110,116,101,114,32,102,97,105,108,101,100,32,110,111,32,99,97,109,101,114,97,32,99,111,110,116,97,105,110,105,110,103,32,112,111,105,110,116,101,114,0,84,101,115,116,105,110,103,32,115,108,97,118,101,32,99,97,109,101,114,97,32,0,86,105,101,119,58,58,114,101,113,117,101,115,116,67,111,110,116,105,110,117,111,117,115,85,112,100,97,116,101,40,41,44,32,78,111,32,118,105,101,119,101,114,32,98,97,115,101,32,104,97,115,32,98,101,101,110,32,97,115,115,105,103,110,101,100,32,121,101,116,46,0,86,105,101,119,58,58,114,101,113,117,101,115,116,82,101,100,114,97,119,40,41,44,32,78,111,32,118,105,101,119,101,114,32,98,97,115,101,32,104,97,115,32,98,101,101,110,32,97,115,115,105,103,110,101,100,32,121,101,116,46,0,99,111,109,112,117,116,101,73,110,116,101,114,115,101,99,116,105,111,110,115,40,0,41,32,108,111,99,97,108,95,120,61,0,44,32,108,111,99,97,108,95,121,61,0,86,105,101,119,58,58,115,101,116,83,99,101,110,101,68,97,116,97,40,41,32,83,104,97,114,105,110,103], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+92412);
/* memory initializer */ allocate([32,115,99,101,110,101,32,0,86,105,101,119,58,58,115,101,116,83,99,101,110,101,68,97,116,97,40,41,32,65,108,108,111,99,97,116,105,110,103,32,110,101,119,32,115,99,101,110,101,0,86,105,101,119,58,58,115,101,116,83,99,101,110,101,68,97,116,97,40,41,32,82,101,117,115,105,110,103,32,101,120,105,115,116,105,110,103,32,115,99,101,110,101,0,34,67,111,108,108,101,99,116,101,100,67,111,111,114,100,105,110,97,116,101,83,121,115,116,101,109,78,111,100,101,115,86,105,115,105,116,111,114,34,0,34,111,115,103,86,105,101,119,101,114,34,0,70,111,117,110,100,32,67,111,111,114,100,105,110,97,116,101,83,121,115,116,101,109,78,111,100,101,32,110,111,100,101,0,32,32,32,32,32,67,111,111,114,100,105,110,97,116,101,83,121,115,116,101,109,32,61,32,0,70,111,117,110,100,32,97,100,100,105,116,105,111,110,97,108,32,67,111,111,114,100,105,110,97,116,101,83,121,115,116,101,109,78,111,100,101,32,110,111,100,101,44,32,98,117,116,32,105,103,110,111,114,105,110,103,0,51,55,67,111,108,108,101,99,116,101,100,67,111,111,114,100,105,110,97,116,101,83,121,115,116,101,109,78,111,100,101,115,86,105,115,105,116,111,114,0,78,111,100,101,86,105,115,105,116,111,114,0,78,57,111,115,103,86,105,101,119,101,114,52,86,105,101,119,69,0,78,57,111,115,103,86,105,101,119,101,114,49,48,86,105,101,119,67,111,110,102,105,103,69,0,78,57,111,115,103,86,105,101,119,101,114,52,86,105,101,119,49,57,83,116,101,114,101,111,83,108,97,118,101,67,97,108,108,98,97,99,107,69,0,78,51,111,115,103,52,86,105,101,119,53,83,108,97,118,101,49,57,85,112,100,97,116,101,83,108,97,118,101,67,97,108,108,98,97,99,107,69,0,86,105,101,119,58,58,105,110,105,116,40,41,0,103,101,116,67,111,111,114,100,105,110,97,116,101,70,114,97,109,101,40,0,99,115,110,45,62,99,111,109,112,117,116,101,76,111,99,97,108,67,111,111,114,100,105,110,97,116,101,70,114,97,109,101,40,112,111,115,105,116,105,111,110,41,42,32,111,115,103,58,58,99,111,109,112,117,116,101,76,111,99,97,108,84,111,87,111,114,108,100,40,116,109,112,80,97,116,104,41,0,111,115,103,58,58,99,111,109,112,117,116,101,76,111,99,97,108,84,111,87,111,114,108,100,40,116,109,112,80,97,116,104,41,0,32,32,32,110,111,32,99,111,111,114,100,105,110,97,116,101,32,115,121,115,116,101,109,32,102,111,117,110,100,44,32,117,115,105,110,103,32,100,101,102,97,117,108,116,32,111,114,105,101,110,116,97,116,105,111,110,0,123,0,125,0,9,0,78,51,111,115,103,50,48,67,111,111,114,100,105,110,97,116,101,83,121,115,116,101,109,78,111,100,101,69,0,50,57,86,105,101,119,101,114,67,111,111,114,100,105,110,97,116,101,70,114,97,109,101,67,97,108,108,98,97,99,107,0,78,53,111,115,103,71,65,49,55,67,97,109,101,114,97,77,97,110,105,112,117,108,97,116,111,114,50,51,67,111,111,114,100,105,110,97,116,101,70,114,97,109,101,67,97,108,108,98,97,99,107,69,0,65,112,112,108,121,105,110,103,32,111,115,103,86,105,101,119,101,114,58,58,86,105,101,119,67,111,110,102,105,103,32,58,32,0,82,101,110,100,101,114,32,116,111,32,116,101,120,116,117,114,101,32,99,97,109,101,114,97,0,68,105,115,116,111,114,116,105,111,110,67,111,114,114,101,99,116,105,111,110,67,97,109,101,114,97,0,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,85,255,255,255,255,0,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,0,0,0,0,85,85,85,85,170,170,170,170,85,85,85,85,170,170,170,170,85,85,85,85,170,170,170,170,85,85,85,85,170,170,170,170,85,85,85,85,170,170,170,170,85,85,85,85,170,170,170,170,85,85,85,85,170,170,170,170,85,85,85,85,170,170,170,170,85,85,85,85,170,170,170,170,85,85,85,85,170,170,170,170,85,85,85,85,170,170,170,170,85,85,85,85,170,170,170,170,85,85,85,85,170,170,170,170,85,85,85,85,170,170,170,170,85,85,85,85,170,170,170,170,85,85,85,85,170,170,170,170,78,57,111,115,103,86,105,101,119,101,114,56,75,101,121,115,116,111,110,101,69,0,86,105,101,119,101,114,0,86,105,101,119,101,114,58,58,126,86,105,101,119,101,114,40,41,58,58,32,115,116,97,114,116,32,100,101,115,116,114,117,99,116,111,114,32,103,101,116,84,104,114,101,97,100,115,32,61,32,0,86,105,101,119,101,114,58,58,126,86,105,101,119,101,114,40,41,32,101,110,100,32,100,101,115,116,114,117,99,116,111,114,32,103,101,116,84,104,114,101,97,100,115,32,61,32,0,71,114,97,112,104,105,99,115,87,105,110,100,111,119,69,109,98,101,100,100,101,100,0,78,57,111,115,103,86,105,101,119,101,114,50,50,71,114,97,112,104,105,99,115,87,105,110,100,111,119,69,109,98,101,100,100,101,100,69,0,85,112,100,97,116,101,32,116,114,97,118,101,114,115,97,108,32,98,101,103,105,110,32,116,105,109,101,0,85,112,100,97,116,101,32,116,114,97,118,101,114,115,97,108,32,101,110,100,32,116,105,109,101,0,85,112,100,97,116,101,32,116,114,97,118,101,114,115,97,108,32,116,105,109,101,32,116,97,107,101,110,0,101,118,101,110,116,0,69,118,101,110,116,32,116,114,97,118,101,114,115,97,108,32,98,101,103,105,110,32,116,105,109,101,0,69,118,101,110,116,32,116,114,97,118,101,114,115,97,108,32,101,110,100,32,116,105,109,101,0,69,118,101,110,116,32,116,114,97,118,101,114,115,97,108,32,116,105,109,101,32,116,97,107,101,110,0,32,32,83,108,97,118,101,32,104,97,115,32,109,97,116,99,104,101,100,32,116,101,120,116,117,114,101,32,99,117,98,101,109,97,112,0,78,53,111,115,103,71,65,49,49,80,111,105,110,116,101,114,68,97,116,97,69,0,102,114,97,109,101,95,114,97,116,101,0,70,114,97,109,101,32,100,117,114,97,116,105,111,110,0,70,114,97,109,101,32,114,97,116,101,0,82,101,102,101,114,101,110,99,101,32,116,105,109,101,0,86,105,101,119,101,114,58,58,114,101,97,108,105,122,101,40,41,32,45,32,78,111,32,118,97,108,105,100,32,99,111,110,116,101,120,116,115,32,102,111,117,110,100,44,32,115,101,116,116,105,110,103,32,117,112,32,118,105,101,119,32,97,99,114,111,115,115,32,97,108,108,32,115,99,114,101,101,110,115,46,0,79,83,71,95,67,79,78,70,73,71,95,70,73,76,69,0,79,83,71,95,83,67,82,69,69,78,0,79,83,71,95,87,73,78,68,79,87,0,86,105,101,119,101,114,58,58,114,101,97,108,105,122,101,40,41,32,45,32,102,97,105,108,101,100,32,116,111,32,115,101,116,32,117,112,32,97,110,121,32,119,105,110,100,111,119,115,0,78,83,116,51,95,95,50,49,53,98,97,115,105,99,95,115,116,114,105,110,103,98,117,102,73,99,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,99,69,69,78,83,95,57,97,108,108,111,99,97,116,111,114,73,99,69,69,69,69,0,78,83,116,51,95,95,50,49,57,98,97,115,105,99,95,105,115,116,114,105,110,103,115,116,114,101,97,109,73,99,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,99,69,69,78,83,95,57,97,108,108,111,99,97,116,111,114,73,99,69,69,69,69,0,86,105,101,119,101,114,58,58,114,101,97,100,67,111,110,102,105,103,117,114,97,116,105,111,110,40,0,85,115,105,110,103,32,111,115,103,86,105,101,119,101,114,58,58,67,111,110,102,105,103,32,58,32,0,69,114,114,111,114,58,32,67,111,110,102,105,103,32,102,105,108,101,32,34,0,34,32,99,111,110,116,97,105,110,105,110,103,32,67,111,109,112,111,115,105,116,101,86,105,101,119,101,114,32,99,97,110,110,111,116,32,98,101,32,108,111,97,100,101,100,32,98,121,32,86,105,101,119,101,114,46,0,34,32,100,111,101,115,32,110,111,116,32,99,111,110,116,97,105,110,32,97,32,118,97,108,105,100,32,86,105,101,119,101,114,32,99,111,110,102,105,103,117,114,97,116,105,111,110,46,0,78,57,111,115,103,86,105,101,119,101,114,54,86,105,101,119,101,114,69,0,79,112,116,105,111,110,115,0,111,115,103,68,66,0,78,53,111,115,103,68,66,55,79,112,116,105,111,110,115,69,0,78,117,109,98,101,114,32,111,102,32,117,110,105,113,117,101,32,83,116,97,116,101,83,101,116,0,78,117,109,98,101,114,32,111,102,32,117,110,105,113,117,101,32,71,114,111,117,112,0,78,117,109,98,101,114,32,111,102,32,117,110,105,113,117,101,32,84,114,97,110,115,102,111,114,109,0,78,117,109,98,101,114,32,111,102,32,117,110,105,113,117,101,32,76,79,68,0,78,117,109,98,101,114,32,111,102,32,117,110,105,113,117,101,32,83,119,105,116,99,104,0,78,117,109,98,101,114,32,111,102,32,117,110,105,113,117,101,32,71,101,111,100,101,0,78,117,109,98,101,114,32,111,102,32,117,110,105,113,117,101,32,68,114,97,119,97,98,108,101,0,78,117,109,98,101,114,32,111,102,32,117,110,105,113,117,101,32,71,101,111,109,101,116,114,121,0,78,117,109,98,101,114,32,111,102,32,117,110,105,113,117,101,32,86,101,114,116,105,99,101,115,0,78,117,109,98,101,114,32,111,102,32,117,110,105,113,117,101,32,80,114,105,109,105,116,105,118,101,115,0,78,117,109,98,101,114,32,111,102,32,105,110,115,116,97,110,99,101,100,32,83,116,97,116,101,115,101,116,0,78,117,109,98,101,114,32,111,102,32,105,110,115,116,97,110,99,101,100,32,71,114,111,117,112,0,78,117,109,98,101,114,32,111,102,32,105,110,115,116,97,110,99,101,100,32,84,114,97,110,115,102,111,114,109,0,78,117,109,98,101,114,32,111,102,32,105,110,115,116,97,110,99,101,100,32,76,79,68,0,78,117,109,98,101,114,32,111,102,32,105,110,115,116,97,110,99,101,100,32,83,119,105,116,99,104,0,78,117,109,98,101,114,32,111,102,32,105,110,115,116,97,110,99,101,100,32,71,101,111,100,101,0,78,117,109,98,101,114,32,111,102,32,105,110,115,116,97,110,99,101,100,32,68,114,97,119,97,98,108,101,0,78,117,109,98,101,114,32,111,102,32,105,110,115,116,97,110,99,101,100,32,71,101,111,109,101,116,114,121,0,78,117,109,98,101,114,32,111,102,32,105,110,115,116,97,110,99,101,100,32,86,101,114,116,105,99,101,115,0,78,117,109,98,101,114,32,111,102,32,105,110,115,116,97,110,99,101,100,32,80,114,105,109,105,116,105,118,101,115,0,117,112,100,97,116,101,0,82,101,110,100,101,114,105,110,103,32,116,114,97,118,101,114,115,97,108,115,32,98,101,103,105,110,32,116,105,109,101,32,0,82,101,110,100,101,114,105,110,103,32,116,114,97,118,101,114,115,97,108,115,32,101,110,100,32,116,105,109,101,32,0,82,101,110,100,101,114,105,110,103,32,116,114,97,118,101,114,115,97,108,115,32,116,105,109,101,32,116,97,107,101,110,0,79,83,71,95,82,85,78,95,70,82,65,77,69,95,67,79,85,78,84,0,86,105,101,119,101,114,58,58,115,116,97,114,116,84,104,114,101,97,100,105,110,103,40,41,32,45,32,115,116,97,114,116,105,110,103,32,116,104,114,101,97,100,105,110,103,0,86,105,101,119,101,114,58,58,115,116,97,114,116,84,104,114,101,97,100,105,110,103,40,41,32,45,32,99,111,110,116,101,120,116,115,46,115,105,122,101,40,41,61,0,69,114,114,111,114,58,32,84,104,114,101,97,100,105,110,103,32,109,111,100,101,108,32,110,111,116,32,115,101,108,101,99,116,101,100,0,77,97,107,105,110,103,32,115,99,101,110,101,32,116,104,114,101,97,100,32,115,97,102,101,0,86,105,101,119,101,114,66,97,115,101,58,58,115,116,97,114,116,84,104,114,101,97,100,105,110,103,40,41,32,58,32,82,101,97,108,105,122,110,103,32,119,105,110,100,111,119,32,0,32,32,99,97,109,101,114,97,45,62,103,101,116,67,97,109,101,114,97,84,104,114,101,97,100,40,41,45,62,32,0,32,32,103,99,45,62,103,101,116,71,114,97,112,104,105,99,115,84,104,114,101,97,100,40,41,45,62,115,116,97,114,116,84,104,114,101,97,100,40,41,32,0,83,101,116,32,117,112,32,116,104,114,101,97,100,105,110,103,0,82,117,110,79,112,101,114,97,116,105,111,110,0,83,119,97,112,66,117,102,102,101,114,115,0,66,97,114,114,105,101,114,0,86,105,101,119,101,114,66,97,115,101,58,58,115,116,111,112,84,104,114,101,97,100,105,110,103,40,41,32,45,32,115,116,111,112,112,105,110,103,32,116,104,114,101,97,100,105,110,103,0,86,105,101,119,101,114,58,58,115,116,111,112,84,104,114,101,97,100,105,110,103,40,41,32,45,32,115,116,111,112,112,101,100,32,116,104,114,101,97,100,105,110,103,46,0,79,83,71,95,84,72,82,69,65,68,73,78,71,0,83,105,110,103,108,101,84,104,114,101,97,100,101,100,0,67,117,108,108,68,114,97,119,84,104,114,101,97,100,80,101,114,67,111,110,116,101,120,116,0,68,114,97,119,84,104,114,101,97,100,80,101,114,67,111,110,116,101,120,116,0,67,117,108,108,84,104,114,101,97,100,80,101,114,67,97,109,101,114,97,68,114,97,119,84,104,114,101,97,100,80,101,114,67,111,110,116,101,120,116,0,86,105,101,119,101,114,66,97,115,101,58,58,99,111,110,102,105,103,117,114,101,65,102,102,105,110,105,116,121,40,41,32,110,117,109,80,114,111,99,101,115,115,111,114,115,61,0,32,32,100,97,116,97,98,97,115,101,80,97,103,101,114,115,32,61,32,0,78,57,111,115,103,86,105,101,119,101,114,49,48,86,105,101,119,101,114,66,97,115,101,69,0,79,83,71,95,67,79,78,70,73,71,95,70,73,76,69,32,60,102,105,108,101,110,97,109,101,62,0,83,112,101,99,105,102,121,32,97,32,118,105,101,119,101,114,32,99,111,110,102,105,103,117,114,97,116,105,111,110,32,102,105,108,101,32,116,111,32,108,111,97,100,32,98,121,32,100,101,102,97,117,108,116,46,0,79,83,71,95,84,72,82,69,65,68,73,78,71,32,60,118,97,108,117,101,62,0,83,101,116,32,116,104,101,32,116,104,114,101,97,100,105,110,103,32,109,111,100,101,108,32,117,115,105,110,103,32,98,121,32,86,105,101,119,101,114,44,32,60,118,97,108,117,101,62,32,99,97,110,32,98,101,32,83,105,110,103,108,101,84,104,114,101,97,100,101,100,44,32,67,117,108,108,68,114,97,119,84,104,114,101,97,100,80,101,114,67,111,110,116,101,120,116,44,32,68,114,97,119,84,104,114,101,97,100,80,101,114,67,111,110,116,101,120,116,32,111,114,32,67,117,108,108,84,104,114,101,97,100,80,101,114,67,97,109,101,114,97,68,114,97,119,84,104,114,101,97,100,80,101,114,67,111,110,116,101,120,116,46,0,79,83,71,95,83,67,82,69,69,78,32,60,118,97,108,117,101,62,0,83,101,116,32,116,104,101,32,100,101,102,97,117,108,116,32,115,99,114,101,101,110,32,116,104,97,116,32,119,105,110,100,111,119,115,32,115,104,111,117,108,100,32,111,112,101,110,32,117,112,32,111,110,46,0,79,83,71,95,87,73,78,68,79,87,32,120,32,121,32,119,105,100,116,104,32,104,101,105,103,104,116,0,83,101,116,32,116,104,101,32,100,101,102,97,117,108,116,32,119,105,110,100,111,119,32,100,105,109,101,110,115,105,111,110,115,32,116,104,97,116,32,119,105,110,100,111,119,115,32,115,104,111,117,108,100,32,111,112,101,110,32,117,112,32,111,110,46,0,79,83,71,95,82,85,78,95,70,82,65,77,69,95,83,67,72,69,77,69,0,70,114,97,109,101,32,114,97,116,101,32,109,97,110,97,103,101,32,115,99,104,101,109,101,32,116,104,97,116,32,118,105,101,119,101,114,32,114,117,110,32,115,104,111,117,108,100,32,117,115,101,44,32,32,79,78,95,68,69,77,65,78,68,32,111,114,32,67,79,78,84,73,78,85,79,85,83,32,40,100,101,102,97,117,108,116,41,46,0,79,83,71,95,82,85,78,95,77,65,88,95,70,82,65,77,69,95,82,65,84,69,0,83,101,116,32,116,104,101,32,109,97,120,105,109,117,109,32,110,117,109,98,101,114,32,111,102,32,102,114,97,109,101,32,97,115,32,115,101,99,111,110,100,32,116,104,97,116,32,118,105,101,119,101,114,32,114,117,110,46,32,48,46,48,32,105,115,32,100,101,102,97,117,108,116,32,97,110,100,32,100,105,115,97,98,108,101,115,32,97,110,32,102,114,97,109,101,32,114,97,116,101,32,99,97,112,112,105,110,103,46,0,79,78,95,68,69,77,65,78,68,0,67,79,78,84,73,78,85,79,85,83,0,78,51,111,115,103,49,49,77,105,120,105,110,86,101,99,116,111,114,73,78,83,95,53,86,101,99,52,102,69,69,69,0,78,51,111,115,103,49,51,84,101,109,112,108,97,116,101,65,114,114,97,121,73,78,83,95,53,86,101,99,52,102,69,76,78,83,95,53,65,114,114,97,121,52,84,121,112,101,69,50,57,69,76,105,52,69,76,105,53,49,50,54,69,69,69,0,78,51,111,115,103,49,49,77,105,120,105,110,86,101,99,116,111,114,73,78,83,95,53,86,101,99,50,102,69,69,69,0,78,51,111,115,103,49,51,84,101,109,112,108,97,116,101,65,114,114,97,121,73,78,83,95,53,86,101,99,50,102,69,76,78,83,95,53,65,114,114,97,121,52,84,121,112,101,69,50,55,69,76,105,50,69,76,105,53,49,50,54,69,69,69,0,78,51,111,115,103,49,49,77,105,120,105,110,86,101,99,116,111,114,73,78,83,95,53,86,101,99,51,102,69,69,69,0,78,51,111,115,103,49,51,84,101,109,112,108,97,116,101,65,114,114,97,121,73,78,83,95,53,86,101,99,51,102,69,76,78,83,95,53,65,114,114,97,121,52,84,121,112,101,69,50,56,69,76,105,51,69,76,105,53,49,50,54,69,69,69,0,83,105,110,103,108,101,87,105,110,100,111,119,58,58,99,111,110,102,105,103,117,114,101,40,41,32,58,32,69,114,114,111,114,44,32,110,111,32,87,105,110,100,111,119,83,121,115,116,101,109,73,110,116,101,114,102,97,99,101,32,97,118,97,105,108,97,98,108,101,44,32,99,97,110,110,111,116,32,99,114,101,97,116,101,32,119,105,110,100,111,119,115,46,0,86,105,101,119,58,58,115,101,116,85,112,86,105,101,119,79,110,83,105,110,103,108,101,83,99,114,101,101,110,32,45,32,71,114,97,112,104,105,99,115,87,105,110,100,111,119,32,104,97,115,32,98,101,101,110,32,99,114,101,97,116,101,100,32,115,117,99,99,101,115,115,102,117,108,108,121,46,0,83,105,110,103,108,101,87,105,110,100,111,119,0,78,57,111,115,103,86,105,101,119,101,114,49,50,83,105,110,103,108,101,87,105,110,100,111,119,69,0,83,105,110,103,108,101,83,99,114,101,101,110,0,78,57,111,115,103,86,105,101,119,101,114,49,50,83,105,110,103,108,101,83,99,114,101,101,110,69,0,65,99,114,111,115,115,65,108,108,83,99,114,101,101,110,115,58,58,99,111,110,102,105,103,117,114,101,40,41,32,58,32,69,114,114,111,114,44,32,110,111,32,87,105,110,100,111,119,83,121,115,116,101,109,73,110,116,101,114,102,97,99,101,32,97,118,97,105,108,97,98,108,101,44,32,99,97,110,110,111,116,32,99,114,101,97,116,101,32,119,105,110,100,111,119,115,46,0,32,32,71,114,97,112,104,105,99,115,87,105,110,100,111,119,32,104,97,115,32,98,101,101,110,32,99,114,101,97,116,101,100,32,115,117,99,99,101,115,115,102,117,108,108,121,46,0,32,32,71,114,97,112,104,105,99,115,87,105,110,100,111,119,32,104,97,115,32,110,111,116,32,98,101,101,110,32,99,114,101,97,116,101,100,32,115,117,99,99,101,115,115,102,117,108,108,121,46,0,65,99,114,111,115,115,65,108,108,83,99,114,101,101,110,115,0,78,57,111,115,103,86,105,101,119,101,114,49,54,65,99,114,111,115,115,65,108,108,83,99,114,101,101,110,115,69,0,78,57,111,115,103,86,105,101,119,101,114,49,53,67,111,109,112,111,115,105,116,101,86,105,101,119,101,114,69,0,71,85,73,69,118,101,110,116,72,97,110,100,108,101,114,0,78,51,111,115,103,49,57,84,101,109,112,108,97,116,101,86,97,108,117,101,79,98,106,101,99,116,73,78,83,116,51,95,95,50,49,50,98,97,115,105,99,95,115,116,114,105,110,103,73,99,78,83,49,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,99,69,69,78,83,49,95,57,97,108,108,111,99,97,116,111,114,73,99,69,69,69,69,69,69,0,87,114,105,116,105,110,103,32,107,101,121,115,116,111,110,101,32,116,111,58,32,0,67,97,108,108,98,97,99,107,0,78,51,111,115,103,56,67,97,108,108,98,97,99,107,69,0,68,114,97,119,97,98,108,101,69,118,101,110,116,67,97,108,108,98,97,99,107,0,78,111,100,101,67,97,108,108,98,97,99,107,0,69,118,101,110,116,72,97,110,100,108,101,114,0,78,57,111,115,103,86,105,101,119,101,114,49,53,75,101,121,115,116,111,110,101,72,97,110,100,108,101,114,69,0,75,101,121,115,116,111,110,101,0,111,115,103,86,105,101,119,101,114,0,75,101,121,115,116,111,110,101,85,112,100,97,116,101,67,97,108,108,98,97,99,107,0,50,50,75,101,121,115,116,111,110,101,85,112,100,97,116,101,67,97,108,108,98,97,99,107,0,75,101,121,115,116,111,110,101,67,117,108,108,67,97,108,108,98,97,99,107,0,50,48,75,101,121,115,116,111,110,101,67,117,108,108,67,97,108,108,98,97,99,107,0,67,114,101,97,116,105,110,103,32,75,101,121,115,116,111,110,101,32,102,111,114,32,102,105,108,101,110,97,109,101,32,101,110,116,114,121,58,32,0,83,116,114,105,110,103,86,97,108,117,101,79,98,106,101,99,116,0,78,51,111,115,103,49,49,86,97,108,117,101,79,98,106,101,99,116,69,0,86,97,108,117,101,79,98,106,101,99,116,0,78,57,111,115,103,86,105,101,119,101,114,49,56,79,112,101,110,71,76,81,117,101,114,121,83,117,112,112,111,114,116,69,0,71,80,85,32,100,114,97,119,32,98,101,103,105,110,32,116,105,109,101,0,71,80,85,32,100,114,97,119,32,101,110,100,32,116,105,109,101,0,71,80,85,32,100,114,97,119,32,116,105,109,101,32,116,97,107,101,110,0,49,53,69,88,84,81,117,101,114,121,83,117,112,112,111,114,116,0,82,101,110,100,101,114,58,58,126,82,101,110,100,101,114,40,41,32,0,78,51,111,115,103,57,79,112,101,114,97,116,105,111,110,69,0,82,101,110,100,101,114,101,114,58,58,99,111,109,112,105,108,101,40,41,0,66,101,102,111,114,101,32,82,101,110,100,101,114,101,114,58,58,99,111,109,112,105,108,101,0,65,102,116,101,114,32,82,101,110,100,101,114,101,114,58,58,99,111,109,112,105,108,101,0,99,117,108,108,95,100,114,97,119,40,41,32,0,103,112,117,0,115,99,101,110,101,0,114,101,110,100,101,114,105,110,103,0,67,111,108,108,101,99,116,105,110,103,32,114,101,110,100,101,114,105,110,103,32,115,116,97,116,115,0,67,117,108,108,32,116,114,97,118,101,114,115,97,108,32,98,101,103,105,110,32,116,105,109,101,0,67,117,108,108,32,116,114,97,118,101,114,115,97,108,32,101,110,100,32,116,105,109,101,0,67,117,108,108,32,116,114,97,118,101,114,115,97,108,32,116,105,109,101,32,116,97,107,101,110,0,68,114,97,119,32,116,114,97,118,101,114,115,97,108,32,98,101,103,105,110,32,116,105,109,101,0,68,114,97,119,32,116,114,97,118,101,114,115,97,108,32,101,110,100,32,116,105,109,101,0,68,114,97,119,32,116,114,97,118,101,114,115,97,108,32,116,105,109,101,32,116,97,107,101,110,0,101,110,100,32,99,117,108,108,95,100,114,97,119,40,41,32,0,86,105,115,105,98,108,101,32,118,101,114,116,101,120,32,99,111,117,110,116,0,86,105,115,105,98,108,101,32,110,117,109,98,101,114,32,111,102,32,100,114,97,119,97,98,108,101,115,0,86,105,115,105,98,108,101,32,110,117,109,98,101,114,32,111,102,32,102,97,115,116,32,100,114,97,119,97,98,108,101,115,0,86,105,115,105,98,108,101,32,110,117,109,98,101,114,32,111,102,32,108,105,103,104,116,115,0,86,105,115,105,98,108,101,32,110,117,109,98,101,114,32,111,102,32,114,101,110,100,101,114,32,98,105,110,115,0,86,105,115,105,98,108,101,32,100,101,112,116,104,0,78,117,109,98,101,114,32,111,102,32,83,116,97,116,101,71,114,97,112,104,115,0,86,105,115,105,98,108,101,32,110,117,109,98,101,114,32,111,102,32,105,109,112,111,115,116,111,114,115,0,78,117,109,98,101,114,32,111,102,32,111,114,100,101,114,101,100,32,108,101,97,118,101,115,0,86,105,115,105,98,108,101,32,110,117,109,98,101,114,32,111,102,32,80,114,105,109,105,116,105,118,101,83,101,116,115,0,86,105,115,105,98,108,101,32,110,117,109,98,101,114,32,111,102,32,71,76,95,80,79,73,78,84,83,0,86,105,115,105,98,108,101,32,110,117,109,98,101,114,32,111,102,32,71,76,95,76,73,78,69,83,0,86,105,115,105,98,108,101,32,110,117,109,98,101,114,32,111,102,32,71,76,95,76,73,78,69,95,83,84,82,73,80,0,86,105,115,105,98,108,101,32,110,117,109,98,101,114,32,111,102,32,71,76,95,76,73,78,69,95,76,79,79,80,0,86,105,115,105,98,108,101,32,110,117,109,98,101,114,32,111,102,32,71,76,95,84,82,73,65,78,71,76,69,83,0,86,105,115,105,98,108,101,32,110,117,109,98,101,114,32,111,102,32,71,76,95,84,82,73,65,78,71,76,69,95,83,84,82,73,80,0,86,105,115,105,98,108,101,32,110,117,109,98,101,114,32,111,102,32,71,76,95,84,82,73,65,78,71,76,69,95,70,65,78,0,86,105,115,105,98,108,101,32,110,117,109,98,101,114,32,111,102,32,71,76,95,81,85,65,68,83,0,86,105,115,105,98,108,101,32,110,117,109,98,101,114,32,111,102,32,71,76,95,81,85,65,68,95,83,84,82,73,80,0,86,105,115,105,98,108,101,32,110,117,109,98,101,114,32,111,102,32,71,76,95,80,79,76,89,71,79,78,0,49,53,65,82,66,81,117,101,114,121,83,117,112,112,111,114,116,0,100,114,97,119,40,41,32,0,100,114,97,119,40,41,32,103,111,116,32,83,99,101,110,101,86,105,101,119,32,0,82,101,110,100,101,114,101,114,58,58,114,101,108,101,97,115,101,40,41,32,99,97,117,115,105,110,103,32,100,114,97,119,32,116,111,32,101,120,105,116,0,82,101,110,100,101,114,101,114,58,58,100,114,97,119,40,41,32,99,111,109,112,108,101,116,105,110,103,32,101,97,114,108,121,32,100,117,101,32,116,111,32,99,104,97,110,103,101,32,105,110,32,95,103,114,97,112,104,105,99,115,84,104,114,101,97,100,68,111,101,115,67,117,108,108,32,102,108,97,103,46,0,101,110,100,32,100,114,97,119,40,41,32,0,99,117,108,108,40,41,0,99,117,108,108,40,41,32,103,111,116,32,83,99,101,110,101,86,105,101,119,32,0,101,110,100,32,99,117,108,108,40,41,32,0,82,101,110,100,101,114,101,114,58,58,114,101,108,101,97,115,101,40,41,0,78,57,111,115,103,86,105,101,119,101,114,56,82,101,110,100,101,114,101,114,69,0,78,49,49,79,112,101,110,84,104,114,101,97,100,115,49,52,82,101,101,110,116,114,97,110,116,77,117,116,101,120,69,0,82,101,110,100,101,114,58,58,82,101,110,100,101,114,40,41,32,0,95,97,118,97,105,108,97,98,108,101,81,117,101,117,101,46,115,105,122,101,40,41,61,0,78,55,111,115,103,85,116,105,108,49,49,67,117,108,108,86,105,115,105,116,111,114,49,48,73,100,101,110,116,105,102,105,101,114,69,0,83,99,101,110,101,0,78,57,111,115,103,86,105,101,119,101,114,53,83,99,101,110,101,69,0,72,97,110,100,108,101,32,101,118,101,110,116,32,0,78,53,111,115,103,71,65,49,50,69,118,101,110,116,72,97,110,100,108,101,114,69,0,78,53,111,115,103,71,65,49,48,69,118,101,110,116,81,117,101,117,101,69,0,82,101,115,101,116,32,101,118,101,110,116,32,116,105,109,101,32,102,114,111,109,32,0,69,118,101,110,116,86,105,115,105,116,111,114,0,78,53,111,115,103,71,65,49,50,69,118,101,110,116,86,105,115,105,116,111,114,69,0,71,85,73,69,118,101,110,116,65,100,97,112,116,101,114,0,78,53,111,115,103,71,65,49,53,71,85,73,69,118,101,110,116,65,100,97,112,116,101,114,57,84,111,117,99,104,68,97,116,97,69,0,78,53,111,115,103,71,65,49,53,71,85,73,69,118,101,110,116,65,100,97,112,116,101,114,69,0,78,53,111,115,103,71,65,53,69,118,101,110,116,69,0,78,53,111,115,103,71,65,49,53,71,85,73,69,118,101,110,116,72,97,110,100,108,101,114,69,0,84,114,97,99,107,98,97,108,108,77,97,110,105,112,117,108,97,116,111,114,0,78,53,111,115,103,71,65,49,54,79,114,98,105,116,77,97,110,105,112,117,108,97,116,111,114,49,56,79,114,98,105,116,65,110,105,109,97,116,105,111,110,68,97,116,97,69,0,78,53,111,115,103,71,65,49,57,83,116,97,110,100,97,114,100,77,97,110,105,112,117,108,97,116,111,114,49,51,65,110,105,109,97,116,105,111,110,68,97,116,97,69,0,78,53,111,115,103,71,65,50,48,84,114,97,99,107,98,97,108,108,77,97,110,105,112,117,108,97,116,111,114,69,0,67,97,109,101,114,97,77,97,110,105,112,117,108,97,116,111,114,0,83,116,97,110,100,97,114,100,77,97,110,105,112,117,108,97,116,111,114,0,79,114,98,105,116,77,97,110,105,112,117,108,97,116,111,114,0,69,118,101,110,116,0,111,115,103,71,65,0,32,67,97,109,101,114,97,77,97,110,105,112,117,108,97,116,111,114,58,58,99,111,109,112,117,116,101,72,111,109,101,80,111,115,105,116,105,111,110,40,0,32,32,32,32,98,111,117,110,100,105,110,103,83,112,104,101,114,101,46,99,101,110,116,101,114,40,41,32,61,32,40,0,32,32,32,32,98,111,117,110,100,105,110,103,83,112,104,101,114,101,46,114,97,100,105,117,115,40,41,32,61,32,0,78,53,111,115,103,71,65,49,55,67,97,109,101,114,97,77,97,110,105,112,117,108,97,116,111,114,69,0,77,97,110,105,112,117,108,97,116,111,114,0,84,114,97,99,107,98,97,108,108,77,97,110,105,112,117,108,97,116,111,114,58,58,115,101,116,84,114,97,99,107,98,97,108,108,83,105,122,101,40,102,108,111,97,116,41,0,87,97,114,110,105,110,103,58,32,0,32,111,102,32,0,32,105,115,32,98,101,108,111,119,32,112,101,114,109,105,116,116,101,100,32,109,105,110,105,109,117,109,44,32,99,108,97,109,112,105,110,103,32,116,111,32,0,32,105,115,32,97,98,111,118,101,32,112,101,114,109,105,116,116,101,100,32,109,97,120,105,109,117,109,44,32,99,108,97,109,112,105,110,103,32,116,111,32,0,78,53,111,115,103,71,65,49,54,79,114,98,105,116,77,97,110,105,112,117,108,97,116,111,114,69,0,83,116,97,110,100,97,114,100,77,97,110,105,112,117,108,97,116,111,114,58,58,102,105,120,86,101,114,116,105,99,97,108,65,120,105,115,32,119,97,114,110,105,110,103,58,32,67,97,110,32,110,111,116,32,117,112,100,97,116,101,32,118,101,114,116,105,99,97,108,32,97,120,105,115,46,0,77,97,110,105,112,117,108,97,116,111,114,32,119,97,114,110,105,110,103,58,32,101,118,101,110,116,84,105,109,101,68,101,108,116,97,32,61,32,0,58,32,83,112,97,99,101,0,82,101,115,101,116,32,116,104,101,32,118,105,101,119,105,110,103,32,112,111,115,105,116,105,111,110,32,116,111,32,104,111,109,101,0,78,53,111,115,103,71,65,49,57,83,116,97,110,100,97,114,100,77,97,110,105,112,117,108,97,116,111,114,69,0,71,76,79,98,106,101,99,116,115,86,105,115,105,116,111,114,0,78,51,111,115,103,49,52,83,116,97,116,101,65,116,116,114,105,98,117,116,101,69,0,78,55,111,115,103,85,116,105,108,49,54,71,76,79,98,106,101,99,116,115,86,105,115,105,116,111,114,69,0,78,55,111,115,103,85,116,105,108,49,49,73,110,116,101,114,115,101,99,116,111,114,69,0,73,110,116,101,114,115,101,99,116,105,111,110,86,105,115,105,116,111,114,0,77,97,116,114,105,120,0,78,51,111,115,103,49,48,82,101,102,77,97,116,114,105,120,100,69,0,78,51,111,115,103,55,77,97,116,114,105,120,100,69,0,78,55,111,115,103,85,116,105,108,49,57,73,110,116,101,114,115,101,99,116,105,111,110,86,105,115,105,116,111,114,69,0,78,55,111,115,103,85,116,105,108,49,52,83,116,97,116,101,84,111,67,111,109,112,105,108,101,69,0,78,55,111,115,103,85,116,105,108,50,55,73,110,99,114,101,109,101,110,116,97,108,67,111,109,112,105,108,101,79,112,101,114,97,116,105,111,110,49,55,67,111,109,112,105,108,101,68,114,97,119,97,98,108,101,79,112,69,0,78,55,111,115,103,85,116,105,108,50,55,73,110,99,114,101,109,101,110,116,97,108,67,111,109,112,105,108,101,79,112,101,114,97,116,105,111,110,57,67,111,109,112,105,108,101,79,112,69,0,78,55,111,115,103,85,116,105,108,50,55,73,110,99,114,101,109,101,110,116,97,108,67,111,109,112,105,108,101,79,112,101,114,97,116,105,111,110,49,54,67,111,109,112,105,108,101,84,101,120,116,117,114,101,79,112,69,0,78,55,111,115,103,85,116,105,108,50,55,73,110,99,114,101,109,101,110,116,97,108,67,111,109,112,105,108,101,79,112,101,114,97,116,105,111,110,49,54,67,111,109,112,105,108,101,80,114,111,103,114,97,109,79,112,69,0,79,83,71,95,77,73,78,73,77,85,77,95,67,79,77,80,73,76,69,95,84,73,77,69,95,80,69,82,95,70,82,65,77,69,32,60,102,108,111,97,116,62,0,109,105,110,105,109,117,109,32,99,111,109,112,105,108,101,32,116,105,109,101,32,97,108,108,111,116,101,100,32,116,111,32,99,111,109,112,105,108,105,110,103,32,79,112,101,110,71,76,32,111,98,106,101,99,116,115,32,112,101,114,32,102,114,97,109,101,32,105,110,32,100,97,116,97,98,97,115,101,32,112,97,103,101,114,46,0,79,83,71,95,77,65,88,73,77,85,77,95,79,66,74,69,67,84,83,95,84,79,95,67,79,77,80,73,76,69,95,80,69,82,95,70,82,65,77,69,32,60,105,110,116,62,0,109,97,120,105,109,117,109,32,110,117,109,98,101,114,32,111,102,32,79,112,101,110,71,76,32,111,98,106,101,99,116,115,32,116,111,32,99,111,109,112,105,108,101,32,112,101,114,32,102,114,97,109,101,32,105,110,32,100,97,116,97,98,97,115,101,32,112,97,103,101,114,46,0,79,83,71,95,70,79,82,67,69,95,84,69,88,84,85,82,69,95,68,79,87,78,76,79,65,68,32,60,79,78,47,79,70,70,62,0,115,104,111,117,108,100,32,116,104,101,32,116,101,120,116,117,114,101,32,99,111,109,112,105,108,101,115,32,98,101,32,102,111,114,99,101,100,32,116,111,32,100,111,119,110,108,111,97,100,32,117,115,105,110,103,32,97,32,100,117,109,109,121,32,71,101,111,109,101,116,114,121,46,0,68,117,109,109,121,79,98,106,101,99,116,0,78,51,111,115,103,49,49,68,117,109,109,121,79,98,106,101,99,116,69,0,73,110,99,114,101,109,101,110,116,97,108,67,111,109,112,105,108,101,79,112,101,114,97,116,105,111,110,58,58,97,100,100,40,67,111,109,112,105,108,101,83,101,116,32,61,32,0,78,55,111,115,103,85,116,105,108,50,55,73,110,99,114,101,109,101,110,116,97,108,67,111,109,112,105,108,101,79,112,101,114,97,116,105,111,110,49,48,67,111,109,112,105,108,101,83,101,116,69,0,87,97,114,110,105,110,103,58,32,75,100,84,114,101,101,58,58,105,110,116,101,114,115,101,99,116,40,41,32,101,110,99,111,117,110,116,101,100,32,117,110,115,117,112,112,111,114,116,101,100,32,112,114,105,109,105,116,105,118,101,32,115,105,122,101,32,111,102,32,0,78,51,111,115,103,50,52,84,101,109,112,108,97,116,101,80,114,105,109,105,116,105,118,101,70,117,110,99,116,111,114,73,78,50,55,76,105,110,101,83,101,103,109,101,110,116,73,110,116,101,114,115,101,99,116,111,114,85,116,105,108,115,49,54,73,110,116,101,114,115,101,99,116,70,117,110,99,116,111,114,73,78,83,95,53,86,101,99,51,102,69,102,69,69,69,69,0,78,50,55,76,105,110,101,83,101,103,109,101,110,116,73,110,116,101,114,115,101,99,116,111,114,85,116,105,108,115,49,54,73,110,116,101,114,115,101,99,116,70,117,110,99,116,111,114,73,78,51,111,115,103,53,86,101,99,51,102,69,102,69,69,0,78,51,111,115,103,49,54,80,114,105,109,105,116,105,118,101,70,117,110,99,116,111,114,69,0,78,51,111,115,103,50,52,84,101,109,112,108,97,116,101,80,114,105,109,105,116,105,118,101,70,117,110,99,116,111,114,73,78,50,55,76,105,110,101,83,101,103,109,101,110,116,73,110,116,101,114,115,101,99,116,111,114,85,116,105,108,115,49,54,73,110,116,101,114,115,101,99,116,70,117,110,99,116,111,114,73,78,83,95,53,86,101,99,51,100,69,100,69,69,69,69,0,78,50,55,76,105,110,101,83,101,103,109,101,110,116,73,110,116,101,114,115,101,99,116,111,114,85,116,105,108,115,49,54,73,110,116,101,114,115,101,99,116,70,117,110,99,116,111,114,73,78,51,111,115,103,53,86,101,99,51,100,69,100,69,69,0,78,50,55,76,105,110,101,83,101,103,109,101,110,116,73,110,116,101,114,115,101,99,116,111,114,85,116,105,108,115,56,83,101,116,116,105,110,103,115,69,0,78,55,111,115,103,85,116,105,108,50,50,76,105,110,101,83,101,103,109,101,110,116,73,110,116,101,114,115,101,99,116,111,114,69,0,78,51,111,115,103,49,51,84,101,109,112,108,97,116,101,65,114,114,97,121,73,102,76,78,83,95,53,65,114,114,97,121,52,84,121,112,101,69,55,69,76,105,49,69,76,105,53,49,50,54,69,69,69,0,78,51,111,115,103,49,49,77,105,120,105,110,86,101,99,116,111,114,73,102,69,69,0,78,55,111,115,103,85,116,105,108,50,48,66,97,115,101,79,112,116,105,109,105,122,101,114,86,105,115,105,116,111,114,69,0,78,51,111,115,103,49,50,65,114,114,97,121,86,105,115,105,116,111,114,69,0,78,83,116,51,95,95,50,49,56,98,97,115,105,99,95,115,116,114,105,110,103,115,116,114,101,97,109,73,99,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,99,69,69,78,83,95,57,97,108,108,111,99,97,116,111,114,73,99,69,69,69,69,0,78,55,111,115,103,85,116,105,108,57,79,112,116,105,109,105,122,101,114,50,56,83,116,97,116,105,99,79,98,106,101,99,116,68,101,116,101,99,116,105,111,110,86,105,115,105,116,111,114,69,0,79,83,71,95,79,80,84,73,77,73,90,69,82,32,34,60,116,121,112,101,62,32,91,60,116,121,112,101,62,93,34,0,79,70,70,32,124,32,68,69,70,65,85,76,84,32,124,32,70,76,65,84,84,69,78,95,83,84,65,84,73,67,95,84,82,65,78,83,70,79,82,77,83,32,124,32,70,76,65,84,84,69,78,95,83,84,65,84,73,67,95,84,82,65,78,83,70,79,82,77,83,95,68,85,80,76,73,67,65,84,73,78,71,95,83,72,65,82,69,68,95,83,85,66,71,82,65,80,72,83,32,124,32,82,69,77,79,86,69,95,82,69,68,85,78,68,65,78,84,95,78,79,68,69,83,32,124,32,67,79,77,66,73,78,69,95,65,68,74,65,67,69,78,84,95,76,79,68,83,32,124,32,83,72,65,82,69,95,68,85,80,76,73,67,65,84,69,95,83,84,65,84,69,32,124,32,77,69,82,71,69,95,71,69,79,77,69,84,82,89,32,124,32,77,69,82,71,69,95,71,69,79,68,69,83,32,124,32,83,80,65,84,73,65,76,73,90,69,95,71,82,79,85,80,83,32,32,124,32,67,79,80,89,95,83,72,65,82,69,68,95,78,79,68,69,83,32,32,124,32,84,82,73,83,84,82,73,80,95,71,69,79,77,69,84,82,89,32,124,32,79,80,84,73,77,73,90,69,95,84,69,88,84,85,82,69,95,83,69,84,84,73,78,71,83,32,124,32,82,69,77,79,86,69,95,76,79,65,68,69,68,95,80,82,79,88,89,95,78,79,68,69,83,32,124,32,84,69,83,83,69,76,76,65,84,69,95,71,69,79,77,69,84,82,89,32,124,32,67,72,69,67,75,95,71,69,79,77,69,84,82,89,32,124,32,32,70,76,65,84,84,69,78,95,66,73,76,76,66,79,65,82,68,83,32,124,32,84,69,88,84,85,82,69,95,65,84,76,65,83,95,66,85,73,76,68,69,82,32,124,32,83,84,65,84,73,67,95,79,66,74,69,67,84,95,68,69,84,69,67,84,73,79,78,32,124,32,73,78,68,69,88,95,77,69,83,72,32,124,32,86,69,82,84,69,88,95,80,79,83,84,84,82,65,78,83,70,79,82,77,32,124,32,86,69,82,84,69,88,95,80,82,69,84,82,65,78,83,70,79,82,77,32,124,32,66,85,70,70,69,82,95,79,66,74,69,67,84,95,83,69,84,84,73,78,71,83,0,78,55,111,115,103,85,116,105,108,49,52,82,97,121,73,110,116,101,114,115,101,99,116,111,114,69,0,102,105,110,105,115,104,101,100,32,115,101,97,114,99,104,105,110,103,32,102,111,114,32,111,99,99,108,117,100,101,114,32,45,32,102,111,117,110,100,32,0,78,55,111,115,103,85,116,105,108,49,48,83,116,97,116,101,71,114,97,112,104,69,0,87,97,114,110,105,110,103,58,32,83,99,101,110,101,86,105,101,119,58,58,100,114,97,119,40,41,32,45,32,86,69,82,84,73,67,65,76,95,73,78,84,69,82,76,65,67,69,44,32,72,79,82,73,90,79,78,84,65,76,95,73,78,84,69,82,76,65,67,69,44,32,97,110,100,32,67,72,69,67,75,69,82,66,79,65,82,68,32,115,116,101,114,101,111,32,110,111,116,32,115,117,112,112,111,114,116,101,100,46,0,87,97,114,110,105,110], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+102652);
/* memory initializer */ allocate([103,58,32,115,116,101,114,101,111,32,109,111,100,101,32,110,111,116,32,105,109,112,108,101,109,101,110,116,101,100,32,121,101,116,46,0,101,110,100,32,111,102,32,83,99,101,110,101,86,105,101,119,58,58,100,114,97,119,40,41,0,87,97,114,110,105,110,103,58,32,110,111,32,118,97,108,105,100,32,111,115,103,85,116,105,108,58,58,83,99,101,110,101,86,105,101,119,58,58,95,115,116,97,116,101,32,97,116,116,97,99,104,101,100,44,32,99,114,101,97,116,105,110,103,32,97,32,100,101,102,97,117,108,116,32,115,116,97,116,101,32,97,117,116,111,109,97,116,105,99,97,108,108,121,46,0,87,97,114,110,105,110,103,58,32,110,111,32,118,97,108,105,100,32,111,115,103,85,116,105,108,58,58,83,99,101,110,101,86,105,101,119,58,58,32,97,116,116,97,99,104,101,100,44,32,99,114,101,97,116,105,110,103,32,97,32,100,101,102,97,117,108,116,32,67,117,108,108,86,105,115,105,116,111,114,32,97,117,116,111,109,97,116,105,99,97,108,108,121,46,0,87,97,114,110,105,110,103,58,32,110,111,32,118,97,108,105,100,32,111,115,103,85,116,105,108,58,58,83,99,101,110,101,86,105,101,119,58,58,32,97,116,116,97,99,104,101,100,44,32,99,114,101,97,116,105,110,103,32,97,32,103,108,111,98,97,108,32,100,101,102,97,117,108,116,32,83,116,97,116,101,71,114,97,112,104,32,97,117,116,111,109,97,116,105,99,97,108,108,121,46,0,87,97,114,110,105,110,103,58,32,110,111,32,118,97,108,105,100,32,111,115,103,85,116,105,108,58,58,83,99,101,110,101,86,105,101,119,58,58,95,114,101,110,100,101,114,83,116,97,103,101,32,97,116,116,97,99,104,101,100,44,32,99,114,101,97,116,105,110,103,32,97,32,100,101,102,97,117,108,116,32,82,101,110,100,101,114,83,116,97,103,101,32,97,117,116,111,109,97,116,105,99,97,108,108,121,46,0,111,115,103,95,70,114,97,109,101,78,117,109,98,101,114,0,111,115,103,95,70,114,97,109,101,84,105,109,101,0,111,115,103,95,68,101,108,116,97,70,114,97,109,101,84,105,109,101,0,111,115,103,95,83,105,109,117,108,97,116,105,111,110,84,105,109,101,0,111,115,103,95,68,101,108,116,97,83,105,109,117,108,97,116,105,111,110,84,105,109,101,0,111,115,103,95,86,105,101,119,77,97,116,114,105,120,0,111,115,103,95,86,105,101,119,77,97,116,114,105,120,73,110,118,101,114,115,101,0,83,99,101,110,101,86,105,101,119,0,87,97,114,110,105,110,103,58,32,97,116,116,101,109,112,116,32,116,111,32,97,115,115,105,103,110,32,97,32,78,85,76,76,32,99,97,109,101,114,97,32,116,111,32,83,99,101,110,101,86,105,101,119,32,110,111,116,32,112,101,114,109,105,116,116,101,100,46,0,78,55,111,115,103,85,116,105,108,57,83,99,101,110,101,86,105,101,119,69,0,47,47,32,83,104,97,100,101,114,71,101,110,32,115,104,97,100,101,114,10,0,35,105,102,100,101,102,32,71,76,95,69,83,10,32,32,32,32,112,114,101,99,105,115,105,111,110,32,104,105,103,104,112,32,102,108,111,97,116,59,10,35,101,110,100,105,102,10,0,118,97,114,121,105,110,103,32,118,101,99,51,32,110,111,114,109,97,108,68,105,114,59,10,0,118,97,114,121,105,110,103,32,118,101,99,51,32,108,105,103,104,116,68,105,114,59,10,0,118,97,114,121,105,110,103,32,118,101,99,51,32,118,105,101,119,68,105,114,59,10,0,118,97,114,121,105,110,103,32,118,101,99,52,32,118,101,114,116,101,120,67,111,108,111,114,59,10,0,100,105,102,102,117,115,101,77,97,112,0,117,110,105,102,111,114,109,32,115,97,109,112,108,101,114,50,68,32,100,105,102,102,117,115,101,77,97,112,59,10,0,110,111,114,109,97,108,77,97,112,0,117,110,105,102,111,114,109,32,115,97,109,112,108,101,114,50,68,32,110,111,114,109,97,108,77,97,112,59,10,0,116,97,110,103,101,110,116,0,97,116,116,114,105,98,117,116,101,32,118,101,99,51,32,116,97,110,103,101,110,116,59,10,0,10,118,111,105,100,32,109,97,105,110,40,41,10,123,10,32,32,103,108,95,80,111,115,105,116,105,111,110,32,61,32,102,116,114,97,110,115,102,111,114,109,40,41,59,10,0,32,32,103,108,95,84,101,120,67,111,111,114,100,91,48,93,32,61,32,103,108,95,77,117,108,116,105,84,101,120,67,111,111,114,100,48,59,10,0,32,32,118,101,99,51,32,110,32,61,32,103,108,95,78,111,114,109,97,108,77,97,116,114,105,120,32,42,32,103,108,95,78,111,114,109,97,108,59,10,32,32,118,101,99,51,32,116,32,61,32,103,108,95,78,111,114,109,97,108,77,97,116,114,105,120,32,42,32,116,97,110,103,101,110,116,59,10,32,32,118,101,99,51,32,98,32,61,32,99,114,111,115,115,40,110,44,32,116,41,59,10,32,32,118,101,99,51,32,100,105,114,32,61,32,45,118,101,99,51,40,103,108,95,77,111,100,101,108,86,105,101,119,77,97,116,114,105,120,32,42,32,103,108,95,86,101,114,116,101,120,41,59,10,32,32,118,105,101,119,68,105,114,46,120,32,61,32,100,111,116,40,100,105,114,44,32,116,41,59,10,32,32,118,105,101,119,68,105,114,46,121,32,61,32,100,111,116,40,100,105,114,44,32,98,41,59,10,32,32,118,105,101,119,68,105,114,46,122,32,61,32,100,111,116,40,100,105,114,44,32,110,41,59,10,32,32,118,101,99,52,32,108,112,111,115,32,61,32,103,108,95,76,105,103,104,116,83,111,117,114,99,101,91,48,93,46,112,111,115,105,116,105,111,110,59,10,32,32,105,102,32,40,108,112,111,115,46,119,32,61,61,32,48,46,48,41,10,32,32,32,32,100,105,114,32,61,32,108,112,111,115,46,120,121,122,59,10,32,32,101,108,115,101,10,32,32,32,32,100,105,114,32,43,61,32,108,112,111,115,46,120,121,122,59,10,32,32,108,105,103,104,116,68,105,114,46,120,32,61,32,100,111,116,40,100,105,114,44,32,116,41,59,10,32,32,108,105,103,104,116,68,105,114,46,121,32,61,32,100,111,116,40,100,105,114,44,32,98,41,59,10,32,32,108,105,103,104,116,68,105,114,46,122,32,61,32,100,111,116,40,100,105,114,44,32,110,41,59,10,0,32,32,118,101,114,116,101,120,67,111,108,111,114,32,61,32,103,108,95,67,111,108,111,114,59,10,0,125,10,0,10,118,111,105,100,32,109,97,105,110,40,41,10,123,10,0,32,32,118,101,99,52,32,98,97,115,101,32,61,32,118,101,114,116,101,120,67,111,108,111,114,32,42,32,116,101,120,116,117,114,101,50,68,40,100,105,102,102,117,115,101,77,97,112,44,32,103,108,95,84,101,120,67,111,111,114,100,91,48,93,46,115,116,41,59,10,0,32,32,118,101,99,52,32,98,97,115,101,32,61,32,118,101,114,116,101,120,67,111,108,111,114,59,10,0,32,32,118,101,99,51,32,110,111,114,109,97,108,68,105,114,32,61,32,116,101,120,116,117,114,101,50,68,40,110,111,114,109,97,108,77,97,112,44,32,103,108,95,84,101,120,67,111,111,114,100,91,48,93,46,115,116,41,46,120,121,122,42,50,46,48,45,49,46,48,59,10,0,32,32,118,101,99,52,32,99,111,108,111,114,32,61,32,98,97,115,101,59,10,0,32,32,103,108,95,70,114,97,103,67,111,108,111,114,32,61,32,99,111,108,111,114,59,10,0,83,104,97,100,101,114,71,101,110,67,97,99,104,101,32,86,101,114,116,101,120,32,115,104,97,100,101,114,58,10,0,83,104,97,100,101,114,71,101,110,67,97,99,104,101,32,70,114,97,103,109,101,110,116,32,115,104,97,100,101,114,58,10,0,78,83,116,51,95,95,50,49,57,98,97,115,105,99,95,111,115,116,114,105,110,103,115,116,114,101,97,109,73,99,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,99,69,69,78,83,95,57,97,108,108,111,99,97,116,111,114,73,99,69,69,69,69,0,78,55,111,115,103,85,116,105,108,49,54,83,104,97,100,101,114,71,101,110,86,105,115,105,116,111,114,69,0,78,55,111,115,103,85,116,105,108,55,83,116,97,116,101,69,120,69,0,78,55,111,115,103,85,116,105,108,49,52,83,104,97,100,101,114,71,101,110,67,97,99,104,101,69,0,78,55,111,115,103,85,116,105,108,49,48,83,116,97,116,105,115,116,105,99,115,69,0,83,116,97,116,115,86,105,115,105,116,111,114,0,79,98,106,101,99,116,32,84,121,112,101,0,85,110,105,113,117,101,0,73,110,115,116,97,110,99,101,100,0,68,121,110,97,109,105,99,0,45,45,45,45,45,45,45,45,45,45,45,0,45,45,45,45,45,45,0,45,45,45,45,45,45,45,45,45,0,83,116,97,116,101,83,101,116,32,32,32,0,32,32,98,105,110,32,49,48,32,32,32,0,32,32,111,116,104,101,114,32,98,105,110,0,71,114,111,117,112,32,32,32,32,32,32,0,84,114,97,110,115,102,111,114,109,32,32,0,76,79,68,32,32,32,32,32,32,32,32,0,83,119,105,116,99,104,32,32,32,32,32,0,71,101,111,100,101,32,32,32,32,32,32,0,68,114,97,119,97,98,108,101,32,32,32,0,71,101,111,109,101,116,114,121,32,32,32,0,70,97,115,116,32,103,101,111,109,46,32,0,86,101,114,116,105,99,101,115,32,32,32,0,80,114,105,109,105,116,105,118,101,115,32,0,78,55,111,115,103,85,116,105,108,49,50,83,116,97,116,115,86,105,115,105,116,111,114,69,0,78,51,111,115,103,50,49,80,114,105,109,105,116,105,118,101,73,110,100,101,120,70,117,110,99,116,111,114,69,0,85,112,100,97,116,101,86,105,115,105,116,111,114,0,78,55,111,115,103,85,116,105,108,49,51,85,112,100,97,116,101,86,105,115,105,116,111,114,69,0,67,117,108,108,86,105,115,105,116,111,114,0,95,99,108,97,109,112,80,114,111,106,101,99,116,105,111,110,77,97,116,114,105,120,32,110,111,116,32,97,112,112,108,105,101,100,44,32,105,110,118,97,108,105,100,32,100,101,112,116,104,32,114,97,110,103,101,44,32,122,110,101,97,114,32,61,32,0,32,32,122,102,97,114,32,61,32,0,84,114,105,97,110,103,108,101,32,70,117,110,99,116,111,114,32,100,111,101,115,32,110,111,116,32,115,117,112,112,111,114,116,32,86,101,99,52,100,42,32,118,101,114,116,101,120,32,97,114,114,97,121,115,0,84,114,105,97,110,103,108,101,32,70,117,110,99,116,111,114,32,100,111,101,115,32,110,111,116,32,115,117,112,112,111,114,116,32,86,101,99,51,100,42,32,118,101,114,116,101,120,32,97,114,114,97,121,115,0,84,114,105,97,110,103,108,101,32,70,117,110,99,116,111,114,32,100,111,101,115,32,110,111,116,32,115,117,112,112,111,114,116,32,86,101,99,50,100,42,32,118,101,114,116,101,120,32,97,114,114,97,121,115,0,84,114,105,97,110,103,108,101,32,70,117,110,99,116,111,114,32,100,111,101,115,32,110,111,116,32,115,117,112,112,111,114,116,32,86,101,99,52,42,32,118,101,114,116,101,120,32,97,114,114,97,121,115,0,84,114,105,97,110,103,108,101,32,70,117,110,99,116,111,114,32,100,111,101,115,32,110,111,116,32,115,117,112,112,111,114,116,32,86,101,99,50,42,32,118,101,114,116,101,120,32,97,114,114,97,121,115,0,78,51,111,115,103,50,52,84,101,109,112,108,97,116,101,80,114,105,109,105,116,105,118,101,70,117,110,99,116,111,114,73,50,49,67,111,109,112,117,116,101,78,101,97,114,70,97,114,70,117,110,99,116,111,114,73,49,55,71,114,101,97,116,101,114,67,111,109,112,97,114,97,116,111,114,69,69,69,0,50,49,67,111,109,112,117,116,101,78,101,97,114,70,97,114,70,117,110,99,116,111,114,73,49,55,71,114,101,97,116,101,114,67,111,109,112,97,114,97,116,111,114,69,0,78,51,111,115,103,50,52,84,101,109,112,108,97,116,101,80,114,105,109,105,116,105,118,101,70,117,110,99,116,111,114,73,50,49,67,111,109,112,117,116,101,78,101,97,114,70,97,114,70,117,110,99,116,111,114,73,49,52,76,101,115,115,67,111,109,112,97,114,97,116,111,114,69,69,69,0,50,49,67,111,109,112,117,116,101,78,101,97,114,70,97,114,70,117,110,99,116,111,114,73,49,52,76,101,115,115,67,111,109,112,97,114,97,116,111,114,69,0,82,101,110,100,101,114,83,116,97,103,101,67,97,99,104,101,0,78,55,111,115,103,85,116,105,108,49,54,82,101,110,100,101,114,83,116,97,103,101,67,97,99,104,101,69,0,67,117,108,108,86,105,115,105,116,111,114,58,58,97,112,112,108,121,40,66,105,108,108,98,111,97,114,100,38,41,32,100,101,116,101,99,116,101,100,32,78,97,78,44,0,32,32,32,32,100,101,112,116,104,61,0,44,32,112,111,115,61,40,0,41,44,0,32,32,32,32,42,98,105,108,108,98,111,97,114,100,95,109,97,116,114,105,120,61,0,32,32,32,32,78,111,100,101,80,97,116,104,58,0,32,32,32,32,32,32,32,32,34,0,87,97,114,110,105,110,103,58,99,114,101,97,116,101,79,114,82,101,117,115,101,82,101,110,100,101,114,76,101,97,102,40,41,32,115,107,105,112,112,105,110,103,32,109,117,108,116,105,112,108,121,32,114,101,102,114,101,110,99,101,100,32,101,110,116,114,121,46,0,87,97,114,110,105,110,103,58,32,67,117,108,108,86,105,115,105,116,111,114,58,58,117,112,100,97,116,101,67,97,108,99,117,108,97,116,101,100,78,101,97,114,70,97,114,40,46,41,32,110,101,97,114,62,102,97,114,32,105,110,32,114,97,110,103,101,32,99,97,108,99,117,108,97,116,105,111,110,44,0,32,32,32,32,32,32,32,32,32,99,111,114,114,101,99,116,105,110,103,32,98,121,32,115,119,97,112,112,105,110,103,32,118,97,108,117,101,115,32,100,95,110,101,97,114,61,0,32,100,102,97,114,61,0,67,117,108,108,86,105,115,105,116,111,114,58,58,97,112,112,108,121,40,71,101,111,100,101,38,41,32,100,101,116,101,99,116,101,100,32,78,97,78,44,0,44,32,99,101,110,116,101,114,61,40,0,32,32,32,32,109,97,116,114,105,120,61,0,78,55,111,115,103,85,116,105,108,49,49,67,117,108,108,86,105,115,105,116,111,114,69,0,78,51,111,115,103,49,49,77,105,120,105,110,86,101,99,116,111,114,73,106,69,69,0,80,114,105,109,105,116,105,118,101,83,101,116,0,78,51,111,115,103,49,50,68,114,97,119,69,108,101,109,101,110,116,115,69,0,78,51,111,115,103,49,51,84,101,109,112,108,97,116,101,65,114,114,97,121,73,100,76,78,83,95,53,65,114,114,97,121,52,84,121,112,101,69,56,69,76,105,49,69,76,105,53,49,51,48,69,69,69,0,78,51,111,115,103,49,49,77,105,120,105,110,86,101,99,116,111,114,73,100,69,69,0,78,51,111,115,103,49,48,73,110,100,101,120,65,114,114,97,121,69,0,78,51,111,115,103,49,56,84,101,109,112,108,97,116,101,73,110,100,101,120,65,114,114,97,121,73,106,76,78,83,95,53,65,114,114,97,121,52,84,121,112,101,69,54,69,76,105,49,69,76,105,53,49,50,53,69,69,69,0,78,51,111,115,103,49,49,77,105,120,105,110,86,101,99,116,111,114,73,116,69,69,0,78,51,111,115,103,49,49,77,105,120,105,110,86,101,99,116,111,114,73,104,69,69,0,78,51,111,115,103,49,56,84,101,109,112,108,97,116,101,73,110,100,101,120,65,114,114,97,121,73,105,76,78,83,95,53,65,114,114,97,121,52,84,121,112,101,69,51,69,76,105,49,69,76,105,53,49,50,52,69,69,69,0,78,51,111,115,103,49,49,77,105,120,105,110,86,101,99,116,111,114,73,105,69,69,0,80,111,115,105,116,105,111,110,97,108,83,116,97,116,101,67,111,110,116,97,105,110,101,114,0,78,55,111,115,103,85,116,105,108,50,52,80,111,115,105,116,105,111,110,97,108,83,116,97,116,101,67,111,110,116,97,105,110,101,114,69,0,87,97,114,110,105,110,103,58,32,82,101,110,100,101,114,66,105,110,58,58,99,111,112,121,76,101,97,118,101,115,70,114,111,109,83,116,97,116,101,71,114,97,112,104,76,105,115,116,84,111,82,101,110,100,101,114,76,101,97,102,76,105,115,116,40,41,32,100,101,116,101,99,116,101,100,32,78,97,78,32,100,101,112,116,104,32,118,97,108,117,101,115,44,32,100,97,116,97,98,97,115,101,32,109,97,121,32,98,101,32,99,111,114,114,117,112,116,101,100,46,0,82,101,110,100,101,114,66,105,110,0,111,115,103,85,116,105,108,0,79,83,71,95,68,69,70,65,85,76,84,95,66,73,78,95,83,79,82,84,95,77,79,68,69,0,83,79,82,84,95,66,89,95,83,84,65,84,69,0,83,79,82,84,95,66,89,95,83,84,65,84,69,95,84,72,69,78,95,70,82,79,78,84,95,84,79,95,66,65,67,75,0,83,79,82,84,95,70,82,79,78,84,95,84,79,95,66,65,67,75,0,83,79,82,84,95,66,65,67,75,95,84,79,95,70,82,79,78,84,0,84,82,65,86,69,82,83,65,76,95,79,82,68,69,82,0,78,55,111,115,103,85,116,105,108,57,82,101,110,100,101,114,66,105,110,69,0,79,83,71,95,68,69,70,65,85,76,84,95,66,73,78,95,83,79,82,84,95,77,79,68,69,32,60,116,121,112,101,62,0,83,79,82,84,95,66,89,95,83,84,65,84,69,32,124,32,83,79,82,84,95,66,89,95,83,84,65,84,69,95,84,72,69,78,95,70,82,79,78,84,95,84,79,95,66,65,67,75,32,124,32,83,79,82,84,95,70,82,79,78,84,95,84,79,95,66,65,67,75,32,124,32,83,79,82,84,95,66,65,67,75,95,84,79,95,70,82,79,78,84,0,83,116,97,116,101,83,111,114,116,101,100,66,105,110,0,68,101,112,116,104,83,111,114,116,101,100,66,105,110,0,84,114,97,118,101,114,115,97,108,79,114,100,101,114,66,105,110,0,50,50,82,101,110,100,101,114,66,105,110,80,114,111,116,111,116,121,112,101,76,105,115,116,0,78,83,116,51,95,95,50,51,109,97,112,73,78,83,95,49,50,98,97,115,105,99,95,115,116,114,105,110,103,73,99,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,99,69,69,78,83,95,57,97,108,108,111,99,97,116,111,114,73,99,69,69,69,69,78,51,111,115,103,55,114,101,102,95,112,116,114,73,78,55,111,115,103,85,116,105,108,57,82,101,110,100,101,114,66,105,110,69,69,69,78,83,95,52,108,101,115,115,73,83,54,95,69,69,78,83,52,95,73,78,83,95,52,112,97,105,114,73,75,83,54,95,83,66,95,69,69,69,69,69,69,0,78,51,111,115,103,49,48,100,101,112,101,110,100,115,95,111,110,73,80,78,49,49,79,112,101,110,84,104,114,101,97,100,115,53,77,117,116,101,120,69,88,97,100,76,95,90,78,83,95,49,48,82,101,102,101,114,101,110,99,101,100,50,52,103,101,116,71,108,111,98,97,108,82,101,102,101,114,101,110,99,101,100,77,117,116,101,120,69,118,69,69,69,69,0,87,97,114,110,105,110,103,58,32,82,101,110,100,101,114,66,105,110,32,34,0,34,32,105,109,112,108,101,109,101,110,116,97,116,105,111,110,32,110,111,116,32,102,111,117,110,100,44,32,117,115,105,110,103,32,100,101,102,97,117,108,116,32,82,101,110,100,101,114,66,105,110,32,97,115,32,97,32,102,97,108,108,98,97,99,107,46,0,78,55,111,115,103,85,116,105,108,49,48,82,101,110,100,101,114,76,101,97,102,69,0,97,102,116,101,114,32,82,101,110,100,101,114,66,105,110,58,58,100,114,97,119,40,46,46,41,0,82,101,110,100,101,114,83,116,97,103,101,58,58,100,114,97,119,73,110,110,101,114,40,44,41,32,70,66,79,32,115,116,97,116,117,115,32,61,32,48,120,0,65,116,116,101,109,112,116,105,110,103,32,116,111,32,114,101,97,100,32,102,114,111,109,32,97,32,109,117,108,116,105,115,97,109,112,108,101,100,32,102,114,97,109,101,98,117,102,102,101,114,32,111,98,106,101,99,116,46,32,83,101,116,32,97,32,114,101,115,111,108,118,101,32,102,114,97,109,101,98,117,102,102,101,114,32,111,110,32,116,104,101,32,82,101,110,100,101,114,83,116,97,103,101,32,116,111,32,102,105,120,32,116,104,105,115,46,0,69,114,114,111,114,58,32,99,97,110,110,111,116,32,100,114,97,119,32,115,116,97,103,101,32,100,117,101,32,116,111,32,117,110,100,101,102,105,110,101,100,32,118,105,101,119,112,111,114,116,46,0,68,114,97,119,73,110,110,101,114,83,116,97,103,101,0,49,56,68,114,97,119,73,110,110,101,114,79,112,101,114,97,116,105,111,110,0,82,101,110,100,101,114,83,116,97,103,101,58,58,114,117,110,67,97,109,101,114,97,83,101,116,85,112,40,111,115,103,58,58,82,101,110,100,101,114,73,110,102,111,38,32,114,101,110,100,101,114,73,110,102,111,41,32,0,83,101,116,116,105,110,103,32,117,112,32,111,115,103,58,58,67,97,109,101,114,97,58,58,70,82,65,77,69,95,66,85,70,70,69,82,95,79,66,74,69,67,84,0,77,117,108,116,105,115,97,109,112,108,101,32,99,111,108,111,114,32,115,97,109,112,108,101,115,32,109,117,115,116,32,98,101,32,108,101,115,115,32,116,104,97,110,32,111,114,32,101,113,117,97,108,32,116,111,32,115,97,109,112,108,101,115,46,32,83,101,116,116,105,110,103,32,99,111,108,111,114,32,115,97,109,112,108,101,115,32,101,113,117,97,108,32,116,111,32,115,97,109,112,108,101,115,46,0,82,101,110,100,101,114,83,116,97,103,101,58,58,114,117,110,67,97,109,101,114,97,83,101,116,85,112,40,41,44,32,70,66,79,32,115,101,116,117,112,32,102,97,105,108,101,100,44,32,70,66,79,32,115,116,97,116,117,115,61,32,48,120,0,82,101,110,100,101,114,83,116,97,103,101,58,58,114,117,110,67,97,109,101,114,97,83,101,116,85,112,40,41,44,32,109,117,108,116,105,115,97,109,112,108,101,32,70,66,79,32,115,101,116,117,112,32,102,97,105,108,101,100,44,32,70,66,79,32,115,116,97,116,117,115,32,61,32,48,120,0,87,71,76,95,65,82,66,95,114,101,110,100,101,114,95,116,101,120,116,117,114,101,0,87,97,114,110,105,110,103,58,32,82,101,110,100,101,114,83,116,97,103,101,58,58,114,117,110,67,97,109,101,114,97,83,101,116,85,112,40,83,116,97,116,101,38,41,32,87,105,110,100,111,119,32,0,87,97,114,110,105,110,103,58,32,82,101,110,100,101,114,83,116,97,103,101,58,58,114,117,110,67,97,109,101,114,97,83,101,116,85,112,40,83,116,97,116,101,38,41,32,80,98,117,102,102,101,114,32,0,100,111,101,115,32,110,111,116,32,115,117,112,112,111,114,116,32,109,117,108,116,105,112,108,101,32,99,111,108,111,114,32,111,117,116,112,117,116,115,46,0,82,101,110,100,101,114,83,116,97,103,101,58,58,114,117,110,67,97,109,101,114,97,83,101,116,85,112,40,83,116,97,116,101,38,41,32,67,111,110,116,101,120,116,32,104,97,115,32,98,101,101,110,32,114,101,97,108,105,122,101,100,32,0,82,101,110,100,101,114,83,116,97,103,101,58,58,114,117,110,67,97,109,101,114,97,83,101,116,85,112,40,83,116,97,116,101,38,41,32,65,115,115,105,103,110,32,103,114,97,112,104,105,115,32,99,111,110,116,101,120,116,32,116,111,32,84,101,120,116,117,114,101,0,82,101,110,100,101,114,83,116,97,103,101,58,58,114,117,110,67,97,109,101,114,97,83,101,116,85,112,40,83,116,97,116,101,38,41,32,65,115,115,105,103,110,105,110,103,32,116,101,120,116,117,114,101,32,116,111,32,82,101,110,100,101,114,83,116,97,103,101,32,115,111,32,116,104,97,116,32,105,116,32,100,111,101,115,32,116,104,101,32,99,111,112,121,0,70,97,105,108,101,100,32,116,111,32,97,99,113,117,105,114,101,32,71,114,97,112,104,105,99,115,32,67,111,110,116,101,120,116,0,83,101,116,116,105,110,103,32,117,112,32,111,115,103,58,58,67,97,109,101,114,97,58,58,70,82,65,77,69,95,66,85,70,70,69,82,0,82,101,110,100,101,114,83,116,97,103,101,0,78,55,111,115,103,85,116,105,108,49,49,82,101,110,100,101,114,83,116,97,103,101,69,0,78,51,111,115,103,49,54,65,112,112,108,105,99,97,116,105,111,110,85,115,97,103,101,69,0,65,114,114,97,121,58,58,99,108,97,115,115,78,97,109,101,40,41,58,32,85,110,107,110,111,119,110,32,97,114,114,97,121,32,116,121,112,101,32,0,85,110,107,110,111,119,110,65,114,114,97,121,0,65,114,114,97,121,0,86,101,99,50,65,114,114,97,121,0,86,101,99,51,65,114,114,97,121,0,86,101,99,52,65,114,114,97,121,0,77,97,116,114,105,120,65,114,114,97,121,0,77,97,116,114,105,120,100,65,114,114,97,121,0,81,117,97,116,65,114,114,97,121,0,85,73,110,116,54,52,65,114,114,97,121,0,73,110,116,54,52,65,114,114,97,121,0,78,51,111,115,103,53,65,114,114,97,121,69,0,78,51,111,115,103,49,52,71,76,66,117,102,102,101,114,79,98,106,101,99,116,69,0,78,51,111,115,103,49,55,71,76,66,117,102,102,101,114,79,98,106,101,99,116,83,101,116,69,0,71,76,66,117,102,102,101,114,79,98,106,101,99,116,58,58,100,101,108,101,116,101,71,76,79,98,106,101,99,116,40,41,32,0,80,108,101,110,116,121,32,111,102,32,115,112,97,99,101,32,105,110,32,71,76,66,117,102,102,101,114,79,98,106,101,99,116,32,112,111,111,108,0,95,112,97,114,101,110,116,45,62,103,101,116,67,117,114,114,71,76,66,117,102,102,101,114,79,98,106,101,99,116,80,111,111,108,83,105,122,101,40,41,61,0,32,95,112,97,114,101,110,116,45,62,103,101,116,77,97,120,71,76,66,117,102,102,101,114,79,98,106,101,99,116,80,111,111,108,83,105,122,101,40,41,61,0,71,76,66,117,102,102,101,114,79,98,106,101,99,116,77,97,110,97,110,103,101,114,58,58,114,101,99,111,109,112,117,116,101,83,116,97,116,115,40,41,0,32,32,32,103,101,116,77,97,120,71,76,66,117,102,102,101,114,79,98,106,101,99,116,80,111,111,108,83,105,122,101,40,41,61,0,44,32,111,115,45,62,99,111,109,112,117,116,101,78,117,109,71,76,66,117,102,102,101,114,79,98,106,101,99,116,115,73,110,76,105,115,116,40,41,0,44,32,111,115,45,62,103,101,116,78,117,109,79,102,71,76,66,117,102,102,101,114,79,98,106,101,99,116,115,40,41,0,71,76,66,117,102,102,101,114,79,98,106,101,99,116,77,97,110,97,110,103,101,114,58,58,114,101,112,111,114,116,83,116,97,116,115,40,41,0,32,32,32,116,111,116,97,108,32,95,110,117,109,79,102,71,76,66,117,102,102,101,114,79,98,106,101,99,116,115,61,0,44,32,95,110,117,109,79,114,112,104,97,110,101,100,71,76,66,117,102,102,101,114,79,98,106,101,99,116,115,61,0,32,95,99,117,114,114,71,76,66,117,102,102,101,114,79,98,106,101,99,116,80,111,111,108,83,105,122,101,61,0,32,32,32,116,111,116,97,108,32,95,110,117,109,65,112,112,108,105,101,100,61,0,44,32,95,97,112,112,108,121,84,105,109,101,61,0,78,51,111,115,103,50,49,71,76,66,117,102,102,101,114,79,98,106,101,99,116,77,97,110,97,103,101,114,69,0,66,117,102,102,101,114,79,98,106,101,99,116,58,58,114,101,108,101,97,115,101,71,76,79,98,106,101,99,116,115,40,0,66,117,102,102,101,114,79,98,106,101,99,116,0,78,51,111,115,103,49,50,66,117,102,102,101,114,79,98,106,101,99,116,69,0,66,117,102,102,101,114,68,97,116,97,58,58,114,101,108,101,97,115,101,71,76,79,98,106,101,99,116,115,40,0,66,117,102,102,101,114,68,97,116,97,0,69,114,114,111,114,32,0,58,58,114,101,109,111,118,101,66,117,102,102,101,114,68,97,116,97,40,0,41,32,111,117,116,32,111,102,32,114,97,110,103,101,46,0,78,51,111,115,103,49,48,66,117,102,102,101,114,68,97,116,97,69,0,86,101,114,116,101,120,66,117,102,102,101,114,79,98,106,101,99,116,0,78,51,111,115,103,49,56,86,101,114,116,101,120,66,117,102,102,101,114,79,98,106,101,99,116,69,0,69,108,101,109,101,110,116,66,117,102,102,101,114,79,98,106,101,99,116,0,78,51,111,115,103,49,57,69,108,101,109,101,110,116,66,117,102,102,101,114,79,98,106,101,99,116,69,0,80,105,120,101,108,66,117,102,102,101,114,79,98,106,101,99,116,0,67,111,110,115,116,114,117,99,116,105,110,103,32,80,105,120,101,108,66,117,102,102,101,114,79,98,106,101,99,116,32,102,111,114,32,105,109,97,103,101,61,0,78,51,111,115,103,49,55,80,105,120,101,108,66,117,102,102,101,114,79,98,106,101,99,116,69,0,71,76,66,117,102,102,101,114,79,98,106,101,99,116,83,101,116,61,0,58,32,82,101,117,115,105,110,103,32,97,110,32,97,99,116,105,118,101,32,71,76,66,117,102,102,101,114,79,98,106,101,99,116,32,0,32,95,110,117,109,79,102,71,76,66,117,102,102,101,114,79,98,106,101,99,116,115,61,0,82,101,117,115,105,110,103,32,97,32,114,101,99,101,110,116,108,121,32,111,114,112,104,97,110,101,100,32,97,99,116,105,118,101,32,71,76,66,117,102,102,101,114,79,98,106,101,99,116,32,0,71,76,66,117,102,102,101,114,79,98,106,101,99,116,83,101,116,58,58,71,76,66,117,102,102,101,114,79,98,106,101,99,116,83,101,116,32,95,112,114,111,102,105,108,101,46,95,115,105,122,101,61,0,66,117,102,102,101,114,79,98,106,101,99,116,58,58,0,58,0,58,58,66,117,102,102,101,114,79,98,106,101,99,116,58,58,99,111,109,112,117,116,101,82,101,113,117,105,114,101,100,66,117,102,102,101,114,83,105,122,101,40,41,32,101,114,114,111,114,44,32,66,117,102,102,101,114,68,97,116,97,32,105,115,32,48,120,48,0,71,76,66,117,102,102,101,114,79,98,106,101,99,116,77,97,110,97,103,101,114,0,110,101,119,84,111,116,97,108,83,105,122,101,61,0,44,32,95,112,114,111,102,105,108,101,46,95,115,105,122,101,61,0,32,32,32,32,65,108,108,111,99,97,116,105,110,103,32,110,101,119,32,103,108,66,117,102,102,101,114,68,97,116,97,40,41,44,32,95,97,108,108,111,99,97,116,101,100,83,105,122,101,61,0,87,97,114,110,105,110,103,58,32,110,101,119,32,77,97,120,71,76,66,117,102,102,101,114,79,98,106,101,99,116,80,111,111,108,83,105,122,101,61,0,32,105,115,32,115,109,97,108,108,101,114,32,116,104,97,110,32,99,117,114,114,101,110,116,32,71,76,66,117,102,102,101,114,79,98,106,101,99,116,80,111,111,108,83,105,122,101,61,0,78,51,111,115,103,49,50,78,111,100,101,67,97,108,108,98,97,99,107,69,0,83,116,97,116,101,65,116,116,114,105,98,117,116,101,67,97,108,108,98,97,99,107,0,78,51,111,115,103,50,50,83,116,97,116,101,65,116,116,114,105,98,117,116,101,67,97,108,108,98,97,99,107,69,0,78,51,111,115,103,49,53,85,110,105,102,111,114,109,67,97,108,108,98,97,99,107,69,0,78,51,111,115,103,50,50,68,114,97,119,97,98,108,101,85,112,100,97,116,101,67,97,108,108,98,97,99,107,69,0,78,51,111,115,103,50,49,68,114,97,119,97,98,108,101,69,118,101,110,116,67,97,108,108,98,97,99,107,69,0,78,51,111,115,103,50,48,68,114,97,119,97,98,108,101,67,117,108,108,67,97,108,108,98,97,99,107,69,0,67,97,109,101,114,97,0,78,51,111,115,103,54,67,97,109,101,114,97,69,0,67,111,108,108,101,99,116,79,99,99,108,117,100,101,114,115,86,105,115,105,116,111,114,0,78,51,111,115,103,50,51,67,111,108,108,101,99,116,79,99,99,108,117,100,101,114,115,86,105,115,105,116,111,114,69,0,67,111,108,111,114,77,97,115,107,0,83,116,97,116,101,65,116,116,114,105,98,117,116,101,0,78,51,111,115,103,57,67,111,108,111,114,77,97,115,107,69,0,67,111,109,112,117,116,101,66,111,117,110,100,115,86,105,115,105,116,111,114,0,78,51,111,115,103,50,48,67,111,109,112,117,116,101,66,111,117,110,100,115,86,105,115,105,116,111,114,69,0,78,51,111,115,103,49,49,67,111,110,116,101,120,116,68,97,116,97,69,0,67,111,110,116,101,120,116,68,97,116,97,0,67,111,110,116,101,120,116,68,97,116,97,58,58,99,114,101,97,116,101,78,101,119,67,111,110,116,101,120,116,73,68,40,41,32,58,32,114,101,117,115,105,110,103,32,99,111,110,116,101,120,116,73,68,61,0,67,111,110,116,101,120,116,68,97,116,97,58,58,99,114,101,97,116,101,78,101,119,67,111,110,116,101,120,116,73,68,40,41,32,99,114,101,97,116,105,110,103,32,99,111,110,116,101,120,116,73,68,61,0,85,112,100,97,116,105,110,103,32,116,104,101,32,77,97,120,78,117,109,98,101,114,79,102,71,114,97,112,104,105,99,115,67,111,110,116,101,120,116,115,32,116,111,32,0,67,111,110,116,101,120,116,68,97,116,97,58,58,105,110,99,114,101,109,101,110,116,67,111,110,116,101,120,116,73,68,85,115,97,103,101,67,111,117,110,116,40,0,41,32,116,111,32,0,67,111,110,116,101,120,116,68,97,116,97,58,58,114,101,103,105,115,116,101,114,71,114,97,112,104,105,99,115,67,111,110,116,101,120,116,32,0,67,111,110,116,101,120,116,68,97,116,97,58,58,117,110,114,101,103,105,115,116,101,114,71,114,97,112,104,105,99,115,67,111,110,116,101,120,116,32,0,67,111,110,116,101,120,116,68,97,116,97,58,58,103,101,116,82,101,103,105,115,116,101,114,101,100,71,114,97,112,104,105,99,115,67,111,110,116,101,120,116,115,32,0,32,99,111,110,116,101,120,116,115,46,115,105,122,101,40,41,61,0,67,111,110,116,101,120,116,68,97,116,97,58,58,99,114,101,97,116,101,67,111,109,112,105,108,101,67,111,110,116,101,120,116,46,0,32,32,32,115,117,99,99,101,101,100,101,100,32,67,111,110,116,101,120,116,68,97,116,97,58,58,99,114,101,97,116,101,67,111,109,112,105,108,101,67,111,110,116,101,120,116,46,0,78,51,111,115,103,54,67,111,112,121,79,112,69,0,78,51,111,115,103,49,48,67,117,108,108,105,110,103,83,101,116,69,0,78,51,111,115,103,49,50,67,117,108,108,83,101,116,116,105,110,103,115,69,0,79,83,71,95,67,79,77,80,85,84,69,95,78,69,65,82,95,70,65,82,95,77,79,68,69,32,60,109,111,100,101,62,0,68,79,95,78,79,84,95,67,79,77,80,85,84,69,95,78,69,65,82,95,70,65,82,32,124,32,67,79,77,80,85,84,69,95,78,69,65,82,95,70,65,82,95,85,83,73,78,71,95,66,79,85,78,68,73,78,71,95,86,79,76,85,77,69,83,32,124,32,67,79,77,80,85,84,69,95,78,69,65,82,95,70,65,82,95,85,83,73,78,71,95,80,82,73,77,73,84,73,86,69,83,0,79,83,71,95,78,69,65,82,95,70,65,82,95,82,65,84,73,79,32,60,102,108,111,97,116,62,0,83,101,116,32,116,104,101,32,114,97,116,105,111,32,98,101,116,119,101,101,110,32,110,101,97,114,32,97,110,100,32,102,97,114,32,112,108,97,110,101,115,32,45,32,109,117,115,116,32,103,114,101,97,116,101,114,32,116,104,97,110,32,48,46,48,32,98,117,116,32,108,101,115,115,32,116,104,97,110,32,49,46,48,46,0,67,117,108,108,83,101,116,116,105,110,103,115,58,58,114,101,97,100,69,110,118,105,114,111,110,109,101,110,116,97,108,86,97,114,105,97,98,108,101,115,40,41,0,79,83,71,95,67,79,77,80,85,84,69,95,78,69,65,82,95,70,65,82,95,77,79,68,69,0,68,79,95,78,79,84,95,67,79,77,80,85,84,69,95,78,69,65,82,95,70,65,82,0,67,79,77,80,85,84,69,95,78,69,65,82,95,70,65,82,95,85,83,73,78,71,95,66,79,85,78,68,73,78,71,95,86,79,76,85,77,69,83,0,67,79,77,80,85,84,69,95,78,69,65,82,95,70,65,82,95,85,83,73,78,71,95,80,82,73,77,73,84,73,86,69,83,0,83,101,116,32,99,111,109,112,117,116,101,32,110,101,97,114,32,102,97,114,32,109,111,100,101,32,116,111,32,0,79,83,71,95,78,69,65,82,95,70,65,82,95,82,65,84,73,79,0,83,101,116,32,110,101,97,114,47,102,97,114,32,114,97,116,105,111,32,116,111,32,0,78,51,111,115,103,57,67,117,108,108,83,116,97,99,107,69,0,78,51,111,115,103,49,53,68,105,115,112,108,97,121,83,101,116,116,105,110,103,115,69,0,79,83,71,95,68,73,83,80,76,65,89,95,84,89,80,69,32,60,116,121,112,101,62,0,77,79,78,73,84,79,82,32,124,32,80,79,87,69,82,87,65,76,76,32,124,32,82,69,65,76,73,84,89,95,67,69,78,84,69,82,32,124,32,72,69,65,68,95,77,79,85,78,84,69,68,95,68,73,83,80,76,65,89,0,79,83,71,95,83,84,69,82,69,79,95,77,79,68,69,32,60,109,111,100,101,62,0,81,85,65,68,95,66,85,70,70,69,82,32,124,32,65,78,65,71,76,89,80,72,73,67,32,124,32,72,79,82,73,90,79,78,84,65,76,95,83,80,76,73,84,32,124,32,86,69,82,84,73,67,65,76,95,83,80,76,73,84,32,124,32,76,69,70,84,95,69,89,69,32,124,32,82,73,71,72,84,95,69,89,69,32,124,32,86,69,82,84,73,67,65,76,95,73,78,84,69,82,76,65,67,69,32,124,32,72,79,82,73,90,79,78,84,65,76,95,73,78,84,69,82,76,65,67,69,0,79,83,71,95,83,84,69,82,69,79,32,60,109,111,100,101,62,0,79,83,71,95,69,89,69,95,83,69,80,65,82,65,84,73,79,78,32,60,102,108,111,97,116,62,0,80,104,121,115,105,99,97,108,32,100,105,115,116,97,110,99,101,32,98,101,116,119,101,101,110,32,101,121,101,115,46,0,79,83,71,95,83,67,82,69,69,78,95,68,73,83,84,65,78,67,69,32,60,102,108,111,97,116,62,0,80,104,121,115,105,99,97,108,32,100,105,115,116,97,110,99,101,32,98,101,116,119,101,101,110,32,101,121,101,115,32,97,110,100,32,115,99,114,101,101,110,46,0,79,83,71,95,83,67,82,69,69,78,95,72,69,73,71,72,84,32,60,102,108,111,97,116,62,0,80,104,121,115,105,99,97,108,32,115,99,114,101,101,110,32,104,101,105,103,104,116,46,0,79,83,71,95,83,67,82,69,69,78,95,87,73,68,84,72,32,60,102,108,111,97,116,62,0,80,104,121,115,105,99,97,108,32,115,99,114,101,101,110,32,119,105,100,116,104,46,0,79,83,71,95,83,80,76,73,84,95,83,84,69,82,69,79,95,72,79,82,73,90,79,78,84,65,76,95,69,89,69,95,77,65,80,80,73,78,71,32,60,109,111,100,101,62,0,76,69,70,84,95,69,89,69,95,76,69,70,84,95,86,73,69,87,80,79,82,84,32,124,32,76,69,70,84,95,69,89,69,95,82,73,71,72,84,95,86,73,69,87,80,79,82,84,0,79,83,71,95,83,80,76,73,84,95,83,84,69,82,69,79,95,72,79,82,73,90,79,78,84,65,76,95,83,69,80,65,82,65,84,73,79,78,32,60,102,108,111,97,116,62,0,78,117,109,98,101,114,32,111,102,32,112,105,120,101,108,115,32,98,101,116,119,101,101,110,32,118,105,101,119,112,111,114,116,115,46,0,79,83,71,95,83,80,76,73,84,95,83,84,69,82,69,79,95,86,69,82,84,73,67,65,76,95,69,89,69,95,77,65,80,80,73,78,71,32,60,109,111,100,101,62,0,76,69,70,84,95,69,89,69,95,84,79,80,95,86,73,69,87,80,79,82,84,32,124,32,76,69,70,84,95,69,89,69,95,66,79,84,84,79,77,95,86,73,69,87,80,79,82,84,0,79,83,71,95,83,80,76,73,84,95,83,84,69,82,69,79,95,65,85,84,79,95,65,68,74,85,83,84,95,65,83,80,69,67,84,95,82,65,84,73,79,32,60,109,111,100,101,62,0,79,70,70,32,124,32,79,78,32,32,68,101,102,97,117,108,116,32,116,111,32,79,70,70,32,116,111,32,99,111,109,112,101,110,115,116,97,116,101,32,102,111,114,32,116,104,101,32,99,111,109,112,114,101,115,115,105,111,110,32,111,102,32,116,104,101,32,97,115,112,101,99,116,32,114,97,116,105,111,32,119,104,101,110,32,118,105,101,119,105,110,103,32,105,110,32,115,112,108,105,116,32,115,99,114,101,101,110,32,115,116,101,114,101,111,46,32,32,78,111,116,101,44,32,105,102,32,121,111,117,32,97,114,101,32,115,101,116,116,105,110,103,32,102,111,118,120,32,97,110,100,32,102,111,118,121,32,101,120,112,108,105,99,105,116,121,108,121,32,79,70,70,32,115,104,111,117,108,100,32,98,101,32,117,115,101,100,46,0,79,83,71,95,83,80,76,73,84,95,83,84,69,82,69,79,95,86,69,82,84,73,67,65,76,95,83,69,80,65,82,65,84,73,79,78,32,60,102,108,111,97,116,62,0,79,83,71,95,77,65,88,95,78,85,77,66,69,82,95,79,70,95,71,82,65,80,72,73,67,83,95,67,79,78,84,69,88,84,83,32,60,105,110,116,62,0,77,97,120,105,109,117,109,32,110,117,109,98,101,114,32,111,102,32,103,114,97,112,104,105,99,115,32,99,111,110,116,101,120,116,115,32,116,111,32,98,101,32,117,115,101,100,32,119,105,116,104,32,97,112,112,108,105,99,97,116,105,111,110,115,46,0,79,83,71,95,67,79,77,80,73,76,69,95,67,79,78,84,69,88,84,83,32,60,109,111,100,101,62,0,79,70,70,32,124,32,79,78,32,68,105,115,97,98,108,101,47,101,110,97,98,108,101,32,116,104,101,32,117,115,101,32,111,102,32,98,97,99,107,103,114,111,117,110,100,32,99,111,109,112,105,108,101,100,32,99,111,110,116,101,120,116,115,32,97,110,100,32,116,104,114,101,97,100,115,46,0,79,83,71,95,83,69,82,73,65,76,73,90,69,95,68,82,65,87,95,68,73,83,80,65,84,67,72,32,60,109,111,100,101,62,0,79,70,70,32,124,32,79,78,32,68,105,115,97,98,108,101,47,101,110,97,98,108,101,32,116,104,101,32,117,115,101,32,111,102,32,97,32,109,117,116,101,120,32,116,111,32,115,101,114,105,97,108,105,122,101,32,116,104,101,32,100,114,97,119,32,100,105,115,112,97,116,99,104,32,119,104,101,110,32,116,104,101,114,101,32,97,114,101,32,109,117,108,116,105,112,108,101,32,103,114,97,112,104,105,99,115,32,116,104,114,101,97,100,115,46,0,79,83,71,95,85,83,69,95,83,67,69,78,69,86,73,69,87,95,70,79,82,95,83,84,69,82,69,79,32,60,109,111,100,101,62,0,79,70,70,32,124,32,79,78,32,68,105,115,97,98,108,101,47,101,110,97,98,108,101,32,116,104,101,32,104,105,110,116,32,116,111,32,117,115,101,32,111,115,103,85,116,105,108,58,58,83,99,101,110,101,86,105,101,119,32,116,111,32,105,109,112,108,101,109,101,110,116,32,115,116,101,114,101,111,32,119,104,101,110,32,114,101,113,117,105,114,101,100,46,46,0,79,83,71,95,78,85,77,95,68,65,84,65,66,65,83,69,95,84,72,82,69,65,68,83,32,60,105,110,116], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+112892);
/* memory initializer */ allocate([62,0,83,101,116,32,116,104,101,32,104,105,110,116,32,102,111,114,32,116,104,101,32,116,111,116,97,108,32,110,117,109,98,101,114,32,111,102,32,116,104,114,101,97,100,115,32,116,111,32,115,101,116,32,117,112,32,105,110,32,116,104,101,32,68,97,116,97,98,97,115,101,80,97,103,101,114,46,0,79,83,71,95,78,85,77,95,72,84,84,80,95,68,65,84,65,66,65,83,69,95,84,72,82,69,65,68,83,32,60,105,110,116,62,0,83,101,116,32,116,104,101,32,104,105,110,116,32,102,111,114,32,116,104,101,32,116,111,116,97,108,32,110,117,109,98,101,114,32,111,102,32,116,104,114,101,97,100,115,32,100,101,100,105,99,97,116,101,100,32,116,111,32,104,116,116,112,32,114,101,113,117,101,115,116,115,32,116,111,32,115,101,116,32,117,112,32,105,110,32,116,104,101,32,68,97,116,97,98,97,115,101,80,97,103,101,114,46,0,79,83,71,95,77,85,76,84,73,95,83,65,77,80,76,69,83,32,60,105,110,116,62,0,83,101,116,32,116,104,101,32,104,105,110,116,32,102,111,114,32,116,104,101,32,110,117,109,98,101,114,32,111,102,32,115,97,109,112,108,101,115,32,116,111,32,117,115,101,32,119,104,101,110,32,109,117,108,116,105,45,115,97,109,112,108,105,110,103,46,0,79,83,71,95,84,69,88,84,85,82,69,95,80,79,79,76,95,83,73,90,69,32,60,105,110,116,62,0,83,101,116,32,116,104,101,32,104,105,110,116,32,102,111,114,32,116,104,101,32,115,105,122,101,32,111,102,32,116,104,101,32,116,101,120,116,117,114,101,32,112,111,111,108,32,116,111,32,109,97,110,97,103,101,46,0,79,83,71,95,66,85,70,70,69,82,95,79,66,74,69,67,84,95,80,79,79,76,95,83,73,90,69,32,60,105,110,116,62,0,83,101,116,32,116,104,101,32,104,105,110,116,32,102,111,114,32,116,104,101,32,115,105,122,101,32,111,102,32,116,104,101,32,118,101,114,116,101,120,32,98,117,102,102,101,114,32,111,98,106,101,99,116,32,112,111,111,108,32,116,111,32,109,97,110,97,103,101,46,0,79,83,71,95,70,66,79,95,80,79,79,76,95,83,73,90,69,32,60,105,110,116,62,0,83,101,116,32,116,104,101,32,104,105,110,116,32,102,111,114,32,116,104,101,32,115,105,122,101,32,111,102,32,116,104,101,32,102,114,97,109,101,32,98,117,102,102,101,114,32,111,98,106,101,99,116,32,112,111,111,108,32,116,111,32,109,97,110,97,103,101,46,0,79,83,71,95,73,77,80,76,73,67,73,84,95,66,85,70,70,69,82,95,65,84,84,65,67,72,77,69,78,84,95,82,69,78,68,69,82,95,77,65,83,75,0,79,70,70,32,124,32,68,69,70,65,85,76,84,32,124,32,91,126,93,67,79,76,79,82,32,124,32,91,126,93,68,69,80,84,72,32,124,32,91,126,93,83,84,69,78,67,73,76,46,32,83,117,98,115,116,105,116,117,116,101,32,109,105,115,115,105,110,103,32,98,117,102,102,101,114,32,97,116,116,97,99,104,109,101,110,116,115,32,102,111,114,32,114,101,110,100,101,114,32,70,66,79,46,0,79,83,71,95,73,77,80,76,73,67,73,84,95,66,85,70,70,69,82,95,65,84,84,65,67,72,77,69,78,84,95,82,69,83,79,76,86,69,95,77,65,83,75,0,79,70,70,32,124,32,68,69,70,65,85,76,84,32,124,32,91,126,93,67,79,76,79,82,32,124,32,91,126,93,68,69,80,84,72,32,124,32,91,126,93,83,84,69,78,67,73,76,46,32,83,117,98,115,116,105,116,117,116,101,32,109,105,115,115,105,110,103,32,98,117,102,102,101,114,32,97,116,116,97,99,104,109,101,110,116,115,32,102,111,114,32,114,101,115,111,108,118,101,32,70,66,79,46,0,79,83,71,95,71,76,95,67,79,78,84,69,88,84,95,86,69,82,83,73,79,78,32,60,109,97,106,111,114,46,109,105,110,111,114,62,0,83,101,116,32,116,104,101,32,104,105,110,116,32,102,111,114,32,116,104,101,32,71,76,32,118,101,114,115,105,111,110,32,116,111,32,99,114,101,97,116,101,32,99,111,110,116,101,120,116,115,32,102,111,114,46,0,79,83,71,95,71,76,95,67,79,78,84,69,88,84,95,70,76,65,71,83,32,60,117,105,110,116,62,0,83,101,116,32,116,104,101,32,104,105,110,116,32,102,111,114,32,116,104,101,32,71,76,32,99,111,110,116,101,120,116,32,102,108,97,103,115,32,116,111,32,117,115,101,32,119,104,101,110,32,99,114,101,97,116,105,110,103,32,99,111,110,116,101,120,116,115,46,0,79,83,71,95,71,76,95,67,79,78,84,69,88,84,95,80,82,79,70,73,76,69,95,77,65,83,75,32,60,117,105,110,116,62,0,83,101,116,32,116,104,101,32,104,105,110,116,32,102,111,114,32,116,104,101,32,71,76,32,99,111,110,116,101,120,116,32,112,114,111,102,105,108,101,32,109,97,115,107,32,116,111,32,117,115,101,32,119,104,101,110,32,99,114,101,97,116,105,110,103,32,99,111,110,116,101,120,116,115,46,0,79,83,71,95,83,87,65,80,95,77,69,84,72,79,68,32,60,109,101,116,104,111,100,62,0,68,69,70,65,85,76,84,32,124,32,69,88,67,72,65,78,71,69,32,124,32,67,79,80,89,32,124,32,85,78,68,69,70,73,78,69,68,46,32,83,101,108,101,99,116,32,112,114,101,102,101,114,114,101,100,32,115,119,97,112,32,109,101,116,104,111,100,46,0,79,83,71,95,75,69,89,83,84,79,78,69,32,79,78,32,124,32,79,70,70,0,83,112,101,99,105,102,121,32,116,104,101,32,104,105,110,116,32,116,111,32,119,104,101,116,104,101,114,32,116,104,101,32,118,105,101,119,101,114,32,115,104,111,117,108,100,32,115,101,116,32,117,112,32,107,101,121,115,116,111,110,101,32,99,111,114,114,101,99,116,105,111,110,46,0,79,83,71,95,75,69,89,83,84,79,78,69,95,70,73,76,69,83,32,60,102,105,108,101,110,97,109,101,62,91,58,102,105,108,101,110,97,109,101,93,46,46,0,83,112,101,99,105,102,121,32,102,105,108,101,110,97,109,101,115,32,111,102,32,107,101,121,115,116,111,110,101,32,112,97,114,97,109,101,116,101,114,32,102,105,108,101,115,46,32,85,110,100,101,114,32,87,105,110,100,111,119,115,32,117,115,101,32,59,32,116,111,32,100,101,108,105,109,105,110,97,116,101,32,102,105,108,101,115,44,32,111,116,104,101,114,119,105,115,101,32,117,115,101,32,58,0,79,83,71,95,77,69,78,85,66,65,82,95,66,69,72,65,86,73,79,82,32,60,98,101,104,97,118,105,111,114,62,0,79,83,88,32,79,110,108,121,32,58,32,83,112,101,99,105,102,121,32,116,104,101,32,98,101,104,97,118,105,111,114,32,111,102,32,116,104,101,32,109,101,110,117,98,97,114,32,40,65,85,84,79,95,72,73,68,69,44,32,70,79,82,67,69,95,72,73,68,69,44,32,70,79,82,67,69,95,83,72,79,87,41,0,79,83,71,95,78,118,79,112,116,105,109,117,115,69,110,97,98,108,101,109,101,110,116,32,60,118,97,108,117,101,62,0,83,101,116,32,116,104,101,32,104,105,110,116,32,116,111,32,78,118,79,112,116,105,109,117,115,32,111,102,32,119,104,101,116,104,101,114,32,116,111,32,101,110,97,98,108,101,32,105,116,32,111,114,32,110,111,116,44,32,115,101,116,32,49,32,116,111,32,101,110,97,98,108,101,44,32,48,32,116,111,32,100,105,115,97,98,108,101,0,79,83,71,95,86,69,82,84,69,88,95,66,85,70,70,69,82,95,72,73,78,84,32,60,118,97,108,117,101,62,0,83,101,116,32,116,104,101,32,104,105,110,116,32,116,111,32,119,104,97,116,32,98,97,99,107,101,110,100,32,111,115,103,58,58,71,101,111,109,101,116,114,121,32,105,109,112,108,101,109,101,110,116,97,116,105,111,110,32,116,111,32,117,115,101,46,32,78,79,95,80,82,69,70,69,82,69,78,67,69,32,124,32,86,69,82,84,69,88,95,66,85,70,70,69,82,95,79,66,74,69,67,84,32,124,32,86,69,82,84,69,88,95,65,82,82,65,89,95,79,66,74,69,67,84,0,79,83,71,95,68,73,83,80,76,65,89,95,84,89,80,69,0,77,79,78,73,84,79,82,0,80,79,87,69,82,87,65,76,76,0,82,69,65,76,73,84,89,95,67,69,78,84,69,82,0,72,69,65,68,95,77,79,85,78,84,69,68,95,68,73,83,80,76,65,89,0,79,83,71,95,83,84,69,82,69,79,95,77,79,68,69,0,81,85,65,68,95,66,85,70,70,69,82,0,65,78,65,71,76,89,80,72,73,67,0,72,79,82,73,90,79,78,84,65,76,95,83,80,76,73,84,0,86,69,82,84,73,67,65,76,95,83,80,76,73,84,0,76,69,70,84,95,69,89,69,0,82,73,71,72,84,95,69,89,69,0,72,79,82,73,90,79,78,84,65,76,95,73,78,84,69,82,76,65,67,69,0,86,69,82,84,73,67,65,76,95,73,78,84,69,82,76,65,67,69,0,67,72,69,67,75,69,82,66,79,65,82,68,0,79,83,71,95,83,84,69,82,69,79,0,79,83,71,95,69,89,69,95,83,69,80,65,82,65,84,73,79,78,0,79,83,71,95,83,67,82,69,69,78,95,87,73,68,84,72,0,79,83,71,95,83,67,82,69,69,78,95,72,69,73,71,72,84,0,79,83,71,95,83,67,82,69,69,78,95,68,73,83,84,65,78,67,69,0,79,83,71,95,83,80,76,73,84,95,83,84,69,82,69,79,95,72,79,82,73,90,79,78,84,65,76,95,69,89,69,95,77,65,80,80,73,78,71,0,76,69,70,84,95,69,89,69,95,76,69,70,84,95,86,73,69,87,80,79,82,84,0,76,69,70,84,95,69,89,69,95,82,73,71,72,84,95,86,73,69,87,80,79,82,84,0,79,83,71,95,83,80,76,73,84,95,83,84,69,82,69,79,95,72,79,82,73,90,79,78,84,65,76,95,83,69,80,65,82,65,84,73,79,78,0,79,83,71,95,83,80,76,73,84,95,83,84,69,82,69,79,95,86,69,82,84,73,67,65,76,95,69,89,69,95,77,65,80,80,73,78,71,0,76,69,70,84,95,69,89,69,95,84,79,80,95,86,73,69,87,80,79,82,84,0,76,69,70,84,95,69,89,69,95,66,79,84,84,79,77,95,86,73,69,87,80,79,82,84,0,79,83,71,95,83,80,76,73,84,95,83,84,69,82,69,79,95,65,85,84,79,95,65,68,74,85,83,84,95,65,83,80,69,67,84,95,82,65,84,73,79,0,79,83,71,95,83,80,76,73,84,95,83,84,69,82,69,79,95,86,69,82,84,73,67,65,76,95,83,69,80,65,82,65,84,73,79,78,0,79,83,71,95,77,65,88,95,78,85,77,66,69,82,95,79,70,95,71,82,65,80,72,73,67,83,95,67,79,78,84,69,88,84,83,0,79,83,71,95,67,79,77,80,73,76,69,95,67,79,78,84,69,88,84,83,0,79,83,71,95,83,69,82,73,65,76,73,90,69,95,68,82,65,87,95,68,73,83,80,65,84,67,72,0,79,83,71,95,85,83,69,95,83,67,69,78,69,86,73,69,87,95,70,79,82,95,83,84,69,82,69,79,0,79,83,71,95,78,85,77,95,68,65,84,65,66,65,83,69,95,84,72,82,69,65,68,83,0,79,83,71,95,78,85,77,95,72,84,84,80,95,68,65,84,65,66,65,83,69,95,84,72,82,69,65,68,83,0,79,83,71,95,77,85,76,84,73,95,83,65,77,80,76,69,83,0,79,83,71,95,84,69,88,84,85,82,69,95,80,79,79,76,95,83,73,90,69,0,79,83,71,95,66,85,70,70,69,82,95,79,66,74,69,67,84,95,80,79,79,76,95,83,73,90,69,0,79,83,71,95,71,76,95,86,69,82,83,73,79,78,0,126,68,69,70,65,85,76,84,0,126,67,79,76,79,82,0,67,79,76,79,82,0,126,68,69,80,84,72,0,126,83,84,69,78,67,73,76,0,83,84,69,78,67,73,76,0,79,83,71,95,71,76,95,67,79,78,84,69,88,84,95,86,69,82,83,73,79,78,0,79,83,71,95,71,76,95,67,79,78,84,69,88,84,95,70,76,65,71,83,0,79,83,71,95,71,76,95,67,79,78,84,69,88,84,95,80,82,79,70,73,76,69,95,77,65,83,75,0,79,83,71,95,83,87,65,80,95,77,69,84,72,79,68,0,69,88,67,72,65,78,71,69,0,67,79,80,89,0,79,83,71,95,83,89,78,67,95,83,87,65,80,95,66,85,70,70,69,82,83,0,79,83,71,95,86,69,82,84,69,88,95,66,85,70,70,69,82,95,72,73,78,84,0,86,69,82,84,69,88,95,66,85,70,70,69,82,95,79,66,74,69,67,84,0,79,83,71,95,86,69,82,84,69,88,95,66,85,70,70,69,82,95,72,73,78,84,32,115,101,116,32,116,111,32,86,69,82,84,69,88,95,66,85,70,70,69,82,95,79,66,74,69,67,84,0,86,69,82,84,69,88,95,65,82,82,65,89,95,79,66,74,69,67,84,0,86,65,79,0,79,83,71,95,86,69,82,84,69,88,95,66,85,70,70,69,82,95,72,73,78,84,32,115,101,116,32,116,111,32,86,69,82,84,69,88,95,65,82,82,65,89,95,79,66,74,69,67,84,0,79,83,71,95,86,69,82,84,69,88,95,66,85,70,70,69,82,95,72,73,78,84,32,115,101,116,32,116,111,32,78,79,95,80,82,69,70,69,82,69,78,67,69,0,79,83,71,95,83,72,65,68,69,82,95,72,73,78,84,0,71,76,50,0,71,76,51,0,71,76,69,83,50,0,71,76,69,83,51,0,78,79,78,69,0,79,83,71,95,75,69,89,83,84,79,78,69,0,79,83,71,95,75,69,89,83,84,79,78,69,95,70,73,76,69,83,0,79,83,71,95,77,69,78,85,66,65,82,95,66,69,72,65,86,73,79,82,0,65,85,84,79,95,72,73,68,69,0,70,79,82,67,69,95,72,73,68,69,0,70,79,82,67,69,95,83,72,79,87,0,79,83,71,95,78,118,79,112,116,105,109,117,115,69,110,97,98,108,101,109,101,110,116,0,68,105,115,112,108,97,121,83,101,116,116,105,110,103,115,58,58,83,72,65,68,69,82,95,71,76,69,83,50,0,49,50,67,111,109,112,117,116,101,66,111,117,110,100,0,87,97,114,110,105,110,103,58,32,68,114,97,119,97,98,108,101,58,58,100,101,108,101,116,101,68,105,115,112,108,97,121,76,105,115,116,40,46,46,41,32,45,32,110,111,116,32,115,117,112,112,111,114,116,101,100,46,0,68,105,115,112,108,97,121,76,105,115,116,77,97,110,97,103,101,114,0,68,105,115,112,108,97,121,76,105,115,116,77,97,110,97,103,101,114,58,58,100,101,108,101,116,101,65,108,108,71,76,79,98,106,101,99,116,115,40,41,32,78,111,116,32,99,117,114,114,101,110,116,108,121,32,105,109,112,108,101,109,101,110,116,97,116,101,100,0,87,97,114,110,105,110,103,58,32,68,114,97,119,97,98,108,101,58,58,102,108,117,115,104,68,101,108,101,116,101,100,68,105,115,112,108,97,121,76,105,115,116,115,40,46,46,41,32,45,32,110,111,116,32,115,117,112,112,111,114,116,101,100,46,0,49,56,68,105,115,112,108,97,121,76,105,115,116,77,97,110,97,103,101,114,0,68,114,97,119,97,98,108,101,0,78,51,111,115,103,56,68,114,97,119,97,98,108,101,69,0,78,51,111,115,103,50,49,71,76,82,101,110,100,101,114,66,117,102,102,101,114,77,97,110,97,103,101,114,69,0,78,51,111,115,103,50,54,71,76,70,114,97,109,101,66,117,102,102,101,114,79,98,106,101,99,116,77,97,110,97,103,101,114,69,0,82,101,110,100,101,114,66,117,102,102,101,114,0,78,51,111,115,103,49,50,82,101,110,100,101,114,66,117,102,102,101,114,69,0,87,97,114,110,105,110,103,58,32,69,88,84,95,102,114,97,109,101,98,117,102,102,101,114,95,111,98,106,101,99,116,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,0,87,97,114,110,105,110,103,58,32,70,114,97,109,101,66,117,102,102,101,114,79,98,106,101,99,116,58,32,99,111,117,108,100,32,110,111,116,32,99,114,101,97,116,101,32,116,104,101,32,70,66,79,0,87,97,114,110,105,110,103,58,32,70,114,97,109,101,66,117,102,102,101,114,79,98,106,101,99,116,58,32,99,111,117,108,100,32,110,111,116,32,115,101,116,32,100,114,97,119,32,98,117,102,102,101,114,115,44,32,103,108,68,114,97,119,66,117,102,102,101,114,115,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,33,0,87,97,114,110,105,110,103,58,32,70,114,97,109,101,66,117,102,102,101,114,79,98,106,101,99,116,58,32,99,111,117,108,100,32,110,111,116,32,97,116,116,97,99,104,32,80,65,67,75,69,68,95,68,69,80,84,72,95,83,84,69,78,67,73,76,95,66,85,70,70,69,82,44,32,69,88,84,95,112,97,99,107,101,100,95,100,101,112,116,104,95,115,116,101,110,99,105,108,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,33,0,67,111,118,101,114,97,103,101,32,115,97,109,112,108,101,115,32,109,117,115,116,32,98,101,32,103,114,101,97,116,101,114,32,116,104,97,110,32,111,114,32,101,113,117,97,108,32,116,111,32,99,111,108,111,114,32,115,97,109,112,108,101,115,46,32,83,101,116,116,105,110,103,32,99,111,118,101,114,97,103,101,32,115,97,109,112,108,101,115,32,101,113,117,97,108,32,116,111,32,99,111,108,111,114,32,115,97,109,112,108,101,115,46,0,70,114,97,109,101,66,117,102,102,101,114,79,98,106,101,99,116,0,78,51,111,115,103,49,55,70,114,97,109,101,66,117,102,102,101,114,79,98,106,101,99,116,69,0,71,76,82,101,110,100,101,114,66,117,102,102,101,114,77,97,110,97,103,101,114,0,71,76,70,114,97,109,101,66,117,102,102,101,114,79,98,106,101,99,116,77,97,110,97,103,101,114,0,69,114,114,111,114,58,32,70,114,97,109,101,66,117,102,102,101,114,65,116,116,97,99,104,109,101,110,116,58,58,70,114,97,109,101,66,117,102,102,101,114,65,116,116,97,99,104,109,101,110,116,40,67,97,109,101,114,97,58,58,65,116,116,97,99,104,109,101,110,116,38,41,32,112,97,115,115,101,100,32,97,110,32,101,109,112,116,121,32,111,115,103,58,58,73,109,97,103,101,44,32,105,109,97,103,101,32,109,117,115,116,32,98,101,32,97,108,108,111,99,97,116,101,100,32,102,105,114,115,116,46,0,69,114,114,111,114,58,32,70,114,97,109,101,66,117,102,102,101,114,65,116,116,97,99,104,109,101,110,116,58,58,70,114,97,109,101,66,117,102,102,101,114,65,116,116,97,99,104,109,101,110,116,40,67,97,109,101,114,97,58,58,65,116,116,97,99,104,109,101,110,116,38,41,32,112,97,115,115,101,100,32,97,110,32,117,110,114,101,99,111,103,110,105,115,101,100,32,84,101,120,116,117,114,101,32,116,121,112,101,46,0,78,51,111,115,103,49,48,70,114,97,109,101,83,116,97,109,112,69,0,71,101,111,100,101,0,78,51,111,115,103,53,71,101,111,100,101,69,0,71,101,111,109,101,116,114,121,58,58,97,99,99,101,112,116,40,80,114,105,109,105,116,105,118,101,73,110,100,101,120,70,117,110,99,116,111,114,38,32,102,117,110,99,116,111,114,41,58,32,85,115,105,110,103,32,118,101,114,116,101,120,32,97,116,116,114,105,98,117,116,101,32,105,110,115,116,101,97,100,0,71,101,111,109,101,116,114,121,58,58,97,99,99,101,112,116,40,80,114,105,109,105,116,105,118,101,73,110,100,101,120,70,117,110,99,116,111,114,38,32,102,117,110,99,116,111,114,41,32,117,110,97,98,108,101,32,116,111,32,119,111,114,107,32,100,117,101,32,116,111,32,100,101,112,114,101,99,97,116,101,100,32,100,97,116,97,44,32,99,97,108,108,32,103,101,111,109,101,116,114,121,45,62,102,105,120,68,101,112,114,101,99,97,116,101,100,68,97,116,97,40,41,59,0,87,97,114,110,105,110,103,58,32,71,101,111,109,101,116,114,121,58,58,97,99,99,101,112,116,40,80,114,105,109,105,116,105,118,101,73,110,100,101,120,70,117,110,99,116,111,114,38,41,32,99,97,110,110,111,116,32,104,97,110,100,108,101,32,86,101,114,116,101,120,32,65,114,114,97,121,32,116,121,112,101,0,85,115,105,110,103,32,118,101,114,116,101,120,32,97,116,116,114,105,98,117,116,101,32,105,110,115,116,101,97,100,0,71,101,111,109,101,116,114,121,58,58,97,99,99,101,112,116,40,80,114,105,109,105,116,105,118,101,70,117,110,99,116,111,114,38,32,102,117,110,99,116,111,114,41,32,117,110,97,98,108,101,32,116,111,32,119,111,114,107,32,100,117,101,32,116,111,32,100,101,112,114,101,99,97,116,101,100,32,100,97,116,97,44,32,99,97,108,108,32,103,101,111,109,101,116,114,121,45,62,102,105,120,68,101,112,114,101,99,97,116,101,100,68,97,116,97,40,41,59,0,87,97,114,110,105,110,103,58,32,71,101,111,109,101,116,114,121,58,58,97,99,99,101,112,116,40,80,114,105,109,105,116,105,118,101,70,117,110,99,116,111,114,38,41,32,99,97,110,110,111,116,32,104,97,110,100,108,101,32,86,101,114,116,101,120,32,65,114,114,97,121,32,116,121,112,101,0,71,101,111,109,101,116,114,121,58,58,97,99,99,101,112,116,40,67,111,110,115,116,65,116,116,114,105,98,117,116,101,70,117,110,99,116,111,114,38,32,97,102,41,58,32,85,115,105,110,103,32,118,101,114,116,101,120,32,97,116,116,114,105,98,117,116,101,32,105,110,115,116,101,97,100,0,78,51,111,115,103,51,51,67,111,110,115,116,65,116,116,114,105,98,117,116,101,70,117,110,99,116,111,114,65,114,114,97,121,86,105,115,105,116,111,114,69,0,78,51,111,115,103,49,55,67,111,110,115,116,65,114,114,97,121,86,105,115,105,116,111,114,69,0,71,101,111,109,101,116,114,121,58,58,97,99,99,101,112,116,40,65,116,116,114,105,98,117,116,101,70,117,110,99,116,111,114,38,32,97,102,41,58,32,85,115,105,110,103,32,118,101,114,116,101,120,32,97,116,116,114,105,98,117,116,101,32,105,110,115,116,101,97,100,0,78,51,111,115,103,50,56,65,116,116,114,105,98,117,116,101,70,117,110,99,116,111,114,65,114,114,97,121,86,105,115,105,116,111,114,69,0,71,101,111,109,101,116,114,121,58,58,100,114,97,119,73,109,112,108,101,109,101,110,116,97,116,105,111,110,40,41,32,117,110,97,98,108,101,32,116,111,32,114,101,110,100,101,114,32,100,117,101,32,116,111,32,100,101,112,114,101,99,97,116,101,100,32,100,97,116,97,44,32,99,97,108,108,32,103,101,111,109,101,116,114,121,45,62,102,105,120,68,101,112,114,101,99,97,116,101,100,68,97,116,97,40,41,59,0,115,116,97,114,116,32,111,102,32,71,101,111,109,101,116,114,121,58,58,100,114,97,119,73,109,112,108,101,109,101,110,116,97,116,105,111,110,40,41,0,71,101,111,109,101,116,114,121,58,58,100,114,97,119,73,109,112,108,101,109,101,110,116,97,116,105,111,110,40,41,32,97,102,116,101,114,32,118,101,114,116,101,120,32,97,114,114,97,121,115,32,115,101,116,117,112,46,0,101,110,100,32,111,102,32,71,101,111,109,101,116,114,121,58,58,100,114,97,119,73,109,112,108,101,109,101,110,116,97,116,105,111,110,40,41,46,0,71,101,111,109,101,116,114,121,0,78,51,111,115,103,56,71,101,111,109,101,116,114,121,69,0,87,97,114,110,105,110,103,58,32,105,110,118,97,108,105,100,32,112,114,105,109,105,116,105,118,101,115,101,116,32,112,97,115,115,101,100,32,116,111,32,111,115,103,58,58,71,101,111,109,101,116,114,121,58,58,97,100,100,80,114,105,109,105,116,105,118,101,83,101,116,40,105,44,32,112,114,105,109,105,116,105,118,101,115,101,116,41,44,32,105,103,110,111,114,105,110,103,32,99,97,108,108,46,0,87,97,114,110,105,110,103,58,32,111,115,103,58,58,99,108,111,110,101,84,121,112,101,40,99,111,110,115,116,32,84,42,41,32,99,108,111,110,101,100,32,111,98,106,101,99,116,32,110,111,116,32,111,102,32,116,121,112,101,32,84,44,32,114,101,116,117,114,110,105,110,103,32,78,85,76,76,46,0,87,97,114,110,105,110,103,58,32,111,115,103,58,58,99,108,111,110,101,84,121,112,101,40,99,111,110,115,116,32,84,42,41,32,112,97,115,115,101,100,32,110,117,108,108,32,111,98,106,101,99,116,32,116,111,32,99,108,111,110,101,44,32,114,101,116,117,114,110,105,110,103,32,78,85,76,76,46,0,79,83,71,95,71,76,95,69,88,84,69,78,83,73,79,78,95,68,73,83,65,66,76,69,0,78,111,116,104,105,110,103,32,100,101,102,105,110,101,100,0,79,112,101,110,71,76,32,101,120,116,101,110,115,105,111,110,115,32,115,117,112,112,111,114,116,101,100,32,98,121,32,105,110,115,116,97,108,108,101,100,32,79,112,101,110,71,76,32,100,114,105,118,101,114,115,32,97,114,101,58,0,32,32,32,32,0,79,112,101,110,71,76,32,101,120,116,101,110,115,105,111,110,32,39,0,39,32,105,115,32,115,117,112,112,111,114,116,101,100,46,0,39,32,105,115,32,115,117,112,112,111,114,116,101,100,32,98,121,32,79,112,101,110,71,76,10,100,114,105,118,101,114,32,98,117,116,32,104,97,115,32,98,101,101,110,32,100,105,115,97,98,108,101,100,32,98,121,32,111,115,103,58,58,103,101,116,71,76,69,120,116,101,110,115,105,111,110,68,105,115,97,98,108,101,83,116,114,105,110,103,40,41,46,0,39,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,46,0,69,114,114,111,114,58,32,79,112,101,110,71,76,32,118,101,114,115,105,111,110,32,116,101,115,116,32,102,97,105,108,101,100,44,32,114,101,113,117,105,114,101,115,32,118,97,108,105,100,32,103,114,97,112,104,105,99,115,32,99,111,110,116,101,120,116,46,0,71,76,95,69,88,84,95,103,101,111,109,101,116,114,121,95,115,104,97,100,101,114,52,0,71,76,95,79,69,83,95,103,101,111,109,101,116,114,121,95,115,104,97,100,101,114,0,71,76,95,69,88,84,95,103,112,117,95,115,104,97,100,101,114,52,0,71,76,95,65,82,66,95,116,101,115,115,101,108,108,97,116,105,111,110,95,115,104,97,100,101,114,0,71,76,95,79,69,83,95,116,101,115,115,101,108,108,97,116,105,111,110,95,115,104,97,100,101,114,0,71,76,95,65,82,66,95,117,110,105,102,111,114,109,95,98,117,102,102,101,114,95,111,98,106,101,99,116,0,71,76,95,65,82,66,95,103,101,116,95,112,114,111,103,114,97,109,95,98,105,110,97,114,121,0,71,76,95,65,82,66,95,103,112,117,95,115,104,97,100,101,114,95,102,112,54,52,0,71,76,95,65,82,66,95,115,104,97,100,101,114,95,97,116,111,109,105,99,95,99,111,117,110,116,101,114,115,0,71,76,95,65,82,66,95,116,101,120,116,117,114,101,95,114,101,99,116,97,110,103,108,101,0,71,76,95,69,88,84,95,116,101,120,116,117,114,101,95,114,101,99,116,97,110,103,108,101,0,71,76,95,78,86,95,116,101,120,116,117,114,101,95,114,101,99,116,97,110,103,108,101,0,71,76,95,65,82,66,95,99,108,105,112,95,99,111,110,116,114,111,108,0,103,108,86,101,114,115,105,111,110,61,0,105,115,71,108,115,108,83,117,112,112,111,114,116,101,100,61,0,78,79,0,103,108,115,108,76,97,110,103,117,97,103,101,86,101,114,115,105,111,110,61,0,103,108,68,114,97,119,66,117,102,102,101,114,115,65,82,66,0,103,108,65,116,116,97,99,104,79,98,106,101,99,116,65,82,66,0,103,108,66,105,110,100,65,116,116,114,105,98,76,111,99,97,116,105,111,110,65,82,66,0,103,108,67,111,109,112,105,108,101,83,104,97,100,101,114,65,82,66,0,103,108,67,114,101,97,116,101,80,114,111,103,114,97,109,79,98,106,101,99,116,65,82,66,0,103,108,67,114,101,97,116,101,83,104,97,100,101,114,79,98,106,101,99,116,65,82,66,0,103,108,68,101,116,97,99,104,79,98,106,101,99,116,65,82,66,0,103,108,71,101,116,65,99,116,105,118,101,65,116,116,114,105,98,65,82,66,0,103,108,71,101,116,65,99,116,105,118,101,85,110,105,102,111,114,109,65,82,66,0,103,108,71,101,116,65,116,116,97,99,104,101,100,79,98,106,101,99,116,115,65,82,66,0,103,108,71,101,116,65,116,116,114,105,98,76,111,99,97,116,105,111,110,65,82,66,0,103,108,71,101,116,83,104,97,100,101,114,83,111,117,114,99,101,65,82,66,0,103,108,71,101,116,85,110,105,102,111,114,109,76,111,99,97,116,105,111,110,65,82,66,0,103,108,71,101,116,85,110,105,102,111,114,109,102,118,65,82,66,0,103,108,71,101,116,85,110,105,102,111,114,109,105,118,65,82,66,0,103,108,71,101,116,86,101,114,116,101,120,65,116,116,114,105,98,100,118,0,103,108,76,105,110,107,80,114,111,103,114,97,109,65,82,66,0,103,108,83,104,97,100,101,114,83,111,117,114,99,101,65,82,66,0,103,108,85,115,101,80,114,111,103,114,97,109,79,98,106,101,99,116,65,82,66,0,103,108,85,110,105,102,111,114,109,49,102,65,82,66,0,103,108,85,110,105,102,111,114,109,50,102,65,82,66,0,103,108,85,110,105,102,111,114,109,51,102,65,82,66,0,103,108,85,110,105,102,111,114,109,52,102,65,82,66,0,103,108,85,110,105,102,111,114,109,49,105,65,82,66,0,103,108,85,110,105,102,111,114,109,50,105,65,82,66,0,103,108,85,110,105,102,111,114,109,51,105,65,82,66,0,103,108,85,110,105,102,111,114,109,52,105,65,82,66,0,103,108,85,110,105,102,111,114,109,49,102,118,65,82,66,0,103,108,85,110,105,102,111,114,109,50,102,118,65,82,66,0,103,108,85,110,105,102,111,114,109,51,102,118,65,82,66,0,103,108,85,110,105,102,111,114,109,52,102,118,65,82,66,0,103,108,85,110,105,102,111,114,109,49,105,118,65,82,66,0,103,108,85,110,105,102,111,114,109,50,105,118,65,82,66,0,103,108,85,110,105,102,111,114,109,51,105,118,65,82,66,0,103,108,85,110,105,102,111,114,109,52,105,118,65,82,66,0,103,108,85,110,105,102,111,114,109,77,97,116,114,105,120,50,102,118,65,82,66,0,103,108,85,110,105,102,111,114,109,77,97,116,114,105,120,51,102,118,65,82,66,0,103,108,85,110,105,102,111,114,109,77,97,116,114,105,120,52,102,118,65,82,66,0,103,108,86,97,108,105,100,97,116,101,80,114,111,103,114,97,109,65,82,66,0,103,108,86,101,114,116,101,120,65,116,116,114,105,98,49,100,0,103,108,86,101,114,116,101,120,65,116,116,114,105,98,49,100,65,82,66,0,103,108,86,101,114,116,101,120,65,116,116,114,105,98,49,100,118,0,103,108,86,101,114,116,101,120,65,116,116,114,105,98,49,102,65,82,66,0,103,108,86,101,114,116,101,120,65,116,116,114,105,98,49,102,118,65,82,66,0,103,108,86,101,114,116,101,120,65,116,116,114,105,98,49,115,0,103,108,86,101,114,116,101,120,65,116,116,114,105,98,49,115,65,82,66,0,103,108,86,101,114,116,101,120,65,116,116,114,105,98,49,115,118,0,103,108,86,101,114,116,101,120,65,116,116,114,105,98,50,100,0,103,108,86,101,114,116,101,120,65,116,116,114,105,98,50,100,118,0,103,108,86,101,114,116,101,120,65,116,116,114,105,98,50,100,118,65,82,66,0,103,108,86,101,114,116,101,120,65,116,116,114,105,98,50,102,118,65,82,66,0,103,108,86,101,114,116,101,120,65,116,116,114,105,98,50,115,0,103,108,86,101,114,116,101,120,65,116,116,114,105,98,50,115,118,0,103,108,86,101,114,116,101,120,65,116,116,114,105,98,51,100,0,103,108,86,101,114,116,101,120,65,116,116,114,105,98,51,100,118,0,103,108,86,101,114,116,101,120,65,116,116,114,105,98,51,100,118,65,82,66,0,103,108,86,101,114,116,101,120,65,116,116,114,105,98,51,102,118,65,82,66,0,103,108,86,101,114,116,101,120,65,116,116,114,105,98,51,115,0,103,108,86,101,114,116,101,120,65,116,116,114,105,98,51,115,118,0,103,108,86,101,114,116,101,120,65,116,116,114,105,98,52,78,98,118,0,103,108,86,101,114,116,101,120,65,116,116,114,105,98,52,78,105,118,0,103,108,86,101,114,116,101,120,65,116,116,114,105,98,52,78,115,118,0,103,108,86,101,114,116,101,120,65,116,116,114,105,98,52,78,117,98,0,103,108,86,101,114,116,101,120,65,116,116,114,105,98,52,78,117,98,118,0,103,108,86,101,114,116,101,120,65,116,116,114,105,98,52,78,117,98,118,65,82,66,0,103,108,86,101,114,116,101,120,65,116,116,114,105,98,52,78,117,105,118,0,103,108,86,101,114,116,101,120,65,116,116,114,105,98,52,78,117,115,118,0,103,108,86,101,114,116,101,120,65,116,116,114,105,98,52,98,118,0,103,108,86,101,114,116,101,120,65,116,116,114,105,98,52,100,0,103,108,86,101,114,116,101,120,65,116,116,114,105,98,52,100,118,0,103,108,86,101,114,116,101,120,65,116,116,114,105,98,52,100,118,65,82,66,0,103,108,86,101,114,116,101,120,65,116,116,114,105,98,52,102,118,65,82,66,0,103,108,86,101,114,116,101,120,65,116,116,114,105,98,52,105,118,0,103,108,86,101,114,116,101,120,65,116,116,114,105,98,52,115,0,103,108,86,101,114,116,101,120,65,116,116,114,105,98,52,115,118,0,103,108,86,101,114,116,101,120,65,116,116,114,105,98,52,117,98,118,0,103,108,86,101,114,116,101,120,65,116,116,114,105,98,52,117,98,118,65,82,66,0,103,108,86,101,114,116,101,120,65,116,116,114,105,98,52,117,105,118,0,103,108,86,101,114,116,101,120,65,116,116,114,105,98,52,117,115,118,0,103,108,86,101,114,116,101,120,65,116,116,114,105,98,73,80,111,105,110,116,101,114,65,82,66,0,103,108,86,101,114,116,101,120,65,116,116,114,105,98,76,80,111,105,110,116,101,114,65,82,66,0,103,108,71,101,116,73,110,102,111,76,111,103,65,82,66,0,103,108,71,101,116,79,98,106,101,99,116,80,97,114,97,109,101,116,101,114,105,118,65,82,66,0,103,108,68,101,108,101,116,101,79,98,106,101,99,116,65,82,66,0,103,108,71,101,116,72,97,110,100,108,101,65,82,66,0,103,108,85,110,105,102,111,114,109,77,97,116,114,105,120,50,120,51,102,118,0,103,108,85,110,105,102,111,114,109,77,97,116,114,105,120,51,120,50,102,118,0,103,108,85,110,105,102,111,114,109,77,97,116,114,105,120,50,120,52,102,118,0,103,108,85,110,105,102,111,114,109,77,97,116,114,105,120,52,120,50,102,118,0,103,108,85,110,105,102,111,114,109,77,97,116,114,105,120,51,120,52,102,118,0,103,108,85,110,105,102,111,114,109,77,97,116,114,105,120,52,120,51,102,118,0,103,108,67,108,105,112,67,111,110,116,114,111,108,0,103,108,80,114,111,103,114,97,109,80,97,114,97,109,101,116,101,114,105,0,103,108,80,114,111,103,114,97,109,80,97,114,97,109,101,116,101,114,105,69,88,84,0,103,108,80,97,116,99,104,80,97,114,97,109,101,116,101,114,105,0,103,108,80,97,116,99,104,80,97,114,97,109,101,116,101,114,102,118,0,103,108,71,101,116,85,110,105,102,111,114,109,117,105,118,0,103,108,71,101,116,85,110,105,102,111,114,109,117,105,118,69,88,84,0,103,108,66,105,110,100,70,114,97,103,68,97,116,97,76,111,99,97,116,105,111,110,0,103,108,66,105,110,100,70,114,97,103,68,97,116,97,76,111,99,97,116,105,111,110,69,88,84,0,103,108,66,105,110,100,70,114,97,103,68,97,116,97,76,111,99,97,116,105,111,110,73,110,100,101,120,101,100,0,103,108,66,105,110,100,70,114,97,103,68,97,116,97,76,111,99,97,116,105,111,110,73,110,100,101,120,101,100,69,88,84,0,103,108,71,101,116,70,114,97,103,68,97,116,97,73,110,100,101,120,0,103,108,71,101,116,70,114,97,103,68,97,116,97,73,110,100,101,120,69,88,84,0,103,108,71,101,116,70,114,97,103,68,97,116,97,76,111,99,97,116,105,111,110,0,103,108,71,101,116,70,114,97,103,68,97,116,97,76,111,99,97,116,105,111,110,69,88,84,0,103,108,85,110,105,102,111,114,109,49,117,105,0,103,108,85,110,105,102,111,114,109,49,117,105,69,88,84,0,103,108,85,110,105,102,111,114,109,50,117,105,0,103,108,85,110,105,102,111,114,109,50,117,105,69,88,84,0,103,108,85,110,105,102,111,114,109,51,117,105,0,103,108,85,110,105,102,111,114,109,51,117,105,69,88,84,0,103,108,85,110,105,102,111,114,109,52,117,105,0,103,108,85,110,105,102,111,114,109,52,117,105,69,88,84,0,103,108,85,110,105,102,111,114,109,49,117,105,118,0,103,108,85,110,105,102,111,114,109,49,117,105,118,69,88,84,0,103,108,85,110,105,102,111,114,109,50,117,105,118,0,103,108,85,110,105,102,111,114,109,50,117,105,118,69,88,84,0,103,108,85,110,105,102,111,114,109,51,117,105,118,0,103,108,85,110,105,102,111,114,109,51,117,105,118,69,88,84,0,103,108,85,110,105,102,111,114,109,52,117,105,118,0,103,108,85,110,105,102,111,114,109,52,117,105,118,69,88,84,0,103,108,85,110,105,102,111,114,109,49,105,54,52,0,103,108,85,110,105,102,111,114,109,49,105,54,52,65,82,66,0,103,108,85,110,105,102,111,114,109,49,117,105,54,52,0,103,108,85,110,105,102,111,114,109,49,117,105,54,52,65,82,66,0,103,108,85,110,105,102,111,114,109,50,105,54,52,0,103,108,85,110,105,102,111,114,109,50,105,54,52,65,82,66,0,103,108,85,110,105,102,111,114,109,50,117,105,54,52,0,103,108,85,110,105,102,111,114,109,50,117,105,54,52,65,82,66,0,103,108,85,110,105,102,111,114,109,51,105,54,52,0,103,108,85,110,105,102,111,114,109,51,105,54,52,65,82,66,0,103,108,85,110,105,102,111,114,109,51,117,105,54,52,0,103,108,85,110,105,102,111,114,109,51,117,105,54,52,65,82,66,0,103,108,85,110,105,102,111,114,109,52,105,54,52,0,103,108,85,110,105,102,111,114,109,52,105,54,52,65,82,66,0,103,108,85,110,105,102,111,114,109,52,117,105,54,52,0,103,108,85,110,105,102,111,114,109,52,117,105,54,52,65,82,66,0,103,108,85,110,105,102,111,114,109,49,105,54,52,118,0,103,108,85,110,105,102,111,114,109,49,105,54,52,118,65,82,66,0,103,108,85,110,105,102,111,114,109,49,117,105,54,52,118,0,103,108,85,110,105,102,111,114,109,49,117,105,54,52,118,65,82,66,0,103,108,85,110,105,102,111,114,109,50,105,54,52,118,0,103,108,85,110,105,102,111,114,109,50,105,54,52,118,65,82,66,0,103,108,85,110,105,102,111,114,109,50,117,105,54,52,118,0,103,108,85,110,105,102,111,114,109,50,117,105,54,52,118,65,82,66,0,103,108,85,110,105,102,111,114,109,51,105,54,52,118,0,103,108,85,110,105,102,111,114,109,51,105,54,52,118,65,82,66,0,103,108,85,110,105,102,111,114,109,51,117,105,54,52,118,0,103,108,85,110,105,102,111,114,109,51,117,105,54,52,118,65,82,66,0,103,108,85,110,105,102,111,114,109,52,105,54,52,118,0,103,108,85,110,105,102,111,114,109,52,105,54,52,118,65,82,66,0,103,108,85,110,105,102,111,114,109,52,117,105,54,52,118,0,103,108,85,110,105,102,111,114,109,52,117,105,54,52,118,65,82,66,0,103,108,71,101,116,85,110,105,102,111,114,109,73,110,100,105,99,101,115,0,103,108,71,101,116,65,99,116,105,118,101,85,110,105,102,111,114,109,115,105,118,0,103,108,71,101,116,65,99,116,105,118,101,85,110,105,102,111,114,109,78,97,109,101,0,103,108,71,101,116,85,110,105,102,111,114,109,66,108,111,99,107,73,110,100,101,120,0,103,108,71,101,116,65,99,116,105,118,101,85,110,105,102,111,114,109,66,108,111,99,107,105,118,0,103,108,71,101,116,65,99,116,105,118,101,85,110,105,102,111,114,109,66,108,111,99,107,78,97,109,101,0,103,108,85,110,105,102,111,114,109,66,108,111,99,107,66,105,110,100,105,110,103,0,103,108,71,101,116,80,114,111,103,114,97,109,66,105,110,97,114,121,0,103,108,80,114,111,103,114,97,109,66,105,110,97,114,121,0,103,108,85,110,105,102,111,114,109,49,100,0,103,108,85,110,105,102,111,114,109,50,100,0,103,108,85,110,105,102,111,114,109,51,100,0,103,108,85,110,105,102,111,114,109,52,100,0,103,108,85,110,105,102,111,114,109,49,100,118,0,103,108,85,110,105,102,111,114,109,50,100,118,0,103,108,85,110,105,102,111,114,109,51,100,118,0,103,108,85,110,105,102,111,114,109,52,100,118,0,103,108,85,110,105,102,111,114,109,77,97,116,114,105,120,50,100,118,0,103,108,85,110,105,102,111,114,109,77,97,116,114,105,120,51,100,118,0,103,108,85,110,105,102,111,114,109,77,97,116,114,105,120,52,100,118,0,103,108,85,110,105,102,111,114,109,77,97,116,114,105,120,50,120,51,100,118,0,103,108,85,110,105,102,111,114,109,77,97,116,114,105,120,51,120,50,100,118,0,103,108,85,110,105,102,111,114,109,77,97,116,114,105,120,50,120,52,100,118,0,103,108,85,110,105,102,111,114,109,77,97,116,114,105,120,52,120,50,100,118,0,103,108,85,110,105,102,111,114,109,77,97,116,114,105,120,51,120,52,100,118,0,103,108,85,110,105,102,111,114,109,77,97,116,114,105,120,52,120,51,100,118,0,103,108,71,101,116,65,99,116,105,118,101,65,116,111,109,105,99,67,111,117,110,116,101,114,66,117,102,102,101,114,105,118,0,103,108,68,105,115,112,97,116,99,104,67,111,109,112,117,116,101,0,103,108,77,101,109,111,114,121,66,97,114,114,105,101,114,0,103,108,77,101,109,111,114,121,66,97,114,114,105,101,114,69,88,84,0,103,108,71,101,110,66,117,102,102,101,114,115,65,82,66,0,103,108,66,117,102,102,101,114,68,97,116,97,65,82,66,0,103,108,66,117,102,102,101,114,83,117,98,68,97,116,97,65,82,66,0,103,108,68,101,108,101,116,101,66,117,102,102,101,114,115,65,82,66,0,103,108,73,115,66,117,102,102,101,114,65,82,66,0,103,108,71,101,116,66,117,102,102,101,114,83,117,98,68,97,116,97,0,103,108,71,101,116,66,117,102,102,101,114,83,117,98,68,97,116,97,65,82,66,0,103,108,77,97,112,66,117,102,102,101,114,0,103,108,77,97,112,66,117,102,102,101,114,65,82,66,0,103,108,77,97,112,66,117,102,102,101,114,82,97,110,103,101,0,103,108,77,97,112,66,117,102,102,101,114,82,97,110,103,101,65,82,66,0,103,108,85,110,109,97,112,66,117,102,102,101,114,0,103,108,85,110,109,97,112,66,117,102,102,101,114,65,82,66,0,103,108,71,101,116,66,117,102,102,101,114,80,97,114,97,109,101,116,101,114,105,118,65,82,66,0,103,108,71,101,116,66,117,102,102,101,114,80,111,105,110,116,101,114,118,0,103,108,71,101,116,66,117,102,102,101,114,80,111,105,110,116,101,114,118,65,82,66,0,103,108,66,105,110,100,66,117,102,102,101,114,82,97,110,103,101,0,103,108,66,105,110,100,66,117,102,102,101,114,66,97,115,101,0,103,108,66,105,110,100,66,117,102,102,101,114,66,97,115,101,69,88,84,0,103,108,66,105,110,100,66,117], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+123132);
/* memory initializer */ allocate([102,102,101,114,66,97,115,101,78,86,0,103,108,84,101,120,66,117,102,102,101,114,0,103,108,84,101,120,66,117,102,102,101,114,65,82,66,0,71,76,95,65,82,66,95,116,101,120,116,117,114,101,95,98,117,102,102,101,114,95,111,98,106,101,99,116,0,71,76,95,65,82,66,95,118,101,114,116,101,120,95,97,114,114,97,121,95,111,98,106,101,99,116,0,71,76,95,79,69,83,95,118,101,114,116,101,120,95,97,114,114,97,121,95,111,98,106,101,99,116,0,71,76,95,65,82,66,95,116,114,97,110,115,102,111,114,109,95,102,101,101,100,98,97,99,107,50,0,103,108,66,108,101,110,100,70,117,110,99,83,101,112,97,114,97,116,101,69,88,84,0,103,108,66,108,101,110,100,70,117,110,99,105,0,103,108,66,108,101,110,100,70,117,110,99,105,65,82,66,0,103,108,66,108,101,110,100,70,117,110,99,83,101,112,97,114,97,116,101,105,0,103,108,66,108,101,110,100,70,117,110,99,83,101,112,97,114,97,116,101,105,65,82,66,0,71,76,95,65,82,66,95,109,117,108,116,105,116,101,120,116,117,114,101,0,71,76,95,78,86,95,111,99,99,108,117,115,105,111,110,95,113,117,101,114,121,0,71,76,95,65,82,66,95,111,99,99,108,117,115,105,111,110,95,113,117,101,114,121,0,71,76,95,69,88,84,95,116,105,109,101,114,95,113,117,101,114,121,0,71,76,95,65,82,66,95,116,105,109,101,114,95,113,117,101,114,121,0,103,108,70,111,103,67,111,111,114,100,102,118,0,103,108,70,111,103,67,111,111,114,100,102,118,69,88,84,0,103,108,83,101,99,111,110,100,97,114,121,67,111,108,111,114,51,117,98,118,0,103,108,83,101,99,111,110,100,97,114,121,67,111,108,111,114,51,117,98,118,69,88,84,0,103,108,83,101,99,111,110,100,97,114,121,67,111,108,111,114,51,102,118,0,103,108,83,101,99,111,110,100,97,114,121,67,111,108,111,114,51,102,118,69,88,84,0,103,108,77,117,108,116,105,84,101,120,67,111,111,114,100,49,102,0,103,108,77,117,108,116,105,84,101,120,67,111,111,114,100,49,102,65,82,66,0,103,108,77,117,108,116,105,84,101,120,67,111,111,114,100,49,102,118,0,103,108,77,117,108,116,105,84,101,120,67,111,111,114,100,49,102,118,65,82,66,0,103,108,77,117,108,116,105,84,101,120,67,111,111,114,100,50,102,118,0,103,108,77,117,108,116,105,84,101,120,67,111,111,114,100,50,102,118,65,82,66,0,103,108,77,117,108,116,105,84,101,120,67,111,111,114,100,51,102,118,0,103,108,77,117,108,116,105,84,101,120,67,111,111,114,100,51,102,118,65,82,66,0,103,108,77,117,108,116,105,84,101,120,67,111,111,114,100,52,102,118,0,103,108,77,117,108,116,105,84,101,120,67,111,111,114,100,52,102,118,65,82,66,0,103,108,77,117,108,116,105,84,101,120,67,111,111,114,100,49,100,0,103,108,77,117,108,116,105,84,101,120,67,111,111,114,100,49,100,65,82,66,0,103,108,77,117,108,116,105,84,101,120,67,111,111,114,100,49,100,118,0,103,108,77,117,108,116,105,84,101,120,67,111,111,114,100,49,100,118,65,82,66,0,103,108,77,117,108,116,105,84,101,120,67,111,111,114,100,50,100,118,0,103,108,77,117,108,116,105,84,101,120,67,111,111,114,100,50,100,118,65,82,66,0,103,108,77,117,108,116,105,84,101,120,67,111,111,114,100,51,100,118,0,103,108,77,117,108,116,105,84,101,120,67,111,111,114,100,51,100,118,65,82,66,0,103,108,77,117,108,116,105,84,101,120,67,111,111,114,100,52,100,118,0,103,108,77,117,108,116,105,84,101,120,67,111,111,114,100,52,100,118,65,82,66,0,103,108,71,101,110,79,99,99,108,117,115,105,111,110,81,117,101,114,105,101,115,0,103,108,71,101,110,79,99,99,108,117,115,105,111,110,81,117,101,114,105,101,115,78,86,0,103,108,68,101,108,101,116,101,79,99,99,108,117,115,105,111,110,81,117,101,114,105,101,115,0,103,108,68,101,108,101,116,101,79,99,99,108,117,115,105,111,110,81,117,101,114,105,101,115,78,86,0,103,108,73,115,79,99,99,108,117,115,105,111,110,81,117,101,114,121,0,103,108,73,115,79,99,99,108,117,115,105,111,110,81,117,101,114,121,78,86,0,103,108,66,101,103,105,110,79,99,99,108,117,115,105,111,110,81,117,101,114,121,0,103,108,66,101,103,105,110,79,99,99,108,117,115,105,111,110,81,117,101,114,121,78,86,0,103,108,69,110,100,79,99,99,108,117,115,105,111,110,81,117,101,114,121,0,103,108,69,110,100,79,99,99,108,117,115,105,111,110,81,117,101,114,121,78,86,0,103,108,71,101,116,79,99,99,108,117,115,105,111,110,81,117,101,114,121,105,118,0,103,108,71,101,116,79,99,99,108,117,115,105,111,110,81,117,101,114,121,105,118,78,86,0,103,108,71,101,116,79,99,99,108,117,115,105,111,110,81,117,101,114,121,117,105,118,0,103,108,71,101,116,79,99,99,108,117,115,105,111,110,81,117,101,114,121,117,105,118,78,86,0,103,108,71,101,110,81,117,101,114,105,101,115,0,103,108,71,101,110,81,117,101,114,105,101,115,65,82,66,0,103,108,68,101,108,101,116,101,81,117,101,114,105,101,115,0,103,108,68,101,108,101,116,101,81,117,101,114,105,101,115,65,82,66,0,103,108,73,115,81,117,101,114,121,0,103,108,73,115,81,117,101,114,121,65,82,66,0,103,108,66,101,103,105,110,81,117,101,114,121,0,103,108,66,101,103,105,110,81,117,101,114,121,65,82,66,0,103,108,69,110,100,81,117,101,114,121,0,103,108,69,110,100,81,117,101,114,121,65,82,66,0,103,108,66,101,103,105,110,81,117,101,114,121,73,110,100,101,120,101,100,0,103,108,66,101,103,105,110,81,117,101,114,121,73,110,100,101,120,101,100,65,82,66,0,103,108,69,110,100,81,117,101,114,121,73,110,100,101,120,101,100,0,103,108,69,110,100,81,117,101,114,121,73,110,100,101,120,101,100,65,82,66,0,103,108,71,101,116,81,117,101,114,121,105,118,0,103,108,71,101,116,81,117,101,114,121,105,118,65,82,66,0,103,108,71,101,116,81,117,101,114,121,79,98,106,101,99,116,105,118,0,103,108,71,101,116,81,117,101,114,121,79,98,106,101,99,116,105,118,65,82,66,0,103,108,71,101,116,81,117,101,114,121,79,98,106,101,99,116,117,105,118,0,103,108,71,101,116,81,117,101,114,121,79,98,106,101,99,116,117,105,118,65,82,66,0,103,108,71,101,116,81,117,101,114,121,79,98,106,101,99,116,117,105,54,52,118,0,103,108,71,101,116,81,117,101,114,121,79,98,106,101,99,116,117,105,54,52,118,69,88,84,0,103,108,81,117,101,114,121,67,111,117,110,116,101,114,0,103,108,71,101,116,73,110,116,101,103,101,114,54,52,118,0,71,76,95,65,82,66,95,116,101,120,116,117,114,101,95,109,117,108,116,105,115,97,109,112,108,101,0,103,108,83,97,109,112,108,101,77,97,115,107,105,0,65,82,66,95,116,101,120,116,117,114,101,95,109,117,108,116,105,115,97,109,112,108,101,0,71,76,95,65,82,66,95,118,101,114,116,101,120,95,112,114,111,103,114,97,109,0,71,76,95,65,82,66,95,102,114,97,103,109,101,110,116,95,112,114,111,103,114,97,109,0,103,108,66,105,110,100,80,114,111,103,114,97,109,65,82,66,0,103,108,71,101,110,80,114,111,103,114,97,109,115,65,82,66,0,103,108,68,101,108,101,116,101,80,114,111,103,114,97,109,115,65,82,66,0,103,108,80,114,111,103,114,97,109,83,116,114,105,110,103,65,82,66,0,103,108,80,114,111,103,114,97,109,76,111,99,97,108,80,97,114,97,109,101,116,101,114,52,102,118,65,82,66,0,103,108,83,97,109,112,108,101,114,80,97,114,97,109,101,116,101,114,105,0,103,108,83,97,109,112,108,101,114,80,97,114,97,109,101,116,101,114,105,65,82,66,0,103,108,83,97,109,112,108,101,114,80,97,114,97,109,101,116,101,114,102,0,103,108,83,97,109,112,108,101,114,80,97,114,97,109,101,116,101,114,102,65,82,66,0,103,108,83,97,109,112,108,101,114,80,97,114,97,109,101,116,101,114,105,118,0,103,108,83,97,109,112,108,101,114,80,97,114,97,109,101,116,101,114,105,118,65,82,66,0,103,108,83,97,109,112,108,101,114,80,97,114,97,109,101,116,101,114,102,118,0,103,108,83,97,109,112,108,101,114,80,97,114,97,109,101,116,101,114,102,118,65,82,66,0,103,108,83,97,109,112,108,101,114,80,97,114,97,109,101,116,101,114,73,105,118,0,103,108,83,97,109,112,108,101,114,80,97,114,97,109,101,116,101,114,73,105,118,65,82,66,0,103,108,83,97,109,112,108,101,114,80,97,114,97,109,101,116,101,114,73,117,105,118,0,103,108,83,97,109,112,108,101,114,80,97,114,97,109,101,116,101,114,73,117,105,118,65,82,66,0,103,108,71,101,116,83,97,109,112,108,101,114,80,97,114,97,109,101,116,101,114,105,118,0,103,108,71,101,116,83,97,109,112,108,101,114,80,97,114,97,109,101,116,101,114,105,118,65,82,66,0,103,108,71,101,116,83,97,109,112,108,101,114,80,97,114,97,109,101,116,101,114,102,118,0,103,108,71,101,116,83,97,109,112,108,101,114,80,97,114,97,109,101,116,101,114,102,118,65,82,66,0,103,108,71,101,116,83,97,109,112,108,101,114,80,97,114,97,109,101,116,101,114,73,105,118,0,103,108,71,101,116,83,97,109,112,108,101,114,80,97,114,97,109,101,116,101,114,73,105,118,65,82,66,0,103,108,71,101,116,83,97,109,112,108,101,114,80,97,114,97,109,101,116,101,114,73,117,105,118,0,103,108,71,101,116,83,97,109,112,108,101,114,80,97,114,97,109,101,116,101,114,73,117,105,118,65,82,66,0,103,108,71,101,110,83,97,109,112,108,101,114,115,0,103,108,71,101,110,83,97,109,112,108,101,114,115,65,82,66,0,103,108,68,101,108,101,116,101,83,97,109,112,108,101,114,115,0,103,108,68,101,108,101,116,101,83,97,109,112,108,101,114,115,65,82,66,0,103,108,66,105,110,100,83,97,109,112,108,101,114,0,103,108,66,105,110,100,83,97,109,112,108,101,114,65,82,66,0,103,108,73,115,83,97,109,112,108,101,114,0,103,108,73,115,83,97,109,112,108,101,114,65,82,66,0,70,105,114,101,71,76,0,70,73,82,69,71,76,0,71,76,95,69,88,84,95,116,101,120,116,117,114,101,95,102,105,108,116,101,114,95,97,110,105,115,111,116,114,111,112,105,99,0,71,76,95,65,82,66,95,116,101,120,116,117,114,101,95,115,119,105,122,122,108,101,0,71,76,95,69,88,84,95,116,101,120,116,117,114,101,95,99,111,109,112,114,101,115,115,105,111,110,95,115,51,116,99,0,71,76,95,83,51,95,115,51,116,99,0,71,76,95,73,77,71,95,116,101,120,116,117,114,101,95,99,111,109,112,114,101,115,115,105,111,110,95,112,118,114,116,99,0,71,76,95,79,69,83,95,99,111,109,112,114,101,115,115,101,100,95,69,84,67,49,95,82,71,66,56,95,116,101,120,116,117,114,101,0,71,76,95,65,82,66,95,69,83,51,95,99,111,109,112,97,116,105,98,105,108,105,116,121,0,71,76,95,69,88,84,95,116,101,120,116,117,114,101,95,99,111,109,112,114,101,115,115,105,111,110,95,114,103,116,99,0,71,76,95,69,88,84,95,116,101,120,116,117,114,101,95,98,111,114,100,101,114,95,99,108,97,109,112,0,71,76,95,65,82,66,95,115,104,97,100,111,119,0,71,76,95,65,82,66,95,115,104,97,100,111,119,95,97,109,98,105,101,110,116,0,71,76,95,65,80,80,76,69,95,99,108,105,101,110,116,95,115,116,111,114,97,103,101,0,71,76,95,69,88,84,95,116,101,120,116,117,114,101,95,105,110,116,101,103,101,114,0,71,101,70,111,114,99,101,32,70,88,0,68,105,115,97,98,108,105,110,103,32,95,105,115,78,111,110,80,111,119,101,114,79,102,84,119,111,84,101,120,116,117,114,101,77,105,112,77,97,112,112,101,100,83,117,112,112,111,114,116,101,100,32,102,111,114,32,71,101,70,111,114,99,101,32,70,88,32,104,97,114,100,119,97,114,101,46,0,103,108,84,101,120,83,116,111,114,97,103,101,50,68,0,103,108,84,101,120,83,116,111,114,97,103,101,50,68,65,82,66,0,103,108,67,111,109,112,114,101,115,115,101,100,84,101,120,73,109,97,103,101,50,68,65,82,66,0,103,108,67,111,109,112,114,101,115,115,101,100,84,101,120,83,117,98,73,109,97,103,101,50,68,65,82,66,0,103,108,71,101,116,67,111,109,112,114,101,115,115,101,100,84,101,120,73,109,97,103,101,0,103,108,71,101,116,67,111,109,112,114,101,115,115,101,100,84,101,120,73,109,97,103,101,65,82,66,0,103,108,84,101,120,73,109,97,103,101,50,68,77,117,108,116,105,115,97,109,112,108,101,0,103,108,84,101,120,73,109,97,103,101,50,68,77,117,108,116,105,115,97,109,112,108,101,65,82,66,0,103,108,84,101,120,80,97,114,97,109,101,116,101,114,73,105,118,0,103,108,84,101,120,80,97,114,97,109,101,116,101,114,73,105,118,65,82,66,0,103,108,84,101,120,80,97,114,97,109,101,116,101,114,73,105,118,69,88,84,0,103,108,84,101,120,80,97,114,97,109,101,116,101,114,73,117,105,118,0,103,108,84,101,120,80,97,114,97,109,101,116,101,114,73,117,105,118,65,82,66,0,103,108,84,101,120,80,97,114,97,109,101,116,101,114,73,117,105,118,69,88,84,0,103,108,66,105,110,100,73,109,97,103,101,84,101,120,116,117,114,101,0,103,108,66,105,110,100,73,109,97,103,101,84,101,120,116,117,114,101,65,82,66,0,71,76,95,65,82,66,95,116,101,120,116,117,114,101,95,115,116,111,114,97,103,101,0,68,73,83,65,66,76,69,0,71,76,95,69,88,84,95,116,101,120,116,117,114,101,51,68,0,103,108,84,101,120,73,109,97,103,101,51,68,0,103,108,84,101,120,73,109,97,103,101,51,68,69,88,84,0,103,108,84,101,120,83,117,98,73,109,97,103,101,51,68,0,103,108,84,101,120,83,117,98,73,109,97,103,101,51,68,69,88,84,0,103,108,67,111,109,112,114,101,115,115,101,100,84,101,120,73,109,97,103,101,51,68,0,103,108,67,111,109,112,114,101,115,115,101,100,84,101,120,73,109,97,103,101,51,68,65,82,66,0,103,108,67,111,109,112,114,101,115,115,101,100,84,101,120,83,117,98,73,109,97,103,101,51,68,0,103,108,67,111,109,112,114,101,115,115,101,100,84,101,120,83,117,98,73,109,97,103,101,51,68,65,82,66,0,103,108,67,111,112,121,84,101,120,83,117,98,73,109,97,103,101,51,68,0,103,108,67,111,112,121,84,101,120,83,117,98,73,109,97,103,101,51,68,69,88,84,0,103,108,66,101,103,105,110,67,111,110,100,105,116,105,111,110,97,108,82,101,110,100,101,114,0,103,108,66,101,103,105,110,67,111,110,100,105,116,105,111,110,97,108,82,101,110,100,101,114,65,82,66,0,103,108,69,110,100,67,111,110,100,105,116,105,111,110,97,108,82,101,110,100,101,114,0,103,108,69,110,100,67,111,110,100,105,116,105,111,110,97,108,82,101,110,100,101,114,65,82,66,0,71,76,95,69,88,84,95,116,101,120,116,117,114,101,95,97,114,114,97,121,0,103,108,71,101,116,84,101,120,116,117,114,101,72,97,110,100,108,101,0,103,108,71,101,116,84,101,120,116,117,114,101,72,97,110,100,108,101,65,82,66,0,103,108,71,101,116,84,101,120,116,117,114,101,72,97,110,100,108,101,78,86,0,103,108,77,97,107,101,84,101,120,116,117,114,101,72,97,110,100,108,101,82,101,115,105,100,101,110,116,0,103,108,77,97,107,101,84,101,120,116,117,114,101,72,97,110,100,108,101,82,101,115,105,100,101,110,116,65,82,66,0,103,108,77,97,107,101,84,101,120,116,117,114,101,72,97,110,100,108,101,82,101,115,105,100,101,110,116,78,86,0,103,108,77,97,107,101,84,101,120,116,117,114,101,72,97,110,100,108,101,78,111,110,82,101,115,105,100,101,110,116,0,103,108,77,97,107,101,84,101,120,116,117,114,101,72,97,110,100,108,101,78,111,110,82,101,115,105,100,101,110,116,65,82,66,0,103,108,77,97,107,101,84,101,120,116,117,114,101,72,97,110,100,108,101,78,111,110,82,101,115,105,100,101,110,116,78,86,0,103,108,85,110,105,102,111,114,109,72,97,110,100,108,101,117,105,54,52,0,103,108,85,110,105,102,111,114,109,72,97,110,100,108,101,117,105,54,52,65,82,66,0,103,108,85,110,105,102,111,114,109,72,97,110,100,108,101,117,105,54,52,78,86,0,103,108,73,115,84,101,120,116,117,114,101,72,97,110,100,108,101,82,101,115,105,100,101,110,116,0,103,108,73,115,84,101,120,116,117,114,101,72,97,110,100,108,101,82,101,115,105,100,101,110,116,65,82,66,0,103,108,73,115,84,101,120,116,117,114,101,72,97,110,100,108,101,82,101,115,105,100,101,110,116,78,86,0,103,108,66,108,101,110,100,67,111,108,111,114,69,88,84,0,71,76,95,83,71,73,88,95,98,108,101,110,100,95,97,108,112,104,97,95,109,105,110,109,97,120,0,71,76,95,69,88,84,95,98,108,101,110,100,95,108,111,103,105,99,95,111,112,0,103,108,66,108,101,110,100,69,113,117,97,116,105,111,110,69,88,84,0,103,108,66,108,101,110,100,69,113,117,97,116,105,111,110,83,101,112,97,114,97,116,101,69,88,84,0,103,108,66,108,101,110,100,69,113,117,97,116,105,111,110,105,0,103,108,66,108,101,110,100,69,113,117,97,116,105,111,110,105,65,82,66,0,103,108,66,108,101,110,100,69,113,117,97,116,105,111,110,83,101,112,97,114,97,116,101,105,0,103,108,66,108,101,110,100,69,113,117,97,116,105,111,110,83,101,112,97,114,97,116,101,105,65,82,66,0,103,108,69,110,97,98,108,101,105,0,103,108,68,105,115,97,98,108,101,105,0,71,76,95,69,88,84,95,115,116,101,110,99,105,108,95,119,114,97,112,0,71,76,95,69,88,84,95,115,116,101,110,99,105,108,95,116,119,111,95,115,105,100,101,0,71,76,95,65,84,73,95,115,101,112,97,114,97,116,101,95,115,116,101,110,99,105,108,0,103,108,65,99,116,105,118,101,83,116,101,110,99,105,108,70,97,99,101,69,88,84,0,103,108,83,116,101,110,99,105,108,79,112,83,101,112,97,114,97,116,101,65,84,73,0,103,108,83,116,101,110,99,105,108,70,117,110,99,83,101,112,97,114,97,116,101,65,84,73,0,103,108,67,111,108,111,114,77,97,115,107,105,0,103,108,67,111,108,111,114,77,97,115,107,105,65,82,66,0,71,76,95,65,82,66,95,99,111,108,111,114,95,98,117,102,102,101,114,95,102,108,111,97,116,0,103,108,67,108,97,109,112,67,111,108,111,114,0,103,108,67,108,97,109,112,67,111,108,111,114,65,82,66,0,103,108,80,114,105,109,105,116,105,118,101,82,101,115,116,97,114,116,73,110,100,101,120,0,103,108,80,114,105,109,105,116,105,118,101,82,101,115,116,97,114,116,73,110,100,101,120,78,86,0,71,76,95,65,82,66,95,112,111,105,110,116,95,112,97,114,97,109,101,116,101,114,115,0,71,76,95,69,88,84,95,112,111,105,110,116,95,112,97,114,97,109,101,116,101,114,115,0,71,76,95,83,71,73,83,95,112,111,105,110,116,95,112,97,114,97,109,101,116,101,114,115,0,103,108,80,111,105,110,116,80,97,114,97,109,101,116,101,114,105,0,103,108,80,111,105,110,116,80,97,114,97,109,101,116,101,114,105,65,82,66,0,103,108,80,111,105,110,116,80,97,114,97,109,101,116,101,114,105,69,88,84,0,103,108,80,111,105,110,116,80,97,114,97,109,101,116,101,114,105,83,71,73,83,0,103,108,80,111,105,110,116,80,97,114,97,109,101,116,101,114,102,0,103,108,80,111,105,110,116,80,97,114,97,109,101,116,101,114,102,65,82,66,0,103,108,80,111,105,110,116,80,97,114,97,109,101,116,101,114,102,69,88,84,0,103,108,80,111,105,110,116,80,97,114,97,109,101,116,101,114,102,83,71,73,83,0,103,108,80,111,105,110,116,80,97,114,97,109,101,116,101,114,102,118,0,103,108,80,111,105,110,116,80,97,114,97,109,101,116,101,114,102,118,65,82,66,0,103,108,80,111,105,110,116,80,97,114,97,109,101,116,101,114,102,118,69,88,84,0,103,108,80,111,105,110,116,80,97,114,97,109,101,116,101,114,102,118,83,71,73,83,0,71,76,95,78,86,95,109,117,108,116,105,115,97,109,112,108,101,95,102,105,108,116,101,114,95,104,105,110,116,0,103,108,83,97,109,112,108,101,67,111,118,101,114,97,103,101,65,82,66,0,103,108,66,105,110,100,82,101,110,100,101,114,98,117,102,102,101,114,69,88,84,0,103,108,66,105,110,100,82,101,110,100,101,114,98,117,102,102,101,114,79,69,83,0,103,108,68,101,108,101,116,101,82,101,110,100,101,114,98,117,102,102,101,114,115,69,88,84,0,103,108,68,101,108,101,116,101,82,101,110,100,101,114,98,117,102,102,101,114,115,79,69,83,0,103,108,71,101,110,82,101,110,100,101,114,98,117,102,102,101,114,115,69,88,84,0,103,108,71,101,110,82,101,110,100,101,114,98,117,102,102,101,114,115,79,69,83,0,103,108,82,101,110,100,101,114,98,117,102,102,101,114,83,116,111,114,97,103,101,69,88,84,0,103,108,82,101,110,100,101,114,98,117,102,102,101,114,83,116,111,114,97,103,101,79,69,83,0,103,108,82,101,110,100,101,114,98,117,102,102,101,114,83,116,111,114,97,103,101,77,117,108,116,105,115,97,109,112,108,101,0,103,108,82,101,110,100,101,114,98,117,102,102,101,114,83,116,111,114,97,103,101,77,117,108,116,105,115,97,109,112,108,101,69,88,84,0,103,108,82,101,110,100,101,114,98,117,102,102,101,114,83,116,111,114,97,103,101,77,117,108,116,105,115,97,109,112,108,101,79,69,83,0,103,108,82,101,110,100,101,114,98,117,102,102,101,114,83,116,111,114,97,103,101,77,117,108,116,105,115,97,109,112,108,101,67,111,118,101,114,97,103,101,78,86,0,103,108,66,105,110,100,70,114,97,109,101,98,117,102,102,101,114,69,88,84,0,103,108,66,105,110,100,70,114,97,109,101,98,117,102,102,101,114,79,69,83,0,103,108,68,101,108,101,116,101,70,114,97,109,101,98,117,102,102,101,114,115,69,88,84,0,103,108,68,101,108,101,116,101,70,114,97,109,101,98,117,102,102,101,114,115,79,69,83,0,103,108,71,101,110,70,114,97,109,101,98,117,102,102,101,114,115,69,88,84,0,103,108,71,101,110,70,114,97,109,101,98,117,102,102,101,114,115,79,69,83,0,103,108,67,104,101,99,107,70,114,97,109,101,98,117,102,102,101,114,83,116,97,116,117,115,69,88,84,0,103,108,67,104,101,99,107,70,114,97,109,101,98,117,102,102,101,114,83,116,97,116,117,115,79,69,83,0,103,108,70,114,97,109,101,98,117,102,102,101,114,84,101,120,116,117,114,101,49,68,0,103,108,70,114,97,109,101,98,117,102,102,101,114,84,101,120,116,117,114,101,49,68,69,88,84,0,103,108,70,114,97,109,101,98,117,102,102,101,114,84,101,120,116,117,114,101,49,68,79,69,83,0,103,108,70,114,97,109,101,98,117,102,102,101,114,84,101,120,116,117,114,101,50,68,69,88,84,0,103,108,70,114,97,109,101,98,117,102,102,101,114,84,101,120,116,117,114,101,50,68,79,69,83,0,103,108,70,114,97,109,101,98,117,102,102,101,114,84,101,120,116,117,114,101,51,68,0,103,108,70,114,97,109,101,98,117,102,102,101,114,84,101,120,116,117,114,101,51,68,69,88,84,0,103,108,70,114,97,109,101,98,117,102,102,101,114,84,101,120,116,117,114,101,51,68,79,69,83,0,103,108,70,114,97,109,101,98,117,102,102,101,114,84,101,120,116,117,114,101,0,103,108,70,114,97,109,101,98,117,102,102,101,114,84,101,120,116,117,114,101,69,88,84,0,103,108,70,114,97,109,101,98,117,102,102,101,114,84,101,120,116,117,114,101,79,69,83,0,103,108,70,114,97,109,101,98,117,102,102,101,114,84,101,120,116,117,114,101,76,97,121,101,114,0,103,108,70,114,97,109,101,98,117,102,102,101,114,84,101,120,116,117,114,101,76,97,121,101,114,69,88,84,0,103,108,70,114,97,109,101,98,117,102,102,101,114,84,101,120,116,117,114,101,76,97,121,101,114,79,69,83,0,103,108,70,114,97,109,101,98,117,102,102,101,114,84,101,120,116,117,114,101,70,97,99,101,0,103,108,70,114,97,109,101,98,117,102,102,101,114,84,101,120,116,117,114,101,70,97,99,101,69,88,84,0,103,108,70,114,97,109,101,98,117,102,102,101,114,84,101,120,116,117,114,101,70,97,99,101,79,69,83,0,103,108,70,114,97,109,101,98,117,102,102,101,114,82,101,110,100,101,114,98,117,102,102,101,114,69,88,84,0,103,108,70,114,97,109,101,98,117,102,102,101,114,82,101,110,100,101,114,98,117,102,102,101,114,79,69,83,0,103,108,71,101,110,101,114,97,116,101,77,105,112,109,97,112,69,88,84,0,103,108,71,101,110,101,114,97,116,101,77,105,112,109,97,112,79,69,83,0,103,108,66,108,105,116,70,114,97,109,101,98,117,102,102,101,114,0,103,108,66,108,105,116,70,114,97,109,101,98,117,102,102,101,114,69,88,84,0,103,108,66,108,105,116,70,114,97,109,101,98,117,102,102,101,114,79,69,83,0,103,108,71,101,116,82,101,110,100,101,114,98,117,102,102,101,114,80,97,114,97,109,101,116,101,114,105,118,69,88,84,0,103,108,71,101,116,82,101,110,100,101,114,98,117,102,102,101,114,80,97,114,97,109,101,116,101,114,105,118,79,69,83,0,71,76,95,69,88,84,95,112,97,99,107,101,100,95,100,101,112,116,104,95,115,116,101,110,99,105,108,0,71,76,95,79,69,83,95,112,97,99,107,101,100,95,100,101,112,116,104,95,115,116,101,110,99,105,108,0,103,108,71,101,116,83,117,98,114,111,117,116,105,110,101,85,110,105,102,111,114,109,76,111,99,97,116,105,111,110,0,103,108,71,101,116,65,99,116,105,118,101,83,117,98,114,111,117,116,105,110,101,85,110,105,102,111,114,109,78,97,109,101,0,103,108,71,101,116,65,99,116,105,118,101,83,117,98,114,111,117,116,105,110,101,85,110,105,102,111,114,109,105,118,0,103,108,71,101,116,83,117,98,114,111,117,116,105,110,101,73,110,100,101,120,0,103,108,71,101,116,65,99,116,105,118,101,83,117,98,114,111,117,116,105,110,101,78,97,109,101,0,103,108,71,101,116,80,114,111,103,114,97,109,83,116,97,103,101,105,118,0,103,108,85,110,105,102,111,114,109,83,117,98,114,111,117,116,105,110,101,115,117,105,118,0,103,108,71,101,116,85,110,105,102,111,114,109,83,117,98,114,111,117,116,105,110,101,117,105,118,0,103,108,70,101,110,99,101,83,121,110,99,0,103,108,73,115,83,121,110,99,0,103,108,68,101,108,101,116,101,83,121,110,99,0,103,108,67,108,105,101,110,116,87,97,105,116,83,121,110,99,0,103,108,87,97,105,116,83,121,110,99,0,103,108,71,101,116,83,121,110,99,105,118,0,103,108,68,114,97,119,65,114,114,97,121,115,73,110,100,105,114,101,99,116,0,103,108,68,114,97,119,65,114,114,97,121,115,73,110,100,105,114,101,99,116,69,88,84,0,103,108,77,117,108,116,105,68,114,97,119,65,114,114,97,121,115,73,110,100,105,114,101,99,116,0,103,108,77,117,108,116,105,68,114,97,119,65,114,114,97,121,115,73,110,100,105,114,101,99,116,69,88,84,0,103,108,68,114,97,119,69,108,101,109,101,110,116,115,73,110,100,105,114,101,99,116,0,103,108,68,114,97,119,69,108,101,109,101,110,116,115,73,110,100,105,114,101,99,116,69,88,84,0,103,108,77,117,108,116,105,68,114,97,119,69,108,101,109,101,110,116,115,73,110,100,105,114,101,99,116,0,103,108,77,117,108,116,105,68,114,97,119,69,108,101,109,101,110,116,115,73,110,100,105,114,101,99,116,69,88,84,0,103,108,66,101,103,105,110,84,114,97,110,115,102,111,114,109,70,101,101,100,98,97,99,107,0,103,108,66,101,103,105,110,84,114,97,110,115,102,111,114,109,70,101,101,100,98,97,99,107,69,88,84,0,103,108,69,110,100,84,114,97,110,115,102,111,114,109,70,101,101,100,98,97,99,107,0,103,108,69,110,100,84,114,97,110,115,102,111,114,109,70,101,101,100,98,97,99,107,69,88,84,0,103,108,84,114,97,110,115,102,111,114,109,70,101,101,100,98,97,99,107,86,97,114,121,105,110,103,115,0,103,108,84,114,97,110,115,102,111,114,109,70,101,101,100,98,97,99,107,86,97,114,121,105,110,103,115,69,88,84,0,103,108,71,101,116,84,114,97,110,115,102,111,114,109,70,101,101,100,98,97,99,107,86,97,114,121,105,110,103,0,103,108,71,101,116,84,114,97,110,115,102,111,114,109,70,101,101,100,98,97,99,107,86,97,114,121,105,110,103,69,88,84,0,103,108,66,105,110,100,84,114,97,110,115,102,111,114,109,70,101,101,100,98,97,99,107,0,103,108,68,101,108,101,116,101,84,114,97,110,115,102,111,114,109,70,101,101,100,98,97,99,107,115,0,103,108,71,101,110,84,114,97,110,115,102,111,114,109,70,101,101,100,98,97,99,107,115,0,103,108,73,115,84,114,97,110,115,102,111,114,109,70,101,101,100,98,97,99,107,0,103,108,80,97,117,115,101,84,114,97,110,115,102,111,114,109,70,101,101,100,98,97,99,107,0,103,108,82,101,115,117,109,101,84,114,97,110,115,102,111,114,109,70,101,101,100,98,97,99,107,0,103,108,68,114,97,119,84,114,97,110,115,102,111,114,109,70,101,101,100,98,97,99,107,0,103,108,68,114,97,119,84,114,97,110,115,102,111,114,109,70,101,101,100,98,97,99,107,83,116,114,101,97,109,0,103,108,68,114,97,119,84,114,97,110,115,102,111,114,109,70,101,101,100,98,97,99,107,73,110,115,116,97,110,99,101,100,0,103,108,68,114,97,119,84,114,97,110,115,102,111,114,109,70,101,101,100,98,97,99,107,83,116,114,101,97,109,73,110,115,116,97,110,99,101,100,0,103,108,67,114,101,97,116,101,84,114,97,110,115,102,111,114,109,70,101,101,100,98,97,99,107,115,0,103,108,84,114,97,110,115,102,111,114,109,70,101,101,100,98,97,99,107,66,117,102,102,101,114,66,97,115,101,0,103,108,84,114,97,110,115,102,111,114,109,70,101,101,100,98,97,99,107,66,117,102,102,101,114,82,97,110,103,101,0,103,108,71,101,116,84,114,97,110,115,102,111,114,109,70,101,101,100,98,97,99,107,105,118,0,103,108,71,101,116,84,114,97,110,115,102,111,114,109,70,101,101,100,98,97,99,107,105,95,118,0,103,108,71,101,116,84,114,97,110,115,102,111,114,109,70,101,101,100,98,97,99,107,105,54,52,95,118,0,103,108,71,101,110,86,101,114,116,101,120,65,114,114,97,121,115,79,69,83,0,103,108,66,105,110,100,86,101,114,116,101,120,65,114,114,97,121,79,69,83,0,103,108,68,101,108,101,116,101,86,101,114,116,101,120,65,114,114,97,121,115,79,69,83,0,103,108,73,115,86,101,114,116,101,120,65,114,114,97,121,0,103,108,73,115,86,101,114,116,101,120,65,114,114,97,121,79,69,83,0,71,76,95,65,82,66,95,118,101,114,116,101,120,95,97,116,116,114,105,98,95,98,105,110,100,105,110,103,0,103,108,66,105,110,100,86,101,114,116,101,120,66,117,102,102,101,114,0,103,108,66,105,110,100,86,101,114,116,101,120,66,117,102,102,101,114,79,69,83,0,103,108,86,101,114,116,101,120,65,114,114,97,121,86,101,114,116,101,120,66,117,102,102,101,114,0,103,108,86,101,114,116,101,120,65,114,114,97,121,86,101,114,116,101,120,66,117,102,102,101,114,79,69,83,0,103,108,86,101,114,116,101,120,65,116,116,114,105,98,66,105,110,100,105,110,103,0,103,108,86,101,114,116,101,120,65,116,116,114,105,98,66,105,110,100,105,110,103,79,69,83,0,103,108,86,101,114,116,101,120,65,114,114,97,121,65,116,116,114,105,98,66,105,110,100,105,110,103,0,103,108,86,101,114,116,101,120,65,114,114,97,121,65,116,116,114,105,98,66,105,110,100,105,110,103,79,69,83,0,103,108,86,101,114,116,101,120,65,116,116,114,105,98,76,70,111,114,109,97,116,0,103,108,86,101,114,116,101,120,65,116,116,114,105,98,76,70,111,114,109,97,116,79,69,83,0,103,108,86,101,114,116,101,120,65,114,114,97,121,65,116,116,114,105,98,70,111,114,109,97,116,0,103,108,86,101,114,116,101,120,65,114,114,97,121,65,116,116,114,105,98,70,111,114,109,97,116,79,69,83,0,103,108,86,101,114,116,101,120,65,114,114,97,121,65,116,116,114,105,98,73,70,111,114,109,97,116,0,103,108,86,101,114,116,101,120,65,114,114,97,121,65,116,116,114,105,98,73,70,111,114,109,97,116,79,69,83,0,103,108,86,101,114,116,101,120,65,114,114,97,121,65,116,116,114,105,98,76,70,111,114,109,97,116,0,103,108,86,101,114,116,101,120,65,114,114,97,121,65,116,116,114,105,98,76,70,111,114,109,97,116,79,69,83,0,103,108,77,117,108,116,105,68,114,97,119,65,114,114,97,121,115,0,103,108,77,117,108,116,105,68,114,97,119,65,114,114,97,121,115,69,88,84,0,103,108,77,117,108,116,105,68,114,97,119,69,108,101,109,101,110,116,115,0,103,108,77,117,108,116,105,68,114,97,119,69,108,101,109,101,110,116,115,69,88,84,0,103,108,68,114,97,119,65,114,114,97,121,115,73,110,115,116,97,110,99,101,100,66,97,115,101,73,110,115,116,97,110,99,101,0,103,108,68,114,97,119,65,114,114,97,121,115,73,110,115,116,97,110,99,101,100,66,97,115,101,73,110,115,116,97,110,99,101,69,88,84,0,103,108,68,114,97,119,69,108,101,109,101,110,116,115,73,110,115,116,97,110,99,101,100,66,97,115,101,73,110,115,116,97,110,99,101,0,103,108,68,114,97,119,69,108,101,109,101,110,116,115,73,110,115,116,97,110,99,101,100,66,97,115,101,73,110,115,116,97,110,99,101,69,88,84,0,103,108,68,114,97,119,69,108,101,109,101,110,116,115,73,110,115,116,97,110,99,101,100,66,97,115,101,86,101,114,116,101,120,66,97,115,101,73,110,115,116,97,110,99,101,0,103,108,68,114,97,119,69,108,101,109,101,110,116,115,73,110,115,116,97,110,99,101,100,66,97,115,101,86,101,114,116,101,120,66,97,115,101,73,110,115,116,97,110,99,101,69,88,84,0,103,108,68,114,97,119,69,108,101,109,101,110,116,115,66,97,115,101,86,101,114,116,101,120,0,103,108,68,114,97,119,69,108,101,109,101,110,116,115,66,97,115,101,86,101,114,116,101,120,69,88,84,0,103,108,68,114,97,119,82,97,110,103,101,69,108,101,109,101,110,116,115,66,97,115,101,86,101,114,116,101,120,0,103,108,68,114,97,119,82,97,110,103,101,69,108,101,109,101,110,116,115,66,97,115,101,86,101,114,116,101,120,69,88,84,0,103,108,68,114,97,119,69,108,101,109,101,110,116,115,73,110,115,116,97,110,99,101,100,66,97,115,101,86,101,114,116,101,120,0,103,108,68,114,97,119,69,108,101,109,101,110,116,115,73,110,115,116,97,110,99,101,100,66,97,115,101,86,101,114,116,101,120,69,88,84,0,103,108,77,117,108,116,105,68,114,97,119,69,108,101,109,101,110,116,115,66,97,115,101,86,101,114,116,101,120,0,103,108,77,117,108,116,105,68,114,97,119,69,108,101,109,101,110,116,115,66,97,115,101,86,101,114,116,101,120,69,88,84,0,103,108,80,114,111,118,111,107,105,110,103,86,101,114,116,101,120,0,103,108,80,114,111,118,111,107,105,110,103,86,101,114,116,101,120,69,88,84,0,103,108,66,101,103,105,110,67,111,110,100,105,116,105,111,110,97,108,82,101,110,100,101,114,69,88,84,0,103,108,69,110,100,67,111,110,100,105,116,105,111,110,97,108,82,101,110,100,101,114,69,88,84,0,71,76,95,65,82,66,95,118,105,101,119,112,111,114,116,95,97,114,114,97,121,0,103,108,86,105,101,119,112,111,114,116,65,114,114,97,121,118,0,103,108,86,105,101,119,112,111,114,116,73,110,100,101,120,101,100,102,0,103,108,86,105,101,119,112,111,114,116,73,110,100,101,120,101,100,102,118,0,103,108,83,99,105,115,115,111,114,65,114,114,97,121,118,0,103,108,83,99,105,115,115,111,114,73,110,100,101,120,101,100,0,103,108,83,99,105,115,115,111,114,73,110,100,101,120,101,100,118,0,103,108,68,101,112,116,104,82,97,110,103,101,65,114,114,97,121,118,0,103,108,68,101,112,116,104,82,97,110,103,101,73,110,100,101,120,101,100,0,103,108,68,101,112,116,104,82,97,110,103,101,73,110,100,101,120,101,100,102,79,69,83,0,103,108,68,101,112,116,104,82,97,110,103,101,73,110,100,101,120,101,100,102,78,86,0,103,108,71,101,116,70,108,111,97,116,105,95,118,0,103,108,71,101,116,68,111,117,98,108,101,105,95,118,0,103,108,71,101,116,73,110,116,101,103,101,114,73,110,100,101,120,101,100,118,69,88,84,0,103,108,69,110,97,98,108,101,73,110,100,101,120,101,100,69,88,84,0,103,108,68,105,115,97,98,108,101,73,110,100,101,120,101,100,69,88,84,0,103,108,73,115,69,110,97,98,108,101,100,73,110,100,101,120,101,100,69,88,84,0,103,108,79,98,106,101,99,116,76,97,98,101,108,0,78,51,111,115,103,49,50,71,76,69,120,116,101,110,115,105,111,110,115,69,0,78,51,111,115,103,49,52,71,114,97,112,104,105,99,115,79,98,106,101,99,116,69,0,58,58,126,0,40,41,0,78,51,111,115,103,50,49,71,114,97,112,104,105,99,115,79,98,106,101,99,116,77,97,110,97,103,101,114,69,0,118,111,105,100,32,0,58,58,99,114,101,97,116,101,71,76,79,98,106,101,99,116,40,41,32,58,32,78,111,116,32,73,109,112,108,101,109,101,110,116,97,116,101,100,0,58,58,100,101,108,101,116,101,65,108,108,71,76,79,98,106,101,99,116,115,40,41,32,58,32,78,111,116,32,73,109,112,108,101,109,101,110,116,97,116,101,100,0,78,51,111,115,103,49,53,71,76,79,98,106,101,99,116,77,97,110,97,103,101,114,69,0,58,58,0,78,51,111,115,103,50,49,71,114,97,112,104,105,99,115,67,111,115,116,69,115,116,105,109,97,116,111,114,69,0,78,51,111,115,103,50,49,71,101,111,109,101,116,114,121,67,111,115,116,69,115,116,105,109,97,116,111,114,69,0,78,51,111,115,103,50,48,84,101,120,116,117,114,101,67,111,115,116,69,115,116,105,109,97,116,111,114,69,0,84,101,120,116,117,114,101,67,111,115,116,69,115,116,105,109,97,116,111,114,58,58,101,115,116,105,109,97,116,101,67,111,109,112,105,108,101,67,111,115,116,40,41,44,32,115,105,122,101,61,0,78,51,111,115,103,50,48,80,114,111,103,114,97,109,67,111,115,116,69,115,116,105,109,97,116,111,114,69,0,71,114,97,112,104,105,99,115,67,111,115,116,69,115,116,105,109,97,116,111,114,58,58,99,97,108,105,98,114,97,116,101,40,46,46,41,0,78,51,111,115,103,49,53,71,114,97,112,104,105,99,115,67,111,110,116,101,120,116,50,53,87,105,110,100,111,119,105,110,103,83,121,115,116,101,109,73,110,116,101,114,102,97,99,101,115,69,0,71,114,97,112,104,105,99,115,67,111,110,116,101,120,116,0,99,108,111,115,101,40,0,82,101,108,101,97,115,105,110,103,32,71,76,32,111,98,106,101,99,116,115,32,102,111,114,32,67,97,109,101,114,97,61,0,32,95,115,116,97,116,101,61,0,67,108,111,115,105,110,103,32,115,116,105,108,108,32,118,105,97,98,108,101,32,119,105,110,100,111,119,32,0,32,95,115,116,97,116,101,45,62,103,101,116,67,111,110,116,101,120,116,73,68,40,41,61,0,68,111,105,110,103,32,100,101,108,101,116,101,32,111,102,32,71,76,32,111,98,106,101,99,116,115,0,68,111,110,101,32,100,101,108,101,116,101,32,111,102,32,71,76,32,111,98,106,101,99,116,115,0,109,97,107,101,67,117,114,114,101,110,116,32,100,105,100,32,110,111,116,32,115,117,99,99,101,101,100,44,32,99,111,117,108,100,32,110,111,116,32,100,111,32,102,108,117,115,104,47,100,101,108,101,116,105,111,110,32,111,102,32,79,112,101,110,71,76,32,111,98,106,101,99,116,115,46,0,68,111,105,110,103,32,100,105,115,99,97,114,100,32,111,102,32,100,101,108,101,116,101,100,32,79,112,101,110,71,76,32,111,98,106,101,99,116,115,46,0,78,51,111,115,103,49,53,71,114,97,112,104,105,99,115,67,111,110,116,101,120,116,69,0,78,51,111,115,103,50,51,83,121,110,99,83,119,97,112,66,117,102,102,101,114,115,67,97,108,108,98,97,99,107,69,0,78,51,111,115,103,49,53,71,114,97,112,104,105,99,115,67,111,110,116,101,120,116,49,50,83,119,97,112,67,97,108,108,98,97,99,107,69,0,87,97,114,110,105,110,103,58,32,71,114,97,112,104,105,99,115,67,111,110,116,101,120,116,58,58,87,105,110,100,111,119,105,110,103,83,121,115,116,101,109,73,110,116,101,114,102,97,99,101,115,58,58,103,101,116,87,105,110,100,111,119,105,110,103,83,121,115,116,101,109,73,110,116,101,114,102,97,99,101,40,41,32,102,97,105,108,101,100,44,32,110,111,32,105,110,116,101,114,102,97,99,101,115,32,97,118,97,105,108,97,98,108,101,46,0,32,32,32,116,114,105,101,100,32,105,110,116,101,114,102,97,99,101,32,0,78,51,111,115,103,55,114,101,102,95,112,116,114,73,78,83,95,49,53,71,114,97,112,104,105,99,115,67,111,110,116,101,120,116,50,52,87,105,110,100,111,119,105,110,103,83,121,115,116,101,109,73,110,116,101,114,102,97,99,101,69,69,69,0,44,32,110,97,109,101,61,32,0,87,97,114,110,105,110,103,58,32,71,114,97,112,104,105,99,115,67,111,110,116,101,120,116,58,58,87,105,110,100,111,119,105,110,103,83,121,115,116,101,109,73,110,116,101,114,102,97,99,101,115,58,58,103,101,116,87,105,110,100,111,119,105,110,103,83,121,115,116,101,109,73,110,116,101,114,102,97,99,101,40,41,32,102,97,105,108,101,100,44,32,110,111,32,105,110,116,101,114,102,97,99,101,115,32,109,97,116,99,104,101,115,32,110,97,109,101,32,58,32,0,68,73,83,80,76,65,89,0,49,46,48,0,78,51,111,115,103,49,53,71,114,97,112,104,105,99,115,67,111,110,116,101,120,116,54,84,114,97,105,116,115,69,0,78,51,111,115,103,49,53,71,114,97,112,104,105,99,115,67,111,110,116,101,120,116,49,54,83,99,114,101,101,110,73,100,101,110,116,105,102,105,101,114,69,0,78,51,111,115,103,56,82,101,102,66,108,111,99,107,69,0,78,49,49,79,112,101,110,84,104,114,101,97,100,115,53,66,108,111,99,107,69,0,67,114,101,97,116,101,100,32,83,121,110,99,83,119,97,112,66,117,102,102,101,114,115,67,97,108,108,98,97,99,107,46,0,78,51,111,115,103,49,52,71,114,97,112,104,105,99,115,84,104,114,101,97,100,69,0,78,51,111,115,103,50,50,66,108,111,99,107,65,110,100,70,108,117,115,104,79,112,101,114,97,116,105,111,110,69,0,78,51,111,115,103,49,55,71,114,97,112,104,105,99,115,79,112,101,114,97,116,105,111,110,69,0,78,51,111,115,103,50,49,69,110,100,79,102,68,121,110,97,109,105,99], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+133372);
/* memory initializer */ allocate([68,114,97,119,66,108,111,99,107,69,0,78,51,111,115,103,53,83,116,97,116,101,51,57,68,121,110,97,109,105,99,79,98,106,101,99,116,82,101,110,100,101,114,105,110,103,67,111,109,112,108,101,116,101,100,67,97,108,108,98,97,99,107,69,0,78,49,49,79,112,101,110,84,104,114,101,97,100,115,49,48,66,108,111,99,107,67,111,117,110,116,69,0,78,51,111,115,103,50,48,83,119,97,112,66,117,102,102,101,114,115,79,112,101,114,97,116,105,111,110,69,0,78,51,111,115,103,49,54,66,97,114,114,105,101,114,79,112,101,114,97,116,105,111,110,69,0,78,51,111,115,103,49,51,82,117,110,79,112,101,114,97,116,105,111,110,115,69,0,66,108,111,99,107,0,87,97,114,110,105,110,103,58,32,71,114,111,117,112,58,58,114,101,109,111,118,101,67,104,105,108,100,40,105,44,110,117,109,67,104,105,108,100,114,101,110,84,111,82,101,109,111,118,101,41,32,104,97,115,32,98,101,101,110,32,112,97,115,115,101,100,32,97,110,32,101,120,99,101,115,115,105,118,101,32,110,117,109,98,101,114,0,32,32,32,32,32,32,32,32,32,111,102,32,99,104,105,108,114,101,110,32,116,111,32,114,101,109,111,118,101,44,32,116,114,105,109,109,105,110,103,32,106,117,115,116,32,116,111,32,101,110,100,32,111,102,32,99,104,105,108,100,32,108,105,115,116,46,0,71,114,111,117,112,0,78,51,111,115,103,53,71,114,111,117,112,69,0,73,109,97,103,101,58,58,99,111,109,112,117,116,101,80,105,120,101,108,83,105,122,101,73,110,66,105,116,115,40,102,111,114,109,97,116,44,116,121,112,101,41,32,58,32,99,97,110,110,111,116,32,99,111,109,112,117,116,101,32,99,111,114,114,101,99,116,32,115,105,122,101,32,111,102,32,99,111,109,112,114,101,115,115,101,100,32,102,111,114,109,97,116,32,40,0,101,114,114,111,114,32,116,121,112,101,32,61,32,0,101,114,114,111,114,32,112,105,120,101,108,70,111,114,109,97,116,32,61,32,0,87,97,114,110,105,110,103,58,32,110,101,103,97,116,105,118,101,32,111,102,102,115,101,116,115,32,112,97,115,115,101,100,32,116,111,32,73,109,97,103,101,58,58,99,111,112,121,83,117,98,73,109,97,103,101,40,46,46,41,32,110,111,116,32,115,117,112,112,111,114,116,101,100,44,32,111,112,101,114,97,116,105,111,110,32,105,103,110,111,114,101,100,46,0,97,108,108,111,99,97,116,105,110,103,32,105,109,97,103,101,0,87,97,114,110,105,110,103,58,32,111,102,102,115,101,116,115,32,112,97,115,115,101,100,32,116,111,32,73,109,97,103,101,58,58,99,111,112,121,83,117,98,73,109,97,103,101,40,46,46,41,32,111,117,116,115,105,100,101,32,100,101,115,116,105,110,97,116,105,111,110,32,105,109,97,103,101,44,32,111,112,101,114,97,116,105,111,110,32,105,103,110,111,114,101,100,46,0,87,97,114,110,105,110,103,58,32,105,109,97,103,101,32,119,105,116,104,32,97,110,32,105,110,99,111,109,112,97,116,105,98,108,101,32,112,105,120,101,108,32,102,111,114,109,97,116,115,32,112,97,115,115,101,100,32,116,111,32,73,109,97,103,101,58,58,99,111,112,121,83,117,98,73,109,97,103,101,40,46,46,41,44,32,111,112,101,114,97,116,105,111,110,32,105,103,110,111,114,101,100,46,0,69,114,114,111,114,32,73,109,97,103,101,58,58,115,99,97,108,101,73,109,97,103,101,40,41,32,100,105,100,32,110,111,116,32,115,117,99,99,101,101,100,32,58,32,101,114,114,111,114,83,116,114,105,110,103,32,61,32,0,46,32,84,104,101,32,114,101,110,100,101,114,105,110,103,32,99,111,110,116,101,120,116,32,109,97,121,32,98,101,32,105,110,118,97,108,105,100,46,0,69,114,114,111,114,32,73,109,97,103,101,58,58,115,99,97,108,101,73,109,97,103,101,40,41,32,100,111,32,110,111,116,32,115,117,99,99,101,101,100,32,58,32,99,97,110,110,111,116,32,115,99,97,108,101,32,78,85,76,76,32,105,109,97,103,101,46,0,69,114,114,111,114,32,73,109,97,103,101,58,58,115,99,97,108,101,73,109,97,103,101,40,41,32,100,111,32,110,111,116,32,115,117,99,99,101,101,100,32,58,32,115,99,97,108,105,110,103,32,111,102,32,118,111,108,117,109,101,115,32,110,111,116,32,105,109,112,108,101,109,101,110,116,101,100,46,0,87,97,114,110,105,110,103,58,32,73,109,97,103,101,58,58,114,101,97,100,73,109,97,103,101,70,114,111,109,67,117,114,114,101,110,116,84,101,120,116,117,114,101,40,41,32,110,111,116,32,115,117,112,112,111,114,116,101,100,46,0,73,109,97,103,101,0,78,51,111,115,103,53,73,109,97,103,101,69,0,78,51,111,115,103,53,73,109,97,103,101,49,52,85,112,100,97,116,101,67,97,108,108,98,97,99,107,69,0,78,51,111,115,103,49,49,73,109,97,103,101,83,116,114,101,97,109,69,0,108,101,102,116,67,104,105,108,100,73,110,100,101,120,61,0,32,38,38,32,111,114,105,103,105,110,97,108,76,101,102,116,67,104,105,108,100,73,110,100,101,120,61,0,114,105,103,104,116,67,104,105,108,100,73,110,100,101,120,61,0,32,38,38,32,111,114,105,103,105,110,97,108,82,105,103,104,116,67,104,105,108,100,73,110,100,101,120,61,0,73,110,118,97,108,105,100,32,66,66,32,108,101,102,116,67,104,105,108,100,73,110,100,101,120,61,0,32,32,98,98,46,95,109,105,110,32,40,0,32,32,98,98,46,95,109,97,120,32,40,0,32,32,103,101,116,78,111,100,101,40,108,101,102,116,67,104,105,108,100,73,110,100,101,120,41,46,98,98,32,109,105,110,32,61,32,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,109,97,120,32,61,32,0,32,32,103,101,116,78,111,100,101,40,114,105,103,104,116,67,104,105,108,100,73,110,100,101,120,41,46,98,98,32,109,105,110,32,61,32,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,109,97,120,32,61,32,0,78,51,111,115,103,50,57,84,101,109,112,108,97,116,101,80,114,105,109,105,116,105,118,101,73,110,100,101,120,70,117,110,99,116,111,114,73,50,53,80,114,105,109,105,116,105,118,101,73,110,100,105,99,101,115,67,111,108,108,101,99,116,111,114,69,69,0,50,53,80,114,105,109,105,116,105,118,101,73,110,100,105,99,101,115,67,111,108,108,101,99,116,111,114,0,75,100,84,114,101,101,0,78,51,111,115,103,54,75,100,84,114,101,101,69,0,75,100,84,114,101,101,66,117,105,108,100,101,114,0,78,51,111,115,103,49,51,75,100,84,114,101,101,66,117,105,108,100,101,114,69,0,78,51,111,115,103,51,76,79,68,69,0,48,120,0,78,111,100,101,0,78,51,111,115,103,52,78,111,100,101,69,0,78,51,111,115,103,49,49,78,111,100,101,86,105,115,105,116,111,114,69,0,78,51,111,115,103,50,49,83,116,97,110,100,97,114,100,78,111,116,105,102,121,72,97,110,100,108,101,114,69,0,79,83,71,95,78,79,84,73,70,89,95,76,69,86,69,76,32,60,109,111,100,101,62,0,70,65,84,65,76,32,124,32,87,65,82,78,32,124,32,78,79,84,73,67,69,32,124,32,68,69,66,85,71,95,73,78,70,79,32,124,32,68,69,66,85,71,95,70,80,32,124,32,68,69,66,85,71,32,124,32,73,78,70,79,32,124,32,65,76,87,65,89,83,0,78,51,111,115,103,49,48,78,117,108,108,83,116,114,101,97,109,69,0,78,51,111,115,103,49,50,78,111,116,105,102,121,83,116,114,101,97,109,69,0,79,83,71,95,78,79,84,73,70,89,95,76,69,86,69,76,0,79,83,71,78,79,84,73,70,89,76,69,86,69,76,0,70,65,84,65,76,0,78,79,84,73,67,69,0,68,69,66,85,71,95,73,78,70,79,0,68,69,66,85,71,95,70,80,0,87,97,114,110,105,110,103,58,32,105,110,118,97,108,105,100,32,79,83,71,95,78,79,84,73,70,89,95,76,69,86,69,76,32,115,101,116,32,40,0,78,51,111,115,103,49,56,78,111,116,105,102,121,83,116,114,101,97,109,66,117,102,102,101,114,69,0,78,51,111,115,103,49,54,78,117,108,108,83,116,114,101,97,109,66,117,102,102,101,114,69,0,78,51,111,115,103,54,79,98,106,101,99,116,69,0,78,51,111,115,103,56,79,98,115,101,114,118,101,114,69,0,78,51,111,115,103,49,49,79,98,115,101,114,118,101,114,83,101,116,69,0,79,98,115,101,114,118,101,114,78,111,100,101,80,97,116,104,58,58,103,101,116,78,111,100,101,80,97,116,104,40,41,32,110,111,100,101,32,104,97,115,32,98,101,101,110,32,105,110,118,97,108,105,100,97,116,101,100,0,78,51,111,115,103,49,50,79,99,99,108,117,100,101,114,78,111,100,101,69,0,78,51,111,115,103,49,52,79,112,101,114,97,116,105,111,110,81,117,101,117,101,69,0,67,97,110,99,101,108,108,105,110,103,32,79,112,101,114,97,116,105,111,110,84,104,114,101,97,100,32,0,32,105,115,82,117,110,110,105,110,103,40,41,61,0,32,32,32,68,111,105,110,103,32,99,97,110,99,101,108,32,0,32,32,32,87,97,105,116,105,110,103,32,102,111,114,32,79,112,101,114,97,116,105,111,110,84,104,114,101,97,100,32,116,111,32,99,97,110,99,101,108,32,0,32,32,79,112,101,114,97,116,105,111,110,84,104,114,101,97,100,58,58,99,97,110,99,101,108,40,41,32,116,104,114,101,97,100,32,99,97,110,99,101,108,108,101,100,32,0,68,111,105,110,103,32,114,117,110,32,0,101,120,105,116,32,108,111,111,112,32,0,78,51,111,115,103,49,53,79,112,101,114,97,116,105,111,110,84,104,114,101,97,100,69,0,68,111,105,110,103,32,97,100,100,0,78,51,111,115,103,56,80,97,103,101,100,76,79,68,69,0,87,97,114,110,105,110,103,58,32,80,111,108,121,103,111,110,77,111,100,101,58,58,97,112,112,108,121,40,83,116,97,116,101,38,41,32,45,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,46,0,80,111,108,121,103,111,110,77,111,100,101,0,78,51,111,115,103,49,49,80,111,108,121,103,111,110,77,111,100,101,69,0,87,97,114,110,105,110,103,58,32,80,111,108,121,103,111,110,83,116,105,112,112,108,101,58,58,97,112,112,108,121,40,83,116,97,116,101,38,41,32,45,32,110,111,116,32,115,117,112,112,111,114,116,101,100,46,0,80,111,108,121,103,111,110,83,116,105,112,112,108,101,0,68,68,68,68,153,153,153,153,68,68,68,68,153,153,153,153,68,68,68,68,153,153,153,153,68,68,68,68,153,153,153,153,68,68,68,68,153,153,153,153,68,68,68,68,153,153,153,153,68,68,68,68,153,153,153,153,68,68,68,68,153,153,153,153,68,68,68,68,153,153,153,153,68,68,68,68,153,153,153,153,68,68,68,68,153,153,153,153,68,68,68,68,153,153,153,153,68,68,68,68,153,153,153,153,68,68,68,68,153,153,153,153,68,68,68,68,153,153,153,153,68,68,68,68,153,153,153,153,78,51,111,115,103,49,52,80,111,108,121,103,111,110,83,116,105,112,112,108,101,69,0,78,51,111,115,103,49,55,68,114,97,119,69,108,101,109,101,110,116,115,85,66,121,116,101,69,0,78,51,111,115,103,49,56,68,114,97,119,69,108,101,109,101,110,116,115,85,83,104,111,114,116,69,0,78,51,111,115,103,49,54,68,114,97,119,69,108,101,109,101,110,116,115,85,73,110,116,69,0,78,51,111,115,103,49,50,80,114,105,109,105,116,105,118,101,83,101,116,69,0,78,51,111,115,103,49,48,68,114,97,119,65,114,114,97,121,115,69,0,80,114,111,103,114,97,109,66,105,110,97,114,121,0,78,51,111,115,103,55,80,114,111,103,114,97,109,49,51,80,114,111,103,114,97,109,66,105,110,97,114,121,69,0,103,108,86,97,108,105,100,97,116,101,80,114,111,103,114,97,109,32,70,65,73,76,69,68,32,34,0,32,105,100,61,0,32,99,111,110,116,101,120,116,73,68,61,0,105,110,102,111,108,111,103,58,10,0,76,105,110,107,105,110,103,32,111,115,103,58,58,80,114,111,103,114,97,109,32,34,0,80,114,111,103,114,97,109,39,115,32,118,101,114,116,101,120,32,97,116,116,114,105,98,32,98,105,110,100,105,110,103,32,0,44,32,0,83,116,97,116,101,39,115,32,118,101,114,116,101,120,32,97,116,116,114,105,98,32,98,105,110,100,105,110,103,32,0,103,108,76,105,110,107,80,114,111,103,114,97,109,32,0,80,114,111,103,114,97,109,32,34,0,34,32,0,108,105,110,107,32,115,117,99,99,101,101,100,101,100,44,32,105,110,102,111,108,111,103,58,10,0,117,110,105,102,111,114,109,32,98,108,111,99,107,32,0,32,98,105,110,100,105,110,103,58,32,0,32,104,97,115,32,110,111,32,98,105,110,100,105,110,103,46,10,0,9,85,110,105,102,111,114,109,32,34,0,32,108,111,99,61,0,32,115,105,122,101,61,0,32,116,121,112,101,61,0,9,85,110,105,102,111,114,109,32,97,116,111,109,105,99,32,99,111,117,110,116,101,114,32,34,0,32,98,117,102,102,101,114,32,98,105,110,100,61,32,0,46,10,0,9,85,110,105,102,111,114,109,32,97,116,111,109,105,99,32,99,111,117,110,116,101,114,32,98,117,102,102,101,114,32,98,105,110,100,32,34,0,32,110,117,109,32,97,99,116,105,118,101,32,97,116,111,109,105,99,32,99,111,117,110,116,101,114,61,32,0,32,109,105,110,32,115,105,122,101,61,32,0,9,9,105,110,100,105,99,101,115,32,117,115,101,100,61,32,0,9,65,116,116,114,105,98,32,34,0,71,76,80,114,111,103,114,97,109,77,97,110,97,103,101,114,0,49,54,71,76,80,114,111,103,114,97,109,77,97,110,97,103,101,114,0,78,51,111,115,103,55,80,114,111,103,114,97,109,49,55,80,101,114,67,111,110,116,101,120,116,80,114,111,103,114,97,109,69,0,78,51,111,115,103,55,80,114,111,103,114,97,109,49,52,80,114,111,103,114,97,109,79,98,106,101,99,116,115,69,0,80,114,111,103,114,97,109,0,78,51,111,115,103,55,80,114,111,103,114,97,109,69,0,78,51,111,115,103,57,80,114,111,120,121,78,111,100,101,69,0,87,97,114,110,105,110,103,58,32,100,101,108,101,116,105,110,103,32,115,116,105,108,108,32,114,101,102,101,114,101,110,99,101,100,32,111,98,106,101,99,116,32,0,32,111,102,32,116,121,112,101,32,39,0,80,78,51,111,115,103,49,48,82,101,102,101,114,101,110,99,101,100,69,0,32,32,32,32,32,32,32,32,32,116,104,101,32,102,105,110,97,108,32,114,101,102,101,114,101,110,99,101,32,99,111,117,110,116,32,119,97,115,32,0,44,32,109,101,109,111,114,121,32,99,111,114,114,117,112,116,105,111,110,32,112,111,115,115,105,98,108,101,46,0,87,97,114,110,105,110,103,32,82,101,102,101,114,101,110,99,101,100,58,58,115,105,103,110,97,108,79,98,115,101,114,118,101,114,115,65,110,100,68,101,108,101,116,101,40,44,44,41,32,100,111,105,110,103,32,100,101,108,101,116,101,32,119,105,116,104,32,95,114,101,102,67,111,117,110,116,61,0,78,51,111,115,103,49,48,82,101,102,101,114,101,110,99,101,100,69,0,32,32,102,111,114,109,97,116,61,0,87,97,114,110,105,110,103,58,32,78,111,32,115,117,105,116,97,98,108,101,32,115,104,97,100,101,114,32,111,102,32,115,117,112,112,111,114,116,101,100,32,102,111,114,109,97,116,32,98,121,32,71,76,69,83,32,100,114,105,118,101,114,32,102,111,117,110,100,32,105,110,32,115,104,97,100,101,114,32,98,105,110,97,114,121,44,32,117,110,97,98,108,101,32,116,111,32,99,111,109,112,105,108,101,32,115,104,97,100,101,114,46,0,111,115,103,58,58,83,104,97,100,101,114,58,58,99,111,109,112,105,108,101,83,104,97,100,101,114,40,41,58,32,78,111,32,115,117,105,116,97,98,108,101,32,115,104,97,100,101,114,32,111,102,32,115,117,112,112,111,114,116,101,100,32,102,111,114,109,97,116,32,98,121,32,71,76,69,83,32,100,114,105,118,101,114,32,102,111,117,110,100,32,105,110,32,115,104,97,100,101,114,32,98,105,110,97,114,121,44,32,102,97,108,108,105,110,103,32,98,97,99,107,32,116,111,32,115,104,97,100,101,114,32,115,111,117,114,99,101,46,0,87,97,114,110,105,110,103,58,32,78,111,32,115,104,97,100,101,114,32,98,105,110,97,114,121,32,102,111,114,109,97,116,115,32,115,117,112,112,111,114,116,101,100,32,98,121,32,71,76,69,83,32,100,114,105,118,101,114,44,32,117,110,97,98,108,101,32,116,111,32,99,111,109,112,105,108,101,32,115,104,97,100,101,114,46,0,111,115,103,58,58,83,104,97,100,101,114,58,58,99,111,109,112,105,108,101,83,104,97,100,101,114,40,41,58,32,78,111,32,115,104,97,100,101,114,32,98,105,110,97,114,121,32,102,111,114,109,97,116,115,32,115,117,112,112,111,114,116,101,100,32,98,121,32,71,76,69,83,32,100,114,105,118,101,114,44,32,102,97,108,108,105,110,103,32,98,97,99,107,32,116,111,32,115,104,97,100,101,114,32,115,111,117,114,99,101,46,0,10,67,111,109,112,105,108,105,110,103,32,0,67,79,77,80,85,84,69,0,70,82,65,71,77,69,78,84,0,71,69,79,77,69,84,82,89,0,84,69,83,83,69,86,65,76,85,65,84,73,79,78,0,84,69,83,83,67,79,78,84,82,79,76,0,86,69,82,84,69,88,0,32,115,111,117,114,99,101,58,10,0,32,9,0,10,13,0,35,118,101,114,115,105,111,110,0,47,47,32,102,111,108,108,111,119,105,110,103,32,118,101,114,115,105,111,110,32,115,112,101,99,32,104,97,115,32,98,101,101,110,32,97,117,116,111,109,97,116,105,99,97,108,108,121,32,114,101,97,115,115,105,103,110,101,100,32,116,111,32,115,116,97,114,116,32,111,102,32,115,111,117,114,99,101,32,108,105,115,116,58,32,0,32,103,108,67,111,109,112,105,108,101,83,104,97,100,101,114,32,34,0,34,32,70,65,73,76,69,68,0,32,83,104,97,100,101,114,32,34,0,34,32,105,110,102,111,108,111,103,58,10,0,83,104,97,100,101,114,32,116,121,112,101,32,105,115,32,85,78,68,69,70,73,78,69,68,0,71,76,83,104,97,100,101,114,77,97,110,97,103,101,114,0,49,53,71,76,83,104,97,100,101,114,77,97,110,97,103,101,114,0,78,51,111,115,103,54,83,104,97,100,101,114,49,54,80,101,114,67,111,110,116,101,120,116,83,104,97,100,101,114,69,0,78,51,111,115,103,54,83,104,97,100,101,114,49,51,83,104,97,100,101,114,79,98,106,101,99,116,115,69,0,83,104,97,100,101,114,0,78,51,111,115,103,54,83,104,97,100,101,114,69,0,35,112,114,97,103,109,97,0,10,70,111,117,110,100,32,112,114,97,103,109,97,32,108,105,110,101,32,91,0,32,9,40,0,105,109,112,111,114,116,95,100,101,102,105,110,101,115,0,114,101,113,117,105,114,101,115,0,32,32,32,32,32,32,100,101,102,105,110,101,32,91,0,32,32,32,32,32,32,114,101,113,117,105,114,101,109,101,110,116,115,32,91,0,32,32,32,32,70,111,117,110,100,32,107,101,121,119,111,114,100,32,91,0,93,32,98,117,116,32,110,111,116,32,109,97,116,99,104,101,100,32,40,41,10,0,83,104,97,100,101,114,58,58,95,112,97,114,115,101,83,104,97,100,101,114,68,101,102,105,110,101,115,40,0,32,9,44,0,32,9,44,41,0,32,32,32,100,101,102,105,110,101,115,46,105,110,115,101,114,116,40,0,78,51,111,115,103,53,83,104,97,112,101,69,0,78,51,111,115,103,49,49,72,101,105,103,104,116,70,105,101,108,100,69,0,87,97,114,110,105,110,103,58,32,66,117,105,108,100,83,104,97,112,101,71,101,111,109,101,116,114,121,86,105,115,105,116,111,114,58,58,97,112,112,108,121,40,99,111,110,115,116,32,73,110,102,105,110,105,116,101,80,108,97,110,101,38,32,112,108,97,110,101,41,32,110,111,116,32,121,101,116,32,105,109,112,108,101,109,101,110,116,101,100,46,32,0,78,51,111,115,103,50,53,66,117,105,108,100,83,104,97,112,101,71,101,111,109,101,116,114,121,86,105,115,105,116,111,114,69,0,78,51,111,115,103,49,55,67,111,110,115,116,83,104,97,112,101,86,105,115,105,116,111,114,69,0,83,104,97,112,101,0,83,112,104,101,114,101,0,78,51,111,115,103,54,83,112,104,101,114,101,69,0,87,97,114,110,105,110,103,58,32,66,117,105,108,100,83,104,97,112,101,71,101,111,109,101,116,114,121,86,105,115,105,116,111,114,40,41,32,71,101,111,109,101,116,114,121,32,99,111,110,116,97,105,110,115,32,99,111,109,112,97,116,105,98,108,101,32,97,114,114,97,121,115,44,32,114,101,115,101,116,116,105,110,103,32,98,101,102,111,114,101,32,115,104,97,112,101,32,98,117,105,108,100,46,0,65,100,100,105,110,103,32,112,97,114,101,110,116,0,83,116,97,116,101,65,116,116,114,105,98,117,116,101,58,58,83,101,116,116,105,110,103,32,85,112,100,97,116,101,32,99,97,108,108,98,97,99,107,115,0,32,32,82,101,109,111,118,101,100,32,102,114,111,109,32,112,97,114,101,110,116,32,0,32,32,32,65,100,100,101,100,32,98,97,99,107,32,116,111,32,112,97,114,101,110,116,32,0,78,51,111,115,103,53,83,116,97,116,101,69,0,79,83,71,95,71,76,95,69,82,82,79,82,95,67,72,69,67,75,73,78,71,32,60,116,121,112,101,62,0,79,78,67,69,95,80,69,82,95,65,84,84,82,73,66,85,84,69,32,124,32,79,78,32,124,32,111,110,32,101,110,97,98,108,101,115,32,102,105,110,101,32,103,114,97,105,110,101,100,32,99,104,101,99,107,105,110,103,44,32,32,79,78,67,69,95,80,69,82,95,70,82,65,77,69,32,101,110,97,98,108,101,115,32,99,111,97,114,115,101,32,103,114,97,105,110,101,100,32,99,104,101,99,107,105,110,103,0,111,115,103,95,77,111,100,101,108,86,105,101,119,77,97,116,114,105,120,0,111,115,103,95,80,114,111,106,101,99,116,105,111,110,77,97,116,114,105,120,0,111,115,103,95,77,111,100,101,108,86,105,101,119,80,114,111,106,101,99,116,105,111,110,77,97,116,114,105,120,0,111,115,103,95,78,111,114,109,97,108,77,97,116,114,105,120,0,79,83,71,95,71,76,95,69,82,82,79,82,95,67,72,69,67,75,73,78,71,0,79,78,67,69,95,80,69,82,95,65,84,84,82,73,66,85,84,69,0,103,108,95,86,101,114,116,101,120,0,111,115,103,95,86,101,114,116,101,120,0,118,101,99,52,32,0,103,108,95,78,111,114,109,97,108,0,111,115,103,95,78,111,114,109,97,108,0,118,101,99,51,32,0,111,115,103,95,67,111,108,111,114,0,103,108,95,83,101,99,111,110,100,97,114,121,67,111,108,111,114,0,111,115,103,95,83,101,99,111,110,100,97,114,121,67,111,108,111,114,0,103,108,95,77,117,108,116,105,84,101,120,67,111,111,114,100,0,111,115,103,95,77,117,108,116,105,84,101,120,67,111,111,114,100,0,103,108,95,70,111,103,67,111,111,114,100,0,111,115,103,95,70,111,103,67,111,111,114,100,0,102,108,111,97,116,32,0,71,76,95,86,69,78,68,79,82,32,61,32,91,0,93,0,71,76,95,69,88,84,95,115,101,99,111,110,100,97,114,121,95,99,111,108,111,114,0,71,76,95,69,88,84,95,102,111,103,95,99,111,111,114,100,0,95,102,111,114,99,101,86,101,114,116,101,120,65,114,114,97,121,79,98,106,101,99,116,32,61,32,0,95,102,111,114,99,101,86,101,114,116,101,120,66,117,102,102,101,114,79,98,106,101,99,116,32,61,32,0,103,108,67,108,105,101,110,116,65,99,116,105,118,101,84,101,120,116,117,114,101,65,82,66,0,103,108,65,99,116,105,118,101,84,101,120,116,117,114,101,65,82,66,0,103,108,70,111,103,67,111,111,114,100,80,111,105,110,116,101,114,0,103,108,70,111,103,67,111,111,114,100,80,111,105,110,116,101,114,69,88,84,0,103,108,83,101,99,111,110,100,97,114,121,67,111,108,111,114,80,111,105,110,116,101,114,0,103,108,83,101,99,111,110,100,97,114,121,67,111,108,111,114,80,111,105,110,116,101,114,69,88,84,0,103,108,86,101,114,116,101,120,65,116,116,114,105,98,80,111,105,110,116,101,114,65,82,66,0,103,108,86,101,114,116,101,120,65,116,116,114,105,98,73,80,111,105,110,116,101,114,0,103,108,86,101,114,116,101,120,65,116,116,114,105,98,76,80,111,105,110,116,101,114,0,103,108,69,110,97,98,108,101,86,101,114,116,101,120,65,116,116,114,105,98,65,114,114,97,121,65,82,66,0,103,108,77,117,108,116,105,84,101,120,67,111,111,114,100,52,102,0,103,108,77,117,108,116,105,84,101,120,67,111,111,114,100,52,102,65,82,66,0,103,108,68,105,115,97,98,108,101,86,101,114,116,101,120,65,116,116,114,105,98,65,114,114,97,121,65,82,66,0,103,108,66,105,110,100,66,117,102,102,101,114,65,82,66,0,103,108,68,114,97,119,65,114,114,97,121,115,73,110,115,116,97,110,99,101,100,65,82,66,0,103,108,68,114,97,119,65,114,114,97,121,115,73,110,115,116,97,110,99,101,100,69,88,84,0,103,108,68,114,97,119,69,108,101,109,101,110,116,115,73,110,115,116,97,110,99,101,100,65,82,66,0,103,108,68,114,97,119,69,108,101,109,101,110,116,115,73,110,115,116,97,110,99,101,100,69,88,84,0,71,76,95,65,82,66,95,118,101,114,116,101,120,95,115,104,97,100,101,114,0,82,97,100,101,111,110,0,82,65,68,69,79,78,0,70,105,114,101,80,114,111,0,111,115,103,58,58,83,116,97,116,101,58,58,95,109,97,120,84,101,120,116,117,114,101,80,111,111,108,83,105,122,101,61,0,111,115,103,58,58,83,116,97,116,101,58,58,95,109,97,120,66,117,102,102,101,114,79,98,106,101,99,116,80,111,111,108,83,105,122,101,61,0,87,97,114,110,105,110,103,58,32,83,116,97,116,101,58,58,114,101,109,111,118,101,83,116,97,116,101,83,101,116,40,0,41,32,111,117,116,32,111,102,32,114,97,110,103,101,0,115,116,97,114,116,32,111,102,32,83,116,97,116,101,58,58,97,112,112,108,121,40,83,116,97,116,101,83,101,116,42,41,0,101,110,100,32,111,102,32,83,116,97,116,101,58,58,97,112,112,108,121,40,83,116,97,116,101,83,101,116,42,41,0,115,116,97,114,116,32,111,102,32,83,116,97,116,101,58,58,97,112,112,108,121,40,41,0,101,110,100,32,111,102,32,83,116,97,116,101,58,58,97,112,112,108,121,40,41,0,87,97,114,110,105,110,103,58,32,100,101,116,101,99,116,101,100,32,79,112,101,110,71,76,32,101,114,114,111,114,32,39,0,39,32,97,102,116,101,114,32,97,112,112,108,121,105,110,103,32,97,116,116,114,105,98,117,116,101,32,0,87,97,114,110,105,110,103,58,32,100,101,116,101,99,116,101,100,32,79,112,101,110,71,76,32,101,114,114,111,114,32,110,117,109,98,101,114,32,48,120,0,32,97,102,116,101,114,32,97,112,112,108,121,105,110,103,32,97,116,116,114,105,98,117,116,101,32,0,39,32,97,102,116,101,114,32,97,112,112,108,121,105,110,103,32,71,76,77,111,100,101,32,48,120,0,32,97,102,116,101,114,32,97,112,112,108,121,105,110,103,32,71,76,77,111,100,101,32,48,120,0,39,0,32,97,116,0,32,105,110,32,111,115,103,58,58,83,116,97,116,101,46,0,83,116,97,116,101,58,58,99,111,110,118,101,114,116,83,104,97,100,101,114,83,111,117,114,99,101,84,111,79,115,103,66,117,105,108,116,73,110,115,40,41,0,43,43,66,101,102,111,114,101,32,67,111,110,118,101,114,116,101,100,32,115,111,117,114,99,101,32,0,43,43,43,43,43,43,43,43,0,97,116,116,114,105,98,117,116,101,32,0,35,118,101,114,115,105,111,110,32,0,115,104,97,100,101,114,32,118,101,114,115,105,111,110,32,102,111,117,110,100,58,32,0,105,110,32,0,35,101,120,116,101,110,115,105,111,110,32,0,102,116,114,97,110,115,102,111,114,109,40,41,0,103,108,95,77,111,100,101,108,86,105,101,119,80,114,111,106,101,99,116,105,111,110,77,97,116,114,105,120,32,42,32,103,108,95,86,101,114,116,101,120,0,103,108,95,77,111,100,101,108,86,105,101,119,77,97,116,114,105,120,0,109,97,116,52,32,0,103,108,95,77,111,100,101,108,86,105,101,119,80,114,111,106,101,99,116,105,111,110,77,97,116,114,105,120,0,103,108,95,80,114,111,106,101,99,116,105,111,110,77,97,116,114,105,120,0,103,108,95,78,111,114,109,97,108,77,97,116,114,105,120,0,109,97,116,51,32,0,45,45,45,45,45,45,45,45,32,67,111,110,118,101,114,116,101,100,32,115,111,117,114,99,101,32,0,45,45,45,45,45,45,45,45,45,45,45,45,45,45,45,45,0,35,100,101,102,105,110,101,32,0,83,116,97,116,101,83,101,116,0,78,51,111,115,103,56,83,116,97,116,101,83,101,116,69,0,118,111,105,100,32,83,116,97,116,101,83,101,116,58,58,115,101,116,71,108,111,98,97,108,68,101,102,97,117,108,116,115,40,41,0,32,32,32,83,116,97,116,101,83,101,116,58,58,115,101,116,71,108,111,98,97,108,68,101,102,97,117,108,116,115,40,41,32,83,101,116,116,105,110,103,32,117,112,32,71,76,51,32,99,111,109,112,97,116,105,98,108,101,32,115,104,97,100,101,114,115,0,35,118,101,114,115,105,111,110,32,51,48,48,32,101,115,10,47,47,32,103,108,51,95,86,101,114,116,101,120,83,104,97,100,101,114,10,35,105,102,100,101,102,32,71,76,95,69,83,10,32,32,32,32,112,114,101,99,105,115,105,111,110,32,104,105,103,104,112,32,102,108,111,97,116,59,10,35,101,110,100,105,102,10,105,110,32,118,101,99,52,32,111,115,103,95,86,101,114,116,101,120,59,10,105,110,32,118,101,99,52,32,111,115,103,95,67,111,108,111,114,59,10,105,110,32,118,101,99,52,32,111,115,103,95,77,117,108,116,105,84,101,120,67,111,111,114,100,48,59,10,117,110,105,102,111,114,109,32,109,97,116,52,32,111,115,103,95,77,111,100,101,108,86,105,101,119,80,114,111,106,101,99,116,105,111,110,77,97,116,114,105,120,59,10,111,117,116,32,118,101,99,50,32,116,101,120,67,111,111,114,100,59,10,111,117,116,32,118,101,99,52,32,118,101,114,116,101,120,67,111,108,111,114,59,10,118,111,105,100,32,109,97,105,110,40,118,111,105,100,41,10,123,10,32,32,32,32,103,108,95,80,111,115,105,116,105,111,110,32,61,32,111,115,103,95,77,111,100,101,108,86,105,101,119,80,114,111,106,101,99,116,105,111,110,77,97,116,114,105,120,32,42,32,111,115,103,95,86,101,114,116,101,120,59,10,32,32,32,32,116,101,120,67,111,111,114,100,32,61,32,111,115,103,95,77,117,108,116,105,84,101,120,67,111,111,114,100,48,46,120,121,59,10,32,32,32,32,118,101,114,116,101,120,67,111,108,111,114,32,61,32,111,115,103,95,67,111,108,111,114,59,32,10,125,10,0,35,118,101,114,115,105,111,110,32,51,48,48,32,101,115,10,47,47,32,103,108,51,95,70,114,97,103,109,101,110,116,83,104,97,100,101,114,10,35,105,102,100,101,102,32,71,76,95,69,83,10,32,32,32,32,112,114,101,99,105,115,105,111,110,32,104,105,103,104,112,32,102,108,111,97,116,59,10,35,101,110,100,105,102,10,117,110,105,102,111,114,109,32,115,97,109,112,108,101,114,50,68,32,98,97,115,101,84,101,120,116,117,114,101,59,10,105,110,32,118,101,99,50,32,116,101,120,67,111,111,114,100,59,10,105,110,32,118,101,99,52,32,118,101,114,116,101,120,67,111,108,111,114,59,10,111,117,116,32,118,101,99,52,32,99,111,108,111,114,59,10,118,111,105,100,32,109,97,105,110,40,118,111,105,100,41,10,123,10,32,32,32,32,99,111,108,111,114,32,61,32,118,101,114,116,101,120,67,111,108,111,114,32,42,32,116,101,120,116,117,114,101,40,98,97,115,101,84,101,120,116,117,114,101,44,32,116,101,120,67,111,111,114,100,41,59,10,125,10,0,98,97,115,101,84,101,120,116,117,114,101,0,32,32,32,83,116,97,116,101,83,101,116,58,58,115,101,116,71,108,111,98,97,108,68,101,102,97,117,108,116,115,40,41,32,83,101,116,116,105,110,103,32,117,112,32,71,76,50,32,99,111,109,112,97,116,105,98,108,101,32,115,104,97,100,101,114,115,0,47,47,32,103,108,50,95,86,101,114,116,101,120,83,104,97,100,101,114,10,35,105,102,100,101,102,32,71,76,95,69,83,10,32,32,32,32,112,114,101,99,105,115,105,111,110,32,104,105,103,104,112,32,102,108,111,97,116,59,10,35,101,110,100,105,102,10,118,97,114,121,105,110,103,32,118,101,99,50,32,116,101,120,67,111,111,114,100,59,10,118,97,114,121,105,110,103,32,118,101,99,52,32,118,101,114,116,101,120,67,111,108,111,114,59,10,118,111,105,100,32,109,97,105,110,40,118,111,105,100,41,10,123,10,32,32,32,32,103,108,95,80,111,115,105,116,105,111,110,32,61,32,103,108,95,77,111,100,101,108,86,105,101,119,80,114,111,106,101,99,116,105,111,110,77,97,116,114,105,120,32,42,32,103,108,95,86,101,114,116,101,120,59,10,32,32,32,32,116,101,120,67,111,111,114,100,32,61,32,103,108,95,77,117,108,116,105,84,101,120,67,111,111,114,100,48,46,120,121,59,10,32,32,32,32,118,101,114,116,101,120,67,111,108,111,114,32,61,32,103,108,95,67,111,108,111,114,59,32,10,125,10,0,47,47,32,103,108,50,95,70,114,97,103,109,101,110,116,83,104,97,100,101,114,10,35,105,102,100,101,102,32,71,76,95,69,83,10,32,32,32,32,112,114,101,99,105,115,105,111,110,32,104,105,103,104,112,32,102,108,111,97,116,59,10,35,101,110,100,105,102,10,117,110,105,102,111,114,109,32,115,97,109,112,108,101,114,50,68,32,98,97,115,101,84,101,120,116,117,114,101,59,10,118,97,114,121,105,110,103,32,118,101,99,50,32,116,101,120,67,111,111,114,100,59,10,118,97,114,121,105,110,103,32,118,101,99,52,32,118,101,114,116,101,120,67,111,108,111,114,59,10,118,111,105,100,32,109,97,105,110,40,118,111,105,100,41,10,123,10,32,32,32,32,103,108,95,70,114,97,103,67,111,108,111,114,32,61,32,118,101,114,116,101,120,67,111,108,111,114,32,42,32,116,101,120,116,117,114,101,50,68,40,98,97,115,101,84,101,120,116,117,114,101,44,32,116,101,120,67,111,111,114,100,41,59,10,125,10,0,87,97,114,110,105,110,103,58,32,116,101,120,116,117,114,101,32,97,116,116,114,105,98,117,116,101,32,39,0,39,32,112,97,115,115,101,100,32,116,111,32,115,101,116,84,101,120,116,117,114,101,65,116,116,114,105,98,117,116,101,40,117,110,105,116,44,97,116,116,114,44,118,97,108,117,101,41,44,32,0,32,32,32,32,32,32,32,32,32,97,115,115,117,109,105,110,103,32,115,101,116,65,116,116,114,105,98,117,116,101,40,97,116,116,114,44,118,97,108,117,101,41,32,105,110,115,116,101,97,100,46,0,32,32,32,32,32,32,32,32,32,112,108,101,97,115,101,32,99,104,97,110,103,101,32,99,97,108,108,105,110,103,32,99,111,100,101,32,116,111,32,117,115,101,32,97,112,112,114,111,112,114,105,97,116,101,32,99,97,108,108,46,0,39,112,97,115,115,101,100,32,116,111,32,115,101,116,65,116,116,114,105,98,117,116,101,40,97,116,116,114,44,118,97,108,117,101,41,44,32,0,32,32,32,32,32,32,32,32,32,97,115,115,117,109,105,110,103,32,115,101,116,84,101,120,116,117,114,101,65,116,116,114,105,98,117,116,101,40,117,110,105,116,61,48,44,97,116,116,114,44,118,97,108,117,101,41,32,105,110,115,116,101,97,100,46,0,39,32,112,97,115,115,101,100,32,116,111,32,115,101,116,65,116,116,114,105,98,117,116,101,65,110,100,77,111,100,101,115,40,97,116,116,114,44,118,97,108,117,101,41,44,32,0,32,32,32,32,32,32,32,32,32,97,115,115,117,109,105,110,103,32,115,101,116,84,101,120,116,117,114,101,65,116,116,114,105,98,117,116,101,65,110,100,77,111,100,101,115,40,117,110,105,116,61,48,44,97,116,116,114,44,118,97,108,117,101,41,32,105,110,115,116,101,97,100,46,0,87,97,114,110,105,110,103,58,32,110,111,110,32,116,101,120,116,117,114,101,32,97,116,116,114,105,98,117,116,101,32,39,0,39,32,112,97,115,115,101,100,32,116,111,32,115,101,116,84,101,120,116,117,114,101,65,116,116,114,105,98,117,116,101,65,110,100,77,111,100,101,115,40,117,110,105,116,44,97,116,116,114,44,118,97,108,117,101,41,44,32,0,32,32,32,32,32,32,32,32,32,97,115,115,117,109,105,110,103,32,115,101,116,65,116,116,114,105,98,117,116,101,65,110,100,77,111,100,101,115,40,97,116,116,114,44,118,97,108,117,101,41,32,105,110,115,116,101,97,100,46,0,87,97,114,110,105,110,103,58,32,110,111,110,45,116,101,120,116,117,114,101,32,109,111,100,101,32,39,0,39,112,97,115,115,101,100,32,116,111,32,115,101,116,84,101,120,116,117,114,101,77,111,100,101,40,117,110,105,116,44,109,111,100,101,44,118,97,108,117,101,41,44,32,0,32,32,32,32,32,32,32,32,32,97,115,115,117,109,105,110,103,32,115,101,116,77,111,100,101,40,109,111,100,101,44,118,97,108,117,101,41,32,105,110,115,116,101,97,100,46,0,50,51,83,101,116,65,115,115,111,99,105,97,116,101,77,111,100,101,115,72,101,108,112,101,114,0,78,51,111,115,103,49,52,83,116,97,116,101,65,116,116,114,105,98,117,116,101,57,77,111,100,101,85,115,97,103,101,69,0,87,97,114,110,105,110,103,58,32,116,101,120,116,117,114,101,32,109,111,100,101,32,39,0,39,112,97,115,115,101,100,32,116,111,32,115,101,116,77,111,100,101,40,109,111,100,101,44,118,97,108,117,101,41,44,32,0,32,32,32,32,32,32,32,32,32,97,115,115,117,109,105,110,103,32,115,101,116,84,101,120,116,117,114,101,77,111,100,101,40,117,110,105,116,61,48,44,109,111,100,101,44,118,97,108,117,101,41,32,105,110,115,116,101,97,100,46,0,69,114,114,111,114,58,32,83,101,116,116,105,110,103,32,109,111,100,101,32,39,71,76,95,67,79,76,79,82,95,77,65,84,69,82,73,65,76,39,32,118,105,97,32,111,115,103,58,58,83,116,97,116,101,83,101,116,58,58,115,101,116,77,111,100,101,40,109,111,100,101,44,118,97,108,117,101,41,32,105,103,110,111,114,101,100,46,10,0,32,32,32,32,32,32,32,84,104,101,32,109,111,100,101,32,39,71,76,95,67,79,76,79,82,95,77,65,84,69,82,73,65,76,39,32,105,115,32,115,101,116,32,98,121,32,116,104,101,32,111,115,103,58,58,77,97,116,101,114,105,97,108,32,83,116,97,116,101,65,116,116,114,105,98,117,116,101,46,10,0,32,32,32,32,32,32,32,83,101,116,116,105,110,103,32,116,104,105,115,32,109,111,100,101,32,119,111,117,108,100,32,99,111,110,102,117,115,101,32,111,115,103,39,115,32,83,116,97,116,101,32,116,114,97,99,107,105,110,103,46,0,39,112,97,115,115,101,100,32,116,111,32,115,101,116,77,111,100,101,84,111,73,110,104,101,114,105,116,40,109,111,100,101,41,44,32,0,32,32,32,32,32,32,32,32,32,97,115,115,117,109,105,110,103,32,115,101,116,84,101,120,116,117,114,101,77,111,100,101,84,111,73,110,104,101,114,105,116,40,117,110,105,116,61,48,44,109,111,100,101,41,32,105,110,115,116,101,97,100,46,0,69,114,114,111,114,58,32,83,101,116,116,105,110,103,32,109,111,100,101,32,39,71,76,95,67,79,76,79,82,95,77,65,84,69,82,73,65,76,39,32,118,105,97,32,111,115,103,58,58,83,116,97,116,101,83,101,116,58,58,114,101,109,111,118,101,77,111,100,101,40,109,111,100,101,41,32,105,103,110,111,114,101,100,46,10,0,39,112,97,115,115,101,100,32,116,111,32,115,101,116,84,101,120,116,117,114,101,77,111,100,101,84,111,73,110,104,101,114,105,116,40,117,110,105,116,44,109,111,100,101,41,44,32,0,32,32,32,32,32,32,32,32,32,97,115,115,117,109,105,110,103,32,115,101,116,77,111,100,101,84,111,73,110,104,101,114,105,116,40,117,110,105,116,61,48,44,109,111,100,101,41,32,105,110,115,116,101,97,100,46,0,98,101,102,111,114,101,32,83,116,97,116,101,83,101,116,58,58,99,111,109,112,105,108,101,71,76,79,98,101,106,99,116,115,40,41,0,83,116,97,116,101,83,101,116,58,58,99,111,109,112,105,108,101,71,76,79,98,101,106,99,116,115,40,41,32,99,111,109,112,105,108,105,110,103,32,0,83,116,97,116,101,83,101,116,58,58,99,111,109,112,105,108,101,71,76,79,98,101,106,99,116,115,40,41,32,99,111,109,112,105,108,105,110,103,32,116,101,120,116,117,114,101,32,97,116,116,114,105,98,117,116,101,0,50,54,82,101,109,111,118,101,65,115,115,111,99,105,97,116,101,77,111,100,101,115,72,101,108,112,101,114,0,78,51,111,115,103,53,83,116,97,116,115,69,0,70,97,105,108,101,100,32,116,111,32,97,115,115,105,103,110,32,118,97,108,105,100,32,105,110,100,101,120,32,102,111,114,32,83,116,97,116,115,58,58,115,101,116,65,116,116,114,105,98,117,116,101,40,0,83,116,101,110,99,105,108,0,78,51,111,115,103,55,83,116,101,110,99,105,108,69,0,87,97,114,110,105,110,103,58,32,84,101,120,77,97,116,58,58,97,112,112,108,121,40,83,116,97,116,101,38,41,32,45,32,110,111,116,32,115,117,112,112,111,114,116,101,100,46,0,84,101,120,77,97,116,0,78,51,111,115,103,54,84,101,120,77,97,116,69,0,78,51,111,115,103,57,84,101,120,116,117,114,101,49,68,69,0,87,97,114,110,105,110,103,58,32,84,101,120,116,117,114,101,49,68,58,58,99,111,112,121,84,101,120,83,117,98,73,109,97,103,101,49,68,40,46,46,41,32,110,111,116,32,115,117,112,112,111,114,116,101,100,46,0,78,51,111,115,103,49,52,84,101,120,116,117,114,101,50,68,65,114,114,97,121,69,0,84,101,120,116,117,114,101,50,68,0,78,51,111,115,103,57,84,101,120,116,117,114,101,50,68,69,0,87,97,114,110,105,110,103,58,32,84,101,120,116,117,114,101,50,68,58,58,99,111,112,121,84,101,120,73,109,97,103,101,50,68,40,44,44,44,44,41,32,115,119,105,116,99,104,32,111,102,102,32,109,105,112,32,109,97,112,112,105,110,103,32,97,115,32,104,97,114,100,119,97,114,101,32,115,117,112,112,111,114,116,32,110,111,116,32,97,118,97,105,108,97,98,108,101,46,0,78,51,111,115,103,50,48,84,101,120,116,117,114,101,50,68,77,117,108,116,105,115,97,109,112,108,101,69,0,78,51,111,115,103,57,84,101,120,116,117,114,101,51,68,69,0,87,97,114,110,105,110,103,58,32,84,101,120,116,117,114,101,51,68,58,58,99,111,112,121,84,101,120,83,117,98,73,109,97,103,101,51,68,40,46,46,41,32,102,97,105,108,101,100], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+143612);
/* memory initializer */ allocate([44,32,99,97,110,110,111,116,32,110,111,116,32,99,111,112,121,32,116,111,32,97,32,110,111,110,32,101,120,105,115,116,101,110,116,32,116,101,120,116,117,114,101,46,0,78,51,111,115,103,49,54,84,101,120,116,117,114,101,79,98,106,101,99,116,83,101,116,69,0,95,112,97,114,101,110,116,45,62,103,101,116,67,117,114,114,84,101,120,116,117,114,101,80,111,111,108,83,105,122,101,40,41,61,0,32,95,112,97,114,101,110,116,45,62,103,101,116,77,97,120,84,101,120,116,117,114,101,80,111,111,108,83,105,122,101,40,41,61,0,76,111,111,107,105,110,103,32,116,111,32,114,101,99,108,97,105,109,32,0,44,32,103,111,105,110,103,32,116,111,32,108,111,111,107,32,116,111,32,114,101,109,111,118,101,32,0,32,102,114,111,109,32,0,32,111,114,112,104,97,110,115,0,84,101,120,116,117,114,101,79,98,106,101,99,116,77,97,110,97,103,101,114,58,58,114,101,99,111,109,112,117,116,101,83,116,97,116,115,40,41,0,32,32,32,110,117,109,79,98,106,101,99,116,115,73,110,76,105,115,116,115,61,0,44,32,110,117,109,65,99,116,105,118,101,61,0,44,32,110,117,109,79,114,112,104,97,110,115,61,0,32,99,117,114,114,101,110,116,83,105,122,101,61,0,32,32,32,103,101,116,77,97,120,84,101,120,116,117,114,101,80,111,111,108,83,105,122,101,40,41,61,0,32,99,117,114,114,101,110,116,47,109,97,120,32,115,105,122,101,32,61,32,0,32,32,32,115,105,122,101,61,0,44,32,111,115,45,62,99,111,109,112,117,116,101,78,117,109,84,101,120,116,117,114,101,79,98,106,101,99,116,115,73,110,76,105,115,116,40,41,0,44,32,111,115,45,62,103,101,116,78,117,109,79,102,84,101,120,116,117,114,101,79,98,106,101,99,116,115,40,41,0,44,32,111,115,45,62,103,101,116,78,117,109,79,114,112,104,97,110,115,40,41,0,44,32,111,115,45,62,103,101,116,78,117,109,80,101,110,100,105,110,103,79,114,112,104,97,110,115,40,41,0,32,32,32,87,65,82,78,73,78,71,58,32,95,99,117,114,114,84,101,120,116,117,114,101,80,111,111,108,83,105,122,101,40,0,41,32,33,61,32,99,117,114,114,101,110,116,83,105,122,101,44,32,100,101,108,116,97,32,61,32,0,84,101,120,116,117,114,101,79,98,106,101,99,116,77,97,110,97,110,103,101,114,58,58,114,101,112,111,114,116,83,116,97,116,115,40,41,0,32,32,32,116,111,116,97,108,32,95,110,117,109,79,102,84,101,120,116,117,114,101,79,98,106,101,99,116,115,61,0,44,32,95,110,117,109,79,114,112,104,97,110,101,100,84,101,120,116,117,114,101,79,98,106,101,99,116,115,61,0,32,95,99,117,114,114,84,101,120,116,117,114,101,80,111,111,108,83,105,122,101,61,0,32,32,32,116,111,116,97,108,32,95,110,117,109,71,101,110,101,114,97,116,101,100,61,0,44,32,95,103,101,110,101,114,97,116,101,84,105,109,101,61,0,44,32,97,118,101,114,97,103,101,80,101,114,70,114,97,109,101,61,0,32,32,32,116,111,116,97,108,32,95,110,117,109,68,101,108,101,116,101,100,61,0,44,32,95,100,101,108,101,116,101,84,105,109,101,61,0,78,51,111,115,103,50,48,84,101,120,116,117,114,101,79,98,106,101,99,116,77,97,110,97,103,101,114,69,0,84,101,120,116,117,114,101,0,78,51,111,115,103,55,84,101,120,116,117,114,101,69,0,78,51,111,115,103,55,84,101,120,116,117,114,101,49,51,84,101,120,116,117,114,101,79,98,106,101,99,116,69,0,79,83,71,95,77,65,88,95,84,69,88,84,85,82,69,95,83,73,90,69,0,83,101,116,32,116,104,101,32,109,97,120,105,109,117,109,32,115,105,122,101,32,111,102,32,116,101,120,116,117,114,101,115,46,0,79,83,71,95,71,76,95,84,69,88,84,85,82,69,95,83,84,79,82,65,71,69,0,79,78,124,79,70,70,32,111,114,32,69,78,65,66,76,69,124,68,73,83,65,66,76,69,44,32,69,110,97,98,108,101,115,47,100,105,115,97,98,108,101,115,32,117,115,97,103,101,32,111,102,32,103,108,84,101,120,83,116,111,114,97,103,101,32,102,111,114,32,116,101,120,116,117,114,101,115,32,119,104,101,114,101,32,115,117,112,112,111,114,116,101,100,44,32,100,101,102,97,117,108,116,32,105,115,32,69,78,65,66,76,69,68,46,0,69,114,114,111,114,32,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,32,83,104,111,117,108,100,32,110,111,116,32,103,101,116,32,104,101,114,101,32,33,33,33,33,33,33,33,33,33,0,69,114,114,111,114,32,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,32,83,104,111,117,108,100,32,110,111,116,32,103,101,116,32,104,101,114,101,32,101,105,116,104,101,114,32,33,33,33,33,33,33,33,33,33,0,82,101,117,115,105,110,103,32,111,114,112,104,97,110,101,100,32,84,101,120,116,117,114,101,79,98,106,101,99,116,44,32,95,110,117,109,79,102,84,101,120,116,117,114,101,79,98,106,101,99,116,115,61,0,84,101,120,116,117,114,101,79,98,106,101,99,116,83,101,116,61,0,58,32,82,101,117,115,105,110,103,32,97,110,32,97,99,116,105,118,101,32,84,101,120,116,117,114,101,79,98,106,101,99,116,32,0,32,95,110,117,109,79,102,84,101,120,116,117,114,101,79,98,106,101,99,116,115,61,0,32,119,105,100,116,104,61,0,32,104,101,105,103,104,116,61,0,82,101,117,115,105,110,103,32,97,32,114,101,99,101,110,116,108,121,32,111,114,112,104,97,110,101,100,32,97,99,116,105,118,101,32,84,101,120,116,117,114,101,79,98,106,101,99,116,32,0,67,114,101,97,116,101,100,32,110,101,119,32,0,32,84,101,120,116,117,114,101,79,98,106,101,99,116,44,32,95,110,117,109,79,102,84,101,120,116,117,114,101,79,98,106,101,99,116,115,32,0,84,101,120,116,117,114,101,79,98,106,101,99,116,77,97,110,97,103,101,114,0,87,97,114,110,105,110,103,58,32,110,101,119,32,77,97,120,84,101,120,116,117,114,101,80,111,111,108,83,105,122,101,61,0,32,105,115,32,115,109,97,108,108,101,114,32,116,104,97,110,32,99,117,114,114,101,110,116,32,84,101,120,116,117,114,101,80,111,111,108,83,105,122,101,61,0,69,114,114,111,114,58,32,105,110,118,97,108,105,100,32,39,119,104,105,99,104,39,32,112,97,115,115,101,100,32,84,101,120,116,117,114,101,58,58,115,101,116,87,114,97,112,40,0,44,0,69,114,114,111,114,58,32,105,110,118,97,108,105,100,32,39,119,104,105,99,104,39,32,112,97,115,115,101,100,32,84,101,120,116,117,114,101,58,58,115,101,116,70,105,108,116,101,114,40,0,69,114,114,111,114,58,32,105,110,118,97,108,105,100,32,39,119,104,105,99,104,39,32,112,97,115,115,101,100,32,84,101,120,116,117,114,101,58,58,103,101,116,70,105,108,116,101,114,40,119,104,105,99,104,41,0,84,101,120,116,117,114,101,58,58,103,101,116,67,111,109,112,114,101,115,115,101,100,83,105,122,101,40,46,46,46,41,32,58,32,99,97,110,110,111,116,32,99,111,109,112,117,116,101,32,99,111,114,114,101,99,116,32,115,105,122,101,32,111,102,32,99,111,109,112,114,101,115,115,101,100,32,102,111,114,109,97,116,32,40,0,41,32,114,101,116,117,114,110,105,110,103,32,48,46,0,82,101,99,101,105,118,101,100,32,97,32,114,101,113,117,101,115,116,32,116,111,32,99,111,109,112,114,101,115,115,32,97,110,32,105,109,97,103,101,44,32,98,117,116,32,105,109,97,103,101,32,115,105,122,101,32,105,115,32,110,111,116,32,97,32,109,117,108,116,105,112,108,101,32,111,102,32,102,111,117,114,32,40,0,41,46,32,82,101,118,101,114,116,105,110,103,32,116,111,32,117,110,99,111,109,112,114,101,115,115,101,100,46,10,0,87,97,114,110,105,110,103,58,58,32,77,105,112,109,97,112,112,101,100,32,111,115,103,58,58,73,109,97,103,101,32,110,111,116,32,97,32,112,111,119,101,114,32,111,102,32,116,119,111,44,32,99,97,110,110,111,116,32,97,112,112,108,121,32,116,111,32,116,101,120,116,117,114,101,46,0,87,97,114,110,105,110,103,58,58,32,67,111,109,112,114,101,115,115,101,100,32,111,115,103,58,58,73,109,97,103,101,32,110,111,116,32,97,32,112,111,119,101,114,32,111,102,32,116,119,111,44,32,99,97,110,110,111,116,32,97,112,112,108,121,32,116,111,32,116,101,120,116,117,114,101,46,0,83,99,97,108,105,110,103,32,105,109,97,103,101,32,39,0,39,32,102,114,111,109,32,40,0,41,32,116,111,32,40,0,83,99,97,108,105,110,103,32,105,109,97,103,101,32,102,114,111,109,32,40,0,87,97,114,110,105,110,103,58,58,32,67,111,109,112,114,101,115,115,101,100,32,105,109,97,103,101,32,99,97,110,110,111,116,32,98,101,32,109,105,112,32,109,97,112,112,101,100,0,78,51,111,115,103,49,52,84,101,120,116,117,114,101,67,117,98,101,77,97,112,69,0,87,97,114,110,105,110,103,32,58,32,102,97,105,108,101,100,32,116,111,32,99,114,101,97,116,101,32,84,101,120,116,117,114,101,67,117,98,101,77,97,112,32,116,101,120,116,117,114,101,32,111,98,101,106,101,99,116,44,32,99,111,112,121,84,101,120,83,117,98,73,109,97,103,101,67,117,98,101,77,97,112,32,97,98,97,110,100,111,110,101,100,46,0,87,97,114,110,105,110,103,58,32,84,101,120,116,117,114,101,67,117,98,101,77,97,112,58,58,99,111,112,121,84,101,120,73,109,97,103,101,50,68,40,44,44,44,44,41,32,115,119,105,116,99,104,32,111,102,102,32,109,105,112,32,109,97,112,112,105,110,103,32,97,115,32,104,97,114,100,119,97,114,101,32,115,117,112,112,111,114,116,32,110,111,116,32,97,118,97,105,108,97,98,108,101,46,0,87,97,114,110,105,110,103,58,32,84,101,120,116,117,114,101,82,101,99,116,97,110,103,108,101,58,58,97,108,108,111,99,97,116,101,77,105,112,109,97,112,40,83,116,97,116,101,38,41,32,99,97,108,108,101,100,32,101,114,111,110,101,111,117,115,108,121,44,32,71,76,95,84,69,88,84,85,82,69,95,82,69,67,84,65,78,71,76,69,32,100,111,101,115,32,110,111,116,32,115,117,112,112,111,114,116,32,109,105,112,109,97,112,112,105,110,103,46,0,87,97,114,110,105,110,103,58,32,84,101,120,116,117,114,101,82,101,99,116,97,110,103,108,101,58,58,97,112,112,108,121,40,46,46,41,32,102,97,105,108,101,100,44,32,116,101,120,116,117,114,101,32,114,101,99,116,97,110,103,108,101,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,32,98,121,32,121,111,117,114,32,79,112,101,110,71,76,32,100,114,105,118,101,114,115,46,0,84,101,120,116,117,114,101,82,101,99,116,97,110,103,108,101,0,78,51,111,115,103,49,54,84,101,120,116,117,114,101,82,101,99,116,97,110,103,108,101,69,0,84,114,97,110,115,102,111,114,109,0,78,51,111,115,103,57,84,114,97,110,115,102,111,114,109,69,0,49,54,84,114,97,110,115,102,111,114,109,86,105,115,105,116,111,114,0,99,97,110,110,111,116,32,99,104,97,110,103,101,32,85,110,105,102,111,114,109,32,110,97,109,101,0,85,110,105,102,111,114,109,0,78,51,111,115,103,55,85,110,105,102,111,114,109,69,0,85,110,105,102,111,114,109,32,110,117,109,69,108,101,109,101,110,116,115,32,60,32,49,32,105,115,32,105,110,118,97,108,105,100,0,87,97,114,110,105,110,103,58,32,85,110,105,102,111,114,109,58,58,115,101,116,78,117,109,69,108,101,109,101,110,116,115,40,41,32,99,97,110,110,111,116,32,99,104,97,110,103,101,32,85,110,105,102,111,114,109,32,110,117,109,69,108,101,109,101,110,116,115,44,32,115,105,122,101,32,97,108,114,101,97,100,121,32,102,105,120,101,100,46,0,85,110,105,102,111,114,109,32,65,100,100,105,110,103,32,112,97,114,101,110,116,0,67,97,110,110,111,116,32,97,115,115,105,103,110,32,98,101,116,119,101,101,110,32,85,110,105,102,111,114,109,32,116,121,112,101,115,32,0,85,78,68,69,70,73,78,69,68,0,117,105,109,97,103,101,50,68,77,83,65,114,114,97,121,0,117,105,109,97,103,101,50,68,77,83,0,117,105,109,97,103,101,67,117,98,101,65,114,114,97,121,0,117,105,109,97,103,101,50,68,65,114,114,97,121,0,117,105,109,97,103,101,49,68,65,114,114,97,121,0,117,105,109,97,103,101,66,117,102,102,101,114,0,117,105,109,97,103,101,67,117,98,101,0,117,105,109,97,103,101,50,68,82,101,99,116,0,117,105,109,97,103,101,51,68,0,117,105,109,97,103,101,50,68,0,117,105,109,97,103,101,49,68,0,105,105,109,97,103,101,50,68,77,83,65,114,114,97,121,0,105,105,109,97,103,101,50,68,77,83,0,105,105,109,97,103,101,67,117,98,101,65,114,114,97,121,0,105,105,109,97,103,101,50,68,65,114,114,97,121,0,105,105,109,97,103,101,49,68,65,114,114,97,121,0,105,105,109,97,103,101,66,117,102,102,101,114,0,105,105,109,97,103,101,67,117,98,101,0,105,105,109,97,103,101,50,68,82,101,99,116,0,105,105,109,97,103,101,51,68,0,105,105,109,97,103,101,50,68,0,105,105,109,97,103,101,49,68,0,105,109,97,103,101,50,68,77,83,65,114,114,97,121,0,105,109,97,103,101,50,68,77,83,0,105,109,97,103,101,67,117,98,101,65,114,114,97,121,0,105,109,97,103,101,50,68,65,114,114,97,121,0,105,109,97,103,101,49,68,65,114,114,97,121,0,105,109,97,103,101,66,117,102,102,101,114,0,105,109,97,103,101,67,117,98,101,0,105,109,97,103,101,50,68,82,101,99,116,0,105,109,97,103,101,51,68,0,105,109,97,103,101,50,68,0,105,109,97,103,101,49,68,0,117,115,97,109,112,108,101,114,50,68,82,101,99,116,0,117,115,97,109,112,108,101,114,66,117,102,102,101,114,0,117,115,97,109,112,108,101,114,50,68,77,83,65,114,114,97,121,0,117,115,97,109,112,108,101,114,50,68,77,83,0,117,115,97,109,112,108,101,114,67,117,98,101,77,97,112,65,114,114,97,121,0,117,115,97,109,112,108,101,114,50,68,65,114,114,97,121,0,117,115,97,109,112,108,101,114,49,68,65,114,114,97,121,0,117,115,97,109,112,108,101,114,67,117,98,101,0,117,115,97,109,112,108,101,114,51,68,0,117,115,97,109,112,108,101,114,50,68,0,117,115,97,109,112,108,101,114,49,68,0,105,115,97,109,112,108,101,114,50,68,82,101,99,116,0,105,115,97,109,112,108,101,114,66,117,102,102,101,114,0,105,115,97,109,112,108,101,114,50,68,77,83,65,114,114,97,121,0,105,115,97,109,112,108,101,114,50,68,77,83,0,105,115,97,109,112,108,101,114,67,117,98,101,77,97,112,65,114,114,97,121,0,105,115,97,109,112,108,101,114,50,68,65,114,114,97,121,0,105,115,97,109,112,108,101,114,49,68,65,114,114,97,121,0,105,115,97,109,112,108,101,114,67,117,98,101,0,105,115,97,109,112,108,101,114,51,68,0,105,115,97,109,112,108,101,114,50,68,0,105,115,97,109,112,108,101,114,49,68,0,115,97,109,112,108,101,114,50,68,82,101,99,116,83,104,97,100,111,119,0,115,97,109,112,108,101,114,50,68,82,101,99,116,0,115,97,109,112,108,101,114,66,117,102,102,101,114,0,115,97,109,112,108,101,114,67,117,98,101,77,97,112,65,114,114,97,121,83,104,97,100,111,119,0,115,97,109,112,108,101,114,67,117,98,101,83,104,97,100,111,119,0,115,97,109,112,108,101,114,50,68,77,83,65,114,114,97,121,0,115,97,109,112,108,101,114,50,68,77,83,0,115,97,109,112,108,101,114,50,68,65,114,114,97,121,83,104,97,100,111,119,0,115,97,109,112,108,101,114,49,68,65,114,114,97,121,83,104,97,100,111,119,0,115,97,109,112,108,101,114,67,117,98,101,77,97,112,65,114,114,97,121,0,115,97,109,112,108,101,114,50,68,65,114,114,97,121,0,115,97,109,112,108,101,114,49,68,65,114,114,97,121,0,115,97,109,112,108,101,114,50,68,83,104,97,100,111,119,0,115,97,109,112,108,101,114,49,68,83,104,97,100,111,119,0,115,97,109,112,108,101,114,67,117,98,101,0,115,97,109,112,108,101,114,51,68,0,115,97,109,112,108,101,114,50,68,0,115,97,109,112,108,101,114,49,68,0,100,109,97,116,52,120,51,0,100,109,97,116,52,120,50,0,100,109,97,116,51,120,52,0,100,109,97,116,51,120,50,0,100,109,97,116,50,120,52,0,100,109,97,116,50,120,51,0,100,109,97,116,52,0,100,109,97,116,51,0,100,109,97,116,50,0,109,97,116,52,120,51,0,109,97,116,52,120,50,0,109,97,116,51,120,52,0,109,97,116,51,120,50,0,109,97,116,50,120,52,0,109,97,116,50,120,51,0,109,97,116,52,0,109,97,116,51,0,109,97,116,50,0,117,105,110,116,54,52,95,116,0,105,110,116,54,52,95,116,0,98,118,101,99,52,0,98,118,101,99,51,0,98,118,101,99,50,0,98,111,111,108,0,117,105,118,101,99,52,0,117,105,118,101,99,51,0,117,105,118,101,99,50,0,117,105,110,116,0,105,118,101,99,52,0,105,118,101,99,51,0,105,118,101,99,50,0,100,118,101,99,52,0,100,118,101,99,51,0,100,118,101,99,50,0,100,111,117,98,108,101,0,118,101,99,52,0,118,101,99,51,0,118,101,99,50,0,102,108,111,97,116,0,32,111,114,32,0,104,111,119,32,103,111,116,32,104,101,114,101,63,32,47,104,111,109,101,47,107,111,114,110,101,114,114,47,109,106,105,110,47,112,114,111,106,101,99,116,115,47,79,112,101,110,83,99,101,110,101,71,114,97,112,104,47,115,114,99,47,111,115,103,47,85,110,105,102,111,114,109,46,99,112,112,58,0,78,51,111,115,103,49,55,85,115,101,114,68,97,116,97,67,111,110,116,97,105,110,101,114,69,0,68,101,102,97,117,108,116,85,115,101,114,68,97,116,97,67,111,110,116,97,105,110,101,114,0,78,51,111,115,103,50,52,68,101,102,97,117,108,116,85,115,101,114,68,97,116,97,67,111,110,116,97,105,110,101,114,69,0,78,51,111,115,103,49,54,86,101,114,116,101,120,65,114,114,97,121,83,116,97,116,101,69,0,32,32,86,101,114,116,101,120,65,114,114,97,121,83,116,97,116,101,58,58,100,101,108,101,116,101,86,101,114,116,101,120,65,114,114,97,121,79,98,106,101,99,116,40,41,32,0,86,101,114,116,101,120,65,114,114,97,121,83,116,97,116,101,58,58,97,115,115,105,103,110,78,111,114,109,97,108,65,114,114,97,121,68,105,115,112,97,116,99,104,101,114,40,41,32,95,115,116,97,116,101,45,62,103,101,116,86,101,114,116,101,120,65,108,105,97,115,40,41,46,95,108,111,99,97,116,105,111,110,61,0,50,53,86,101,114,116,101,120,65,116,116,114,105,98,65,114,114,97,121,68,105,115,112,97,116,99,104,0,78,51,111,115,103,49,54,86,101,114,116,101,120,65,114,114,97,121,83,116,97,116,101,49,51,65,114,114,97,121,68,105,115,112,97,116,99,104,69,0,86,101,114,116,101,120,65,114,114,97,121,83,116,97,116,101,58,58,97,115,115,105,103,110,78,111,114,109,97,108,65,114,114,97,121,68,105,115,112,97,116,99,104,101,114,40,41,32,95,115,116,97,116,101,45,62,103,101,116,78,111,114,109,97,108,65,108,105,97,115,40,41,46,95,108,111,99,97,116,105,111,110,61,0,86,101,114,116,101,120,65,114,114,97,121,83,116,97,116,101,58,58,97,115,115,105,103,110,67,111,108,111,114,65,114,114,97,121,68,105,115,112,97,116,99,104,101,114,40,41,32,95,115,116,97,116,101,45,62,103,101,116,67,111,108,111,114,65,108,105,97,115,40,41,46,95,108,111,99,97,116,105,111,110,61,0,86,101,114,116,101,120,65,114,114,97,121,83,116,97,116,101,58,58,86,101,114,116,101,120,65,114,114,97,121,83,116,97,116,101,58,58,97,115,115,105,103,110,84,101,120,67,111,111,114,100,65,114,114,97,121,68,105,115,112,97,116,99,104,101,114,40,41,32,95,115,116,97,116,101,45,62,103,101,116,84,101,120,67,111,111,114,100,65,108,105,97,115,76,105,115,116,40,41,91,105,93,46,95,108,111,99,97,116,105,111,110,61,0,86,101,114,116,101,120,65,114,114,97,121,83,116,97,116,101,58,58,114,101,108,101,97,115,101,40,41,32,0,86,101,114,116,101,120,65,114,114,97,121,83,116,97,116,101,77,97,110,97,103,101,114,58,58,114,101,108,101,97,115,101,40,0,86,101,114,116,101,120,65,114,114,97,121,83,116,97,116,101,77,97,110,97,103,101,114,0,86,101,114,116,101,120,65,114,114,97,121,83,116,97,116,101,77,97,110,97,103,101,114,58,58,102,108,117,115,104,65,108,108,68,101,108,101,116,101,100,71,76,79,98,106,101,99,116,115,40,41,0,86,101,114,116,101,120,65,114,114,97,121,83,116,97,116,101,77,97,110,97,103,101,114,58,58,100,101,108,101,116,101,65,108,108,71,76,79,98,106,101,99,116,115,40,41,32,78,111,116,32,99,117,114,114,101,110,116,108,121,32,105,109,112,108,101,109,101,110,116,97,116,101,100,0,86,101,114,116,101,120,65,114,114,97,121,83,116,97,116,101,77,97,110,97,103,101,114,58,58,102,108,117,115,104,68,101,108,101,116,101,100,71,76,79,98,106,101,99,116,115,40,41,0,50,51,86,101,114,116,101,120,65,114,114,97,121,83,116,97,116,101,77,97,110,97,103,101,114,0,68,101,115,116,114,117,99,116,105,110,103,32,111,115,103,58,58,86,105,101,119,0,68,111,110,101,32,100,101,115,116,114,117,99,116,105,110,103,32,111,115,103,58,58,86,105,101,119,0,78,51,111,115,103,52,86,105,101,119,53,83,108,97,118,101,69,0,78,51,111,115,103,52,86,105,101,119,69,0,86,105,101,119,112,111,114,116,0,78,51,111,115,103,56,86,105,101,119,112,111,114,116,69,0,32,0,103,108,117,84,101,115,115,66,101,103,105,110,80,111,108,121,103,111,110,40,41,32,109,117,115,116,32,112,114,101,99,101,100,101,32,97,32,103,108,117,84,101,115,115,69,110,100,80,111,108,121,103,111,110,40,41,0,103,108,117,84,101,115,115,66,101,103,105,110,67,111,110,116,111,117,114,40,41,32,109,117,115,116,32,112,114,101,99,101,100,101,32,97,32,103,108,117,84,101,115,115,69,110,100,67,111,110,116,111,117,114,40,41,0,103,108,117,84,101,115,115,69,110,100,80,111,108,121,103,111,110,40,41,32,109,117,115,116,32,102,111,108,108,111,119,32,97,32,103,108,117,84,101,115,115,66,101,103,105,110,80,111,108,121,103,111,110,40,41,0,103,108,117,84,101,115,115,69,110,100,67,111,110,116,111,117,114,40,41,32,109,117,115,116,32,102,111,108,108,111,119,32,97,32,103,108,117,84,101,115,115,66,101,103,105,110,67,111,110,116,111,117,114,40,41,0,97,32,99,111,111,114,100,105,110,97,116,101,32,105,115,32,116,111,111,32,108,97,114,103,101,0,110,101,101,100,32,99,111,109,98,105,110,101,32,99,97,108,108,98,97,99,107,0,110,111,32,101,114,114,111,114,0,105,110,118,97,108,105,100,32,101,110,117,109,101,114,97,110,116,0,105,110,118,97,108,105,100,32,118,97,108,117,101,0,105,110,118,97,108,105,100,32,111,112,101,114,97,116,105,111,110,0,115,116,97,99,107,32,111,118,101,114,102,108,111,119,0,115,116,97,99,107,32,117,110,100,101,114,102,108,111,119,0,111,117,116,32,111,102,32,109,101,109,111,114,121,0,116,97,98,108,101,32,116,111,111,32,108,97,114,103,101,0,105,110,118,97,108,105,100,32,102,114,97,109,101,98,117,102,102,101,114,32,111,112,101,114,97,116,105,111,110,0,105,110,99,111,109,112,97,116,105,98,108,101,32,103,108,32,118,101,114,115,105,111,110,0,78,51,111,115,103,50,48,65,116,116,114,105,98,117,116,101,68,105,115,112,97,116,99,104,101,114,115,69,0,78,51,111,115,103,51,49,84,101,109,112,108,97,116,101,84,97,114,103,101,116,65,116,116,114,105,98,117,116,101,68,105,115,112,97,116,99,104,73,106,102,69,69,0,78,51,111,115,103,49,55,65,116,116,114,105,98,117,116,101,68,105,115,112,97,116,99,104,69,0,87,97,114,110,105,110,103,58,32,66,108,101,110,100,70,117,110,99,58,58,97,112,112,108,121,40,46,46,41,32,102,97,105,108,101,100,44,32,66,108,101,110,100,70,117,110,99,83,101,112,97,114,97,116,101,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,32,98,121,32,79,112,101,110,71,76,32,100,114,105,118,101,114,44,32,102,97,108,108,105,110,103,32,98,97,99,107,32,116,111,32,66,108,101,110,100,70,117,110,99,46,0,66,108,101,110,100,70,117,110,99,0,78,51,111,115,103,57,66,108,101,110,100,70,117,110,99,69,0,87,97,114,110,105,110,103,58,32,76,105,103,104,116,58,58,97,112,112,108,121,40,83,116,97,116,101,38,41,32,45,32,110,111,116,32,115,117,112,112,111,114,116,101,100,46,0,76,105,103,104,116,0,78,51,111,115,103,53,76,105,103,104,116,69,0,83,104,97,100,101,114,67,111,109,112,111,115,101,114,58,58,99,111,109,112,111,115,101,77,97,105,110,40,83,104,97,100,101,114,115,41,32,115,104,97,100,101,114,115,46,115,105,122,101,40,41,61,61,0,87,97,114,110,105,110,103,58,83,104,97,100,101,114,67,111,109,112,111,115,101,114,58,58,99,111,109,112,111,115,101,77,97,105,110,40,41,32,109,105,120,105,110,103,32,100,105,102,102,101,114,101,110,116,32,116,121,112,101,115,32,111,102,32,83,104,97,100,101,114,115,32,112,114,111,104,105,98,105,116,101,100,46,0,118,111,105,100,32,109,97,105,110,40,118,111,105,100,41,10,0,116,121,112,101,32,61,61,0,102,117,108,108,95,115,111,117,114,99,101,32,61,61,32,0,101,110,100,32,111,102,32,83,104,97,100,101,114,67,111,109,112,111,115,101,114,58,58,99,111,109,112,111,115,101,77,97,105,110,40,83,104,97,100,101,114,115,41,0,83,104,97,100,101,114,67,111,109,112,111,115,101,114,58,58,103,101,116,79,114,67,114,101,97,116,101,80,114,111,103,114,97,109,40,115,104,97,100,101,114,67,111,109,112,111,110,101,110,116,115,46,115,105,122,101,40,41,61,61,0,87,97,114,110,105,110,103,58,32,83,104,97,100,101,114,67,111,109,112,111,115,101,58,58,103,101,116,79,114,67,114,101,97,116,101,80,114,111,103,97,109,40,83,104,97,100,101,114,67,111,109,112,111,110,116,115,41,32,101,110,99,111,117,110,116,101,114,100,32,105,110,118,97,108,105,100,32,83,104,97,100,101,114,58,58,84,121,112,101,46,0,83,104,97,100,101,114,67,111,109,112,111,115,101,114,58,58,103,101,116,79,114,67,114,101,97,116,101,80,114,111,103,114,97,109,40,46,46,41,32,99,114,101,97,116,101,100,32,110,101,119,32,80,114,111,103,114,97,109,0,83,104,97,100,101,114,67,111,109,112,111,115,101,114,0,83,104,97,100,101,114,67,111,109,112,111,115,101,114,58,58,83,104,97,100,101,114,67,111,109,112,111,115,101,114,40,99,111,110,115,116,32,83,104,97,100,101,114,67,111,109,112,111,115,101,114,38,44,32,99,111,110,115,116,32,67,111,112,121,79,112,38,32,99,111,112,121,111,112,41,32,0,83,104,97,100,101,114,67,111,109,112,111,115,101,114,58,58,83,104,97,100,101,114,67,111,109,112,111,115,101,114,40,41,32,0,83,104,97,100,101,114,67,111,109,112,111,115,101,114,58,58,126,83,104,97,100,101,114,67,111,109,112,111,115,101,114,40,41,32,0,78,51,111,115,103,49,52,83,104,97,100,101,114,67,111,109,112,111,115,101,114,69,0,69,114,114,111,114,58,32,84,104,114,101,97,100,32,0,32,115,116,105,108,108,32,114,117,110,110,105,110,103,32,105,110,32,100,101,115,116,114,117,99,116,111,114,0,78,49,49,79,112,101,110,84,104,114,101,97,100,115,54,84,104,114,101,97,100,69,0,69,114,114,111,114,58,32,112,116,104,114,101,97,100,95,107,101,121,95,99,114,101,97,116,101,40,44,41,32,114,101,116,117,114,110,101,100,32,101,114,114,111,114,32,115,116,97,116,117,115,44,32,115,116,97,116,117,115,32,61,32,37,100,10,0,78,49,49,79,112,101,110,84,104,114,101,97,100,115,49,56,80,84,104,114,101,97,100,80,114,105,118,97,116,101,68,97,116,97,69,0,69,114,114,111,114,58,32,112,116,104,114,101,97,100,95,115,101,116,115,112,101,99,105,102,105,99,40,44,41,32,114,101,116,117,114,110,101,100,32,101,114,114,111,114,32,115,116,97,116,117,115,44,32,115,116,97,116,117,115,32,61,32,37,100,10,0,78,49,49,79,112,101,110,84,104,114,101,97,100,115,55,66,97,114,114,105,101,114,69,0,78,49,49,79,112,101,110,84,104,114,101,97,100,115,50,53,80,84,104,114,101,97,100,66,97,114,114,105,101,114,80,114,105,118,97,116,101,68,97,116,97,69,0,69,114,114,111,114,58,32,112,116,104,114,101,97,100,95,99,111,110,100,95,100,101,115,116,114,111,121,40,44,41,32,114,101,116,117,114,110,101,100,32,101,114,114,111,114,32,115,116,97,116,117,115,44,32,115,116,97,116,117,115,32,61,32,37,100,10,0,78,49,49,79,112,101,110,84,104,114,101,97,100,115,57,67,111,110,100,105,116,105,111,110,69,0,69,114,114,111,114,58,32,112,116,104,114,101,97,100,95,99,111,110,100,95,105,110,105,116,40,44,41,32,114,101,116,117,114,110,101,100,32,101,114,114,111,114,32,115,116,97,116,117,115,44,32,115,116,97,116,117,115,32,61,32,37,100,10,0,78,49,49,79,112,101,110,84,104,114,101,97,100,115,50,55,80,84,104,114,101,97,100,67,111,110,100,105,116,105,111,110,80,114,105,118,97,116,101,68,97,116,97,69,0,78,49,49,79,112,101,110,84,104,114,101,97,100,115,53,77,117,116,101,120,69,0,78,49,49,79,112,101,110,84,104,114,101,97,100,115,50,51,80,84,104,114,101,97,100,77,117,116,101,120,80,114,105,118,97,116,101,68,97,116,97,69,0,1,78,83,116,51,95,95,50,49,55,98,97,100,95,102,117,110,99,116,105,111,110,95,99,97,108,108,69,0,90,78,52,109,106,105,110,49,49,97,112,112,108,105,99,97,116,105,111,110,54,109,101,109,111,114,121,49,49,67,111,111,114,100,105,110,97,116,111,114,49,52,115,101,116,117,112,83,101,108,101,99,116,105,111,110,69,118,69,51,36,95,48,0,78,83,116,51,95,95,50,49,48,95,95,102,117,110,99,116,105,111,110,54,95,95,102,117,110,99,73,90,78,52,109,106,105,110,49,49,97,112,112,108,105,99,97,116,105,111,110,54,109,101,109,111,114,121,49,49,67,111,111,114,100,105,110,97,116,111,114,49,52,115,101,116,117,112,83,101,108,101,99,116,105,111,110,69,118,69,51,36,95,48,78,83,95,57,97,108,108,111,99,97,116,111,114,73,83,54,95,69,69,70,118,82,75,98,69,69,69,0,78,83,116,51,95,95,50,49,48,95,95,102,117,110,99,116,105,111,110,54,95,95,98,97,115,101,73,70,118,82,75,98,69,69,69,0,90,78,52,109,106,105,110,49,49,97,112,112,108,105,99,97,116,105,111,110,54,109,101,109,111,114,121,52,71,97,109,101,49,56,109,97,116,99,104,83,101,108,101,99,116,101,100,73,116,101,109,115,69,118,69,51,36,95,49,0,78,83,116,51,95,95,50,49,48,95,95,102,117,110,99,116,105,111,110,54,95,95,102,117,110,99,73,90,78,52,109,106,105,110,49,49,97,112,112,108,105,99,97,116,105,111,110,54,109,101,109,111,114,121,52,71,97,109,101,49,56,109,97,116,99,104,83,101,108,101,99,116,101,100,73,116,101,109,115,69,118,69,51,36,95,49,78,83,95,57,97,108,108,111,99,97,116,111,114,73,83,54,95,69,69,70,118,118,69,69,69,0,78,83,116,51,95,95,50,49,48,95,95,102,117,110,99,116,105,111,110,54,95,95,98,97,115,101,73,70,118,118,69,69,69,0,90,78,52,109,106,105,110,49,49,97,112,112,108,105,99,97,116,105,111,110,54,109,101,109,111,114,121,52,71,97,109,101,49,56,97,110,105,109,97,116,101,77,97,116,99,104,79,114,77,105,115,115,69,98,78,83,116,51,95,95,50,56,102,117,110,99,116,105,111,110,73,70,118,118,69,69,69,69,51,36,95,50,0,78,83,116,51,95,95,50,49,48,95,95,102,117,110,99,116,105,111,110,54,95,95,102,117,110,99,73,90,78,52,109,106,105,110,49,49,97,112,112,108,105,99,97,116,105,111,110,54,109,101,109,111,114,121,52,71,97,109,101,49,56,97,110,105,109,97,116,101,77,97,116,99,104,79,114,77,105,115,115,69,98,78,83,95,56,102,117,110,99,116,105,111,110,73,70,118,118,69,69,69,69,51,36,95,50,78,83,95,57,97,108,108,111,99,97,116,111,114,73,83,57,95,69,69,70,98,100,69,69,69,0,78,83,116,51,95,95,50,49,48,95,95,102,117,110,99,116,105,111,110,54,95,95,98,97,115,101,73,70,98,100,69,69,69,0,90,78,52,109,106,105,110,49,49,97,112,112,108,105,99,97,116,105,111,110,54,109,101,109,111,114,121,52,71,97,109,101,49,56,109,97,116,99,104,83,101,108,101,99,116,101,100,73,116,101,109,115,69,118,69,51,36,95,48,0,78,83,116,51,95,95,50,49,48,95,95,102,117,110,99,116,105,111,110,54,95,95,102,117,110,99,73,90,78,52,109,106,105,110,49,49,97,112,112,108,105,99,97,116,105,111,110,54,109,101,109,111,114,121,52,71,97,109,101,49,56,109,97,116,99,104,83,101,108,101,99,116,101,100,73,116,101,109,115,69,118,69,51,36,95,48,78,83,95,57,97,108,108,111,99,97,116,111,114,73,83,54,95,69,69,70,118,118,69,69,69,0,35,105,102,100,101,102,32,71,76,95,69,83,10,32,32,32,32,112,114,101,99,105,115,105,111,110,32,104,105,103,104,112,32,102,108,111,97,116,59,10,35,101,110,100,105,102,10,117,110,105,102,111,114,109,32,118,101,99,51,32,99,111,108,111,114,59,10,118,111,105,100,32,109,97,105,110,40,41,10,123,10,32,32,32,32,103,108,95,70,114,97,103,67,111,108,111,114,32,61,32,118,101,99,52,40,99,111,108,111,114,44,32,49,46,48,41,59,10,125,0,118,111,105,100,32,109,97,105,110,40,41,10,123,10,32,32,32,32,103,108,95,80,111,115,105,116,105,111,110,32,61,32,103,108,95,77,111,100,101,108,86,105,101,119,80,114,111,106,101,99,116,105,111,110,77,97,116,114,105,120,32,42,32,103,108,95,86,101,114,116,101,120,59,10,125,0,80,111,111,108,32,84,79,68,79,32,82,101,109,111,118,101,32,109,97,116,101,114,105,97,108,115,0,80,111,111,108,32,69,82,82,79,82,32,67,97,110,110,111,116,32,114,101,102,101,114,101,110,99,101,32,109,97,116,101,114,105,97,108,32,98,101,99,97,117,115,101,32,111,119,110,101,114,32,39,37,112,39,32,97,108,114,101,97,100,121,32,104,97,115,32,109,97,116,101,114,105,97,108,0,80,111,111,108,46,114,101,102,101,114,101,110,99,101,40,37,112,44,32,37,112,44,32,99,111,108,111,114,40,37,102,44,37,102,44,37,102,41,41,0,99,111,108,111,114,0,80,111,111,108,46,32,83,84,65,84,83,32,82,101,102,101,114,101,110,99,101,115,32,110,98,58,32,39,37,108,117,39,32,77,97,116,101,114,105,97,108,115,32,110,98,58,32,39,37,108,117,39,0,80,111,111,108,46,32,83,84,65,84,83,32,82,101,102,101,114,101,110,99,101,40,111,119,110,101,114,58,32,39,37,112,39,32,109,97,116,101,114,105,97,108,58,32,39,37,112,39,41,0,80,111,111,108,46,32,83,84,65,84,83,32,77,97,116,101,114,105,97,108,40,109,97,116,101,114,105,97,108,58,32,39,37,112,39,32,105,115,82,101,102,101,114,101,110,99,101,100,58,32,39,37,100,39,41,0,80,111,111,108,32,69,82,82,79,82,32,67,97,110,110,111,116,32,114,101,108,101,97,115,101,32,109,97,116,101,114,105,97,108,32,98,101,99,97,117,115,101,32,111,119,110,101,114,32,39,37,112,39,32,105,115,32,97,98,115,101,110,116,0,84,101,115,115,101,108,108,97,116,105,111,110,72,105,110,116,115,0,78,51,111,115,103,49,55,84,101,115,115,101,108,108,97,116,105,111,110,72,105,110,116,115,69,0,115,101,108,101,99,116,105,111,110,46,32,69,82,82,79,82,32,78,111,116,104,105,110,103,32,115,101,108,101,99,116,101,100,44,32,98,117,116,32,115,104,111,117,108,100,32,98,101,46,32,73,78,86,69,83,84,73,71,65,84,69,0,78,52,109,106,105,110,49,49,97,112,112,108,105,99,97,116,105,111,110,54,109,101,109,111,114,121,53,105,110,112,117,116,53,77,111,117,115,101,69,0,78,52,109,106,105,110,54,114,101,110,100,101,114,49,53,86,66,79,83,101,116,117,112,86,105,115,105,116,111,114,69,0,68,97,116,97,98,97,115,101,80,97,103,101,114,58,58,82,101,113,117,101,115,116,81,117,101,117,101,58,58,126,82,101,113,117,101,115,116,81,117,101,117,101,40,41,32,68,101,115,116,114,117,99,116,105,110,103,32,113,117,101,117,101,46,0,32,32,32,68,97,116,97,98,97,115,101,80,97,103,101,114,58,58,68,97,116,97,98,97,115,101,82,101,113,117,101,115,116,58,58,105,110,118,97,108,105,100,97,116,101,40,41,46,0,78,53,111,115,103,68,66,49,51,68,97,116,97,98,97,115,101,80,97,103,101,114,49,50,82,101,113,117,101,115,116,81,117,101,117,101,69,0,78,53,111,115,103,68,66,49,51,68,97,116,97,98,97,115,101,80,97,103,101,114,57,82,101,97,100,81,117,101,117,101,69,0,58,32,68,97,116,97,98,97,115,101,80,97,103,101,114,58,58,68,97,116,97,98,97,115,101,84,104,114,101,97,100,58,58,114,117,110,0,58,32,95,112,97,103,101,114,45,62,115,105,122,101,40,41,61,32,0,32,116,111,32,100,101,108,101,116,101,32,61,32,0,58,32,80,97,115,115,105,110,103,32,104,116,116,112,32,114,101,113,117,101,115,116,115,32,111,118,101,114,32,0,69,114,114,111,114,32,105,110,32,114,101,97,100,105,110,103,32,102,105,108,101,32,0,32,58,32,0,58,32,87,97,114,110,105,110,103,32,68,97,116,97,98,97,115,101,82,113,117,101,115,116,32,110,111,32,108,111,110,103,101,114,32,114,101,113,117,105,114,101,100,46,0,76,111,97,100,101,100,32,102,114,111,109,32,79,98,106,101,99,116,67,97,99,104,101,0,34,70,105,110,100,67,111,109,112,105,108,101,97,98,108,101,71,76,79,98,106,101,99,116,115,86,105,115,105,116,111,114,34,0,34,111,115,103,68,66,34,0,78,53,111,115,103,68,66,49,51,68,97,116,97,98,97,115,101,80,97,103,101,114,51,49,70,105,110,100,67,111,109,112,105,108,101,97,98,108,101,71,76,79,98,106,101,99,116,115,86,105,115,105,116,111,114,69,0,78,53,111,115,103,68,66,49,51,68,97,116,97,98,97,115,101,80,97,103,101,114,51,55,68,97,116,97,98,97,115,101,80,97,103,101,114,67,111,109,112,105,108,101,67,111,109,112,108,101,116,101,100,67,97,108,108,98,97,99,107,69,0,78,55,111,115,103,85,116,105,108,50,55,73,110,99,114,101,109,101,110,116,97,108,67,111,109,112,105,108,101,79,112,101,114,97,116,105,111,110,50,52,67,111,109,112,105,108,101,67,111,109,112,108,101,116,101,100,67,97,108,108,98,97,99,107,69,0,68,97,116,97,98,97,115,101,80,97,103,101,114,58,58,82,101,113,117,101,115,116,81,117,101,117,101,58,58,116,97,107,101,70,105,114,115,116,40,41,58,32,80,114,117,110,105,110,103,32,0,32,68,97,116,97,98,97,115,101,80,97,103,101,114,58,58,82,101,113,117,101,115,116,81,117,101,117,101,58,58,116,97,107,101,70,105,114,115,116,40,41,32,70,111,117,110,100,32,68,97,116,97,98,97,115,101,82,101,113,117,101,115,116,32,115,105,122,101,40,41,61,0,32,68,97,116,97,98,97,115,101,80,97,103,101,114,58,58,82,101,113,117,101,115,116,81,117,101,117,101,58,58,116,97,107,101,70,105,114,115,116,40,41,32,78,111,32,115,117,105,116,97,98,108,101,32,68,97,116,97,98,97,115,101,82,101,113,117,101,115,116,32,102,111,117,110,100,32,115,105,122,101,40,41,61,0,78,53,111,115,103,68,66,49,51,68,97,116,97,98,97,115,101,80,97,103,101,114,49,52,68,97,116,97,98,97,115,101,84,104,114,101,97,100,69,0,97,99,116,105,118,101,61,0,32,111,118,101,114,97,108,108,32,61,32,0,32,65,61,0,32,97,118,103,61,0,32,109,97,120,32,61,32,0,32,66,61,0,32,67,61,0,68,97,116,97,98,97,115,101,80,97,103,101,114,58,58,97,100,100,76,111,97,100,101,100,68,97,116,97,84,111,83,99,101,110,101,71,114,97,112,104,40,41,32,110,111,100,101,32,105,110,32,112,97,114,101,110,116,97,108,32,99,104,97,105,110,32,100,101,108,101,116,101,100,44,32,100,105,115,99,97,114,100,105,110,103,32,115,117,98,103,97,112,104,46,0,68,111,110,101,32,68,97,116,97,98,97,115,101,80,97,103,101,114,58,58,97,100,100,76,111,97,100,101,100,68,97,116,97,84,111,83,99,101,110,101,71,114,97,112,104,0,109,115,44,9,0,109,115,0,32,32,111,98,106,101,99,116,115,0,34,70,105,110,100,80,97,103,101,100,76,79,68,115,86,105,115,105,116,111,114,34,0,78,53,111,115,103,68,66,49,51,68,97,116,97,98,97,115,101,80,97,103,101,114,50,48,70,105,110,100,80,97,103,101,100,76,79,68,115,86,105,115,105,116,111,114,69,0,68,97,116,97,98,97,115,101,80,97,103,101,114,58,58,82,101,113,117,101,115,116,81,117,101,117,101,58,58,112,114,117,110,101,79,108,100,82,101,113,117,101,115,116,115,65,110,100,67,104,101,99,107,73,102,69,109,112,116,121,40,41,58,32,80,114,117,110,105,110,103,32,0,68,97,116,97,98,97,115,101,80,97,103,101,114,58,58,97,100,100,68,97,116,97,98,97,115,101,84,104,114,101,97,100,40,41,32,0,68,97,116,97,98,97,115,101,80,97,103,101,114,58,58,115,116,97,114,116,84,104,114,101,97,100,40,41,0,72,97,115,66,101,101,110,66,121,83,116,97,116,101,84,111,67,111,109,112,105,108,101,80,114,111,99,101,115,115,101,100,77,97,114,107,101,114,0,102,105,108,101,82,101,113,117,101,115,116,81,117,101,117,101,0,104,116,116,112,82,101,113,117,101,115,116,81,117,101,117,101,0,68,97,116,97,98,97,115,101,80,97,103,101,114,0,87,97,114,110,105,110,103,58,32,68,97,116,97,98,97,115,101,80,97,103,101,114,58,58,114,101,113,117,101,115,116,78,111,100,101,70,105,108,101,40,46,46,41,32,112,97,115,115,101,100,32,101,109,112,116,121,32,78,111,100,101,80,97,116,104,44,32,115,111,32,110,111,119,104,101,114,101,32,116,111,32,97,116,116,97,99,104,32,110,101,119,32,115,117,98,103,114,97,112,104,32,116,111,46,0,87,97,114,110,105,110,103], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+153852);
/* memory initializer */ allocate([58,32,68,97,116,97,98,97,115,101,80,97,103,101,114,58,58,114,101,113,117,101,115,116,78,111,100,101,70,105,108,101,40,46,46,41,32,112,97,115,115,101,100,32,78,111,100,101,80,97,116,104,32,119,105,116,104,111,117,116,32,103,114,111,117,112,32,97,115,32,108,97,115,116,32,110,111,100,101,32,105,110,32,112,97,116,104,44,32,115,111,32,110,111,119,104,101,114,101,32,116,111,32,97,116,116,97,99,104,32,110,101,119,32,115,117,98,103,114,97,112,104,32,116,111,46,0,68,97,116,97,98,97,115,101,82,101,113,117,101,115,116,32,104,97,115,32,98,101,101,110,32,112,114,101,118,105,111,117,115,108,121,32,105,110,118,97,108,105,100,97,116,101,100,32,119,104,105,108,115,116,32,115,116,105,108,108,32,97,116,116,97,99,104,101,100,32,116,111,32,115,99,101,110,101,32,103,114,97,112,104,46,0,68,97,116,97,98,97,115,101,80,97,103,101,114,58,58,114,101,113,117,101,115,116,78,111,100,101,70,105,108,101,40,0,41,32,117,112,100,97,116,105,110,103,32,97,108,114,101,97,100,121,32,97,115,115,105,103,110,101,100,46,0,41,32,111,114,112,104,97,110,101,100,44,32,114,101,115,117,98,109,105,116,116,105,110,103,46,0,73,110,32,68,97,116,97,98,97,115,101,80,97,103,101,114,58,58,114,101,113,117,101,115,116,78,111,100,101,70,105,108,101,40,0,72,65,78,68,76,69,95,65,76,76,95,82,69,81,85,69,83,84,83,0,72,65,78,68,76,69,95,78,79,78,95,72,84,84,80,0,72,65,78,68,76,69,95,79,78,76,89,95,72,84,84,80,0,78,53,111,115,103,68,66,49,51,68,97,116,97,98,97,115,101,80,97,103,101,114,49,53,68,97,116,97,98,97,115,101,82,101,113,117,101,115,116,69,0,78,53,111,115,103,68,66,49,51,68,97,116,97,98,97,115,101,80,97,103,101,114,69,0,78,51,111,115,103,49,49,78,111,100,101,86,105,115,105,116,111,114,50,50,68,97,116,97,98,97,115,101,82,101,113,117,101,115,116,72,97,110,100,108,101,114,69,0,79,83,71,95,68,79,95,80,82,69,95,67,79,77,80,73,76,69,32,60,79,78,47,79,70,70,62,0,83,119,105,116,99,104,32,111,110,32,111,114,32,111,102,102,32,116,104,101,32,112,114,101,32,99,111,109,112,105,108,101,32,111,102,32,79,112,101,110,71,76,32,111,98,106,101,99,116,32,100,97,116,97,98,97,115,101,32,112,97,103,101,114,46,0,79,83,71,95,68,65,84,65,66,65,83,69,95,80,65,71,69,82,95,68,82,65,87,65,66,76,69,32,60,109,111,100,101,62,0,83,101,116,32,116,104,101,32,100,114,97,119,97,98,108,101,32,112,111,108,105,99,121,32,102,111,114,32,115,101,116,116,105,110,103,32,111,102,32,108,111,97,100,101,100,32,100,114,97,119,97,98,108,101,32,116,111,32,115,112,101,99,105,102,105,101,100,32,116,121,112,101,46,32,32,109,111,100,101,32,99,97,110,32,98,101,32,111,110,101,32,111,102,32,68,111,78,111,116,77,111,100,105,102,121,44,32,68,105,115,112,108,97,121,76,105,115,116,44,32,86,66,79,32,111,114,32,86,101,114,116,101,120,65,114,114,97,121,115,62,46,0,79,83,71,95,68,65,84,65,66,65,83,69,95,80,65,71,69,82,95,80,82,73,79,82,73,84,89,32,60,109,111,100,101,62,0,83,101,116,32,116,104,101,32,116,104,114,101,97,100,32,112,114,105,111,114,105,116,121,32,116,111,32,68,69,70,65,85,76,84,44,32,77,73,78,44,32,76,79,87,44,32,78,79,77,73,78,65,76,44,32,72,73,71,72,32,111,114,32,77,65,88,46,0,79,83,71,95,77,65,88,95,80,65,71,69,68,76,79,68,32,60,110,117,109,62,0,83,101,116,32,116,104,101,32,116,97,114,103,101,116,32,109,97,120,105,109,117,109,32,110,117,109,98,101,114,32,111,102,32,80,97,103,101,100,76,79,68,32,116,111,32,109,97,105,110,116,97,105,110,46,0,79,83,71,95,65,83,83,73,71,78,95,80,66,79,95,84,79,95,73,77,65,71,69,83,32,60,79,78,47,79,70,70,62,0,83,101,116,32,119,104,101,116,104,101,114,32,80,105,120,101,108,66,117,102,102,101,114,79,98,106,101,99,116,115,32,115,104,111,117,108,100,32,98,101,32,97,115,115,105,103,110,101,100,32,116,111,32,73,109,97,103,101,115,32,116,111,32,97,105,100,32,100,111,119,110,108,111,97,100,32,116,111,32,116,104,101,32,71,80,85,46,0,79,83,71,95,68,65,84,65,66,65,83,69,95,80,65,71,69,82,95,71,69,79,77,69,84,82,89,0,79,83,71,95,68,65,84,65,66,65,83,69,95,80,65,71,69,82,95,68,82,65,87,65,66,76,69,0,68,111,78,111,116,77,111,100,105,102,121,0,68,105,115,112,108,97,121,76,105,115,116,0,68,76,0,86,66,79,0,86,101,114,116,101,120,65,114,114,97,121,115,0,86,65,0,79,83,71,95,65,83,83,73,71,78,95,80,66,79,95,84,79,95,73,77,65,71,69,83,0,89,69,83,0,111,110,0,79,78,0,79,83,71,95,65,83,83,73,71,78,95,80,66,79,95,84,79,95,73,77,65,71,69,83,32,115,101,116,32,116,111,32,0,79,83,71,95,68,69,76,69,84,69,95,73,78,95,68,65,84,65,66,65,83,69,95,84,72,82,69,65,68,0,79,83,71,95,77,65,88,95,80,65,71,69,68,76,79,68,0,95,116,97,114,103,101,116,77,97,120,105,109,117,109,78,117,109,98,101,114,79,102,80,97,103,101,76,79,68,32,61,32,0,79,83,71,95,68,79,95,80,82,69,95,67,79,77,80,73,76,69,0,79,83,71,95,68,65,84,65,66,65,83,69,95,80,65,71,69,82,95,80,82,73,79,82,73,84,89,0,68,69,70,65,85,76,84,0,77,73,78,0,76,79,87,0,78,79,77,73,78,65,76,0,72,73,71,72,0,77,65,88,0,87,97,114,110,105,110,103,58,32,83,101,116,66,97,115,101,100,80,97,103,101,100,76,79,68,76,105,115,116,58,58,105,110,115,101,114,116,80,97,103,101,100,76,79,68,40,0,41,32,97,108,114,101,97,100,121,32,105,110,115,101,114,116,101,100,0,82,101,109,111,118,105,110,103,32,110,111,100,101,32,102,114,111,109,32,80,97,103,101,100,76,79,68,32,108,105,115,116,0,68,97,116,97,98,97,115,101,80,97,103,101,114,58,58,114,101,109,111,118,101,69,120,112,105,114,101,100,83,117,98,103,114,97,112,104,115,40,41,32,95,105,110,97,99,116,105,118,101,80,97,103,101,100,76,79,68,32,104,97,115,32,98,101,101,110,32,105,110,118,97,108,105,100,97,116,101,100,44,32,98,117,116,32,105,103,110,111,114,101,100,0,34,69,120,112,105,114,101,80,97,103,101,100,76,79,68,115,86,105,115,105,116,111,114,34,0,78,53,111,115,103,68,66,49,51,68,97,116,97,98,97,115,101,80,97,103,101,114,50,50,69,120,112,105,114,101,80,97,103,101,100,76,79,68,115,86,105,115,105,116,111,114,69,0,50,48,83,101,116,66,97,115,101,100,80,97,103,101,100,76,79,68,76,105,115,116,0,78,53,111,115,103,68,66,49,51,68,97,116,97,98,97,115,101,80,97,103,101,114,49,50,80,97,103,101,100,76,79,68,76,105,115,116,69,0,73,109,97,103,101,80,97,103,101,114,58,58,73,109,97,103,101,84,104,114,101,97,100,58,58,114,117,110,40,41,32,0,73,109,97,103,101,80,97,103,101,114,58,58,73,109,97,103,101,84,104,114,101,97,100,58,58,100,111,110,101,40,41,0,73,109,97,103,101,80,97,103,101,114,58,58,82,101,97,100,81,117,101,117,101,58,58,116,97,107,101,70,105,114,115,116,40,46,46,41,44,32,115,105,122,101,40,41,61,0,78,53,111,115,103,68,66,49,48,73,109,97,103,101,80,97,103,101,114,49,49,73,109,97,103,101,84,104,114,101,97,100,69,0,73,109,97,103,101,80,97,103,101,114,58,58,117,112,100,97,116,101,83,99,101,110,101,71,114,97,112,104,40,41,32,58,32,101,114,114,111,114,44,32,105,109,97,103,101,32,114,101,113,117,101,115,116,32,97,116,116,97,99,104,109,101,110,116,32,116,121,112,101,32,110,111,116,32,104,97,110,100,108,101,100,32,121,101,116,46,0,73,109,97,103,101,80,97,103,101,114,58,58,82,101,97,100,81,117,101,117,101,58,58,97,100,100,40,0,41,44,32,115,105,122,101,40,41,61,0,78,53,111,115,103,68,66,49,48,73,109,97,103,101,80,97,103,101,114,49,50,73,109,97,103,101,82,101,113,117,101,115,116,69,0,78,53,111,115,103,68,66,49,48,73,109,97,103,101,80,97,103,101,114,69,0,78,51,111,115,103,49,49,78,111,100,101,86,105,115,105,116,111,114,49,57,73,109,97,103,101,82,101,113,117,101,115,116,72,97,110,100,108,101,114,69,0,78,53,111,115,103,68,66,49,48,73,109,97,103,101,80,97,103,101,114,49,50,82,101,113,117,101,115,116,81,117,101,117,101,69,0,78,53,111,115,103,68,66,49,48,73,109,97,103,101,80,97,103,101,114,57,82,101,97,100,81,117,101,117,101,69,0,73,109,97,103,101,32,81,117,101,117,101,0,73,109,97,103,101,32,84,104,114,101,97,100,32,49,0,73,109,97,103,101,32,84,104,114,101,97,100,32,50,0,73,109,97,103,101,32,84,104,114,101,97,100,32,51,0,78,53,111,115,103,68,66,49,49,79,98,106,101,99,116,67,97,99,104,101,69,0,73,110,115,101,114,116,105,110,103,32,111,98,106,101,99,116,115,32,116,111,32,109,97,105,110,32,79,98,106,101,99,116,67,97,99,104,101,32,0,65,100,100,105,110,103,32,0,32,119,105,116,104,32,111,112,116,105,111,110,115,32,39,0,39,32,116,111,32,79,98,106,101,99,116,67,97,99,104,101,32,0,87,97,114,110,105,110,103,58,32,111,115,103,58,58,99,108,111,110,101,40,99,111,110,115,116,32,84,42,44,32,111,115,103,58,58,67,111,112,121,79,112,38,41,32,99,108,111,110,101,100,32,111,98,106,101,99,116,32,110,111,116,32,111,102,32,116,121,112,101,32,84,44,32,114,101,116,117,114,110,105,110,103,32,78,85,76,76,46,0,87,97,114,110,105,110,103,58,32,111,115,103,58,58,99,108,111,110,101,40,99,111,110,115,116,32,84,42,44,32,111,115,103,58,58,67,111,112,121,79,112,38,41,32,112,97,115,115,101,100,32,110,117,108,108,32,111,98,106,101,99,116,32,116,111,32,99,108,111,110,101,44,32,114,101,116,117,114,110,105,110,103,32,78,85,76,76,46,0,70,111,117,110,100,32,0,39,32,105,110,32,79,98,106,101,99,116,67,97,99,104,101,32,0,32,105,110,32,79,98,106,101,99,116,67,97,99,104,101,32,0,78,53,111,115,103,68,66,49,50,82,101,97,100,101,114,87,114,105,116,101,114,69,0,110,111,116,32,105,109,112,108,101,109,101,110,116,101,100,0,102,105,108,101,32,110,111,116,32,104,97,110,100,108,101,100,0,102,105,108,101,32,110,111,116,32,102,111,117,110,100,0,114,101,97,100,32,101,114,114,111,114,0,102,105,108,101,32,108,111,97,100,101,100,0,102,105,108,101,32,108,111,97,100,101,100,32,102,114,111,109,32,99,97,99,104,101,0,102,105,108,101,32,114,101,113,117,101,115,116,101,100,0,105,110,115,117,102,102,105,99,105,101,110,116,32,109,101,109,111,114,121,32,116,111,32,108,111,97,100,0,32,40,0,119,114,105,116,101,32,101,114,114,111,114,0,102,105,108,101,32,115,97,118,101,100,0,69,114,114,111,114,32,114,101,97,100,105,110,103,32,102,105,108,101,32,0,78,53,111,115,103,68,66,56,82,101,103,105,115,116,114,121,69,0,79,83,71,95,70,73,76,69,95,80,65,84,72,32,60,112,97,116,104,62,91,58,112,97,116,104,93,46,46,0,80,97,116,104,115,32,102,111,114,32,108,111,99,97,116,105,110,103,32,100,97,116,97,102,105,108,101,115,0,79,83,71,95,76,73,66,82,65,82,89,95,80,65,84,72,32,60,112,97,116,104,62,91,58,112,97,116,104,93,46,46,0,80,97,116,104,115,32,102,111,114,32,108,111,99,97,116,105,110,103,32,108,105,98,114,97,114,105,101,115,47,32,112,108,117,103,105,110,115,0,79,83,71,95,66,85,73,76,68,95,75,68,84,82,69,69,83,32,111,110,47,111,102,102,0,69,110,97,98,108,101,47,100,105,115,97,98,108,101,32,116,104,101,32,97,117,116,111,109,97,116,105,99,32,98,117,105,108,100,105,110,103,32,111,102,32,75,100,84,114,101,101,115,32,102,111,114,32,101,97,99,104,32,108,111,97,100,101,100,32,71,101,111,109,101,116,114,121,46,0,79,83,71,95,66,85,73,76,68,95,75,68,84,82,69,69,83,0,111,102,102,0,79,70,70,0,79,102,102,0,79,83,71,95,69,88,80,73,82,89,95,68,69,76,65,89,0,82,101,103,105,115,116,114,121,32,58,32,69,120,112,105,114,121,32,100,101,108,97,121,32,61,32,0,79,83,71,95,70,73,76,69,95,67,65,67,72,69,0,79,83,71,95,79,80,69,78,95,70,76,73,71,72,84,95,80,76,85,71,73,78,0,110,101,119,0,102,108,116,0,79,112,101,110,70,108,105,103,104,116,0,115,104,97,100,111,119,0,111,115,103,115,104,97,100,111,119,0,116,101,114,114,97,105,110,0,111,115,103,116,101,114,114,97,105,110,0,111,115,103,118,105,101,119,101,114,0,115,103,105,0,105,110,116,0,105,118,122,0,111,122,103,0,109,97,103,0,100,105,99,111,109,0,105,109,97,0,100,99,109,0,100,105,99,0,106,112,101,0,108,119,111,0,116,116,102,0,116,116,99,0,99,105,100,0,99,102,102,0,99,101,102,0,102,111,110,0,102,110,116,0,116,101,120,116,51,100,0,116,102,45,50,53,53,0,97,100,100,101,100,0,114,101,118,105,115,105,111,110,115,0,114,101,109,111,118,101,100,0,115,116,112,0,111,112,101,110,99,97,115,99,97,100,101,0,104,116,116,112,115,0,102,116,112,0,78,53,111,115,103,68,66,51,48,68,101,112,114,101,99,97,116,101,100,68,111,116,79,115,103,87,114,97,112,112,101,114,77,97,110,97,103,101,114,69,0,79,83,71,95,76,73,66,82,65,82,89,95,80,65,84,72,0,79,83,71,95,76,68,95,76,73,66,82,65,82,89,95,80,65,84,72,0,79,83,71,95,70,73,76,69,95,80,65,84,72,0,79,83,71,70,73,76,69,80,65,84,72,0,111,115,103,80,108,117,103,105,110,115,45,0,111,115,103,100,98,95,0,46,115,111,0,78,111,119,32,99,104,101,99,107,105,110,103,32,102,111,114,32,112,108,117,103,45,105,110,32,0,34,46,0,70,105,110,100,70,105,108,101,73,110,80,97,116,104,40,0,41,58,32,114,101,116,117,114,110,105,110,103,32,0,67,111,110,116,97,105,110,115,32,97,114,99,104,105,118,101,32,58,32,0,32,32,32,32,32,32,32,32,32,97,114,99,104,105,118,101,32,58,32,0,32,32,32,32,32,32,32,32,32,102,105,108,101,110,97,109,101,32,58,32,0,82,101,97,100,32,111,98,106,101,99,116,32,102,114,111,109,32,97,114,99,104,105,118,101,0,70,97,105,108,101,100,32,116,111,32,114,101,97,100,32,111,98,106,101,99,116,32,102,114,111,109,32,97,114,99,104,105,118,101,0,67,111,117,108,100,32,110,111,116,32,102,105,110,100,32,116,104,101,32,46,99,117,114,108,32,112,108,117,103,105,110,32,116,111,32,114,101,97,100,32,102,114,111,109,32,115,101,114,118,101,114,46,0,67,111,117,108,100,32,110,111,116,32,102,105,110,100,32,112,108,117,103,105,110,32,116,111,32,114,101,97,100,32,111,98,106,101,99,116,115,32,102,114,111,109,32,102,105,108,101,32,34,0,69,114,114,111,114,32,102,105,108,101,32,100,111,101,115,32,110,111,116,32,99,111,110,116,97,105,110,32,97,110,32,111,115,103,58,58,79,98,106,101,99,116,0,78,111,32,118,97,108,105,100,32,111,98,106,101,99,116,32,102,111,117,110,100,32,102,111,114,32,0,78,53,111,115,103,68,66,56,82,101,103,105,115,116,114,121,49,56,82,101,97,100,65,114,99,104,105,118,101,70,117,110,99,116,111,114,69,0,78,53,111,115,103,68,66,56,82,101,103,105,115,116,114,121,49,49,82,101,97,100,70,117,110,99,116,111,114,69,0,78,53,111,115,103,68,66,56,82,101,103,105,115,116,114,121,49,55,82,101,97,100,79,98,106,101,99,116,70,117,110,99,116,111,114,69,0,67,111,117,108,100,32,110,111,116,32,102,105,110,100,32,112,108,117,103,105,110,32,116,111,32,119,114,105,116,101,32,111,98,106,101,99,116,115,32,116,111,32,102,105,108,101,32,34,0,78,53,111,115,103,68,66,56,82,101,103,105,115,116,114,121,49,54,82,101,97,100,73,109,97,103,101,70,117,110,99,116,111,114,69,0,67,111,117,108,100,32,110,111,116,32,102,105,110,100,32,112,108,117,103,105,110,32,116,111,32,119,114,105,116,101,32,105,109,97,103,101,32,116,111,32,102,105,108,101,32,34,0,78,53,111,115,103,68,66,56,82,101,103,105,115,116,114,121,50,50,82,101,97,100,72,101,105,103,104,116,70,105,101,108,100,70,117,110,99,116,111,114,69,0,67,111,117,108,100,32,110,111,116,32,102,105,110,100,32,112,108,117,103,105,110,32,116,111,32,119,114,105,116,101,32,72,101,105,103,104,116,70,105,101,108,100,32,116,111,32,102,105,108,101,32,34,0,78,53,111,115,103,68,66,56,82,101,103,105,115,116,114,121,49,53,82,101,97,100,78,111,100,101,70,117,110,99,116,111,114,69,0,67,111,117,108,100,32,110,111,116,32,102,105,110,100,32,112,108,117,103,105,110,32,116,111,32,119,114,105,116,101,32,110,111,100,101,115,32,116,111,32,102,105,108,101,32,34,0,78,53,111,115,103,68,66,56,82,101,103,105,115,116,114,121,49,55,82,101,97,100,83,104,97,100,101,114,70,117,110,99,116,111,114,69,0,67,111,117,108,100,32,110,111,116,32,102,105,110,100,32,112,108,117,103,105,110,32,116,111,32,119,114,105,116,101,32,115,104,97,100,101,114,32,116,111,32,102,105,108,101,32,34,0,69,114,114,111,114,32,119,114,105,116,105,110,103,32,102,105,108,101,32,0,78,53,111,115,103,68,66,50,48,79,98,106,101,99,116,87,114,97,112,112,101,114,77,97,110,97,103,101,114,69,0,71,76,95,65,76,80,72,65,95,84,69,83,84,0,71,76,95,66,76,69,78,68,0,71,76,95,67,79,76,79,82,95,76,79,71,73,67,95,79,80,0,71,76,95,67,79,76,79,82,95,77,65,84,69,82,73,65,76,0,71,76,95,67,85,76,76,95,70,65,67,69,0,71,76,95,68,69,80,84,72,95,84,69,83,84,0,71,76,95,70,79,71,0,71,76,95,70,82,65,71,77,69,78,84,95,80,82,79,71,82,65,77,95,65,82,66,0,71,76,95,76,73,78,69,95,83,84,73,80,80,76,69,0,71,76,95,80,79,73,78,84,95,83,77,79,79,84,72,0,71,76,95,80,79,73,78,84,95,83,80,82,73,84,69,95,65,82,66,0,71,76,95,80,79,76,89,71,79,78,95,79,70,70,83,69,84,95,70,73,76,76,0,71,76,95,80,79,76,89,71,79,78,95,79,70,70,83,69,84,95,76,73,78,69,0,71,76,95,80,79,76,89,71,79,78,95,79,70,70,83,69,84,95,80,79,73,78,84,0,71,76,95,80,79,76,89,71,79,78,95,83,84,73,80,80,76,69,0,71,76,95,83,67,73,83,83,79,82,95,84,69,83,84,0,71,76,95,83,84,69,78,67,73,76,95,84,69,83,84,0,71,76,95,83,84,69,78,67,73,76,95,84,69,83,84,95,84,87,79,95,83,73,68,69,0,71,76,95,86,69,82,84,69,88,95,80,82,79,71,82,65,77,95,65,82,66,0,71,76,95,67,79,76,79,82,95,83,85,77,0,71,76,95,76,73,71,72,84,73,78,71,0,71,76,95,78,79,82,77,65,76,73,90,69,0,71,76,95,82,69,83,67,65,76,69,95,78,79,82,77,65,76,0,71,76,95,84,69,88,84,85,82,69,95,49,68,0,71,76,95,84,69,88,84,85,82,69,95,50,68,0,71,76,95,84,69,88,84,85,82,69,95,51,68,0,71,76,95,84,69,88,84,85,82,69,95,67,85,66,69,95,77,65,80,0,71,76,95,84,69,88,84,85,82,69,95,82,69,67,84,65,78,71,76,69,0,71,76,95,84,69,88,84,85,82,69,95,71,69,78,95,81,0,71,76,95,84,69,88,84,85,82,69,95,71,69,78,95,82,0,71,76,95,84,69,88,84,85,82,69,95,71,69,78,95,83,0,71,76,95,84,69,88,84,85,82,69,95,71,69,78,95,84,0,71,76,95,67,76,73,80,95,80,76,65,78,69,48,0,71,76,95,67,76,73,80,95,80,76,65,78,69,49,0,71,76,95,67,76,73,80,95,80,76,65,78,69,50,0,71,76,95,67,76,73,80,95,80,76,65,78,69,51,0,71,76,95,67,76,73,80,95,80,76,65,78,69,52,0,71,76,95,67,76,73,80,95,80,76,65,78,69,53,0,71,76,95,76,73,71,72,84,48,0,71,76,95,76,73,71,72,84,49,0,71,76,95,76,73,71,72,84,50,0,71,76,95,76,73,71,72,84,51,0,71,76,95,76,73,71,72,84,52,0,71,76,95,76,73,71,72,84,53,0,71,76,95,76,73,71,72,84,54,0,71,76,95,76,73,71,72,84,55,0,71,76,95,86,69,82,84,69,88,95,80,82,79,71,82,65,77,95,80,79,73,78,84,95,83,73,90,69,0,71,76,95,86,69,82,84,69,88,95,80,82,79,71,82,65,77,95,84,87,79,95,83,73,68,69,0,78,69,86,69,82,0,76,69,83,83,0,69,81,85,65,76,0,76,69,81,85,65,76,0,71,82,69,65,84,69,82,0,78,79,84,69,81,85,65,76,0,71,69,81,85,65,76,0,65,76,87,65,89,83,0,82,69,80,76,65,67,69,0,77,79,68,85,76,65,84,69,0,65,68,68,0,65,68,68,95,83,73,71,78,69,68,0,73,78,84,69,82,80,79,76,65,84,69,0,83,85,66,84,82,65,67,84,0,68,79,84,51,95,82,71,66,0,68,79,84,51,95,82,71,66,65,0,67,79,78,83,84,65,78,84,0,80,82,73,77,65,82,89,95,67,79,76,79,82,0,80,82,69,86,73,79,85,83,0,84,69,88,84,85,82,69,0,84,69,88,84,85,82,69,48,0,84,69,88,84,85,82,69,49,0,84,69,88,84,85,82,69,50,0,84,69,88,84,85,82,69,51,0,84,69,88,84,85,82,69,52,0,84,69,88,84,85,82,69,53,0,84,69,88,84,85,82,69,54,0,84,69,88,84,85,82,69,55,0,67,76,65,77,80,0,67,76,65,77,80,95,84,79,95,69,68,71,69,0,67,76,65,77,80,95,84,79,95,66,79,82,68,69,82,0,82,69,80,69,65,84,0,77,73,82,82,79,82,0,76,73,78,69,65,82,0,76,73,78,69,65,82,95,77,73,80,77,65,80,95,76,73,78,69,65,82,0,76,73,78,69,65,82,95,77,73,80,77,65,80,95,78,69,65,82,69,83,84,0,78,69,65,82,69,83,84,0,78,69,65,82,69,83,84,95,77,73,80,77,65,80,95,76,73,78,69,65,82,0,78,69,65,82,69,83,84,95,77,73,80,77,65,80,95,78,69,65,82,69,83,84,0,71,76,95,73,78,84,69,78,83,73,84,89,0,71,76,95,76,85,77,73,78,65,78,67,69,0,71,76,95,65,76,80,72,65,0,71,76,95,76,85,77,73,78,65,78,67,69,95,65,76,80,72,65,0,71,76,95,82,71,66,0,71,76,95,82,71,66,65,0,71,76,95,67,79,77,80,82,69,83,83,69,68,95,65,76,80,72,65,95,65,82,66,0,71,76,95,67,79,77,80,82,69,83,83,69,68,95,76,85,77,73,78,65,78,67,69,95,65,82,66,0,71,76,95,67,79,77,80,82,69,83,83,69,68,95,73,78,84,69,78,83,73,84,89,95,65,82,66,0,71,76,95,67,79,77,80,82,69,83,83,69,68,95,76,85,77,73,78,65,78,67,69,95,65,76,80,72,65,95,65,82,66,0,71,76,95,67,79,77,80,82,69,83,83,69,68,95,82,71,66,95,65,82,66,0,71,76,95,67,79,77,80,82,69,83,83,69,68,95,82,71,66,65,95,65,82,66,0,71,76,95,67,79,77,80,82,69,83,83,69,68,95,82,71,66,95,83,51,84,67,95,68,88,84,49,95,69,88,84,0,71,76,95,67,79,77,80,82,69,83,83,69,68,95,82,71,66,65,95,83,51,84,67,95,68,88,84,49,95,69,88,84,0,71,76,95,67,79,77,80,82,69,83,83,69,68,95,82,71,66,65,95,83,51,84,67,95,68,88,84,51,95,69,88,84,0,71,76,95,67,79,77,80,82,69,83,83,69,68,95,82,71,66,65,95,83,51,84,67,95,68,88,84,53,95,69,88,84,0,71,76,95,67,79,77,80,82,69,83,83,69,68,95,82,71,66,95,80,86,82,84,67,95,52,66,80,80,86,49,95,73,77,71,0,71,76,95,67,79,77,80,82,69,83,83,69,68,95,82,71,66,95,80,86,82,84,67,95,50,66,80,80,86,49,95,73,77,71,0,71,76,95,67,79,77,80,82,69,83,83,69,68,95,82,71,66,65,95,80,86,82,84,67,95,52,66,80,80,86,49,95,73,77,71,0,71,76,95,67,79,77,80,82,69,83,83,69,68,95,82,71,66,65,95,80,86,82,84,67,95,50,66,80,80,86,49,95,73,77,71,0,71,76,95,69,84,67,49,95,82,71,66,56,95,79,69,83,0,71,76,95,67,79,77,80,82,69,83,83,69,68,95,82,71,66,56,95,69,84,67,50,0,71,76,95,67,79,77,80,82,69,83,83,69,68,95,83,82,71,66,56,95,69,84,67,50,0,71,76,95,67,79,77,80,82,69,83,83,69,68,95,82,71,66,56,95,80,85,78,67,72,84,72,82,79,85,71,72,95,65,76,80,72,65,49,95,69,84,67,50,0,71,76,95,67,79,77,80,82,69,83,83,69,68,95,83,82,71,66,56,95,80,85,78,67,72,84,72,82,79,85,71,72,95,65,76,80,72,65,49,95,69,84,67,50,0,71,76,95,67,79,77,80,82,69,83,83,69,68,95,82,71,66,65,56,95,69,84,67,50,95,69,65,67,0,71,76,95,67,79,77,80,82,69,83,83,69,68,95,83,82,71,66,56,95,65,76,80,72,65,56,95,69,84,67,50,95,69,65,67,0,71,76,95,67,79,77,80,82,69,83,83,69,68,95,82,49,49,95,69,65,67,0,71,76,95,67,79,77,80,82,69,83,83,69,68,95,83,73,71,78,69,68,95,82,49,49,95,69,65,67,0,71,76,95,67,79,77,80,82,69,83,83,69,68,95,82,71,49,49,95,69,65,67,0,71,76,95,67,79,77,80,82,69,83,83,69,68,95,83,73,71,78,69,68,95,82,71,49,49,95,69,65,67,0,71,76,95,66,89,84,69,0,71,76,95,83,72,79,82,84,0,71,76,95,73,78,84,0,71,76,95,70,76,79,65,84,0,71,76,95,68,79,85,66,76,69,0,71,76,95,85,78,83,73,71,78,69,68,95,66,89,84,69,0,71,76,95,85,78,83,73,71,78,69,68,95,83,72,79,82,84,0,71,76,95,85,78,83,73,71,78,69,68,95,73,78,84,0,68,83,84,95,65,76,80,72,65,0,68,83,84,95,67,79,76,79,82,0,79,78,69,0,79,78,69,95,77,73,78,85,83,95,68,83,84,95,65,76,80,72,65,0,79,78,69,95,77,73,78,85,83,95,68,83,84,95,67,79,76,79,82,0,79,78,69,95,77,73,78,85,83,95,83,82,67,95,65,76,80,72,65,0,79,78,69,95,77,73,78,85,83,95,83,82,67,95,67,79,76,79,82,0,83,82,67,95,65,76,80,72,65,0,83,82,67,95,65,76,80,72,65,95,83,65,84,85,82,65,84,69,0,83,82,67,95,67,79,76,79,82,0,67,79,78,83,84,65,78,84,95,67,79,76,79,82,0,79,78,69,95,77,73,78,85,83,95,67,79,78,83,84,65,78,84,95,67,79,76,79,82,0,67,79,78,83,84,65,78,84,95,65,76,80,72,65,0,79,78,69,95,77,73,78,85,83,95,67,79,78,83,84,65,78,84,95,65,76,80,72,65,0,90,69,82,79,0,67,79,79,82,68,73,78,65,84,69,0,68,69,80,84,72,0,70,79,71,95,72,73,78,84,0,71,69,78,69,82,65,84,69,95,77,73,80,77,65,80,95,72,73,78,84,0,76,73,78,69,95,83,77,79,79,84,72,95,72,73,78,84,0,80,69,82,83,80,69,67,84,73,86,69,95,67,79,82,82,69,67,84,73,79,78,95,72,73,78,84,0,80,79,73,78,84,95,83,77,79,79,84,72,95,72,73,78,84,0,80,79,76,89,71,79,78,95,83,77,79,79,84,72,95,72,73,78,84,0,84,69,88,84,85,82,69,95,67,79,77,80,82,69,83,83,73,79,78,95,72,73,78,84,0,70,82,65,71,77,69,78,84,95,83,72,65,68,69,82,95,68,69,82,73,86,65,84,73,86,69,95,72,73,78,84,0,80,79,73,78,84,0,76,73,78,69,0,70,73,76,76,0,66,65,67,75,0,70,82,79,78,84,0,70,82,79,78,84,95,65,78,68,95,66,65,67,75,0,70,73,88,69,68,95,79,78,76,89,0,70,65,83,84,69,83,84,0,78,73,67,69,83,84,0,68,79,78,84,95,67,65,82,69,0,65,114,114,97,121,84,121,112,101,0,66,121,116,101,65,114,114,97,121,0,85,66,121,116,101,65,114,114,97,121,0,83,104,111,114,116,65,114,114,97,121,0,85,83,104,111,114,116,65,114,114,97,121,0,73,110,116,65,114,114,97,121,0,85,73,110,116,65,114,114,97,121,0,70,108,111,97,116,65,114,114,97,121,0,68,111,117,98,108,101,65,114,114,97,121,0,86,101,99,50,98,65,114,114,97,121,0,86,101,99,51,98,65,114,114,97,121,0,86,101,99,52,98,65,114,114,97,121,0,86,101,99,50,117,98,65,114,114,97,121,0,86,101,99,51,117,98,65,114,114,97,121,0,86,101,99,52,117,98,65,114,114,97,121,0,86,101,99,50,115,65,114,114,97,121,0,86,101,99,51,115,65,114,114,97,121,0,86,101,99,52,115,65,114,114,97,121,0,86,101,99,50,117,115,65,114,114,97,121,0,86,101,99,51,117,115,65,114,114,97,121,0,86,101,99,52,117,115,65,114,114,97,121,0,86,101,99,50,102,65,114,114,97,121,0,86,101,99,51,102,65,114,114,97,121,0,86,101,99,52,102,65,114,114,97,121,0,86,101,99,50,100,65,114,114,97,121,0,86,101,99,51,100,65,114,114,97,121,0,86,101,99,52,100,65,114,114,97,121,0,86,101,99,50,105,65,114,114,97,121,0,86,101,99,51,105,65,114,114,97,121,0,86,101,99,52,105,65,114,114,97,121,0,86,101,99,50,117,105,65,114,114,97,121,0,86,101,99,51,117,105,65,114,114,97,121,0,86,101,99,52,117,105,65,114,114,97,121,0,80,114,105,109,105,116,105,118,101,84,121,112,101,0,68,114,97,119,65,114,114,97,121,115,0,68,114,97,119,65,114,114,97,121,115,76,101,110,103,116,104,0,68,114,97,119,69,108,101,109,101,110,116,115,85,66,121,116,101,0,68,114,97,119,69,108,101,109,101,110,116,115,85,83,104,111,114,116,0,68,114,97,119,69,108,101,109,101,110,116,115,85,73,110,116,0,71,76,95,80,79,73,78,84,83,0,71,76,95,76,73,78,69,83,0,71,76,95,76,73,78,69,95,83,84,82,73,80,0,71,76,95,76,73,78,69,95,76,79,79,80,0,71,76,95,84,82,73,65,78,71,76,69,83,0,71,76,95,84,82,73,65,78,71,76,69,95,83,84,82,73,80,0,71,76,95,84,82,73,65,78,71,76,69,95,70,65,78,0,71,76,95,81,85,65,68,83,0,71,76,95,81,85,65,68,95,83,84,82,73,80,0,71,76,95,80,79,76,89,71,79,78,0,71,76,95,76,73,78,69,83,95,65,68,74,65,67,69,78,67,89,95,69,88,84,0,71,76,95,76,73,78,69,83,95,65,68,74,65,67,69,78,67,89,0,71,76,95,76,73,78,69,95,83,84,82,73,80,95,65,68,74,65,67,69,78,67,89,95,69,88,84,0,71,76,95,76,73,78,69,95,83,84,82,73,80,95,65,68,74,65,67,69,78,67,89,0,71,76,95,84,82,73,65,78,71,76,69,83,95,65,68,74,65,67,69,78,67,89,95,69,88,84,0,71,76,95,84,82,73,65,78,71,76,69,83,95,65,68,74,65,67,69,78,67,89,0,71,76,95,84,82,73,65,78,71,76,69,95,83,84,82,73,80,95,65,68,74,65,67,69,78,67,89,95,69,88,84,0,71,76,95,84,82,73,65,78,71,76,69,95,83,84,82,73,80,95,65,68,74,65,67,69,78,67,89,0,71,76,95,80,65,84,67,72,69,83,0,68,117,112,108,105,99,97,116,101,32,101,110,117,109,32,118,97,108,117,101,32,0,32,119,105,116,104,32,111,108,100,32,115,116,114,105,110,103,58,32,0,32,97,110,100,32,110,101,119,32,115,116,114,105,110,103,115,58,32,0,32,97,110,100,32,0,32,97,110,100,32,110,101,119,32,115,116,114,105,110,103,58,32,0,78,53,111,115,103,68,66,55,65,114,99,104,105,118,101,69,0,67,108,111,115,105,110,103,32,68,121,110,97,109,105,99,76,105,98,114,97,114,121,32,0,78,53,111,115,103,68,66,49,52,68,121,110,97,109,105,99,76,105,98,114,97,114,121,69,0,79,112,101,110,101,100,32,68,121,110,97,109,105,99,76,105,98,114,97,114,121,32,0,68,121,110,97,109,105,99,76,105,98,114,97,114,121,58,58,102,97,105,108,101,100,32,108,111,97,100,105,110,103,32,34,0,34,0,87,97,114,110,105,110,103,58,32,100,121,110,97,109,105,99,32,108,105,98,114,97,114,121,32,39,0,39,32,101,120,105,115,116,115,44,32,98,117,116,32,97,110,32,101,114,114,111,114,32,111,99,99,117,114,114,101,100,32,119,104,105,108,101,32,116,114,121,105,110,103,32,116,111,32,111,112,101,110,32,105,116,58,0,39,32,100,111,101,115,32,110,111,116,32,101,120,105,115,116,32,40,111,114,32,105,115,110,39,116,32,114,101,97,100,97,98,108,101,41,58,0,67,111,117,108,100,32,110,111,116,32,99,114,101,97,116,101,32,99,97,99,104,101,32,100,105,114,101,99,116,111,114,121,58,32,0,70,105,108,101,67,97,99,104,101,58,58,119,114,105,116,101,83,104,97,100,101,114,84,111,67,97,99,104,101,40,0,41,32,97,115,32,0,70,105,108,101,67,97,99,104,101,58,58,114,101,97,100,83,104,97,100,101,114,70,114,111,109,67,97,99,104,101,40,0,70,105,108,101,67,97,99,104,101,58,58,119,114,105,116,101,78,111,100,101,84,111,67,97,99,104,101,40,0,70,105,108,101,67,97,99,104,101,58,58,114,101,97,100,78,111,100,101,70,114,111,109,67,97,99,104,101,40,0,70,105,108,101,67,97,99,104,101,58,58,119,114,105,116,101,72,101,105,103,104,116,70,105,101,108,100,84,111,67,97,99,104,101,40,0,70,105,108,101,67,97,99,104,101,58,58,114,101,97,100,72,101,105,103,104,116,70,105,101,108,100,70,114,111,109,67,97,99,104,101,40,0,70,105,108,101,67,97,99,104,101,58,58,119,114,105,116,101,79,98,106,101,99,116,84,111,67,97,99,104,101,40,0,70,105,108,101,67,97,99,104,101,58,58,114,101,97,100,79,98,106,101,99,116,70,114,111,109,67,97,99,104,101,40,0,70,105,108,101,67,97,99,104,101,58,58,119,114,105,116,101,73,109,97,103,101,84,111,67,97,99,104,101,40,0,70,105,108,101,67,97,99,104,101,58,58,114,101,97,100,73,109,97,103,101,70,114,111,109,67,97,99,104,101,40,0,70,105,108,101,67,97,99,104,101,58,58,99,114,101,97,116,101,67,97,99,104,101,70,105,108,101,78,97,109,101,40,0,41,32,61,32,0,68,101,115,116,114,117,99,116,101,100,32,70,105,108,101,67,97,99,104,101,32,0,78,53,111,115,103,68,66,57,70,105,108,101,67,97,99,104,101,69,0,67,111,110,115,116,114,117,99,116,101,100,32,70,105,108,101,67,97,99,104,101,32,58,32,0,47,92,0,58,47,47,0,111,115,103,68,66,58,58,109,97,107,101,68,105,114,101,99,116,111,114,121,40,41,58,32,99,97,110,110,111,116,32,99,114,101,97,116,101,32,97,110,32,101,109,112,116,121,32,100,105,114,101,99,116,111,114,121,0,111,115,103,68,66,58,58,109,97,107,101,68,105,114,101,99,116,111,114,121,40,41,58,32,0,32,97,108,114,101,97,100,121,32,101,120,105,115,116,115,32,97,110,100,32,105,115,32,110,111,116,32,97,32,100,105,114,101,99,116,111,114,121,33,0,105,116,114,61,39,0,39,10,0,70,105,110,100,70,105,108,101,73,110,80,97,116,104,40,41,32,58,32,116,114,121,105,110,103,32,0,32,46,46,46,10,0,70,105,110,100,70,105,108,101,73,110,80,97,116,104,40,41,32,58,32,85,83,73,78,71,32,0,46,47,0,46,92,0,47,0,102,105,110,100,70,105,108,101,73,110,68,105,114,101,99,116,111,114,121,40,41,32,58,32,108,111,111,107,105,110,103,32,102,111,114,32,0,32,105,110,32,0,46,46,46,10,0,76,68,95,76,73,66,82,65,82,89,95,80,65,84,72,0,47,117,115,114,47,108,105,98,47,58,47,117,115,114,47,108,111,99,97,108,47,108,105,98,47,0,97,112,112,108,105,99,97,116,105,111,110,47,100,120,102,0,100,120,102,0,97,112,112,108,105,99,97,116,105,111,110,47,103,110,117,116,97,114,0,116,103,122,0,97,112,112,108,105,99,97,116,105,111,110,47,112,100,102,0,112,100,102,0,97,112,112,108,105,99,97,116,105,111,110,47,112,108,97,105,110,0,97,112,112,108,105,99,97,116,105,111,110,47,112,111,115,116,115,99,114,105,112,116,0,112,115,0,97,112,112,108,105,99,97,116,105,111,110,47,120,45,98,122,105,112,0,98,122,0,97,112,112,108,105,99,97,116,105,111,110,47,120,45,98,122,105,112,50,0,98,122,50,0,97,112,112,108,105,99,97,116,105,111,110,47,120,45,99,111,109,112,114,101,115,115,101,100,0,122,105,112,0,97,112,112,108,105,99,97,116,105,111,110,47,120,45,103,122,105,112,0,103,122,0,97,112,112,108,105,99,97,116,105,111,110,47,120,45,105,110,118,101,110,116,111,114,0,105,118,0,97,112,112,108,105,99,97,116,105,111,110,47,120,45,106,97,118,97,115,99,114,105,112,116,0,106,115,0,97,112,112,108,105,99,97,116,105,111,110,47,120,109,108,0,120,109,108,0,97,112,112,108,105,99,97,116,105,111,110,47,120,45,116,97,114,0,116,97,114,0,97,112,112,108,105,99,97,116,105,111,110,47,120,45,118,114,109,108,0,119,114,108,0,97,112,112,108,105,99,97,116,105,111,110,47,120,45,119,111,114,108,100,0,97,112,112,108,105,99,97,116,105,111,110,47,120,45,122,105,112,45,99,111,109,112,114,101,115,115,101,100,0,97,112,112,108,105,99,97,116,105,111,110,47,122,105,112,0,100,114,97,119,105,110,103,47,120,45,100,119,102,40,111,108,100,41,0,100,119,102,0,105,109,97,103,101,47,98,109,112,0,98,109,112,0,105,109,97,103,101,47,99,109,117,45,114,97,115,116,101,114,0,114,97,115,0,105,109,97,103,101,47,102,105,102,0,102,105,102,0,105,109,97,103,101,47,102,108,111,114,105,97,110,0,102,108,111,0,105,109,97,103,101,47,103,51,102,97,120,0,103,51,0,105,109,97,103,101,47,103,105,102,0,103,105,102,0,105,109,97,103,101,47,105,101,102,0,105,101,102,0,105,109,97,103,101,47,106,112,101,103,0,106,112,103,0,105,109,97,103,101,47,106,117,116,118,105,115,105,111,110,0,106,117,116,0,105,109,97,103,101,47,110,97,112,108,112,115,0,110,97,112,0,110,97,112,108,112,115,0,105,109,97,103,101,47,112,105,99,116,0,112,105,99,0,105,109,97,103,101,47,112,106,112,101,103,0,105,109,97,103,101,47,112,110,103,0,112,110,103,0,105,109,97,103,101,47,116,105,102,102,0,116,105,102,0,105,109,97,103,101,47,118,97,115,97,0,109,99,102,0,105,109,97,103,101,47,118,110,100,46,100,119,103,0,105,109,97,103,101,47,118,110,100,46,102,112,120,0,102,112,120,0,105,109,97,103,101,47,118,110,100,46,110,101,116,45,102,112,120,0,105,109,97,103,101,47,118,110,100,46,114,110,45,114,101,97,108,102,108,97,115,104,0,114,102,0,105,109,97,103,101,47,118,110,100,46,114,110,45,114,101,97,108,112,105,120,0,114,112,0,105,109,97,103,101,47,118,110,100,46,119,97,112,46,119,98,109,112,0,119,98,109,112,0,105,109,97,103,101,47,118,110,100,46,120,105,102,102,0,120,105,102,0,105,109,97,103,101,47,120,98,109,0,120,98,109,0,105,109,97,103,101,47,120,45,99,109,117,45,114,97,115,116,101,114,0,105,109,97,103,101,47,120,45,100,119,103,0,105,109,97,103,101,47,120,45,105,99,111,110,0,105,99,111,0,105,109,97,103,101,47,120,45,106,103,0,97,114,116,0,105,109,97,103,101,47,120,45,106,112,115,0,106,112,115,0,105,109,97,103,101,47,120,45,110,105,102,102,0,110,105,102,0,105,109,97,103,101,47,120,45,112,99,120,0,112,99,120,0,105,109,97,103,101,47,120,45,112,105,99,116,0,112,99,116,0,105,109,97,103,101,47,120,112,109,0,120,112,109,0,105,109,97,103,101,47,120,45,112,111,114,116,97,98,108,101,45,97,110,121,109,97,112,0,112,110,109,0,105,109,97,103,101,47,120,45,112,111,114,116,97,98,108,101,45,98,105,116,109,97,112,0,112,98,109,0,105,109,97,103,101,47,120,45,112,111,114,116,97,98,108,101,45,103,114,97,121,109,97,112,0,112,103,109,0,105,109,97,103,101,47,120,45,112,111,114,116,97,98,108,101,45,103,114,101,121,109,97,112,0,105,109,97,103,101,47,120,45,112,111,114,116,97,98,108,101,45,112,105,120,109,97,112,0,112,112,109,0,105,109,97,103,101,47,120,45,113,117,105,99,107,116,105,109,101,0,113,105,102,0,105,109,97,103,101,47,120,45,114,103,98,0,114,103,98,0,105,109,97,103,101,47,120,45,116,105,102,102,0,105,109,97,103,101,47,120,45,119,105,110,100,111,119,115,45,98,109,112,0,105,109,97,103,101,47,120,45,120,98,105,116,109,97,112,0,105,109,97,103,101,47,120,45,120,98,109,0,105,109,97,103,101,47,120,45,120,112,105,120,109,97,112,0,105,109,97,103,101,47,120,45,120,119,100,0,120,119,100,0,105,109,97,103,101,47,120,45,120,119,105,110,100,111,119,100,117,109,112,0,105,45,119,111,114,108,100,47,105,45,118,114,109,108,0,105,118,114,0,109,111,100,101,108,47,105,103,101,115,0,105,103,115,0,109,111,100,101,108,47,118,110,100,46,100,119,102,0,109,111,100,101,108,47,118,114,109,108,0,109,111,100,101,108,47,120,45,112,111,118,0,112,111,118,0,109,117,108,116,105,112,97,114,116,47,120,45,103,122,105,112,0,103,122,105,112,0,109,117,108,116,105,112,97,114,116,47,120,45,117,115,116,97,114,0,117,115,116,97,114,0,109,117,108,116,105,112,97,114,116,47,120,45,122,105,112,0,118,105,100,101,111,47,97,110,105,109,97,102,108,101,120,0,97,102,108,0,118,105,100,101,111,47,97,118,105,0,97,118,105,0,118,105,100,101,111,47,97,118,115,45,118,105,100,101,111,0,97,118,115,0,118], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+164092);
/* memory initializer */ allocate([105,100,101,111,47,100,108,0,100,108,0,118,105,100,101,111,47,102,108,105,0,102,108,105,0,118,105,100,101,111,47,103,108,0,103,108,0,118,105,100,101,111,47,109,112,101,103,0,109,112,103,0,118,105,100,101,111,47,109,115,118,105,100,101,111,0,118,105,100,101,111,47,113,117,105,99,107,116,105,109,101,0,113,116,0,118,105,100,101,111,47,118,100,111,0,118,100,111,0,118,105,100,101,111,47,118,105,118,111,0,118,105,118,0,118,105,100,101,111,47,118,110,100,46,114,110,45,114,101,97,108,118,105,100,101,111,0,114,118,0,118,105,100,101,111,47,118,110,100,46,118,105,118,111,0,118,105,100,101,111,47,118,111,115,97,105,99,0,118,111,115,0,118,105,100,101,111,47,120,45,97,109,116,45,100,101,109,111,114,117,110,0,120,100,114,0,118,105,100,101,111,47,120,45,97,109,116,45,115,104,111,119,114,117,110,0,120,115,114,0,118,105,100,101,111,47,120,45,97,116,111,109,105,99,51,100,45,102,101,97,116,117,114,101,0,102,109,102,0,118,105,100,101,111,47,120,45,100,108,0,118,105,100,101,111,47,120,45,100,118,0,100,118,0,118,105,100,101,111,47,120,45,102,108,105,0,118,105,100,101,111,47,120,45,103,108,0,118,105,100,101,111,47,120,45,105,115,118,105,100,101,111,0,105,115,117,0,118,105,100,101,111,47,120,45,109,111,116,105,111,110,45,106,112,101,103,0,109,106,112,103,0,118,105,100,101,111,47,120,45,109,112,101,103,0,109,112,51,0,118,105,100,101,111,47,120,45,109,112,101,113,50,97,0,109,112,50,0,118,105,100,101,111,47,120,45,109,115,45,97,115,102,0,97,115,102,0,118,105,100,101,111,47,120,45,109,115,45,97,115,102,45,112,108,117,103,105,110,0,97,115,120,0,118,105,100,101,111,47,120,45,109,115,118,105,100,101,111,0,118,105,100,101,111,47,120,45,113,116,99,0,113,116,99,0,118,105,100,101,111,47,120,45,115,99,109,0,115,99,109,0,118,105,100,101,111,47,120,45,115,103,105,45,109,111,118,105,101,0,109,111,118,105,101,0,119,105,110,100,111,119,115,47,109,101,116,97,102,105,108,101,0,119,109,102,0,120,103,108,47,100,114,97,119,105,110,103,0,120,103,122,0,120,103,108,47,109,111,118,105,101,0,120,109,122,0,120,45,119,111,114,108,100,47,120,45,51,100,109,102,0,51,100,109,0,120,45,119,111,114,108,100,47,120,45,115,118,114,0,115,118,114,0,120,45,119,111,114,108,100,47,120,45,118,114,109,108,0,120,45,119,111,114,108,100,47,120,45,118,114,116,0,118,114,116,0,68,97,116,97,98,97,115,101,82,101,118,105,115,105,111,110,40,0,41,58,58,105,115,70,105,108,101,66,108,97,99,107,76,105,115,116,101,100,40,0,41,0,70,105,108,101,32,105,115,32,98,108,97,99,107,32,108,105,115,116,101,100,32,0,77,111,118,105,110,103,32,102,111,114,119,97,114,100,32,102,114,111,109,32,0,32,116,111,32,0,32,32,32,100,101,108,101,116,105,110,103,32,0,77,111,118,105,110,103,32,98,97,99,107,32,102,114,111,109,32,0,78,51,111,115,103,49,51,73,109,97,103,101,83,101,113,117,101,110,99,101,69,0,83,104,97,112,101,68,114,97,119,97,98,108,101,0,111,115,103,0,78,51,111,115,103,49,51,83,104,97,112,101,68,114,97,119,97,98,108,101,69,0,37,100,46,37,100,46,37,100,0,111,112,101,110,103,108,101,115,50,0,67,111,117,108,100,110,39,116,32,108,111,97,100,32,71,76,69,83,50,32,102,117,110,99,116,105,111,110,32,37,115,58,32,37,115,10,0,103,101,110,101,114,105,99,0,85,78,75,78,79,87,78,0,71,76,95,79,85,84,95,79,70,95,77,69,77,79,82,89,0,71,76,95,73,78,86,65,76,73,68,95,79,80,69,82,65,84,73,79,78,0,71,76,95,73,78,86,65,76,73,68,95,86,65,76,85,69,0,71,76,95,73,78,86,65,76,73,68,95,69,78,85,77,0,37,115,58,32,37,115,32,40,37,100,41,58,32,37,115,32,37,115,32,40,48,120,37,88,41,0,47,104,111,109,101,47,107,111,114,110,101,114,114,47,46,101,109,115,99,114,105,112,116,101,110,95,112,111,114,116,115,47,115,100,108,50,47,83,68,76,50,45,118,101,114,115,105,111,110,95,49,51,47,115,114,99,47,114,101,110,100,101,114,47,111,112,101,110,103,108,101,115,50,47,83,68,76,95,114,101,110,100,101,114,95,103,108,101,115,50,46,99,0,118,111,105,100,32,71,76,69,83,50,95,82,101,115,101,116,83,116,97,116,101,40,83,68,76,95,82,101,110,100,101,114,101,114,32,42,41,0,86,105,100,101,111,32,115,117,98,115,121,115,116,101,109,32,104,97,115,32,110,111,116,32,98,101,101,110,32,105,110,105,116,105,97,108,105,122,101,100,0,84,104,101,32,115,112,101,99,105,102,105,101,100,32,119,105,110,100,111,119,32,105,115,110,39,116,32,97,110,32,79,112,101,110,71,76,32,119,105,110,100,111,119,0,84,104,101,32,115,112,101,99,105,102,105,101,100,32,119,105,110,100,111,119,32,104,97,115,32,110,111,116,32,98,101,101,110,32,109,97,100,101,32,99,117,114,114,101,110,116,0,103,108,82,101,97,100,80,105,120,101,108,115,40,41,0,105,110,116,32,71,76,69,83,50,95,82,101,110,100,101,114,82,101,97,100,80,105,120,101,108,115,40,83,68,76,95,82,101,110,100,101,114,101,114,32,42,44,32,99,111,110,115,116,32,83,68,76,95,82,101,99,116,32,42,44,32,85,105,110,116,51,50,44,32,118,111,105,100,32,42,44,32,105,110,116,41,0,100,115,116,0,100,115,116,95,112,105,116,99,104,0,85,110,107,110,111,119,110,32,70,79,85,82,67,67,32,112,105,120,101,108,32,102,111,114,109,97,116,0,73,110,100,101,120,101,100,32,112,105,120,101,108,32,102,111,114,109,97,116,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,0,83,68,76,95,66,76,73,84,95,67,80,85,95,70,69,65,84,85,82,69,83,0,66,108,105,116,32,99,111,109,98,105,110,97,116,105,111,110,32,110,111,116,32,115,117,112,112,111,114,116,101,100,0,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57,58,59,60,61,62,63,64,65,66,67,68,69,70,71,72,73,74,75,76,77,78,79,80,81,82,83,84,85,86,87,88,89,90,91,92,93,94,95,96,97,98,99,100,101,102,103,104,105,106,107,108,109,110,111,112,113,114,115,116,117,118,119,120,121,122,123,124,125,126,127,128,129,130,131,132,133,134,135,136,137,138,139,140,141,142,143,144,145,146,147,148,149,150,151,152,153,154,155,156,157,158,159,160,161,162,163,164,165,166,167,168,169,170,171,172,173,174,175,176,177,178,179,180,181,182,183,184,185,186,187,188,189,190,191,192,193,194,195,196,197,198,199,200,201,202,203,204,205,206,207,208,209,210,211,212,213,214,215,216,217,218,219,220,221,222,223,224,225,226,227,228,229,230,231,232,233,234,235,236,237,238,239,240,241,242,243,244,245,246,247,248,249,250,251,252,253,254,255,0,2,4,6,8,10,12,14,16,18,20,22,24,26,28,30,32,34,36,38,40,42,44,46,48,50,52,54,56,58,60,62,64,66,68,70,72,74,76,78,80,82,84,86,88,90,92,94,96,98,100,102,104,106,108,110,112,114,116,118,120,122,124,126,128,130,132,134,136,138,140,142,144,146,148,150,152,154,156,158,160,162,164,166,168,170,172,174,176,178,180,182,184,186,188,190,192,194,196,198,200,202,204,206,208,210,212,214,216,218,220,222,224,226,228,230,232,234,236,238,240,242,244,246,248,250,252,255,0,4,8,12,16,20,24,28,32,36,40,44,48,52,56,60,64,68,72,76,80,85,89,93,97,101,105,109,113,117,121,125,129,133,137,141,145,149,153,157,161,165,170,174,178,182,186,190,194,198,202,206,210,214,218,222,226,230,234,238,242,246,250,255,0,8,16,24,32,41,49,57,65,74,82,90,98,106,115,123,131,139,148,156,164,172,180,189,197,205,213,222,230,238,246,255,0,17,34,51,68,85,102,119,136,153,170,187,204,221,238,255,0,36,72,109,145,182,218,255,0,85,170,255,0,255,255,102,111,114,109,97,116,0,83,68,76,95,83,101,116,80,105,120,101,108,70,111,114,109,97,116,80,97,108,101,116,116,101,40,41,32,112,97,115,115,101,100,32,78,85,76,76,32,102,111,114,109,97,116,0,83,68,76,95,83,101,116,80,105,120,101,108,70,111,114,109,97,116,80,97,108,101,116,116,101,40,41,32,112,97,115,115,101,100,32,97,32,112,97,108,101,116,116,101,32,116,104,97,116,32,100,111,101,115,110,39,116,32,109,97,116,99,104,32,116,104,101,32,102,111,114,109,97,116,0,83,68,76,95,70,105,108,108,82,101,99,116,40,41,58,32,85,110,115,117,112,112,111,114,116,101,100,32,115,117,114,102,97,99,101,32,102,111,114,109,97,116,0,83,68,76,95,70,105,108,108,82,101,99,116,40,41,58,32,89,111,117,32,109,117,115,116,32,108,111,99,107,32,116,104,101,32,115,117,114,102,97,99,101,0,66,0,114,101,115,117,108,116,0,70,79,85,82,67,67,32,112,105,120,101,108,32,102,111,114,109,97,116,115,32,97,114,101,32,110,111,116,32,115,117,112,112,111,114,116,101,100,0,73,110,118,97,108,105,100,32,114,101,110,100,101,114,101,114,0,73,110,118,97,108,105,100,32,116,101,120,116,117,114,101,0,82,101,110,100,101,114,101,114,32,100,111,101,115,110,39,116,32,115,117,112,112,111,114,116,32,113,117,101,114,121,105,110,103,32,111,117,116,112,117,116,32,115,105,122,101,0,105,110,116,32,71,76,69,83,50,95,82,101,110,100,101,114,67,111,112,121,69,120,40,83,68,76,95,82,101,110,100,101,114,101,114,32,42,44,32,83,68,76,95,84,101,120,116,117,114,101,32,42,44,32,99,111,110,115,116,32,83,68,76,95,82,101,99,116,32,42,44,32,99,111,110,115,116,32,83,68,76,95,70,82,101,99,116,32,42,44,32,99,111,110,115,116,32,100,111,117,98,108,101,44,32,99,111,110,115,116,32,83,68,76,95,70,80,111,105,110,116,32,42,44,32,99,111,110,115,116,32,83,68,76,95,82,101,110,100,101,114,101,114,70,108,105,112,41,0,85,110,115,117,112,112,111,114,116,101,100,32,116,101,120,116,117,114,101,32,102,111,114,109,97,116,0,97,95,112,111,115,105,116,105,111,110,0,97,95,116,101,120,67,111,111,114,100,0,97,95,97,110,103,108,101,0,97,95,99,101,110,116,101,114,0,70,97,105,108,101,100,32,116,111,32,108,105,110,107,32,115,104,97,100,101,114,32,112,114,111,103,114,97,109,0,117,95,112,114,111,106,101,99,116,105,111,110,0,117,95,116,101,120,116,117,114,101,95,118,0,117,95,116,101,120,116,117,114,101,95,117,0,117,95,116,101,120,116,117,114,101,0,117,95,109,111,100,117,108,97,116,105,111,110,0,117,95,99,111,108,111,114,0,78,111,32,115,104,97,100,101,114,32,109,97,116,99,104,105,110,103,32,116,104,101,32,114,101,113,117,101,115,116,101,100,32,99,104,97,114,97,99,116,101,114,105,115,116,105,99,115,32,119,97,115,32,102,111,117,110,100,0,84,104,101,32,115,112,101,99,105,102,105,101,100,32,115,104,97,100,101,114,32,99,97,110,110,111,116,32,98,101,32,108,111,97,100,101,100,32,111,110,32,116,104,101,32,99,117,114,114,101,110,116,32,112,108,97,116,102,111,114,109,0,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,116,104,101,32,115,104,97,100,101,114,58,32,37,115,0,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,116,104,101,32,115,104,97,100,101,114,0,32,32,32,32,32,112,114,101,99,105,115,105,111,110,32,109,101,100,105,117,109,112,32,102,108,111,97,116,59,32,32,32,32,32,117,110,105,102,111,114,109,32,115,97,109,112,108,101,114,50,68,32,117,95,116,101,120,116,117,114,101,59,32,32,32,32,32,117,110,105,102,111,114,109,32,118,101,99,52,32,117,95,109,111,100,117,108,97,116,105,111,110,59,32,32,32,32,32,118,97,114,121,105,110,103,32,118,101,99,50,32,118,95,116,101,120,67,111,111,114,100,59,32,32,32,32,32,32,32,32,32,118,111,105,100,32,109,97,105,110,40,41,32,32,32,32,32,123,32,32,32,32,32,32,32,32,32,118,101,99,52,32,97,98,103,114,32,61,32,116,101,120,116,117,114,101,50,68,40,117,95,116,101,120,116,117,114,101,44,32,118,95,116,101,120,67,111,111,114,100,41,59,32,32,32,32,32,32,32,32,32,103,108,95,70,114,97,103,67,111,108,111,114,32,61,32,97,98,103,114,59,32,32,32,32,32,32,32,32,32,103,108,95,70,114,97,103,67,111,108,111,114,46,97,32,61,32,49,46,48,59,32,32,32,32,32,32,32,32,32,103,108,95,70,114,97,103,67,111,108,111,114,32,42,61,32,117,95,109,111,100,117,108,97,116,105,111,110,59,32,32,32,32,32,125,32,0,32,32,32,32,32,112,114,101,99,105,115,105,111,110,32,109,101,100,105,117,109,112,32,102,108,111,97,116,59,32,32,32,32,32,117,110,105,102,111,114,109,32,115,97,109,112,108,101,114,50,68,32,117,95,116,101,120,116,117,114,101,59,32,32,32,32,32,117,110,105,102,111,114,109,32,118,101,99,52,32,117,95,109,111,100,117,108,97,116,105,111,110,59,32,32,32,32,32,118,97,114,121,105,110,103,32,118,101,99,50,32,118,95,116,101,120,67,111,111,114,100,59,32,32,32,32,32,32,32,32,32,118,111,105,100,32,109,97,105,110,40,41,32,32,32,32,32,123,32,32,32,32,32,32,32,32,32,118,101,99,52,32,97,98,103,114,32,61,32,116,101,120,116,117,114,101,50,68,40,117,95,116,101,120,116,117,114,101,44,32,118,95,116,101,120,67,111,111,114,100,41,59,32,32,32,32,32,32,32,32,32,103,108,95,70,114,97,103,67,111,108,111,114,32,61,32,97,98,103,114,59,32,32,32,32,32,32,32,32,32,103,108,95,70,114,97,103,67,111,108,111,114,46,114,32,61,32,97,98,103,114,46,98,59,32,32,32,32,32,32,32,32,32,103,108,95,70,114,97,103,67,111,108,111,114,46,98,32,61,32,97,98,103,114,46,114,59,32,32,32,32,32,32,32,32,32,103,108,95,70,114,97,103,67,111,108,111,114,46,97,32,61,32,49,46,48,59,32,32,32,32,32,32,32,32,32,103,108,95,70,114,97,103,67,111,108,111,114,32,42,61,32,117,95,109,111,100,117,108,97,116,105,111,110,59,32,32,32,32,32,125,32,0,32,32,32,32,32,112,114,101,99,105,115,105,111,110,32,109,101,100,105,117,109,112,32,102,108,111,97,116,59,32,32,32,32,32,117,110,105,102,111,114,109,32,115,97,109,112,108,101,114,50,68,32,117,95,116,101,120,116,117,114,101,59,32,32,32,32,32,117,110,105,102,111,114,109,32,118,101,99,52,32,117,95,109,111,100,117,108,97,116,105,111,110,59,32,32,32,32,32,118,97,114,121,105,110,103,32,118,101,99,50,32,118,95,116,101,120,67,111,111,114,100,59,32,32,32,32,32,32,32,32,32,118,111,105,100,32,109,97,105,110,40,41,32,32,32,32,32,123,32,32,32,32,32,32,32,32,32,118,101,99,52,32,97,98,103,114,32,61,32,116,101,120,116,117,114,101,50,68,40,117,95,116,101,120,116,117,114,101,44,32,118,95,116,101,120,67,111,111,114,100,41,59,32,32,32,32,32,32,32,32,32,103,108,95,70,114,97,103,67,111,108,111,114,32,61,32,97,98,103,114,59,32,32,32,32,32,32,32,32,32,103,108,95,70,114,97,103,67,111,108,111,114,46,114,32,61,32,97,98,103,114,46,98,59,32,32,32,32,32,32,32,32,32,103,108,95,70,114,97,103,67,111,108,111,114,46,98,32,61,32,97,98,103,114,46,114,59,32,32,32,32,32,32,32,32,32,103,108,95,70,114,97,103,67,111,108,111,114,32,42,61,32,117,95,109,111,100,117,108,97,116,105,111,110,59,32,32,32,32,32,125,32,0,32,32,32,32,32,112,114,101,99,105,115,105,111,110,32,109,101,100,105,117,109,112,32,102,108,111,97,116,59,32,32,32,32,32,117,110,105,102,111,114,109,32,115,97,109,112,108,101,114,50,68,32,117,95,116,101,120,116,117,114,101,59,32,32,32,32,32,117,110,105,102,111,114,109,32,118,101,99,52,32,117,95,109,111,100,117,108,97,116,105,111,110,59,32,32,32,32,32,118,97,114,121,105,110,103,32,118,101,99,50,32,118,95,116,101,120,67,111,111,114,100,59,32,32,32,32,32,32,32,32,32,118,111,105,100,32,109,97,105,110,40,41,32,32,32,32,32,123,32,32,32,32,32,32,32,32,32,103,108,95,70,114,97,103,67,111,108,111,114,32,61,32,116,101,120,116,117,114,101,50,68,40,117,95,116,101,120,116,117,114,101,44,32,118,95,116,101,120,67,111,111,114,100,41,59,32,32,32,32,32,32,32,32,32,103,108,95,70,114,97,103,67,111,108,111,114,32,42,61,32,117,95,109,111,100,117,108,97,116,105,111,110,59,32,32,32,32,32,125,32,0,32,32,32,32,32,112,114,101,99,105,115,105,111,110,32,109,101,100,105,117,109,112,32,102,108,111,97,116,59,32,32,32,32,32,117,110,105,102,111,114,109,32,118,101,99,52,32,117,95,99,111,108,111,114,59,32,32,32,32,32,32,32,32,32,118,111,105,100,32,109,97,105,110,40,41,32,32,32,32,32,123,32,32,32,32,32,32,32,32,32,103,108,95,70,114,97,103,67,111,108,111,114,32,61,32,117,95,99,111,108,111,114,59,32,32,32,32,32,125,32,0,32,32,32,32,32,117,110,105,102,111,114,109,32,109,97,116,52,32,117,95,112,114,111,106,101,99,116,105,111,110,59,32,32,32,32,32,97,116,116,114,105,98,117,116,101,32,118,101,99,50,32,97,95,112,111,115,105,116,105,111,110,59,32,32,32,32,32,97,116,116,114,105,98,117,116,101,32,118,101,99,50,32,97,95,116,101,120,67,111,111,114,100,59,32,32,32,32,32,97,116,116,114,105,98,117,116,101,32,102,108,111,97,116,32,97,95,97,110,103,108,101,59,32,32,32,32,32,97,116,116,114,105,98,117,116,101,32,118,101,99,50,32,97,95,99,101,110,116,101,114,59,32,32,32,32,32,118,97,114,121,105,110,103,32,118,101,99,50,32,118,95,116,101,120,67,111,111,114,100,59,32,32,32,32,32,32,32,32,32,118,111,105,100,32,109,97,105,110,40,41,32,32,32,32,32,123,32,32,32,32,32,32,32,32,32,102,108,111,97,116,32,97,110,103,108,101,32,61,32,114,97,100,105,97,110,115,40,97,95,97,110,103,108,101,41,59,32,32,32,32,32,32,32,32,32,102,108,111,97,116,32,99,32,61,32,99,111,115,40,97,110,103,108,101,41,59,32,32,32,32,32,32,32,32,32,102,108,111,97,116,32,115,32,61,32,115,105,110,40,97,110,103,108,101,41,59,32,32,32,32,32,32,32,32,32,109,97,116,50,32,114,111,116,97,116,105,111,110,77,97,116,114,105,120,32,61,32,109,97,116,50,40,99,44,32,45,115,44,32,115,44,32,99,41,59,32,32,32,32,32,32,32,32,32,118,101,99,50,32,112,111,115,105,116,105,111,110,32,61,32,114,111,116,97,116,105,111,110,77,97,116,114,105,120,32,42,32,40,97,95,112,111,115,105,116,105,111,110,32,45,32,97,95,99,101,110,116,101,114,41,32,43,32,97,95,99,101,110,116,101,114,59,32,32,32,32,32,32,32,32,32,118,95,116,101,120,67,111,111,114,100,32,61,32,97,95,116,101,120,67,111,111,114,100,59,32,32,32,32,32,32,32,32,32,103,108,95,80,111,115,105,116,105,111,110,32,61,32,117,95,112,114,111,106,101,99,116,105,111,110,32,42,32,118,101,99,52,40,112,111,115,105,116,105,111,110,44,32,48,46,48,44,32,49,46,48,41,59,32,32,32,32,32,32,32,32,103,108,95,80,111,105,110,116,83,105,122,101,32,61,32,49,46,48,59,32,32,32,32,32,125,32,0,32,32,32,32,32,112,114,101,99,105,115,105,111,110,32,109,101,100,105,117,109,112,32,102,108,111,97,116,59,32,32,32,32,32,117,110,105,102,111,114,109,32,115,97,109,112,108,101,114,50,68,32,117,95,116,101,120,116,117,114,101,59,32,32,32,32,32,117,110,105,102,111,114,109,32,115,97,109,112,108,101,114,50,68,32,117,95,116,101,120,116,117,114,101,95,117,59,32,32,32,32,32,117,110,105,102,111,114,109,32,115,97,109,112,108,101,114,50,68,32,117,95,116,101,120,116,117,114,101,95,118,59,32,32,32,32,32,117,110,105,102,111,114,109,32,118,101,99,52,32,117,95,109,111,100,117,108,97,116,105,111,110,59,32,32,32,32,32,118,97,114,121,105,110,103,32,118,101,99,50,32,118,95,116,101,120,67,111,111,114,100,59,32,32,32,32,32,32,32,32,32,118,111,105,100,32,109,97,105,110,40,41,32,32,32,32,32,123,32,32,32,32,32,32,32,32,32,109,101,100,105,117,109,112,32,118,101,99,51,32,121,117,118,59,32,32,32,32,32,32,32,32,32,108,111,119,112,32,118,101,99,51,32,114,103,98,59,32,32,32,32,32,32,32,32,32,121,117,118,46,120,32,61,32,116,101,120,116,117,114,101,50,68,40,117,95,116,101,120,116,117,114,101,44,32,32,32,118,95,116,101,120,67,111,111,114,100,41,46,114,59,32,32,32,32,32,32,32,32,32,121,117,118,46,121,32,61,32,116,101,120,116,117,114,101,50,68,40,117,95,116,101,120,116,117,114,101,95,117,44,32,118,95,116,101,120,67,111,111,114,100,41,46,114,32,45,32,48,46,53,59,32,32,32,32,32,32,32,32,32,121,117,118,46,122,32,61,32,116,101,120,116,117,114,101,50,68,40,117,95,116,101,120,116,117,114,101,95,118,44,32,118,95,116,101,120,67,111,111,114,100,41,46,114,32,45,32,48,46,53,59,32,32,32,32,32,32,32,32,32,114,103,98,32,61,32,109,97,116,51,40,32,49,44,32,32,32,32,32,32,32,32,49,44,32,32,32,32,32,32,32,49,44,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,48,44,32,32,32,32,32,32,32,45,48,46,51,57,52,54,53,44,32,50,46,48,51,50,49,49,44,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,49,46,49,51,57,56,51,44,32,45,48,46,53,56,48,54,48,44,32,48,41,32,42,32,121,117,118,59,32,32,32,32,32,32,32,32,32,103,108,95,70,114,97,103,67,111,108,111,114,32,61,32,118,101,99,52,40,114,103,98,44,32,49,41,59,32,32,32,32,32,32,32,32,32,103,108,95,70,114,97,103,67,111,108,111,114,32,42,61,32,117,95,109,111,100,117,108,97,116,105,111,110,59,32,32,32,32,32,125,32,0,32,32,32,32,32,112,114,101,99,105,115,105,111,110,32,109,101,100,105,117,109,112,32,102,108,111,97,116,59,32,32,32,32,32,117,110,105,102,111,114,109,32,115,97,109,112,108,101,114,50,68,32,117,95,116,101,120,116,117,114,101,59,32,32,32,32,32,117,110,105,102,111,114,109,32,115,97,109,112,108,101,114,50,68,32,117,95,116,101,120,116,117,114,101,95,117,59,32,32,32,32,32,117,110,105,102,111,114,109,32,118,101,99,52,32,117,95,109,111,100,117,108,97,116,105,111,110,59,32,32,32,32,32,118,97,114,121,105,110,103,32,118,101,99,50,32,118,95,116,101,120,67,111,111,114,100,59,32,32,32,32,32,32,32,32,32,118,111,105,100,32,109,97,105,110,40,41,32,32,32,32,32,123,32,32,32,32,32,32,32,32,32,109,101,100,105,117,109,112,32,118,101,99,51,32,121,117,118,59,32,32,32,32,32,32,32,32,32,108,111,119,112,32,118,101,99,51,32,114,103,98,59,32,32,32,32,32,32,32,32,32,121,117,118,46,120,32,61,32,116,101,120,116,117,114,101,50,68,40,117,95,116,101,120,116,117,114,101,44,32,32,32,118,95,116,101,120,67,111,111,114,100,41,46,114,59,32,32,32,32,32,32,32,32,32,121,117,118,46,121,122,32,61,32,116,101,120,116,117,114,101,50,68,40,117,95,116,101,120,116,117,114,101,95,117,44,32,118,95,116,101,120,67,111,111,114,100,41,46,114,97,32,45,32,48,46,53,59,32,32,32,32,32,32,32,32,32,114,103,98,32,61,32,109,97,116,51,40,32,49,44,32,32,32,32,32,32,32,32,49,44,32,32,32,32,32,32,32,49,44,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,48,44,32,32,32,32,32,32,32,45,48,46,51,57,52,54,53,44,32,50,46,48,51,50,49,49,44,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,49,46,49,51,57,56,51,44,32,45,48,46,53,56,48,54,48,44,32,48,41,32,42,32,121,117,118,59,32,32,32,32,32,32,32,32,32,103,108,95,70,114,97,103,67,111,108,111,114,32,61,32,118,101,99,52,40,114,103,98,44,32,49,41,59,32,32,32,32,32,32,32,32,32,103,108,95,70,114,97,103,67,111,108,111,114,32,42,61,32,117,95,109,111,100,117,108,97,116,105,111,110,59,32,32,32,32,32,125,32,0,32,32,32,32,32,112,114,101,99,105,115,105,111,110,32,109,101,100,105,117,109,112,32,102,108,111,97,116,59,32,32,32,32,32,117,110,105,102,111,114,109,32,115,97,109,112,108,101,114,50,68,32,117,95,116,101,120,116,117,114,101,59,32,32,32,32,32,117,110,105,102,111,114,109,32,115,97,109,112,108,101,114,50,68,32,117,95,116,101,120,116,117,114,101,95,117,59,32,32,32,32,32,117,110,105,102,111,114,109,32,118,101,99,52,32,117,95,109,111,100,117,108,97,116,105,111,110,59,32,32,32,32,32,118,97,114,121,105,110,103,32,118,101,99,50,32,118,95,116,101,120,67,111,111,114,100,59,32,32,32,32,32,32,32,32,32,118,111,105,100,32,109,97,105,110,40,41,32,32,32,32,32,123,32,32,32,32,32,32,32,32,32,109,101,100,105,117,109,112,32,118,101,99,51,32,121,117,118,59,32,32,32,32,32,32,32,32,32,108,111,119,112,32,118,101,99,51,32,114,103,98,59,32,32,32,32,32,32,32,32,32,121,117,118,46,120,32,61,32,116,101,120,116,117,114,101,50,68,40,117,95,116,101,120,116,117,114,101,44,32,32,32,118,95,116,101,120,67,111,111,114,100,41,46,114,59,32,32,32,32,32,32,32,32,32,121,117,118,46,121,122,32,61,32,116,101,120,116,117,114,101,50,68,40,117,95,116,101,120,116,117,114,101,95,117,44,32,118,95,116,101,120,67,111,111,114,100,41,46,97,114,32,45,32,48,46,53,59,32,32,32,32,32,32,32,32,32,114,103,98,32,61,32,109,97,116,51,40,32,49,44,32,32,32,32,32,32,32,32,49,44,32,32,32,32,32,32,32,49,44,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,48,44,32,32,32,32,32,32,32,45,48,46,51,57,52,54,53,44,32,50,46,48,51,50,49,49,44,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,49,46,49,51,57,56,51,44,32,45,48,46,53,56,48,54,48,44,32,48,41,32,42,32,121,117,118,59,32,32,32,32,32,32,32,32,32,103,108,95,70,114,97,103,67,111,108,111,114,32,61,32,118,101,99,52,40,114,103,98,44,32,49,41,59,32,32,32,32,32,32,32,32,32,103,108,95,70,114,97,103,67,111,108,111,114,32,42,61,32,117,95,109,111,100,117,108,97,116,105,111,110,59,32,32,32,32,32,125,32,0,105,110,116,32,71,76,69,83,50,95,82,101,110,100,101,114,67,111,112,121,40,83,68,76,95,82,101,110,100,101,114,101,114,32,42,44,32,83,68,76,95,84,101,120,116,117,114,101,32,42,44,32,99,111,110,115,116,32,83,68,76,95,82,101,99,116,32,42,44,32,99,111,110,115,116,32,83,68,76,95,70,82,101,99,116,32,42,41,0,105,110,116,32,71,76,69,83,50,95,82,101,110,100,101,114,70,105,108,108,82,101,99,116,115,40,83,68,76,95,82,101,110,100,101,114,101,114,32,42,44,32,99,111,110,115,116,32,83,68,76,95,70,82,101,99,116,32,42,44,32,105,110,116,41,0,105,110,116,32,71,76,69,83,50,95,82,101,110,100,101,114,68,114,97,119,76,105,110,101,115,40,83,68,76,95,82,101,110,100,101,114,101,114,32,42,44,32,99,111,110,115,116,32,83,68,76,95,70,80,111,105,110,116,32,42,44,32,105,110,116,41,0,105,110,116,32,71,76,69,83,50,95,85,112,100,97,116,101,86,105,101,119,112,111,114,116,40,83,68,76,95,82,101,110,100,101,114,101,114,32,42,41,0,103,108,70,114,97,109,101,98,117,102,102,101,114,84,101,120,116,117,114,101,50,68,40,41,32,102,97,105,108,101,100,0,103,108,84,101,120,83,117,98,73,109,97,103,101,50,68,40,41,0,105,110,116,32,71,76,69,83,50,95,85,112,100,97,116,101,84,101,120,116,117,114,101,89,85,86,40,83,68,76,95,82,101,110,100,101,114,101,114,32,42,44,32,83,68,76,95,84,101,120,116,117,114,101,32,42,44,32,99,111,110,115,116,32,83,68,76,95,82,101,99,116,32,42,44,32,99,111,110,115,116,32,85,105,110,116,56,32,42,44,32,105,110,116,44,32,99,111,110,115,116,32,85,105,110,116,56,32,42,44,32,105,110,116,44,32,99,111,110,115,116,32,85,105,110,116,56,32,42,44,32,105,110,116,41,0,105,110,116,32,71,76,69,83,50,95,85,112,100,97,116,101,84,101,120,116,117,114,101,40,83,68,76,95,82,101,110,100,101,114,101,114,32,42,44,32,83,68,76,95,84,101,120,116,117,114,101,32,42,44,32,99,111,110,115,116,32,83,68,76,95,82,101,99,116,32,42,44,32,99,111,110,115,116,32,118,111,105,100,32,42,44,32,105,110,116,41,0,84,101,120,116,117,114,101,32,102,111,114,109,97,116,32,110,111,116,32,115,117,112,112,111,114,116,101,100,0,105,110,116,32,71,76,69,83,50,95,67,114,101,97,116,101,84,101,120,116,117,114,101,40,83,68,76,95,82,101,110,100,101,114,101,114,32,42,44,32,83,68,76,95,84,101,120,116,117,114,101,32,42,41,0,103,108,71,101,110,84,101,120,117,114,101,115,40,41,0,103,108,84,101,120,73,109,97,103,101,50,68,40,41,0,78,111,32,79,112,101,110,71,76,32,99,111,110,116,101,120,116,32,104,97,115,32,98,101,101,110,32,109,97,100,101,32,99,117,114,114,101,110,116,0,83,101,116,116,105,110,103,32,116,104,101,32,115,119,97,112,32,105,110,116,101,114,118,97,108,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,0,37,115,0,37,115,58,32,37,115,10,0,86,69,82,66,79,83,69,0,68,69,66,85,71,0,73,78,70,79,0,87,65,82,78,0,69,82,82,79,82,0,67,82,73,84,73,67,65,76,0,78,111,32,71,76,32,100,114,105,118,101,114,32,104,97,115,32,98,101,101,110,32,108,111,97,100,101,100,0,78,111,32,100,121,110,97,109,105,99,32,71,76,32,115,117,112,112,111,114,116,32,105,110,32,118,105,100,101,111,32,100,114,105,118,101,114,0,105,100,0,118,111,105,100,32,71,76,69,83,50,95,68,101,115,116,114,111,121,82,101,110,100,101,114,101,114,40,83,68,76,95,82,101,110,100,101,114,101,114,32,42,41,0,79,117,116,32,111,102,32,109,101,109,111,114,121,0,69,114,114,111,114,32,114,101,97,100,105,110,103,32,102,114,111,109,32,100,97,116,97,115,116,114,101,97,109,0,69,114,114,111,114,32,119,114,105,116,105,110,103,32,116,111,32,100,97,116,97,115,116,114,101,97,109,0,69,114,114,111,114,32,115,101,101,107,105,110,103,32,105,110,32,100,97,116,97,115,116,114,101,97,109,0,84,104,97,116,32,111,112,101,114,97,116,105,111,110,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,0,85,110,107,110,111,119,110,32,83,68,76,32,101,114,114,111,114,0,78,111,32,79,112,101,110,71,76,32,115,117,112,112,111,114,116,32,105,110,32,118,105,100,101,111,32,100,114,105,118,101,114,0,110,111,32,103,101,115,116,117,114,101,32,116,111,117,99,104,32,100,101,118,105,99,101,115,32,114,101,103,105,115,116,101,114,101,100,0,69,82,82,79,82,58,32,78,117,109,80,111,105,110,116,115,32,61,32,37,105,10,0,84,104,101,32,101,118,101,110,116,32,115,121,115,116,101,109,32,104,97,115,32,98,101,101,110,32,115,104,117,116,32,100,111,119,110,0,69,118,101,110,116,32,113,117,101,117,101,32,105,115,32,102,117,108,108,32,40,37,100,32,101,118,101,110,116,115,41,0,67,111,117,108,100,110,39,116,32,108,111,99,107,32,101,118,101,110,116,32,113,117,101,117,101,0,86,105,100,101,111,32,100,114,105,118,101,114,32,100,111,101,115,110,39,116,32,115,117,112,112,111,114,116,32,99,104,97,110,103,105,110,103,32,100,105,115,112,108,97,121,32,109,111,100,101,0,78,111,32,118,105,100,101,111,32,109,111,100,101,32,108,97,114,103,101,32,101,110,111,117,103,104,32,102,111,114,32,37,100,120,37,100,0,77,105,115,115,105,110,103,32,100,101,115,105,114,101,100,32,109,111,100,101,32,111,114,32,99,108,111,115,101,115,116,32,109,111,100,101,32,112,97,114,97,109,101,116,101,114,0,109,111,100,101,0,67,111,117,108,100,110,39,116,32,102,105,110,100,32,100,105,115,112,108,97,121,32,109,111,100,101,32,109,97,116,99,104,0,67,111,117,108,100,110,39,116,32,102,105,110,100,32,97,110,121,32,100,105,115,112,108,97,121,115,0,112,111,105,110,116,115,0,99,111,117,110,116,0,100,105,115,112,108,97,121,73,110,100,101,120,32,109,117,115,116,32,98,101,32,105,110,32,116,104,101,32,114,97,110,103,101,32,48,32,45,32,37,100,0,85,110,107,110,111,119,110,32,79,112,101,110,71,76,32,99,111,110,116,101,120,116,32,102,108,97,103,32,37,100,0,85,110,107,110,111,119,110,32,79,112,101,110,71,76,32,99,111,110,116,101,120,116,32,112,114,111,102,105,108,101,32,37,100,0,85,110,107,110,111,119,110,32,79,112,101,110,71,76,32,97,116,116,114,105,98,117,116,101,0,70,97,105,108,101,100,32,103,101,116,116,105,110,103,32,79,112,101,110,71,76,32,103,108,71,101,116,73,110,116,101,103,101,114,118,32,101,110,116,114,121,32,112,111,105,110,116,0,70,97,105,108,101,100,32,103,101,116,116,105,110,103,32,79,112,101,110,71,76,32,103,108,71,101,116,69,114,114,111,114,32,101,110,116,114,121,32,112,111,105,110,116,0,79,112,101,110,71,76,32,101,114,114,111,114,58,32,71,76,95,73,78,86,65,76,73,68,95,69,78,85,77,0,79,112,101,110,71,76,32,101,114,114,111,114,58,32,71,76,95,73,78,86,65,76,73,68,95,86,65,76,85,69,0,79,112,101,110,71,76,32,101,114,114,111,114,58,32,37,48,56,88,0,67,97,110,39,116,32,99,114,101,97,116,101,32,114,101,110,100,101,114,101,114,32,102,111,114,32,78,85,76,76,32,115,117,114,102,97,99,101,0,87,105,110,100,111,119,32,115,117,114,102,97,99,101,32,105,115,32,105,110,118,97,108,105,100,44,32,112,108,101,97,115,101,32,99,97,108,108,32,83,68,76,95,71,101,116,87,105,110,100,111,119,83,117,114,102,97,99,101,40,41,32,116,111,32,103,101,116,32,97,32,110,101,119,32,115,117,114,102,97,99,101,0,84,114,105,101,100,32,116,111,32,114,101,97,100,32,111,117,116,115,105,100,101,32,111,102,32,115,117,114,102,97,99,101,32,98,111,117,110,100,115,0,83,68,76,95,82,69,78,68,69,82,95,83,67,65,76,69,95,81,85,65,76,73,84,89,0,110,101,97,114,101,115,116,0,83,68,76,95,85,112,112,101,114,66,108,105,116,58,32,112,97,115,115,101,100,32,97,32,78,85,76,76,32,115,117,114,102,97,99,101,0,83,117,114,102,97,99,101,115,32,109,117,115,116,32,110,111,116,32,98,101,32,108,111,99,107,101,100,32,100,117,114,105,110,103,32,98,108,105,116,0,69,109,112,116,121,32,100,101,115,116,105,110,97,116,105,111,110,32,112,97,108,101,116,116,101,0,85,110,107,110,111,119,110,32,112,105,120,101,108,32,102,111,114,109,97,116,0,107,101,121,0,112,97,108,101,116,116,101,0,110,99,111,108,111,114,115,0,83,68,76,95,85,112,112,101,114,66,108,105,116,83,99,97,108,101,100,58,32,112,97,115,115,101,100,32,97,32,78,85,76,76,32,115,117,114,102,97,99,101,0,79,110,108,121,32,119,111,114,107,115,32,119,105,116,104,32,115,97,109,101,32,102,111,114,109,97,116,32,115,117,114,102,97,99,101,115,0,73,110,118,97,108,105,100,32,115,111,117,114,99,101,32,98,108,105,116,32,114,101,99,116,97,110,103,108,101,0,73,110,118,97,108,105,100,32,100,101,115,116,105,110,97,116,105,111,110,32,98,108,105,116,32,114,101,99,116,97,110,103,108,101,0,85,110,97,98,108,101,32,116,111,32,108,111,99,107,32,100,101,115,116,105,110,97,116,105,111,110,32,115,117,114,102,97,99,101,0,85,110,97,98,108,101,32,116,111,32,108,111,99,107,32,115,111,117,114,99,101,32,115,117,114,102,97,99,101,0,115,117,114,102,97,99,101,0,83,68,76,95,66,108,101,110,100,70,105,108,108,82,101,99,116,115,40,41,58,32,85,110,115,117,112,112,111,114,116,101,100,32,115,117,114,102,97,99,101,32,102,111,114,109,97,116,0,83,68,76,95,70,105,108,108,82,101,99,116,115,40,41,32,112,97,115,115,101,100,32,78,85,76,76,32,114,101,99,116,115,0,83,68,76,95,66,108,101,110,100,76,105,110,101,115,40,41,58,32,80,97,115,115,101,100,32,78,85,76,76,32,100,101,115,116,105,110,97,116,105,111,110,32,115,117,114,102,97,99,101,0,83,68,76,95,66,108,101,110,100,76,105,110,101,115,40,41,58,32,85,110,115,117,112,112,111,114,116,101,100,32,115,117,114,102,97,99,101,32,102,111,114,109,97,116,0,83,68,76,95,66,108,101,110,100,80,111,105,110,116,40,41,58,32,85,110,115,117,112,112,111,114,116,101,100,32,115,117,114,102,97,99,101,32,102,111,114,109,97,116,0,114,101,99,116,0,88,49,0,89,49,0,88,50,0,89,50,0,83,68,76,95,68,114,97,119,76,105,110,101,115,40,41,58,32,80,97,115,115,101,100,32,78,85,76,76,32,100,101,115,116,105,110,97,116,105,111,110,32,115,117,114,102,97,99,101,0,83,68,76,95,68,114,97,119,76,105,110,101,115,40,41,58,32,85,110,115,117,112,112,111,114,116,101,100,32,115,117,114,102,97,99,101,32,102,111,114,109,97,116,0,80,97,115,115,101,100,32,78,85,76,76,32,100,101,115,116,105,110,97,116,105,111,110,32,115,117,114,102,97,99,101,0,83,68,76,95,68,114,97,119,80,111,105,110,116,40,41,58,32,85,110,115,117,112,112,111,114,116,101,100,32,115,117,114,102,97,99,101,32,102,111,114,109,97,116,0,83,68,76,95,66,108,101,110,100,80,111,105,110,116,115,40,41,58,32,85,110,115,117,112,112,111,114,116,101,100,32,115,117,114,102,97,99,101,32,102,111,114,109,97,116,0,83,68,76,95,68,114,97,119,80,111,105,110,116,115,40,41,58,32,85,110,115,117,112,112,111,114,116,101,100,32,115,117,114,102,97,99,101,32,102,111,114,109,97,116,0,85,110,107,110,111,119,110,32,116,101,120,116,117,114,101,32,102,111,114,109,97,116,0,83,111,102,116,119,97,114,101,32,114,101,110,100,101,114,101,114,32,100,111,101,115,110,39,116,32,104,97,118,101,32,97,110,32,111,117,116,112,117,116,32,115,117,114,102,97,99,101,0,83,68,76,32,101,109,115,99,114,105,112,116,101,110,32,118,105,100,101,111,32,100,114,105,118,101,114,0,83,68,76,95,86,73,68,69,79,95,77,73,78,73,77,73,90,69,95,79,78,95,70,79,67,85,83,95,76,79,83,83,0,48,0,69,71,76,32,110,111,116,32,105,110,105,116,105,97,108,105,122,101,100,0,85,110,97,98,108,101,32,116,111,32,115,101,116,32,116,104,101,32,69,71,76,32,115,119,97,112,32,105,110,116,101,114,118,97,108,0,79,112,101,110,71,76,32,110,111,116,32,105,110,105,116,105,97,108,105,122,101,100,0,85,110,97,98,108,101,32,116,111,32,109,97,107,101,32,69,71,76,32,99,111,110,116,101,120,116,32,99,117,114,114,101,110,116,0,67,111,117,108,100,32,110,111,116,32,99,114,101,97,116,101,32,69,71,76,32,99,111,110,116,101,120,116,32,40,99,111,110,116,101,120,116,32,97,116,116,114,105,98,117,116,101,115,32,97,114,101,32,110,111,116,32,115,117,112,112,111,114,116,101,100,41,0,67,111,117,108,100,32,110,111,116,32,99,114,101,97,116,101,32,69,71,76,32,99,111,110,116,101,120,116,0,67,111,117,108,100,32,110,111,116,32,109,97,107,101,32,69,71,76,32,99,111,110,116,101,120,116,32,99,117,114,114,101,110,116,0,70,97,105,108,101,100,32,108,111,97,100,105,110,103,32,37,115,58,32,37,115,0,67,111,117,108,100,32,110,111,116,32,103,101,116,32,69,71,76,32,100,105,115,112,108,97,121,0,67,111,117,108,100,32,110,111,116,32,105,110,105,116,105,97,108,105,122,101,32,69,71,76,0,67,111,117,108,100,110,39,116,32,102,105,110,100,32,102,114,97,109,101,98,117,102,102,101,114,32,115,117,114,102,97,99,101,32,102,111,114,32,119,105,110,100,111,119,0,123,32,118,97,114,32,119,32,61,32,36,48,59,32,118,97,114,32,104,32,61,32,36,49,59,32,118,97,114,32,112,105,120,101,108,115,32,61,32,36,50,59,32,105,102,32,40,33,77,111,100,117,108,101,91,39,83,68,76,50,39,93,41,32,77,111,100,117,108,101,91,39,83,68,76,50,39,93,32,61,32,123,125,59,32,118,97,114,32,83,68,76,50,32,61,32,77,111,100,117,108,101,91,39,83,68,76,50,39,93,59,32,105,102,32,40,83,68,76,50,46,99,116,120,67,97,110,118,97,115,32,33,61,61,32,77,111,100,117,108,101,91,39,99,97,110,118,97,115,39,93,41,32,123,32,83,68,76,50,46,99,116,120,32,61,32,77,111,100,117,108,101,91,39,99,114,101,97,116,101,67,111,110,116,101,120,116,39,93,40,77,111,100,117,108,101,91,39,99,97,110,118,97,115,39,93,44,32,102,97,108,115,101,44,32,116,114,117,101,41,59,32,83,68,76,50,46,99,116,120,67,97,110,118,97,115,32,61,32,77,111,100,117,108,101,91,39,99,97,110,118,97,115,39,93,59,32,125,32,105,102,32,40,83,68,76,50,46,119,32,33,61,61,32,119,32,124,124,32,83,68,76,50,46,104,32,33,61,61,32,104,32,124,124,32,83,68,76,50,46,105,109,97,103,101,67,116,120,32,33,61,61,32,83,68,76,50,46,99,116,120,41,32,123,32,83,68,76,50,46,105,109,97,103,101,32,61,32,83,68,76,50,46,99,116,120,46,99,114,101,97,116,101,73,109,97,103,101,68,97,116,97,40,119,44,32,104], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+174332);
/* memory initializer */ allocate([41,59,32,83,68,76,50,46,119,32,61,32,119,59,32,83,68,76,50,46,104,32,61,32,104,59,32,83,68,76,50,46,105,109,97,103,101,67,116,120,32,61,32,83,68,76,50,46,99,116,120,59,32,125,32,118,97,114,32,100,97,116,97,32,61,32,83,68,76,50,46,105,109,97,103,101,46,100,97,116,97,59,32,118,97,114,32,115,114,99,32,61,32,112,105,120,101,108,115,32,62,62,32,50,59,32,118,97,114,32,100,115,116,32,61,32,48,59,32,118,97,114,32,110,117,109,59,32,105,102,32,40,116,121,112,101,111,102,32,67,97,110,118,97,115,80,105,120,101,108,65,114,114,97,121,32,33,61,61,32,39,117,110,100,101,102,105,110,101,100,39,32,38,38,32,100,97,116,97,32,105,110,115,116,97,110,99,101,111,102,32,67,97,110,118,97,115,80,105,120,101,108,65,114,114,97,121,41,32,123,32,110,117,109,32,61,32,100,97,116,97,46,108,101,110,103,116,104,59,32,119,104,105,108,101,32,40,100,115,116,32,60,32,110,117,109,41,32,123,32,118,97,114,32,118,97,108,32,61,32,72,69,65,80,51,50,91,115,114,99,93,59,32,100,97,116,97,91,100,115,116,32,93,32,61,32,118,97,108,32,38,32,48,120,102,102,59,32,100,97,116,97,91,100,115,116,43,49,93,32,61,32,40,118,97,108,32,62,62,32,56,41,32,38,32,48,120,102,102,59,32,100,97,116,97,91,100,115,116,43,50,93,32,61,32,40,118,97,108,32,62,62,32,49,54,41,32,38,32,48,120,102,102,59,32,100,97,116,97,91,100,115,116,43,51,93,32,61,32,48,120,102,102,59,32,115,114,99,43,43,59,32,100,115,116,32,43,61,32,52,59,32,125,32,125,32,101,108,115,101,32,123,32,105,102,32,40,83,68,76,50,46,100,97,116,97,51,50,68,97,116,97,32,33,61,61,32,100,97,116,97,41,32,123,32,83,68,76,50,46,100,97,116,97,51,50,32,61,32,110,101,119,32,73,110,116,51,50,65,114,114,97,121,40,100,97,116,97,46,98,117,102,102,101,114,41,59,32,83,68,76,50,46,100,97,116,97,56,32,61,32,110,101,119,32,85,105,110,116,56,65,114,114,97,121,40,100,97,116,97,46,98,117,102,102,101,114,41,59,32,125,32,118,97,114,32,100,97,116,97,51,50,32,61,32,83,68,76,50,46,100,97,116,97,51,50,59,32,110,117,109,32,61,32,100,97,116,97,51,50,46,108,101,110,103,116,104,59,32,100,97,116,97,51,50,46,115,101,116,40,72,69,65,80,51,50,46,115,117,98,97,114,114,97,121,40,115,114,99,44,32,115,114,99,32,43,32,110,117,109,41,41,59,32,118,97,114,32,100,97,116,97,56,32,61,32,83,68,76,50,46,100,97,116,97,56,59,32,118,97,114,32,105,32,61,32,51,59,32,118,97,114,32,106,32,61,32,105,32,43,32,52,42,110,117,109,59,32,105,102,32,40,110,117,109,32,37,32,56,32,61,61,32,48,41,32,123,32,119,104,105,108,101,32,40,105,32,60,32,106,41,32,123,32,100,97,116,97,56,91,105,93,32,61,32,48,120,102,102,59,32,105,32,61,32,105,32,43,32,52,32,124,32,48,59,32,100,97,116,97,56,91,105,93,32,61,32,48,120,102,102,59,32,105,32,61,32,105,32,43,32,52,32,124,32,48,59,32,100,97,116,97,56,91,105,93,32,61,32,48,120,102,102,59,32,105,32,61,32,105,32,43,32,52,32,124,32,48,59,32,100,97,116,97,56,91,105,93,32,61,32,48,120,102,102,59,32,105,32,61,32,105,32,43,32,52,32,124,32,48,59,32,100,97,116,97,56,91,105,93,32,61,32,48,120,102,102,59,32,105,32,61,32,105,32,43,32,52,32,124,32,48,59,32,100,97,116,97,56,91,105,93,32,61,32,48,120,102,102,59,32,105,32,61,32,105,32,43,32,52,32,124,32,48,59,32,100,97,116,97,56,91,105,93,32,61,32,48,120,102,102,59,32,105,32,61,32,105,32,43,32,52,32,124,32,48,59,32,100,97,116,97,56,91,105,93,32,61,32,48,120,102,102,59,32,105,32,61,32,105,32,43,32,52,32,124,32,48,59,32,125,32,125,32,101,108,115,101,32,123,32,119,104,105,108,101,32,40,105,32,60,32,106,41,32,123,32,100,97,116,97,56,91,105,93,32,61,32,48,120,102,102,59,32,105,32,61,32,105,32,43,32,52,32,124,32,48,59,32,125,32,125,32,125,32,83,68,76,50,46,99,116,120,46,112,117,116,73,109,97,103,101,68,97,116,97,40,83,68,76,50,46,105,109,97,103,101,44,32,48,44,32,48,41,59,32,114,101,116,117,114,110,32,48,59,32,125,0,35,99,97,110,118,97,115,0,35,100,111,99,117,109,101,110,116,0,35,119,105,110,100,111,119,0,83,68,76,95,69,77,83,67,82,73,80,84,69,78,95,75,69,89,66,79,65,82,68,95,69,76,69,77,69,78,84,0,123,32,105,102,32,40,116,121,112,101,111,102,32,77,111,100,117,108,101,91,39,115,101,116,87,105,110,100,111,119,84,105,116,108,101,39,93,32,33,61,61,32,39,117,110,100,101,102,105,110,101,100,39,41,32,123,32,77,111,100,117,108,101,91,39,115,101,116,87,105,110,100,111,119,84,105,116,108,101,39,93,40,77,111,100,117,108,101,91,39,80,111,105,110,116,101,114,95,115,116,114,105,110,103,105,102,121,39,93,40,36,48,41,41,59,32,125,32,114,101,116,117,114,110,32,48,59,32,125,0,67,111,117,108,100,32,110,111,116,32,99,114,101,97,116,101,32,71,76,69,83,32,119,105,110,100,111,119,32,115,117,114,102,97,99,101,0,85,110,107,110,111,119,110,32,116,111,117,99,104,32,100,101,118,105,99,101,0,78,111,32,119,105,110,100,111,119,32,104,97,115,32,102,111,99,117,115,0,69,71,76,32,105,109,112,108,101,109,101,110,116,97,116,105,111,110,32,100,111,101,115,32,110,111,116,32,115,117,112,112,111,114,116,32,115,82,71,66,32,115,121,115,116,101,109,32,102,114,97,109,101,98,117,102,102,101,114,115,0,67,111,117,108,100,110,39,116,32,102,105,110,100,32,109,97,116,99,104,105,110,103,32,69,71,76,32,99,111,110,102,105,103,0,79,112,101,110,71,76,32,108,105,98,114,97,114,121,32,97,108,114,101,97,100,121,32,108,111,97,100,101,100,0,123,32,114,101,116,117,114,110,32,115,99,114,101,101,110,46,119,105,100,116,104,59,32,125,0,123,32,114,101,116,117,114,110,32,115,99,114,101,101,110,46,104,101,105,103,104,116,59,32,125,0,100,101,102,97,117,108,116,0,112,111,105,110,116,101,114,0,110,111,116,45,97,108,108,111,119,101,100,0,110,115,45,114,101,115,105,122,101,0,101,119,45,114,101,115,105,122,101,0,110,101,115,119,45,114,101,115,105,122,101,0,110,119,115,101,45,114,101,115,105,122,101,0,112,114,111,103,114,101,115,115,0,99,114,111,115,115,104,97,105,114,0,119,97,105,116,0,116,101,120,116,0,123,32,105,102,32,40,77,111,100,117,108,101,91,39,99,97,110,118,97,115,39,93,41,32,123,32,77,111,100,117,108,101,91,39,99,97,110,118,97,115,39,93,46,115,116,121,108,101,91,39,99,117,114,115,111,114,39,93,32,61,32,77,111,100,117,108,101,91,39,80,111,105,110,116,101,114,95,115,116,114,105,110,103,105,102,121,39,93,40,36,48,41,59,32,125,32,114,101,116,117,114,110,32,48,59,32,125,0,105,102,32,40,77,111,100,117,108,101,91,39,99,97,110,118,97,115,39,93,41,32,123,32,77,111,100,117,108,101,91,39,99,97,110,118,97,115,39,93,46,115,116,121,108,101,91,39,99,117,114,115,111,114,39,93,32,61,32,39,110,111,110,101,39,59,32,125,0,123,32,118,97,114,32,119,32,61,32,36,48,59,32,118,97,114,32,104,32,61,32,36,49,59,32,118,97,114,32,112,105,120,101,108,115,32,61,32,36,50,59,32,118,97,114,32,99,97,110,118,97,115,32,61,32,100,111,99,117,109,101,110,116,46,99,114,101,97,116,101,69,108,101,109,101,110,116,40,34,99,97,110,118,97,115,34,41,59,32,99,97,110,118,97,115,46,119,105,100,116,104,32,61,32,119,59,32,99,97,110,118,97,115,46,104,101,105,103,104,116,32,61,32,104,59,32,118,97,114,32,99,116,120,32,61,32,99,97,110,118,97,115,46,103,101,116,67,111,110,116,101,120,116,40,34,50,100,34,41,59,32,118,97,114,32,105,109,97,103,101,32,61,32,99,116,120,46,99,114,101,97,116,101,73,109,97,103,101,68,97,116,97,40,119,44,32,104,41,59,32,118,97,114,32,100,97,116,97,32,61,32,105,109,97,103,101,46,100,97,116,97,59,32,118,97,114,32,115,114,99,32,61,32,112,105,120,101,108,115,32,62,62,32,50,59,32,118,97,114,32,100,115,116,32,61,32,48,59,32,118,97,114,32,110,117,109,59,32,105,102,32,40,116,121,112,101,111,102,32,67,97,110,118,97,115,80,105,120,101,108,65,114,114,97,121,32,33,61,61,32,39,117,110,100,101,102,105,110,101,100,39,32,38,38,32,100,97,116,97,32,105,110,115,116,97,110,99,101,111,102,32,67,97,110,118,97,115,80,105,120,101,108,65,114,114,97,121,41,32,123,32,110,117,109,32,61,32,100,97,116,97,46,108,101,110,103,116,104,59,32,119,104,105,108,101,32,40,100,115,116,32,60,32,110,117,109,41,32,123,32,118,97,114,32,118,97,108,32,61,32,72,69,65,80,51,50,91,115,114,99,93,59,32,100,97,116,97,91,100,115,116,32,93,32,61,32,118,97,108,32,38,32,48,120,102,102,59,32,100,97,116,97,91,100,115,116,43,49,93,32,61,32,40,118,97,108,32,62,62,32,56,41,32,38,32,48,120,102,102,59,32,100,97,116,97,91,100,115,116,43,50,93,32,61,32,40,118,97,108,32,62,62,32,49,54,41,32,38,32,48,120,102,102,59,32,100,97,116,97,91,100,115,116,43,51,93,32,61,32,40,118,97,108,32,62,62,32,50,52,41,32,38,32,48,120,102,102,59,32,115,114,99,43,43,59,32,100,115,116,32,43,61,32,52,59,32,125,32,125,32,101,108,115,101,32,123,32,118,97,114,32,100,97,116,97,51,50,32,61,32,110,101,119,32,73,110,116,51,50,65,114,114,97,121,40,100,97,116,97,46,98,117,102,102,101,114,41,59,32,110,117,109,32,61,32,100,97,116,97,51,50,46,108,101,110,103,116,104,59,32,100,97,116,97,51,50,46,115,101,116,40,72,69,65,80,51,50,46,115,117,98,97,114,114,97,121,40,115,114,99,44,32,115,114,99,32,43,32,110,117,109,41,41,59,32,125,32,99,116,120,46,112,117,116,73,109,97,103,101,68,97,116,97,40,105,109,97,103,101,44,32,48,44,32,48,41,59,32,118,97,114,32,117,114,108,32,61,32,34,117,114,108,40,34,32,43,32,99,97,110,118,97,115,46,116,111,68,97,116,97,85,82,76,40,41,32,43,32,34,41,44,32,97,117,116,111,34,59,32,118,97,114,32,117,114,108,66,117,102,32,61,32,95,109,97,108,108,111,99,40,117,114,108,46,108,101,110,103,116,104,32,43,32,49,41,59,32,115,116,114,105,110,103,84,111,85,84,70,56,40,117,114,108,44,32,117,114,108,66,117,102,44,32,117,114,108,46,108,101,110,103,116,104,32,43,32,49,41,59,32,114,101,116,117,114,110,32,117,114,108,66,117,102,59,32,125,0,48,49,50,51,52,53,54,55,56,57,65,66,67,68,69,70,71,72,73,74,75,76,77,78,79,80,81,82,83,84,85,86,87,88,89,90,83,68,76,32,101,109,115,99,114,105,112,116,101,110,32,97,117,100,105,111,32,100,114,105,118,101,114,0,123,32,105,102,32,40,116,121,112,101,111,102,40,65,117,100,105,111,67,111,110,116,101,120,116,41,32,33,61,61,32,39,117,110,100,101,102,105,110,101,100,39,41,32,123,32,114,101,116,117,114,110,32,49,59,32,125,32,101,108,115,101,32,105,102,32,40,116,121,112,101,111,102,40,119,101,98,107,105,116,65,117,100,105,111,67,111,110,116,101,120,116,41,32,33,61,61,32,39,117,110,100,101,102,105,110,101,100,39,41,32,123,32,114,101,116,117,114,110,32,49,59,32,125,32,114,101,116,117,114,110,32,48,59,32,125,0,78,111,32,97,117,100,105,111,32,99,111,110,116,101,120,116,32,97,118,97,105,108,97,98,108,101,0,123,32,105,102,32,40,40,116,121,112,101,111,102,40,110,97,118,105,103,97,116,111,114,46,109,101,100,105,97,68,101,118,105,99,101,115,41,32,33,61,61,32,39,117,110,100,101,102,105,110,101,100,39,41,32,38,38,32,40,116,121,112,101,111,102,40,110,97,118,105,103,97,116,111,114,46,109,101,100,105,97,68,101,118,105,99,101,115,46,103,101,116,85,115,101,114,77,101,100,105,97,41,32,33,61,61,32,39,117,110,100,101,102,105,110,101,100,39,41,41,32,123,32,114,101,116,117,114,110,32,49,59,32,125,32,101,108,115,101,32,105,102,32,40,116,121,112,101,111,102,40,110,97,118,105,103,97,116,111,114,46,119,101,98,107,105,116,71,101,116,85,115,101,114,77,101,100,105,97,41,32,33,61,61,32,39,117,110,100,101,102,105,110,101,100,39,41,32,123,32,114,101,116,117,114,110,32,49,59,32,125,32,114,101,116,117,114,110,32,48,59,32,125,0,123,32,105,102,32,40,36,48,41,32,123,32,105,102,32,40,83,68,76,50,46,99,97,112,116,117,114,101,46,115,105,108,101,110,99,101,84,105,109,101,114,32,33,61,61,32,117,110,100,101,102,105,110,101,100,41,32,123,32,99,108,101,97,114,84,105,109,101,111,117,116,40,83,68,76,50,46,99,97,112,116,117,114,101,46,115,105,108,101,110,99,101,84,105,109,101,114,41,59,32,125,32,105,102,32,40,83,68,76,50,46,99,97,112,116,117,114,101,46,115,116,114,101,97,109,32,33,61,61,32,117,110,100,101,102,105,110,101,100,41,32,123,32,118,97,114,32,116,114,97,99,107,115,32,61,32,83,68,76,50,46,99,97,112,116,117,114,101,46,115,116,114,101,97,109,46,103,101,116,65,117,100,105,111,84,114,97,99,107,115,40,41,59,32,102,111,114,32,40,118,97,114,32,105,32,61,32,48,59,32,105,32,60,32,116,114,97,99,107,115,46,108,101,110,103,116,104,59,32,105,43,43,41,32,123,32,83,68,76,50,46,99,97,112,116,117,114,101,46,115,116,114,101,97,109,46,114,101,109,111,118,101,84,114,97,99,107,40,116,114,97,99,107,115,91,105,93,41,59,32,125,32,83,68,76,50,46,99,97,112,116,117,114,101,46,115,116,114,101,97,109,32,61,32,117,110,100,101,102,105,110,101,100,59,32,125,32,105,102,32,40,83,68,76,50,46,99,97,112,116,117,114,101,46,115,99,114,105,112,116,80,114,111,99,101,115,115,111,114,78,111,100,101,32,33,61,61,32,117,110,100,101,102,105,110,101,100,41,32,123,32,83,68,76,50,46,99,97,112,116,117,114,101,46,115,99,114,105,112,116,80,114,111,99,101,115,115,111,114,78,111,100,101,46,111,110,97,117,100,105,111,112,114,111,99,101,115,115,32,61,32,102,117,110,99,116,105,111,110,40,97,117,100,105,111,80,114,111,99,101,115,115,105,110,103,69,118,101,110,116,41,32,123,125,59,32,83,68,76,50,46,99,97,112,116,117,114,101,46,115,99,114,105,112,116,80,114,111,99,101,115,115,111,114,78,111,100,101,46,100,105,115,99,111,110,110,101,99,116,40,41,59,32,83,68,76,50,46,99,97,112,116,117,114,101,46,115,99,114,105,112,116,80,114,111,99,101,115,115,111,114,78,111,100,101,32,61,32,117,110,100,101,102,105,110,101,100,59,32,125,32,105,102,32,40,83,68,76,50,46,99,97,112,116,117,114,101,46,109,101,100,105,97,83,116,114,101,97,109,78,111,100,101,32,33,61,61,32,117,110,100,101,102,105,110,101,100,41,32,123,32,83,68,76,50,46,99,97,112,116,117,114,101,46,109,101,100,105,97,83,116,114,101,97,109,78,111,100,101,46,100,105,115,99,111,110,110,101,99,116,40,41,59,32,83,68,76,50,46,99,97,112,116,117,114,101,46,109,101,100,105,97,83,116,114,101,97,109,78,111,100,101,32,61,32,117,110,100,101,102,105,110,101,100,59,32,125,32,105,102,32,40,83,68,76,50,46,99,97,112,116,117,114,101,46,115,105,108,101,110,99,101,66,117,102,102,101,114,32,33,61,61,32,117,110,100,101,102,105,110,101,100,41,32,123,32,83,68,76,50,46,99,97,112,116,117,114,101,46,115,105,108,101,110,99,101,66,117,102,102,101,114,32,61,32,117,110,100,101,102,105,110,101,100,32,125,32,83,68,76,50,46,99,97,112,116,117,114,101,32,61,32,117,110,100,101,102,105,110,101,100,59,32,125,32,101,108,115,101,32,123,32,105,102,32,40,83,68,76,50,46,97,117,100,105,111,46,115,99,114,105,112,116,80,114,111,99,101,115,115,111,114,78,111,100,101,32,33,61,32,117,110,100,101,102,105,110,101,100,41,32,123,32,83,68,76,50,46,97,117,100,105,111,46,115,99,114,105,112,116,80,114,111,99,101,115,115,111,114,78,111,100,101,46,100,105,115,99,111,110,110,101,99,116,40,41,59,32,83,68,76,50,46,97,117,100,105,111,46,115,99,114,105,112,116,80,114,111,99,101,115,115,111,114,78,111,100,101,32,61,32,117,110,100,101,102,105,110,101,100,59,32,125,32,83,68,76,50,46,97,117,100,105,111,32,61,32,117,110,100,101,102,105,110,101,100,59,32,125,32,105,102,32,40,40,83,68,76,50,46,97,117,100,105,111,67,111,110,116,101,120,116,32,33,61,61,32,117,110,100,101,102,105,110,101,100,41,32,38,38,32,40,83,68,76,50,46,97,117,100,105,111,32,61,61,61,32,117,110,100,101,102,105,110,101,100,41,32,38,38,32,40,83,68,76,50,46,99,97,112,116,117,114,101,32,61,61,61,32,117,110,100,101,102,105,110,101,100,41,41,32,123,32,83,68,76,50,46,97,117,100,105,111,67,111,110,116,101,120,116,46,99,108,111,115,101,40,41,59,32,83,68,76,50,46,97,117,100,105,111,67,111,110,116,101,120,116,32,61,32,117,110,100,101,102,105,110,101,100,59,32,125,32,125,0,123,32,105,102,40,116,121,112,101,111,102,40,83,68,76,50,41,32,61,61,61,32,39,117,110,100,101,102,105,110,101,100,39,41,32,123,32,83,68,76,50,32,61,32,123,125,59,32,125,32,105,102,32,40,33,36,48,41,32,123,32,83,68,76,50,46,97,117,100,105,111,32,61,32,123,125,59,32,125,32,101,108,115,101,32,123,32,83,68,76,50,46,99,97,112,116,117,114,101,32,61,32,123,125,59,32,125,32,105,102,32,40,33,83,68,76,50,46,97,117,100,105,111,67,111,110,116,101,120,116,41,32,123,32,105,102,32,40,116,121,112,101,111,102,40,65,117,100,105,111,67,111,110,116,101,120,116,41,32,33,61,61,32,39,117,110,100,101,102,105,110,101,100,39,41,32,123,32,83,68,76,50,46,97,117,100,105,111,67,111,110,116,101,120,116,32,61,32,110,101,119,32,65,117,100,105,111,67,111,110,116,101,120,116,40,41,59,32,125,32,101,108,115,101,32,105,102,32,40,116,121,112,101,111,102,40,119,101,98,107,105,116,65,117,100,105,111,67,111,110,116,101,120,116,41,32,33,61,61,32,39,117,110,100,101,102,105,110,101,100,39,41,32,123,32,83,68,76,50,46,97,117,100,105,111,67,111,110,116,101,120,116,32,61,32,110,101,119,32,119,101,98,107,105,116,65,117,100,105,111,67,111,110,116,101,120,116,40,41,59,32,125,32,125,32,114,101,116,117,114,110,32,83,68,76,50,46,97,117,100,105,111,67,111,110,116,101,120,116,32,61,61,61,32,117,110,100,101,102,105,110,101,100,32,63,32,45,49,32,58,32,48,59,32,125,0,87,101,98,32,65,117,100,105,111,32,65,80,73,32,105,115,32,110,111,116,32,97,118,97,105,108,97,98,108,101,33,0,78,111,32,99,111,109,112,97,116,105,98,108,101,32,97,117,100,105,111,32,102,111,114,109,97,116,33,0,123,32,114,101,116,117,114,110,32,83,68,76,50,46,97,117,100,105,111,67,111,110,116,101,120,116,46,115,97,109,112,108,101,82,97,116,101,59,32,125,0,123,32,118,97,114,32,104,97,118,101,95,109,105,99,114,111,112,104,111,110,101,32,61,32,102,117,110,99,116,105,111,110,40,115,116,114,101,97,109,41,32,123,32,105,102,32,40,83,68,76,50,46,99,97,112,116,117,114,101,46,115,105,108,101,110,99,101,84,105,109,101,114,32,33,61,61,32,117,110,100,101,102,105,110,101,100,41,32,123,32,99,108,101,97,114,84,105,109,101,111,117,116,40,83,68,76,50,46,99,97,112,116,117,114,101,46,115,105,108,101,110,99,101,84,105,109,101,114,41,59,32,83,68,76,50,46,99,97,112,116,117,114,101,46,115,105,108,101,110,99,101,84,105,109,101,114,32,61,32,117,110,100,101,102,105,110,101,100,59,32,125,32,83,68,76,50,46,99,97,112,116,117,114,101,46,109,101,100,105,97,83,116,114,101,97,109,78,111,100,101,32,61,32,83,68,76,50,46,97,117,100,105,111,67,111,110,116,101,120,116,46,99,114,101,97,116,101,77,101,100,105,97,83,116,114,101,97,109,83,111,117,114,99,101,40,115,116,114,101,97,109,41,59,32,83,68,76,50,46,99,97,112,116,117,114,101,46,115,99,114,105,112,116,80,114,111,99,101,115,115,111,114,78,111,100,101,32,61,32,83,68,76,50,46,97,117,100,105,111,67,111,110,116,101,120,116,46,99,114,101,97,116,101,83,99,114,105,112,116,80,114,111,99,101,115,115,111,114,40,36,49,44,32,36,48,44,32,49,41,59,32,83,68,76,50,46,99,97,112,116,117,114,101,46,115,99,114,105,112,116,80,114,111,99,101,115,115,111,114,78,111,100,101,46,111,110,97,117,100,105,111,112,114,111,99,101,115,115,32,61,32,102,117,110,99,116,105,111,110,40,97,117,100,105,111,80,114,111,99,101,115,115,105,110,103,69,118,101,110,116,41,32,123,32,105,102,32,40,40,83,68,76,50,32,61,61,61,32,117,110,100,101,102,105,110,101,100,41,32,124,124,32,40,83,68,76,50,46,99,97,112,116,117,114,101,32,61,61,61,32,117,110,100,101,102,105,110,101,100,41,41,32,123,32,114,101,116,117,114,110,59,32,125,32,97,117,100,105,111,80,114,111,99,101,115,115,105,110,103,69,118,101,110,116,46,111,117,116,112,117,116,66,117,102,102,101,114,46,103,101,116,67,104,97,110,110,101,108,68,97,116,97,40,48,41,46,102,105,108,108,40,48,46,48,41,59,32,83,68,76,50,46,99,97,112,116,117,114,101,46,99,117,114,114,101,110,116,67,97,112,116,117,114,101,66,117,102,102,101,114,32,61,32,97,117,100,105,111,80,114,111,99,101,115,115,105,110,103,69,118,101,110,116,46,105,110,112,117,116,66,117,102,102,101,114,59,32,82,117,110,116,105,109,101,46,100,121,110,67,97,108,108,40,39,118,105,39,44,32,36,50,44,32,91,36,51,93,41,59,32,125,59,32,83,68,76,50,46,99,97,112,116,117,114,101,46,109,101,100,105,97,83,116,114,101,97,109,78,111,100,101,46,99,111,110,110,101,99,116,40,83,68,76,50,46,99,97,112,116,117,114,101,46,115,99,114,105,112,116,80,114,111,99,101,115,115,111,114,78,111,100,101,41,59,32,83,68,76,50,46,99,97,112,116,117,114,101,46,115,99,114,105,112,116,80,114,111,99,101,115,115,111,114,78,111,100,101,46,99,111,110,110,101,99,116,40,83,68,76,50,46,97,117,100,105,111,67,111,110,116,101,120,116,46,100,101,115,116,105,110,97,116,105,111,110,41,59,32,83,68,76,50,46,99,97,112,116,117,114,101,46,115,116,114,101,97,109,32,61,32,115,116,114,101,97,109,59,32,125,59,32,118,97,114,32,110,111,95,109,105,99,114,111,112,104,111,110,101,32,61,32,102,117,110,99,116,105,111,110,40,101,114,114,111,114,41,32,123,32,125,59,32,83,68,76,50,46,99,97,112,116,117,114,101,46,115,105,108,101,110,99,101,66,117,102,102,101,114,32,61,32,83,68,76,50,46,97,117,100,105,111,67,111,110,116,101,120,116,46,99,114,101,97,116,101,66,117,102,102,101,114,40,36,48,44,32,36,49,44,32,83,68,76,50,46,97,117,100,105,111,67,111,110,116,101,120,116,46,115,97,109,112,108,101,82,97,116,101,41,59,32,83,68,76,50,46,99,97,112,116,117,114,101,46,115,105,108,101,110,99,101,66,117,102,102,101,114,46,103,101,116,67,104,97,110,110,101,108,68,97,116,97,40,48,41,46,102,105,108,108,40,48,46,48,41,59,32,118,97,114,32,115,105,108,101,110,99,101,95,99,97,108,108,98,97,99,107,32,61,32,102,117,110,99,116,105,111,110,40,41,32,123,32,83,68,76,50,46,99,97,112,116,117,114,101,46,99,117,114,114,101,110,116,67,97,112,116,117,114,101,66,117,102,102,101,114,32,61,32,83,68,76,50,46,99,97,112,116,117,114,101,46,115,105,108,101,110,99,101,66,117,102,102,101,114,59,32,82,117,110,116,105,109,101,46,100,121,110,67,97,108,108,40,39,118,105,39,44,32,36,50,44,32,91,36,51,93,41,59,32,125,59,32,83,68,76,50,46,99,97,112,116,117,114,101,46,115,105,108,101,110,99,101,84,105,109,101,114,32,61,32,115,101,116,84,105,109,101,111,117,116,40,115,105,108,101,110,99,101,95,99,97,108,108,98,97,99,107,44,32,40,36,49,32,47,32,83,68,76,50,46,97,117,100,105,111,67,111,110,116,101,120,116,46,115,97,109,112,108,101,82,97,116,101,41,32,42,32,49,48,48,48,41,59,32,105,102,32,40,40,110,97,118,105,103,97,116,111,114,46,109,101,100,105,97,68,101,118,105,99,101,115,32,33,61,61,32,117,110,100,101,102,105,110,101,100,41,32,38,38,32,40,110,97,118,105,103,97,116,111,114,46,109,101,100,105,97,68,101,118,105,99,101,115,46,103,101,116,85,115,101,114,77,101,100,105,97,32,33,61,61,32,117,110,100,101,102,105,110,101,100,41,41,32,123,32,110,97,118,105,103,97,116,111,114,46,109,101,100,105,97,68,101,118,105,99,101,115,46,103,101,116,85,115,101,114,77,101,100,105,97,40,123,32,97,117,100,105,111,58,32,116,114,117,101,44,32,118,105,100,101,111,58,32,102,97,108,115,101,32,125,41,46,116,104,101,110,40,104,97,118,101,95,109,105,99,114,111,112,104,111,110,101,41,46,99,97,116,99,104,40,110,111,95,109,105,99,114,111,112,104,111,110,101,41,59,32,125,32,101,108,115,101,32,105,102,32,40,110,97,118,105,103,97,116,111,114,46,119,101,98,107,105,116,71,101,116,85,115,101,114,77,101,100,105,97,32,33,61,61,32,117,110,100,101,102,105,110,101,100,41,32,123,32,110,97,118,105,103,97,116,111,114,46,119,101,98,107,105,116,71,101,116,85,115,101,114,77,101,100,105,97,40,123,32,97,117,100,105,111,58,32,116,114,117,101,44,32,118,105,100,101,111,58,32,102,97,108,115,101,32,125,44,32,104,97,118,101,95,109,105,99,114,111,112,104,111,110,101,44,32,110,111,95,109,105,99,114,111,112,104,111,110,101,41,59,32,125,32,125,0,123,32,83,68,76,50,46,97,117,100,105,111,46,115,99,114,105,112,116,80,114,111,99,101,115,115,111,114,78,111,100,101,32,61,32,83,68,76,50,46,97,117,100,105,111,67,111,110,116,101,120,116,91,39,99,114,101,97,116,101,83,99,114,105,112,116,80,114,111,99,101,115,115,111,114,39,93,40,36,49,44,32,48,44,32,36,48,41,59,32,83,68,76,50,46,97,117,100,105,111,46,115,99,114,105,112,116,80,114,111,99,101,115,115,111,114,78,111,100,101,91,39,111,110,97,117,100,105,111,112,114,111,99,101,115,115,39,93,32,61,32,102,117,110,99,116,105,111,110,32,40,101,41,32,123,32,105,102,32,40,40,83,68,76,50,32,61,61,61,32,117,110,100,101,102,105,110,101,100,41,32,124,124,32,40,83,68,76,50,46,97,117,100,105,111,32,61,61,61,32,117,110,100,101,102,105,110,101,100,41,41,32,123,32,114,101,116,117,114,110,59,32,125,32,83,68,76,50,46,97,117,100,105,111,46,99,117,114,114,101,110,116,79,117,116,112,117,116,66,117,102,102,101,114,32,61,32,101,91,39,111,117,116,112,117,116,66,117,102,102,101,114,39,93,59,32,82,117,110,116,105,109,101,46,100,121,110,67,97,108,108,40,39,118,105,39,44,32,36,50,44,32,91,36,51,93,41,59,32,125,59,32,83,68,76,50,46,97,117,100,105,111,46,115,99,114,105,112,116,80,114,111,99,101,115,115,111,114,78,111,100,101,91,39,99,111,110,110,101,99,116,39,93,40,83,68,76,50,46,97,117,100,105,111,67,111,110,116,101,120,116,91,39,100,101,115,116,105,110,97,116,105,111,110,39,93,41,59,32,125,0,123,32,118,97,114,32,110,117,109,67,104,97,110,110,101,108,115,32,61,32,83,68,76,50,46,97,117,100,105,111,46,99,117,114,114,101,110,116,79,117,116,112,117,116,66,117,102,102,101,114,91,39,110,117,109,98,101,114,79,102,67,104,97,110,110,101,108,115,39,93,59,32,102,111,114,32,40,118,97,114,32,99,32,61,32,48,59,32,99,32,60,32,110,117,109,67,104,97,110,110,101,108,115,59,32,43,43,99,41,32,123,32,118,97,114,32,99,104,97,110,110,101,108,68,97,116,97,32,61,32,83,68,76,50,46,97,117,100,105,111,46,99,117,114,114,101,110,116,79,117,116,112,117,116,66,117,102,102,101,114,91,39,103,101,116,67,104,97,110,110,101,108,68,97,116,97,39,93,40,99,41,59,32,105,102,32,40,99,104,97,110,110,101,108,68,97,116,97,46,108,101,110,103,116,104,32,33,61,32,36,49,41,32,123,32,116,104,114,111,119,32,39,87,101,98,32,65,117,100,105,111,32,111,117,116,112,117,116,32,98,117,102,102,101,114,32,108,101,110,103,116,104,32,109,105,115,109,97,116,99,104,33,32,68,101,115,116,105,110,97,116,105,111,110,32,115,105,122,101,58,32,39,32,43,32,99,104,97,110,110,101,108,68,97,116,97,46,108,101,110,103,116,104,32,43,32,39,32,115,97,109,112,108,101,115,32,118,115,32,101,120,112,101,99,116,101,100,32,39,32,43,32,36,49,32,43,32,39,32,115,97,109,112,108,101,115,33,39,59,32,125,32,102,111,114,32,40,118,97,114,32,106,32,61,32,48,59,32,106,32,60,32,36,49,59,32,43,43,106,41,32,123,32,99,104,97,110,110,101,108,68,97,116,97,91,106,93,32,61,32,72,69,65,80,70,51,50,91,36,48,32,43,32,40,40,106,42,110,117,109,67,104,97,110,110,101,108,115,32,43,32,99,41,32,60,60,32,50,41,32,62,62,32,50,93,59,32,125,32,125,32,125,0,78,111,32,98,117,102,102,101,114,32,97,108,108,111,99,97,116,101,100,32,102,111,114,32,99,111,110,118,101,114,115,105,111,110,0,123,32,118,97,114,32,110,117,109,67,104,97,110,110,101,108,115,32,61,32,83,68,76,50,46,99,97,112,116,117,114,101,46,99,117,114,114,101,110,116,67,97,112,116,117,114,101,66,117,102,102,101,114,46,110,117,109,98,101,114,79,102,67,104,97,110,110,101,108,115,59,32,105,102,32,40,110,117,109,67,104,97,110,110,101,108,115,32,61,61,32,49,41,32,123,32,118,97,114,32,99,104,97,110,110,101,108,68,97,116,97,32,61,32,83,68,76,50,46,99,97,112,116,117,114,101,46,99,117,114,114,101,110,116,67,97,112,116,117,114,101,66,117,102,102,101,114,46,103,101,116,67,104,97,110,110,101,108,68,97,116,97,40,48,41,59,32,105,102,32,40,99,104,97,110,110,101,108,68,97,116,97,46,108,101,110,103,116,104,32,33,61,32,36,49,41,32,123,32,116,104,114,111,119,32,39,87,101,98,32,65,117,100,105,111,32,99,97,112,116,117,114,101,32,98,117,102,102,101,114,32,108,101,110,103,116,104,32,109,105,115,109,97,116,99,104,33,32,68,101,115,116,105,110,97,116,105,111,110,32,115,105,122,101,58,32,39,32,43,32,99,104,97,110,110,101,108,68,97,116,97,46,108,101,110,103,116,104,32,43,32,39,32,115,97,109,112,108,101,115,32,118,115,32,101,120,112,101,99,116,101,100,32,39,32,43,32,36,49,32,43,32,39,32,115,97,109,112,108,101,115,33,39,59,32,125,32,102,111,114,32,40,118,97,114,32,106,32,61,32,48,59,32,106,32,60,32,36,49,59,32,43,43,106,41,32,123,32,115,101,116,86,97,108,117,101,40,36,48,32,43,32,40,106,32,42,32,52,41,44,32,99,104,97,110,110,101,108,68,97,116,97,91,106,93,44,32,39,102,108,111,97,116,39,41,59,32,125,32,125,32,101,108,115,101,32,123,32,102,111,114,32,40,118,97,114,32,99,32,61,32,48,59,32,99,32,60,32,110,117,109,67,104,97,110,110,101,108,115,59,32,43,43,99,41,32,123,32,118,97,114,32,99,104,97,110,110,101,108,68,97,116,97,32,61,32,83,68,76,50,46,99,97,112,116,117,114,101,46,99,117,114,114,101,110,116,67,97,112,116,117,114,101,66,117,102,102,101,114,46,103,101,116,67,104,97,110,110,101,108,68,97,116,97,40,99,41,59,32,105,102,32,40,99,104,97,110,110,101,108,68,97,116,97,46,108,101,110,103,116,104,32,33,61,32,36,49,41,32,123,32,116,104,114,111,119,32,39,87,101,98,32,65,117,100,105,111,32,99,97,112,116,117,114,101,32,98,117,102,102,101,114,32,108,101,110,103,116,104,32,109,105,115,109,97,116,99,104,33,32,68,101,115,116,105,110,97,116,105,111,110,32,115,105,122,101,58,32,39,32,43,32,99,104,97,110,110,101,108,68,97,116,97,46,108,101,110,103,116,104,32,43,32,39,32,115,97,109,112,108,101,115,32,118,115,32,101,120,112,101,99,116,101,100,32,39,32,43,32,36,49,32,43,32,39,32,115,97,109,112,108,101,115,33,39,59,32,125,32,102,111,114,32,40,118,97,114,32,106,32,61,32,48,59,32,106,32,60,32,36,49,59,32,43,43,106,41,32,123,32,115,101,116,86,97,108,117,101,40,36,48,32,43,32,40,40,40,106,32,42,32,110,117,109,67,104,97,110,110,101,108,115,41,32,43,32,99,41,32,42,32,52,41,44,32,99,104,97,110,110,101,108,68,97,116,97,91,106,93,44,32,39,102,108,111,97,116,39,41,59,32,125,32,125,32,125,32,125,0,83,68,76,32,100,117,109,109,121,32,118,105,100,101,111,32,100,114,105,118,101,114,0,95,83,68,76,95,68,117,109,109,121,83,117,114,102,97,99,101,0,67,111,117,108,100,110,39,116,32,102,105,110,100,32,100,117,109,109,121,32,115,117,114,102,97,99,101,32,102,111,114,32,119,105,110,100,111,119,0,83,68,76,95,86,73,68,69,79,95,68,85,77,77,89,95,83,65,86,69,95,70,82,65,77,69,83,0,83,68,76,95,119,105,110,100,111,119,37,100,45,37,56,46,56,100,46,98,109,112,0,37,100,32,98,112,112,32,66,77,80,32,102,105,108,101,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,0,67,111,117,108,100,110,39,116,32,99,111,110,118,101,114,116,32,105,109,97,103,101,32,116,111,32,37,100,32,98,112,112,0,83,68,76,95,66,77,80,95,83,65,86,69,95,76,69,71,65,67,89,95,70,79,82,77,65,84,0,83,68,76,95,82,87,70,114,111,109,70,105,108,101,40,41,58,32,78,111,32,102,105,108,101,32,111,114,32,110,111,32,109,111,100,101,32,115,112,101,99,105,102,105,101,100,0,67,111,117,108,100,110,39,116,32,111,112,101,110,32,37,115,0,100,105,115,107,0,100,105,114,101,99,116,45,116,111,45,100,105,115,107,32,97,117,100,105,111,0,115,100,108,97,117,100,105,111,45,105,110,46,114,97,119,0,115,100,108,97,117,100,105,111,46,114,97,119,0,83,68,76,95,68,73,83,75,65,85,68,73,79,70,73,76,69,73,78,0,83,68,76,95,68,73,83,75,65,85,68,73,79,70,73,76,69,0,83,68,76,95,68,73,83,75,65,85,68,73,79,68,69,76,65,89,0,114,98,0,119,98,0,82,101,97,100,105,110,103,32,102,114,111,109,0,87,114,105,116,105,110,103,32,116,111,0,87,65,82,78,73,78,71,58,32,89,111,117,32,97,114,101,32,117,115,105,110,103,32,116,104,101,32,83,68,76,32,100,105,115,107,32,105,47,111,32,97,117,100,105,111,32,100,114,105,118,101,114,33,10,32,37,115,32,102,105,108,101,32,91,37,115,93,46,10,0,100,117,109,109,121,0,83,68,76,32,100,117,109,109,121,32,97,117,100,105,111,32,100,114,105,118,101,114,0,83,68,76,32,110,111,116,32,98,117,105,108,116,32,119,105,116,104,32,104,97,112,116,105,99,32,40,102,111,114,99,101,32,102,101,101,100,98,97,99,107,41,32,115,117,112,112,111,114,116,0,101,109,115,99,114,105,112,116,101,110,44,83,116,97,110,100,97,114,100,32,71,97,109,101,112,97,100,44,97,58,98,48,44,98,58,98,49,44,98,97,99,107,58,98,56,44,100,112,100,111,119,110,58,98,49,51,44,100,112,108,101,102,116,58,98,49,52,44,100,112,114,105,103,104,116,58,98,49,53,44,100,112,117,112,58,98,49,50,44,103,117,105,100,101,58,98,49,54,44,108,101,102,116,115,104,111,117,108,100,101,114,58,98,52,44,108,101,102,116,115,116,105,99,107,58,98,49,48,44,108,101,102,116,116,114,105,103,103,101,114,58,98,54,44,108,101,102,116,120,58,97,48,44,108,101,102,116,121,58,97,49,44,114,105,103,104,116,115,104,111,117,108,100,101,114,58,98,53,44,114,105,103,104,116,115,116,105,99,107,58,98,49,49,44,114,105,103,104,116,116,114,105,103,103,101,114,58,98,55,44,114,105,103,104,116,120,58,97,50,44,114,105,103,104,116,121,58,97,51,44,115,116,97,114,116,58,98,57,44,120,58,98,50,44,121,58,98,51,44,0,83,68,76,95,71,65,77,69,67,79,78,84,82,79,76,76,69,82,67,79,78,70,73,71,0,88,98,111,120,0,88,45,66,111,120,0,84,104,101,114,101,32,97,114,101,32,37,100,32,106,111,121,115,116,105,99,107,115,32,97,118,97,105,108,97,98,108,101,0,83,68,76,95,71,97,109,101,67,111,110,116,114,111,108,108,101,114,69,118,101,110,116,87,97,116,99,104,101,114,58,32,65,120,105,115,32,105,110,100,101,120,32,37,100,32,116,111,111,32,108,97,114,103,101,44,32,105,103,110,111,114,105,110,103,32,109,111,116,105,111,110,0,83,68,76,95,71,97,109,101,67,111,110,116,114,111,108,108,101,114,69,118,101,110,116,87,97,116,99,104,101,114,58,32,66,117,116,116,111,110,32,105,110,100,101,120,32,37,100,32,116,111,111,32,108,97,114,103,101,44,32,105,103,110,111,114,105,110,103,32,117,112,100,97,116,101,0,109,97,112,112,105,110,103,83,116,114,105,110,103,0,67,111,117,108,100,110,39,116,32,112,97,114,115,101,32,71,85,73,68,32,102,114,111,109,32,37,115,0,120,105,110,112,117,116,0,101,109,115,99,114,105,112,116,101,110,0,67,111,117,108,100,110,39,116,32,112,97,114,115,101,32,110,97,109,101,32,102,114,111,109,32,37,115,0,67,111,117,108,100,110,39,116,32,112,97,114,115,101,32,37,115,0,66,117,116,116,111,110,32,110,97,109,101,32,116,111,111,32,108,97,114,103,101,58,32,37,115,0,74,111,121,115,116,105,99,107,32,98,117,116,116,111,110,32,110,97,109,101,32,116,111,111,32,108,97,114,103,101,58,32,37,115,0,65,120,105,115,32,105,110,100,101,120,32,116,111,111,32,108,97,114,103,101,58,32,37,100,0,66,117,116,116,111,110,32,105,110,100,101,120,32,116,111,111,32,108,97,114,103,101,58,32,37,100,0,72,97,116,32,105,110,100,101,120,32,116,111,111,32,108,97,114,103,101,58,32,37,100,0,108,101,102,116,120,0,108,101,102,116,121,0,114,105,103,104,116,120,0,114,105,103,104,116,121,0,108,101,102,116,116,114,105,103,103,101,114,0,114,105,103,104,116,116,114,105,103,103,101,114,0,120,0,121,0,98,97,99,107,0,103,117,105,100,101,0,115,116,97,114,116,0,108,101,102,116,115,116,105,99,107,0,114,105,103,104,116,115,116,105,99,107,0,108,101,102,116,115,104,111,117,108,100,101,114,0,114,105,103,104,116,115,104,111,117,108,100,101,114,0,100,112,117,112,0,100,112,100,111,119,110,0,100,112,108,101,102,116,0,100,112,114,105,103,104,116,0,83,68,76,95,74,79,89,83,84,73,67,75,95,65,76,76,79,87,95,66,65,67,75,71,82,79,85,78,68,95,69,86,69,78,84,83,0,67,111,117,108,100,32,110,111,116,32,115,101,116,32,103,97,109,101,112,97,100,32,100,105,115,99,111,110,110,101,99,116,32,99,97,108,108,98,97,99,107,0,67,111,117,108,100,32,110,111,116,32,115,101,116,32,103,97,109,101,112,97,100,32,99,111,110,110,101,99,116,32,99,97,108,108,98,97,99,107,0,71,97,109,101,112,97,100,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,0,110,97,109,101,0,99,97,108,108,98,97,99,107,0,83,68,76,95,65,85,68,73,79,68,82,73,86,69,82,0,65,117,100,105,111,32,116,97,114,103,101,116,32,39,37,115,39,32,110,111,116,32,97,118,97,105,108,97,98,108,101,0,78,111,32,97,118,97,105,108,97,98,108,101,32,97,117,100,105,111,32,100,101,118,105,99,101,0,83,121,115,116,101,109,32,97,117,100,105,111,32,111,117,116,112,117,116,32,100,101,118,105,99,101,0,83,121,115,116,101,109,32,97,117,100,105,111,32,99,97,112,116,117,114,101,32,100,101,118,105,99,101,0,83,68,76,32,110,111,116,32,98,117,105,108,116,32,119,105,116,104,32,116,104,114,101,97,100,32,115,117,112,112,111,114,116,0,83,68,76,95,86,73,68,69,79,68,82,73,86,69,82,0,37,115,32,110,111,116,32,97,118,97,105,108,97,98,108,101,0,78,111,32,97,118,97,105,108,97,98,108,101,32,118,105,100,101,111,32,100,101,118,105,99,101,0,84,104,101,32,118,105,100,101,111,32,100,114,105,118,101,114,32,100,105,100,32,110,111,116,32,97,100,100,32,97,110,121,32,100,105,115,112,108,97,121,115,0,115,111,102,116,119,97,114,101,0,83,68,76,95,70,82,65,77,69,66,85,70,70,69,82,95,65,67,67,69,76,69,82,65,84,73,79,78,0,83,68,76,95,86,73,68,69,79,95,65,76,76,79,87,95,83,67,82,69,69,78,83,65,86,69,82,0,95,83,68,76,95,87,105,110,100,111,119,84,101,120,116,117,114,101,68,97,116,97,0,95,83,68,76,95,87,105,110,100,111,119,82,101,110,100,101,114,68,97,116,97,0,84,101,120,116,117,114,101,32,119,97,115,32,110,111,116,32,99,114,101,97,116,101,100,32,119,105,116,104,32,116,104,105,115,32,114,101,110,100,101,114,101,114,0,84,101,120,116,117,114,101,32,110,111,116,32,99,114,101,97,116,101,100,32,119,105,116,104,32,83,68,76,95,84,69,88,84,85,82,69,65,67,67,69,83,83,95,84,65,82,71,69,84,0,78,111,32,119,105,110,100,111,119,32,116,101,120,116,117,114,101,32,100,97,116,97,0,80,97,114,97,109,101,116,101,114,32,39,37,115,39,32,105,115,32,105,110,118,97,108,105,100,0,112,105,120,101,108,115,0,112,105,116,99,104,0,73,110,118,97,108,105,100,32,116,97,114,103,101,116,32,112,105,120,101,108,32,102,111,114,109,97,116,0,85,110,115,117,112,112,111,114,116,101,100,32,89], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+184572);
/* memory initializer */ allocate([85,86,32,100,101,115,116,105,110,97,116,105,111,110,32,102,111,114,109,97,116,0,85,110,115,117,112,112,111,114,116,101,100,32,89,85,86,32,102,111,114,109,97,116,32,105,110,32,99,111,112,121,0,83,68,76,95,76,111,99,107,84,101,120,116,117,114,101,40,41,58,32,116,101,120,116,117,114,101,32,109,117,115,116,32,98,101,32,115,116,114,101,97,109,105,110,103,0,89,86,49,50,32,97,110,100,32,73,89,85,86,32,116,101,120,116,117,114,101,115,32,111,110,108,121,32,115,117,112,112,111,114,116,32,102,117,108,108,32,115,117,114,102,97,99,101,32,108,111,99,107,115,0,119,105,100,116,104,0,104,101,105,103,104,116,0,114,101,99,116,115,0,115,112,97,110,0,110,117,109,114,101,99,116,115,0,78,111,32,104,97,114,100,119,97,114,101,32,97,99,99,101,108,101,114,97,116,101,100,32,114,101,110,100,101,114,101,114,115,32,97,118,97,105,108,97,98,108,101,0,73,110,118,97,108,105,100,32,116,101,120,116,117,114,101,32,102,111,114,109,97,116,0,80,97,108,101,116,116,105,122,101,100,32,116,101,120,116,117,114,101,115,32,97,114,101,32,110,111,116,32,115,117,112,112,111,114,116,101,100,0,84,101,120,116,117,114,101,32,100,105,109,101,110,115,105,111,110,115,32,99,97,110,39,116,32,98,101,32,48,0,84,101,120,116,117,114,101,32,100,105,109,101,110,115,105,111,110,115,32,97,114,101,32,108,105,109,105,116,101,100,32,116,111,32,37,100,120,37,100,0,85,110,115,117,112,112,111,114,116,101,100,32,89,85,86,32,102,111,114,109,97,116,0,73,110,118,97,108,105,100,32,119,105,110,100,111,119,0,82,101,110,100,101,114,101,114,32,97,108,114,101,97,100,121,32,97,115,115,111,99,105,97,116,101,100,32,119,105,116,104,32,119,105,110,100,111,119,0,83,68,76,95,82,69,78,68,69,82,95,86,83,89,78,67,0,83,68,76,95,82,69,78,68,69,82,95,68,82,73,86,69,82,0,67,111,117,108,100,110,39,116,32,102,105,110,100,32,109,97,116,99,104,105,110,103,32,114,101,110,100,101,114,32,100,114,105,118,101,114,0,105,110,100,101,120,32,109,117,115,116,32,98,101,32,45,49,32,111,114,32,105,110,32,116,104,101,32,114,97,110,103,101,32,111,102,32,48,32,45,32,37,100,0,67,114,101,97,116,101,100,32,114,101,110,100,101,114,101,114,58,32,37,115,0,105,110,100,101,120,32,109,117,115,116,32,98,101,32,105,110,32,116,104,101,32,114,97,110,103,101,32,111,102,32,48,32,45,32,37,100,0,83,68,76,95,69,86,69,78,84,95,81,85,69,85,69,95,83,84,65,84,73,83,84,73,67,83,0,83,68,76,32,69,86,69,78,84,32,81,85,69,85,69,58,32,77,97,120,105,109,117,109,32,101,118,101,110,116,115,32,105,110,45,102,108,105,103,104,116,58,32,37,100,10,0,83,68,76,95,77,79,85,83,69,95,82,69,76,65,84,73,86,69,95,77,79,68,69,95,87,65,82,80,0,83,68,76,95,78,79,95,83,73,71,78,65,76,95,72,65,78,68,76,69,82,83,0,10,10,83,68,76,32,97,115,115,101,114,116,105,111,110,32,114,101,112,111,114,116,46,10,0,65,108,108,32,83,68,76,32,97,115,115,101,114,116,105,111,110,115,32,98,101,116,119,101,101,110,32,108,97,115,116,32,105,110,105,116,47,113,117,105,116,58,10,10,0,115,0,121,101,115,0,110,111,0,39,37,115,39,10,32,32,32,32,42,32,37,115,32,40,37,115,58,37,100,41,10,32,32,32,32,42,32,116,114,105,103,103,101,114,101,100,32,37,117,32,116,105,109,101,37,115,46,10,32,32,32,32,42,32,97,108,119,97,121,115,32,105,103,110,111,114,101,58,32,37,115,46,10,0,10,0,116,105,109,101,0,116,105,109,101,115,0,65,115,115,101,114,116,105,111,110,32,102,97,105,108,117,114,101,32,97,116,32,37,115,32,40,37,115,58,37,100,41,44,32,116,114,105,103,103,101,114,101,100,32,37,117,32,37,115,58,10,32,32,39,37,115,39,0,10,10,37,115,10,10,0,83,68,76,95,65,83,83,69,82,84,0,97,98,111,114,116,0,98,114,101,97,107,0,114,101,116,114,121,0,105,103,110,111,114,101,0,97,108,119,97,121,115,95,105,103,110,111,114,101,0,65,115,115,101,114,116,105,111,110,32,70,97,105,108,101,100,0,65,98,111,114,116,47,66,114,101,97,107,47,82,101,116,114,121,47,73,103,110,111,114,101,47,65,108,119,97,121,115,73,103,110,111,114,101,63,32,91,97,98,114,105,65,93,32,58,32,0,97,0,98,0,114,0,105,0,65,0,109,101,115,115,97,103,101,98,111,120,100,97,116,97,0,78,111,32,109,101,115,115,97,103,101,32,115,121,115,116,101,109,32,97,118,97,105,108,97,98,108,101,0,82,101,116,114,121,0,66,114,101,97,107,0,65,98,111,114,116,0,73,103,110,111,114,101,0,65,108,119,97,121,115,32,73,103,110,111,114,101,0,67,111,110,102,108,105,99,116,105,110,103,32,119,105,110,100,111,119,32,102,108,97,103,115,32,115,112,101,99,105,102,105,101,100,0,87,105,110,100,111,119,32,105,115,32,116,111,111,32,108,97,114,103,101,46,0,83,68,76,95,86,73,68,69,79,95,72,73,71,72,68,80,73,95,68,73,83,65,66,76,69,68,0,69,88,84,0,65,82,66,0,79,69,83,0,65,78,71,76,69,0,103,108,67,114,101,97,116,101,80,114,111,103,114,97,109,79,98,106,101,99,116,0,103,108,67,114,101,97,116,101,80,114,111,103,114,97,109,0,103,108,85,115,101,80,114,111,103,114,97,109,79,98,106,101,99,116,0,103,108,85,115,101,80,114,111,103,114,97,109,0,103,108,67,114,101,97,116,101,83,104,97,100,101,114,79,98,106,101,99,116,0,103,108,67,114,101,97,116,101,83,104,97,100,101,114,0,103,108,65,116,116,97,99,104,79,98,106,101,99,116,0,103,108,65,116,116,97,99,104,83,104,97,100,101,114,0,103,108,68,101,116,97,99,104,79,98,106,101,99,116,0,103,108,68,101,116,97,99,104,83,104,97,100,101,114,0,103,108,80,105,120,101,108,83,116,111,114,101,105,0,103,108,71,101,116,83,116,114,105,110,103,0,103,108,71,101,116,73,110,116,101,103,101,114,118,0,103,108,71,101,116,70,108,111,97,116,118,0,103,108,71,101,116,66,111,111,108,101,97,110,118,0,103,108,71,101,110,84,101,120,116,117,114,101,115,0,103,108,68,101,108,101,116,101,84,101,120,116,117,114,101,115,0,103,108,67,111,109,112,114,101,115,115,101,100,84,101,120,73,109,97,103,101,50,68,0,103,108,67,111,109,112,114,101,115,115,101,100,84,101,120,83,117,98,73,109,97,103,101,50,68,0,103,108,84,101,120,73,109,97,103,101,50,68,0,103,108,84,101,120,83,117,98,73,109,97,103,101,50,68,0,103,108,82,101,97,100,80,105,120,101,108,115,0,103,108,66,105,110,100,84,101,120,116,117,114,101,0,103,108,71,101,116,84,101,120,80,97,114,97,109,101,116,101,114,102,118,0,103,108,71,101,116,84,101,120,80,97,114,97,109,101,116,101,114,105,118,0,103,108,84,101,120,80,97,114,97,109,101,116,101,114,102,118,0,103,108,84,101,120,80,97,114,97,109,101,116,101,114,105,118,0,103,108,73,115,84,101,120,116,117,114,101,0,103,108,71,101,110,66,117,102,102,101,114,115,0,103,108,68,101,108,101,116,101,66,117,102,102,101,114,115,0,103,108,71,101,116,66,117,102,102,101,114,80,97,114,97,109,101,116,101,114,105,118,0,103,108,66,117,102,102,101,114,68,97,116,97,0,103,108,66,117,102,102,101,114,83,117,98,68,97,116,97,0,103,108,73,115,66,117,102,102,101,114,0,103,108,71,101,110,82,101,110,100,101,114,98,117,102,102,101,114,115,0,103,108,68,101,108,101,116,101,82,101,110,100,101,114,98,117,102,102,101,114,115,0,103,108,66,105,110,100,82,101,110,100,101,114,98,117,102,102,101,114,0,103,108,71,101,116,82,101,110,100,101,114,98,117,102,102,101,114,80,97,114,97,109,101,116,101,114,105,118,0,103,108,73,115,82,101,110,100,101,114,98,117,102,102,101,114,0,103,108,71,101,116,85,110,105,102,111,114,109,102,118,0,103,108,71,101,116,85,110,105,102,111,114,109,105,118,0,103,108,71,101,116,85,110,105,102,111,114,109,76,111,99,97,116,105,111,110,0,103,108,71,101,116,86,101,114,116,101,120,65,116,116,114,105,98,102,118,0,103,108,71,101,116,86,101,114,116,101,120,65,116,116,114,105,98,105,118,0,103,108,71,101,116,86,101,114,116,101,120,65,116,116,114,105,98,80,111,105,110,116,101,114,118,0,103,108,71,101,116,65,99,116,105,118,101,85,110,105,102,111,114,109,0,103,108,85,110,105,102,111,114,109,49,102,0,103,108,85,110,105,102,111,114,109,50,102,0,103,108,85,110,105,102,111,114,109,51,102,0,103,108,85,110,105,102,111,114,109,52,102,0,103,108,85,110,105,102,111,114,109,49,105,0,103,108,85,110,105,102,111,114,109,50,105,0,103,108,85,110,105,102,111,114,109,51,105,0,103,108,85,110,105,102,111,114,109,52,105,0,103,108,85,110,105,102,111,114,109,49,105,118,0,103,108,85,110,105,102,111,114,109,50,105,118,0,103,108,85,110,105,102,111,114,109,51,105,118,0,103,108,85,110,105,102,111,114,109,52,105,118,0,103,108,85,110,105,102,111,114,109,49,102,118,0,103,108,85,110,105,102,111,114,109,50,102,118,0,103,108,85,110,105,102,111,114,109,51,102,118,0,103,108,85,110,105,102,111,114,109,52,102,118,0,103,108,85,110,105,102,111,114,109,77,97,116,114,105,120,50,102,118,0,103,108,85,110,105,102,111,114,109,77,97,116,114,105,120,51,102,118,0,103,108,85,110,105,102,111,114,109,77,97,116,114,105,120,52,102,118,0,103,108,66,105,110,100,66,117,102,102,101,114,0,103,108,86,101,114,116,101,120,65,116,116,114,105,98,49,102,118,0,103,108,86,101,114,116,101,120,65,116,116,114,105,98,50,102,118,0,103,108,86,101,114,116,101,120,65,116,116,114,105,98,51,102,118,0,103,108,86,101,114,116,101,120,65,116,116,114,105,98,52,102,118,0,103,108,71,101,116,65,116,116,114,105,98,76,111,99,97,116,105,111,110,0,103,108,71,101,116,65,99,116,105,118,101,65,116,116,114,105,98,0,103,108,68,101,108,101,116,101,83,104,97,100,101,114,0,103,108,71,101,116,65,116,116,97,99,104,101,100,83,104,97,100,101,114,115,0,103,108,83,104,97,100,101,114,83,111,117,114,99,101,0,103,108,71,101,116,83,104,97,100,101,114,83,111,117,114,99,101,0,103,108,67,111,109,112,105,108,101,83,104,97,100,101,114,0,103,108,71,101,116,83,104,97,100,101,114,73,110,102,111,76,111,103,0,103,108,71,101,116,83,104,97,100,101,114,105,118,0,103,108,71,101,116,80,114,111,103,114,97,109,105,118,0,103,108,73,115,83,104,97,100,101,114,0,103,108,68,101,108,101,116,101,80,114,111,103,114,97,109,0,103,108,71,101,116,83,104,97,100,101,114,80,114,101,99,105,115,105,111,110,70,111,114,109,97,116,0,103,108,76,105,110,107,80,114,111,103,114,97,109,0,103,108,71,101,116,80,114,111,103,114,97,109,73,110,102,111,76,111,103,0,103,108,86,97,108,105,100,97,116,101,80,114,111,103,114,97,109,0,103,108,73,115,80,114,111,103,114,97,109,0,103,108,66,105,110,100,65,116,116,114,105,98,76,111,99,97,116,105,111,110,0,103,108,66,105,110,100,70,114,97,109,101,98,117,102,102,101,114,0,103,108,71,101,110,70,114,97,109,101,98,117,102,102,101,114,115,0,103,108,68,101,108,101,116,101,70,114,97,109,101,98,117,102,102,101,114,115,0,103,108,70,114,97,109,101,98,117,102,102,101,114,82,101,110,100,101,114,98,117,102,102,101,114,0,103,108,70,114,97,109,101,98,117,102,102,101,114,84,101,120,116,117,114,101,50,68,0,103,108,71,101,116,70,114,97,109,101,98,117,102,102,101,114,65,116,116,97,99,104,109,101,110,116,80,97,114,97,109,101,116,101,114,105,118,0,103,108,73,115,70,114,97,109,101,98,117,102,102,101,114,0,103,108,68,101,108,101,116,101,79,98,106,101,99,116,0,103,108,71,101,116,79,98,106,101,99,116,80,97,114,97,109,101,116,101,114,105,118,0,103,108,71,101,116,73,110,102,111,76,111,103,0,103,108,66,105,110,100,80,114,111,103,114,97,109,0,103,108,71,101,116,80,111,105,110,116,101,114,118,0,103,108,68,114,97,119,82,97,110,103,101,69,108,101,109,101,110,116,115,0,103,108,69,110,97,98,108,101,67,108,105,101,110,116,83,116,97,116,101,0,103,108,86,101,114,116,101,120,80,111,105,110,116,101,114,0,103,108,84,101,120,67,111,111,114,100,80,111,105,110,116,101,114,0,103,108,78,111,114,109,97,108,80,111,105,110,116,101,114,0,103,108,67,111,108,111,114,80,111,105,110,116,101,114,0,103,108,67,108,105,101,110,116,65,99,116,105,118,101,84,101,120,116,117,114,101,0,103,108,71,101,110,86,101,114,116,101,120,65,114,114,97,121,115,0,103,108,68,101,108,101,116,101,86,101,114,116,101,120,65,114,114,97,121,115,0,103,108,66,105,110,100,86,101,114,116,101,120,65,114,114,97,121,0,103,108,77,97,116,114,105,120,77,111,100,101,0,103,108,76,111,97,100,73,100,101,110,116,105,116,121,0,103,108,76,111,97,100,77,97,116,114,105,120,102,0,103,108,70,114,117,115,116,117,109,0,103,108,82,111,116,97,116,101,102,0,103,108,86,101,114,116,101,120,65,116,116,114,105,98,80,111,105,110,116,101,114,0,103,108,69,110,97,98,108,101,86,101,114,116,101,120,65,116,116,114,105,98,65,114,114,97,121,0,103,108,68,105,115,97,98,108,101,86,101,114,116,101,120,65,116,116,114,105,98,65,114,114,97,121,0,103,108,68,114,97,119,65,114,114,97,121,115,0,103,108,68,114,97,119,69,108,101,109,101,110,116,115,0,103,108,83,104,97,100,101,114,66,105,110,97,114,121,0,103,108,82,101,108,101,97,115,101,83,104,97,100,101,114,67,111,109,112,105,108,101,114,0,103,108,71,101,116,69,114,114,111,114,0,103,108,86,101,114,116,101,120,65,116,116,114,105,98,68,105,118,105,115,111,114,0,103,108,68,114,97,119,65,114,114,97,121,115,73,110,115,116,97,110,99,101,100,0,103,108,68,114,97,119,69,108,101,109,101,110,116,115,73,110,115,116,97,110,99,101,100,0,103,108,70,105,110,105,115,104,0,103,108,70,108,117,115,104,0,103,108,67,108,101,97,114,68,101,112,116,104,0,103,108,67,108,101,97,114,68,101,112,116,104,102,0,103,108,68,101,112,116,104,70,117,110,99,0,103,108,69,110,97,98,108,101,0,103,108,68,105,115,97,98,108,101,0,103,108,70,114,111,110,116,70,97,99,101,0,103,108,67,117,108,108,70,97,99,101,0,103,108,67,108,101,97,114,0,103,108,76,105,110,101,87,105,100,116,104,0,103,108,67,108,101,97,114,83,116,101,110,99,105,108,0,103,108,68,101,112,116,104,77,97,115,107,0,103,108,83,116,101,110,99,105,108,77,97,115,107,0,103,108,67,104,101,99,107,70,114,97,109,101,98,117,102,102,101,114,83,116,97,116,117,115,0,103,108,71,101,110,101,114,97,116,101,77,105,112,109,97,112,0,103,108,65,99,116,105,118,101,84,101,120,116,117,114,101,0,103,108,66,108,101,110,100,69,113,117,97,116,105,111,110,0,103,108,73,115,69,110,97,98,108,101,100,0,103,108,66,108,101,110,100,70,117,110,99,0,103,108,66,108,101,110,100,69,113,117,97,116,105,111,110,83,101,112,97,114,97,116,101,0,103,108,68,101,112,116,104,82,97,110,103,101,0,103,108,68,101,112,116,104,82,97,110,103,101,102,0,103,108,83,116,101,110,99,105,108,77,97,115,107,83,101,112,97,114,97,116,101,0,103,108,72,105,110,116,0,103,108,80,111,108,121,103,111,110,79,102,102,115,101,116,0,103,108,86,101,114,116,101,120,65,116,116,114,105,98,49,102,0,103,108,83,97,109,112,108,101,67,111,118,101,114,97,103,101,0,103,108,84,101,120,80,97,114,97,109,101,116,101,114,105,0,103,108,84,101,120,80,97,114,97,109,101,116,101,114,102,0,103,108,86,101,114,116,101,120,65,116,116,114,105,98,50,102,0,103,108,83,116,101,110,99,105,108,70,117,110,99,0,103,108,83,116,101,110,99,105,108,79,112,0,103,108,86,105,101,119,112,111,114,116,0,103,108,67,108,101,97,114,67,111,108,111,114,0,103,108,83,99,105,115,115,111,114,0,103,108,86,101,114,116,101,120,65,116,116,114,105,98,51,102,0,103,108,67,111,108,111,114,77,97,115,107,0,103,108,82,101,110,100,101,114,98,117,102,102,101,114,83,116,111,114,97,103,101,0,103,108,66,108,101,110,100,70,117,110,99,83,101,112,97,114,97,116,101,0,103,108,66,108,101,110,100,67,111,108,111,114,0,103,108,83,116,101,110,99,105,108,70,117,110,99,83,101,112,97,114,97,116,101,0,103,108,83,116,101,110,99,105,108,79,112,83,101,112,97,114,97,116,101,0,103,108,86,101,114,116,101,120,65,116,116,114,105,98,52,102,0,103,108,67,111,112,121,84,101,120,73,109,97,103,101,50,68,0,103,108,67,111,112,121,84,101,120,83,117,98,73,109,97,103,101,50,68,0,103,108,68,114,97,119,66,117,102,102,101,114,115,0,77,111,100,117,108,101,46,112,114,105,110,116,69,114,114,40,39,98,97,100,32,110,97,109,101,32,105,110,32,103,101,116,80,114,111,99,65,100,100,114,101,115,115,58,32,39,32,43,32,91,80,111,105,110,116,101,114,95,115,116,114,105,110,103,105,102,121,40,36,48,41,44,32,80,111,105,110,116,101,114,95,115,116,114,105,110,103,105,102,121,40,36,49,41,93,41,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,1,2,3,4,5,6,7,8,9,255,255,255,255,255,255,255,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,255,255,255,255,255,255,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,1,2,4,7,3,6,5,0,105,110,102,105,110,105,116,121,0,17,0,10,0,17,17,17,0,0,0,0,5,0,0,0,0,0,0,9,0,0,0,0,11,0,0,0,0,0,0,0,0,17,0,15,10,17,17,17,3,10,7,0,1,19,9,11,11,0,0,9,6,11,0,0,11,0,6,17,0,0,0,17,17,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,0,0,0,0,0,0,0,17,0,10,10,17,17,17,0,10,0,0,2,0,9,11,0,0,0,9,0,11,0,0,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,12,0,0,0,0,9,12,0,0,0,0,0,12,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,13,0,0,0,4,13,0,0,0,0,9,14,0,0,0,0,0,14,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,15,0,0,0,0,15,0,0,0,0,9,16,0,0,0,0,0,16,0,0,16,0,0,18,0,0,0,18,18,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,0,18,18,18,0,0,0,0,0,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,0,0,0,0,0,0,0,0,0,0,10,0,0,0,0,10,0,0,0,0,9,11,0,0,0,0,0,11,0,0,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,12,0,0,0,0,9,12,0,0,0,0,0,12,0,0,12,0,0,45,43,32,32,32,48,88,48,120,0,40,110,117,108,108,41,0,45,48,88,43,48,88,32,48,88,45,48,120,43,48,120,32,48,120,0,105,110,102,0,73,78,70,0,110,97,110,0,78,65,78,0,48,49,50,51,52,53,54,55,56,57,65,66,67,68,69,70,46,0,84,33,34,25,13,1,2,3,17,75,28,12,16,4,11,29,18,30,39,104,110,111,112,113,98,32,5,6,15,19,20,21,26,8,22,7,40,36,23,24,9,10,14,27,31,37,35,131,130,125,38,42,43,60,61,62,63,67,71,74,77,88,89,90,91,92,93,94,95,96,97,99,100,101,102,103,105,106,107,108,114,115,116,121,122,123,124,0,73,108,108,101,103,97,108,32,98,121,116,101,32,115,101,113,117,101,110,99,101,0,68,111,109,97,105,110,32,101,114,114,111,114,0,82,101,115,117,108,116,32,110,111,116,32,114,101,112,114,101,115,101,110,116,97,98,108,101,0,78,111,116,32,97,32,116,116,121,0,80,101,114,109,105,115,115,105,111,110,32,100,101,110,105,101,100,0,79,112,101,114,97,116,105,111,110,32,110,111,116,32,112,101,114,109,105,116,116,101,100,0,78,111,32,115,117,99,104,32,102,105,108,101,32,111,114,32,100,105,114,101,99,116,111,114,121,0,78,111,32,115,117,99,104,32,112,114,111,99,101,115,115,0,70,105,108,101,32,101,120,105,115,116,115,0,86,97,108,117,101,32,116,111,111,32,108,97,114,103,101,32,102,111,114,32,100,97,116,97,32,116,121,112,101,0,78,111,32,115,112,97,99,101,32,108,101,102,116,32,111,110,32,100,101,118,105,99,101,0,79,117,116,32,111,102,32,109,101,109,111,114,121,0,82,101,115,111,117,114,99,101,32,98,117,115,121,0,73,110,116,101,114,114,117,112,116,101,100,32,115,121,115,116,101,109,32,99,97,108,108,0,82,101,115,111,117,114,99,101,32,116,101,109,112,111,114,97,114,105,108,121,32,117,110,97,118,97,105,108,97,98,108,101,0,73,110,118,97,108,105,100,32,115,101,101,107,0,67,114,111,115,115,45,100,101,118,105,99,101,32,108,105,110,107,0,82,101,97,100,45,111,110,108,121,32,102,105,108,101,32,115,121,115,116,101,109,0,68,105,114,101,99,116,111,114,121,32,110,111,116,32,101,109,112,116,121,0,67,111,110,110,101,99,116,105,111,110,32,114,101,115,101,116,32,98,121,32,112,101,101,114,0,79,112,101,114,97,116,105,111,110,32,116,105,109,101,100,32,111,117,116,0,67,111,110,110,101,99,116,105,111,110,32,114,101,102,117,115,101,100,0,72,111,115,116,32,105,115,32,100,111,119,110,0,72,111,115,116,32,105,115,32,117,110,114,101,97,99,104,97,98,108,101,0,65,100,100,114,101,115,115,32,105,110,32,117,115,101,0,66,114,111,107,101,110,32,112,105,112,101,0,73,47,79,32,101,114,114,111,114,0,78,111,32,115,117,99,104,32,100,101,118,105,99,101,32,111,114,32,97,100,100,114,101,115,115,0,66,108,111,99,107,32,100,101,118,105,99,101,32,114,101,113,117,105,114,101,100,0,78,111,32,115,117,99,104,32,100,101,118,105,99,101,0,78,111,116,32,97,32,100,105,114,101,99,116,111,114,121,0,73,115,32,97,32,100,105,114,101,99,116,111,114,121,0,84,101,120,116,32,102,105,108,101,32,98,117,115,121,0,69,120,101,99,32,102,111,114,109,97,116,32,101,114,114,111,114,0,73,110,118,97,108,105,100,32,97,114,103,117,109,101,110,116,0,65,114,103,117,109,101,110,116,32,108,105,115,116,32,116,111,111,32,108,111,110,103,0,83,121,109,98,111,108,105,99,32,108,105,110,107,32,108,111,111,112,0,70,105,108,101,110,97,109,101,32,116,111,111,32,108,111,110,103,0,84,111,111,32,109,97,110,121,32,111,112,101,110,32,102,105,108,101,115,32,105,110,32,115,121,115,116,101,109,0,78,111,32,102,105,108,101,32,100,101,115,99,114,105,112,116,111,114,115,32,97,118,97,105,108,97,98,108,101,0,66,97,100,32,102,105,108,101,32,100,101,115,99,114,105,112,116,111,114,0,78,111,32,99,104,105,108,100,32,112,114,111,99,101,115,115,0,66,97,100,32,97,100,100,114,101,115,115,0,70,105,108,101,32,116,111,111,32,108,97,114,103,101,0,84,111,111,32,109,97,110,121,32,108,105,110,107,115,0,78,111,32,108,111,99,107,115,32,97,118,97,105,108,97,98,108,101,0,82,101,115,111,117,114,99,101,32,100,101,97,100,108,111,99,107,32,119,111,117,108,100,32,111,99,99,117,114,0,83,116,97,116,101,32,110,111,116,32,114,101,99,111,118,101,114,97,98,108,101,0,80,114,101,118,105,111,117,115,32,111,119,110,101,114,32,100,105,101,100,0,79,112,101,114,97,116,105,111,110,32,99,97,110,99,101,108,101,100,0,70,117,110,99,116,105,111,110,32,110,111,116,32,105,109,112,108,101,109,101,110,116,101,100,0,78,111,32,109,101,115,115,97,103,101,32,111,102,32,100,101,115,105,114,101,100,32,116,121,112,101,0,73,100,101,110,116,105,102,105,101,114,32,114,101,109,111,118,101,100,0,68,101,118,105,99,101,32,110,111,116,32,97,32,115,116,114,101,97,109,0,78,111,32,100,97,116,97,32,97,118,97,105,108,97,98,108,101,0,68,101,118,105,99,101,32,116,105,109,101,111,117,116,0,79,117,116,32,111,102,32,115,116,114,101,97,109,115,32,114,101,115,111,117,114,99,101,115,0,76,105,110,107,32,104,97,115,32,98,101,101,110,32,115,101,118,101,114,101,100,0,80,114,111,116,111,99,111,108,32,101,114,114,111,114,0,66,97,100,32,109,101,115,115,97,103,101,0,70,105,108,101,32,100,101,115,99,114,105,112,116,111,114,32,105,110,32,98,97,100,32,115,116,97,116,101,0,78,111,116,32,97,32,115,111,99,107,101,116,0,68,101,115,116,105,110,97,116,105,111,110,32,97,100,100,114,101,115,115,32,114,101,113,117,105,114,101,100,0,77,101,115,115,97,103,101,32,116,111,111,32,108,97,114,103,101,0,80,114,111,116,111,99,111,108,32,119,114,111,110,103,32,116,121,112,101,32,102,111,114,32,115,111,99,107,101,116,0,80,114,111,116,111,99,111,108,32,110,111,116,32,97,118,97,105,108,97,98,108,101,0,80,114,111,116,111,99,111,108,32,110,111,116,32,115,117,112,112,111,114,116,101,100,0,83,111,99,107,101,116,32,116,121,112,101,32,110,111,116,32,115,117,112,112,111,114,116,101,100,0,78,111,116,32,115,117,112,112,111,114,116,101,100,0,80,114,111,116,111,99,111,108,32,102,97,109,105,108,121,32,110,111,116,32,115,117,112,112,111,114,116,101,100,0,65,100,100,114,101,115,115,32,102,97,109,105,108,121,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,98,121,32,112,114,111,116,111,99,111,108,0,65,100,100,114,101,115,115,32,110,111,116,32,97,118,97,105,108,97,98,108,101,0,78,101,116,119,111,114,107,32,105,115,32,100,111,119,110,0,78,101,116,119,111,114,107,32,117,110,114,101,97,99,104,97,98,108,101,0,67,111,110,110,101,99,116,105,111,110,32,114,101,115,101,116,32,98,121,32,110,101,116,119,111,114,107,0,67,111,110,110,101,99,116,105,111,110,32,97,98,111,114,116,101,100,0,78,111,32,98,117,102,102,101,114,32,115,112,97,99,101,32,97,118,97,105,108,97,98,108,101,0,83,111,99,107,101,116,32,105,115,32,99,111,110,110,101,99,116,101,100,0,83,111,99,107,101,116,32,110,111,116,32,99,111,110,110,101,99,116,101,100,0,67,97,110,110,111,116,32,115,101,110,100,32,97,102,116,101,114,32,115,111,99,107,101,116,32,115,104,117,116,100,111,119,110,0,79,112,101,114,97,116,105,111,110,32,97,108,114,101,97,100,121,32,105,110,32,112,114,111,103,114,101,115,115,0,79,112,101,114,97,116,105,111,110,32,105,110,32,112,114,111,103,114,101,115,115,0,83,116,97,108,101,32,102,105,108,101,32,104,97,110,100,108,101,0,82,101,109,111,116,101,32,73,47,79,32,101,114,114,111,114,0,81,117,111,116,97,32,101,120,99,101,101,100,101,100,0,78,111,32,109,101,100,105,117,109,32,102,111,117,110,100,0,87,114,111,110,103,32,109,101,100,105,117,109,32,116,121,112,101,0,78,111,32,101,114,114,111,114,32,105,110,102,111,114,109,97,116,105,111,110,0,0,47,112,114,111,99,47,115,101,108,102,47,102,100,47,0,114,119,97,0,76,67,95,65,76,76,0,76,67,95,67,84,89,80,69,0,0,0,0,76,67,95,78,85,77,69,82,73,67,0,0,76,67,95,84,73,77,69,0,0,0,0,0,76,67,95,67,79,76,76,65,84,69,0,0,76,67,95,77,79,78,69,84,65,82,89,0,76,67,95,77,69,83,83,65,71,69,83,0,76,65,78,71,0,67,46,85,84,70,45,56,0,80,79,83,73,88,0,77,85,83,76,95,76,79,67,80,65,84,72,0,78,83,116,51,95,95,50,56,105,111,115,95,98,97,115,101,69,0,78,83,116,51,95,95,50,57,98,97,115,105,99,95,105,111,115,73,99,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,99,69,69,69,69,0,78,83,116,51,95,95,50,57,98,97,115,105,99,95,105,111,115,73,119,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,119,69,69,69,69,0,78,83,116,51,95,95,50,49,53,98,97,115,105,99,95,115,116,114,101,97,109,98,117,102,73,99,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,99,69,69,69,69,0,78,83,116,51,95,95,50,49,53,98,97,115,105,99,95,115,116,114,101,97,109,98,117,102,73,119,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,119,69,69,69,69,0,78,83,116,51,95,95,50,49,51,98,97,115,105,99,95,105,115,116,114,101,97,109,73,99,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,99,69,69,69,69,0,78,83,116,51,95,95,50,49,51,98,97,115,105,99,95,105,115,116,114,101,97,109,73,119,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,119,69,69,69,69,0,78,83,116,51,95,95,50,49,51,98,97,115,105,99,95,111,115,116,114,101,97,109,73,99,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,99,69,69,69,69,0,78,83,116,51,95,95,50,49,51,98,97,115,105,99,95,111,115,116,114,101,97,109,73,119,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,119,69,69,69,69,0,78,83,116,51,95,95,50,49,52,98,97,115,105,99,95,105,111,115,116,114,101,97,109,73,99,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,99,69,69,69,69,0,117,110,115,112,101,99,105,102,105,101,100,32,105,111,115,116,114,101,97,109,95,99,97,116,101,103,111,114,121,32,101,114,114,111,114,0,105,111,115,116,114,101,97,109,0,78,83,116,51,95,95,50,49,57,95,95,105,111,115,116,114,101,97,109,95,99,97,116,101,103,111,114,121,69,0,78,83,116,51,95,95,50,56,105,111,115,95,98,97,115,101,55,102,97,105,108,117,114,101,69,0,105,111,115,95,98,97,115,101,58,58,99,108,101,97,114,0,78,83,116,51,95,95,50,49,49,95,95,115,116,100,111,117,116,98,117,102,73,119,69,69,0,78,83,116,51,95,95,50,49,49,95,95,115,116,100,111,117,116,98,117,102,73,99,69,69,0,117,110,115,117,112,112,111,114,116,101,100,32,108,111,99,97,108,101,32,102,111,114,32,115,116,97,110,100,97,114,100,32,105,110,112,117,116,0,78,83,116,51,95,95,50,49,48,95,95,115,116,100,105,110,98,117,102,73,119,69,69,0,78,83,116,51,95,95,50,49,48,95,95,115,116,100,105,110,98,117,102,73,99,69,69,0,78,83,116,51,95,95,50,55,99,111,108,108,97,116,101,73,99,69,69,0,78,83,116,51,95,95,50,54,108,111,99,97,108,101,53,102,97,99,101,116,69,0,78,83,116,51,95,95,50,55,99,111,108,108,97,116,101,73,119,69,69,0,48,49,50,51,52,53,54,55,56,57,97,98,99,100,101,102,65,66,67,68,69,70,120,88,43,45,112,80,105,73,110,78,0,37,112,0,67,0,78,83,116,51,95,95,50,55,110,117,109,95,103,101,116,73,99,78,83,95,49,57,105,115,116,114,101,97,109,98,117,102,95,105,116,101,114,97,116,111,114,73,99,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,99,69,69,69,69,69,69,0,78,83,116,51,95,95,50,57,95,95,110,117,109,95,103,101,116,73,99,69,69,0,78,83,116,51,95,95,50,49,52,95,95,110,117,109,95,103,101,116,95,98,97,115,101,69,0,78,83,116,51,95,95,50,55,110,117,109,95,103,101,116,73,119,78,83,95,49,57,105,115,116,114,101,97,109,98,117,102,95,105,116,101,114,97,116,111,114,73,119,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,119,69,69,69,69,69,69,0,78,83,116,51,95,95,50,57,95,95,110,117,109,95,103,101,116,73,119,69,69,0,37,112,0,0,0,0,76,0,108,108,0,37,0,0,0,0,0,108,0,78,83,116,51,95,95,50,55,110,117,109,95,112,117,116,73,99,78,83,95,49,57,111,115,116,114,101,97,109,98,117,102,95,105,116,101,114,97,116,111,114,73,99,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,99,69,69,69,69,69,69,0,78,83,116,51,95,95,50,57,95,95,110,117,109,95,112,117,116,73,99,69,69,0,78,83,116,51,95,95,50,49,52,95,95,110,117,109,95,112,117,116,95,98,97,115,101,69,0,78,83,116,51,95,95,50,55,110,117,109,95,112,117,116,73,119,78,83,95,49,57,111,115,116,114,101,97,109,98,117,102,95,105,116,101,114,97,116,111,114,73,119,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,119,69,69,69,69,69,69,0,78,83,116,51,95,95,50,57,95,95,110,117,109,95,112,117,116,73,119,69,69,0,37,72,58,37,77,58,37,83,0,37,109,47,37,100,47,37,121,0,37,73,58,37,77,58,37,83,32,37,112,0,37,97,32,37,98,32,37,100,32,37,72,58,37,77,58,37,83,32,37,89,0,65,77,0,80,77,0,74,97,110,117,97,114,121,0,70,101,98,114,117,97,114,121,0,77,97,114,99,104,0,65,112,114,105,108,0,77,97,121,0,74,117,110,101,0,74,117,108,121,0,65,117,103,117,115,116,0,83,101,112,116,101,109,98,101,114,0,79,99,116,111,98,101,114,0,78,111,118,101,109,98,101,114,0,68,101,99,101,109,98,101,114,0,74,97,110,0,70,101,98,0,77,97,114,0,65,112,114,0,74,117,110,0,74,117,108,0,65,117,103,0,83,101,112,0,79,99,116,0,78,111,118,0,68,101,99,0,83,117,110,100,97,121,0,77,111,110,100,97,121,0,84,117,101,115,100,97,121,0,87,101,100,110,101,115,100,97,121,0,84,104,117,114,115,100,97,121,0,70,114,105,100,97,121,0,83,97,116,117,114,100,97,121,0,83,117,110,0,77,111,110,0,84,117,101,0,87,101,100,0,84,104,117,0,70,114,105,0,83,97,116,0,37,109,47,37,100,47,37,121,37,89,45,37,109,45,37,100,37,73,58,37,77,58,37,83,32,37,112,37,72,58,37,77,37,72,58,37,77,58,37,83,37,72,58,37,77,58,37,83,78,83,116,51,95,95,50,56,116,105,109,101,95,103,101,116,73,99,78,83,95,49,57,105,115,116,114,101,97,109,98,117,102,95,105,116,101,114,97,116,111,114,73,99,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,99,69,69,69,69,69,69,0,78,83,116,51,95,95,50,50,48,95,95,116,105,109,101,95,103,101,116,95,99,95,115,116,111,114,97,103,101,73,99,69,69,0,78,83,116,51,95,95,50,57,116,105,109,101,95,98,97,115,101,69,0,78,83,116,51,95,95,50,56,116,105,109,101,95,103,101,116,73,119,78,83,95,49,57,105,115,116,114,101,97,109,98,117,102,95,105,116,101,114,97,116,111,114,73,119,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,119,69,69,69,69,69,69,0,78,83,116,51,95,95,50,50,48,95,95,116,105,109,101,95,103,101,116,95,99,95,115,116,111,114,97,103,101,73,119,69,69,0,78,83,116,51,95,95,50,56,116,105,109,101,95,112,117,116,73,99,78,83,95,49,57,111,115,116,114,101,97,109,98,117,102,95,105,116,101,114,97,116,111,114,73,99,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,99,69,69,69,69,69,69,0,78,83,116,51,95,95,50,49,48,95,95,116,105,109,101,95,112,117,116,69,0,108,111,99,97,108,101,32,110,111,116,32,115,117,112,112,111,114,116,101,100,0,78,83,116,51,95,95,50,56,116,105,109,101,95,112,117,116,73,119,78,83,95,49,57,111,115,116,114,101,97,109,98,117,102,95,105,116,101,114,97,116,111,114,73,119,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,119,69,69,69,69,69,69,0,78,83,116,51,95,95,50,49,48,109,111,110,101,121,112,117,110,99,116,73,99,76,98,48,69,69,69,0,78,83,116,51,95,95,50,49,48,109,111,110,101,121,95,98,97,115,101,69,0,78,83,116,51,95,95,50,49,48,109,111,110,101,121,112,117,110,99,116,73,99,76,98,49,69,69,69,0,78,83,116,51,95,95,50,49,48,109,111,110,101,121,112,117,110,99,116,73,119,76,98,48,69,69,69,0,78,83,116,51,95,95,50,49,48,109,111,110,101,121,112,117,110,99,116,73,119,76,98,49,69,69,69,0,48,49,50,51,52,53,54,55,56,57,0,37,76,102,0,109,111,110,101,121,95,103,101,116,32,101,114,114,111,114,0,78,83,116,51,95,95,50,57,109,111,110,101,121,95,103,101,116,73,99,78,83,95,49,57,105,115,116,114,101,97,109,98,117,102,95,105,116,101,114,97,116,111,114,73,99,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,99,69,69,69,69,69,69,0,78,83,116,51,95,95,50,49,49,95,95,109,111,110,101,121,95,103,101,116,73,99,69,69,0,48,49,50,51,52,53,54,55,56,57,0,78,83,116,51,95,95,50,57,109,111,110,101,121,95,103,101,116,73,119,78,83,95,49,57,105,115,116,114,101,97,109,98,117,102,95,105,116,101,114,97,116,111,114,73,119,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,119,69,69,69,69,69,69,0,78,83,116,51,95,95,50,49,49,95,95,109,111,110,101,121,95,103,101,116,73,119,69,69,0,37,46,48,76,102,0,78,83,116,51,95,95,50,57,109,111,110,101,121,95,112,117,116,73,99,78,83,95,49,57,111,115,116,114,101,97,109,98,117,102,95,105,116,101,114,97,116,111,114,73,99,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,99,69,69,69,69,69,69,0,78,83,116,51,95,95,50,49,49,95,95,109,111,110,101,121,95,112,117,116,73,99,69,69,0,78,83,116,51,95,95,50,57,109,111,110,101,121,95,112,117,116,73,119,78,83,95,49,57,111,115,116,114,101,97,109,98,117,102,95,105,116,101,114,97,116,111,114,73,119,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,119,69,69,69,69,69,69,0,78,83,116,51,95,95,50,49,49,95,95,109,111,110,101,121,95,112,117,116,73,119,69,69,0,78,83,116,51,95,95,50,56,109,101,115,115,97,103,101,115,73,99,69,69,0,78,83,116,51,95,95,50,49,51,109,101,115,115,97,103,101,115,95,98,97,115,101,69,0,78,83,116,51,95,95,50,49,55,95,95,119,105,100,101,110,95,102,114,111,109,95,117,116,102,56,73,76,106,51,50,69,69,69,0,78,83,116,51,95,95,50,55,99,111,100,101,99,118,116,73,68,105,99,49,49,95,95,109,98,115,116,97,116,101,95,116,69,69,0,78,83,116,51,95,95,50,49,50,99,111,100,101,99,118,116,95,98,97,115,101,69,0,78,83,116,51,95,95,50,49,54,95,95,110,97,114,114,111,119,95,116,111,95,117,116,102,56,73,76,106,51,50,69,69,69,0,78,83,116,51,95,95,50,56,109,101,115,115,97,103,101,115,73,119,69,69,0,78,83,116,51,95,95,50,55,99,111,100,101,99,118,116,73,99,99,49,49,95,95,109,98,115,116,97,116,101,95,116,69,69,0,78,83,116,51,95,95,50,55,99,111,100,101,99,118,116,73,119,99,49,49,95,95,109,98,115,116,97,116,101,95,116,69,69,0,78,83,116,51,95,95,50,55,99,111,100,101,99,118,116,73,68,115,99,49,49,95,95,109,98,115,116,97,116,101,95,116,69,69,0,78,83,116,51,95,95,50,54,108,111,99,97,108,101,53,95,95,105,109,112,69,0,78,83,116,51,95,95,50,53,99,116,121,112,101,73,99,69,69,0,78,83,116,51,95,95,50,49,48,99,116,121,112,101,95,98,97,115,101,69,0,78,83,116,51,95,95,50,53,99,116,121,112,101,73,119,69,69,0,102,97,108,115,101,0,116,114,117,101,0,78,83,116,51,95,95,50,56,110,117,109,112,117,110,99,116,73,99,69,69,0,78,83,116,51,95,95,50,56,110,117,109,112,117,110,99,116,73,119,69,69,0,118,101,99,116,111,114,0,78,83,116,51,95,95,50,49,52,95,95,115,104,97,114,101,100,95,99,111,117,110,116,69,0,98,97,115,105,99,95,115,116,114,105,110,103,0,97,108,108,111,99,97,116,111,114,60,84,62,58,58,97,108,108,111,99,97,116,101,40,115,105,122,101,95,116,32,110,41,32,39,110,39,32,101,120,99,101,101,100,115,32,109,97,120,105,109,117,109,32,115,117,112,112,111,114,116,101,100,32,115,105,122,101,0,115,116,111,105,0,58,32,110,111,32,99,111,110,118,101,114,115,105,111,110,0,58,32,111,117,116,32,111,102,32,114,97,110,103,101,0,37,117,0,85,110,107,110,111,119,110,32,101,114,114,111,114,32,37,100,0,110,101,119,95,101,114,114,110,111,32,61,61,32,69,82,65,78,71,69,0,47,104,111,109,101,47,107,111,114,110,101,114,114,47,101,109,115,100,107,45,112,111,114,116,97,98,108,101,47,101,109,115,99,114,105,112,116,101,110,47,49,46,51,55,46,50,49,47,115,121,115,116,101,109,47,108,105,98,47,108,105,98,99,120,120,47,115,121,115,116,101,109,95,101,114,114], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+194812);
/* memory initializer */ allocate([111,114,46,99,112,112,0,100,111,95,115,116,114,101,114,114,111,114,95,114,0,78,83,116,51,95,95,50,49,50,95,95,100,111,95,109,101,115,115,97,103,101,69,0,78,83,116,51,95,95,50,49,52,101,114,114,111,114,95,99,97,116,101,103,111,114,121,69,0,78,83,116,51,95,95,50,49,50,115,121,115,116,101,109,95,101,114,114,111,114,69,0,58,32,0,116,101,114,109,105,110,97,116,105,110,103,32,119,105,116,104,32,37,115,32,101,120,99,101,112,116,105,111,110,32,111,102,32,116,121,112,101,32,37,115,58,32,37,115,0,116,101,114,109,105,110,97,116,105,110,103,32,119,105,116,104,32,37,115,32,101,120,99,101,112,116,105,111,110,32,111,102,32,116,121,112,101,32,37,115,0,116,101,114,109,105,110,97,116,105,110,103,32,119,105,116,104,32,37,115,32,102,111,114,101,105,103,110,32,101,120,99,101,112,116,105,111,110,0,116,101,114,109,105,110,97,116,105,110,103,0,117,110,99,97,117,103,104,116,0,83,116,57,101,120,99,101,112,116,105,111,110,0,78,49,48,95,95,99,120,120,97,98,105,118,49,49,54,95,95,115,104,105,109,95,116,121,112,101,95,105,110,102,111,69,0,83,116,57,116,121,112,101,95,105,110,102,111,0,78,49,48,95,95,99,120,120,97,98,105,118,49,50,48,95,95,115,105,95,99,108,97,115,115,95,116,121,112,101,95,105,110,102,111,69,0,78,49,48,95,95,99,120,120,97,98,105,118,49,49,55,95,95,99,108,97,115,115,95,116,121,112,101,95,105,110,102,111,69,0,112,116,104,114,101,97,100,95,111,110,99,101,32,102,97,105,108,117,114,101,32,105,110,32,95,95,99,120,97,95,103,101,116,95,103,108,111,98,97,108,115,95,102,97,115,116,40,41,0,99,97,110,110,111,116,32,99,114,101,97,116,101,32,112,116,104,114,101,97,100,32,107,101,121,32,102,111,114,32,95,95,99,120,97,95,103,101,116,95,103,108,111,98,97,108,115,40,41,0,99,97,110,110,111,116,32,122,101,114,111,32,111,117,116,32,116,104,114,101,97,100,32,118,97,108,117,101,32,102,111,114,32,95,95,99,120,97,95,103,101,116,95,103,108,111,98,97,108,115,40,41,0,116,101,114,109,105,110,97,116,101,95,104,97,110,100,108,101,114,32,117,110,101,120,112,101,99,116,101,100,108,121,32,114,101,116,117,114,110,101,100,0,116,101,114,109,105,110,97,116,101,95,104,97,110,100,108,101,114,32,117,110,101,120,112,101,99,116,101,100,108,121,32,116,104,114,101,119,32,97,110,32,101,120,99,101,112,116,105,111,110,0,115,116,100,58,58,98,97,100,95,97,108,108,111,99,0,83,116,57,98,97,100,95,97,108,108,111,99,0,115,116,100,58,58,101,120,99,101,112,116,105,111,110,0,83,116,49,49,108,111,103,105,99,95,101,114,114,111,114,0,83,116,49,51,114,117,110,116,105,109,101,95,101,114,114,111,114,0,83,116,49,54,105,110,118,97,108,105,100,95,97,114,103,117,109,101,110,116,0,83,116,49,50,108,101,110,103,116,104,95,101,114,114,111,114,0,83,116,49,50,111,117,116,95,111,102,95,114,97,110,103,101,0,115,116,100,58,58,98,97,100,95,99,97,115,116,0,83,116,56,98,97,100,95,99,97,115,116,0,115,116,100,58,58,98,97,100,95,116,121,112,101,105,100,0,83,116,49,48,98,97,100,95,116,121,112,101,105,100,0,78,49,48,95,95,99,120,120,97,98,105,118,49,49,57,95,95,112,111,105,110,116,101,114,95,116,121,112,101,95,105,110,102,111,69,0,78,49,48,95,95,99,120,120,97,98,105,118,49,49,55,95,95,112,98,97,115,101,95,116,121,112,101,95,105,110,102,111,69,0,78,49,48,95,95,99,120,120,97,98,105,118,49,50,49,95,95,118,109,105,95,99,108,97,115,115,95,116,121,112,101,95,105,110,102,111,69,0], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+205052);





/* no memory initializer */
var tempDoublePtr = STATICTOP; STATICTOP += 16;

assert(tempDoublePtr % 8 == 0);

function copyTempFloat(ptr) { // functions, because inlining this code increases code size too much

  HEAP8[tempDoublePtr] = HEAP8[ptr];

  HEAP8[tempDoublePtr+1] = HEAP8[ptr+1];

  HEAP8[tempDoublePtr+2] = HEAP8[ptr+2];

  HEAP8[tempDoublePtr+3] = HEAP8[ptr+3];

}

function copyTempDouble(ptr) {

  HEAP8[tempDoublePtr] = HEAP8[ptr];

  HEAP8[tempDoublePtr+1] = HEAP8[ptr+1];

  HEAP8[tempDoublePtr+2] = HEAP8[ptr+2];

  HEAP8[tempDoublePtr+3] = HEAP8[ptr+3];

  HEAP8[tempDoublePtr+4] = HEAP8[ptr+4];

  HEAP8[tempDoublePtr+5] = HEAP8[ptr+5];

  HEAP8[tempDoublePtr+6] = HEAP8[ptr+6];

  HEAP8[tempDoublePtr+7] = HEAP8[ptr+7];

}

// {{PRE_LIBRARY}}


  
  var JSEvents={keyEvent:0,mouseEvent:0,wheelEvent:0,uiEvent:0,focusEvent:0,deviceOrientationEvent:0,deviceMotionEvent:0,fullscreenChangeEvent:0,pointerlockChangeEvent:0,visibilityChangeEvent:0,touchEvent:0,lastGamepadState:null,lastGamepadStateFrame:null,numGamepadsConnected:0,previousFullscreenElement:null,previousScreenX:null,previousScreenY:null,removeEventListenersRegistered:false,staticInit:function () {
        if (typeof window !== 'undefined') {
          window.addEventListener("gamepadconnected", function() { ++JSEvents.numGamepadsConnected; });
          window.addEventListener("gamepaddisconnected", function() { --JSEvents.numGamepadsConnected; });
          
          // Chromium does not fire the gamepadconnected event on reload, so we need to get the number of gamepads here as a workaround.
          // See https://bugs.chromium.org/p/chromium/issues/detail?id=502824
          var firstState = navigator.getGamepads ? navigator.getGamepads() : (navigator.webkitGetGamepads ? navigator.webkitGetGamepads() : null);
          if (firstState) {
            JSEvents.numGamepadsConnected = firstState.length;
          }
        }
      },registerRemoveEventListeners:function () {
        if (!JSEvents.removeEventListenersRegistered) {
        __ATEXIT__.push(function() {
            for(var i = JSEvents.eventHandlers.length-1; i >= 0; --i) {
              JSEvents._removeHandler(i);
            }
           });
          JSEvents.removeEventListenersRegistered = true;
        }
      },findEventTarget:function (target) {
        if (target) {
          if (typeof target == "number") {
            target = Pointer_stringify(target);
          }
          if (target == '#window') return window;
          else if (target == '#document') return document;
          else if (target == '#screen') return window.screen;
          else if (target == '#canvas') return Module['canvas'];
  
          if (typeof target == 'string') return document.getElementById(target);
          else return target;
        } else {
          // The sensible target varies between events, but use window as the default
          // since DOM events mostly can default to that. Specific callback registrations
          // override their own defaults.
          return window;
        }
      },deferredCalls:[],deferCall:function (targetFunction, precedence, argsList) {
        function arraysHaveEqualContent(arrA, arrB) {
          if (arrA.length != arrB.length) return false;
  
          for(var i in arrA) {
            if (arrA[i] != arrB[i]) return false;
          }
          return true;
        }
        // Test if the given call was already queued, and if so, don't add it again.
        for(var i in JSEvents.deferredCalls) {
          var call = JSEvents.deferredCalls[i];
          if (call.targetFunction == targetFunction && arraysHaveEqualContent(call.argsList, argsList)) {
            return;
          }
        }
        JSEvents.deferredCalls.push({
          targetFunction: targetFunction,
          precedence: precedence,
          argsList: argsList
        });
  
        JSEvents.deferredCalls.sort(function(x,y) { return x.precedence < y.precedence; });
      },removeDeferredCalls:function (targetFunction) {
        for(var i = 0; i < JSEvents.deferredCalls.length; ++i) {
          if (JSEvents.deferredCalls[i].targetFunction == targetFunction) {
            JSEvents.deferredCalls.splice(i, 1);
            --i;
          }
        }
      },canPerformEventHandlerRequests:function () {
        return JSEvents.inEventHandler && JSEvents.currentEventHandler.allowsDeferredCalls;
      },runDeferredCalls:function () {
        if (!JSEvents.canPerformEventHandlerRequests()) {
          return;
        }
        for(var i = 0; i < JSEvents.deferredCalls.length; ++i) {
          var call = JSEvents.deferredCalls[i];
          JSEvents.deferredCalls.splice(i, 1);
          --i;
          call.targetFunction.apply(this, call.argsList);
        }
      },inEventHandler:0,currentEventHandler:null,eventHandlers:[],isInternetExplorer:function () { return navigator.userAgent.indexOf('MSIE') !== -1 || navigator.appVersion.indexOf('Trident/') > 0; },removeAllHandlersOnTarget:function (target, eventTypeString) {
        for(var i = 0; i < JSEvents.eventHandlers.length; ++i) {
          if (JSEvents.eventHandlers[i].target == target && 
            (!eventTypeString || eventTypeString == JSEvents.eventHandlers[i].eventTypeString)) {
             JSEvents._removeHandler(i--);
           }
        }
      },_removeHandler:function (i) {
        var h = JSEvents.eventHandlers[i];
        h.target.removeEventListener(h.eventTypeString, h.eventListenerFunc, h.useCapture);
        JSEvents.eventHandlers.splice(i, 1);
      },registerOrRemoveHandler:function (eventHandler) {
        var jsEventHandler = function jsEventHandler(event) {
          // Increment nesting count for the event handler.
          ++JSEvents.inEventHandler;
          JSEvents.currentEventHandler = eventHandler;
          // Process any old deferred calls the user has placed.
          JSEvents.runDeferredCalls();
          // Process the actual event, calls back to user C code handler.
          eventHandler.handlerFunc(event);
          // Process any new deferred calls that were placed right now from this event handler.
          JSEvents.runDeferredCalls();
          // Out of event handler - restore nesting count.
          --JSEvents.inEventHandler;
        }
        
        if (eventHandler.callbackfunc) {
          eventHandler.eventListenerFunc = jsEventHandler;
          eventHandler.target.addEventListener(eventHandler.eventTypeString, jsEventHandler, eventHandler.useCapture);
          JSEvents.eventHandlers.push(eventHandler);
          JSEvents.registerRemoveEventListeners();
        } else {
          for(var i = 0; i < JSEvents.eventHandlers.length; ++i) {
            if (JSEvents.eventHandlers[i].target == eventHandler.target
             && JSEvents.eventHandlers[i].eventTypeString == eventHandler.eventTypeString) {
               JSEvents._removeHandler(i--);
             }
          }
        }
      },registerKeyEventCallback:function (target, userData, useCapture, callbackfunc, eventTypeId, eventTypeString) {
        if (!JSEvents.keyEvent) {
          JSEvents.keyEvent = _malloc( 164 );
        }
        var handlerFunc = function(event) {
          var e = event || window.event;
          stringToUTF8(e.key ? e.key : "", JSEvents.keyEvent + 0, 32);
          stringToUTF8(e.code ? e.code : "", JSEvents.keyEvent + 32, 32);
          HEAP32[(((JSEvents.keyEvent)+(64))>>2)]=e.location;
          HEAP32[(((JSEvents.keyEvent)+(68))>>2)]=e.ctrlKey;
          HEAP32[(((JSEvents.keyEvent)+(72))>>2)]=e.shiftKey;
          HEAP32[(((JSEvents.keyEvent)+(76))>>2)]=e.altKey;
          HEAP32[(((JSEvents.keyEvent)+(80))>>2)]=e.metaKey;
          HEAP32[(((JSEvents.keyEvent)+(84))>>2)]=e.repeat;
          stringToUTF8(e.locale ? e.locale : "", JSEvents.keyEvent + 88, 32);
          stringToUTF8(e.char ? e.char : "", JSEvents.keyEvent + 120, 32);
          HEAP32[(((JSEvents.keyEvent)+(152))>>2)]=e.charCode;
          HEAP32[(((JSEvents.keyEvent)+(156))>>2)]=e.keyCode;
          HEAP32[(((JSEvents.keyEvent)+(160))>>2)]=e.which;
          var shouldCancel = Module['dynCall_iiii'](callbackfunc, eventTypeId, JSEvents.keyEvent, userData);
          if (shouldCancel) {
            e.preventDefault();
          }
        };
  
        var eventHandler = {
          target: JSEvents.findEventTarget(target),
          allowsDeferredCalls: JSEvents.isInternetExplorer() ? false : true, // MSIE doesn't allow fullscreen and pointerlock requests from key handlers, others do.
          eventTypeString: eventTypeString,
          callbackfunc: callbackfunc,
          handlerFunc: handlerFunc,
          useCapture: useCapture
        };
        JSEvents.registerOrRemoveHandler(eventHandler);
      },getBoundingClientRectOrZeros:function (target) {
        return target.getBoundingClientRect ? target.getBoundingClientRect() : { left: 0, top: 0 };
      },fillMouseEventData:function (eventStruct, e, target) {
        HEAPF64[((eventStruct)>>3)]=JSEvents.tick();
        HEAP32[(((eventStruct)+(8))>>2)]=e.screenX;
        HEAP32[(((eventStruct)+(12))>>2)]=e.screenY;
        HEAP32[(((eventStruct)+(16))>>2)]=e.clientX;
        HEAP32[(((eventStruct)+(20))>>2)]=e.clientY;
        HEAP32[(((eventStruct)+(24))>>2)]=e.ctrlKey;
        HEAP32[(((eventStruct)+(28))>>2)]=e.shiftKey;
        HEAP32[(((eventStruct)+(32))>>2)]=e.altKey;
        HEAP32[(((eventStruct)+(36))>>2)]=e.metaKey;
        HEAP16[(((eventStruct)+(40))>>1)]=e.button;
        HEAP16[(((eventStruct)+(42))>>1)]=e.buttons;
        HEAP32[(((eventStruct)+(44))>>2)]=e["movementX"] || e["mozMovementX"] || e["webkitMovementX"] || (e.screenX-JSEvents.previousScreenX);
        HEAP32[(((eventStruct)+(48))>>2)]=e["movementY"] || e["mozMovementY"] || e["webkitMovementY"] || (e.screenY-JSEvents.previousScreenY);
  
        if (Module['canvas']) {
          var rect = Module['canvas'].getBoundingClientRect();
          HEAP32[(((eventStruct)+(60))>>2)]=e.clientX - rect.left;
          HEAP32[(((eventStruct)+(64))>>2)]=e.clientY - rect.top;
        } else { // Canvas is not initialized, return 0.
          HEAP32[(((eventStruct)+(60))>>2)]=0;
          HEAP32[(((eventStruct)+(64))>>2)]=0;
        }
        if (target) {
          var rect = JSEvents.getBoundingClientRectOrZeros(target);
          HEAP32[(((eventStruct)+(52))>>2)]=e.clientX - rect.left;
          HEAP32[(((eventStruct)+(56))>>2)]=e.clientY - rect.top;        
        } else { // No specific target passed, return 0.
          HEAP32[(((eventStruct)+(52))>>2)]=0;
          HEAP32[(((eventStruct)+(56))>>2)]=0;
        }
        // wheel and mousewheel events contain wrong screenX/screenY on chrome/opera
        // https://github.com/kripken/emscripten/pull/4997
        // https://bugs.chromium.org/p/chromium/issues/detail?id=699956
        if (e.type !== 'wheel' && e.type !== 'mousewheel') {
          JSEvents.previousScreenX = e.screenX;
          JSEvents.previousScreenY = e.screenY;
        }
      },registerMouseEventCallback:function (target, userData, useCapture, callbackfunc, eventTypeId, eventTypeString) {
        if (!JSEvents.mouseEvent) {
          JSEvents.mouseEvent = _malloc( 72 );
        }
        target = JSEvents.findEventTarget(target);
        var handlerFunc = function(event) {
          var e = event || window.event;
          JSEvents.fillMouseEventData(JSEvents.mouseEvent, e, target);
          var shouldCancel = Module['dynCall_iiii'](callbackfunc, eventTypeId, JSEvents.mouseEvent, userData);
          if (shouldCancel) {
            e.preventDefault();
          }
        };
  
        var eventHandler = {
          target: target,
          allowsDeferredCalls: eventTypeString != 'mousemove' && eventTypeString != 'mouseenter' && eventTypeString != 'mouseleave', // Mouse move events do not allow fullscreen/pointer lock requests to be handled in them!
          eventTypeString: eventTypeString,
          callbackfunc: callbackfunc,
          handlerFunc: handlerFunc,
          useCapture: useCapture
        };
        // In IE, mousedown events don't either allow deferred calls to be run!
        if (JSEvents.isInternetExplorer() && eventTypeString == 'mousedown') eventHandler.allowsDeferredCalls = false;
        JSEvents.registerOrRemoveHandler(eventHandler);
      },registerWheelEventCallback:function (target, userData, useCapture, callbackfunc, eventTypeId, eventTypeString) {
        if (!JSEvents.wheelEvent) {
          JSEvents.wheelEvent = _malloc( 104 );
        }
        target = JSEvents.findEventTarget(target);
        // The DOM Level 3 events spec event 'wheel'
        var wheelHandlerFunc = function(event) {
          var e = event || window.event;
          JSEvents.fillMouseEventData(JSEvents.wheelEvent, e, target);
          HEAPF64[(((JSEvents.wheelEvent)+(72))>>3)]=e["deltaX"];
          HEAPF64[(((JSEvents.wheelEvent)+(80))>>3)]=e["deltaY"];
          HEAPF64[(((JSEvents.wheelEvent)+(88))>>3)]=e["deltaZ"];
          HEAP32[(((JSEvents.wheelEvent)+(96))>>2)]=e["deltaMode"];
          var shouldCancel = Module['dynCall_iiii'](callbackfunc, eventTypeId, JSEvents.wheelEvent, userData);
          if (shouldCancel) {
            e.preventDefault();
          }
        };
        // The 'mousewheel' event as implemented in Safari 6.0.5
        var mouseWheelHandlerFunc = function(event) {
          var e = event || window.event;
          JSEvents.fillMouseEventData(JSEvents.wheelEvent, e, target);
          HEAPF64[(((JSEvents.wheelEvent)+(72))>>3)]=e["wheelDeltaX"] || 0;
          HEAPF64[(((JSEvents.wheelEvent)+(80))>>3)]=-(e["wheelDeltaY"] ? e["wheelDeltaY"] : e["wheelDelta"]) /* 1. Invert to unify direction with the DOM Level 3 wheel event. 2. MSIE does not provide wheelDeltaY, so wheelDelta is used as a fallback. */;
          HEAPF64[(((JSEvents.wheelEvent)+(88))>>3)]=0 /* Not available */;
          HEAP32[(((JSEvents.wheelEvent)+(96))>>2)]=0 /* DOM_DELTA_PIXEL */;
          var shouldCancel = Module['dynCall_iiii'](callbackfunc, eventTypeId, JSEvents.wheelEvent, userData);
          if (shouldCancel) {
            e.preventDefault();
          }
        };
  
        var eventHandler = {
          target: target,
          allowsDeferredCalls: true,
          eventTypeString: eventTypeString,
          callbackfunc: callbackfunc,
          handlerFunc: (eventTypeString == 'wheel') ? wheelHandlerFunc : mouseWheelHandlerFunc,
          useCapture: useCapture
        };
        JSEvents.registerOrRemoveHandler(eventHandler);
      },pageScrollPos:function () {
        if (window.pageXOffset > 0 || window.pageYOffset > 0) {
          return [window.pageXOffset, window.pageYOffset];
        }
        if (typeof document.documentElement.scrollLeft !== 'undefined' || typeof document.documentElement.scrollTop !== 'undefined') {
          return [document.documentElement.scrollLeft, document.documentElement.scrollTop];
        }
        return [document.body.scrollLeft|0, document.body.scrollTop|0];
      },registerUiEventCallback:function (target, userData, useCapture, callbackfunc, eventTypeId, eventTypeString) {
        if (!JSEvents.uiEvent) {
          JSEvents.uiEvent = _malloc( 36 );
        }
  
        if (eventTypeString == "scroll" && !target) {
          target = document; // By default read scroll events on document rather than window.
        } else {
          target = JSEvents.findEventTarget(target);
        }
  
        var handlerFunc = function(event) {
          var e = event || window.event;
          if (e.target != target) {
            // Never take ui events such as scroll via a 'bubbled' route, but always from the direct element that
            // was targeted. Otherwise e.g. if app logs a message in response to a page scroll, the Emscripten log
            // message box could cause to scroll, generating a new (bubbled) scroll message, causing a new log print,
            // causing a new scroll, etc..
            return;
          }
          var scrollPos = JSEvents.pageScrollPos();
          HEAP32[((JSEvents.uiEvent)>>2)]=e.detail;
          HEAP32[(((JSEvents.uiEvent)+(4))>>2)]=document.body.clientWidth;
          HEAP32[(((JSEvents.uiEvent)+(8))>>2)]=document.body.clientHeight;
          HEAP32[(((JSEvents.uiEvent)+(12))>>2)]=window.innerWidth;
          HEAP32[(((JSEvents.uiEvent)+(16))>>2)]=window.innerHeight;
          HEAP32[(((JSEvents.uiEvent)+(20))>>2)]=window.outerWidth;
          HEAP32[(((JSEvents.uiEvent)+(24))>>2)]=window.outerHeight;
          HEAP32[(((JSEvents.uiEvent)+(28))>>2)]=scrollPos[0];
          HEAP32[(((JSEvents.uiEvent)+(32))>>2)]=scrollPos[1];
          var shouldCancel = Module['dynCall_iiii'](callbackfunc, eventTypeId, JSEvents.uiEvent, userData);
          if (shouldCancel) {
            e.preventDefault();
          }
        };
  
        var eventHandler = {
          target: target,
          allowsDeferredCalls: false, // Neither scroll or resize events allow running requests inside them.
          eventTypeString: eventTypeString,
          callbackfunc: callbackfunc,
          handlerFunc: handlerFunc,
          useCapture: useCapture
        };
        JSEvents.registerOrRemoveHandler(eventHandler);
      },getNodeNameForTarget:function (target) {
        if (!target) return '';
        if (target == window) return '#window';
        if (target == window.screen) return '#screen';
        return (target && target.nodeName) ? target.nodeName : '';
      },registerFocusEventCallback:function (target, userData, useCapture, callbackfunc, eventTypeId, eventTypeString) {
        if (!JSEvents.focusEvent) {
          JSEvents.focusEvent = _malloc( 256 );
        }
        var handlerFunc = function(event) {
          var e = event || window.event;
  
          var nodeName = JSEvents.getNodeNameForTarget(e.target);
          var id = e.target.id ? e.target.id : '';
          stringToUTF8(nodeName, JSEvents.focusEvent + 0, 128);
          stringToUTF8(id, JSEvents.focusEvent + 128, 128);
          var shouldCancel = Module['dynCall_iiii'](callbackfunc, eventTypeId, JSEvents.focusEvent, userData);
          if (shouldCancel) {
            e.preventDefault();
          }
        };
  
        var eventHandler = {
          target: JSEvents.findEventTarget(target),
          allowsDeferredCalls: false,
          eventTypeString: eventTypeString,
          callbackfunc: callbackfunc,
          handlerFunc: handlerFunc,
          useCapture: useCapture
        };
        JSEvents.registerOrRemoveHandler(eventHandler);
      },tick:function () {
        if (window['performance'] && window['performance']['now']) return window['performance']['now']();
        else return Date.now();
      },registerDeviceOrientationEventCallback:function (target, userData, useCapture, callbackfunc, eventTypeId, eventTypeString) {
        if (!JSEvents.deviceOrientationEvent) {
          JSEvents.deviceOrientationEvent = _malloc( 40 );
        }
        var handlerFunc = function(event) {
          var e = event || window.event;
  
          HEAPF64[((JSEvents.deviceOrientationEvent)>>3)]=JSEvents.tick();
          HEAPF64[(((JSEvents.deviceOrientationEvent)+(8))>>3)]=e.alpha;
          HEAPF64[(((JSEvents.deviceOrientationEvent)+(16))>>3)]=e.beta;
          HEAPF64[(((JSEvents.deviceOrientationEvent)+(24))>>3)]=e.gamma;
          HEAP32[(((JSEvents.deviceOrientationEvent)+(32))>>2)]=e.absolute;
  
          var shouldCancel = Module['dynCall_iiii'](callbackfunc, eventTypeId, JSEvents.deviceOrientationEvent, userData);
          if (shouldCancel) {
            e.preventDefault();
          }
        };
  
        var eventHandler = {
          target: JSEvents.findEventTarget(target),
          allowsDeferredCalls: false,
          eventTypeString: eventTypeString,
          callbackfunc: callbackfunc,
          handlerFunc: handlerFunc,
          useCapture: useCapture
        };
        JSEvents.registerOrRemoveHandler(eventHandler);
      },registerDeviceMotionEventCallback:function (target, userData, useCapture, callbackfunc, eventTypeId, eventTypeString) {
        if (!JSEvents.deviceMotionEvent) {
          JSEvents.deviceMotionEvent = _malloc( 80 );
        }
        var handlerFunc = function(event) {
          var e = event || window.event;
  
          HEAPF64[((JSEvents.deviceMotionEvent)>>3)]=JSEvents.tick();
          HEAPF64[(((JSEvents.deviceMotionEvent)+(8))>>3)]=e.acceleration.x;
          HEAPF64[(((JSEvents.deviceMotionEvent)+(16))>>3)]=e.acceleration.y;
          HEAPF64[(((JSEvents.deviceMotionEvent)+(24))>>3)]=e.acceleration.z;
          HEAPF64[(((JSEvents.deviceMotionEvent)+(32))>>3)]=e.accelerationIncludingGravity.x;
          HEAPF64[(((JSEvents.deviceMotionEvent)+(40))>>3)]=e.accelerationIncludingGravity.y;
          HEAPF64[(((JSEvents.deviceMotionEvent)+(48))>>3)]=e.accelerationIncludingGravity.z;
          HEAPF64[(((JSEvents.deviceMotionEvent)+(56))>>3)]=e.rotationRate.alpha;
          HEAPF64[(((JSEvents.deviceMotionEvent)+(64))>>3)]=e.rotationRate.beta;
          HEAPF64[(((JSEvents.deviceMotionEvent)+(72))>>3)]=e.rotationRate.gamma;
  
          var shouldCancel = Module['dynCall_iiii'](callbackfunc, eventTypeId, JSEvents.deviceMotionEvent, userData);
          if (shouldCancel) {
            e.preventDefault();
          }
        };
  
        var eventHandler = {
          target: JSEvents.findEventTarget(target),
          allowsDeferredCalls: false,
          eventTypeString: eventTypeString,
          callbackfunc: callbackfunc,
          handlerFunc: handlerFunc,
          useCapture: useCapture
        };
        JSEvents.registerOrRemoveHandler(eventHandler);
      },screenOrientation:function () {
        if (!window.screen) return undefined;
        return window.screen.orientation || window.screen.mozOrientation || window.screen.webkitOrientation || window.screen.msOrientation;
      },fillOrientationChangeEventData:function (eventStruct, e) {
        var orientations  = ["portrait-primary", "portrait-secondary", "landscape-primary", "landscape-secondary"];
        var orientations2 = ["portrait",         "portrait",           "landscape",         "landscape"];
  
        var orientationString = JSEvents.screenOrientation();
        var orientation = orientations.indexOf(orientationString);
        if (orientation == -1) {
          orientation = orientations2.indexOf(orientationString);
        }
  
        HEAP32[((eventStruct)>>2)]=1 << orientation;
        HEAP32[(((eventStruct)+(4))>>2)]=window.orientation;
      },registerOrientationChangeEventCallback:function (target, userData, useCapture, callbackfunc, eventTypeId, eventTypeString) {
        if (!JSEvents.orientationChangeEvent) {
          JSEvents.orientationChangeEvent = _malloc( 8 );
        }
  
        if (!target) {
          target = window.screen; // Orientation events need to be captured from 'window.screen' instead of 'window'
        } else {
          target = JSEvents.findEventTarget(target);
        }
  
        var handlerFunc = function(event) {
          var e = event || window.event;
  
          JSEvents.fillOrientationChangeEventData(JSEvents.orientationChangeEvent, e);
  
          var shouldCancel = Module['dynCall_iiii'](callbackfunc, eventTypeId, JSEvents.orientationChangeEvent, userData);
          if (shouldCancel) {
            e.preventDefault();
          }
        };
  
        if (eventTypeString == "orientationchange" && window.screen.mozOrientation !== undefined) {
          eventTypeString = "mozorientationchange";
        }
  
        var eventHandler = {
          target: target,
          allowsDeferredCalls: false,
          eventTypeString: eventTypeString,
          callbackfunc: callbackfunc,
          handlerFunc: handlerFunc,
          useCapture: useCapture
        };
        JSEvents.registerOrRemoveHandler(eventHandler);
      },fullscreenEnabled:function () {
        return document.fullscreenEnabled || document.mozFullScreenEnabled || document.webkitFullscreenEnabled || document.msFullscreenEnabled;
      },fillFullscreenChangeEventData:function (eventStruct, e) {
        var fullscreenElement = document.fullscreenElement || document.mozFullScreenElement || document.webkitFullscreenElement || document.msFullscreenElement;
        var isFullscreen = !!fullscreenElement;
        HEAP32[((eventStruct)>>2)]=isFullscreen;
        HEAP32[(((eventStruct)+(4))>>2)]=JSEvents.fullscreenEnabled();
        // If transitioning to fullscreen, report info about the element that is now fullscreen.
        // If transitioning to windowed mode, report info about the element that just was fullscreen.
        var reportedElement = isFullscreen ? fullscreenElement : JSEvents.previousFullscreenElement;
        var nodeName = JSEvents.getNodeNameForTarget(reportedElement);
        var id = (reportedElement && reportedElement.id) ? reportedElement.id : '';
        stringToUTF8(nodeName, eventStruct + 8, 128);
        stringToUTF8(id, eventStruct + 136, 128);
        HEAP32[(((eventStruct)+(264))>>2)]=reportedElement ? reportedElement.clientWidth : 0;
        HEAP32[(((eventStruct)+(268))>>2)]=reportedElement ? reportedElement.clientHeight : 0;
        HEAP32[(((eventStruct)+(272))>>2)]=screen.width;
        HEAP32[(((eventStruct)+(276))>>2)]=screen.height;
        if (isFullscreen) {
          JSEvents.previousFullscreenElement = fullscreenElement;
        }
      },registerFullscreenChangeEventCallback:function (target, userData, useCapture, callbackfunc, eventTypeId, eventTypeString) {
        if (!JSEvents.fullscreenChangeEvent) {
          JSEvents.fullscreenChangeEvent = _malloc( 280 );
        }
  
        if (!target) {
          target = document; // Fullscreen change events need to be captured from 'document' by default instead of 'window'
        } else {
          target = JSEvents.findEventTarget(target);
        }
  
        var handlerFunc = function(event) {
          var e = event || window.event;
  
          JSEvents.fillFullscreenChangeEventData(JSEvents.fullscreenChangeEvent, e);
  
          var shouldCancel = Module['dynCall_iiii'](callbackfunc, eventTypeId, JSEvents.fullscreenChangeEvent, userData);
          if (shouldCancel) {
            e.preventDefault();
          }
        };
  
        var eventHandler = {
          target: target,
          allowsDeferredCalls: false,
          eventTypeString: eventTypeString,
          callbackfunc: callbackfunc,
          handlerFunc: handlerFunc,
          useCapture: useCapture
        };
        JSEvents.registerOrRemoveHandler(eventHandler);
      },resizeCanvasForFullscreen:function (target, strategy) {
        var restoreOldStyle = __registerRestoreOldStyle(target);
        var cssWidth = strategy.softFullscreen ? window.innerWidth : screen.width;
        var cssHeight = strategy.softFullscreen ? window.innerHeight : screen.height;
        var rect = target.getBoundingClientRect();
        var windowedCssWidth = rect.right - rect.left;
        var windowedCssHeight = rect.bottom - rect.top;
        var windowedRttWidth = target.width;
        var windowedRttHeight = target.height;
  
        if (strategy.scaleMode == 3) {
          __setLetterbox(target, (cssHeight - windowedCssHeight) / 2, (cssWidth - windowedCssWidth) / 2);
          cssWidth = windowedCssWidth;
          cssHeight = windowedCssHeight;
        } else if (strategy.scaleMode == 2) {
          if (cssWidth*windowedRttHeight < windowedRttWidth*cssHeight) {
            var desiredCssHeight = windowedRttHeight * cssWidth / windowedRttWidth;
            __setLetterbox(target, (cssHeight - desiredCssHeight) / 2, 0);
            cssHeight = desiredCssHeight;
          } else {
            var desiredCssWidth = windowedRttWidth * cssHeight / windowedRttHeight;
            __setLetterbox(target, 0, (cssWidth - desiredCssWidth) / 2);
            cssWidth = desiredCssWidth;
          }
        }
  
        // If we are adding padding, must choose a background color or otherwise Chrome will give the
        // padding a default white color. Do it only if user has not customized their own background color.
        if (!target.style.backgroundColor) target.style.backgroundColor = 'black';
        // IE11 does the same, but requires the color to be set in the document body.
        if (!document.body.style.backgroundColor) document.body.style.backgroundColor = 'black'; // IE11
        // Firefox always shows black letterboxes independent of style color.
  
        target.style.width = cssWidth + 'px';
        target.style.height = cssHeight + 'px';
  
        if (strategy.filteringMode == 1) {
          target.style.imageRendering = 'optimizeSpeed';
          target.style.imageRendering = '-moz-crisp-edges';
          target.style.imageRendering = '-o-crisp-edges';
          target.style.imageRendering = '-webkit-optimize-contrast';
          target.style.imageRendering = 'optimize-contrast';
          target.style.imageRendering = 'crisp-edges';
          target.style.imageRendering = 'pixelated';
        }
  
        var dpiScale = (strategy.canvasResolutionScaleMode == 2) ? window.devicePixelRatio : 1;
        if (strategy.canvasResolutionScaleMode != 0) {
          target.width = cssWidth * dpiScale;
          target.height = cssHeight * dpiScale;
          if (target.GLctxObject) target.GLctxObject.GLctx.viewport(0, 0, target.width, target.height);
        }
        return restoreOldStyle;
      },requestFullscreen:function (target, strategy) {
        // EMSCRIPTEN_FULLSCREEN_SCALE_DEFAULT + EMSCRIPTEN_FULLSCREEN_CANVAS_SCALE_NONE is a mode where no extra logic is performed to the DOM elements.
        if (strategy.scaleMode != 0 || strategy.canvasResolutionScaleMode != 0) {
          JSEvents.resizeCanvasForFullscreen(target, strategy);
        }
  
        if (target.requestFullscreen) {
          target.requestFullscreen();
        } else if (target.msRequestFullscreen) {
          target.msRequestFullscreen();
        } else if (target.mozRequestFullScreen) {
          target.mozRequestFullScreen();
        } else if (target.mozRequestFullscreen) {
          target.mozRequestFullscreen();
        } else if (target.webkitRequestFullscreen) {
          target.webkitRequestFullscreen(Element.ALLOW_KEYBOARD_INPUT);
        } else {
          if (typeof JSEvents.fullscreenEnabled() === 'undefined') {
            return -1;
          } else {
            return -3;
          }
        }
  
        if (strategy.canvasResizedCallback) {
          Module['dynCall_iiii'](strategy.canvasResizedCallback, 37, 0, strategy.canvasResizedCallbackUserData);
        }
  
        return 0;
      },fillPointerlockChangeEventData:function (eventStruct, e) {
        var pointerLockElement = document.pointerLockElement || document.mozPointerLockElement || document.webkitPointerLockElement || document.msPointerLockElement;
        var isPointerlocked = !!pointerLockElement;
        HEAP32[((eventStruct)>>2)]=isPointerlocked;
        var nodeName = JSEvents.getNodeNameForTarget(pointerLockElement);
        var id = (pointerLockElement && pointerLockElement.id) ? pointerLockElement.id : '';
        stringToUTF8(nodeName, eventStruct + 4, 128);
        stringToUTF8(id, eventStruct + 132, 128);
      },registerPointerlockChangeEventCallback:function (target, userData, useCapture, callbackfunc, eventTypeId, eventTypeString) {
        if (!JSEvents.pointerlockChangeEvent) {
          JSEvents.pointerlockChangeEvent = _malloc( 260 );
        }
  
        if (!target) {
          target = document; // Pointer lock change events need to be captured from 'document' by default instead of 'window'
        } else {
          target = JSEvents.findEventTarget(target);
        }
  
        var handlerFunc = function(event) {
          var e = event || window.event;
  
          JSEvents.fillPointerlockChangeEventData(JSEvents.pointerlockChangeEvent, e);
  
          var shouldCancel = Module['dynCall_iiii'](callbackfunc, eventTypeId, JSEvents.pointerlockChangeEvent, userData);
          if (shouldCancel) {
            e.preventDefault();
          }
        };
  
        var eventHandler = {
          target: target,
          allowsDeferredCalls: false,
          eventTypeString: eventTypeString,
          callbackfunc: callbackfunc,
          handlerFunc: handlerFunc,
          useCapture: useCapture
        };
        JSEvents.registerOrRemoveHandler(eventHandler);
      },registerPointerlockErrorEventCallback:function (target, userData, useCapture, callbackfunc, eventTypeId, eventTypeString) {
        if (!target) {
          target = document; // Pointer lock events need to be captured from 'document' by default instead of 'window'
        } else {
          target = JSEvents.findEventTarget(target);
        }
  
        var handlerFunc = function(event) {
          var e = event || window.event;
  
          var shouldCancel = Module['dynCall_iiii'](callbackfunc, eventTypeId, 0, userData);
          if (shouldCancel) {
            e.preventDefault();
          }
        };
  
        var eventHandler = {
          target: target,
          allowsDeferredCalls: false,
          eventTypeString: eventTypeString,
          callbackfunc: callbackfunc,
          handlerFunc: handlerFunc,
          useCapture: useCapture
        };
        JSEvents.registerOrRemoveHandler(eventHandler);
      },requestPointerLock:function (target) {
        if (target.requestPointerLock) {
          target.requestPointerLock();
        } else if (target.mozRequestPointerLock) {
          target.mozRequestPointerLock();
        } else if (target.webkitRequestPointerLock) {
          target.webkitRequestPointerLock();
        } else if (target.msRequestPointerLock) {
          target.msRequestPointerLock();
        } else {
          // document.body is known to accept pointer lock, so use that to differentiate if the user passed a bad element,
          // or if the whole browser just doesn't support the feature.
          if (document.body.requestPointerLock || document.body.mozRequestPointerLock || document.body.webkitRequestPointerLock || document.body.msRequestPointerLock) {
            return -3;
          } else {
            return -1;
          }
        }
        return 0;
      },fillVisibilityChangeEventData:function (eventStruct, e) {
        var visibilityStates = [ "hidden", "visible", "prerender", "unloaded" ];
        var visibilityState = visibilityStates.indexOf(document.visibilityState);
  
        HEAP32[((eventStruct)>>2)]=document.hidden;
        HEAP32[(((eventStruct)+(4))>>2)]=visibilityState;
      },registerVisibilityChangeEventCallback:function (target, userData, useCapture, callbackfunc, eventTypeId, eventTypeString) {
        if (!JSEvents.visibilityChangeEvent) {
          JSEvents.visibilityChangeEvent = _malloc( 8 );
        }
  
        if (!target) {
          target = document; // Visibility change events need to be captured from 'document' by default instead of 'window'
        } else {
          target = JSEvents.findEventTarget(target);
        }
  
        var handlerFunc = function(event) {
          var e = event || window.event;
  
          JSEvents.fillVisibilityChangeEventData(JSEvents.visibilityChangeEvent, e);
  
          var shouldCancel = Module['dynCall_iiii'](callbackfunc, eventTypeId, JSEvents.visibilityChangeEvent, userData);
          if (shouldCancel) {
            e.preventDefault();
          }
        };
  
        var eventHandler = {
          target: target,
          allowsDeferredCalls: false,
          eventTypeString: eventTypeString,
          callbackfunc: callbackfunc,
          handlerFunc: handlerFunc,
          useCapture: useCapture
        };
        JSEvents.registerOrRemoveHandler(eventHandler);
      },registerTouchEventCallback:function (target, userData, useCapture, callbackfunc, eventTypeId, eventTypeString) {
        if (!JSEvents.touchEvent) {
          JSEvents.touchEvent = _malloc( 1684 );
        }
  
        target = JSEvents.findEventTarget(target);
  
        var handlerFunc = function(event) {
          var e = event || window.event;
  
          var touches = {};
          for(var i = 0; i < e.touches.length; ++i) {
            var touch = e.touches[i];
            touches[touch.identifier] = touch;
          }
          for(var i = 0; i < e.changedTouches.length; ++i) {
            var touch = e.changedTouches[i];
            touches[touch.identifier] = touch;
            touch.changed = true;
          }
          for(var i = 0; i < e.targetTouches.length; ++i) {
            var touch = e.targetTouches[i];
            touches[touch.identifier].onTarget = true;
          }
          
          var ptr = JSEvents.touchEvent;
          HEAP32[(((ptr)+(4))>>2)]=e.ctrlKey;
          HEAP32[(((ptr)+(8))>>2)]=e.shiftKey;
          HEAP32[(((ptr)+(12))>>2)]=e.altKey;
          HEAP32[(((ptr)+(16))>>2)]=e.metaKey;
          ptr += 20; // Advance to the start of the touch array.
          var canvasRect = Module['canvas'] ? Module['canvas'].getBoundingClientRect() : undefined;
          var targetRect = JSEvents.getBoundingClientRectOrZeros(target);
          var numTouches = 0;
          for(var i in touches) {
            var t = touches[i];
            HEAP32[((ptr)>>2)]=t.identifier;
            HEAP32[(((ptr)+(4))>>2)]=t.screenX;
            HEAP32[(((ptr)+(8))>>2)]=t.screenY;
            HEAP32[(((ptr)+(12))>>2)]=t.clientX;
            HEAP32[(((ptr)+(16))>>2)]=t.clientY;
            HEAP32[(((ptr)+(20))>>2)]=t.pageX;
            HEAP32[(((ptr)+(24))>>2)]=t.pageY;
            HEAP32[(((ptr)+(28))>>2)]=t.changed;
            HEAP32[(((ptr)+(32))>>2)]=t.onTarget;
            if (canvasRect) {
              HEAP32[(((ptr)+(44))>>2)]=t.clientX - canvasRect.left;
              HEAP32[(((ptr)+(48))>>2)]=t.clientY - canvasRect.top;
            } else {
              HEAP32[(((ptr)+(44))>>2)]=0;
              HEAP32[(((ptr)+(48))>>2)]=0;            
            }
            HEAP32[(((ptr)+(36))>>2)]=t.clientX - targetRect.left;
            HEAP32[(((ptr)+(40))>>2)]=t.clientY - targetRect.top;
            
            ptr += 52;
  
            if (++numTouches >= 32) {
              break;
            }
          }
          HEAP32[((JSEvents.touchEvent)>>2)]=numTouches;
  
          var shouldCancel = Module['dynCall_iiii'](callbackfunc, eventTypeId, JSEvents.touchEvent, userData);
          if (shouldCancel) {
            e.preventDefault();
          }
        };
  
        var eventHandler = {
          target: target,
          allowsDeferredCalls: eventTypeString == 'touchstart' || eventTypeString == 'touchend',
          eventTypeString: eventTypeString,
          callbackfunc: callbackfunc,
          handlerFunc: handlerFunc,
          useCapture: useCapture
        };
        JSEvents.registerOrRemoveHandler(eventHandler);
      },fillGamepadEventData:function (eventStruct, e) {
        HEAPF64[((eventStruct)>>3)]=e.timestamp;
        for(var i = 0; i < e.axes.length; ++i) {
          HEAPF64[(((eventStruct+i*8)+(16))>>3)]=e.axes[i];
        }
        for(var i = 0; i < e.buttons.length; ++i) {
          if (typeof(e.buttons[i]) === 'object') {
            HEAPF64[(((eventStruct+i*8)+(528))>>3)]=e.buttons[i].value;
          } else {
            HEAPF64[(((eventStruct+i*8)+(528))>>3)]=e.buttons[i];
          }
        }
        for(var i = 0; i < e.buttons.length; ++i) {
          if (typeof(e.buttons[i]) === 'object') {
            HEAP32[(((eventStruct+i*4)+(1040))>>2)]=e.buttons[i].pressed;
          } else {
            HEAP32[(((eventStruct+i*4)+(1040))>>2)]=e.buttons[i] == 1.0;
          }
        }
        HEAP32[(((eventStruct)+(1296))>>2)]=e.connected;
        HEAP32[(((eventStruct)+(1300))>>2)]=e.index;
        HEAP32[(((eventStruct)+(8))>>2)]=e.axes.length;
        HEAP32[(((eventStruct)+(12))>>2)]=e.buttons.length;
        stringToUTF8(e.id, eventStruct + 1304, 64);
        stringToUTF8(e.mapping, eventStruct + 1368, 64);
      },registerGamepadEventCallback:function (target, userData, useCapture, callbackfunc, eventTypeId, eventTypeString) {
        if (!JSEvents.gamepadEvent) {
          JSEvents.gamepadEvent = _malloc( 1432 );
        }
  
        var handlerFunc = function(event) {
          var e = event || window.event;
  
          JSEvents.fillGamepadEventData(JSEvents.gamepadEvent, e.gamepad);
  
          var shouldCancel = Module['dynCall_iiii'](callbackfunc, eventTypeId, JSEvents.gamepadEvent, userData);
          if (shouldCancel) {
            e.preventDefault();
          }
        };
  
        var eventHandler = {
          target: JSEvents.findEventTarget(target),
          allowsDeferredCalls: true,
          eventTypeString: eventTypeString,
          callbackfunc: callbackfunc,
          handlerFunc: handlerFunc,
          useCapture: useCapture
        };
        JSEvents.registerOrRemoveHandler(eventHandler);
      },registerBeforeUnloadEventCallback:function (target, userData, useCapture, callbackfunc, eventTypeId, eventTypeString) {
        var handlerFunc = function(event) {
          var e = event || window.event;
  
          var confirmationMessage = Module['dynCall_iiii'](callbackfunc, eventTypeId, 0, userData);
          
          if (confirmationMessage) {
            confirmationMessage = Pointer_stringify(confirmationMessage);
          }
          if (confirmationMessage) {
            e.preventDefault();
            e.returnValue = confirmationMessage;
            return confirmationMessage;
          }
        };
  
        var eventHandler = {
          target: JSEvents.findEventTarget(target),
          allowsDeferredCalls: false,
          eventTypeString: eventTypeString,
          callbackfunc: callbackfunc,
          handlerFunc: handlerFunc,
          useCapture: useCapture
        };
        JSEvents.registerOrRemoveHandler(eventHandler);
      },battery:function () { return navigator.battery || navigator.mozBattery || navigator.webkitBattery; },fillBatteryEventData:function (eventStruct, e) {
        HEAPF64[((eventStruct)>>3)]=e.chargingTime;
        HEAPF64[(((eventStruct)+(8))>>3)]=e.dischargingTime;
        HEAPF64[(((eventStruct)+(16))>>3)]=e.level;
        HEAP32[(((eventStruct)+(24))>>2)]=e.charging;
      },registerBatteryEventCallback:function (target, userData, useCapture, callbackfunc, eventTypeId, eventTypeString) {
        if (!JSEvents.batteryEvent) {
          JSEvents.batteryEvent = _malloc( 32 );
        }
  
        var handlerFunc = function(event) {
          var e = event || window.event;
  
          JSEvents.fillBatteryEventData(JSEvents.batteryEvent, JSEvents.battery());
  
          var shouldCancel = Module['dynCall_iiii'](callbackfunc, eventTypeId, JSEvents.batteryEvent, userData);
          if (shouldCancel) {
            e.preventDefault();
          }
        };
  
        var eventHandler = {
          target: JSEvents.findEventTarget(target),
          allowsDeferredCalls: false,
          eventTypeString: eventTypeString,
          callbackfunc: callbackfunc,
          handlerFunc: handlerFunc,
          useCapture: useCapture
        };
        JSEvents.registerOrRemoveHandler(eventHandler);
      },registerWebGlEventCallback:function (target, userData, useCapture, callbackfunc, eventTypeId, eventTypeString) {
        if (!target) {
          target = Module['canvas'];
        }
        var handlerFunc = function(event) {
          var e = event || window.event;
  
          var shouldCancel = Module['dynCall_iiii'](callbackfunc, eventTypeId, 0, userData);
          if (shouldCancel) {
            e.preventDefault();
          }
        };
  
        var eventHandler = {
          target: JSEvents.findEventTarget(target),
          allowsDeferredCalls: false,
          eventTypeString: eventTypeString,
          callbackfunc: callbackfunc,
          handlerFunc: handlerFunc,
          useCapture: useCapture
        };
        JSEvents.registerOrRemoveHandler(eventHandler);
      }};function _emscripten_set_visibilitychange_callback(userData, useCapture, callbackfunc) {
      JSEvents.registerVisibilityChangeEventCallback(document, userData, useCapture, callbackfunc, 21, "visibilitychange");
      return 0;
    }

  
  var GL={counter:1,lastError:0,buffers:[],mappedBuffers:{},programs:[],framebuffers:[],renderbuffers:[],textures:[],uniforms:[],shaders:[],vaos:[],contexts:[],currentContext:null,offscreenCanvases:{},timerQueriesEXT:[],byteSizeByTypeRoot:5120,byteSizeByType:[1,1,2,2,4,4,4,2,3,4,8],programInfos:{},stringCache:{},tempFixedLengthArray:[],packAlignment:4,unpackAlignment:4,init:function () {
        GL.miniTempBuffer = new Float32Array(GL.MINI_TEMP_BUFFER_SIZE);
        for (var i = 0; i < GL.MINI_TEMP_BUFFER_SIZE; i++) {
          GL.miniTempBufferViews[i] = GL.miniTempBuffer.subarray(0, i+1);
        }
  
        // For functions such as glDrawBuffers, glInvalidateFramebuffer and glInvalidateSubFramebuffer that need to pass a short array to the WebGL API,
        // create a set of short fixed-length arrays to avoid having to generate any garbage when calling those functions.
        for (var i = 0; i < 32; i++) {
          GL.tempFixedLengthArray.push(new Array(i));
        }
      },recordError:function recordError(errorCode) {
        if (!GL.lastError) {
          GL.lastError = errorCode;
        }
      },getNewId:function (table) {
        var ret = GL.counter++;
        for (var i = table.length; i < ret; i++) {
          table[i] = null;
        }
        return ret;
      },MINI_TEMP_BUFFER_SIZE:256,miniTempBuffer:null,miniTempBufferViews:[0],getSource:function (shader, count, string, length) {
        var source = '';
        for (var i = 0; i < count; ++i) {
          var frag;
          if (length) {
            var len = HEAP32[(((length)+(i*4))>>2)];
            if (len < 0) {
              frag = Pointer_stringify(HEAP32[(((string)+(i*4))>>2)]);
            } else {
              frag = Pointer_stringify(HEAP32[(((string)+(i*4))>>2)], len);
            }
          } else {
            frag = Pointer_stringify(HEAP32[(((string)+(i*4))>>2)]);
          }
          source += frag;
        }
        return source;
      },createContext:function (canvas, webGLContextAttributes) {
        if (typeof webGLContextAttributes['majorVersion'] === 'undefined' && typeof webGLContextAttributes['minorVersion'] === 'undefined') {
          webGLContextAttributes['majorVersion'] = 1;
          webGLContextAttributes['minorVersion'] = 0;
        }
  
  
        var ctx;
        var errorInfo = '?';
        function onContextCreationError(event) {
          errorInfo = event.statusMessage || errorInfo;
        }
        try {
          canvas.addEventListener('webglcontextcreationerror', onContextCreationError, false);
          try {
            if (webGLContextAttributes['majorVersion'] == 1 && webGLContextAttributes['minorVersion'] == 0) {
              ctx = canvas.getContext("webgl", webGLContextAttributes) || canvas.getContext("experimental-webgl", webGLContextAttributes);
            } else if (webGLContextAttributes['majorVersion'] == 2 && webGLContextAttributes['minorVersion'] == 0) {
              ctx = canvas.getContext("webgl2", webGLContextAttributes);
            } else {
              throw 'Unsupported WebGL context version ' + majorVersion + '.' + minorVersion + '!'
            }
          } finally {
            canvas.removeEventListener('webglcontextcreationerror', onContextCreationError, false);
          }
          if (!ctx) throw ':(';
        } catch (e) {
          Module.print('Could not create canvas: ' + [errorInfo, e, JSON.stringify(webGLContextAttributes)]);
          return 0;
        }
        // possible GL_DEBUG entry point: ctx = wrapDebugGL(ctx);
  
        if (!ctx) return 0;
        return GL.registerContext(ctx, webGLContextAttributes);
      },registerContext:function (ctx, webGLContextAttributes) {
        var handle = GL.getNewId(GL.contexts);
        var context = {
          handle: handle,
          attributes: webGLContextAttributes,
          version: webGLContextAttributes['majorVersion'],
          GLctx: ctx
        };
  
  
        // Store the created context object so that we can access the context given a canvas without having to pass the parameters again.
        if (ctx.canvas) ctx.canvas.GLctxObject = context;
        GL.contexts[handle] = context;
        if (typeof webGLContextAttributes['enableExtensionsByDefault'] === 'undefined' || webGLContextAttributes['enableExtensionsByDefault']) {
          GL.initExtensions(context);
        }
        return handle;
      },makeContextCurrent:function (contextHandle) {
        var context = GL.contexts[contextHandle];
        if (!context) return false;
        GLctx = Module.ctx = context.GLctx; // Active WebGL context object.
        GL.currentContext = context; // Active Emscripten GL layer context object.
        return true;
      },getContext:function (contextHandle) {
        return GL.contexts[contextHandle];
      },deleteContext:function (contextHandle) {
        if (GL.currentContext === GL.contexts[contextHandle]) GL.currentContext = null;
        if (typeof JSEvents === 'object') JSEvents.removeAllHandlersOnTarget(GL.contexts[contextHandle].GLctx.canvas); // Release all JS event handlers on the DOM element that the GL context is associated with since the context is now deleted.
        if (GL.contexts[contextHandle] && GL.contexts[contextHandle].GLctx.canvas) GL.contexts[contextHandle].GLctx.canvas.GLctxObject = undefined; // Make sure the canvas object no longer refers to the context object so there are no GC surprises.
        GL.contexts[contextHandle] = null;
      },initExtensions:function (context) {
        // If this function is called without a specific context object, init the extensions of the currently active context.
        if (!context) context = GL.currentContext;
  
        if (context.initExtensionsDone) return;
        context.initExtensionsDone = true;
  
        var GLctx = context.GLctx;
  
        context.maxVertexAttribs = GLctx.getParameter(GLctx.MAX_VERTEX_ATTRIBS);
  
        // Detect the presence of a few extensions manually, this GL interop layer itself will need to know if they exist. 
  
        if (context.version < 2) {
          // Extension available from Firefox 26 and Google Chrome 30
          var instancedArraysExt = GLctx.getExtension('ANGLE_instanced_arrays');
          if (instancedArraysExt) {
            GLctx['vertexAttribDivisor'] = function(index, divisor) { instancedArraysExt['vertexAttribDivisorANGLE'](index, divisor); };
            GLctx['drawArraysInstanced'] = function(mode, first, count, primcount) { instancedArraysExt['drawArraysInstancedANGLE'](mode, first, count, primcount); };
            GLctx['drawElementsInstanced'] = function(mode, count, type, indices, primcount) { instancedArraysExt['drawElementsInstancedANGLE'](mode, count, type, indices, primcount); };
          }
  
          // Extension available from Firefox 25 and WebKit
          var vaoExt = GLctx.getExtension('OES_vertex_array_object');
          if (vaoExt) {
            GLctx['createVertexArray'] = function() { return vaoExt['createVertexArrayOES'](); };
            GLctx['deleteVertexArray'] = function(vao) { vaoExt['deleteVertexArrayOES'](vao); };
            GLctx['bindVertexArray'] = function(vao) { vaoExt['bindVertexArrayOES'](vao); };
            GLctx['isVertexArray'] = function(vao) { return vaoExt['isVertexArrayOES'](vao); };
          }
  
          var drawBuffersExt = GLctx.getExtension('WEBGL_draw_buffers');
          if (drawBuffersExt) {
            GLctx['drawBuffers'] = function(n, bufs) { drawBuffersExt['drawBuffersWEBGL'](n, bufs); };
          }
        }
  
        GLctx.disjointTimerQueryExt = GLctx.getExtension("EXT_disjoint_timer_query");
  
        // These are the 'safe' feature-enabling extensions that don't add any performance impact related to e.g. debugging, and
        // should be enabled by default so that client GLES2/GL code will not need to go through extra hoops to get its stuff working.
        // As new extensions are ratified at http://www.khronos.org/registry/webgl/extensions/ , feel free to add your new extensions
        // here, as long as they don't produce a performance impact for users that might not be using those extensions.
        // E.g. debugging-related extensions should probably be off by default.
        var automaticallyEnabledExtensions = [ "OES_texture_float", "OES_texture_half_float", "OES_standard_derivatives",
                                               "OES_vertex_array_object", "WEBGL_compressed_texture_s3tc", "WEBGL_depth_texture",
                                               "OES_element_index_uint", "EXT_texture_filter_anisotropic", "ANGLE_instanced_arrays",
                                               "OES_texture_float_linear", "OES_texture_half_float_linear", "WEBGL_compressed_texture_atc",
                                               "WEBGL_compressed_texture_pvrtc", "EXT_color_buffer_half_float", "WEBGL_color_buffer_float",
                                               "EXT_frag_depth", "EXT_sRGB", "WEBGL_draw_buffers", "WEBGL_shared_resources",
                                               "EXT_shader_texture_lod", "EXT_color_buffer_float"];
  
        function shouldEnableAutomatically(extension) {
          var ret = false;
          automaticallyEnabledExtensions.forEach(function(include) {
            if (ext.indexOf(include) != -1) {
              ret = true;
            }
          });
          return ret;
        }
  
        var exts = GLctx.getSupportedExtensions();
        if (exts && exts.length > 0) {
          GLctx.getSupportedExtensions().forEach(function(ext) {
            if (automaticallyEnabledExtensions.indexOf(ext) != -1) {
              GLctx.getExtension(ext); // Calling .getExtension enables that extension permanently, no need to store the return value to be enabled.
            }
          });
        }
      },populateUniformTable:function (program) {
        var p = GL.programs[program];
        GL.programInfos[program] = {
          uniforms: {},
          maxUniformLength: 0, // This is eagerly computed below, since we already enumerate all uniforms anyway.
          maxAttributeLength: -1, // This is lazily computed and cached, computed when/if first asked, "-1" meaning not computed yet.
          maxUniformBlockNameLength: -1 // Lazily computed as well
        };
  
        var ptable = GL.programInfos[program];
        var utable = ptable.uniforms;
        // A program's uniform table maps the string name of an uniform to an integer location of that uniform.
        // The global GL.uniforms map maps integer locations to WebGLUniformLocations.
        var numUniforms = GLctx.getProgramParameter(p, GLctx.ACTIVE_UNIFORMS);
        for (var i = 0; i < numUniforms; ++i) {
          var u = GLctx.getActiveUniform(p, i);
  
          var name = u.name;
          ptable.maxUniformLength = Math.max(ptable.maxUniformLength, name.length+1);
  
          // Strip off any trailing array specifier we might have got, e.g. "[0]".
          if (name.indexOf(']', name.length-1) !== -1) {
            var ls = name.lastIndexOf('[');
            name = name.slice(0, ls);
          }
  
          // Optimize memory usage slightly: If we have an array of uniforms, e.g. 'vec3 colors[3];', then 
          // only store the string 'colors' in utable, and 'colors[0]', 'colors[1]' and 'colors[2]' will be parsed as 'colors'+i.
          // Note that for the GL.uniforms table, we still need to fetch the all WebGLUniformLocations for all the indices.
          var loc = GLctx.getUniformLocation(p, name);
          if (loc != null)
          {
            var id = GL.getNewId(GL.uniforms);
            utable[name] = [u.size, id];
            GL.uniforms[id] = loc;
  
            for (var j = 1; j < u.size; ++j) {
              var n = name + '['+j+']';
              loc = GLctx.getUniformLocation(p, n);
              id = GL.getNewId(GL.uniforms);
  
              GL.uniforms[id] = loc;
            }
          }
        }
      }};function _emscripten_glIsRenderbuffer(renderbuffer) {
      var rb = GL.renderbuffers[renderbuffer];
      if (!rb) return 0;
      return GLctx.isRenderbuffer(rb);
    }

  function _emscripten_glStencilMaskSeparate(x0, x1) { GLctx['stencilMaskSeparate'](x0, x1) }

  
  
  
  
  function _emscripten_set_main_loop_timing(mode, value) {
      Browser.mainLoop.timingMode = mode;
      Browser.mainLoop.timingValue = value;
  
      if (!Browser.mainLoop.func) {
        console.error('emscripten_set_main_loop_timing: Cannot set timing mode for main loop since a main loop does not exist! Call emscripten_set_main_loop first to set one up.');
        return 1; // Return non-zero on failure, can't set timing mode when there is no main loop.
      }
  
      if (mode == 0 /*EM_TIMING_SETTIMEOUT*/) {
        Browser.mainLoop.scheduler = function Browser_mainLoop_scheduler_setTimeout() {
          var timeUntilNextTick = Math.max(0, Browser.mainLoop.tickStartTime + value - _emscripten_get_now())|0;
          setTimeout(Browser.mainLoop.runner, timeUntilNextTick); // doing this each time means that on exception, we stop
        };
        Browser.mainLoop.method = 'timeout';
      } else if (mode == 1 /*EM_TIMING_RAF*/) {
        Browser.mainLoop.scheduler = function Browser_mainLoop_scheduler_rAF() {
          Browser.requestAnimationFrame(Browser.mainLoop.runner);
        };
        Browser.mainLoop.method = 'rAF';
      } else if (mode == 2 /*EM_TIMING_SETIMMEDIATE*/) {
        if (!window['setImmediate']) {
          // Emulate setImmediate. (note: not a complete polyfill, we don't emulate clearImmediate() to keep code size to minimum, since not needed)
          var setImmediates = [];
          var emscriptenMainLoopMessageId = 'setimmediate';
          function Browser_setImmediate_messageHandler(event) {
            if (event.source === window && event.data === emscriptenMainLoopMessageId) {
              event.stopPropagation();
              setImmediates.shift()();
            }
          }
          window.addEventListener("message", Browser_setImmediate_messageHandler, true);
          window['setImmediate'] = function Browser_emulated_setImmediate(func) {
            setImmediates.push(func);
            if (ENVIRONMENT_IS_WORKER) {
              if (Module['setImmediates'] === undefined) Module['setImmediates'] = [];
              Module['setImmediates'].push(func);
              window.postMessage({target: emscriptenMainLoopMessageId}); // In --proxy-to-worker, route the message via proxyClient.js
            } else window.postMessage(emscriptenMainLoopMessageId, "*"); // On the main thread, can just send the message to itself.
          }
        }
        Browser.mainLoop.scheduler = function Browser_mainLoop_scheduler_setImmediate() {
          window['setImmediate'](Browser.mainLoop.runner);
        };
        Browser.mainLoop.method = 'immediate';
      }
      return 0;
    }
  
  function _emscripten_get_now() { abort() }function _emscripten_set_main_loop(func, fps, simulateInfiniteLoop, arg, noSetTiming) {
      Module['noExitRuntime'] = true;
  
      assert(!Browser.mainLoop.func, 'emscripten_set_main_loop: there can only be one main loop function at once: call emscripten_cancel_main_loop to cancel the previous one before setting a new one with different parameters.');
  
      Browser.mainLoop.func = func;
      Browser.mainLoop.arg = arg;
  
      var browserIterationFunc;
      if (typeof arg !== 'undefined') {
        browserIterationFunc = function() {
          Module['dynCall_vi'](func, arg);
        };
      } else {
        browserIterationFunc = function() {
          Module['dynCall_v'](func);
        };
      }
  
      var thisMainLoopId = Browser.mainLoop.currentlyRunningMainloop;
  
      Browser.mainLoop.runner = function Browser_mainLoop_runner() {
        if (ABORT) return;
        if (Browser.mainLoop.queue.length > 0) {
          var start = Date.now();
          var blocker = Browser.mainLoop.queue.shift();
          blocker.func(blocker.arg);
          if (Browser.mainLoop.remainingBlockers) {
            var remaining = Browser.mainLoop.remainingBlockers;
            var next = remaining%1 == 0 ? remaining-1 : Math.floor(remaining);
            if (blocker.counted) {
              Browser.mainLoop.remainingBlockers = next;
            } else {
              // not counted, but move the progress along a tiny bit
              next = next + 0.5; // do not steal all the next one's progress
              Browser.mainLoop.remainingBlockers = (8*remaining + next)/9;
            }
          }
          console.log('main loop blocker "' + blocker.name + '" took ' + (Date.now() - start) + ' ms'); //, left: ' + Browser.mainLoop.remainingBlockers);
          Browser.mainLoop.updateStatus();
          
          // catches pause/resume main loop from blocker execution
          if (thisMainLoopId < Browser.mainLoop.currentlyRunningMainloop) return;
          
          setTimeout(Browser.mainLoop.runner, 0);
          return;
        }
  
        // catch pauses from non-main loop sources
        if (thisMainLoopId < Browser.mainLoop.currentlyRunningMainloop) return;
  
        // Implement very basic swap interval control
        Browser.mainLoop.currentFrameNumber = Browser.mainLoop.currentFrameNumber + 1 | 0;
        if (Browser.mainLoop.timingMode == 1/*EM_TIMING_RAF*/ && Browser.mainLoop.timingValue > 1 && Browser.mainLoop.currentFrameNumber % Browser.mainLoop.timingValue != 0) {
          // Not the scheduled time to render this frame - skip.
          Browser.mainLoop.scheduler();
          return;
        } else if (Browser.mainLoop.timingMode == 0/*EM_TIMING_SETTIMEOUT*/) {
          Browser.mainLoop.tickStartTime = _emscripten_get_now();
        }
  
        // Signal GL rendering layer that processing of a new frame is about to start. This helps it optimize
        // VBO double-buffering and reduce GPU stalls.
  
  
        if (Browser.mainLoop.method === 'timeout' && Module.ctx) {
          Module.printErr('Looks like you are rendering without using requestAnimationFrame for the main loop. You should use 0 for the frame rate in emscripten_set_main_loop in order to use requestAnimationFrame, as that can greatly improve your frame rates!');
          Browser.mainLoop.method = ''; // just warn once per call to set main loop
        }
  
        Browser.mainLoop.runIter(browserIterationFunc);
  
        checkStackCookie();
  
        // catch pauses from the main loop itself
        if (thisMainLoopId < Browser.mainLoop.currentlyRunningMainloop) return;
  
        // Queue new audio data. This is important to be right after the main loop invocation, so that we will immediately be able
        // to queue the newest produced audio samples.
        // TODO: Consider adding pre- and post- rAF callbacks so that GL.newRenderingFrameStarted() and SDL.audio.queueNewAudioData()
        //       do not need to be hardcoded into this function, but can be more generic.
        if (typeof SDL === 'object' && SDL.audio && SDL.audio.queueNewAudioData) SDL.audio.queueNewAudioData();
  
        Browser.mainLoop.scheduler();
      }
  
      if (!noSetTiming) {
        if (fps && fps > 0) _emscripten_set_main_loop_timing(0/*EM_TIMING_SETTIMEOUT*/, 1000.0 / fps);
        else _emscripten_set_main_loop_timing(1/*EM_TIMING_RAF*/, 1); // Do rAF by rendering each frame (no decimating)
  
        Browser.mainLoop.scheduler();
      }
  
      if (simulateInfiniteLoop) {
        throw 'SimulateInfiniteLoop';
      }
    }var Browser={mainLoop:{scheduler:null,method:"",currentlyRunningMainloop:0,func:null,arg:0,timingMode:0,timingValue:0,currentFrameNumber:0,queue:[],pause:function () {
          Browser.mainLoop.scheduler = null;
          Browser.mainLoop.currentlyRunningMainloop++; // Incrementing this signals the previous main loop that it's now become old, and it must return.
        },resume:function () {
          Browser.mainLoop.currentlyRunningMainloop++;
          var timingMode = Browser.mainLoop.timingMode;
          var timingValue = Browser.mainLoop.timingValue;
          var func = Browser.mainLoop.func;
          Browser.mainLoop.func = null;
          _emscripten_set_main_loop(func, 0, false, Browser.mainLoop.arg, true /* do not set timing and call scheduler, we will do it on the next lines */);
          _emscripten_set_main_loop_timing(timingMode, timingValue);
          Browser.mainLoop.scheduler();
        },updateStatus:function () {
          if (Module['setStatus']) {
            var message = Module['statusMessage'] || 'Please wait...';
            var remaining = Browser.mainLoop.remainingBlockers;
            var expected = Browser.mainLoop.expectedBlockers;
            if (remaining) {
              if (remaining < expected) {
                Module['setStatus'](message + ' (' + (expected - remaining) + '/' + expected + ')');
              } else {
                Module['setStatus'](message);
              }
            } else {
              Module['setStatus']('');
            }
          }
        },runIter:function (func) {
          if (ABORT) return;
          if (Module['preMainLoop']) {
            var preRet = Module['preMainLoop']();
            if (preRet === false) {
              return; // |return false| skips a frame
            }
          }
          try {
            func();
          } catch (e) {
            if (e instanceof ExitStatus) {
              return;
            } else {
              if (e && typeof e === 'object' && e.stack) Module.printErr('exception thrown: ' + [e, e.stack]);
              throw e;
            }
          }
          if (Module['postMainLoop']) Module['postMainLoop']();
        }},isFullscreen:false,pointerLock:false,moduleContextCreatedCallbacks:[],workers:[],init:function () {
        if (!Module["preloadPlugins"]) Module["preloadPlugins"] = []; // needs to exist even in workers
  
        if (Browser.initted) return;
        Browser.initted = true;
  
        try {
          new Blob();
          Browser.hasBlobConstructor = true;
        } catch(e) {
          Browser.hasBlobConstructor = false;
          console.log("warning: no blob constructor, cannot create blobs with mimetypes");
        }
        Browser.BlobBuilder = typeof MozBlobBuilder != "undefined" ? MozBlobBuilder : (typeof WebKitBlobBuilder != "undefined" ? WebKitBlobBuilder : (!Browser.hasBlobConstructor ? console.log("warning: no BlobBuilder") : null));
        Browser.URLObject = typeof window != "undefined" ? (window.URL ? window.URL : window.webkitURL) : undefined;
        if (!Module.noImageDecoding && typeof Browser.URLObject === 'undefined') {
          console.log("warning: Browser does not support creating object URLs. Built-in browser image decoding will not be available.");
          Module.noImageDecoding = true;
        }
  
        // Support for plugins that can process preloaded files. You can add more of these to
        // your app by creating and appending to Module.preloadPlugins.
        //
        // Each plugin is asked if it can handle a file based on the file's name. If it can,
        // it is given the file's raw data. When it is done, it calls a callback with the file's
        // (possibly modified) data. For example, a plugin might decompress a file, or it
        // might create some side data structure for use later (like an Image element, etc.).
  
        var imagePlugin = {};
        imagePlugin['canHandle'] = function imagePlugin_canHandle(name) {
          return !Module.noImageDecoding && /\.(jpg|jpeg|png|bmp)$/i.test(name);
        };
        imagePlugin['handle'] = function imagePlugin_handle(byteArray, name, onload, onerror) {
          var b = null;
          if (Browser.hasBlobConstructor) {
            try {
              b = new Blob([byteArray], { type: Browser.getMimetype(name) });
              if (b.size !== byteArray.length) { // Safari bug #118630
                // Safari's Blob can only take an ArrayBuffer
                b = new Blob([(new Uint8Array(byteArray)).buffer], { type: Browser.getMimetype(name) });
              }
            } catch(e) {
              Runtime.warnOnce('Blob constructor present but fails: ' + e + '; falling back to blob builder');
            }
          }
          if (!b) {
            var bb = new Browser.BlobBuilder();
            bb.append((new Uint8Array(byteArray)).buffer); // we need to pass a buffer, and must copy the array to get the right data range
            b = bb.getBlob();
          }
          var url = Browser.URLObject.createObjectURL(b);
          assert(typeof url == 'string', 'createObjectURL must return a url as a string');
          var img = new Image();
          img.onload = function img_onload() {
            assert(img.complete, 'Image ' + name + ' could not be decoded');
            var canvas = document.createElement('canvas');
            canvas.width = img.width;
            canvas.height = img.height;
            var ctx = canvas.getContext('2d');
            ctx.drawImage(img, 0, 0);
            Module["preloadedImages"][name] = canvas;
            Browser.URLObject.revokeObjectURL(url);
            if (onload) onload(byteArray);
          };
          img.onerror = function img_onerror(event) {
            console.log('Image ' + url + ' could not be decoded');
            if (onerror) onerror();
          };
          img.src = url;
        };
        Module['preloadPlugins'].push(imagePlugin);
  
        var audioPlugin = {};
        audioPlugin['canHandle'] = function audioPlugin_canHandle(name) {
          return !Module.noAudioDecoding && name.substr(-4) in { '.ogg': 1, '.wav': 1, '.mp3': 1 };
        };
        audioPlugin['handle'] = function audioPlugin_handle(byteArray, name, onload, onerror) {
          var done = false;
          function finish(audio) {
            if (done) return;
            done = true;
            Module["preloadedAudios"][name] = audio;
            if (onload) onload(byteArray);
          }
          function fail() {
            if (done) return;
            done = true;
            Module["preloadedAudios"][name] = new Audio(); // empty shim
            if (onerror) onerror();
          }
          if (Browser.hasBlobConstructor) {
            try {
              var b = new Blob([byteArray], { type: Browser.getMimetype(name) });
            } catch(e) {
              return fail();
            }
            var url = Browser.URLObject.createObjectURL(b); // XXX we never revoke this!
            assert(typeof url == 'string', 'createObjectURL must return a url as a string');
            var audio = new Audio();
            audio.addEventListener('canplaythrough', function() { finish(audio) }, false); // use addEventListener due to chromium bug 124926
            audio.onerror = function audio_onerror(event) {
              if (done) return;
              console.log('warning: browser could not fully decode audio ' + name + ', trying slower base64 approach');
              function encode64(data) {
                var BASE = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/';
                var PAD = '=';
                var ret = '';
                var leftchar = 0;
                var leftbits = 0;
                for (var i = 0; i < data.length; i++) {
                  leftchar = (leftchar << 8) | data[i];
                  leftbits += 8;
                  while (leftbits >= 6) {
                    var curr = (leftchar >> (leftbits-6)) & 0x3f;
                    leftbits -= 6;
                    ret += BASE[curr];
                  }
                }
                if (leftbits == 2) {
                  ret += BASE[(leftchar&3) << 4];
                  ret += PAD + PAD;
                } else if (leftbits == 4) {
                  ret += BASE[(leftchar&0xf) << 2];
                  ret += PAD;
                }
                return ret;
              }
              audio.src = 'data:audio/x-' + name.substr(-3) + ';base64,' + encode64(byteArray);
              finish(audio); // we don't wait for confirmation this worked - but it's worth trying
            };
            audio.src = url;
            // workaround for chrome bug 124926 - we do not always get oncanplaythrough or onerror
            Browser.safeSetTimeout(function() {
              finish(audio); // try to use it even though it is not necessarily ready to play
            }, 10000);
          } else {
            return fail();
          }
        };
        Module['preloadPlugins'].push(audioPlugin);
  
        // Canvas event setup
  
        function pointerLockChange() {
          Browser.pointerLock = document['pointerLockElement'] === Module['canvas'] ||
                                document['mozPointerLockElement'] === Module['canvas'] ||
                                document['webkitPointerLockElement'] === Module['canvas'] ||
                                document['msPointerLockElement'] === Module['canvas'];
        }
        var canvas = Module['canvas'];
        if (canvas) {
          // forced aspect ratio can be enabled by defining 'forcedAspectRatio' on Module
          // Module['forcedAspectRatio'] = 4 / 3;
          
          canvas.requestPointerLock = canvas['requestPointerLock'] ||
                                      canvas['mozRequestPointerLock'] ||
                                      canvas['webkitRequestPointerLock'] ||
                                      canvas['msRequestPointerLock'] ||
                                      function(){};
          canvas.exitPointerLock = document['exitPointerLock'] ||
                                   document['mozExitPointerLock'] ||
                                   document['webkitExitPointerLock'] ||
                                   document['msExitPointerLock'] ||
                                   function(){}; // no-op if function does not exist
          canvas.exitPointerLock = canvas.exitPointerLock.bind(document);
  
          document.addEventListener('pointerlockchange', pointerLockChange, false);
          document.addEventListener('mozpointerlockchange', pointerLockChange, false);
          document.addEventListener('webkitpointerlockchange', pointerLockChange, false);
          document.addEventListener('mspointerlockchange', pointerLockChange, false);
  
          if (Module['elementPointerLock']) {
            canvas.addEventListener("click", function(ev) {
              if (!Browser.pointerLock && Module['canvas'].requestPointerLock) {
                Module['canvas'].requestPointerLock();
                ev.preventDefault();
              }
            }, false);
          }
        }
      },createContext:function (canvas, useWebGL, setInModule, webGLContextAttributes) {
        if (useWebGL && Module.ctx && canvas == Module.canvas) return Module.ctx; // no need to recreate GL context if it's already been created for this canvas.
  
        var ctx;
        var contextHandle;
        if (useWebGL) {
          // For GLES2/desktop GL compatibility, adjust a few defaults to be different to WebGL defaults, so that they align better with the desktop defaults.
          var contextAttributes = {
            antialias: false,
            alpha: false
          };
  
          if (webGLContextAttributes) {
            for (var attribute in webGLContextAttributes) {
              contextAttributes[attribute] = webGLContextAttributes[attribute];
            }
          }
  
          contextHandle = GL.createContext(canvas, contextAttributes);
          if (contextHandle) {
            ctx = GL.getContext(contextHandle).GLctx;
          }
        } else {
          ctx = canvas.getContext('2d');
        }
  
        if (!ctx) return null;
  
        if (setInModule) {
          if (!useWebGL) assert(typeof GLctx === 'undefined', 'cannot set in module if GLctx is used, but we are a non-GL context that would replace it');
  
          Module.ctx = ctx;
          if (useWebGL) GL.makeContextCurrent(contextHandle);
          Module.useWebGL = useWebGL;
          Browser.moduleContextCreatedCallbacks.forEach(function(callback) { callback() });
          Browser.init();
        }
        return ctx;
      },destroyContext:function (canvas, useWebGL, setInModule) {},fullscreenHandlersInstalled:false,lockPointer:undefined,resizeCanvas:undefined,requestFullscreen:function (lockPointer, resizeCanvas, vrDevice) {
        Browser.lockPointer = lockPointer;
        Browser.resizeCanvas = resizeCanvas;
        Browser.vrDevice = vrDevice;
        if (typeof Browser.lockPointer === 'undefined') Browser.lockPointer = true;
        if (typeof Browser.resizeCanvas === 'undefined') Browser.resizeCanvas = false;
        if (typeof Browser.vrDevice === 'undefined') Browser.vrDevice = null;
  
        var canvas = Module['canvas'];
        function fullscreenChange() {
          Browser.isFullscreen = false;
          var canvasContainer = canvas.parentNode;
          if ((document['fullscreenElement'] || document['mozFullScreenElement'] ||
               document['msFullscreenElement'] || document['webkitFullscreenElement'] ||
               document['webkitCurrentFullScreenElement']) === canvasContainer) {
            canvas.exitFullscreen = document['exitFullscreen'] ||
                                    document['cancelFullScreen'] ||
                                    document['mozCancelFullScreen'] ||
                                    document['msExitFullscreen'] ||
                                    document['webkitCancelFullScreen'] ||
                                    function() {};
            canvas.exitFullscreen = canvas.exitFullscreen.bind(document);
            if (Browser.lockPointer) canvas.requestPointerLock();
            Browser.isFullscreen = true;
            if (Browser.resizeCanvas) Browser.setFullscreenCanvasSize();
          } else {
            
            // remove the full screen specific parent of the canvas again to restore the HTML structure from before going full screen
            canvasContainer.parentNode.insertBefore(canvas, canvasContainer);
            canvasContainer.parentNode.removeChild(canvasContainer);
            
            if (Browser.resizeCanvas) Browser.setWindowedCanvasSize();
          }
          if (Module['onFullScreen']) Module['onFullScreen'](Browser.isFullscreen);
          if (Module['onFullscreen']) Module['onFullscreen'](Browser.isFullscreen);
          Browser.updateCanvasDimensions(canvas);
        }
  
        if (!Browser.fullscreenHandlersInstalled) {
          Browser.fullscreenHandlersInstalled = true;
          document.addEventListener('fullscreenchange', fullscreenChange, false);
          document.addEventListener('mozfullscreenchange', fullscreenChange, false);
          document.addEventListener('webkitfullscreenchange', fullscreenChange, false);
          document.addEventListener('MSFullscreenChange', fullscreenChange, false);
        }
  
        // create a new parent to ensure the canvas has no siblings. this allows browsers to optimize full screen performance when its parent is the full screen root
        var canvasContainer = document.createElement("div");
        canvas.parentNode.insertBefore(canvasContainer, canvas);
        canvasContainer.appendChild(canvas);
  
        // use parent of canvas as full screen root to allow aspect ratio correction (Firefox stretches the root to screen size)
        canvasContainer.requestFullscreen = canvasContainer['requestFullscreen'] ||
                                            canvasContainer['mozRequestFullScreen'] ||
                                            canvasContainer['msRequestFullscreen'] ||
                                           (canvasContainer['webkitRequestFullscreen'] ? function() { canvasContainer['webkitRequestFullscreen'](Element['ALLOW_KEYBOARD_INPUT']) } : null) ||
                                           (canvasContainer['webkitRequestFullScreen'] ? function() { canvasContainer['webkitRequestFullScreen'](Element['ALLOW_KEYBOARD_INPUT']) } : null);
  
        if (vrDevice) {
          canvasContainer.requestFullscreen({ vrDisplay: vrDevice });
        } else {
          canvasContainer.requestFullscreen();
        }
      },requestFullScreen:function (lockPointer, resizeCanvas, vrDevice) {
          Module.printErr('Browser.requestFullScreen() is deprecated. Please call Browser.requestFullscreen instead.');
          Browser.requestFullScreen = function(lockPointer, resizeCanvas, vrDevice) {
            return Browser.requestFullscreen(lockPointer, resizeCanvas, vrDevice);
          }
          return Browser.requestFullscreen(lockPointer, resizeCanvas, vrDevice);
      },nextRAF:0,fakeRequestAnimationFrame:function (func) {
        // try to keep 60fps between calls to here
        var now = Date.now();
        if (Browser.nextRAF === 0) {
          Browser.nextRAF = now + 1000/60;
        } else {
          while (now + 2 >= Browser.nextRAF) { // fudge a little, to avoid timer jitter causing us to do lots of delay:0
            Browser.nextRAF += 1000/60;
          }
        }
        var delay = Math.max(Browser.nextRAF - now, 0);
        setTimeout(func, delay);
      },requestAnimationFrame:function requestAnimationFrame(func) {
        if (typeof window === 'undefined') { // Provide fallback to setTimeout if window is undefined (e.g. in Node.js)
          Browser.fakeRequestAnimationFrame(func);
        } else {
          if (!window.requestAnimationFrame) {
            window.requestAnimationFrame = window['requestAnimationFrame'] ||
                                           window['mozRequestAnimationFrame'] ||
                                           window['webkitRequestAnimationFrame'] ||
                                           window['msRequestAnimationFrame'] ||
                                           window['oRequestAnimationFrame'] ||
                                           Browser.fakeRequestAnimationFrame;
          }
          window.requestAnimationFrame(func);
        }
      },safeCallback:function (func) {
        return function() {
          if (!ABORT) return func.apply(null, arguments);
        };
      },allowAsyncCallbacks:true,queuedAsyncCallbacks:[],pauseAsyncCallbacks:function () {
        Browser.allowAsyncCallbacks = false;
      },resumeAsyncCallbacks:function () { // marks future callbacks as ok to execute, and synchronously runs any remaining ones right now
        Browser.allowAsyncCallbacks = true;
        if (Browser.queuedAsyncCallbacks.length > 0) {
          var callbacks = Browser.queuedAsyncCallbacks;
          Browser.queuedAsyncCallbacks = [];
          callbacks.forEach(function(func) {
            func();
          });
        }
      },safeRequestAnimationFrame:function (func) {
        return Browser.requestAnimationFrame(function() {
          if (ABORT) return;
          if (Browser.allowAsyncCallbacks) {
            func();
          } else {
            Browser.queuedAsyncCallbacks.push(func);
          }
        });
      },safeSetTimeout:function (func, timeout) {
        Module['noExitRuntime'] = true;
        return setTimeout(function() {
          if (ABORT) return;
          if (Browser.allowAsyncCallbacks) {
            func();
          } else {
            Browser.queuedAsyncCallbacks.push(func);
          }
        }, timeout);
      },safeSetInterval:function (func, timeout) {
        Module['noExitRuntime'] = true;
        return setInterval(function() {
          if (ABORT) return;
          if (Browser.allowAsyncCallbacks) {
            func();
          } // drop it on the floor otherwise, next interval will kick in
        }, timeout);
      },getMimetype:function (name) {
        return {
          'jpg': 'image/jpeg',
          'jpeg': 'image/jpeg',
          'png': 'image/png',
          'bmp': 'image/bmp',
          'ogg': 'audio/ogg',
          'wav': 'audio/wav',
          'mp3': 'audio/mpeg'
        }[name.substr(name.lastIndexOf('.')+1)];
      },getUserMedia:function (func) {
        if(!window.getUserMedia) {
          window.getUserMedia = navigator['getUserMedia'] ||
                                navigator['mozGetUserMedia'];
        }
        window.getUserMedia(func);
      },getMovementX:function (event) {
        return event['movementX'] ||
               event['mozMovementX'] ||
               event['webkitMovementX'] ||
               0;
      },getMovementY:function (event) {
        return event['movementY'] ||
               event['mozMovementY'] ||
               event['webkitMovementY'] ||
               0;
      },getMouseWheelDelta:function (event) {
        var delta = 0;
        switch (event.type) {
          case 'DOMMouseScroll': 
            delta = event.detail;
            break;
          case 'mousewheel': 
            delta = event.wheelDelta;
            break;
          case 'wheel': 
            delta = event['deltaY'];
            break;
          default:
            throw 'unrecognized mouse wheel event: ' + event.type;
        }
        return delta;
      },mouseX:0,mouseY:0,mouseMovementX:0,mouseMovementY:0,touches:{},lastTouches:{},calculateMouseEvent:function (event) { // event should be mousemove, mousedown or mouseup
        if (Browser.pointerLock) {
          // When the pointer is locked, calculate the coordinates
          // based on the movement of the mouse.
          // Workaround for Firefox bug 764498
          if (event.type != 'mousemove' &&
              ('mozMovementX' in event)) {
            Browser.mouseMovementX = Browser.mouseMovementY = 0;
          } else {
            Browser.mouseMovementX = Browser.getMovementX(event);
            Browser.mouseMovementY = Browser.getMovementY(event);
          }
          
          // check if SDL is available
          if (typeof SDL != "undefined") {
          	Browser.mouseX = SDL.mouseX + Browser.mouseMovementX;
          	Browser.mouseY = SDL.mouseY + Browser.mouseMovementY;
          } else {
          	// just add the mouse delta to the current absolut mouse position
          	// FIXME: ideally this should be clamped against the canvas size and zero
          	Browser.mouseX += Browser.mouseMovementX;
          	Browser.mouseY += Browser.mouseMovementY;
          }        
        } else {
          // Otherwise, calculate the movement based on the changes
          // in the coordinates.
          var rect = Module["canvas"].getBoundingClientRect();
          var cw = Module["canvas"].width;
          var ch = Module["canvas"].height;
  
          // Neither .scrollX or .pageXOffset are defined in a spec, but
          // we prefer .scrollX because it is currently in a spec draft.
          // (see: http://www.w3.org/TR/2013/WD-cssom-view-20131217/)
          var scrollX = ((typeof window.scrollX !== 'undefined') ? window.scrollX : window.pageXOffset);
          var scrollY = ((typeof window.scrollY !== 'undefined') ? window.scrollY : window.pageYOffset);
          // If this assert lands, it's likely because the browser doesn't support scrollX or pageXOffset
          // and we have no viable fallback.
          assert((typeof scrollX !== 'undefined') && (typeof scrollY !== 'undefined'), 'Unable to retrieve scroll position, mouse positions likely broken.');
  
          if (event.type === 'touchstart' || event.type === 'touchend' || event.type === 'touchmove') {
            var touch = event.touch;
            if (touch === undefined) {
              return; // the "touch" property is only defined in SDL
  
            }
            var adjustedX = touch.pageX - (scrollX + rect.left);
            var adjustedY = touch.pageY - (scrollY + rect.top);
  
            adjustedX = adjustedX * (cw / rect.width);
            adjustedY = adjustedY * (ch / rect.height);
  
            var coords = { x: adjustedX, y: adjustedY };
            
            if (event.type === 'touchstart') {
              Browser.lastTouches[touch.identifier] = coords;
              Browser.touches[touch.identifier] = coords;
            } else if (event.type === 'touchend' || event.type === 'touchmove') {
              var last = Browser.touches[touch.identifier];
              if (!last) last = coords;
              Browser.lastTouches[touch.identifier] = last;
              Browser.touches[touch.identifier] = coords;
            } 
            return;
          }
  
          var x = event.pageX - (scrollX + rect.left);
          var y = event.pageY - (scrollY + rect.top);
  
          // the canvas might be CSS-scaled compared to its backbuffer;
          // SDL-using content will want mouse coordinates in terms
          // of backbuffer units.
          x = x * (cw / rect.width);
          y = y * (ch / rect.height);
  
          Browser.mouseMovementX = x - Browser.mouseX;
          Browser.mouseMovementY = y - Browser.mouseY;
          Browser.mouseX = x;
          Browser.mouseY = y;
        }
      },asyncLoad:function (url, onload, onerror, noRunDep) {
        var dep = !noRunDep ? getUniqueRunDependency('al ' + url) : '';
        Module['readAsync'](url, function(arrayBuffer) {
          assert(arrayBuffer, 'Loading data file "' + url + '" failed (no arrayBuffer).');
          onload(new Uint8Array(arrayBuffer));
          if (dep) removeRunDependency(dep);
        }, function(event) {
          if (onerror) {
            onerror();
          } else {
            throw 'Loading data file "' + url + '" failed.';
          }
        });
        if (dep) addRunDependency(dep);
      },resizeListeners:[],updateResizeListeners:function () {
        var canvas = Module['canvas'];
        Browser.resizeListeners.forEach(function(listener) {
          listener(canvas.width, canvas.height);
        });
      },setCanvasSize:function (width, height, noUpdates) {
        var canvas = Module['canvas'];
        Browser.updateCanvasDimensions(canvas, width, height);
        if (!noUpdates) Browser.updateResizeListeners();
      },windowedWidth:0,windowedHeight:0,setFullscreenCanvasSize:function () {
        // check if SDL is available   
        if (typeof SDL != "undefined") {
        	var flags = HEAPU32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)];
        	flags = flags | 0x00800000; // set SDL_FULLSCREEN flag
        	HEAP32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)]=flags
        }
        Browser.updateResizeListeners();
      },setWindowedCanvasSize:function () {
        // check if SDL is available       
        if (typeof SDL != "undefined") {
        	var flags = HEAPU32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)];
        	flags = flags & ~0x00800000; // clear SDL_FULLSCREEN flag
        	HEAP32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)]=flags
        }
        Browser.updateResizeListeners();
      },updateCanvasDimensions:function (canvas, wNative, hNative) {
        if (wNative && hNative) {
          canvas.widthNative = wNative;
          canvas.heightNative = hNative;
        } else {
          wNative = canvas.widthNative;
          hNative = canvas.heightNative;
        }
        var w = wNative;
        var h = hNative;
        if (Module['forcedAspectRatio'] && Module['forcedAspectRatio'] > 0) {
          if (w/h < Module['forcedAspectRatio']) {
            w = Math.round(h * Module['forcedAspectRatio']);
          } else {
            h = Math.round(w / Module['forcedAspectRatio']);
          }
        }
        if (((document['fullscreenElement'] || document['mozFullScreenElement'] ||
             document['msFullscreenElement'] || document['webkitFullscreenElement'] ||
             document['webkitCurrentFullScreenElement']) === canvas.parentNode) && (typeof screen != 'undefined')) {
           var factor = Math.min(screen.width / w, screen.height / h);
           w = Math.round(w * factor);
           h = Math.round(h * factor);
        }
        if (Browser.resizeCanvas) {
          if (canvas.width  != w) canvas.width  = w;
          if (canvas.height != h) canvas.height = h;
          if (typeof canvas.style != 'undefined') {
            canvas.style.removeProperty( "width");
            canvas.style.removeProperty("height");
          }
        } else {
          if (canvas.width  != wNative) canvas.width  = wNative;
          if (canvas.height != hNative) canvas.height = hNative;
          if (typeof canvas.style != 'undefined') {
            if (w != wNative || h != hNative) {
              canvas.style.setProperty( "width", w + "px", "important");
              canvas.style.setProperty("height", h + "px", "important");
            } else {
              canvas.style.removeProperty( "width");
              canvas.style.removeProperty("height");
            }
          }
        }
      },wgetRequests:{},nextWgetRequestHandle:0,getNextWgetRequestHandle:function () {
        var handle = Browser.nextWgetRequestHandle;
        Browser.nextWgetRequestHandle++;
        return handle;
      }};var EGL={errorCode:12288,defaultDisplayInitialized:false,currentContext:0,currentReadSurface:0,currentDrawSurface:0,stringCache:{},setErrorCode:function (code) {
        EGL.errorCode = code;
      },chooseConfig:function (display, attribList, config, config_size, numConfigs) { 
        if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
          EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
          return 0;
        }
        // TODO: read attribList.
        if ((!config || !config_size) && !numConfigs) {
          EGL.setErrorCode(0x300C /* EGL_BAD_PARAMETER */);
          return 0;
        }
        if (numConfigs) {
          HEAP32[((numConfigs)>>2)]=1; // Total number of supported configs: 1.
        }
        if (config && config_size > 0) {
          HEAP32[((config)>>2)]=62002; 
        }
        
        EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
        return 1;
      }};
  
  function _eglWaitClient() {
      EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
      return 1;
    }function _eglTerminate(display) {
      if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0;
      }
      EGL.currentContext = 0;
      EGL.currentReadSurface = 0;
      EGL.currentDrawSurface = 0;
      EGL.defaultDisplayInitialized = false;
      EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
      return 1;
    }

  function _emscripten_glStencilMask(x0) { GLctx['stencilMask'](x0) }

   

  
  function ___cxa_free_exception(ptr) {
      try {
        return _free(ptr);
      } catch(e) { // XXX FIXME
        Module.printErr('exception during cxa_free_exception: ' + e);
      }
    }
  
  var EXCEPTIONS={last:0,caught:[],infos:{},deAdjust:function (adjusted) {
        if (!adjusted || EXCEPTIONS.infos[adjusted]) return adjusted;
        for (var ptr in EXCEPTIONS.infos) {
          var info = EXCEPTIONS.infos[ptr];
          if (info.adjusted === adjusted) {
            return ptr;
          }
        }
        return adjusted;
      },addRef:function (ptr) {
        if (!ptr) return;
        var info = EXCEPTIONS.infos[ptr];
        info.refcount++;
      },decRef:function (ptr) {
        if (!ptr) return;
        var info = EXCEPTIONS.infos[ptr];
        assert(info.refcount > 0);
        info.refcount--;
        // A rethrown exception can reach refcount 0; it must not be discarded
        // Its next handler will clear the rethrown flag and addRef it, prior to
        // final decRef and destruction here
        if (info.refcount === 0 && !info.rethrown) {
          if (info.destructor) {
            Module['dynCall_vi'](info.destructor, ptr);
          }
          delete EXCEPTIONS.infos[ptr];
          ___cxa_free_exception(ptr);
        }
      },clearRef:function (ptr) {
        if (!ptr) return;
        var info = EXCEPTIONS.infos[ptr];
        info.refcount = 0;
      }};function ___cxa_end_catch() {
      // Clear state flag.
      Module['setThrew'](0);
      // Call destructor if one is registered then clear it.
      var ptr = EXCEPTIONS.caught.pop();
      if (ptr) {
        EXCEPTIONS.decRef(EXCEPTIONS.deAdjust(ptr));
        EXCEPTIONS.last = 0; // XXX in decRef?
      }
    }

  function _emscripten_set_mouseleave_callback(target, userData, useCapture, callbackfunc) {
      JSEvents.registerMouseEventCallback(target, userData, useCapture, callbackfunc, 34, "mouseleave");
      return 0;
    }

  function _emscripten_glStencilFunc(x0, x1, x2) { GLctx['stencilFunc'](x0, x1, x2) }

  function _emscripten_glVertexPointer(){ throw 'Legacy GL function (glVertexPointer) called. If you want legacy GL emulation, you need to compile with -s LEGACY_GL_EMULATION=1 to enable legacy GL emulation.'; }

  function _emscripten_glUniform3iv(location, count, value) {
  
  
      GLctx.uniform3iv(GL.uniforms[location], HEAP32.subarray((value)>>2,(value+count*12)>>2));
    }

  function _emscripten_glUniform4f(location, v0, v1, v2, v3) {
      GLctx.uniform4f(GL.uniforms[location], v0, v1, v2, v3);
    }

  function _emscripten_glShaderSource(shader, count, string, length) {
      var source = GL.getSource(shader, count, string, length);
  
  
      GLctx.shaderSource(GL.shaders[shader], source);
    }

  function _pthread_mutex_init() {}

  function _emscripten_glReleaseShaderCompiler() {
      // NOP (as allowed by GLES 2.0 spec)
    }

  function _emscripten_glIsTexture(texture) {
      var texture = GL.textures[texture];
      if (!texture) return 0;
      return GLctx.isTexture(texture);
    }

  function _emscripten_glTexParameterf(x0, x1, x2) { GLctx['texParameterf'](x0, x1, x2) }

  
  var DLFCN={error:null,errorMsg:null,loadedLibs:{},loadedLibNames:{}};function _dlerror() {
      // char *dlerror(void);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/dlerror.html
      if (DLFCN.errorMsg === null) {
        return 0;
      } else {
        if (DLFCN.error) _free(DLFCN.error);
        var msgArr = intArrayFromString(DLFCN.errorMsg);
        DLFCN.error = allocate(msgArr, 'i8', ALLOC_NORMAL);
        DLFCN.errorMsg = null;
        return DLFCN.error;
      }
    }

   

  function _eglWaitGL() {
  return _eglWaitClient.apply(null, arguments)
  }

  
  
  
  var ERRNO_CODES={EPERM:1,ENOENT:2,ESRCH:3,EINTR:4,EIO:5,ENXIO:6,E2BIG:7,ENOEXEC:8,EBADF:9,ECHILD:10,EAGAIN:11,EWOULDBLOCK:11,ENOMEM:12,EACCES:13,EFAULT:14,ENOTBLK:15,EBUSY:16,EEXIST:17,EXDEV:18,ENODEV:19,ENOTDIR:20,EISDIR:21,EINVAL:22,ENFILE:23,EMFILE:24,ENOTTY:25,ETXTBSY:26,EFBIG:27,ENOSPC:28,ESPIPE:29,EROFS:30,EMLINK:31,EPIPE:32,EDOM:33,ERANGE:34,ENOMSG:42,EIDRM:43,ECHRNG:44,EL2NSYNC:45,EL3HLT:46,EL3RST:47,ELNRNG:48,EUNATCH:49,ENOCSI:50,EL2HLT:51,EDEADLK:35,ENOLCK:37,EBADE:52,EBADR:53,EXFULL:54,ENOANO:55,EBADRQC:56,EBADSLT:57,EDEADLOCK:35,EBFONT:59,ENOSTR:60,ENODATA:61,ETIME:62,ENOSR:63,ENONET:64,ENOPKG:65,EREMOTE:66,ENOLINK:67,EADV:68,ESRMNT:69,ECOMM:70,EPROTO:71,EMULTIHOP:72,EDOTDOT:73,EBADMSG:74,ENOTUNIQ:76,EBADFD:77,EREMCHG:78,ELIBACC:79,ELIBBAD:80,ELIBSCN:81,ELIBMAX:82,ELIBEXEC:83,ENOSYS:38,ENOTEMPTY:39,ENAMETOOLONG:36,ELOOP:40,EOPNOTSUPP:95,EPFNOSUPPORT:96,ECONNRESET:104,ENOBUFS:105,EAFNOSUPPORT:97,EPROTOTYPE:91,ENOTSOCK:88,ENOPROTOOPT:92,ESHUTDOWN:108,ECONNREFUSED:111,EADDRINUSE:98,ECONNABORTED:103,ENETUNREACH:101,ENETDOWN:100,ETIMEDOUT:110,EHOSTDOWN:112,EHOSTUNREACH:113,EINPROGRESS:115,EALREADY:114,EDESTADDRREQ:89,EMSGSIZE:90,EPROTONOSUPPORT:93,ESOCKTNOSUPPORT:94,EADDRNOTAVAIL:99,ENETRESET:102,EISCONN:106,ENOTCONN:107,ETOOMANYREFS:109,EUSERS:87,EDQUOT:122,ESTALE:116,ENOTSUP:95,ENOMEDIUM:123,EILSEQ:84,EOVERFLOW:75,ECANCELED:125,ENOTRECOVERABLE:131,EOWNERDEAD:130,ESTRPIPE:86};
  
  var ERRNO_MESSAGES={0:"Success",1:"Not super-user",2:"No such file or directory",3:"No such process",4:"Interrupted system call",5:"I/O error",6:"No such device or address",7:"Arg list too long",8:"Exec format error",9:"Bad file number",10:"No children",11:"No more processes",12:"Not enough core",13:"Permission denied",14:"Bad address",15:"Block device required",16:"Mount device busy",17:"File exists",18:"Cross-device link",19:"No such device",20:"Not a directory",21:"Is a directory",22:"Invalid argument",23:"Too many open files in system",24:"Too many open files",25:"Not a typewriter",26:"Text file busy",27:"File too large",28:"No space left on device",29:"Illegal seek",30:"Read only file system",31:"Too many links",32:"Broken pipe",33:"Math arg out of domain of func",34:"Math result not representable",35:"File locking deadlock error",36:"File or path name too long",37:"No record locks available",38:"Function not implemented",39:"Directory not empty",40:"Too many symbolic links",42:"No message of desired type",43:"Identifier removed",44:"Channel number out of range",45:"Level 2 not synchronized",46:"Level 3 halted",47:"Level 3 reset",48:"Link number out of range",49:"Protocol driver not attached",50:"No CSI structure available",51:"Level 2 halted",52:"Invalid exchange",53:"Invalid request descriptor",54:"Exchange full",55:"No anode",56:"Invalid request code",57:"Invalid slot",59:"Bad font file fmt",60:"Device not a stream",61:"No data (for no delay io)",62:"Timer expired",63:"Out of streams resources",64:"Machine is not on the network",65:"Package not installed",66:"The object is remote",67:"The link has been severed",68:"Advertise error",69:"Srmount error",70:"Communication error on send",71:"Protocol error",72:"Multihop attempted",73:"Cross mount point (not really error)",74:"Trying to read unreadable message",75:"Value too large for defined data type",76:"Given log. name not unique",77:"f.d. invalid for this operation",78:"Remote address changed",79:"Can   access a needed shared lib",80:"Accessing a corrupted shared lib",81:".lib section in a.out corrupted",82:"Attempting to link in too many libs",83:"Attempting to exec a shared library",84:"Illegal byte sequence",86:"Streams pipe error",87:"Too many users",88:"Socket operation on non-socket",89:"Destination address required",90:"Message too long",91:"Protocol wrong type for socket",92:"Protocol not available",93:"Unknown protocol",94:"Socket type not supported",95:"Not supported",96:"Protocol family not supported",97:"Address family not supported by protocol family",98:"Address already in use",99:"Address not available",100:"Network interface is not configured",101:"Network is unreachable",102:"Connection reset by network",103:"Connection aborted",104:"Connection reset by peer",105:"No buffer space available",106:"Socket is already connected",107:"Socket is not connected",108:"Can't send after socket shutdown",109:"Too many references",110:"Connection timed out",111:"Connection refused",112:"Host is down",113:"Host is unreachable",114:"Socket already connected",115:"Connection already in progress",116:"Stale file handle",122:"Quota exceeded",123:"No medium (in tape drive)",125:"Operation canceled",130:"Previous owner died",131:"State not recoverable"};
  
  function ___setErrNo(value) {
      if (Module['___errno_location']) HEAP32[((Module['___errno_location']())>>2)]=value;
      else Module.printErr('failed to set errno from JS');
      return value;
    }
  
  var PATH={splitPath:function (filename) {
        var splitPathRe = /^(\/?|)([\s\S]*?)((?:\.{1,2}|[^\/]+?|)(\.[^.\/]*|))(?:[\/]*)$/;
        return splitPathRe.exec(filename).slice(1);
      },normalizeArray:function (parts, allowAboveRoot) {
        // if the path tries to go above the root, `up` ends up > 0
        var up = 0;
        for (var i = parts.length - 1; i >= 0; i--) {
          var last = parts[i];
          if (last === '.') {
            parts.splice(i, 1);
          } else if (last === '..') {
            parts.splice(i, 1);
            up++;
          } else if (up) {
            parts.splice(i, 1);
            up--;
          }
        }
        // if the path is allowed to go above the root, restore leading ..s
        if (allowAboveRoot) {
          for (; up; up--) {
            parts.unshift('..');
          }
        }
        return parts;
      },normalize:function (path) {
        var isAbsolute = path.charAt(0) === '/',
            trailingSlash = path.substr(-1) === '/';
        // Normalize the path
        path = PATH.normalizeArray(path.split('/').filter(function(p) {
          return !!p;
        }), !isAbsolute).join('/');
        if (!path && !isAbsolute) {
          path = '.';
        }
        if (path && trailingSlash) {
          path += '/';
        }
        return (isAbsolute ? '/' : '') + path;
      },dirname:function (path) {
        var result = PATH.splitPath(path),
            root = result[0],
            dir = result[1];
        if (!root && !dir) {
          // No dirname whatsoever
          return '.';
        }
        if (dir) {
          // It has a dirname, strip trailing slash
          dir = dir.substr(0, dir.length - 1);
        }
        return root + dir;
      },basename:function (path) {
        // EMSCRIPTEN return '/'' for '/', not an empty string
        if (path === '/') return '/';
        var lastSlash = path.lastIndexOf('/');
        if (lastSlash === -1) return path;
        return path.substr(lastSlash+1);
      },extname:function (path) {
        return PATH.splitPath(path)[3];
      },join:function () {
        var paths = Array.prototype.slice.call(arguments, 0);
        return PATH.normalize(paths.join('/'));
      },join2:function (l, r) {
        return PATH.normalize(l + '/' + r);
      },resolve:function () {
        var resolvedPath = '',
          resolvedAbsolute = false;
        for (var i = arguments.length - 1; i >= -1 && !resolvedAbsolute; i--) {
          var path = (i >= 0) ? arguments[i] : FS.cwd();
          // Skip empty and invalid entries
          if (typeof path !== 'string') {
            throw new TypeError('Arguments to path.resolve must be strings');
          } else if (!path) {
            return ''; // an invalid portion invalidates the whole thing
          }
          resolvedPath = path + '/' + resolvedPath;
          resolvedAbsolute = path.charAt(0) === '/';
        }
        // At this point the path should be resolved to a full absolute path, but
        // handle relative paths to be safe (might happen when process.cwd() fails)
        resolvedPath = PATH.normalizeArray(resolvedPath.split('/').filter(function(p) {
          return !!p;
        }), !resolvedAbsolute).join('/');
        return ((resolvedAbsolute ? '/' : '') + resolvedPath) || '.';
      },relative:function (from, to) {
        from = PATH.resolve(from).substr(1);
        to = PATH.resolve(to).substr(1);
        function trim(arr) {
          var start = 0;
          for (; start < arr.length; start++) {
            if (arr[start] !== '') break;
          }
          var end = arr.length - 1;
          for (; end >= 0; end--) {
            if (arr[end] !== '') break;
          }
          if (start > end) return [];
          return arr.slice(start, end - start + 1);
        }
        var fromParts = trim(from.split('/'));
        var toParts = trim(to.split('/'));
        var length = Math.min(fromParts.length, toParts.length);
        var samePartsLength = length;
        for (var i = 0; i < length; i++) {
          if (fromParts[i] !== toParts[i]) {
            samePartsLength = i;
            break;
          }
        }
        var outputParts = [];
        for (var i = samePartsLength; i < fromParts.length; i++) {
          outputParts.push('..');
        }
        outputParts = outputParts.concat(toParts.slice(samePartsLength));
        return outputParts.join('/');
      }};
  
  var TTY={ttys:[],init:function () {
        // https://github.com/kripken/emscripten/pull/1555
        // if (ENVIRONMENT_IS_NODE) {
        //   // currently, FS.init does not distinguish if process.stdin is a file or TTY
        //   // device, it always assumes it's a TTY device. because of this, we're forcing
        //   // process.stdin to UTF8 encoding to at least make stdin reading compatible
        //   // with text files until FS.init can be refactored.
        //   process['stdin']['setEncoding']('utf8');
        // }
      },shutdown:function () {
        // https://github.com/kripken/emscripten/pull/1555
        // if (ENVIRONMENT_IS_NODE) {
        //   // inolen: any idea as to why node -e 'process.stdin.read()' wouldn't exit immediately (with process.stdin being a tty)?
        //   // isaacs: because now it's reading from the stream, you've expressed interest in it, so that read() kicks off a _read() which creates a ReadReq operation
        //   // inolen: I thought read() in that case was a synchronous operation that just grabbed some amount of buffered data if it exists?
        //   // isaacs: it is. but it also triggers a _read() call, which calls readStart() on the handle
        //   // isaacs: do process.stdin.pause() and i'd think it'd probably close the pending call
        //   process['stdin']['pause']();
        // }
      },register:function (dev, ops) {
        TTY.ttys[dev] = { input: [], output: [], ops: ops };
        FS.registerDevice(dev, TTY.stream_ops);
      },stream_ops:{open:function (stream) {
          var tty = TTY.ttys[stream.node.rdev];
          if (!tty) {
            throw new FS.ErrnoError(ERRNO_CODES.ENODEV);
          }
          stream.tty = tty;
          stream.seekable = false;
        },close:function (stream) {
          // flush any pending line data
          stream.tty.ops.flush(stream.tty);
        },flush:function (stream) {
          stream.tty.ops.flush(stream.tty);
        },read:function (stream, buffer, offset, length, pos /* ignored */) {
          if (!stream.tty || !stream.tty.ops.get_char) {
            throw new FS.ErrnoError(ERRNO_CODES.ENXIO);
          }
          var bytesRead = 0;
          for (var i = 0; i < length; i++) {
            var result;
            try {
              result = stream.tty.ops.get_char(stream.tty);
            } catch (e) {
              throw new FS.ErrnoError(ERRNO_CODES.EIO);
            }
            if (result === undefined && bytesRead === 0) {
              throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
            }
            if (result === null || result === undefined) break;
            bytesRead++;
            buffer[offset+i] = result;
          }
          if (bytesRead) {
            stream.node.timestamp = Date.now();
          }
          return bytesRead;
        },write:function (stream, buffer, offset, length, pos) {
          if (!stream.tty || !stream.tty.ops.put_char) {
            throw new FS.ErrnoError(ERRNO_CODES.ENXIO);
          }
          for (var i = 0; i < length; i++) {
            try {
              stream.tty.ops.put_char(stream.tty, buffer[offset+i]);
            } catch (e) {
              throw new FS.ErrnoError(ERRNO_CODES.EIO);
            }
          }
          if (length) {
            stream.node.timestamp = Date.now();
          }
          return i;
        }},default_tty_ops:{get_char:function (tty) {
          if (!tty.input.length) {
            var result = null;
            if (ENVIRONMENT_IS_NODE) {
              // we will read data by chunks of BUFSIZE
              var BUFSIZE = 256;
              var buf = new Buffer(BUFSIZE);
              var bytesRead = 0;
  
              var isPosixPlatform = (process.platform != 'win32'); // Node doesn't offer a direct check, so test by exclusion
  
              var fd = process.stdin.fd;
              if (isPosixPlatform) {
                // Linux and Mac cannot use process.stdin.fd (which isn't set up as sync)
                var usingDevice = false;
                try {
                  fd = fs.openSync('/dev/stdin', 'r');
                  usingDevice = true;
                } catch (e) {}
              }
  
              try {
                bytesRead = fs.readSync(fd, buf, 0, BUFSIZE, null);
              } catch(e) {
                // Cross-platform differences: on Windows, reading EOF throws an exception, but on other OSes,
                // reading EOF returns 0. Uniformize behavior by treating the EOF exception to return 0.
                if (e.toString().indexOf('EOF') != -1) bytesRead = 0;
                else throw e;
              }
  
              if (usingDevice) { fs.closeSync(fd); }
              if (bytesRead > 0) {
                result = buf.slice(0, bytesRead).toString('utf-8');
              } else {
                result = null;
              }
  
            } else if (typeof window != 'undefined' &&
              typeof window.prompt == 'function') {
              // Browser.
              result = window.prompt('Input: ');  // returns null on cancel
              if (result !== null) {
                result += '\n';
              }
            } else if (typeof readline == 'function') {
              // Command line.
              result = readline();
              if (result !== null) {
                result += '\n';
              }
            }
            if (!result) {
              return null;
            }
            tty.input = intArrayFromString(result, true);
          }
          return tty.input.shift();
        },put_char:function (tty, val) {
          if (val === null || val === 10) {
            Module['print'](UTF8ArrayToString(tty.output, 0));
            tty.output = [];
          } else {
            if (val != 0) tty.output.push(val); // val == 0 would cut text output off in the middle.
          }
        },flush:function (tty) {
          if (tty.output && tty.output.length > 0) {
            Module['print'](UTF8ArrayToString(tty.output, 0));
            tty.output = [];
          }
        }},default_tty1_ops:{put_char:function (tty, val) {
          if (val === null || val === 10) {
            Module['printErr'](UTF8ArrayToString(tty.output, 0));
            tty.output = [];
          } else {
            if (val != 0) tty.output.push(val);
          }
        },flush:function (tty) {
          if (tty.output && tty.output.length > 0) {
            Module['printErr'](UTF8ArrayToString(tty.output, 0));
            tty.output = [];
          }
        }}};
  
  var MEMFS={ops_table:null,mount:function (mount) {
        return MEMFS.createNode(null, '/', 16384 | 511 /* 0777 */, 0);
      },createNode:function (parent, name, mode, dev) {
        if (FS.isBlkdev(mode) || FS.isFIFO(mode)) {
          // no supported
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (!MEMFS.ops_table) {
          MEMFS.ops_table = {
            dir: {
              node: {
                getattr: MEMFS.node_ops.getattr,
                setattr: MEMFS.node_ops.setattr,
                lookup: MEMFS.node_ops.lookup,
                mknod: MEMFS.node_ops.mknod,
                rename: MEMFS.node_ops.rename,
                unlink: MEMFS.node_ops.unlink,
                rmdir: MEMFS.node_ops.rmdir,
                readdir: MEMFS.node_ops.readdir,
                symlink: MEMFS.node_ops.symlink
              },
              stream: {
                llseek: MEMFS.stream_ops.llseek
              }
            },
            file: {
              node: {
                getattr: MEMFS.node_ops.getattr,
                setattr: MEMFS.node_ops.setattr
              },
              stream: {
                llseek: MEMFS.stream_ops.llseek,
                read: MEMFS.stream_ops.read,
                write: MEMFS.stream_ops.write,
                allocate: MEMFS.stream_ops.allocate,
                mmap: MEMFS.stream_ops.mmap,
                msync: MEMFS.stream_ops.msync
              }
            },
            link: {
              node: {
                getattr: MEMFS.node_ops.getattr,
                setattr: MEMFS.node_ops.setattr,
                readlink: MEMFS.node_ops.readlink
              },
              stream: {}
            },
            chrdev: {
              node: {
                getattr: MEMFS.node_ops.getattr,
                setattr: MEMFS.node_ops.setattr
              },
              stream: FS.chrdev_stream_ops
            }
          };
        }
        var node = FS.createNode(parent, name, mode, dev);
        if (FS.isDir(node.mode)) {
          node.node_ops = MEMFS.ops_table.dir.node;
          node.stream_ops = MEMFS.ops_table.dir.stream;
          node.contents = {};
        } else if (FS.isFile(node.mode)) {
          node.node_ops = MEMFS.ops_table.file.node;
          node.stream_ops = MEMFS.ops_table.file.stream;
          node.usedBytes = 0; // The actual number of bytes used in the typed array, as opposed to contents.length which gives the whole capacity.
          // When the byte data of the file is populated, this will point to either a typed array, or a normal JS array. Typed arrays are preferred
          // for performance, and used by default. However, typed arrays are not resizable like normal JS arrays are, so there is a small disk size
          // penalty involved for appending file writes that continuously grow a file similar to std::vector capacity vs used -scheme.
          node.contents = null; 
        } else if (FS.isLink(node.mode)) {
          node.node_ops = MEMFS.ops_table.link.node;
          node.stream_ops = MEMFS.ops_table.link.stream;
        } else if (FS.isChrdev(node.mode)) {
          node.node_ops = MEMFS.ops_table.chrdev.node;
          node.stream_ops = MEMFS.ops_table.chrdev.stream;
        }
        node.timestamp = Date.now();
        // add the new node to the parent
        if (parent) {
          parent.contents[name] = node;
        }
        return node;
      },getFileDataAsRegularArray:function (node) {
        if (node.contents && node.contents.subarray) {
          var arr = [];
          for (var i = 0; i < node.usedBytes; ++i) arr.push(node.contents[i]);
          return arr; // Returns a copy of the original data.
        }
        return node.contents; // No-op, the file contents are already in a JS array. Return as-is.
      },getFileDataAsTypedArray:function (node) {
        if (!node.contents) return new Uint8Array;
        if (node.contents.subarray) return node.contents.subarray(0, node.usedBytes); // Make sure to not return excess unused bytes.
        return new Uint8Array(node.contents);
      },expandFileStorage:function (node, newCapacity) {
        // If we are asked to expand the size of a file that already exists, revert to using a standard JS array to store the file
        // instead of a typed array. This makes resizing the array more flexible because we can just .push() elements at the back to
        // increase the size.
        if (node.contents && node.contents.subarray && newCapacity > node.contents.length) {
          node.contents = MEMFS.getFileDataAsRegularArray(node);
          node.usedBytes = node.contents.length; // We might be writing to a lazy-loaded file which had overridden this property, so force-reset it.
        }
  
        if (!node.contents || node.contents.subarray) { // Keep using a typed array if creating a new storage, or if old one was a typed array as well.
          var prevCapacity = node.contents ? node.contents.length : 0;
          if (prevCapacity >= newCapacity) return; // No need to expand, the storage was already large enough.
          // Don't expand strictly to the given requested limit if it's only a very small increase, but instead geometrically grow capacity.
          // For small filesizes (<1MB), perform size*2 geometric increase, but for large sizes, do a much more conservative size*1.125 increase to
          // avoid overshooting the allocation cap by a very large margin.
          var CAPACITY_DOUBLING_MAX = 1024 * 1024;
          newCapacity = Math.max(newCapacity, (prevCapacity * (prevCapacity < CAPACITY_DOUBLING_MAX ? 2.0 : 1.125)) | 0);
          if (prevCapacity != 0) newCapacity = Math.max(newCapacity, 256); // At minimum allocate 256b for each file when expanding.
          var oldContents = node.contents;
          node.contents = new Uint8Array(newCapacity); // Allocate new storage.
          if (node.usedBytes > 0) node.contents.set(oldContents.subarray(0, node.usedBytes), 0); // Copy old data over to the new storage.
          return;
        }
        // Not using a typed array to back the file storage. Use a standard JS array instead.
        if (!node.contents && newCapacity > 0) node.contents = [];
        while (node.contents.length < newCapacity) node.contents.push(0);
      },resizeFileStorage:function (node, newSize) {
        if (node.usedBytes == newSize) return;
        if (newSize == 0) {
          node.contents = null; // Fully decommit when requesting a resize to zero.
          node.usedBytes = 0;
          return;
        }
        if (!node.contents || node.contents.subarray) { // Resize a typed array if that is being used as the backing store.
          var oldContents = node.contents;
          node.contents = new Uint8Array(new ArrayBuffer(newSize)); // Allocate new storage.
          if (oldContents) {
            node.contents.set(oldContents.subarray(0, Math.min(newSize, node.usedBytes))); // Copy old data over to the new storage.
          }
          node.usedBytes = newSize;
          return;
        }
        // Backing with a JS array.
        if (!node.contents) node.contents = [];
        if (node.contents.length > newSize) node.contents.length = newSize;
        else while (node.contents.length < newSize) node.contents.push(0);
        node.usedBytes = newSize;
      },node_ops:{getattr:function (node) {
          var attr = {};
          // device numbers reuse inode numbers.
          attr.dev = FS.isChrdev(node.mode) ? node.id : 1;
          attr.ino = node.id;
          attr.mode = node.mode;
          attr.nlink = 1;
          attr.uid = 0;
          attr.gid = 0;
          attr.rdev = node.rdev;
          if (FS.isDir(node.mode)) {
            attr.size = 4096;
          } else if (FS.isFile(node.mode)) {
            attr.size = node.usedBytes;
          } else if (FS.isLink(node.mode)) {
            attr.size = node.link.length;
          } else {
            attr.size = 0;
          }
          attr.atime = new Date(node.timestamp);
          attr.mtime = new Date(node.timestamp);
          attr.ctime = new Date(node.timestamp);
          // NOTE: In our implementation, st_blocks = Math.ceil(st_size/st_blksize),
          //       but this is not required by the standard.
          attr.blksize = 4096;
          attr.blocks = Math.ceil(attr.size / attr.blksize);
          return attr;
        },setattr:function (node, attr) {
          if (attr.mode !== undefined) {
            node.mode = attr.mode;
          }
          if (attr.timestamp !== undefined) {
            node.timestamp = attr.timestamp;
          }
          if (attr.size !== undefined) {
            MEMFS.resizeFileStorage(node, attr.size);
          }
        },lookup:function (parent, name) {
          throw FS.genericErrors[ERRNO_CODES.ENOENT];
        },mknod:function (parent, name, mode, dev) {
          return MEMFS.createNode(parent, name, mode, dev);
        },rename:function (old_node, new_dir, new_name) {
          // if we're overwriting a directory at new_name, make sure it's empty.
          if (FS.isDir(old_node.mode)) {
            var new_node;
            try {
              new_node = FS.lookupNode(new_dir, new_name);
            } catch (e) {
            }
            if (new_node) {
              for (var i in new_node.contents) {
                throw new FS.ErrnoError(ERRNO_CODES.ENOTEMPTY);
              }
            }
          }
          // do the internal rewiring
          delete old_node.parent.contents[old_node.name];
          old_node.name = new_name;
          new_dir.contents[new_name] = old_node;
          old_node.parent = new_dir;
        },unlink:function (parent, name) {
          delete parent.contents[name];
        },rmdir:function (parent, name) {
          var node = FS.lookupNode(parent, name);
          for (var i in node.contents) {
            throw new FS.ErrnoError(ERRNO_CODES.ENOTEMPTY);
          }
          delete parent.contents[name];
        },readdir:function (node) {
          var entries = ['.', '..']
          for (var key in node.contents) {
            if (!node.contents.hasOwnProperty(key)) {
              continue;
            }
            entries.push(key);
          }
          return entries;
        },symlink:function (parent, newname, oldpath) {
          var node = MEMFS.createNode(parent, newname, 511 /* 0777 */ | 40960, 0);
          node.link = oldpath;
          return node;
        },readlink:function (node) {
          if (!FS.isLink(node.mode)) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
          return node.link;
        }},stream_ops:{read:function (stream, buffer, offset, length, position) {
          var contents = stream.node.contents;
          if (position >= stream.node.usedBytes) return 0;
          var size = Math.min(stream.node.usedBytes - position, length);
          assert(size >= 0);
          if (size > 8 && contents.subarray) { // non-trivial, and typed array
            buffer.set(contents.subarray(position, position + size), offset);
          } else {
            for (var i = 0; i < size; i++) buffer[offset + i] = contents[position + i];
          }
          return size;
        },write:function (stream, buffer, offset, length, position, canOwn) {
          if (!length) return 0;
          var node = stream.node;
          node.timestamp = Date.now();
  
          if (buffer.subarray && (!node.contents || node.contents.subarray)) { // This write is from a typed array to a typed array?
            if (canOwn) {
              assert(position === 0, 'canOwn must imply no weird position inside the file');
              node.contents = buffer.subarray(offset, offset + length);
              node.usedBytes = length;
              return length;
            } else if (node.usedBytes === 0 && position === 0) { // If this is a simple first write to an empty file, do a fast set since we don't need to care about old data.
              node.contents = new Uint8Array(buffer.subarray(offset, offset + length));
              node.usedBytes = length;
              return length;
            } else if (position + length <= node.usedBytes) { // Writing to an already allocated and used subrange of the file?
              node.contents.set(buffer.subarray(offset, offset + length), position);
              return length;
            }
          }
  
          // Appending to an existing file and we need to reallocate, or source data did not come as a typed array.
          MEMFS.expandFileStorage(node, position+length);
          if (node.contents.subarray && buffer.subarray) node.contents.set(buffer.subarray(offset, offset + length), position); // Use typed array write if available.
          else {
            for (var i = 0; i < length; i++) {
             node.contents[position + i] = buffer[offset + i]; // Or fall back to manual write if not.
            }
          }
          node.usedBytes = Math.max(node.usedBytes, position+length);
          return length;
        },llseek:function (stream, offset, whence) {
          var position = offset;
          if (whence === 1) {  // SEEK_CUR.
            position += stream.position;
          } else if (whence === 2) {  // SEEK_END.
            if (FS.isFile(stream.node.mode)) {
              position += stream.node.usedBytes;
            }
          }
          if (position < 0) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
          return position;
        },allocate:function (stream, offset, length) {
          MEMFS.expandFileStorage(stream.node, offset + length);
          stream.node.usedBytes = Math.max(stream.node.usedBytes, offset + length);
        },mmap:function (stream, buffer, offset, length, position, prot, flags) {
          if (!FS.isFile(stream.node.mode)) {
            throw new FS.ErrnoError(ERRNO_CODES.ENODEV);
          }
          var ptr;
          var allocated;
          var contents = stream.node.contents;
          // Only make a new copy when MAP_PRIVATE is specified.
          if ( !(flags & 2) &&
                (contents.buffer === buffer || contents.buffer === buffer.buffer) ) {
            // We can't emulate MAP_SHARED when the file is not backed by the buffer
            // we're mapping to (e.g. the HEAP buffer).
            allocated = false;
            ptr = contents.byteOffset;
          } else {
            // Try to avoid unnecessary slices.
            if (position > 0 || position + length < stream.node.usedBytes) {
              if (contents.subarray) {
                contents = contents.subarray(position, position + length);
              } else {
                contents = Array.prototype.slice.call(contents, position, position + length);
              }
            }
            allocated = true;
            ptr = _malloc(length);
            if (!ptr) {
              throw new FS.ErrnoError(ERRNO_CODES.ENOMEM);
            }
            buffer.set(contents, ptr);
          }
          return { ptr: ptr, allocated: allocated };
        },msync:function (stream, buffer, offset, length, mmapFlags) {
          if (!FS.isFile(stream.node.mode)) {
            throw new FS.ErrnoError(ERRNO_CODES.ENODEV);
          }
          if (mmapFlags & 2) {
            // MAP_PRIVATE calls need not to be synced back to underlying fs
            return 0;
          }
  
          var bytesWritten = MEMFS.stream_ops.write(stream, buffer, 0, length, offset, false);
          // should we check if bytesWritten and length are the same?
          return 0;
        }}};
  
  var IDBFS={dbs:{},indexedDB:function () {
        if (typeof indexedDB !== 'undefined') return indexedDB;
        var ret = null;
        if (typeof window === 'object') ret = window.indexedDB || window.mozIndexedDB || window.webkitIndexedDB || window.msIndexedDB;
        assert(ret, 'IDBFS used, but indexedDB not supported');
        return ret;
      },DB_VERSION:21,DB_STORE_NAME:"FILE_DATA",mount:function (mount) {
        // reuse all of the core MEMFS functionality
        return MEMFS.mount.apply(null, arguments);
      },syncfs:function (mount, populate, callback) {
        IDBFS.getLocalSet(mount, function(err, local) {
          if (err) return callback(err);
  
          IDBFS.getRemoteSet(mount, function(err, remote) {
            if (err) return callback(err);
  
            var src = populate ? remote : local;
            var dst = populate ? local : remote;
  
            IDBFS.reconcile(src, dst, callback);
          });
        });
      },getDB:function (name, callback) {
        // check the cache first
        var db = IDBFS.dbs[name];
        if (db) {
          return callback(null, db);
        }
  
        var req;
        try {
          req = IDBFS.indexedDB().open(name, IDBFS.DB_VERSION);
        } catch (e) {
          return callback(e);
        }
        if (!req) {
          return callback("Unable to connect to IndexedDB");
        }
        req.onupgradeneeded = function(e) {
          var db = e.target.result;
          var transaction = e.target.transaction;
  
          var fileStore;
  
          if (db.objectStoreNames.contains(IDBFS.DB_STORE_NAME)) {
            fileStore = transaction.objectStore(IDBFS.DB_STORE_NAME);
          } else {
            fileStore = db.createObjectStore(IDBFS.DB_STORE_NAME);
          }
  
          if (!fileStore.indexNames.contains('timestamp')) {
            fileStore.createIndex('timestamp', 'timestamp', { unique: false });
          }
        };
        req.onsuccess = function() {
          db = req.result;
  
          // add to the cache
          IDBFS.dbs[name] = db;
          callback(null, db);
        };
        req.onerror = function(e) {
          callback(this.error);
          e.preventDefault();
        };
      },getLocalSet:function (mount, callback) {
        var entries = {};
  
        function isRealDir(p) {
          return p !== '.' && p !== '..';
        };
        function toAbsolute(root) {
          return function(p) {
            return PATH.join2(root, p);
          }
        };
  
        var check = FS.readdir(mount.mountpoint).filter(isRealDir).map(toAbsolute(mount.mountpoint));
  
        while (check.length) {
          var path = check.pop();
          var stat;
  
          try {
            stat = FS.stat(path);
          } catch (e) {
            return callback(e);
          }
  
          if (FS.isDir(stat.mode)) {
            check.push.apply(check, FS.readdir(path).filter(isRealDir).map(toAbsolute(path)));
          }
  
          entries[path] = { timestamp: stat.mtime };
        }
  
        return callback(null, { type: 'local', entries: entries });
      },getRemoteSet:function (mount, callback) {
        var entries = {};
  
        IDBFS.getDB(mount.mountpoint, function(err, db) {
          if (err) return callback(err);
  
          var transaction = db.transaction([IDBFS.DB_STORE_NAME], 'readonly');
          transaction.onerror = function(e) {
            callback(this.error);
            e.preventDefault();
          };
  
          var store = transaction.objectStore(IDBFS.DB_STORE_NAME);
          var index = store.index('timestamp');
  
          index.openKeyCursor().onsuccess = function(event) {
            var cursor = event.target.result;
  
            if (!cursor) {
              return callback(null, { type: 'remote', db: db, entries: entries });
            }
  
            entries[cursor.primaryKey] = { timestamp: cursor.key };
  
            cursor.continue();
          };
        });
      },loadLocalEntry:function (path, callback) {
        var stat, node;
  
        try {
          var lookup = FS.lookupPath(path);
          node = lookup.node;
          stat = FS.stat(path);
        } catch (e) {
          return callback(e);
        }
  
        if (FS.isDir(stat.mode)) {
          return callback(null, { timestamp: stat.mtime, mode: stat.mode });
        } else if (FS.isFile(stat.mode)) {
          // Performance consideration: storing a normal JavaScript array to a IndexedDB is much slower than storing a typed array.
          // Therefore always convert the file contents to a typed array first before writing the data to IndexedDB.
          node.contents = MEMFS.getFileDataAsTypedArray(node);
          return callback(null, { timestamp: stat.mtime, mode: stat.mode, contents: node.contents });
        } else {
          return callback(new Error('node type not supported'));
        }
      },storeLocalEntry:function (path, entry, callback) {
        try {
          if (FS.isDir(entry.mode)) {
            FS.mkdir(path, entry.mode);
          } else if (FS.isFile(entry.mode)) {
            FS.writeFile(path, entry.contents, { encoding: 'binary', canOwn: true });
          } else {
            return callback(new Error('node type not supported'));
          }
  
          FS.chmod(path, entry.mode);
          FS.utime(path, entry.timestamp, entry.timestamp);
        } catch (e) {
          return callback(e);
        }
  
        callback(null);
      },removeLocalEntry:function (path, callback) {
        try {
          var lookup = FS.lookupPath(path);
          var stat = FS.stat(path);
  
          if (FS.isDir(stat.mode)) {
            FS.rmdir(path);
          } else if (FS.isFile(stat.mode)) {
            FS.unlink(path);
          }
        } catch (e) {
          return callback(e);
        }
  
        callback(null);
      },loadRemoteEntry:function (store, path, callback) {
        var req = store.get(path);
        req.onsuccess = function(event) { callback(null, event.target.result); };
        req.onerror = function(e) {
          callback(this.error);
          e.preventDefault();
        };
      },storeRemoteEntry:function (store, path, entry, callback) {
        var req = store.put(entry, path);
        req.onsuccess = function() { callback(null); };
        req.onerror = function(e) {
          callback(this.error);
          e.preventDefault();
        };
      },removeRemoteEntry:function (store, path, callback) {
        var req = store.delete(path);
        req.onsuccess = function() { callback(null); };
        req.onerror = function(e) {
          callback(this.error);
          e.preventDefault();
        };
      },reconcile:function (src, dst, callback) {
        var total = 0;
  
        var create = [];
        Object.keys(src.entries).forEach(function (key) {
          var e = src.entries[key];
          var e2 = dst.entries[key];
          if (!e2 || e.timestamp > e2.timestamp) {
            create.push(key);
            total++;
          }
        });
  
        var remove = [];
        Object.keys(dst.entries).forEach(function (key) {
          var e = dst.entries[key];
          var e2 = src.entries[key];
          if (!e2) {
            remove.push(key);
            total++;
          }
        });
  
        if (!total) {
          return callback(null);
        }
  
        var errored = false;
        var completed = 0;
        var db = src.type === 'remote' ? src.db : dst.db;
        var transaction = db.transaction([IDBFS.DB_STORE_NAME], 'readwrite');
        var store = transaction.objectStore(IDBFS.DB_STORE_NAME);
  
        function done(err) {
          if (err) {
            if (!done.errored) {
              done.errored = true;
              return callback(err);
            }
            return;
          }
          if (++completed >= total) {
            return callback(null);
          }
        };
  
        transaction.onerror = function(e) {
          done(this.error);
          e.preventDefault();
        };
  
        // sort paths in ascending order so directory entries are created
        // before the files inside them
        create.sort().forEach(function (path) {
          if (dst.type === 'local') {
            IDBFS.loadRemoteEntry(store, path, function (err, entry) {
              if (err) return done(err);
              IDBFS.storeLocalEntry(path, entry, done);
            });
          } else {
            IDBFS.loadLocalEntry(path, function (err, entry) {
              if (err) return done(err);
              IDBFS.storeRemoteEntry(store, path, entry, done);
            });
          }
        });
  
        // sort paths in descending order so files are deleted before their
        // parent directories
        remove.sort().reverse().forEach(function(path) {
          if (dst.type === 'local') {
            IDBFS.removeLocalEntry(path, done);
          } else {
            IDBFS.removeRemoteEntry(store, path, done);
          }
        });
      }};
  
  var NODEFS={isWindows:false,staticInit:function () {
        NODEFS.isWindows = !!process.platform.match(/^win/);
      },mount:function (mount) {
        assert(ENVIRONMENT_IS_NODE);
        return NODEFS.createNode(null, '/', NODEFS.getMode(mount.opts.root), 0);
      },createNode:function (parent, name, mode, dev) {
        if (!FS.isDir(mode) && !FS.isFile(mode) && !FS.isLink(mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var node = FS.createNode(parent, name, mode);
        node.node_ops = NODEFS.node_ops;
        node.stream_ops = NODEFS.stream_ops;
        return node;
      },getMode:function (path) {
        var stat;
        try {
          stat = fs.lstatSync(path);
          if (NODEFS.isWindows) {
            // On Windows, directories return permission bits 'rw-rw-rw-', even though they have 'rwxrwxrwx', so
            // propagate write bits to execute bits.
            stat.mode = stat.mode | ((stat.mode & 146) >> 1);
          }
        } catch (e) {
          if (!e.code) throw e;
          throw new FS.ErrnoError(ERRNO_CODES[e.code]);
        }
        return stat.mode;
      },realPath:function (node) {
        var parts = [];
        while (node.parent !== node) {
          parts.push(node.name);
          node = node.parent;
        }
        parts.push(node.mount.opts.root);
        parts.reverse();
        return PATH.join.apply(null, parts);
      },flagsToPermissionStringMap:{0:"r",1:"r+",2:"r+",64:"r",65:"r+",66:"r+",129:"rx+",193:"rx+",514:"w+",577:"w",578:"w+",705:"wx",706:"wx+",1024:"a",1025:"a",1026:"a+",1089:"a",1090:"a+",1153:"ax",1154:"ax+",1217:"ax",1218:"ax+",4096:"rs",4098:"rs+"},flagsToPermissionString:function (flags) {
        flags &= ~0x200000 /*O_PATH*/; // Ignore this flag from musl, otherwise node.js fails to open the file.
        flags &= ~0x800 /*O_NONBLOCK*/; // Ignore this flag from musl, otherwise node.js fails to open the file.
        flags &= ~0x8000 /*O_LARGEFILE*/; // Ignore this flag from musl, otherwise node.js fails to open the file.
        flags &= ~0x80000 /*O_CLOEXEC*/; // Some applications may pass it; it makes no sense for a single process.
        if (flags in NODEFS.flagsToPermissionStringMap) {
          return NODEFS.flagsToPermissionStringMap[flags];
        } else {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
      },node_ops:{getattr:function (node) {
          var path = NODEFS.realPath(node);
          var stat;
          try {
            stat = fs.lstatSync(path);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
          // node.js v0.10.20 doesn't report blksize and blocks on Windows. Fake them with default blksize of 4096.
          // See http://support.microsoft.com/kb/140365
          if (NODEFS.isWindows && !stat.blksize) {
            stat.blksize = 4096;
          }
          if (NODEFS.isWindows && !stat.blocks) {
            stat.blocks = (stat.size+stat.blksize-1)/stat.blksize|0;
          }
          return {
            dev: stat.dev,
            ino: stat.ino,
            mode: stat.mode,
            nlink: stat.nlink,
            uid: stat.uid,
            gid: stat.gid,
            rdev: stat.rdev,
            size: stat.size,
            atime: stat.atime,
            mtime: stat.mtime,
            ctime: stat.ctime,
            blksize: stat.blksize,
            blocks: stat.blocks
          };
        },setattr:function (node, attr) {
          var path = NODEFS.realPath(node);
          try {
            if (attr.mode !== undefined) {
              fs.chmodSync(path, attr.mode);
              // update the common node structure mode as well
              node.mode = attr.mode;
            }
            if (attr.timestamp !== undefined) {
              var date = new Date(attr.timestamp);
              fs.utimesSync(path, date, date);
            }
            if (attr.size !== undefined) {
              fs.truncateSync(path, attr.size);
            }
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },lookup:function (parent, name) {
          var path = PATH.join2(NODEFS.realPath(parent), name);
          var mode = NODEFS.getMode(path);
          return NODEFS.createNode(parent, name, mode);
        },mknod:function (parent, name, mode, dev) {
          var node = NODEFS.createNode(parent, name, mode, dev);
          // create the backing node for this in the fs root as well
          var path = NODEFS.realPath(node);
          try {
            if (FS.isDir(node.mode)) {
              fs.mkdirSync(path, node.mode);
            } else {
              fs.writeFileSync(path, '', { mode: node.mode });
            }
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
          return node;
        },rename:function (oldNode, newDir, newName) {
          var oldPath = NODEFS.realPath(oldNode);
          var newPath = PATH.join2(NODEFS.realPath(newDir), newName);
          try {
            fs.renameSync(oldPath, newPath);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },unlink:function (parent, name) {
          var path = PATH.join2(NODEFS.realPath(parent), name);
          try {
            fs.unlinkSync(path);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },rmdir:function (parent, name) {
          var path = PATH.join2(NODEFS.realPath(parent), name);
          try {
            fs.rmdirSync(path);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },readdir:function (node) {
          var path = NODEFS.realPath(node);
          try {
            return fs.readdirSync(path);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },symlink:function (parent, newName, oldPath) {
          var newPath = PATH.join2(NODEFS.realPath(parent), newName);
          try {
            fs.symlinkSync(oldPath, newPath);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },readlink:function (node) {
          var path = NODEFS.realPath(node);
          try {
            path = fs.readlinkSync(path);
            path = NODEJS_PATH.relative(NODEJS_PATH.resolve(node.mount.opts.root), path);
            return path;
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        }},stream_ops:{open:function (stream) {
          var path = NODEFS.realPath(stream.node);
          try {
            if (FS.isFile(stream.node.mode)) {
              stream.nfd = fs.openSync(path, NODEFS.flagsToPermissionString(stream.flags));
            }
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },close:function (stream) {
          try {
            if (FS.isFile(stream.node.mode) && stream.nfd) {
              fs.closeSync(stream.nfd);
            }
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },read:function (stream, buffer, offset, length, position) {
          if (length === 0) return 0; // node errors on 0 length reads
          // FIXME this is terrible.
          var nbuffer = new Buffer(length);
          var res;
          try {
            res = fs.readSync(stream.nfd, nbuffer, 0, length, position);
          } catch (e) {
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
          if (res > 0) {
            for (var i = 0; i < res; i++) {
              buffer[offset + i] = nbuffer[i];
            }
          }
          return res;
        },write:function (stream, buffer, offset, length, position) {
          // FIXME this is terrible.
          var nbuffer = new Buffer(buffer.subarray(offset, offset + length));
          var res;
          try {
            res = fs.writeSync(stream.nfd, nbuffer, 0, length, position);
          } catch (e) {
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
          return res;
        },llseek:function (stream, offset, whence) {
          var position = offset;
          if (whence === 1) {  // SEEK_CUR.
            position += stream.position;
          } else if (whence === 2) {  // SEEK_END.
            if (FS.isFile(stream.node.mode)) {
              try {
                var stat = fs.fstatSync(stream.nfd);
                position += stat.size;
              } catch (e) {
                throw new FS.ErrnoError(ERRNO_CODES[e.code]);
              }
            }
          }
  
          if (position < 0) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
  
          return position;
        }}};
  
  var WORKERFS={DIR_MODE:16895,FILE_MODE:33279,reader:null,mount:function (mount) {
        assert(ENVIRONMENT_IS_WORKER);
        if (!WORKERFS.reader) WORKERFS.reader = new FileReaderSync();
        var root = WORKERFS.createNode(null, '/', WORKERFS.DIR_MODE, 0);
        var createdParents = {};
        function ensureParent(path) {
          // return the parent node, creating subdirs as necessary
          var parts = path.split('/');
          var parent = root;
          for (var i = 0; i < parts.length-1; i++) {
            var curr = parts.slice(0, i+1).join('/');
            // Issue 4254: Using curr as a node name will prevent the node
            // from being found in FS.nameTable when FS.open is called on
            // a path which holds a child of this node,
            // given that all FS functions assume node names
            // are just their corresponding parts within their given path,
            // rather than incremental aggregates which include their parent's
            // directories.
            if (!createdParents[curr]) {
              createdParents[curr] = WORKERFS.createNode(parent, parts[i], WORKERFS.DIR_MODE, 0);
            }
            parent = createdParents[curr];
          }
          return parent;
        }
        function base(path) {
          var parts = path.split('/');
          return parts[parts.length-1];
        }
        // We also accept FileList here, by using Array.prototype
        Array.prototype.forEach.call(mount.opts["files"] || [], function(file) {
          WORKERFS.createNode(ensureParent(file.name), base(file.name), WORKERFS.FILE_MODE, 0, file, file.lastModifiedDate);
        });
        (mount.opts["blobs"] || []).forEach(function(obj) {
          WORKERFS.createNode(ensureParent(obj["name"]), base(obj["name"]), WORKERFS.FILE_MODE, 0, obj["data"]);
        });
        (mount.opts["packages"] || []).forEach(function(pack) {
          pack['metadata'].files.forEach(function(file) {
            var name = file.filename.substr(1); // remove initial slash
            WORKERFS.createNode(ensureParent(name), base(name), WORKERFS.FILE_MODE, 0, pack['blob'].slice(file.start, file.end));
          });
        });
        return root;
      },createNode:function (parent, name, mode, dev, contents, mtime) {
        var node = FS.createNode(parent, name, mode);
        node.mode = mode;
        node.node_ops = WORKERFS.node_ops;
        node.stream_ops = WORKERFS.stream_ops;
        node.timestamp = (mtime || new Date).getTime();
        assert(WORKERFS.FILE_MODE !== WORKERFS.DIR_MODE);
        if (mode === WORKERFS.FILE_MODE) {
          node.size = contents.size;
          node.contents = contents;
        } else {
          node.size = 4096;
          node.contents = {};
        }
        if (parent) {
          parent.contents[name] = node;
        }
        return node;
      },node_ops:{getattr:function (node) {
          return {
            dev: 1,
            ino: undefined,
            mode: node.mode,
            nlink: 1,
            uid: 0,
            gid: 0,
            rdev: undefined,
            size: node.size,
            atime: new Date(node.timestamp),
            mtime: new Date(node.timestamp),
            ctime: new Date(node.timestamp),
            blksize: 4096,
            blocks: Math.ceil(node.size / 4096),
          };
        },setattr:function (node, attr) {
          if (attr.mode !== undefined) {
            node.mode = attr.mode;
          }
          if (attr.timestamp !== undefined) {
            node.timestamp = attr.timestamp;
          }
        },lookup:function (parent, name) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        },mknod:function (parent, name, mode, dev) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        },rename:function (oldNode, newDir, newName) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        },unlink:function (parent, name) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        },rmdir:function (parent, name) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        },readdir:function (node) {
          var entries = ['.', '..'];
          for (var key in node.contents) {
            if (!node.contents.hasOwnProperty(key)) {
              continue;
            }
            entries.push(key);
          }
          return entries;
        },symlink:function (parent, newName, oldPath) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        },readlink:function (node) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }},stream_ops:{read:function (stream, buffer, offset, length, position) {
          if (position >= stream.node.size) return 0;
          var chunk = stream.node.contents.slice(position, position + length);
          var ab = WORKERFS.reader.readAsArrayBuffer(chunk);
          buffer.set(new Uint8Array(ab), offset);
          return chunk.size;
        },write:function (stream, buffer, offset, length, position) {
          throw new FS.ErrnoError(ERRNO_CODES.EIO);
        },llseek:function (stream, offset, whence) {
          var position = offset;
          if (whence === 1) {  // SEEK_CUR.
            position += stream.position;
          } else if (whence === 2) {  // SEEK_END.
            if (FS.isFile(stream.node.mode)) {
              position += stream.node.size;
            }
          }
          if (position < 0) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
          return position;
        }}};
  
  var _stdin=STATICTOP; STATICTOP += 16;;
  
  var _stdout=STATICTOP; STATICTOP += 16;;
  
  var _stderr=STATICTOP; STATICTOP += 16;;var FS={root:null,mounts:[],devices:[null],streams:[],nextInode:1,nameTable:null,currentPath:"/",initialized:false,ignorePermissions:true,trackingDelegate:{},tracking:{openFlags:{READ:1,WRITE:2}},ErrnoError:null,genericErrors:{},filesystems:null,syncFSRequests:0,handleFSError:function (e) {
        if (!(e instanceof FS.ErrnoError)) throw e + ' : ' + stackTrace();
        return ___setErrNo(e.errno);
      },lookupPath:function (path, opts) {
        path = PATH.resolve(FS.cwd(), path);
        opts = opts || {};
  
        if (!path) return { path: '', node: null };
  
        var defaults = {
          follow_mount: true,
          recurse_count: 0
        };
        for (var key in defaults) {
          if (opts[key] === undefined) {
            opts[key] = defaults[key];
          }
        }
  
        if (opts.recurse_count > 8) {  // max recursive lookup of 8
          throw new FS.ErrnoError(ERRNO_CODES.ELOOP);
        }
  
        // split the path
        var parts = PATH.normalizeArray(path.split('/').filter(function(p) {
          return !!p;
        }), false);
  
        // start at the root
        var current = FS.root;
        var current_path = '/';
  
        for (var i = 0; i < parts.length; i++) {
          var islast = (i === parts.length-1);
          if (islast && opts.parent) {
            // stop resolving
            break;
          }
  
          current = FS.lookupNode(current, parts[i]);
          current_path = PATH.join2(current_path, parts[i]);
  
          // jump to the mount's root node if this is a mountpoint
          if (FS.isMountpoint(current)) {
            if (!islast || (islast && opts.follow_mount)) {
              current = current.mounted.root;
            }
          }
  
          // by default, lookupPath will not follow a symlink if it is the final path component.
          // setting opts.follow = true will override this behavior.
          if (!islast || opts.follow) {
            var count = 0;
            while (FS.isLink(current.mode)) {
              var link = FS.readlink(current_path);
              current_path = PATH.resolve(PATH.dirname(current_path), link);
  
              var lookup = FS.lookupPath(current_path, { recurse_count: opts.recurse_count });
              current = lookup.node;
  
              if (count++ > 40) {  // limit max consecutive symlinks to 40 (SYMLOOP_MAX).
                throw new FS.ErrnoError(ERRNO_CODES.ELOOP);
              }
            }
          }
        }
  
        return { path: current_path, node: current };
      },getPath:function (node) {
        var path;
        while (true) {
          if (FS.isRoot(node)) {
            var mount = node.mount.mountpoint;
            if (!path) return mount;
            return mount[mount.length-1] !== '/' ? mount + '/' + path : mount + path;
          }
          path = path ? node.name + '/' + path : node.name;
          node = node.parent;
        }
      },hashName:function (parentid, name) {
        var hash = 0;
  
  
        for (var i = 0; i < name.length; i++) {
          hash = ((hash << 5) - hash + name.charCodeAt(i)) | 0;
        }
        return ((parentid + hash) >>> 0) % FS.nameTable.length;
      },hashAddNode:function (node) {
        var hash = FS.hashName(node.parent.id, node.name);
        node.name_next = FS.nameTable[hash];
        FS.nameTable[hash] = node;
      },hashRemoveNode:function (node) {
        var hash = FS.hashName(node.parent.id, node.name);
        if (FS.nameTable[hash] === node) {
          FS.nameTable[hash] = node.name_next;
        } else {
          var current = FS.nameTable[hash];
          while (current) {
            if (current.name_next === node) {
              current.name_next = node.name_next;
              break;
            }
            current = current.name_next;
          }
        }
      },lookupNode:function (parent, name) {
        var err = FS.mayLookup(parent);
        if (err) {
          throw new FS.ErrnoError(err, parent);
        }
        var hash = FS.hashName(parent.id, name);
        for (var node = FS.nameTable[hash]; node; node = node.name_next) {
          var nodeName = node.name;
          if (node.parent.id === parent.id && nodeName === name) {
            return node;
          }
        }
        // if we failed to find it in the cache, call into the VFS
        return FS.lookup(parent, name);
      },createNode:function (parent, name, mode, rdev) {
        if (!FS.FSNode) {
          FS.FSNode = function(parent, name, mode, rdev) {
            if (!parent) {
              parent = this;  // root node sets parent to itself
            }
            this.parent = parent;
            this.mount = parent.mount;
            this.mounted = null;
            this.id = FS.nextInode++;
            this.name = name;
            this.mode = mode;
            this.node_ops = {};
            this.stream_ops = {};
            this.rdev = rdev;
          };
  
          FS.FSNode.prototype = {};
  
          // compatibility
          var readMode = 292 | 73;
          var writeMode = 146;
  
          // NOTE we must use Object.defineProperties instead of individual calls to
          // Object.defineProperty in order to make closure compiler happy
          Object.defineProperties(FS.FSNode.prototype, {
            read: {
              get: function() { return (this.mode & readMode) === readMode; },
              set: function(val) { val ? this.mode |= readMode : this.mode &= ~readMode; }
            },
            write: {
              get: function() { return (this.mode & writeMode) === writeMode; },
              set: function(val) { val ? this.mode |= writeMode : this.mode &= ~writeMode; }
            },
            isFolder: {
              get: function() { return FS.isDir(this.mode); }
            },
            isDevice: {
              get: function() { return FS.isChrdev(this.mode); }
            }
          });
        }
  
        var node = new FS.FSNode(parent, name, mode, rdev);
  
        FS.hashAddNode(node);
  
        return node;
      },destroyNode:function (node) {
        FS.hashRemoveNode(node);
      },isRoot:function (node) {
        return node === node.parent;
      },isMountpoint:function (node) {
        return !!node.mounted;
      },isFile:function (mode) {
        return (mode & 61440) === 32768;
      },isDir:function (mode) {
        return (mode & 61440) === 16384;
      },isLink:function (mode) {
        return (mode & 61440) === 40960;
      },isChrdev:function (mode) {
        return (mode & 61440) === 8192;
      },isBlkdev:function (mode) {
        return (mode & 61440) === 24576;
      },isFIFO:function (mode) {
        return (mode & 61440) === 4096;
      },isSocket:function (mode) {
        return (mode & 49152) === 49152;
      },flagModes:{"r":0,"rs":1052672,"r+":2,"w":577,"wx":705,"xw":705,"w+":578,"wx+":706,"xw+":706,"a":1089,"ax":1217,"xa":1217,"a+":1090,"ax+":1218,"xa+":1218},modeStringToFlags:function (str) {
        var flags = FS.flagModes[str];
        if (typeof flags === 'undefined') {
          throw new Error('Unknown file open mode: ' + str);
        }
        return flags;
      },flagsToPermissionString:function (flag) {
        var perms = ['r', 'w', 'rw'][flag & 3];
        if ((flag & 512)) {
          perms += 'w';
        }
        return perms;
      },nodePermissions:function (node, perms) {
        if (FS.ignorePermissions) {
          return 0;
        }
        // return 0 if any user, group or owner bits are set.
        if (perms.indexOf('r') !== -1 && !(node.mode & 292)) {
          return ERRNO_CODES.EACCES;
        } else if (perms.indexOf('w') !== -1 && !(node.mode & 146)) {
          return ERRNO_CODES.EACCES;
        } else if (perms.indexOf('x') !== -1 && !(node.mode & 73)) {
          return ERRNO_CODES.EACCES;
        }
        return 0;
      },mayLookup:function (dir) {
        var err = FS.nodePermissions(dir, 'x');
        if (err) return err;
        if (!dir.node_ops.lookup) return ERRNO_CODES.EACCES;
        return 0;
      },mayCreate:function (dir, name) {
        try {
          var node = FS.lookupNode(dir, name);
          return ERRNO_CODES.EEXIST;
        } catch (e) {
        }
        return FS.nodePermissions(dir, 'wx');
      },mayDelete:function (dir, name, isdir) {
        var node;
        try {
          node = FS.lookupNode(dir, name);
        } catch (e) {
          return e.errno;
        }
        var err = FS.nodePermissions(dir, 'wx');
        if (err) {
          return err;
        }
        if (isdir) {
          if (!FS.isDir(node.mode)) {
            return ERRNO_CODES.ENOTDIR;
          }
          if (FS.isRoot(node) || FS.getPath(node) === FS.cwd()) {
            return ERRNO_CODES.EBUSY;
          }
        } else {
          if (FS.isDir(node.mode)) {
            return ERRNO_CODES.EISDIR;
          }
        }
        return 0;
      },mayOpen:function (node, flags) {
        if (!node) {
          return ERRNO_CODES.ENOENT;
        }
        if (FS.isLink(node.mode)) {
          return ERRNO_CODES.ELOOP;
        } else if (FS.isDir(node.mode)) {
          if (FS.flagsToPermissionString(flags) !== 'r' || // opening for write
              (flags & 512)) { // TODO: check for O_SEARCH? (== search for dir only)
            return ERRNO_CODES.EISDIR;
          }
        }
        return FS.nodePermissions(node, FS.flagsToPermissionString(flags));
      },MAX_OPEN_FDS:4096,nextfd:function (fd_start, fd_end) {
        fd_start = fd_start || 0;
        fd_end = fd_end || FS.MAX_OPEN_FDS;
        for (var fd = fd_start; fd <= fd_end; fd++) {
          if (!FS.streams[fd]) {
            return fd;
          }
        }
        throw new FS.ErrnoError(ERRNO_CODES.EMFILE);
      },getStream:function (fd) {
        return FS.streams[fd];
      },createStream:function (stream, fd_start, fd_end) {
        if (!FS.FSStream) {
          FS.FSStream = function(){};
          FS.FSStream.prototype = {};
          // compatibility
          Object.defineProperties(FS.FSStream.prototype, {
            object: {
              get: function() { return this.node; },
              set: function(val) { this.node = val; }
            },
            isRead: {
              get: function() { return (this.flags & 2097155) !== 1; }
            },
            isWrite: {
              get: function() { return (this.flags & 2097155) !== 0; }
            },
            isAppend: {
              get: function() { return (this.flags & 1024); }
            }
          });
        }
        // clone it, so we can return an instance of FSStream
        var newStream = new FS.FSStream();
        for (var p in stream) {
          newStream[p] = stream[p];
        }
        stream = newStream;
        var fd = FS.nextfd(fd_start, fd_end);
        stream.fd = fd;
        FS.streams[fd] = stream;
        return stream;
      },closeStream:function (fd) {
        FS.streams[fd] = null;
      },chrdev_stream_ops:{open:function (stream) {
          var device = FS.getDevice(stream.node.rdev);
          // override node's stream ops with the device's
          stream.stream_ops = device.stream_ops;
          // forward the open call
          if (stream.stream_ops.open) {
            stream.stream_ops.open(stream);
          }
        },llseek:function () {
          throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);
        }},major:function (dev) {
        return ((dev) >> 8);
      },minor:function (dev) {
        return ((dev) & 0xff);
      },makedev:function (ma, mi) {
        return ((ma) << 8 | (mi));
      },registerDevice:function (dev, ops) {
        FS.devices[dev] = { stream_ops: ops };
      },getDevice:function (dev) {
        return FS.devices[dev];
      },getMounts:function (mount) {
        var mounts = [];
        var check = [mount];
  
        while (check.length) {
          var m = check.pop();
  
          mounts.push(m);
  
          check.push.apply(check, m.mounts);
        }
  
        return mounts;
      },syncfs:function (populate, callback) {
        if (typeof(populate) === 'function') {
          callback = populate;
          populate = false;
        }
  
        FS.syncFSRequests++;
  
        if (FS.syncFSRequests > 1) {
          console.log('warning: ' + FS.syncFSRequests + ' FS.syncfs operations in flight at once, probably just doing extra work');
        }
  
        var mounts = FS.getMounts(FS.root.mount);
        var completed = 0;
  
        function doCallback(err) {
          assert(FS.syncFSRequests > 0);
          FS.syncFSRequests--;
          return callback(err);
        }
  
        function done(err) {
          if (err) {
            if (!done.errored) {
              done.errored = true;
              return doCallback(err);
            }
            return;
          }
          if (++completed >= mounts.length) {
            doCallback(null);
          }
        };
  
        // sync all mounts
        mounts.forEach(function (mount) {
          if (!mount.type.syncfs) {
            return done(null);
          }
          mount.type.syncfs(mount, populate, done);
        });
      },mount:function (type, opts, mountpoint) {
        var root = mountpoint === '/';
        var pseudo = !mountpoint;
        var node;
  
        if (root && FS.root) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        } else if (!root && !pseudo) {
          var lookup = FS.lookupPath(mountpoint, { follow_mount: false });
  
          mountpoint = lookup.path;  // use the absolute path
          node = lookup.node;
  
          if (FS.isMountpoint(node)) {
            throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
          }
  
          if (!FS.isDir(node.mode)) {
            throw new FS.ErrnoError(ERRNO_CODES.ENOTDIR);
          }
        }
  
        var mount = {
          type: type,
          opts: opts,
          mountpoint: mountpoint,
          mounts: []
        };
  
        // create a root node for the fs
        var mountRoot = type.mount(mount);
        mountRoot.mount = mount;
        mount.root = mountRoot;
  
        if (root) {
          FS.root = mountRoot;
        } else if (node) {
          // set as a mountpoint
          node.mounted = mount;
  
          // add the new mount to the current mount's children
          if (node.mount) {
            node.mount.mounts.push(mount);
          }
        }
  
        return mountRoot;
      },unmount:function (mountpoint) {
        var lookup = FS.lookupPath(mountpoint, { follow_mount: false });
  
        if (!FS.isMountpoint(lookup.node)) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
  
        // destroy the nodes for this mount, and all its child mounts
        var node = lookup.node;
        var mount = node.mounted;
        var mounts = FS.getMounts(mount);
  
        Object.keys(FS.nameTable).forEach(function (hash) {
          var current = FS.nameTable[hash];
  
          while (current) {
            var next = current.name_next;
  
            if (mounts.indexOf(current.mount) !== -1) {
              FS.destroyNode(current);
            }
  
            current = next;
          }
        });
  
        // no longer a mountpoint
        node.mounted = null;
  
        // remove this mount from the child mounts
        var idx = node.mount.mounts.indexOf(mount);
        assert(idx !== -1);
        node.mount.mounts.splice(idx, 1);
      },lookup:function (parent, name) {
        return parent.node_ops.lookup(parent, name);
      },mknod:function (path, mode, dev) {
        var lookup = FS.lookupPath(path, { parent: true });
        var parent = lookup.node;
        var name = PATH.basename(path);
        if (!name || name === '.' || name === '..') {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var err = FS.mayCreate(parent, name);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        if (!parent.node_ops.mknod) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        return parent.node_ops.mknod(parent, name, mode, dev);
      },create:function (path, mode) {
        mode = mode !== undefined ? mode : 438 /* 0666 */;
        mode &= 4095;
        mode |= 32768;
        return FS.mknod(path, mode, 0);
      },mkdir:function (path, mode) {
        mode = mode !== undefined ? mode : 511 /* 0777 */;
        mode &= 511 | 512;
        mode |= 16384;
        return FS.mknod(path, mode, 0);
      },mkdirTree:function (path, mode) {
        var dirs = path.split('/');
        var d = '';
        for (var i = 0; i < dirs.length; ++i) {
          if (!dirs[i]) continue;
          d += '/' + dirs[i];
          try {
            FS.mkdir(d, mode);
          } catch(e) {
            if (e.errno != ERRNO_CODES.EEXIST) throw e;
          }
        }
      },mkdev:function (path, mode, dev) {
        if (typeof(dev) === 'undefined') {
          dev = mode;
          mode = 438 /* 0666 */;
        }
        mode |= 8192;
        return FS.mknod(path, mode, dev);
      },symlink:function (oldpath, newpath) {
        if (!PATH.resolve(oldpath)) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        }
        var lookup = FS.lookupPath(newpath, { parent: true });
        var parent = lookup.node;
        if (!parent) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        }
        var newname = PATH.basename(newpath);
        var err = FS.mayCreate(parent, newname);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        if (!parent.node_ops.symlink) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        return parent.node_ops.symlink(parent, newname, oldpath);
      },rename:function (old_path, new_path) {
        var old_dirname = PATH.dirname(old_path);
        var new_dirname = PATH.dirname(new_path);
        var old_name = PATH.basename(old_path);
        var new_name = PATH.basename(new_path);
        // parents must exist
        var lookup, old_dir, new_dir;
        try {
          lookup = FS.lookupPath(old_path, { parent: true });
          old_dir = lookup.node;
          lookup = FS.lookupPath(new_path, { parent: true });
          new_dir = lookup.node;
        } catch (e) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        }
        if (!old_dir || !new_dir) throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        // need to be part of the same mount
        if (old_dir.mount !== new_dir.mount) {
          throw new FS.ErrnoError(ERRNO_CODES.EXDEV);
        }
        // source must exist
        var old_node = FS.lookupNode(old_dir, old_name);
        // old path should not be an ancestor of the new path
        var relative = PATH.relative(old_path, new_dirname);
        if (relative.charAt(0) !== '.') {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        // new path should not be an ancestor of the old path
        relative = PATH.relative(new_path, old_dirname);
        if (relative.charAt(0) !== '.') {
          throw new FS.ErrnoError(ERRNO_CODES.ENOTEMPTY);
        }
        // see if the new path already exists
        var new_node;
        try {
          new_node = FS.lookupNode(new_dir, new_name);
        } catch (e) {
          // not fatal
        }
        // early out if nothing needs to change
        if (old_node === new_node) {
          return;
        }
        // we'll need to delete the old entry
        var isdir = FS.isDir(old_node.mode);
        var err = FS.mayDelete(old_dir, old_name, isdir);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        // need delete permissions if we'll be overwriting.
        // need create permissions if new doesn't already exist.
        err = new_node ?
          FS.mayDelete(new_dir, new_name, isdir) :
          FS.mayCreate(new_dir, new_name);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        if (!old_dir.node_ops.rename) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (FS.isMountpoint(old_node) || (new_node && FS.isMountpoint(new_node))) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        }
        // if we are going to change the parent, check write permissions
        if (new_dir !== old_dir) {
          err = FS.nodePermissions(old_dir, 'w');
          if (err) {
            throw new FS.ErrnoError(err);
          }
        }
        try {
          if (FS.trackingDelegate['willMovePath']) {
            FS.trackingDelegate['willMovePath'](old_path, new_path);
          }
        } catch(e) {
          console.log("FS.trackingDelegate['willMovePath']('"+old_path+"', '"+new_path+"') threw an exception: " + e.message);
        }
        // remove the node from the lookup hash
        FS.hashRemoveNode(old_node);
        // do the underlying fs rename
        try {
          old_dir.node_ops.rename(old_node, new_dir, new_name);
        } catch (e) {
          throw e;
        } finally {
          // add the node back to the hash (in case node_ops.rename
          // changed its name)
          FS.hashAddNode(old_node);
        }
        try {
          if (FS.trackingDelegate['onMovePath']) FS.trackingDelegate['onMovePath'](old_path, new_path);
        } catch(e) {
          console.log("FS.trackingDelegate['onMovePath']('"+old_path+"', '"+new_path+"') threw an exception: " + e.message);
        }
      },rmdir:function (path) {
        var lookup = FS.lookupPath(path, { parent: true });
        var parent = lookup.node;
        var name = PATH.basename(path);
        var node = FS.lookupNode(parent, name);
        var err = FS.mayDelete(parent, name, true);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        if (!parent.node_ops.rmdir) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (FS.isMountpoint(node)) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        }
        try {
          if (FS.trackingDelegate['willDeletePath']) {
            FS.trackingDelegate['willDeletePath'](path);
          }
        } catch(e) {
          console.log("FS.trackingDelegate['willDeletePath']('"+path+"') threw an exception: " + e.message);
        }
        parent.node_ops.rmdir(parent, name);
        FS.destroyNode(node);
        try {
          if (FS.trackingDelegate['onDeletePath']) FS.trackingDelegate['onDeletePath'](path);
        } catch(e) {
          console.log("FS.trackingDelegate['onDeletePath']('"+path+"') threw an exception: " + e.message);
        }
      },readdir:function (path) {
        var lookup = FS.lookupPath(path, { follow: true });
        var node = lookup.node;
        if (!node.node_ops.readdir) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOTDIR);
        }
        return node.node_ops.readdir(node);
      },unlink:function (path) {
        var lookup = FS.lookupPath(path, { parent: true });
        var parent = lookup.node;
        var name = PATH.basename(path);
        var node = FS.lookupNode(parent, name);
        var err = FS.mayDelete(parent, name, false);
        if (err) {
          // According to POSIX, we should map EISDIR to EPERM, but
          // we instead do what Linux does (and we must, as we use
          // the musl linux libc).
          throw new FS.ErrnoError(err);
        }
        if (!parent.node_ops.unlink) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (FS.isMountpoint(node)) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        }
        try {
          if (FS.trackingDelegate['willDeletePath']) {
            FS.trackingDelegate['willDeletePath'](path);
          }
        } catch(e) {
          console.log("FS.trackingDelegate['willDeletePath']('"+path+"') threw an exception: " + e.message);
        }
        parent.node_ops.unlink(parent, name);
        FS.destroyNode(node);
        try {
          if (FS.trackingDelegate['onDeletePath']) FS.trackingDelegate['onDeletePath'](path);
        } catch(e) {
          console.log("FS.trackingDelegate['onDeletePath']('"+path+"') threw an exception: " + e.message);
        }
      },readlink:function (path) {
        var lookup = FS.lookupPath(path);
        var link = lookup.node;
        if (!link) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        }
        if (!link.node_ops.readlink) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        return PATH.resolve(FS.getPath(link.parent), link.node_ops.readlink(link));
      },stat:function (path, dontFollow) {
        var lookup = FS.lookupPath(path, { follow: !dontFollow });
        var node = lookup.node;
        if (!node) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        }
        if (!node.node_ops.getattr) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        return node.node_ops.getattr(node);
      },lstat:function (path) {
        return FS.stat(path, true);
      },chmod:function (path, mode, dontFollow) {
        var node;
        if (typeof path === 'string') {
          var lookup = FS.lookupPath(path, { follow: !dontFollow });
          node = lookup.node;
        } else {
          node = path;
        }
        if (!node.node_ops.setattr) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        node.node_ops.setattr(node, {
          mode: (mode & 4095) | (node.mode & ~4095),
          timestamp: Date.now()
        });
      },lchmod:function (path, mode) {
        FS.chmod(path, mode, true);
      },fchmod:function (fd, mode) {
        var stream = FS.getStream(fd);
        if (!stream) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        FS.chmod(stream.node, mode);
      },chown:function (path, uid, gid, dontFollow) {
        var node;
        if (typeof path === 'string') {
          var lookup = FS.lookupPath(path, { follow: !dontFollow });
          node = lookup.node;
        } else {
          node = path;
        }
        if (!node.node_ops.setattr) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        node.node_ops.setattr(node, {
          timestamp: Date.now()
          // we ignore the uid / gid for now
        });
      },lchown:function (path, uid, gid) {
        FS.chown(path, uid, gid, true);
      },fchown:function (fd, uid, gid) {
        var stream = FS.getStream(fd);
        if (!stream) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        FS.chown(stream.node, uid, gid);
      },truncate:function (path, len) {
        if (len < 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var node;
        if (typeof path === 'string') {
          var lookup = FS.lookupPath(path, { follow: true });
          node = lookup.node;
        } else {
          node = path;
        }
        if (!node.node_ops.setattr) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (FS.isDir(node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EISDIR);
        }
        if (!FS.isFile(node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var err = FS.nodePermissions(node, 'w');
        if (err) {
          throw new FS.ErrnoError(err);
        }
        node.node_ops.setattr(node, {
          size: len,
          timestamp: Date.now()
        });
      },ftruncate:function (fd, len) {
        var stream = FS.getStream(fd);
        if (!stream) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if ((stream.flags & 2097155) === 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        FS.truncate(stream.node, len);
      },utime:function (path, atime, mtime) {
        var lookup = FS.lookupPath(path, { follow: true });
        var node = lookup.node;
        node.node_ops.setattr(node, {
          timestamp: Math.max(atime, mtime)
        });
      },open:function (path, flags, mode, fd_start, fd_end) {
        if (path === "") {
          throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        }
        flags = typeof flags === 'string' ? FS.modeStringToFlags(flags) : flags;
        mode = typeof mode === 'undefined' ? 438 /* 0666 */ : mode;
        if ((flags & 64)) {
          mode = (mode & 4095) | 32768;
        } else {
          mode = 0;
        }
        var node;
        if (typeof path === 'object') {
          node = path;
        } else {
          path = PATH.normalize(path);
          try {
            var lookup = FS.lookupPath(path, {
              follow: !(flags & 131072)
            });
            node = lookup.node;
          } catch (e) {
            // ignore
          }
        }
        // perhaps we need to create the node
        var created = false;
        if ((flags & 64)) {
          if (node) {
            // if O_CREAT and O_EXCL are set, error out if the node already exists
            if ((flags & 128)) {
              throw new FS.ErrnoError(ERRNO_CODES.EEXIST);
            }
          } else {
            // node doesn't exist, try to create it
            node = FS.mknod(path, mode, 0);
            created = true;
          }
        }
        if (!node) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        }
        // can't truncate a device
        if (FS.isChrdev(node.mode)) {
          flags &= ~512;
        }
        // if asked only for a directory, then this must be one
        if ((flags & 65536) && !FS.isDir(node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOTDIR);
        }
        // check permissions, if this is not a file we just created now (it is ok to
        // create and write to a file with read-only permissions; it is read-only
        // for later use)
        if (!created) {
          var err = FS.mayOpen(node, flags);
          if (err) {
            throw new FS.ErrnoError(err);
          }
        }
        // do truncation if necessary
        if ((flags & 512)) {
          FS.truncate(node, 0);
        }
        // we've already handled these, don't pass down to the underlying vfs
        flags &= ~(128 | 512);
  
        // register the stream with the filesystem
        var stream = FS.createStream({
          node: node,
          path: FS.getPath(node),  // we want the absolute path to the node
          flags: flags,
          seekable: true,
          position: 0,
          stream_ops: node.stream_ops,
          // used by the file family libc calls (fopen, fwrite, ferror, etc.)
          ungotten: [],
          error: false
        }, fd_start, fd_end);
        // call the new stream's open function
        if (stream.stream_ops.open) {
          stream.stream_ops.open(stream);
        }
        if (Module['logReadFiles'] && !(flags & 1)) {
          if (!FS.readFiles) FS.readFiles = {};
          if (!(path in FS.readFiles)) {
            FS.readFiles[path] = 1;
            Module['printErr']('read file: ' + path);
          }
        }
        try {
          if (FS.trackingDelegate['onOpenFile']) {
            var trackingFlags = 0;
            if ((flags & 2097155) !== 1) {
              trackingFlags |= FS.tracking.openFlags.READ;
            }
            if ((flags & 2097155) !== 0) {
              trackingFlags |= FS.tracking.openFlags.WRITE;
            }
            FS.trackingDelegate['onOpenFile'](path, trackingFlags);
          }
        } catch(e) {
          console.log("FS.trackingDelegate['onOpenFile']('"+path+"', flags) threw an exception: " + e.message);
        }
        return stream;
      },close:function (stream) {
        if (stream.getdents) stream.getdents = null; // free readdir state
        try {
          if (stream.stream_ops.close) {
            stream.stream_ops.close(stream);
          }
        } catch (e) {
          throw e;
        } finally {
          FS.closeStream(stream.fd);
        }
      },llseek:function (stream, offset, whence) {
        if (!stream.seekable || !stream.stream_ops.llseek) {
          throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);
        }
        stream.position = stream.stream_ops.llseek(stream, offset, whence);
        stream.ungotten = [];
        return stream.position;
      },read:function (stream, buffer, offset, length, position) {
        if (length < 0 || position < 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        if ((stream.flags & 2097155) === 1) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if (FS.isDir(stream.node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EISDIR);
        }
        if (!stream.stream_ops.read) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var seeking = true;
        if (typeof position === 'undefined') {
          position = stream.position;
          seeking = false;
        } else if (!stream.seekable) {
          throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);
        }
        var bytesRead = stream.stream_ops.read(stream, buffer, offset, length, position);
        if (!seeking) stream.position += bytesRead;
        return bytesRead;
      },write:function (stream, buffer, offset, length, position, canOwn) {
        if (length < 0 || position < 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        if ((stream.flags & 2097155) === 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if (FS.isDir(stream.node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EISDIR);
        }
        if (!stream.stream_ops.write) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        if (stream.flags & 1024) {
          // seek to the end before writing in append mode
          FS.llseek(stream, 0, 2);
        }
        var seeking = true;
        if (typeof position === 'undefined') {
          position = stream.position;
          seeking = false;
        } else if (!stream.seekable) {
          throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);
        }
        var bytesWritten = stream.stream_ops.write(stream, buffer, offset, length, position, canOwn);
        if (!seeking) stream.position += bytesWritten;
        try {
          if (stream.path && FS.trackingDelegate['onWriteToFile']) FS.trackingDelegate['onWriteToFile'](stream.path);
        } catch(e) {
          console.log("FS.trackingDelegate['onWriteToFile']('"+path+"') threw an exception: " + e.message);
        }
        return bytesWritten;
      },allocate:function (stream, offset, length) {
        if (offset < 0 || length <= 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        if ((stream.flags & 2097155) === 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if (!FS.isFile(stream.node.mode) && !FS.isDir(stream.node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.ENODEV);
        }
        if (!stream.stream_ops.allocate) {
          throw new FS.ErrnoError(ERRNO_CODES.EOPNOTSUPP);
        }
        stream.stream_ops.allocate(stream, offset, length);
      },mmap:function (stream, buffer, offset, length, position, prot, flags) {
        // TODO if PROT is PROT_WRITE, make sure we have write access
        if ((stream.flags & 2097155) === 1) {
          throw new FS.ErrnoError(ERRNO_CODES.EACCES);
        }
        if (!stream.stream_ops.mmap) {
          throw new FS.ErrnoError(ERRNO_CODES.ENODEV);
        }
        return stream.stream_ops.mmap(stream, buffer, offset, length, position, prot, flags);
      },msync:function (stream, buffer, offset, length, mmapFlags) {
        if (!stream || !stream.stream_ops.msync) {
          return 0;
        }
        return stream.stream_ops.msync(stream, buffer, offset, length, mmapFlags);
      },munmap:function (stream) {
        return 0;
      },ioctl:function (stream, cmd, arg) {
        if (!stream.stream_ops.ioctl) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOTTY);
        }
        return stream.stream_ops.ioctl(stream, cmd, arg);
      },readFile:function (path, opts) {
        opts = opts || {};
        opts.flags = opts.flags || 'r';
        opts.encoding = opts.encoding || 'binary';
        if (opts.encoding !== 'utf8' && opts.encoding !== 'binary') {
          throw new Error('Invalid encoding type "' + opts.encoding + '"');
        }
        var ret;
        var stream = FS.open(path, opts.flags);
        var stat = FS.stat(path);
        var length = stat.size;
        var buf = new Uint8Array(length);
        FS.read(stream, buf, 0, length, 0);
        if (opts.encoding === 'utf8') {
          ret = UTF8ArrayToString(buf, 0);
        } else if (opts.encoding === 'binary') {
          ret = buf;
        }
        FS.close(stream);
        return ret;
      },writeFile:function (path, data, opts) {
        opts = opts || {};
        opts.flags = opts.flags || 'w';
        opts.encoding = opts.encoding || 'utf8';
        if (opts.encoding !== 'utf8' && opts.encoding !== 'binary') {
          throw new Error('Invalid encoding type "' + opts.encoding + '"');
        }
        var stream = FS.open(path, opts.flags, opts.mode);
        if (opts.encoding === 'utf8') {
          var buf = new Uint8Array(lengthBytesUTF8(data)+1);
          var actualNumBytes = stringToUTF8Array(data, buf, 0, buf.length);
          FS.write(stream, buf, 0, actualNumBytes, 0, opts.canOwn);
        } else if (opts.encoding === 'binary') {
          FS.write(stream, data, 0, data.length, 0, opts.canOwn);
        }
        FS.close(stream);
      },cwd:function () {
        return FS.currentPath;
      },chdir:function (path) {
        var lookup = FS.lookupPath(path, { follow: true });
        if (lookup.node === null) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        }
        if (!FS.isDir(lookup.node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOTDIR);
        }
        var err = FS.nodePermissions(lookup.node, 'x');
        if (err) {
          throw new FS.ErrnoError(err);
        }
        FS.currentPath = lookup.path;
      },createDefaultDirectories:function () {
        FS.mkdir('/tmp');
        FS.mkdir('/home');
        FS.mkdir('/home/web_user');
      },createDefaultDevices:function () {
        // create /dev
        FS.mkdir('/dev');
        // setup /dev/null
        FS.registerDevice(FS.makedev(1, 3), {
          read: function() { return 0; },
          write: function(stream, buffer, offset, length, pos) { return length; }
        });
        FS.mkdev('/dev/null', FS.makedev(1, 3));
        // setup /dev/tty and /dev/tty1
        // stderr needs to print output using Module['printErr']
        // so we register a second tty just for it.
        TTY.register(FS.makedev(5, 0), TTY.default_tty_ops);
        TTY.register(FS.makedev(6, 0), TTY.default_tty1_ops);
        FS.mkdev('/dev/tty', FS.makedev(5, 0));
        FS.mkdev('/dev/tty1', FS.makedev(6, 0));
        // setup /dev/[u]random
        var random_device;
        if (typeof crypto !== 'undefined') {
          // for modern web browsers
          var randomBuffer = new Uint8Array(1);
          random_device = function() { crypto.getRandomValues(randomBuffer); return randomBuffer[0]; };
        } else if (ENVIRONMENT_IS_NODE) {
          // for nodejs
          random_device = function() { return require('crypto').randomBytes(1)[0]; };
        } else {
          // default for ES5 platforms
          random_device = function() { return (Math.random()*256)|0; };
        }
        FS.createDevice('/dev', 'random', random_device);
        FS.createDevice('/dev', 'urandom', random_device);
        // we're not going to emulate the actual shm device,
        // just create the tmp dirs that reside in it commonly
        FS.mkdir('/dev/shm');
        FS.mkdir('/dev/shm/tmp');
      },createSpecialDirectories:function () {
        // create /proc/self/fd which allows /proc/self/fd/6 => readlink gives the name of the stream for fd 6 (see test_unistd_ttyname)
        FS.mkdir('/proc');
        FS.mkdir('/proc/self');
        FS.mkdir('/proc/self/fd');
        FS.mount({
          mount: function() {
            var node = FS.createNode('/proc/self', 'fd', 16384 | 511 /* 0777 */, 73);
            node.node_ops = {
              lookup: function(parent, name) {
                var fd = +name;
                var stream = FS.getStream(fd);
                if (!stream) throw new FS.ErrnoError(ERRNO_CODES.EBADF);
                var ret = {
                  parent: null,
                  mount: { mountpoint: 'fake' },
                  node_ops: { readlink: function() { return stream.path } }
                };
                ret.parent = ret; // make it look like a simple root node
                return ret;
              }
            };
            return node;
          }
        }, {}, '/proc/self/fd');
      },createStandardStreams:function () {
        // TODO deprecate the old functionality of a single
        // input / output callback and that utilizes FS.createDevice
        // and instead require a unique set of stream ops
  
        // by default, we symlink the standard streams to the
        // default tty devices. however, if the standard streams
        // have been overwritten we create a unique device for
        // them instead.
        if (Module['stdin']) {
          FS.createDevice('/dev', 'stdin', Module['stdin']);
        } else {
          FS.symlink('/dev/tty', '/dev/stdin');
        }
        if (Module['stdout']) {
          FS.createDevice('/dev', 'stdout', null, Module['stdout']);
        } else {
          FS.symlink('/dev/tty', '/dev/stdout');
        }
        if (Module['stderr']) {
          FS.createDevice('/dev', 'stderr', null, Module['stderr']);
        } else {
          FS.symlink('/dev/tty1', '/dev/stderr');
        }
  
        // open default streams for the stdin, stdout and stderr devices
        var stdin = FS.open('/dev/stdin', 'r');
        assert(stdin.fd === 0, 'invalid handle for stdin (' + stdin.fd + ')');
  
        var stdout = FS.open('/dev/stdout', 'w');
        assert(stdout.fd === 1, 'invalid handle for stdout (' + stdout.fd + ')');
  
        var stderr = FS.open('/dev/stderr', 'w');
        assert(stderr.fd === 2, 'invalid handle for stderr (' + stderr.fd + ')');
      },ensureErrnoError:function () {
        if (FS.ErrnoError) return;
        FS.ErrnoError = function ErrnoError(errno, node) {
          //Module.printErr(stackTrace()); // useful for debugging
          this.node = node;
          this.setErrno = function(errno) {
            this.errno = errno;
            for (var key in ERRNO_CODES) {
              if (ERRNO_CODES[key] === errno) {
                this.code = key;
                break;
              }
            }
          };
          this.setErrno(errno);
          this.message = ERRNO_MESSAGES[errno];
          if (this.stack) this.stack = demangleAll(this.stack);
        };
        FS.ErrnoError.prototype = new Error();
        FS.ErrnoError.prototype.constructor = FS.ErrnoError;
        // Some errors may happen quite a bit, to avoid overhead we reuse them (and suffer a lack of stack info)
        [ERRNO_CODES.ENOENT].forEach(function(code) {
          FS.genericErrors[code] = new FS.ErrnoError(code);
          FS.genericErrors[code].stack = '<generic error, no stack>';
        });
      },staticInit:function () {
        FS.ensureErrnoError();
  
        FS.nameTable = new Array(4096);
  
        FS.mount(MEMFS, {}, '/');
  
        FS.createDefaultDirectories();
        FS.createDefaultDevices();
        FS.createSpecialDirectories();
  
        FS.filesystems = {
          'MEMFS': MEMFS,
          'IDBFS': IDBFS,
          'NODEFS': NODEFS,
          'WORKERFS': WORKERFS,
        };
      },init:function (input, output, error) {
        assert(!FS.init.initialized, 'FS.init was previously called. If you want to initialize later with custom parameters, remove any earlier calls (note that one is automatically added to the generated code)');
        FS.init.initialized = true;
  
        FS.ensureErrnoError();
  
        // Allow Module.stdin etc. to provide defaults, if none explicitly passed to us here
        Module['stdin'] = input || Module['stdin'];
        Module['stdout'] = output || Module['stdout'];
        Module['stderr'] = error || Module['stderr'];
  
        FS.createStandardStreams();
      },quit:function () {
        FS.init.initialized = false;
        // force-flush all streams, so we get musl std streams printed out
        var fflush = Module['_fflush'];
        if (fflush) fflush(0);
        // close all of our streams
        for (var i = 0; i < FS.streams.length; i++) {
          var stream = FS.streams[i];
          if (!stream) {
            continue;
          }
          FS.close(stream);
        }
      },getMode:function (canRead, canWrite) {
        var mode = 0;
        if (canRead) mode |= 292 | 73;
        if (canWrite) mode |= 146;
        return mode;
      },joinPath:function (parts, forceRelative) {
        var path = PATH.join.apply(null, parts);
        if (forceRelative && path[0] == '/') path = path.substr(1);
        return path;
      },absolutePath:function (relative, base) {
        return PATH.resolve(base, relative);
      },standardizePath:function (path) {
        return PATH.normalize(path);
      },findObject:function (path, dontResolveLastLink) {
        var ret = FS.analyzePath(path, dontResolveLastLink);
        if (ret.exists) {
          return ret.object;
        } else {
          ___setErrNo(ret.error);
          return null;
        }
      },analyzePath:function (path, dontResolveLastLink) {
        // operate from within the context of the symlink's target
        try {
          var lookup = FS.lookupPath(path, { follow: !dontResolveLastLink });
          path = lookup.path;
        } catch (e) {
        }
        var ret = {
          isRoot: false, exists: false, error: 0, name: null, path: null, object: null,
          parentExists: false, parentPath: null, parentObject: null
        };
        try {
          var lookup = FS.lookupPath(path, { parent: true });
          ret.parentExists = true;
          ret.parentPath = lookup.path;
          ret.parentObject = lookup.node;
          ret.name = PATH.basename(path);
          lookup = FS.lookupPath(path, { follow: !dontResolveLastLink });
          ret.exists = true;
          ret.path = lookup.path;
          ret.object = lookup.node;
          ret.name = lookup.node.name;
          ret.isRoot = lookup.path === '/';
        } catch (e) {
          ret.error = e.errno;
        };
        return ret;
      },createFolder:function (parent, name, canRead, canWrite) {
        var path = PATH.join2(typeof parent === 'string' ? parent : FS.getPath(parent), name);
        var mode = FS.getMode(canRead, canWrite);
        return FS.mkdir(path, mode);
      },createPath:function (parent, path, canRead, canWrite) {
        parent = typeof parent === 'string' ? parent : FS.getPath(parent);
        var parts = path.split('/').reverse();
        while (parts.length) {
          var part = parts.pop();
          if (!part) continue;
          var current = PATH.join2(parent, part);
          try {
            FS.mkdir(current);
          } catch (e) {
            // ignore EEXIST
          }
          parent = current;
        }
        return current;
      },createFile:function (parent, name, properties, canRead, canWrite) {
        var path = PATH.join2(typeof parent === 'string' ? parent : FS.getPath(parent), name);
        var mode = FS.getMode(canRead, canWrite);
        return FS.create(path, mode);
      },createDataFile:function (parent, name, data, canRead, canWrite, canOwn) {
        var path = name ? PATH.join2(typeof parent === 'string' ? parent : FS.getPath(parent), name) : parent;
        var mode = FS.getMode(canRead, canWrite);
        var node = FS.create(path, mode);
        if (data) {
          if (typeof data === 'string') {
            var arr = new Array(data.length);
            for (var i = 0, len = data.length; i < len; ++i) arr[i] = data.charCodeAt(i);
            data = arr;
          }
          // make sure we can write to the file
          FS.chmod(node, mode | 146);
          var stream = FS.open(node, 'w');
          FS.write(stream, data, 0, data.length, 0, canOwn);
          FS.close(stream);
          FS.chmod(node, mode);
        }
        return node;
      },createDevice:function (parent, name, input, output) {
        var path = PATH.join2(typeof parent === 'string' ? parent : FS.getPath(parent), name);
        var mode = FS.getMode(!!input, !!output);
        if (!FS.createDevice.major) FS.createDevice.major = 64;
        var dev = FS.makedev(FS.createDevice.major++, 0);
        // Create a fake device that a set of stream ops to emulate
        // the old behavior.
        FS.registerDevice(dev, {
          open: function(stream) {
            stream.seekable = false;
          },
          close: function(stream) {
            // flush any pending line data
            if (output && output.buffer && output.buffer.length) {
              output(10);
            }
          },
          read: function(stream, buffer, offset, length, pos /* ignored */) {
            var bytesRead = 0;
            for (var i = 0; i < length; i++) {
              var result;
              try {
                result = input();
              } catch (e) {
                throw new FS.ErrnoError(ERRNO_CODES.EIO);
              }
              if (result === undefined && bytesRead === 0) {
                throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
              }
              if (result === null || result === undefined) break;
              bytesRead++;
              buffer[offset+i] = result;
            }
            if (bytesRead) {
              stream.node.timestamp = Date.now();
            }
            return bytesRead;
          },
          write: function(stream, buffer, offset, length, pos) {
            for (var i = 0; i < length; i++) {
              try {
                output(buffer[offset+i]);
              } catch (e) {
                throw new FS.ErrnoError(ERRNO_CODES.EIO);
              }
            }
            if (length) {
              stream.node.timestamp = Date.now();
            }
            return i;
          }
        });
        return FS.mkdev(path, mode, dev);
      },createLink:function (parent, name, target, canRead, canWrite) {
        var path = PATH.join2(typeof parent === 'string' ? parent : FS.getPath(parent), name);
        return FS.symlink(target, path);
      },forceLoadFile:function (obj) {
        if (obj.isDevice || obj.isFolder || obj.link || obj.contents) return true;
        var success = true;
        if (typeof XMLHttpRequest !== 'undefined') {
          throw new Error("Lazy loading should have been performed (contents set) in createLazyFile, but it was not. Lazy loading only works in web workers. Use --embed-file or --preload-file in emcc on the main thread.");
        } else if (Module['read']) {
          // Command-line.
          try {
            // WARNING: Can't read binary files in V8's d8 or tracemonkey's js, as
            //          read() will try to parse UTF8.
            obj.contents = intArrayFromString(Module['read'](obj.url), true);
            obj.usedBytes = obj.contents.length;
          } catch (e) {
            success = false;
          }
        } else {
          throw new Error('Cannot load without read() or XMLHttpRequest.');
        }
        if (!success) ___setErrNo(ERRNO_CODES.EIO);
        return success;
      },createLazyFile:function (parent, name, url, canRead, canWrite) {
        // Lazy chunked Uint8Array (implements get and length from Uint8Array). Actual getting is abstracted away for eventual reuse.
        function LazyUint8Array() {
          this.lengthKnown = false;
          this.chunks = []; // Loaded chunks. Index is the chunk number
        }
        LazyUint8Array.prototype.get = function LazyUint8Array_get(idx) {
          if (idx > this.length-1 || idx < 0) {
            return undefined;
          }
          var chunkOffset = idx % this.chunkSize;
          var chunkNum = (idx / this.chunkSize)|0;
          return this.getter(chunkNum)[chunkOffset];
        }
        LazyUint8Array.prototype.setDataGetter = function LazyUint8Array_setDataGetter(getter) {
          this.getter = getter;
        }
        LazyUint8Array.prototype.cacheLength = function LazyUint8Array_cacheLength() {
          // Find length
          var xhr = new XMLHttpRequest();
          xhr.open('HEAD', url, false);
          xhr.send(null);
          if (!(xhr.status >= 200 && xhr.status < 300 || xhr.status === 304)) throw new Error("Couldn't load " + url + ". Status: " + xhr.status);
          var datalength = Number(xhr.getResponseHeader("Content-length"));
          var header;
          var hasByteServing = (header = xhr.getResponseHeader("Accept-Ranges")) && header === "bytes";
          var usesGzip = (header = xhr.getResponseHeader("Content-Encoding")) && header === "gzip";
  
          var chunkSize = 1024*1024; // Chunk size in bytes
  
          if (!hasByteServing) chunkSize = datalength;
  
          // Function to get a range from the remote URL.
          var doXHR = (function(from, to) {
            if (from > to) throw new Error("invalid range (" + from + ", " + to + ") or no bytes requested!");
            if (to > datalength-1) throw new Error("only " + datalength + " bytes available! programmer error!");
  
            // TODO: Use mozResponseArrayBuffer, responseStream, etc. if available.
            var xhr = new XMLHttpRequest();
            xhr.open('GET', url, false);
            if (datalength !== chunkSize) xhr.setRequestHeader("Range", "bytes=" + from + "-" + to);
  
            // Some hints to the browser that we want binary data.
            if (typeof Uint8Array != 'undefined') xhr.responseType = 'arraybuffer';
            if (xhr.overrideMimeType) {
              xhr.overrideMimeType('text/plain; charset=x-user-defined');
            }
  
            xhr.send(null);
            if (!(xhr.status >= 200 && xhr.status < 300 || xhr.status === 304)) throw new Error("Couldn't load " + url + ". Status: " + xhr.status);
            if (xhr.response !== undefined) {
              return new Uint8Array(xhr.response || []);
            } else {
              return intArrayFromString(xhr.responseText || '', true);
            }
          });
          var lazyArray = this;
          lazyArray.setDataGetter(function(chunkNum) {
            var start = chunkNum * chunkSize;
            var end = (chunkNum+1) * chunkSize - 1; // including this byte
            end = Math.min(end, datalength-1); // if datalength-1 is selected, this is the last block
            if (typeof(lazyArray.chunks[chunkNum]) === "undefined") {
              lazyArray.chunks[chunkNum] = doXHR(start, end);
            }
            if (typeof(lazyArray.chunks[chunkNum]) === "undefined") throw new Error("doXHR failed!");
            return lazyArray.chunks[chunkNum];
          });
  
          if (usesGzip || !datalength) {
            // if the server uses gzip or doesn't supply the length, we have to download the whole file to get the (uncompressed) length
            chunkSize = datalength = 1; // this will force getter(0)/doXHR do download the whole file
            datalength = this.getter(0).length;
            chunkSize = datalength;
            console.log("LazyFiles on gzip forces download of the whole file when length is accessed");
          }
  
          this._length = datalength;
          this._chunkSize = chunkSize;
          this.lengthKnown = true;
        }
        if (typeof XMLHttpRequest !== 'undefined') {
          if (!ENVIRONMENT_IS_WORKER) throw 'Cannot do synchronous binary XHRs outside webworkers in modern browsers. Use --embed-file or --preload-file in emcc';
          var lazyArray = new LazyUint8Array();
          Object.defineProperties(lazyArray, {
            length: {
              get: function() {
                if(!this.lengthKnown) {
                  this.cacheLength();
                }
                return this._length;
              }
            },
            chunkSize: {
              get: function() {
                if(!this.lengthKnown) {
                  this.cacheLength();
                }
                return this._chunkSize;
              }
            }
          });
  
          var properties = { isDevice: false, contents: lazyArray };
        } else {
          var properties = { isDevice: false, url: url };
        }
  
        var node = FS.createFile(parent, name, properties, canRead, canWrite);
        // This is a total hack, but I want to get this lazy file code out of the
        // core of MEMFS. If we want to keep this lazy file concept I feel it should
        // be its own thin LAZYFS proxying calls to MEMFS.
        if (properties.contents) {
          node.contents = properties.contents;
        } else if (properties.url) {
          node.contents = null;
          node.url = properties.url;
        }
        // Add a function that defers querying the file size until it is asked the first time.
        Object.defineProperties(node, {
          usedBytes: {
            get: function() { return this.contents.length; }
          }
        });
        // override each stream op with one that tries to force load the lazy file first
        var stream_ops = {};
        var keys = Object.keys(node.stream_ops);
        keys.forEach(function(key) {
          var fn = node.stream_ops[key];
          stream_ops[key] = function forceLoadLazyFile() {
            if (!FS.forceLoadFile(node)) {
              throw new FS.ErrnoError(ERRNO_CODES.EIO);
            }
            return fn.apply(null, arguments);
          };
        });
        // use a custom read function
        stream_ops.read = function stream_ops_read(stream, buffer, offset, length, position) {
          if (!FS.forceLoadFile(node)) {
            throw new FS.ErrnoError(ERRNO_CODES.EIO);
          }
          var contents = stream.node.contents;
          if (position >= contents.length)
            return 0;
          var size = Math.min(contents.length - position, length);
          assert(size >= 0);
          if (contents.slice) { // normal array
            for (var i = 0; i < size; i++) {
              buffer[offset + i] = contents[position + i];
            }
          } else {
            for (var i = 0; i < size; i++) { // LazyUint8Array from sync binary XHR
              buffer[offset + i] = contents.get(position + i);
            }
          }
          return size;
        };
        node.stream_ops = stream_ops;
        return node;
      },createPreloadedFile:function (parent, name, url, canRead, canWrite, onload, onerror, dontCreateFile, canOwn, preFinish) {
        Browser.init(); // XXX perhaps this method should move onto Browser?
        // TODO we should allow people to just pass in a complete filename instead
        // of parent and name being that we just join them anyways
        var fullname = name ? PATH.resolve(PATH.join2(parent, name)) : parent;
        var dep = getUniqueRunDependency('cp ' + fullname); // might have several active requests for the same fullname
        function processData(byteArray) {
          function finish(byteArray) {
            if (preFinish) preFinish();
            if (!dontCreateFile) {
              FS.createDataFile(parent, name, byteArray, canRead, canWrite, canOwn);
            }
            if (onload) onload();
            removeRunDependency(dep);
          }
          var handled = false;
          Module['preloadPlugins'].forEach(function(plugin) {
            if (handled) return;
            if (plugin['canHandle'](fullname)) {
              plugin['handle'](byteArray, fullname, finish, function() {
                if (onerror) onerror();
                removeRunDependency(dep);
              });
              handled = true;
            }
          });
          if (!handled) finish(byteArray);
        }
        addRunDependency(dep);
        if (typeof url == 'string') {
          Browser.asyncLoad(url, function(byteArray) {
            processData(byteArray);
          }, onerror);
        } else {
          processData(url);
        }
      },indexedDB:function () {
        return window.indexedDB || window.mozIndexedDB || window.webkitIndexedDB || window.msIndexedDB;
      },DB_NAME:function () {
        return 'EM_FS_' + window.location.pathname;
      },DB_VERSION:20,DB_STORE_NAME:"FILE_DATA",saveFilesToDB:function (paths, onload, onerror) {
        onload = onload || function(){};
        onerror = onerror || function(){};
        var indexedDB = FS.indexedDB();
        try {
          var openRequest = indexedDB.open(FS.DB_NAME(), FS.DB_VERSION);
        } catch (e) {
          return onerror(e);
        }
        openRequest.onupgradeneeded = function openRequest_onupgradeneeded() {
          console.log('creating db');
          var db = openRequest.result;
          db.createObjectStore(FS.DB_STORE_NAME);
        };
        openRequest.onsuccess = function openRequest_onsuccess() {
          var db = openRequest.result;
          var transaction = db.transaction([FS.DB_STORE_NAME], 'readwrite');
          var files = transaction.objectStore(FS.DB_STORE_NAME);
          var ok = 0, fail = 0, total = paths.length;
          function finish() {
            if (fail == 0) onload(); else onerror();
          }
          paths.forEach(function(path) {
            var putRequest = files.put(FS.analyzePath(path).object.contents, path);
            putRequest.onsuccess = function putRequest_onsuccess() { ok++; if (ok + fail == total) finish() };
            putRequest.onerror = function putRequest_onerror() { fail++; if (ok + fail == total) finish() };
          });
          transaction.onerror = onerror;
        };
        openRequest.onerror = onerror;
      },loadFilesFromDB:function (paths, onload, onerror) {
        onload = onload || function(){};
        onerror = onerror || function(){};
        var indexedDB = FS.indexedDB();
        try {
          var openRequest = indexedDB.open(FS.DB_NAME(), FS.DB_VERSION);
        } catch (e) {
          return onerror(e);
        }
        openRequest.onupgradeneeded = onerror; // no database to load from
        openRequest.onsuccess = function openRequest_onsuccess() {
          var db = openRequest.result;
          try {
            var transaction = db.transaction([FS.DB_STORE_NAME], 'readonly');
          } catch(e) {
            onerror(e);
            return;
          }
          var files = transaction.objectStore(FS.DB_STORE_NAME);
          var ok = 0, fail = 0, total = paths.length;
          function finish() {
            if (fail == 0) onload(); else onerror();
          }
          paths.forEach(function(path) {
            var getRequest = files.get(path);
            getRequest.onsuccess = function getRequest_onsuccess() {
              if (FS.analyzePath(path).exists) {
                FS.unlink(path);
              }
              FS.createDataFile(PATH.dirname(path), PATH.basename(path), getRequest.result, true, true, true);
              ok++;
              if (ok + fail == total) finish();
            };
            getRequest.onerror = function getRequest_onerror() { fail++; if (ok + fail == total) finish() };
          });
          transaction.onerror = onerror;
        };
        openRequest.onerror = onerror;
      }};var SYSCALLS={DEFAULT_POLLMASK:5,mappings:{},umask:511,calculateAt:function (dirfd, path) {
        if (path[0] !== '/') {
          // relative path
          var dir;
          if (dirfd === -100) {
            dir = FS.cwd();
          } else {
            var dirstream = FS.getStream(dirfd);
            if (!dirstream) throw new FS.ErrnoError(ERRNO_CODES.EBADF);
            dir = dirstream.path;
          }
          path = PATH.join2(dir, path);
        }
        return path;
      },doStat:function (func, path, buf) {
        try {
          var stat = func(path);
        } catch (e) {
          if (e && e.node && PATH.normalize(path) !== PATH.normalize(FS.getPath(e.node))) {
            // an error occurred while trying to look up the path; we should just report ENOTDIR
            return -ERRNO_CODES.ENOTDIR;
          }
          throw e;
        }
        HEAP32[((buf)>>2)]=stat.dev;
        HEAP32[(((buf)+(4))>>2)]=0;
        HEAP32[(((buf)+(8))>>2)]=stat.ino;
        HEAP32[(((buf)+(12))>>2)]=stat.mode;
        HEAP32[(((buf)+(16))>>2)]=stat.nlink;
        HEAP32[(((buf)+(20))>>2)]=stat.uid;
        HEAP32[(((buf)+(24))>>2)]=stat.gid;
        HEAP32[(((buf)+(28))>>2)]=stat.rdev;
        HEAP32[(((buf)+(32))>>2)]=0;
        HEAP32[(((buf)+(36))>>2)]=stat.size;
        HEAP32[(((buf)+(40))>>2)]=4096;
        HEAP32[(((buf)+(44))>>2)]=stat.blocks;
        HEAP32[(((buf)+(48))>>2)]=(stat.atime.getTime() / 1000)|0;
        HEAP32[(((buf)+(52))>>2)]=0;
        HEAP32[(((buf)+(56))>>2)]=(stat.mtime.getTime() / 1000)|0;
        HEAP32[(((buf)+(60))>>2)]=0;
        HEAP32[(((buf)+(64))>>2)]=(stat.ctime.getTime() / 1000)|0;
        HEAP32[(((buf)+(68))>>2)]=0;
        HEAP32[(((buf)+(72))>>2)]=stat.ino;
        return 0;
      },doMsync:function (addr, stream, len, flags) {
        var buffer = new Uint8Array(HEAPU8.subarray(addr, addr + len));
        FS.msync(stream, buffer, 0, len, flags);
      },doMkdir:function (path, mode) {
        // remove a trailing slash, if one - /a/b/ has basename of '', but
        // we want to create b in the context of this function
        path = PATH.normalize(path);
        if (path[path.length-1] === '/') path = path.substr(0, path.length-1);
        FS.mkdir(path, mode, 0);
        return 0;
      },doMknod:function (path, mode, dev) {
        // we don't want this in the JS API as it uses mknod to create all nodes.
        switch (mode & 61440) {
          case 32768:
          case 8192:
          case 24576:
          case 4096:
          case 49152:
            break;
          default: return -ERRNO_CODES.EINVAL;
        }
        FS.mknod(path, mode, dev);
        return 0;
      },doReadlink:function (path, buf, bufsize) {
        if (bufsize <= 0) return -ERRNO_CODES.EINVAL;
        var ret = FS.readlink(path);
  
        var len = Math.min(bufsize, lengthBytesUTF8(ret));
        var endChar = HEAP8[buf+len];
        stringToUTF8(ret, buf, bufsize+1);
        // readlink is one of the rare functions that write out a C string, but does never append a null to the output buffer(!)
        // stringToUTF8() always appends a null byte, so restore the character under the null byte after the write.
        HEAP8[buf+len] = endChar;
  
        return len;
      },doAccess:function (path, amode) {
        if (amode & ~7) {
          // need a valid mode
          return -ERRNO_CODES.EINVAL;
        }
        var node;
        var lookup = FS.lookupPath(path, { follow: true });
        node = lookup.node;
        var perms = '';
        if (amode & 4) perms += 'r';
        if (amode & 2) perms += 'w';
        if (amode & 1) perms += 'x';
        if (perms /* otherwise, they've just passed F_OK */ && FS.nodePermissions(node, perms)) {
          return -ERRNO_CODES.EACCES;
        }
        return 0;
      },doDup:function (path, flags, suggestFD) {
        var suggest = FS.getStream(suggestFD);
        if (suggest) FS.close(suggest);
        return FS.open(path, flags, 0, suggestFD, suggestFD).fd;
      },doReadv:function (stream, iov, iovcnt, offset) {
        var ret = 0;
        for (var i = 0; i < iovcnt; i++) {
          var ptr = HEAP32[(((iov)+(i*8))>>2)];
          var len = HEAP32[(((iov)+(i*8 + 4))>>2)];
          var curr = FS.read(stream, HEAP8,ptr, len, offset);
          if (curr < 0) return -1;
          ret += curr;
          if (curr < len) break; // nothing more to read
        }
        return ret;
      },doWritev:function (stream, iov, iovcnt, offset) {
        var ret = 0;
        for (var i = 0; i < iovcnt; i++) {
          var ptr = HEAP32[(((iov)+(i*8))>>2)];
          var len = HEAP32[(((iov)+(i*8 + 4))>>2)];
          var curr = FS.write(stream, HEAP8,ptr, len, offset);
          if (curr < 0) return -1;
          ret += curr;
        }
        return ret;
      },varargs:0,get:function (varargs) {
        SYSCALLS.varargs += 4;
        var ret = HEAP32[(((SYSCALLS.varargs)-(4))>>2)];
        return ret;
      },getStr:function () {
        var ret = Pointer_stringify(SYSCALLS.get());
        return ret;
      },getStreamFromFD:function () {
        var stream = FS.getStream(SYSCALLS.get());
        if (!stream) throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        return stream;
      },getSocketFromFD:function () {
        var socket = SOCKFS.getSocket(SYSCALLS.get());
        if (!socket) throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        return socket;
      },getSocketAddress:function (allowNull) {
        var addrp = SYSCALLS.get(), addrlen = SYSCALLS.get();
        if (allowNull && addrp === 0) return null;
        var info = __read_sockaddr(addrp, addrlen);
        if (info.errno) throw new FS.ErrnoError(info.errno);
        info.addr = DNS.lookup_addr(info.addr) || info.addr;
        return info;
      },get64:function () {
        var low = SYSCALLS.get(), high = SYSCALLS.get();
        if (low >= 0) assert(high === 0);
        else assert(high === -1);
        return low;
      },getZero:function () {
        assert(SYSCALLS.get() === 0);
      }};function ___syscall54(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // ioctl
      var stream = SYSCALLS.getStreamFromFD(), op = SYSCALLS.get();
      switch (op) {
        case 21505: {
          if (!stream.tty) return -ERRNO_CODES.ENOTTY;
          return 0;
        }
        case 21506: {
          if (!stream.tty) return -ERRNO_CODES.ENOTTY;
          return 0; // no-op, not actually adjusting terminal settings
        }
        case 21519: {
          if (!stream.tty) return -ERRNO_CODES.ENOTTY;
          var argp = SYSCALLS.get();
          HEAP32[((argp)>>2)]=0;
          return 0;
        }
        case 21520: {
          if (!stream.tty) return -ERRNO_CODES.ENOTTY;
          return -ERRNO_CODES.EINVAL; // not supported
        }
        case 21531: {
          var argp = SYSCALLS.get();
          return FS.ioctl(stream, op, argp);
        }
        case 21523: {
          // TODO: in theory we should write to the winsize struct that gets
          // passed in, but for now musl doesn't read anything on it
          if (!stream.tty) return -ERRNO_CODES.ENOTTY;
          return 0;
        }
        default: abort('bad ioctl syscall ' + op);
      }
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function _emscripten_glSampleCoverage(value, invert) {
      GLctx.sampleCoverage(value, !!invert);
    }

  function _eglSwapBuffers() {
  
      if (!EGL.defaultDisplayInitialized) {
        EGL.setErrorCode(0x3001 /* EGL_NOT_INITIALIZED */);
      } else if (!Module.ctx) {
        EGL.setErrorCode(0x3002 /* EGL_BAD_ACCESS */);
      } else if (Module.ctx.isContextLost()) {
        EGL.setErrorCode(0x300E /* EGL_CONTEXT_LOST */);
      } else {
        // According to documentation this does an implicit flush.
        // Due to discussion at https://github.com/kripken/emscripten/pull/1871
        // the flush was removed since this _may_ result in slowing code down.
        //_glFlush();
        EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
        return 1 /* EGL_TRUE */;
      }
      return 0 /* EGL_FALSE */;
    }

  function _emscripten_glFrustum() {
  Module['printErr']('missing function: emscripten_glFrustum'); abort(-1);
  }

  function _emscripten_glGetTexParameterfv(target, pname, params) {
      if (!params) {
        // GLES2 specification does not specify how to behave if params is a null pointer. Since calling this function does not make sense
        // if p == null, issue a GL error to notify user about it. 
        GL.recordError(0x0501 /* GL_INVALID_VALUE */);
        return;
      }
      HEAPF32[((params)>>2)]=GLctx.getTexParameter(target, pname);
    }

  function _emscripten_glUniform4i(location, v0, v1, v2, v3) {
      GLctx.uniform4i(GL.uniforms[location], v0, v1, v2, v3);
    }

  function _emscripten_glBindRenderbuffer(target, renderbuffer) {
      GLctx.bindRenderbuffer(target, renderbuffer ? GL.renderbuffers[renderbuffer] : null);
    }

  function _emscripten_glViewport(x0, x1, x2, x3) { GLctx['viewport'](x0, x1, x2, x3) }

  function _dlclose(handle) {
      // int dlclose(void *handle);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/dlclose.html
      if (!DLFCN.loadedLibs[handle]) {
        DLFCN.errorMsg = 'Tried to dlclose() unopened handle: ' + handle;
        return 1;
      } else {
        var lib_record = DLFCN.loadedLibs[handle];
        if (--lib_record.refcount == 0) {
          if (lib_record.module.cleanups) {
            lib_record.module.cleanups.forEach(function(cleanup) { cleanup() });
          }
          delete DLFCN.loadedLibNames[lib_record.name];
          delete DLFCN.loadedLibs[handle];
        }
        return 0;
      }
    }

  
  function __emscripten_sample_gamepad_data() {
      // Polling gamepads generates garbage, so don't do it when we know there are no gamepads connected.
      if (!JSEvents.numGamepadsConnected) return;
  
      // Produce a new Gamepad API sample if we are ticking a new game frame, or if not using emscripten_set_main_loop() at all to drive animation.
      if (Browser.mainLoop.currentFrameNumber !== JSEvents.lastGamepadStateFrame || !Browser.mainLoop.currentFrameNumber) {
        JSEvents.lastGamepadState = navigator.getGamepads ? navigator.getGamepads() : (navigator.webkitGetGamepads ? navigator.webkitGetGamepads : null);
        JSEvents.lastGamepadStateFrame = Browser.mainLoop.currentFrameNumber;
      }
    }function _emscripten_get_gamepad_status(index, gamepadState) {
      __emscripten_sample_gamepad_data();
      if (!JSEvents.lastGamepadState) return -1;
  
      // INVALID_PARAM is returned on a Gamepad index that never was there.
      if (index < 0 || index >= JSEvents.lastGamepadState.length) return -5;
  
      // NO_DATA is returned on a Gamepad index that was removed.
      // For previously disconnected gamepads there should be an empty slot (null/undefined/false) at the index.
      // This is because gamepads must keep their original position in the array.
      // For example, removing the first of two gamepads produces [null/undefined/false, gamepad].
      if (!JSEvents.lastGamepadState[index]) return -7;
  
      JSEvents.fillGamepadEventData(gamepadState, JSEvents.lastGamepadState[index]);
      return 0;
    }

  var _llvm_pow_f64=Math_pow;

  function _emscripten_glCopyTexImage2D(x0, x1, x2, x3, x4, x5, x6, x7) { GLctx['copyTexImage2D'](x0, x1, x2, x3, x4, x5, x6, x7) }

  function _emscripten_glTexParameterfv(target, pname, params) {
      var param = HEAPF32[((params)>>2)];
      GLctx.texParameterf(target, pname, param);
    }

  function _emscripten_glDepthRangef(x0, x1) { GLctx['depthRange'](x0, x1) }

  function _emscripten_glUniform3f(location, v0, v1, v2) {
      GLctx.uniform3f(GL.uniforms[location], v0, v1, v2);
    }

  function ___resumeException(ptr) {
      if (!EXCEPTIONS.last) { EXCEPTIONS.last = ptr; }
      throw ptr;
    }

  function _emscripten_glGetObjectParameterivARB() {
  Module['printErr']('missing function: emscripten_glGetObjectParameterivARB'); abort(-1);
  }

  function _emscripten_glBlendFunc(x0, x1) { GLctx['blendFunc'](x0, x1) }

  function _emscripten_glUniform3i(location, v0, v1, v2) {
      GLctx.uniform3i(GL.uniforms[location], v0, v1, v2);
    }

  function _emscripten_glStencilOp(x0, x1, x2) { GLctx['stencilOp'](x0, x1, x2) }

  function _emscripten_glBindAttribLocation(program, index, name) {
      name = Pointer_stringify(name);
      GLctx.bindAttribLocation(GL.programs[program], index, name);
    }

  function _glCopyTexSubImage2D(x0, x1, x2, x3, x4, x5, x6, x7) { GLctx['copyTexSubImage2D'](x0, x1, x2, x3, x4, x5, x6, x7) }

  
  
  function emscriptenWebGLComputeImageSize(width, height, sizePerPixel, alignment) {
      function roundedToNextMultipleOf(x, y) {
        return Math.floor((x + y - 1) / y) * y
      }
      var plainRowSize = width * sizePerPixel;
      var alignedRowSize = roundedToNextMultipleOf(plainRowSize, alignment);
      return (height <= 0) ? 0 :
               ((height - 1) * alignedRowSize + plainRowSize);
    }function emscriptenWebGLGetTexPixelData(type, format, width, height, pixels, internalFormat) {
      var sizePerPixel;
      var numChannels;
      switch(format) {
        case 0x1906 /* GL_ALPHA */:
        case 0x1909 /* GL_LUMINANCE */:
        case 0x1902 /* GL_DEPTH_COMPONENT */:
          numChannels = 1;
          break;
        case 0x190A /* GL_LUMINANCE_ALPHA */:
          numChannels = 2;
          break;
        case 0x1907 /* GL_RGB */:
        case 0x8C40 /* GL_SRGB_EXT */:
          numChannels = 3;
          break;
        case 0x1908 /* GL_RGBA */:
        case 0x8C42 /* GL_SRGB_ALPHA_EXT */:
          numChannels = 4;
          break;
        default:
          GL.recordError(0x0500); // GL_INVALID_ENUM
          return null;
      }
      switch (type) {
        case 0x1401 /* GL_UNSIGNED_BYTE */:
          sizePerPixel = numChannels*1;
          break;
        case 0x1403 /* GL_UNSIGNED_SHORT */:
        case 0x8D61 /* GL_HALF_FLOAT_OES */:
          sizePerPixel = numChannels*2;
          break;
        case 0x1405 /* GL_UNSIGNED_INT */:
        case 0x1406 /* GL_FLOAT */:
          sizePerPixel = numChannels*4;
          break;
        case 0x84FA /* GL_UNSIGNED_INT_24_8_WEBGL/GL_UNSIGNED_INT_24_8 */:
          sizePerPixel = 4;
          break;
        case 0x8363 /* GL_UNSIGNED_SHORT_5_6_5 */:
        case 0x8033 /* GL_UNSIGNED_SHORT_4_4_4_4 */:
        case 0x8034 /* GL_UNSIGNED_SHORT_5_5_5_1 */:
          sizePerPixel = 2;
          break;
        default:
          GL.recordError(0x0500); // GL_INVALID_ENUM
          return null;
      }
      var bytes = emscriptenWebGLComputeImageSize(width, height, sizePerPixel, GL.unpackAlignment);
      switch(type) {
        case 0x1401 /* GL_UNSIGNED_BYTE */:
          return HEAPU8.subarray((pixels),(pixels+bytes));
        case 0x1406 /* GL_FLOAT */:
          return HEAPF32.subarray((pixels)>>2,(pixels+bytes)>>2);
        case 0x1405 /* GL_UNSIGNED_INT */:
        case 0x84FA /* GL_UNSIGNED_INT_24_8_WEBGL/GL_UNSIGNED_INT_24_8 */:
          return HEAPU32.subarray((pixels)>>2,(pixels+bytes)>>2);
        case 0x1403 /* GL_UNSIGNED_SHORT */:
        case 0x8363 /* GL_UNSIGNED_SHORT_5_6_5 */:
        case 0x8033 /* GL_UNSIGNED_SHORT_4_4_4_4 */:
        case 0x8034 /* GL_UNSIGNED_SHORT_5_5_5_1 */:
        case 0x8D61 /* GL_HALF_FLOAT_OES */:
          return HEAPU16.subarray((pixels)>>1,(pixels+bytes)>>1);
        default:
          GL.recordError(0x0500); // GL_INVALID_ENUM
          return null;
      }
    }function _glTexSubImage2D(target, level, xoffset, yoffset, width, height, format, type, pixels) {
      var pixelData = null;
      if (pixels) pixelData = emscriptenWebGLGetTexPixelData(type, format, width, height, pixels, 0);
      GLctx.texSubImage2D(target, level, xoffset, yoffset, width, height, format, type, pixelData);
    }

  function _glDisable(x0) { GLctx['disable'](x0) }

  function _emscripten_glEnableVertexAttribArray(index) {
      GLctx.enableVertexAttribArray(index);
    }

   

  function _glBindTexture(target, texture) {
      GLctx.bindTexture(target, texture ? GL.textures[texture] : null);
    }


  function _emscripten_glCopyTexSubImage2D(x0, x1, x2, x3, x4, x5, x6, x7) { GLctx['copyTexSubImage2D'](x0, x1, x2, x3, x4, x5, x6, x7) }

  function _emscripten_set_touchcancel_callback(target, userData, useCapture, callbackfunc) {
      JSEvents.registerTouchEventCallback(target, userData, useCapture, callbackfunc, 25, "touchcancel");
      return 0;
    }

  function ___lock() {}

  function _emscripten_glBlendFuncSeparate(x0, x1, x2, x3) { GLctx['blendFuncSeparate'](x0, x1, x2, x3) }

  function _emscripten_glGetVertexAttribPointerv(index, pname, pointer) {
      if (!pointer) {
        // GLES2 specification does not specify how to behave if pointer is a null pointer. Since calling this function does not make sense
        // if pointer == null, issue a GL error to notify user about it. 
        GL.recordError(0x0501 /* GL_INVALID_VALUE */);
        return;
      }
      HEAP32[((pointer)>>2)]=GLctx.getVertexAttribOffset(index, pname);
    }

  function _emscripten_glVertexAttrib3f(x0, x1, x2, x3) { GLctx['vertexAttrib3f'](x0, x1, x2, x3) }

  function _emscripten_set_mousemove_callback(target, userData, useCapture, callbackfunc) {
      JSEvents.registerMouseEventCallback(target, userData, useCapture, callbackfunc, 8, "mousemove");
      return 0;
    }

  function _emscripten_glNormalPointer() {
  Module['printErr']('missing function: emscripten_glNormalPointer'); abort(-1);
  }

  
  
   
  
   
  
  var cttz_i8 = allocate([8,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,6,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,7,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,6,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0], "i8", ALLOC_STATIC);   

  function _eglGetProcAddress(name_) {
      return _emscripten_GetProcAddress(name_);
    }

  function _emscripten_get_pointerlock_status(pointerlockStatus) {
      if (pointerlockStatus) JSEvents.fillPointerlockChangeEventData(pointerlockStatus);
      if (!document.body || (!document.body.requestPointerLock && !document.body.mozRequestPointerLock && !document.body.webkitRequestPointerLock && !document.body.msRequestPointerLock)) {
        return -1;
      }
      return 0;
    }

  function _eglSwapInterval(display, interval) {
      if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0;
      }
      if (interval == 0) _emscripten_set_main_loop_timing(0/*EM_TIMING_SETTIMEOUT*/, 0);
      else _emscripten_set_main_loop_timing(1/*EM_TIMING_RAF*/, interval);
  
      EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
      return 1;
    }

  
  function emscriptenWebGLGetVertexAttrib(index, pname, params, type) {
      if (!params) {
        // GLES2 specification does not specify how to behave if params is a null pointer. Since calling this function does not make sense
        // if params == null, issue a GL error to notify user about it. 
        GL.recordError(0x0501 /* GL_INVALID_VALUE */);
        return;
      }
      var data = GLctx.getVertexAttrib(index, pname);
      if (pname == 0x889F/*VERTEX_ATTRIB_ARRAY_BUFFER_BINDING*/) {
        HEAP32[((params)>>2)]=data["name"];
      } else if (typeof data == 'number' || typeof data == 'boolean') {
        switch (type) {
          case 'Integer': HEAP32[((params)>>2)]=data; break;
          case 'Float': HEAPF32[((params)>>2)]=data; break;
          case 'FloatToInteger': HEAP32[((params)>>2)]=Math.fround(data); break;
          default: throw 'internal emscriptenWebGLGetVertexAttrib() error, bad type: ' + type;
        }
      } else {
        for (var i = 0; i < data.length; i++) {
          switch (type) {
            case 'Integer': HEAP32[(((params)+(i*4))>>2)]=data[i]; break;
            case 'Float': HEAPF32[(((params)+(i*4))>>2)]=data[i]; break;
            case 'FloatToInteger': HEAP32[(((params)+(i*4))>>2)]=Math.fround(data[i]); break;
            default: throw 'internal emscriptenWebGLGetVertexAttrib() error, bad type: ' + type;
          }
        }
      }
    }function _emscripten_glGetVertexAttribfv(index, pname, params) {
      // N.B. This function may only be called if the vertex attribute was specified using the function glVertexAttrib*f(),
      // otherwise the results are undefined. (GLES3 spec 6.1.12)
      emscriptenWebGLGetVertexAttrib(index, pname, params, 'Float');
    }

  function _emscripten_set_touchstart_callback(target, userData, useCapture, callbackfunc) {
      JSEvents.registerTouchEventCallback(target, userData, useCapture, callbackfunc, 22, "touchstart");
      return 0;
    }

  function _glShaderBinary() {
      GL.recordError(0x0500/*GL_INVALID_ENUM*/);
    }

  function _emscripten_glDeleteShader(id) {
      if (!id) return;
      var shader = GL.shaders[id];
      if (!shader) { // glDeleteShader actually signals an error when deleting a nonexisting object, unlike some other GL delete functions.
        GL.recordError(0x0501 /* GL_INVALID_VALUE */);
        return;
      }
      GLctx.deleteShader(shader);
      GL.shaders[id] = null;
    }

  function _pthread_attr_init(attr) {
      /* int pthread_attr_init(pthread_attr_t *attr); */
      //FIXME: should allocate a pthread_attr_t
      return 0;
    }

  function _pthread_testcancel() {
  Module['printErr']('missing function: pthread_testcancel'); abort(-1);
  }

  function _emscripten_glDeleteBuffers(n, buffers) {
      for (var i = 0; i < n; i++) {
        var id = HEAP32[(((buffers)+(i*4))>>2)];
        var buffer = GL.buffers[id];
  
        // From spec: "glDeleteBuffers silently ignores 0's and names that do not
        // correspond to existing buffer objects."
        if (!buffer) continue;
  
        GLctx.deleteBuffer(buffer);
        buffer.name = 0;
        GL.buffers[id] = null;
  
        if (id == GL.currArrayBuffer) GL.currArrayBuffer = 0;
        if (id == GL.currElementArrayBuffer) GL.currElementArrayBuffer = 0;
      }
    }

  function _emscripten_glTexParameteriv(target, pname, params) {
      var param = HEAP32[((params)>>2)];
      GLctx.texParameteri(target, pname, param);
    }

  function _glDrawElements(mode, count, type, indices) {
  
      GLctx.drawElements(mode, count, type, indices);
  
    }

  function _emscripten_glUniformMatrix2fv(location, count, transpose, value) {
  
  
      var view;
      if (4*count <= GL.MINI_TEMP_BUFFER_SIZE) {
        // avoid allocation when uploading few enough uniforms
        view = GL.miniTempBufferViews[4*count-1];
        for (var i = 0; i < 4*count; i += 4) {
          view[i] = HEAPF32[(((value)+(4*i))>>2)];
          view[i+1] = HEAPF32[(((value)+(4*i+4))>>2)];
          view[i+2] = HEAPF32[(((value)+(4*i+8))>>2)];
          view[i+3] = HEAPF32[(((value)+(4*i+12))>>2)];
        }
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*16)>>2);
      }
      GLctx.uniformMatrix2fv(GL.uniforms[location], !!transpose, view);
    }

  function ___syscall5(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // open
      var pathname = SYSCALLS.getStr(), flags = SYSCALLS.get(), mode = SYSCALLS.get() // optional TODO
      var stream = FS.open(pathname, flags, mode);
      return stream.fd;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  
  
  
  
  var _environ=STATICTOP; STATICTOP += 16;;var ___environ=_environ;function ___buildEnvironment(env) {
      // WARNING: Arbitrary limit!
      var MAX_ENV_VALUES = 64;
      var TOTAL_ENV_SIZE = 1024;
  
      // Statically allocate memory for the environment.
      var poolPtr;
      var envPtr;
      if (!___buildEnvironment.called) {
        ___buildEnvironment.called = true;
        // Set default values. Use string keys for Closure Compiler compatibility.
        ENV['USER'] = ENV['LOGNAME'] = 'web_user';
        ENV['PATH'] = '/';
        ENV['PWD'] = '/';
        ENV['HOME'] = '/home/web_user';
        ENV['LANG'] = 'C';
        ENV['_'] = Module['thisProgram'];
        // Allocate memory.
        poolPtr = allocate(TOTAL_ENV_SIZE, 'i8', ALLOC_STATIC);
        envPtr = allocate(MAX_ENV_VALUES * 4,
                          'i8*', ALLOC_STATIC);
        HEAP32[((envPtr)>>2)]=poolPtr;
        HEAP32[((_environ)>>2)]=envPtr;
      } else {
        envPtr = HEAP32[((_environ)>>2)];
        poolPtr = HEAP32[((envPtr)>>2)];
      }
  
      // Collect key=value lines.
      var strings = [];
      var totalSize = 0;
      for (var key in env) {
        if (typeof env[key] === 'string') {
          var line = key + '=' + env[key];
          strings.push(line);
          totalSize += line.length;
        }
      }
      if (totalSize > TOTAL_ENV_SIZE) {
        throw new Error('Environment size exceeded TOTAL_ENV_SIZE!');
      }
  
      // Make new.
      var ptrSize = 4;
      for (var i = 0; i < strings.length; i++) {
        var line = strings[i];
        writeAsciiToMemory(line, poolPtr);
        HEAP32[(((envPtr)+(i * ptrSize))>>2)]=poolPtr;
        poolPtr += line.length + 1;
      }
      HEAP32[(((envPtr)+(strings.length * ptrSize))>>2)]=0;
    }var ENV={};function _dlopen(filename, flag) {
      abort("To use dlopen, you need to use Emscripten's linking support, see https://github.com/kripken/emscripten/wiki/Linking");
      // void *dlopen(const char *file, int mode);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/dlopen.html
      var searchpaths = [];
      if (filename === 0) {
        filename = '__self__';
      } else {
        var strfilename = Pointer_stringify(filename);
        var isValidFile = function (filename) {
          var target = FS.findObject(filename);
          return target && !target.isFolder && !target.isDevice;
        };
  
        if (isValidFile(strfilename)) {
          filename = strfilename;
        } else {
          if (ENV['LD_LIBRARY_PATH']) {
            searchpaths = ENV['LD_LIBRARY_PATH'].split(':');
          }
  
          for (var ident in searchpaths) {
            var searchfile = PATH.join2(searchpaths[ident],strfilename);
            if (isValidFile(searchfile)) {
              filename = searchfile;
              break;
            }
          }
        }
      }
  
      if (DLFCN.loadedLibNames[filename]) {
        // Already loaded; increment ref count and return.
        var handle = DLFCN.loadedLibNames[filename];
        DLFCN.loadedLibs[handle].refcount++;
        return handle;
      }
  
      if (filename === '__self__') {
        var handle = -1;
        var lib_module = Module;
        var cached_functions = {};
      } else {
        var target = FS.findObject(filename);
        if (!target || target.isFolder || target.isDevice) {
          DLFCN.errorMsg = 'Could not find dynamic lib: ' + filename;
          return 0;
        }
        FS.forceLoadFile(target);
  
        var lib_module;
        try {
          // the shared library is a JS file, which we eval
          var lib_data = FS.readFile(filename, { encoding: 'utf8' });
          lib_module = eval(lib_data)(
            Runtime.alignFunctionTables(),
            Module
          );
        } catch (e) {
          Module.printErr('Error in loading dynamic library: ' + e);
          DLFCN.errorMsg = 'Could not evaluate dynamic lib: ' + filename + '\n' + e;
          return 0;
        }
  
        // Not all browsers support Object.keys().
        var handle = 1;
        for (var key in DLFCN.loadedLibs) {
          if (DLFCN.loadedLibs.hasOwnProperty(key)) handle++;
        }
  
        // We don't care about RTLD_NOW and RTLD_LAZY.
        if (flag & 256) { // RTLD_GLOBAL
          for (var ident in lib_module) {
            if (lib_module.hasOwnProperty(ident)) {
              // When RTLD_GLOBAL is enable, the symbols defined by this shared object will be made
              // available for symbol resolution of subsequently loaded shared objects.
              //
              // We should copy the symbols (which include methods and variables) from SIDE_MODULE to MAIN_MODULE.
              //
              // Module of SIDE_MODULE has not only the symbols (which should be copied)
              // but also others (print*, asmGlobal*, FUNCTION_TABLE_**, NAMED_GLOBALS, and so on).
              //
              // When the symbol (which should be copied) is method, Module._* 's type becomes function.
              // When the symbol (which should be copied) is variable, Module._* 's type becomes number.
              //
              // Except for the symbol prefix (_), there is no difference in the symbols (which should be copied) and others.
              // So this just copies over compiled symbols (which start with _).
              if (ident[0] == '_') {
                Module[ident] = lib_module[ident];
              }
            }
          }
        }
  
        var cached_functions = {};
      }
      DLFCN.loadedLibs[handle] = {
        refcount: 1,
        name: filename,
        module: lib_module,
        cached_functions: cached_functions
      };
      DLFCN.loadedLibNames[filename] = handle;
  
      return handle;
    }

  function ___syscall6(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // close
      var stream = SYSCALLS.getStreamFromFD();
      FS.close(stream);
      return 0;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function _emscripten_glGetVertexAttribiv(index, pname, params) {
      // N.B. This function may only be called if the vertex attribute was specified using the function glVertexAttrib*f(),
      // otherwise the results are undefined. (GLES3 spec 6.1.12)
      emscriptenWebGLGetVertexAttrib(index, pname, params, 'FloatToInteger');
    }

  function _emscripten_glUniformMatrix4fv(location, count, transpose, value) {
  
  
      var view;
      if (16*count <= GL.MINI_TEMP_BUFFER_SIZE) {
        // avoid allocation when uploading few enough uniforms
        view = GL.miniTempBufferViews[16*count-1];
        for (var i = 0; i < 16*count; i += 16) {
          view[i] = HEAPF32[(((value)+(4*i))>>2)];
          view[i+1] = HEAPF32[(((value)+(4*i+4))>>2)];
          view[i+2] = HEAPF32[(((value)+(4*i+8))>>2)];
          view[i+3] = HEAPF32[(((value)+(4*i+12))>>2)];
          view[i+4] = HEAPF32[(((value)+(4*i+16))>>2)];
          view[i+5] = HEAPF32[(((value)+(4*i+20))>>2)];
          view[i+6] = HEAPF32[(((value)+(4*i+24))>>2)];
          view[i+7] = HEAPF32[(((value)+(4*i+28))>>2)];
          view[i+8] = HEAPF32[(((value)+(4*i+32))>>2)];
          view[i+9] = HEAPF32[(((value)+(4*i+36))>>2)];
          view[i+10] = HEAPF32[(((value)+(4*i+40))>>2)];
          view[i+11] = HEAPF32[(((value)+(4*i+44))>>2)];
          view[i+12] = HEAPF32[(((value)+(4*i+48))>>2)];
          view[i+13] = HEAPF32[(((value)+(4*i+52))>>2)];
          view[i+14] = HEAPF32[(((value)+(4*i+56))>>2)];
          view[i+15] = HEAPF32[(((value)+(4*i+60))>>2)];
        }
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*64)>>2);
      }
      GLctx.uniformMatrix4fv(GL.uniforms[location], !!transpose, view);
    }

  function _emscripten_glCompressedTexImage2D(target, level, internalFormat, width, height, border, imageSize, data) {
      GLctx['compressedTexImage2D'](target, level, internalFormat, width, height, border, data ? HEAPU8.subarray((data),(data+imageSize)) : null);
    }

  function _emscripten_glDrawArraysInstanced(mode, first, count, primcount) {
      GLctx['drawArraysInstanced'](mode, first, count, primcount);
    }

  function _emscripten_glEnableClientState() {
  Module['printErr']('missing function: emscripten_glEnableClientState'); abort(-1);
  }

  function _emscripten_glGetPointerv() {
  Module['printErr']('missing function: emscripten_glGetPointerv'); abort(-1);
  }

  function _eglChooseConfig(display, attrib_list, configs, config_size, numConfigs) { 
      return EGL.chooseConfig(display, attrib_list, configs, config_size, numConfigs);
    }

  function ___syscall146(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // writev
      var stream = SYSCALLS.getStreamFromFD(), iov = SYSCALLS.get(), iovcnt = SYSCALLS.get();
      return SYSCALLS.doWritev(stream, iov, iovcnt);
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function _emscripten_glUniform1i(location, v0) {
      GLctx.uniform1i(GL.uniforms[location], v0);
    }

  function ___syscall145(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // readv
      var stream = SYSCALLS.getStreamFromFD(), iov = SYSCALLS.get(), iovcnt = SYSCALLS.get();
      return SYSCALLS.doReadv(stream, iov, iovcnt);
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  
  function _atexit(func, arg) {
      __ATEXIT__.unshift({ func: func, arg: arg });
    }function ___cxa_atexit() {
  return _atexit.apply(null, arguments)
  }

  function _emscripten_glStencilFuncSeparate(x0, x1, x2, x3) { GLctx['stencilFuncSeparate'](x0, x1, x2, x3) }

  function _eglGetConfigAttrib(display, config, attribute, value) {
      if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0;
      }
      if (config != 62002 /* Magic ID for the only EGLConfig supported by Emscripten */) {
        EGL.setErrorCode(0x3005 /* EGL_BAD_CONFIG */);
        return 0;
      }
      if (!value) {
        EGL.setErrorCode(0x300C /* EGL_BAD_PARAMETER */);
        return 0;
      }
      EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
      switch(attribute) {
      case 0x3020: // EGL_BUFFER_SIZE
        HEAP32[((value)>>2)]=32;
        return 1;
      case 0x3021: // EGL_ALPHA_SIZE
        HEAP32[((value)>>2)]=8;
        return 1;
      case 0x3022: // EGL_BLUE_SIZE
        HEAP32[((value)>>2)]=8;
        return 1;
      case 0x3023: // EGL_GREEN_SIZE
        HEAP32[((value)>>2)]=8;
        return 1;
      case 0x3024: // EGL_RED_SIZE
        HEAP32[((value)>>2)]=8;
        return 1;
      case 0x3025: // EGL_DEPTH_SIZE
        HEAP32[((value)>>2)]=24;
        return 1;
      case 0x3026: // EGL_STENCIL_SIZE
        HEAP32[((value)>>2)]=8;
        return 1;
      case 0x3027: // EGL_CONFIG_CAVEAT
        // We can return here one of EGL_NONE (0x3038), EGL_SLOW_CONFIG (0x3050) or EGL_NON_CONFORMANT_CONFIG (0x3051).
        HEAP32[((value)>>2)]=0x3038;
        return 1;
      case 0x3028: // EGL_CONFIG_ID
        HEAP32[((value)>>2)]=62002;
        return 1;
      case 0x3029: // EGL_LEVEL
        HEAP32[((value)>>2)]=0;
        return 1;
      case 0x302A: // EGL_MAX_PBUFFER_HEIGHT
        HEAP32[((value)>>2)]=4096;
        return 1;
      case 0x302B: // EGL_MAX_PBUFFER_PIXELS
        HEAP32[((value)>>2)]=16777216;
        return 1;
      case 0x302C: // EGL_MAX_PBUFFER_WIDTH
        HEAP32[((value)>>2)]=4096;
        return 1;
      case 0x302D: // EGL_NATIVE_RENDERABLE
        HEAP32[((value)>>2)]=0;
        return 1;
      case 0x302E: // EGL_NATIVE_VISUAL_ID
        HEAP32[((value)>>2)]=0;
        return 1;
      case 0x302F: // EGL_NATIVE_VISUAL_TYPE
        HEAP32[((value)>>2)]=0x3038;
        return 1;
      case 0x3031: // EGL_SAMPLES
        HEAP32[((value)>>2)]=4;
        return 1;
      case 0x3032: // EGL_SAMPLE_BUFFERS
        HEAP32[((value)>>2)]=1;
        return 1;
      case 0x3033: // EGL_SURFACE_TYPE
        HEAP32[((value)>>2)]=0x0004;
        return 1;
      case 0x3034: // EGL_TRANSPARENT_TYPE
        // If this returns EGL_TRANSPARENT_RGB (0x3052), transparency is used through color-keying. No such thing applies to Emscripten canvas.
        HEAP32[((value)>>2)]=0x3038;
        return 1;
      case 0x3035: // EGL_TRANSPARENT_BLUE_VALUE
      case 0x3036: // EGL_TRANSPARENT_GREEN_VALUE
      case 0x3037: // EGL_TRANSPARENT_RED_VALUE
        // "If EGL_TRANSPARENT_TYPE is EGL_NONE, then the values for EGL_TRANSPARENT_RED_VALUE, EGL_TRANSPARENT_GREEN_VALUE, and EGL_TRANSPARENT_BLUE_VALUE are undefined."
        HEAP32[((value)>>2)]=-1;
        return 1;
      case 0x3039: // EGL_BIND_TO_TEXTURE_RGB
      case 0x303A: // EGL_BIND_TO_TEXTURE_RGBA
        HEAP32[((value)>>2)]=0;
        return 1;
      case 0x303B: // EGL_MIN_SWAP_INTERVAL
      case 0x303C: // EGL_MAX_SWAP_INTERVAL
        HEAP32[((value)>>2)]=1;
        return 1;
      case 0x303D: // EGL_LUMINANCE_SIZE
      case 0x303E: // EGL_ALPHA_MASK_SIZE
        HEAP32[((value)>>2)]=0;
        return 1;
      case 0x303F: // EGL_COLOR_BUFFER_TYPE
        // EGL has two types of buffers: EGL_RGB_BUFFER and EGL_LUMINANCE_BUFFER.
        HEAP32[((value)>>2)]=0x308E;
        return 1;
      case 0x3040: // EGL_RENDERABLE_TYPE
        // A bit combination of EGL_OPENGL_ES_BIT,EGL_OPENVG_BIT,EGL_OPENGL_ES2_BIT and EGL_OPENGL_BIT.
        HEAP32[((value)>>2)]=0x0004;
        return 1;
      case 0x3042: // EGL_CONFORMANT
        // "EGL_CONFORMANT is a mask indicating if a client API context created with respect to the corresponding EGLConfig will pass the required conformance tests for that API."
        HEAP32[((value)>>2)]=0;
        return 1;
      default:
        EGL.setErrorCode(0x3004 /* EGL_BAD_ATTRIBUTE */);
        return 0;
      }
    }


  function _emscripten_glClearDepthf(x0) { GLctx['clearDepth'](x0) }

  
  function __ZSt18uncaught_exceptionv() { // std::uncaught_exception()
      return !!__ZSt18uncaught_exceptionv.uncaught_exception;
    }
  
  function ___cxa_find_matching_catch() {
      var thrown = EXCEPTIONS.last;
      if (!thrown) {
        // just pass through the null ptr
        return ((Runtime.setTempRet0(0),0)|0);
      }
      var info = EXCEPTIONS.infos[thrown];
      var throwntype = info.type;
      if (!throwntype) {
        // just pass through the thrown ptr
        return ((Runtime.setTempRet0(0),thrown)|0);
      }
      var typeArray = Array.prototype.slice.call(arguments);
  
      var pointer = Module['___cxa_is_pointer_type'](throwntype);
      // can_catch receives a **, add indirection
      if (!___cxa_find_matching_catch.buffer) ___cxa_find_matching_catch.buffer = _malloc(4);
      HEAP32[((___cxa_find_matching_catch.buffer)>>2)]=thrown;
      thrown = ___cxa_find_matching_catch.buffer;
      // The different catch blocks are denoted by different types.
      // Due to inheritance, those types may not precisely match the
      // type of the thrown object. Find one which matches, and
      // return the type of the catch block which should be called.
      for (var i = 0; i < typeArray.length; i++) {
        if (typeArray[i] && Module['___cxa_can_catch'](typeArray[i], throwntype, thrown)) {
          thrown = HEAP32[((thrown)>>2)]; // undo indirection
          info.adjusted = thrown;
          return ((Runtime.setTempRet0(typeArray[i]),thrown)|0);
        }
      }
      // Shouldn't happen unless we have bogus data in typeArray
      // or encounter a type for which emscripten doesn't have suitable
      // typeinfo defined. Best-efforts match just in case.
      thrown = HEAP32[((thrown)>>2)]; // undo indirection
      return ((Runtime.setTempRet0(throwntype),thrown)|0);
    }function ___cxa_throw(ptr, type, destructor) {
      EXCEPTIONS.infos[ptr] = {
        ptr: ptr,
        adjusted: ptr,
        type: type,
        destructor: destructor,
        refcount: 0,
        caught: false,
        rethrown: false
      };
      EXCEPTIONS.last = ptr;
      if (!("uncaught_exception" in __ZSt18uncaught_exceptionv)) {
        __ZSt18uncaught_exceptionv.uncaught_exception = 1;
      } else {
        __ZSt18uncaught_exceptionv.uncaught_exception++;
      }
      throw ptr;
    }

  function _emscripten_set_touchend_callback(target, userData, useCapture, callbackfunc) {
      JSEvents.registerTouchEventCallback(target, userData, useCapture, callbackfunc, 23, "touchend");
      return 0;
    }

  
  
  function __setLetterbox(element, topBottom, leftRight) {
      if (JSEvents.isInternetExplorer()) {
        // Cannot use padding on IE11, because IE11 computes padding in addition to the size, unlike
        // other browsers, which treat padding to be part of the size.
        // e.g.
        // FF, Chrome: If CSS size = 1920x1080, padding-leftright = 460, padding-topbottomx40, then content size = (1920 - 2*460) x (1080-2*40) = 1000x1000px, and total element size = 1920x1080px.
        //       IE11: If CSS size = 1920x1080, padding-leftright = 460, padding-topbottomx40, then content size = 1920x1080px and total element size = (1920+2*460) x (1080+2*40)px.
        // IE11  treats margin like Chrome and FF treat padding.
        element.style.marginLeft = element.style.marginRight = leftRight + 'px';
        element.style.marginTop = element.style.marginBottom = topBottom + 'px';
      } else {
        // Cannot use margin to specify letterboxes in FF or Chrome, since those ignore margins in fullscreen mode.
        element.style.paddingLeft = element.style.paddingRight = leftRight + 'px';
        element.style.paddingTop = element.style.paddingBottom = topBottom + 'px';
      }
    }function _emscripten_do_request_fullscreen(target, strategy) {
      if (typeof JSEvents.fullscreenEnabled() === 'undefined') return -1;
      if (!JSEvents.fullscreenEnabled()) return -3;
      if (!target) target = '#canvas';
      target = JSEvents.findEventTarget(target);
      if (!target) return -4;
  
      if (!target.requestFullscreen && !target.msRequestFullscreen && !target.mozRequestFullScreen && !target.mozRequestFullscreen && !target.webkitRequestFullscreen) {
        return -3;
      }
  
      var canPerformRequests = JSEvents.canPerformEventHandlerRequests();
  
      // Queue this function call if we're not currently in an event handler and the user saw it appropriate to do so.
      if (!canPerformRequests) {
        if (strategy.deferUntilInEventHandler) {
          JSEvents.deferCall(JSEvents.requestFullscreen, 1 /* priority over pointer lock */, [target, strategy]);
          return 1;
        } else {
          return -2;
        }
      }
  
      return JSEvents.requestFullscreen(target, strategy);
    }
  
  var __currentFullscreenStrategy={};
  
  function __registerRestoreOldStyle(canvas) {
      var oldWidth = canvas.width;
      var oldHeight = canvas.height;
      var oldCssWidth = canvas.style.width;
      var oldCssHeight = canvas.style.height;
      var oldBackgroundColor = canvas.style.backgroundColor; // Chrome reads color from here.
      var oldDocumentBackgroundColor = document.body.style.backgroundColor; // IE11 reads color from here.
      // Firefox always has black background color.
      var oldPaddingLeft = canvas.style.paddingLeft; // Chrome, FF, Safari
      var oldPaddingRight = canvas.style.paddingRight;
      var oldPaddingTop = canvas.style.paddingTop;
      var oldPaddingBottom = canvas.style.paddingBottom;
      var oldMarginLeft = canvas.style.marginLeft; // IE11
      var oldMarginRight = canvas.style.marginRight;
      var oldMarginTop = canvas.style.marginTop;
      var oldMarginBottom = canvas.style.marginBottom;
      var oldDocumentBodyMargin = document.body.style.margin;
      var oldDocumentOverflow = document.documentElement.style.overflow; // Chrome, Firefox
      var oldDocumentScroll = document.body.scroll; // IE
      var oldImageRendering = canvas.style.imageRendering;
  
      function restoreOldStyle() {
        var fullscreenElement = document.fullscreenElement || document.mozFullScreenElement || document.webkitFullscreenElement || document.msFullscreenElement;
        if (!fullscreenElement) {
          document.removeEventListener('fullscreenchange', restoreOldStyle);
          document.removeEventListener('mozfullscreenchange', restoreOldStyle);
          document.removeEventListener('webkitfullscreenchange', restoreOldStyle);
          document.removeEventListener('MSFullscreenChange', restoreOldStyle);
  
          canvas.width = oldWidth;
          canvas.height = oldHeight;
          canvas.style.width = oldCssWidth;
          canvas.style.height = oldCssHeight;
          canvas.style.backgroundColor = oldBackgroundColor; // Chrome
          // IE11 hack: assigning 'undefined' or an empty string to document.body.style.backgroundColor has no effect, so first assign back the default color
          // before setting the undefined value. Setting undefined value is also important, or otherwise we would later treat that as something that the user
          // had explicitly set so subsequent fullscreen transitions would not set background color properly.
          if (!oldDocumentBackgroundColor) document.body.style.backgroundColor = 'white';
          document.body.style.backgroundColor = oldDocumentBackgroundColor; // IE11
          canvas.style.paddingLeft = oldPaddingLeft; // Chrome, FF, Safari
          canvas.style.paddingRight = oldPaddingRight;
          canvas.style.paddingTop = oldPaddingTop;
          canvas.style.paddingBottom = oldPaddingBottom;
          canvas.style.marginLeft = oldMarginLeft; // IE11
          canvas.style.marginRight = oldMarginRight;
          canvas.style.marginTop = oldMarginTop;
          canvas.style.marginBottom = oldMarginBottom;
          document.body.style.margin = oldDocumentBodyMargin;
          document.documentElement.style.overflow = oldDocumentOverflow; // Chrome, Firefox
          document.body.scroll = oldDocumentScroll; // IE
          canvas.style.imageRendering = oldImageRendering;
          if (canvas.GLctxObject) canvas.GLctxObject.GLctx.viewport(0, 0, oldWidth, oldHeight);
  
          if (__currentFullscreenStrategy.canvasResizedCallback) {
            Module['dynCall_iiii'](__currentFullscreenStrategy.canvasResizedCallback, 37, 0, __currentFullscreenStrategy.canvasResizedCallbackUserData);
          }
        }
      }
      document.addEventListener('fullscreenchange', restoreOldStyle);
      document.addEventListener('mozfullscreenchange', restoreOldStyle);
      document.addEventListener('webkitfullscreenchange', restoreOldStyle);
      document.addEventListener('MSFullscreenChange', restoreOldStyle);
      return restoreOldStyle;
    }function _emscripten_request_fullscreen_strategy(target, deferUntilInEventHandler, fullscreenStrategy) {
      var strategy = {};
      strategy.scaleMode = HEAP32[((fullscreenStrategy)>>2)];
      strategy.canvasResolutionScaleMode = HEAP32[(((fullscreenStrategy)+(4))>>2)];
      strategy.filteringMode = HEAP32[(((fullscreenStrategy)+(8))>>2)];
      strategy.deferUntilInEventHandler = deferUntilInEventHandler;
      strategy.canvasResizedCallback = HEAP32[(((fullscreenStrategy)+(12))>>2)];
      strategy.canvasResizedCallbackUserData = HEAP32[(((fullscreenStrategy)+(16))>>2)];
      __currentFullscreenStrategy = strategy;
  
      return _emscripten_do_request_fullscreen(target, strategy);
    }

  function _emscripten_glDisableVertexAttribArray(index) {
      GLctx.disableVertexAttribArray(index);
    }

  function _emscripten_glVertexAttrib1f(x0, x1) { GLctx['vertexAttrib1f'](x0, x1) }

  function _emscripten_glFinish() { GLctx['finish']() }

  function _glDrawArrays(mode, first, count) {
  
      GLctx.drawArrays(mode, first, count);
  
    }

  function _emscripten_glDepthFunc(x0) { GLctx['depthFunc'](x0) }

  function _emscripten_get_num_gamepads() {
      // Polling gamepads generates garbage, so don't do it when we know there are no gamepads connected.
      if (!JSEvents.numGamepadsConnected) return 0;
  
      __emscripten_sample_gamepad_data();
      if (!JSEvents.lastGamepadState) return -1;
      return JSEvents.lastGamepadState.length;
    }

  function _emscripten_set_blur_callback(target, userData, useCapture, callbackfunc) {
      JSEvents.registerFocusEventCallback(target, userData, useCapture, callbackfunc, 12, "blur");
      return 0;
    }

  function _sigaction(signum, act, oldact) {
      //int sigaction(int signum, const struct sigaction *act, struct sigaction *oldact);
      Module.printErr('Calling stub instead of sigaction()');
      return 0;
    }

  function _emscripten_glUniform4iv(location, count, value) {
  
  
      GLctx.uniform4iv(GL.uniforms[location], HEAP32.subarray((value)>>2,(value+count*16)>>2));
    }

  function _glClear(x0) { GLctx['clear'](x0) }

  function _emscripten_set_resize_callback(target, userData, useCapture, callbackfunc) {
      JSEvents.registerUiEventCallback(target, userData, useCapture, callbackfunc, 10, "resize");
      return 0;
    }

  function _emscripten_glLoadIdentity(){ throw 'Legacy GL function (glLoadIdentity) called. If you want legacy GL emulation, you need to compile with -s LEGACY_GL_EMULATION=1 to enable legacy GL emulation.'; }

  function _emscripten_set_element_css_size(target, width, height) {
      if (!target) {
        target = Module['canvas'];
      } else {
        target = JSEvents.findEventTarget(target);
      }
  
      if (!target) return -4;
  
      target.style.setProperty("width", width + "px");
      target.style.setProperty("height", height + "px");
  
      return 0;
    }

  function ___syscall91(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // munmap
      var addr = SYSCALLS.get(), len = SYSCALLS.get();
      // TODO: support unmmap'ing parts of allocations
      var info = SYSCALLS.mappings[addr];
      if (!info) return 0;
      if (len === info.len) {
        var stream = FS.getStream(info.fd);
        SYSCALLS.doMsync(addr, stream, len, info.flags)
        FS.munmap(stream);
        SYSCALLS.mappings[addr] = null;
        if (info.allocated) {
          _free(info.malloc);
        }
      }
      return 0;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function _emscripten_glAttachShader(program, shader) {
      GLctx.attachShader(GL.programs[program],
                              GL.shaders[shader]);
    }

  function _glStencilOp(x0, x1, x2) { GLctx['stencilOp'](x0, x1, x2) }

  function _glReadPixels(x, y, width, height, format, type, pixels) {
      var pixelData = emscriptenWebGLGetTexPixelData(type, format, width, height, pixels, format);
      if (!pixelData) {
        GL.recordError(0x0500/*GL_INVALID_ENUM*/);
        return;
      }
      GLctx.readPixels(x, y, width, height, format, type, pixelData);
    }

  function _glStencilMask(x0) { GLctx['stencilMask'](x0) }

  function _emscripten_glGetRenderbufferParameteriv(target, pname, params) {
      if (!params) {
        // GLES2 specification does not specify how to behave if params is a null pointer. Since calling this function does not make sense
        // if params == null, issue a GL error to notify user about it. 
        GL.recordError(0x0501 /* GL_INVALID_VALUE */);
        return;
      }
      HEAP32[((params)>>2)]=GLctx.getRenderbufferParameter(target, pname);
    }

  function _emscripten_request_pointerlock(target, deferUntilInEventHandler) {
      if (!target) target = '#canvas';
      target = JSEvents.findEventTarget(target);
      if (!target) return -4;
      if (!target.requestPointerLock && !target.mozRequestPointerLock && !target.webkitRequestPointerLock && !target.msRequestPointerLock) {
        return -1;
      }
  
      var canPerformRequests = JSEvents.canPerformEventHandlerRequests();
  
      // Queue this function call if we're not currently in an event handler and the user saw it appropriate to do so.
      if (!canPerformRequests) {
        if (deferUntilInEventHandler) {
          JSEvents.deferCall(JSEvents.requestPointerLock, 2 /* priority below fullscreen */, [target]);
          return 1;
        } else {
          return -2;
        }
      }
  
      return JSEvents.requestPointerLock(target);
    }

  function _eglCreateWindowSurface(display, config, win, attrib_list) { 
      if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0;
      }
      if (config != 62002 /* Magic ID for the only EGLConfig supported by Emscripten */) {
        EGL.setErrorCode(0x3005 /* EGL_BAD_CONFIG */);
        return 0;
      }
      // TODO: Examine attrib_list! Parameters that can be present there are:
      // - EGL_RENDER_BUFFER (must be EGL_BACK_BUFFER)
      // - EGL_VG_COLORSPACE (can't be set)
      // - EGL_VG_ALPHA_FORMAT (can't be set)
      EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
      return 62006; /* Magic ID for Emscripten 'default surface' */
    }


   

  function _gettimeofday(ptr) {
      var now = Date.now();
      HEAP32[((ptr)>>2)]=(now/1000)|0; // seconds
      HEAP32[(((ptr)+(4))>>2)]=((now % 1000)*1000)|0; // microseconds
      return 0;
    }

  function _glTexParameteriv(target, pname, params) {
      var param = HEAP32[((params)>>2)];
      GLctx.texParameteri(target, pname, param);
    }

  function _emscripten_glDetachShader(program, shader) {
      GLctx.detachShader(GL.programs[program],
                              GL.shaders[shader]);
    }

  function _emscripten_get_device_pixel_ratio() {
      return window.devicePixelRatio || 1.0;
    }

  function _emscripten_glDeleteVertexArrays(n, vaos) {
      for (var i = 0; i < n; i++) {
        var id = HEAP32[(((vaos)+(i*4))>>2)];
        GLctx['deleteVertexArray'](GL.vaos[id]);
        GL.vaos[id] = null;
      }
    }

  function _emscripten_glTexParameteri(x0, x1, x2) { GLctx['texParameteri'](x0, x1, x2) }

  function _emscripten_get_element_css_size(target, width, height) {
      if (!target) {
        target = Module['canvas'];
      } else {
        target = JSEvents.findEventTarget(target);
      }
  
      if (!target) return -4;
  
      if (target.getBoundingClientRect) {
        var rect = target.getBoundingClientRect();
        HEAPF64[((width)>>3)]=rect.right - rect.left;
        HEAPF64[((height)>>3)]=rect.bottom - rect.top;
      } else {
        HEAPF64[((width)>>3)]=target.clientWidth;
        HEAPF64[((height)>>3)]=target.clientHeight;
      }
  
      return 0;
    }

  function _emscripten_glMatrixMode(){ throw 'Legacy GL function (glMatrixMode) called. If you want legacy GL emulation, you need to compile with -s LEGACY_GL_EMULATION=1 to enable legacy GL emulation.'; }

  function _glStencilFunc(x0, x1, x2) { GLctx['stencilFunc'](x0, x1, x2) }

  function _pthread_mutex_destroy() {}

  function _emscripten_glGetTexParameteriv(target, pname, params) {
      if (!params) {
        // GLES2 specification does not specify how to behave if params is a null pointer. Since calling this function does not make sense
        // if p == null, issue a GL error to notify user about it. 
        GL.recordError(0x0501 /* GL_INVALID_VALUE */);
        return;
      }
      HEAP32[((params)>>2)]=GLctx.getTexParameter(target, pname);
    }

  function _glGetString(name_) {
      if (GL.stringCache[name_]) return GL.stringCache[name_];
      var ret; 
      switch(name_) {
        case 0x1F00 /* GL_VENDOR */:
        case 0x1F01 /* GL_RENDERER */:
        case 0x9245 /* UNMASKED_VENDOR_WEBGL */:
        case 0x9246 /* UNMASKED_RENDERER_WEBGL */:
          ret = allocate(intArrayFromString(GLctx.getParameter(name_)), 'i8', ALLOC_NORMAL);
          break;
        case 0x1F02 /* GL_VERSION */:
          var glVersion = GLctx.getParameter(GLctx.VERSION);
          // return GLES version string corresponding to the version of the WebGL context
          {
            glVersion = 'OpenGL ES 2.0 (' + glVersion + ')';
          }
          ret = allocate(intArrayFromString(glVersion), 'i8', ALLOC_NORMAL);
          break;
        case 0x1F03 /* GL_EXTENSIONS */:
          var exts = GLctx.getSupportedExtensions();
          var gl_exts = [];
          for (var i = 0; i < exts.length; ++i) {
            gl_exts.push(exts[i]);
            gl_exts.push("GL_" + exts[i]);
          }
          ret = allocate(intArrayFromString(gl_exts.join(' ')), 'i8', ALLOC_NORMAL);
          break;
        case 0x8B8C /* GL_SHADING_LANGUAGE_VERSION */:
          var glslVersion = GLctx.getParameter(GLctx.SHADING_LANGUAGE_VERSION);
          // extract the version number 'N.M' from the string 'WebGL GLSL ES N.M ...'
          var ver_re = /^WebGL GLSL ES ([0-9]\.[0-9][0-9]?)(?:$| .*)/;
          var ver_num = glslVersion.match(ver_re);
          if (ver_num !== null) {
            if (ver_num[1].length == 3) ver_num[1] = ver_num[1] + '0'; // ensure minor version has 2 digits
            glslVersion = 'OpenGL ES GLSL ES ' + ver_num[1] + ' (' + glslVersion + ')';
          }
          ret = allocate(intArrayFromString(glslVersion), 'i8', ALLOC_NORMAL);
          break;
        default:
          GL.recordError(0x0500/*GL_INVALID_ENUM*/);
          return 0;
      }
      GL.stringCache[name_] = ret;
      return ret;
    }

  function _emscripten_glGenerateMipmap(x0) { GLctx['generateMipmap'](x0) }

  function _emscripten_glCullFace(x0) { GLctx['cullFace'](x0) }

  function _glDeleteTextures(n, textures) {
      for (var i = 0; i < n; i++) {
        var id = HEAP32[(((textures)+(i*4))>>2)];
        var texture = GL.textures[id];
        if (!texture) continue; // GL spec: "glDeleteTextures silently ignores 0s and names that do not correspond to existing textures".
        GLctx.deleteTexture(texture);
        texture.name = 0;
        GL.textures[id] = null;
      }
    }

  function _emscripten_glUseProgram(program) {
      GLctx.useProgram(program ? GL.programs[program] : null);
    }

  function _emscripten_glHint(x0, x1) { GLctx['hint'](x0, x1) }

  function _emscripten_glFramebufferTexture2D(target, attachment, textarget, texture, level) {
      GLctx.framebufferTexture2D(target, attachment, textarget,
                                      GL.textures[texture], level);
    }

  function _dlsym(handle, symbol) {
      // void *dlsym(void *restrict handle, const char *restrict name);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/dlsym.html
      symbol = Pointer_stringify(symbol);
  
      if (!DLFCN.loadedLibs[handle]) {
        DLFCN.errorMsg = 'Tried to dlsym() from an unopened handle: ' + handle;
        return 0;
      } else {
        var lib = DLFCN.loadedLibs[handle];
        symbol = '_' + symbol;
        if (lib.cached_functions.hasOwnProperty(symbol)) {
          return lib.cached_functions[symbol];
        }
        if (!lib.module.hasOwnProperty(symbol)) {
          DLFCN.errorMsg = ('Tried to lookup unknown symbol "' + symbol +
                                 '" in dynamic lib: ' + lib.name);
          return 0;
        } else {
          var result = lib.module[symbol];
          if (typeof result == 'function') {
            result = Runtime.addFunction(result);
            //Module.printErr('adding function dlsym result for ' + symbol + ' => ' + result);
            lib.cached_functions = result;
          }
          return result;
        }
      }
    }

  function _emscripten_glUniform2fv(location, count, value) {
  
  
      var view;
      if (2*count <= GL.MINI_TEMP_BUFFER_SIZE) {
        // avoid allocation when uploading few enough uniforms
        view = GL.miniTempBufferViews[2*count-1];
        for (var i = 0; i < 2*count; i += 2) {
          view[i] = HEAPF32[(((value)+(4*i))>>2)];
          view[i+1] = HEAPF32[(((value)+(4*i+4))>>2)];
        }
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*8)>>2);
      }
      GLctx.uniform2fv(GL.uniforms[location], view);
    }

  
  
  function __isLeapYear(year) {
        return year%4 === 0 && (year%100 !== 0 || year%400 === 0);
    }
  
  function __arraySum(array, index) {
      var sum = 0;
      for (var i = 0; i <= index; sum += array[i++]);
      return sum;
    }
  
  
  var __MONTH_DAYS_LEAP=[31,29,31,30,31,30,31,31,30,31,30,31];
  
  var __MONTH_DAYS_REGULAR=[31,28,31,30,31,30,31,31,30,31,30,31];function __addDays(date, days) {
      var newDate = new Date(date.getTime());
      while(days > 0) {
        var leap = __isLeapYear(newDate.getFullYear());
        var currentMonth = newDate.getMonth();
        var daysInCurrentMonth = (leap ? __MONTH_DAYS_LEAP : __MONTH_DAYS_REGULAR)[currentMonth];
  
        if (days > daysInCurrentMonth-newDate.getDate()) {
          // we spill over to next month
          days -= (daysInCurrentMonth-newDate.getDate()+1);
          newDate.setDate(1);
          if (currentMonth < 11) {
            newDate.setMonth(currentMonth+1)
          } else {
            newDate.setMonth(0);
            newDate.setFullYear(newDate.getFullYear()+1);
          }
        } else {
          // we stay in current month 
          newDate.setDate(newDate.getDate()+days);
          return newDate;
        }
      }
  
      return newDate;
    }function _strftime(s, maxsize, format, tm) {
      // size_t strftime(char *restrict s, size_t maxsize, const char *restrict format, const struct tm *restrict timeptr);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/strftime.html
  
      var tm_zone = HEAP32[(((tm)+(40))>>2)];
  
      var date = {
        tm_sec: HEAP32[((tm)>>2)],
        tm_min: HEAP32[(((tm)+(4))>>2)],
        tm_hour: HEAP32[(((tm)+(8))>>2)],
        tm_mday: HEAP32[(((tm)+(12))>>2)],
        tm_mon: HEAP32[(((tm)+(16))>>2)],
        tm_year: HEAP32[(((tm)+(20))>>2)],
        tm_wday: HEAP32[(((tm)+(24))>>2)],
        tm_yday: HEAP32[(((tm)+(28))>>2)],
        tm_isdst: HEAP32[(((tm)+(32))>>2)],
        tm_gmtoff: HEAP32[(((tm)+(36))>>2)],
        tm_zone: tm_zone ? Pointer_stringify(tm_zone) : ''
      };
  
      var pattern = Pointer_stringify(format);
  
      // expand format
      var EXPANSION_RULES_1 = {
        '%c': '%a %b %d %H:%M:%S %Y',     // Replaced by the locale's appropriate date and time representation - e.g., Mon Aug  3 14:02:01 2013
        '%D': '%m/%d/%y',                 // Equivalent to %m / %d / %y
        '%F': '%Y-%m-%d',                 // Equivalent to %Y - %m - %d
        '%h': '%b',                       // Equivalent to %b
        '%r': '%I:%M:%S %p',              // Replaced by the time in a.m. and p.m. notation
        '%R': '%H:%M',                    // Replaced by the time in 24-hour notation
        '%T': '%H:%M:%S',                 // Replaced by the time
        '%x': '%m/%d/%y',                 // Replaced by the locale's appropriate date representation
        '%X': '%H:%M:%S'                  // Replaced by the locale's appropriate date representation
      };
      for (var rule in EXPANSION_RULES_1) {
        pattern = pattern.replace(new RegExp(rule, 'g'), EXPANSION_RULES_1[rule]);
      }
  
      var WEEKDAYS = ['Sunday', 'Monday', 'Tuesday', 'Wednesday', 'Thursday', 'Friday', 'Saturday'];
      var MONTHS = ['January', 'February', 'March', 'April', 'May', 'June', 'July', 'August', 'September', 'October', 'November', 'December'];
  
      function leadingSomething(value, digits, character) {
        var str = typeof value === 'number' ? value.toString() : (value || '');
        while (str.length < digits) {
          str = character[0]+str;
        }
        return str;
      };
  
      function leadingNulls(value, digits) {
        return leadingSomething(value, digits, '0');
      };
  
      function compareByDay(date1, date2) {
        function sgn(value) {
          return value < 0 ? -1 : (value > 0 ? 1 : 0);
        };
  
        var compare;
        if ((compare = sgn(date1.getFullYear()-date2.getFullYear())) === 0) {
          if ((compare = sgn(date1.getMonth()-date2.getMonth())) === 0) {
            compare = sgn(date1.getDate()-date2.getDate());
          }
        }
        return compare;
      };
  
      function getFirstWeekStartDate(janFourth) {
          switch (janFourth.getDay()) {
            case 0: // Sunday
              return new Date(janFourth.getFullYear()-1, 11, 29);
            case 1: // Monday
              return janFourth;
            case 2: // Tuesday
              return new Date(janFourth.getFullYear(), 0, 3);
            case 3: // Wednesday
              return new Date(janFourth.getFullYear(), 0, 2);
            case 4: // Thursday
              return new Date(janFourth.getFullYear(), 0, 1);
            case 5: // Friday
              return new Date(janFourth.getFullYear()-1, 11, 31);
            case 6: // Saturday
              return new Date(janFourth.getFullYear()-1, 11, 30);
          }
      };
  
      function getWeekBasedYear(date) {
          var thisDate = __addDays(new Date(date.tm_year+1900, 0, 1), date.tm_yday);
  
          var janFourthThisYear = new Date(thisDate.getFullYear(), 0, 4);
          var janFourthNextYear = new Date(thisDate.getFullYear()+1, 0, 4);
  
          var firstWeekStartThisYear = getFirstWeekStartDate(janFourthThisYear);
          var firstWeekStartNextYear = getFirstWeekStartDate(janFourthNextYear);
  
          if (compareByDay(firstWeekStartThisYear, thisDate) <= 0) {
            // this date is after the start of the first week of this year
            if (compareByDay(firstWeekStartNextYear, thisDate) <= 0) {
              return thisDate.getFullYear()+1;
            } else {
              return thisDate.getFullYear();
            }
          } else { 
            return thisDate.getFullYear()-1;
          }
      };
  
      var EXPANSION_RULES_2 = {
        '%a': function(date) {
          return WEEKDAYS[date.tm_wday].substring(0,3);
        },
        '%A': function(date) {
          return WEEKDAYS[date.tm_wday];
        },
        '%b': function(date) {
          return MONTHS[date.tm_mon].substring(0,3);
        },
        '%B': function(date) {
          return MONTHS[date.tm_mon];
        },
        '%C': function(date) {
          var year = date.tm_year+1900;
          return leadingNulls((year/100)|0,2);
        },
        '%d': function(date) {
          return leadingNulls(date.tm_mday, 2);
        },
        '%e': function(date) {
          return leadingSomething(date.tm_mday, 2, ' ');
        },
        '%g': function(date) {
          // %g, %G, and %V give values according to the ISO 8601:2000 standard week-based year. 
          // In this system, weeks begin on a Monday and week 1 of the year is the week that includes 
          // January 4th, which is also the week that includes the first Thursday of the year, and 
          // is also the first week that contains at least four days in the year. 
          // If the first Monday of January is the 2nd, 3rd, or 4th, the preceding days are part of 
          // the last week of the preceding year; thus, for Saturday 2nd January 1999, 
          // %G is replaced by 1998 and %V is replaced by 53. If December 29th, 30th, 
          // or 31st is a Monday, it and any following days are part of week 1 of the following year. 
          // Thus, for Tuesday 30th December 1997, %G is replaced by 1998 and %V is replaced by 01.
          
          return getWeekBasedYear(date).toString().substring(2);
        },
        '%G': function(date) {
          return getWeekBasedYear(date);
        },
        '%H': function(date) {
          return leadingNulls(date.tm_hour, 2);
        },
        '%I': function(date) {
          var twelveHour = date.tm_hour;
          if (twelveHour == 0) twelveHour = 12;
          else if (twelveHour > 12) twelveHour -= 12;
          return leadingNulls(twelveHour, 2);
        },
        '%j': function(date) {
          // Day of the year (001-366)
          return leadingNulls(date.tm_mday+__arraySum(__isLeapYear(date.tm_year+1900) ? __MONTH_DAYS_LEAP : __MONTH_DAYS_REGULAR, date.tm_mon-1), 3);
        },
        '%m': function(date) {
          return leadingNulls(date.tm_mon+1, 2);
        },
        '%M': function(date) {
          return leadingNulls(date.tm_min, 2);
        },
        '%n': function() {
          return '\n';
        },
        '%p': function(date) {
          if (date.tm_hour >= 0 && date.tm_hour < 12) {
            return 'AM';
          } else {
            return 'PM';
          }
        },
        '%S': function(date) {
          return leadingNulls(date.tm_sec, 2);
        },
        '%t': function() {
          return '\t';
        },
        '%u': function(date) {
          var day = new Date(date.tm_year+1900, date.tm_mon+1, date.tm_mday, 0, 0, 0, 0);
          return day.getDay() || 7;
        },
        '%U': function(date) {
          // Replaced by the week number of the year as a decimal number [00,53]. 
          // The first Sunday of January is the first day of week 1; 
          // days in the new year before this are in week 0. [ tm_year, tm_wday, tm_yday]
          var janFirst = new Date(date.tm_year+1900, 0, 1);
          var firstSunday = janFirst.getDay() === 0 ? janFirst : __addDays(janFirst, 7-janFirst.getDay());
          var endDate = new Date(date.tm_year+1900, date.tm_mon, date.tm_mday);
          
          // is target date after the first Sunday?
          if (compareByDay(firstSunday, endDate) < 0) {
            // calculate difference in days between first Sunday and endDate
            var februaryFirstUntilEndMonth = __arraySum(__isLeapYear(endDate.getFullYear()) ? __MONTH_DAYS_LEAP : __MONTH_DAYS_REGULAR, endDate.getMonth()-1)-31;
            var firstSundayUntilEndJanuary = 31-firstSunday.getDate();
            var days = firstSundayUntilEndJanuary+februaryFirstUntilEndMonth+endDate.getDate();
            return leadingNulls(Math.ceil(days/7), 2);
          }
  
          return compareByDay(firstSunday, janFirst) === 0 ? '01': '00';
        },
        '%V': function(date) {
          // Replaced by the week number of the year (Monday as the first day of the week) 
          // as a decimal number [01,53]. If the week containing 1 January has four 
          // or more days in the new year, then it is considered week 1. 
          // Otherwise, it is the last week of the previous year, and the next week is week 1. 
          // Both January 4th and the first Thursday of January are always in week 1. [ tm_year, tm_wday, tm_yday]
          var janFourthThisYear = new Date(date.tm_year+1900, 0, 4);
          var janFourthNextYear = new Date(date.tm_year+1901, 0, 4);
  
          var firstWeekStartThisYear = getFirstWeekStartDate(janFourthThisYear);
          var firstWeekStartNextYear = getFirstWeekStartDate(janFourthNextYear);
  
          var endDate = __addDays(new Date(date.tm_year+1900, 0, 1), date.tm_yday);
  
          if (compareByDay(endDate, firstWeekStartThisYear) < 0) {
            // if given date is before this years first week, then it belongs to the 53rd week of last year
            return '53';
          } 
  
          if (compareByDay(firstWeekStartNextYear, endDate) <= 0) {
            // if given date is after next years first week, then it belongs to the 01th week of next year
            return '01';
          }
  
          // given date is in between CW 01..53 of this calendar year
          var daysDifference;
          if (firstWeekStartThisYear.getFullYear() < date.tm_year+1900) {
            // first CW of this year starts last year
            daysDifference = date.tm_yday+32-firstWeekStartThisYear.getDate()
          } else {
            // first CW of this year starts this year
            daysDifference = date.tm_yday+1-firstWeekStartThisYear.getDate();
          }
          return leadingNulls(Math.ceil(daysDifference/7), 2);
        },
        '%w': function(date) {
          var day = new Date(date.tm_year+1900, date.tm_mon+1, date.tm_mday, 0, 0, 0, 0);
          return day.getDay();
        },
        '%W': function(date) {
          // Replaced by the week number of the year as a decimal number [00,53]. 
          // The first Monday of January is the first day of week 1; 
          // days in the new year before this are in week 0. [ tm_year, tm_wday, tm_yday]
          var janFirst = new Date(date.tm_year, 0, 1);
          var firstMonday = janFirst.getDay() === 1 ? janFirst : __addDays(janFirst, janFirst.getDay() === 0 ? 1 : 7-janFirst.getDay()+1);
          var endDate = new Date(date.tm_year+1900, date.tm_mon, date.tm_mday);
  
          // is target date after the first Monday?
          if (compareByDay(firstMonday, endDate) < 0) {
            var februaryFirstUntilEndMonth = __arraySum(__isLeapYear(endDate.getFullYear()) ? __MONTH_DAYS_LEAP : __MONTH_DAYS_REGULAR, endDate.getMonth()-1)-31;
            var firstMondayUntilEndJanuary = 31-firstMonday.getDate();
            var days = firstMondayUntilEndJanuary+februaryFirstUntilEndMonth+endDate.getDate();
            return leadingNulls(Math.ceil(days/7), 2);
          }
          return compareByDay(firstMonday, janFirst) === 0 ? '01': '00';
        },
        '%y': function(date) {
          // Replaced by the last two digits of the year as a decimal number [00,99]. [ tm_year]
          return (date.tm_year+1900).toString().substring(2);
        },
        '%Y': function(date) {
          // Replaced by the year as a decimal number (for example, 1997). [ tm_year]
          return date.tm_year+1900;
        },
        '%z': function(date) {
          // Replaced by the offset from UTC in the ISO 8601:2000 standard format ( +hhmm or -hhmm ).
          // For example, "-0430" means 4 hours 30 minutes behind UTC (west of Greenwich).
          var off = date.tm_gmtoff;
          var ahead = off >= 0;
          off = Math.abs(off) / 60;
          // convert from minutes into hhmm format (which means 60 minutes = 100 units)
          off = (off / 60)*100 + (off % 60);
          return (ahead ? '+' : '-') + String("0000" + off).slice(-4);
        },
        '%Z': function(date) {
          return date.tm_zone;
        },
        '%%': function() {
          return '%';
        }
      };
      for (var rule in EXPANSION_RULES_2) {
        if (pattern.indexOf(rule) >= 0) {
          pattern = pattern.replace(new RegExp(rule, 'g'), EXPANSION_RULES_2[rule](date));
        }
      }
  
      var bytes = intArrayFromString(pattern, false);
      if (bytes.length > maxsize) {
        return 0;
      } 
  
      writeArrayToMemory(bytes, s);
      return bytes.length-1;
    }function _strftime_l(s, maxsize, format, tm) {
      return _strftime(s, maxsize, format, tm); // no locale support yet
    }

  function _abort() {
      Module['abort']();
    }

  function _emscripten_glVertexAttribDivisor(index, divisor) {
      GLctx['vertexAttribDivisor'](index, divisor);
    }

  function _emscripten_glFramebufferRenderbuffer(target, attachment, renderbuffertarget, renderbuffer) {
      GLctx.framebufferRenderbuffer(target, attachment, renderbuffertarget,
                                         GL.renderbuffers[renderbuffer]);
    }

  function _emscripten_glPolygonOffset(x0, x1) { GLctx['polygonOffset'](x0, x1) }

  function _emscripten_glIsBuffer(buffer) {
      var b = GL.buffers[buffer];
      if (!b) return 0;
      return GLctx.isBuffer(b);
    }

  function _emscripten_glUniform2iv(location, count, value) {
  
  
      GLctx.uniform2iv(GL.uniforms[location], HEAP32.subarray((value)>>2,(value+count*8)>>2));
    }

  
  var PTHREAD_SPECIFIC={};function _pthread_getspecific(key) {
      return PTHREAD_SPECIFIC[key] || 0;
    }

  function _emscripten_glVertexAttrib1fv(index, v) {
  
      GLctx.vertexAttrib1f(index, HEAPF32[v>>2]);
    }

  function _glEnable(x0) { GLctx['enable'](x0) }

  function _llvm_exp2_f32(x) {
      return Math.pow(2, x);
    }

  function _emscripten_glTexSubImage2D(target, level, xoffset, yoffset, width, height, format, type, pixels) {
      var pixelData = null;
      if (pixels) pixelData = emscriptenWebGLGetTexPixelData(type, format, width, height, pixels, 0);
      GLctx.texSubImage2D(target, level, xoffset, yoffset, width, height, format, type, pixelData);
    }

  var _emscripten_asm_const_int=true;

  function _emscripten_glUniform2f(location, v0, v1) {
      GLctx.uniform2f(GL.uniforms[location], v0, v1);
    }

  function _emscripten_glBindVertexArray(vao) {
      GLctx['bindVertexArray'](GL.vaos[vao]);
    }

  function _emscripten_glUniform2i(location, v0, v1) {
      GLctx.uniform2i(GL.uniforms[location], v0, v1);
    }

  function _glBlendFunc(x0, x1) { GLctx['blendFunc'](x0, x1) }

  function _emscripten_glDeleteRenderbuffers(n, renderbuffers) {
      for (var i = 0; i < n; i++) {
        var id = HEAP32[(((renderbuffers)+(i*4))>>2)];
        var renderbuffer = GL.renderbuffers[id];
        if (!renderbuffer) continue; // GL spec: "glDeleteRenderbuffers silently ignores 0s and names that do not correspond to existing renderbuffer objects".
        GLctx.deleteRenderbuffer(renderbuffer);
        renderbuffer.name = 0;
        GL.renderbuffers[id] = null;
      }
    }

  function ___cxa_pure_virtual() {
      ABORT = true;
      throw 'Pure virtual function called!';
    }

  
  function emscriptenWebGLGetUniform(program, location, params, type) {
      if (!params) {
        // GLES2 specification does not specify how to behave if params is a null pointer. Since calling this function does not make sense
        // if params == null, issue a GL error to notify user about it. 
        GL.recordError(0x0501 /* GL_INVALID_VALUE */);
        return;
      }
      var data = GLctx.getUniform(GL.programs[program], GL.uniforms[location]);
      if (typeof data == 'number' || typeof data == 'boolean') {
        switch (type) {
          case 'Integer': HEAP32[((params)>>2)]=data; break;
          case 'Float': HEAPF32[((params)>>2)]=data; break;
          default: throw 'internal emscriptenWebGLGetUniform() error, bad type: ' + type;
        }
      } else {
        for (var i = 0; i < data.length; i++) {
          switch (type) {
            case 'Integer': HEAP32[(((params)+(i*4))>>2)]=data[i]; break;
            case 'Float': HEAPF32[(((params)+(i*4))>>2)]=data[i]; break;
            default: throw 'internal emscriptenWebGLGetUniform() error, bad type: ' + type;
          }
        }
      }
    }function _emscripten_glGetUniformiv(program, location, params) {
      emscriptenWebGLGetUniform(program, location, params, 'Integer');
    }

  function _pthread_cond_wait() { return 0; }

  function _emscripten_set_mousedown_callback(target, userData, useCapture, callbackfunc) {
      JSEvents.registerMouseEventCallback(target, userData, useCapture, callbackfunc, 5, "mousedown");
      return 0;
    }

  function _emscripten_glDepthRange(x0, x1) { GLctx['depthRange'](x0, x1) }

  function _emscripten_set_fullscreenchange_callback(target, userData, useCapture, callbackfunc) {
      if (typeof JSEvents.fullscreenEnabled() === 'undefined') return -1;
      if (!target) target = document;
      else {
        target = JSEvents.findEventTarget(target);
        if (!target) return -4;
      }
      JSEvents.registerFullscreenChangeEventCallback(target, userData, useCapture, callbackfunc, 19, "fullscreenchange");
      JSEvents.registerFullscreenChangeEventCallback(target, userData, useCapture, callbackfunc, 19, "mozfullscreenchange");
      JSEvents.registerFullscreenChangeEventCallback(target, userData, useCapture, callbackfunc, 19, "webkitfullscreenchange");
      JSEvents.registerFullscreenChangeEventCallback(target, userData, useCapture, callbackfunc, 19, "msfullscreenchange");
      return 0;
    }

  function _pthread_join() {}

  function ___syscall140(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // llseek
      var stream = SYSCALLS.getStreamFromFD(), offset_high = SYSCALLS.get(), offset_low = SYSCALLS.get(), result = SYSCALLS.get(), whence = SYSCALLS.get();
      // NOTE: offset_high is unused - Emscripten's off_t is 32-bit
      var offset = offset_low;
      FS.llseek(stream, offset, whence);
      HEAP32[((result)>>2)]=stream.position;
      if (stream.getdents && offset === 0 && whence === 0) stream.getdents = null; // reset readdir state
      return 0;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  
    

  function _emscripten_glGetShaderPrecisionFormat(shaderType, precisionType, range, precision) {
      var result = GLctx.getShaderPrecisionFormat(shaderType, precisionType);
      HEAP32[((range)>>2)]=result.rangeMin;
      HEAP32[(((range)+(4))>>2)]=result.rangeMax;
      HEAP32[((precision)>>2)]=result.precision;
    }

  function _emscripten_glUniform1fv(location, count, value) {
  
  
      var view;
      if (count <= GL.MINI_TEMP_BUFFER_SIZE) {
        // avoid allocation when uploading few enough uniforms
        view = GL.miniTempBufferViews[count-1];
        for (var i = 0; i < count; ++i) {
          view[i] = HEAPF32[(((value)+(4*i))>>2)];
        }
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*4)>>2);
      }
      GLctx.uniform1fv(GL.uniforms[location], view);
    }

  function _emscripten_set_wheel_callback(target, userData, useCapture, callbackfunc) {
      target = JSEvents.findEventTarget(target);
      if (typeof target.onwheel !== 'undefined') {
        JSEvents.registerWheelEventCallback(target, userData, useCapture, callbackfunc, 9, "wheel");
        return 0;
      } else if (typeof target.onmousewheel !== 'undefined') {
        JSEvents.registerWheelEventCallback(target, userData, useCapture, callbackfunc, 9, "mousewheel");
        return 0;
      } else {
        return -1;
      }
    }

  function _emscripten_set_gamepaddisconnected_callback(userData, useCapture, callbackfunc) {
      if (!navigator.getGamepads && !navigator.webkitGetGamepads) return -1;
      JSEvents.registerGamepadEventCallback(window, userData, useCapture, callbackfunc, 27, "gamepaddisconnected");
      return 0;
   }

  function _glScissor(x0, x1, x2, x3) { GLctx['scissor'](x0, x1, x2, x3) }

  function _emscripten_set_mouseenter_callback(target, userData, useCapture, callbackfunc) {
      JSEvents.registerMouseEventCallback(target, userData, useCapture, callbackfunc, 33, "mouseenter");
      return 0;
    }

  function _emscripten_glBindProgramARB() {
  Module['printErr']('missing function: emscripten_glBindProgramARB'); abort(-1);
  }

  function _emscripten_glCheckFramebufferStatus(x0) { return GLctx['checkFramebufferStatus'](x0) }

  function _emscripten_glDeleteProgram(id) {
      if (!id) return;
      var program = GL.programs[id];
      if (!program) { // glDeleteProgram actually signals an error when deleting a nonexisting object, unlike some other GL delete functions.
        GL.recordError(0x0501 /* GL_INVALID_VALUE */);
        return;
      }
      GLctx.deleteProgram(program);
      program.name = 0;
      GL.programs[id] = null;
      GL.programInfos[id] = null;
    }

  function _emscripten_glDisable(x0) { GLctx['disable'](x0) }

  function _emscripten_glVertexAttrib3fv(index, v) {
  
      GLctx.vertexAttrib3f(index, HEAPF32[v>>2], HEAPF32[v+4>>2], HEAPF32[v+8>>2]);
    }

  function _glFlush() { GLctx['flush']() }

  function _glClearColor(x0, x1, x2, x3) { GLctx['clearColor'](x0, x1, x2, x3) }

  function _emscripten_glGetActiveAttrib(program, index, bufSize, length, size, type, name) {
      program = GL.programs[program];
      var info = GLctx.getActiveAttrib(program, index);
      if (!info) return; // If an error occurs, nothing will be written to length, size and type and name.
  
      if (bufSize > 0 && name) {
        var numBytesWrittenExclNull = stringToUTF8(info.name, name, bufSize);
        if (length) HEAP32[((length)>>2)]=numBytesWrittenExclNull;
      } else {
        if (length) HEAP32[((length)>>2)]=0;
      }
  
      if (size) HEAP32[((size)>>2)]=info.size;
      if (type) HEAP32[((type)>>2)]=info.type;
    }

  function _emscripten_glIsFramebuffer(framebuffer) {
      var fb = GL.framebuffers[framebuffer];
      if (!fb) return 0;
      return GLctx.isFramebuffer(fb);
    }

  function _emscripten_glLineWidth(x0) { GLctx['lineWidth'](x0) }

  function _emscripten_glGetString(name_) {
      if (GL.stringCache[name_]) return GL.stringCache[name_];
      var ret; 
      switch(name_) {
        case 0x1F00 /* GL_VENDOR */:
        case 0x1F01 /* GL_RENDERER */:
        case 0x9245 /* UNMASKED_VENDOR_WEBGL */:
        case 0x9246 /* UNMASKED_RENDERER_WEBGL */:
          ret = allocate(intArrayFromString(GLctx.getParameter(name_)), 'i8', ALLOC_NORMAL);
          break;
        case 0x1F02 /* GL_VERSION */:
          var glVersion = GLctx.getParameter(GLctx.VERSION);
          // return GLES version string corresponding to the version of the WebGL context
          {
            glVersion = 'OpenGL ES 2.0 (' + glVersion + ')';
          }
          ret = allocate(intArrayFromString(glVersion), 'i8', ALLOC_NORMAL);
          break;
        case 0x1F03 /* GL_EXTENSIONS */:
          var exts = GLctx.getSupportedExtensions();
          var gl_exts = [];
          for (var i = 0; i < exts.length; ++i) {
            gl_exts.push(exts[i]);
            gl_exts.push("GL_" + exts[i]);
          }
          ret = allocate(intArrayFromString(gl_exts.join(' ')), 'i8', ALLOC_NORMAL);
          break;
        case 0x8B8C /* GL_SHADING_LANGUAGE_VERSION */:
          var glslVersion = GLctx.getParameter(GLctx.SHADING_LANGUAGE_VERSION);
          // extract the version number 'N.M' from the string 'WebGL GLSL ES N.M ...'
          var ver_re = /^WebGL GLSL ES ([0-9]\.[0-9][0-9]?)(?:$| .*)/;
          var ver_num = glslVersion.match(ver_re);
          if (ver_num !== null) {
            if (ver_num[1].length == 3) ver_num[1] = ver_num[1] + '0'; // ensure minor version has 2 digits
            glslVersion = 'OpenGL ES GLSL ES ' + ver_num[1] + ' (' + glslVersion + ')';
          }
          ret = allocate(intArrayFromString(glslVersion), 'i8', ALLOC_NORMAL);
          break;
        default:
          GL.recordError(0x0500/*GL_INVALID_ENUM*/);
          return 0;
      }
      GL.stringCache[name_] = ret;
      return ret;
    }

  function ___syscall195(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // SYS_stat64
      var path = SYSCALLS.getStr(), buf = SYSCALLS.get();
      return SYSCALLS.doStat(FS.stat, path, buf);
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function _eglDestroySurface(display, surface) { 
      if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0; 
      }
      if (surface != 62006 /* Magic ID for the only EGLSurface supported by Emscripten */) {
        EGL.setErrorCode(0x300D /* EGL_BAD_SURFACE */);
        return 1;
      }
      if (EGL.currentReadSurface == surface) {
        EGL.currentReadSurface = 0;
      }
      if (EGL.currentDrawSurface == surface) {
        EGL.currentDrawSurface = 0;
      }
      EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
      return 1; /* Magic ID for Emscripten 'default surface' */
    }

  function ___syscall197(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // SYS_fstat64
      var stream = SYSCALLS.getStreamFromFD(), buf = SYSCALLS.get();
      return SYSCALLS.doStat(FS.stat, stream.path, buf);
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function _emscripten_glGetAttribLocation(program, name) {
      program = GL.programs[program];
      name = Pointer_stringify(name);
      return GLctx.getAttribLocation(program, name);
    }

  function _emscripten_glRotatef() {
  Module['printErr']('missing function: emscripten_glRotatef'); abort(-1);
  }

  
  function emscriptenWebGLGet(name_, p, type) {
      // Guard against user passing a null pointer.
      // Note that GLES2 spec does not say anything about how passing a null pointer should be treated.
      // Testing on desktop core GL 3, the application crashes on glGetIntegerv to a null pointer, but
      // better to report an error instead of doing anything random.
      if (!p) {
        GL.recordError(0x0501 /* GL_INVALID_VALUE */);
        return;
      }
      var ret = undefined;
      switch(name_) { // Handle a few trivial GLES values
        case 0x8DFA: // GL_SHADER_COMPILER
          ret = 1;
          break;
        case 0x8DF8: // GL_SHADER_BINARY_FORMATS
          if (type !== 'Integer' && type !== 'Integer64') {
            GL.recordError(0x0500); // GL_INVALID_ENUM
          }
          return; // Do not write anything to the out pointer, since no binary formats are supported.
        case 0x8DF9: // GL_NUM_SHADER_BINARY_FORMATS
          ret = 0;
          break;
        case 0x86A2: // GL_NUM_COMPRESSED_TEXTURE_FORMATS
          // WebGL doesn't have GL_NUM_COMPRESSED_TEXTURE_FORMATS (it's obsolete since GL_COMPRESSED_TEXTURE_FORMATS returns a JS array that can be queried for length),
          // so implement it ourselves to allow C++ GLES2 code get the length.
          var formats = GLctx.getParameter(0x86A3 /*GL_COMPRESSED_TEXTURE_FORMATS*/);
          ret = formats.length;
          break;
      }
  
      if (ret === undefined) {
        var result = GLctx.getParameter(name_);
        switch (typeof(result)) {
          case "number":
            ret = result;
            break;
          case "boolean":
            ret = result ? 1 : 0;
            break;
          case "string":
            GL.recordError(0x0500); // GL_INVALID_ENUM
            return;
          case "object":
            if (result === null) {
              // null is a valid result for some (e.g., which buffer is bound - perhaps nothing is bound), but otherwise
              // can mean an invalid name_, which we need to report as an error
              switch(name_) {
                case 0x8894: // ARRAY_BUFFER_BINDING
                case 0x8B8D: // CURRENT_PROGRAM
                case 0x8895: // ELEMENT_ARRAY_BUFFER_BINDING
                case 0x8CA6: // FRAMEBUFFER_BINDING
                case 0x8CA7: // RENDERBUFFER_BINDING
                case 0x8069: // TEXTURE_BINDING_2D
                case 0x8514: { // TEXTURE_BINDING_CUBE_MAP
                  ret = 0;
                  break;
                }
                default: {
                  GL.recordError(0x0500); // GL_INVALID_ENUM
                  return;
                }
              }
            } else if (result instanceof Float32Array ||
                       result instanceof Uint32Array ||
                       result instanceof Int32Array ||
                       result instanceof Array) {
              for (var i = 0; i < result.length; ++i) {
                switch (type) {
                  case 'Integer': HEAP32[(((p)+(i*4))>>2)]=result[i];   break;
                  case 'Float':   HEAPF32[(((p)+(i*4))>>2)]=result[i]; break;
                  case 'Boolean': HEAP8[(((p)+(i))>>0)]=result[i] ? 1 : 0;    break;
                  default: throw 'internal glGet error, bad type: ' + type;
                }
              }
              return;
            } else if (result instanceof WebGLBuffer ||
                       result instanceof WebGLProgram ||
                       result instanceof WebGLFramebuffer ||
                       result instanceof WebGLRenderbuffer ||
                       result instanceof WebGLTexture) {
              ret = result.name | 0;
            } else {
              GL.recordError(0x0500); // GL_INVALID_ENUM
              return;
            }
            break;
          default:
            GL.recordError(0x0500); // GL_INVALID_ENUM
            return;
        }
      }
  
      switch (type) {
        case 'Integer64': (tempI64 = [ret>>>0,(tempDouble=ret,(+(Math_abs(tempDouble))) >= 1.0 ? (tempDouble > 0.0 ? ((Math_min((+(Math_floor((tempDouble)/4294967296.0))), 4294967295.0))|0)>>>0 : (~~((+(Math_ceil((tempDouble - +(((~~(tempDouble)))>>>0))/4294967296.0)))))>>>0) : 0)],HEAP32[((p)>>2)]=tempI64[0],HEAP32[(((p)+(4))>>2)]=tempI64[1]);    break;
        case 'Integer': HEAP32[((p)>>2)]=ret;    break;
        case 'Float':   HEAPF32[((p)>>2)]=ret;  break;
        case 'Boolean': HEAP8[((p)>>0)]=ret ? 1 : 0; break;
        default: throw 'internal glGet error, bad type: ' + type;
      }
    }function _emscripten_glGetIntegerv(name_, p) {
      emscriptenWebGLGet(name_, p, 'Integer');
    }

  function _emscripten_glGetFramebufferAttachmentParameteriv(target, attachment, pname, params) {
      var result = GLctx.getFramebufferAttachmentParameter(target, attachment, pname);
      HEAP32[((params)>>2)]=result;
    }

  function _emscripten_glClientActiveTexture() {
  Module['printErr']('missing function: emscripten_glClientActiveTexture'); abort(-1);
  }

  function _emscripten_set_focus_callback(target, userData, useCapture, callbackfunc) {
      JSEvents.registerFocusEventCallback(target, userData, useCapture, callbackfunc, 13, "focus");
      return 0;
    }

  
  function _emscripten_memcpy_big(dest, src, num) {
      HEAPU8.set(HEAPU8.subarray(src, src+num), dest);
      return dest;
    } 

  function _emscripten_glGetShaderInfoLog(shader, maxLength, length, infoLog) {
      var log = GLctx.getShaderInfoLog(GL.shaders[shader]);
      if (log === null) log = '(unknown error)';
      if (maxLength > 0 && infoLog) {
        var numBytesWrittenExclNull = stringToUTF8(log, infoLog, maxLength);
        if (length) HEAP32[((length)>>2)]=numBytesWrittenExclNull;
      } else {
        if (length) HEAP32[((length)>>2)]=0;
      }
    }

  function _emscripten_set_mouseup_callback(target, userData, useCapture, callbackfunc) {
      JSEvents.registerMouseEventCallback(target, userData, useCapture, callbackfunc, 6, "mouseup");
      return 0;
    }

  function _emscripten_glStencilOpSeparate(x0, x1, x2, x3) { GLctx['stencilOpSeparate'](x0, x1, x2, x3) }

  
  
  var GLUT={initTime:null,idleFunc:null,displayFunc:null,keyboardFunc:null,keyboardUpFunc:null,specialFunc:null,specialUpFunc:null,reshapeFunc:null,motionFunc:null,passiveMotionFunc:null,mouseFunc:null,buttons:0,modifiers:0,initWindowWidth:256,initWindowHeight:256,initDisplayMode:18,windowX:0,windowY:0,windowWidth:0,windowHeight:0,requestedAnimationFrame:false,saveModifiers:function (event) {
        GLUT.modifiers = 0;
        if (event['shiftKey'])
          GLUT.modifiers += 1; /* GLUT_ACTIVE_SHIFT */
        if (event['ctrlKey'])
          GLUT.modifiers += 2; /* GLUT_ACTIVE_CTRL */
        if (event['altKey'])
          GLUT.modifiers += 4; /* GLUT_ACTIVE_ALT */
      },onMousemove:function (event) {
        /* Send motion event only if the motion changed, prevents
         * spamming our app with uncessary callback call. It does happen in
         * Chrome on Windows.
         */
        var lastX = Browser.mouseX;
        var lastY = Browser.mouseY;
        Browser.calculateMouseEvent(event);
        var newX = Browser.mouseX;
        var newY = Browser.mouseY;
        if (newX == lastX && newY == lastY) return;
  
        if (GLUT.buttons == 0 && event.target == Module["canvas"] && GLUT.passiveMotionFunc) {
          event.preventDefault();
          GLUT.saveModifiers(event);
          Module['dynCall_vii'](GLUT.passiveMotionFunc, lastX, lastY);
        } else if (GLUT.buttons != 0 && GLUT.motionFunc) {
          event.preventDefault();
          GLUT.saveModifiers(event);
          Module['dynCall_vii'](GLUT.motionFunc, lastX, lastY);
        }
      },getSpecialKey:function (keycode) {
          var key = null;
          switch (keycode) {
            case 8:  key = 120 /* backspace */; break;
            case 46: key = 111 /* delete */; break;
  
            case 0x70 /*DOM_VK_F1*/: key = 1 /* GLUT_KEY_F1 */; break;
            case 0x71 /*DOM_VK_F2*/: key = 2 /* GLUT_KEY_F2 */; break;
            case 0x72 /*DOM_VK_F3*/: key = 3 /* GLUT_KEY_F3 */; break;
            case 0x73 /*DOM_VK_F4*/: key = 4 /* GLUT_KEY_F4 */; break;
            case 0x74 /*DOM_VK_F5*/: key = 5 /* GLUT_KEY_F5 */; break;
            case 0x75 /*DOM_VK_F6*/: key = 6 /* GLUT_KEY_F6 */; break;
            case 0x76 /*DOM_VK_F7*/: key = 7 /* GLUT_KEY_F7 */; break;
            case 0x77 /*DOM_VK_F8*/: key = 8 /* GLUT_KEY_F8 */; break;
            case 0x78 /*DOM_VK_F9*/: key = 9 /* GLUT_KEY_F9 */; break;
            case 0x79 /*DOM_VK_F10*/: key = 10 /* GLUT_KEY_F10 */; break;
            case 0x7a /*DOM_VK_F11*/: key = 11 /* GLUT_KEY_F11 */; break;
            case 0x7b /*DOM_VK_F12*/: key = 12 /* GLUT_KEY_F12 */; break;
            case 0x25 /*DOM_VK_LEFT*/: key = 100 /* GLUT_KEY_LEFT */; break;
            case 0x26 /*DOM_VK_UP*/: key = 101 /* GLUT_KEY_UP */; break;
            case 0x27 /*DOM_VK_RIGHT*/: key = 102 /* GLUT_KEY_RIGHT */; break;
            case 0x28 /*DOM_VK_DOWN*/: key = 103 /* GLUT_KEY_DOWN */; break;
            case 0x21 /*DOM_VK_PAGE_UP*/: key = 104 /* GLUT_KEY_PAGE_UP */; break;
            case 0x22 /*DOM_VK_PAGE_DOWN*/: key = 105 /* GLUT_KEY_PAGE_DOWN */; break;
            case 0x24 /*DOM_VK_HOME*/: key = 106 /* GLUT_KEY_HOME */; break;
            case 0x23 /*DOM_VK_END*/: key = 107 /* GLUT_KEY_END */; break;
            case 0x2d /*DOM_VK_INSERT*/: key = 108 /* GLUT_KEY_INSERT */; break;
  
            case 16   /*DOM_VK_SHIFT*/:
            case 0x05 /*DOM_VK_LEFT_SHIFT*/:
              key = 112 /* GLUT_KEY_SHIFT_L */;
              break;
            case 0x06 /*DOM_VK_RIGHT_SHIFT*/:
              key = 113 /* GLUT_KEY_SHIFT_R */;
              break;
  
            case 17   /*DOM_VK_CONTROL*/:
            case 0x03 /*DOM_VK_LEFT_CONTROL*/:
              key = 114 /* GLUT_KEY_CONTROL_L */;
              break;
            case 0x04 /*DOM_VK_RIGHT_CONTROL*/:
              key = 115 /* GLUT_KEY_CONTROL_R */;
              break;
  
            case 18   /*DOM_VK_ALT*/:
            case 0x02 /*DOM_VK_LEFT_ALT*/:
              key = 116 /* GLUT_KEY_ALT_L */;
              break;
            case 0x01 /*DOM_VK_RIGHT_ALT*/:
              key = 117 /* GLUT_KEY_ALT_R */;
              break;
          };
          return key;
      },getASCIIKey:function (event) {
        if (event['ctrlKey'] || event['altKey'] || event['metaKey']) return null;
  
        var keycode = event['keyCode'];
  
        /* The exact list is soooo hard to find in a canonical place! */
  
        if (48 <= keycode && keycode <= 57)
          return keycode; // numeric  TODO handle shift?
        if (65 <= keycode && keycode <= 90)
          return event['shiftKey'] ? keycode : keycode + 32;
        if (96 <= keycode && keycode <= 105)
          return keycode - 48; // numpad numbers    
        if (106 <= keycode && keycode <= 111)
          return keycode - 106 + 42; // *,+-./  TODO handle shift?
  
        switch (keycode) {
          case 9:  // tab key
          case 13: // return key
          case 27: // escape
          case 32: // space
          case 61: // equal
            return keycode;
        }
  
        var s = event['shiftKey'];
        switch (keycode) {
          case 186: return s ? 58 : 59; // colon / semi-colon
          case 187: return s ? 43 : 61; // add / equal (these two may be wrong)
          case 188: return s ? 60 : 44; // less-than / comma
          case 189: return s ? 95 : 45; // dash
          case 190: return s ? 62 : 46; // greater-than / period
          case 191: return s ? 63 : 47; // forward slash
          case 219: return s ? 123 : 91; // open bracket
          case 220: return s ? 124 : 47; // back slash
          case 221: return s ? 125 : 93; // close braket
          case 222: return s ? 34 : 39; // single quote
        }
  
        return null;
      },onKeydown:function (event) {
        if (GLUT.specialFunc || GLUT.keyboardFunc) {
          var key = GLUT.getSpecialKey(event['keyCode']);
          if (key !== null) {
            if( GLUT.specialFunc ) {
              event.preventDefault();
              GLUT.saveModifiers(event);
              Module['dynCall_viii'](GLUT.specialFunc, key, Browser.mouseX, Browser.mouseY);
            }
          }
          else
          {
            key = GLUT.getASCIIKey(event);
            if( key !== null && GLUT.keyboardFunc ) {
              event.preventDefault();
              GLUT.saveModifiers(event);
              Module['dynCall_viii'](GLUT.keyboardFunc, key, Browser.mouseX, Browser.mouseY);
            }
          }
        }
      },onKeyup:function (event) {
        if (GLUT.specialUpFunc || GLUT.keyboardUpFunc) {
          var key = GLUT.getSpecialKey(event['keyCode']);
          if (key !== null) {
            if(GLUT.specialUpFunc) {
              event.preventDefault ();
              GLUT.saveModifiers(event);
              Module['dynCall_viii'](GLUT.specialUpFunc, key, Browser.mouseX, Browser.mouseY);
            }
          }
          else
          {
            key = GLUT.getASCIIKey(event);
            if( key !== null && GLUT.keyboardUpFunc ) {
              event.preventDefault ();
              GLUT.saveModifiers(event);
              Module['dynCall_viii'](GLUT.keyboardUpFunc, key, Browser.mouseX, Browser.mouseY);
            }
          }
        }
      },touchHandler:function (event) {
        if (event.target != Module['canvas']) {
          return;
        }
  
        var touches = event.changedTouches,
            main = touches[0],
            type = "";
  
        switch(event.type) {
          case "touchstart": type = "mousedown"; break;
          case "touchmove": type = "mousemove"; break;
          case "touchend": type = "mouseup"; break;
          default: return;
        }
  
        var simulatedEvent = document.createEvent("MouseEvent");
        simulatedEvent.initMouseEvent(type, true, true, window, 1, 
                                      main.screenX, main.screenY, 
                                      main.clientX, main.clientY, false, 
                                      false, false, false, 0/*main*/, null);
  
        main.target.dispatchEvent(simulatedEvent);
        event.preventDefault();
      },onMouseButtonDown:function (event) {
        Browser.calculateMouseEvent(event);
  
        GLUT.buttons |= (1 << event['button']);
  
        if (event.target == Module["canvas"] && GLUT.mouseFunc) {
          try {
            event.target.setCapture();
          } catch (e) {}
          event.preventDefault();
          GLUT.saveModifiers(event);
          Module['dynCall_viiii'](GLUT.mouseFunc, event['button'], 0/*GLUT_DOWN*/, Browser.mouseX, Browser.mouseY);
        }
      },onMouseButtonUp:function (event) {
        Browser.calculateMouseEvent(event);
  
        GLUT.buttons &= ~(1 << event['button']);
  
        if (GLUT.mouseFunc) {
          event.preventDefault();
          GLUT.saveModifiers(event);
          Module['dynCall_viiii'](GLUT.mouseFunc, event['button'], 1/*GLUT_UP*/, Browser.mouseX, Browser.mouseY);
        }
      },onMouseWheel:function (event) {
        Browser.calculateMouseEvent(event);
  
        // cross-browser wheel delta
        var e = window.event || event; // old IE support
        // Note the minus sign that flips browser wheel direction (positive direction scrolls page down) to native wheel direction (positive direction is mouse wheel up)
        var delta = -Browser.getMouseWheelDelta(event);
        delta = (delta == 0) ? 0 : (delta > 0 ? Math.max(delta, 1) : Math.min(delta, -1)); // Quantize to integer so that minimum scroll is at least +/- 1.
  
        var button = 3; // wheel up
        if (delta < 0) {
          button = 4; // wheel down
        }
  
        if (GLUT.mouseFunc) {
          event.preventDefault();
          GLUT.saveModifiers(event);
          Module['dynCall_viiii'](GLUT.mouseFunc, button, 0/*GLUT_DOWN*/, Browser.mouseX, Browser.mouseY);
        }
      },onFullscreenEventChange:function (event) {
        var width;
        var height;
        if (document["fullscreen"] || document["fullScreen"] || document["mozFullScreen"] || document["webkitIsFullScreen"]) {
          width = screen["width"];
          height = screen["height"];
        } else {
          width = GLUT.windowWidth;
          height = GLUT.windowHeight;
          // TODO set position
          document.removeEventListener('fullscreenchange', GLUT.onFullscreenEventChange, true);
          document.removeEventListener('mozfullscreenchange', GLUT.onFullscreenEventChange, true);
          document.removeEventListener('webkitfullscreenchange', GLUT.onFullscreenEventChange, true);
        }
        Browser.setCanvasSize(width, height);
        /* Can't call _glutReshapeWindow as that requests cancelling fullscreen. */
        if (GLUT.reshapeFunc) {
          // console.log("GLUT.reshapeFunc (from FS): " + width + ", " + height);
          Module['dynCall_vii'](GLUT.reshapeFunc, width, height);
        }
        _glutPostRedisplay();
      },requestFullscreen:function () {
        Browser.requestFullscreen(/*lockPointer=*/false, /*resieCanvas=*/false);
      },requestFullScreen:function () {
        Module.printErr('GLUT.requestFullScreen() is deprecated. Please call GLUT.requestFullscreen instead.');
        GLUT.requestFullScreen = function() {
          return GLUT.requestFullscreen();
        }
        return GLUT.requestFullscreen();
      },exitFullscreen:function () {
        var CFS = document['exitFullscreen'] ||
                  document['cancelFullScreen'] ||
                  document['mozCancelFullScreen'] ||
                  document['webkitCancelFullScreen'] ||
            (function() {});
        CFS.apply(document, []);
      },cancelFullScreen:function () {
        Module.printErr('GLUT.cancelFullScreen() is deprecated. Please call GLUT.exitFullscreen instead.');
        GLUT.cancelFullScreen = function() {
          return GLUT.exitFullscreen();
        }
        return GLUT.exitFullscreen();
      }};function _glutInitDisplayMode(mode) {
      GLUT.initDisplayMode = mode;
    }
  
  function _glutCreateWindow(name) {
      var contextAttributes = {
        antialias: ((GLUT.initDisplayMode & 0x0080 /*GLUT_MULTISAMPLE*/) != 0),
        depth: ((GLUT.initDisplayMode & 0x0010 /*GLUT_DEPTH*/) != 0),
        stencil: ((GLUT.initDisplayMode & 0x0020 /*GLUT_STENCIL*/) != 0),
        alpha: ((GLUT.initDisplayMode & 0x0008 /*GLUT_ALPHA*/) != 0)
      };
      Module.ctx = Browser.createContext(Module['canvas'], true, true, contextAttributes);
      return Module.ctx ? 1 /* a new GLUT window ID for the created context */ : 0 /* failure */;
    }function _eglCreateContext(display, config, hmm, contextAttribs) {
      if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0;
      }
  
      // EGL 1.4 spec says default EGL_CONTEXT_CLIENT_VERSION is GLES1, but this is not supported by Emscripten.
      // So user must pass EGL_CONTEXT_CLIENT_VERSION == 2 to initialize EGL.
      var glesContextVersion = 1;
      for(;;) {
        var param = HEAP32[((contextAttribs)>>2)];
        if (param == 0x3098 /*EGL_CONTEXT_CLIENT_VERSION*/) {
          glesContextVersion = HEAP32[(((contextAttribs)+(4))>>2)];
        } else if (param == 0x3038 /*EGL_NONE*/) {
          break;
        } else {
          /* EGL1.4 specifies only EGL_CONTEXT_CLIENT_VERSION as supported attribute */
          EGL.setErrorCode(0x3004 /*EGL_BAD_ATTRIBUTE*/);
          return 0;
        }
        contextAttribs += 8;
      }
      if (glesContextVersion != 2) {
        EGL.setErrorCode(0x3005 /* EGL_BAD_CONFIG */);
        return 0; /* EGL_NO_CONTEXT */
      }
  
      _glutInitDisplayMode(0xB2 /* GLUT_RGBA | GLUT_DOUBLE | GLUT_DEPTH | GLUT_MULTISAMPLE | GLUT_STENCIL */);
      EGL.windowID = _glutCreateWindow();
      if (EGL.windowID != 0) {
        EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
        // Note: This function only creates a context, but it shall not make it active.
        return 62004; // Magic ID for Emscripten EGLContext
      } else {
        EGL.setErrorCode(0x3009 /* EGL_BAD_MATCH */); // By the EGL 1.4 spec, an implementation that does not support GLES2 (WebGL in this case), this error code is set.
        return 0; /* EGL_NO_CONTEXT */
      }
    }

  function _emscripten_glReadPixels(x, y, width, height, format, type, pixels) {
      var pixelData = emscriptenWebGLGetTexPixelData(type, format, width, height, pixels, format);
      if (!pixelData) {
        GL.recordError(0x0500/*GL_INVALID_ENUM*/);
        return;
      }
      GLctx.readPixels(x, y, width, height, format, type, pixelData);
    }

  function _emscripten_glCompressedTexSubImage2D(target, level, xoffset, yoffset, width, height, format, imageSize, data) {
      GLctx['compressedTexSubImage2D'](target, level, xoffset, yoffset, width, height, format, data ? HEAPU8.subarray((data),(data+imageSize)) : null);
    }

  function _emscripten_glGetError() {
      // First return any GL error generated by the emscripten library_gl.js interop layer.
      if (GL.lastError) {
        var error = GL.lastError;
        GL.lastError = 0/*GL_NO_ERROR*/;
        return error;
      } else { // If there were none, return the GL error from the browser GL context.
        return GLctx.getError();
      }
    }

  function _eglBindAPI(api) {
      if (api == 0x30A0 /* EGL_OPENGL_ES_API */) {
        EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
        return 1;
      } else { // if (api == 0x30A1 /* EGL_OPENVG_API */ || api == 0x30A2 /* EGL_OPENGL_API */) {
        EGL.setErrorCode(0x300C /* EGL_BAD_PARAMETER */);
        return 0;
      }
    }

  function ___syscall39(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // mkdir
      var path = SYSCALLS.getStr(), mode = SYSCALLS.get();
      return SYSCALLS.doMkdir(path, mode);
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall33(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // access
      var path = SYSCALLS.getStr(), amode = SYSCALLS.get();
      return SYSCALLS.doAccess(path, amode);
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function _pthread_cleanup_push(routine, arg) {
      __ATEXIT__.push(function() { Module['dynCall_vi'](routine, arg) })
      _pthread_cleanup_push.level = __ATEXIT__.length;
    }

  function _emscripten_glIsEnabled(x0) { return GLctx['isEnabled'](x0) }

  function _glClearDepthf(x0) { GLctx['clearDepth'](x0) }

  function _glClearStencil(x0) { GLctx['clearStencil'](x0) }

  function _emscripten_glUniform1f(location, v0) {
      GLctx.uniform1f(GL.uniforms[location], v0);
    }

   

  function _glGenTextures(n, textures) {
      for (var i = 0; i < n; i++) {
        var texture = GLctx.createTexture();
        if (!texture) {
          GL.recordError(0x0502 /* GL_INVALID_OPERATION */); // GLES + EGL specs don't specify what should happen here, so best to issue an error and create IDs with 0.
          while(i < n) HEAP32[(((textures)+(i++*4))>>2)]=0;
          return;
        }
        var id = GL.getNewId(GL.textures);
        texture.name = id;
        GL.textures[id] = texture;
        HEAP32[(((textures)+(i*4))>>2)]=id;
      }
    }

  
  var __sigalrm_handler=0;function _signal(sig, func) {
      if (sig == 14 /*SIGALRM*/) {
        __sigalrm_handler = func;
      } else {
        Module.printErr('Calling stub instead of signal()');
      }
      return 0;
    }

  function _emscripten_glVertexAttrib4f(x0, x1, x2, x3, x4) { GLctx['vertexAttrib4f'](x0, x1, x2, x3, x4) }

  function _glColorMask(red, green, blue, alpha) {
      GLctx.colorMask(!!red, !!green, !!blue, !!alpha);
    }

   

  function _pthread_cancel() {}

  function ___cxa_rethrow() {
      var ptr = EXCEPTIONS.caught.pop();
      if (!EXCEPTIONS.infos[ptr].rethrown) {
        // Only pop if the corresponding push was through rethrow_primary_exception
        EXCEPTIONS.caught.push(ptr)
        EXCEPTIONS.infos[ptr].rethrown = true;
      }
      EXCEPTIONS.last = ptr;
      throw ptr;
    }

  function _emscripten_glClear(x0) { GLctx['clear'](x0) }

  
  function _emscripten_get_now_is_monotonic() {
      // return whether emscripten_get_now is guaranteed monotonic; the Date.now
      // implementation is not :(
      return ENVIRONMENT_IS_NODE || (typeof dateNow !== 'undefined') ||
          ((ENVIRONMENT_IS_WEB || ENVIRONMENT_IS_WORKER) && self['performance'] && self['performance']['now']);
    }function _clock_gettime(clk_id, tp) {
      // int clock_gettime(clockid_t clk_id, struct timespec *tp);
      var now;
      if (clk_id === 0) {
        now = Date.now();
      } else if (clk_id === 1 && _emscripten_get_now_is_monotonic()) {
        now = _emscripten_get_now();
      } else {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return -1;
      }
      HEAP32[((tp)>>2)]=(now/1000)|0; // seconds
      HEAP32[(((tp)+(4))>>2)]=((now % 1000)*1000*1000)|0; // nanoseconds
      return 0;
    }

  function _emscripten_glBindBuffer(target, buffer) {
      var bufferObj = buffer ? GL.buffers[buffer] : null;
  
  
      GLctx.bindBuffer(target, bufferObj);
    }

  function _emscripten_glCompileShader(shader) {
      GLctx.compileShader(GL.shaders[shader]);
    }

  function _emscripten_glGetUniformfv(program, location, params) {
      emscriptenWebGLGetUniform(program, location, params, 'Float');
    }

  function ___gxx_personality_v0() {
    }

  function _pthread_cond_signal() { return 0; }

  function _emscripten_glGetBufferParameteriv(target, value, data) {
      if (!data) {
        // GLES2 specification does not specify how to behave if data is a null pointer. Since calling this function does not make sense
        // if data == null, issue a GL error to notify user about it. 
        GL.recordError(0x0501 /* GL_INVALID_VALUE */);
        return;
      }
      HEAP32[((data)>>2)]=GLctx.getBufferParameter(target, value);
    }

  function _emscripten_glGetAttachedShaders(program, maxCount, count, shaders) {
      var result = GLctx.getAttachedShaders(GL.programs[program]);
      var len = result.length;
      if (len > maxCount) {
        len = maxCount;
      }
      HEAP32[((count)>>2)]=len;
      for (var i = 0; i < len; ++i) {
        var id = GL.shaders.indexOf(result[i]);
        assert(id !== -1, 'shader not bound to local id');
        HEAP32[(((shaders)+(i*4))>>2)]=id;
      }
    }

  function _emscripten_glGenRenderbuffers(n, renderbuffers) {
      for (var i = 0; i < n; i++) {
        var renderbuffer = GLctx.createRenderbuffer();
        if (!renderbuffer) {
          GL.recordError(0x0502 /* GL_INVALID_OPERATION */);
          while(i < n) HEAP32[(((renderbuffers)+(i++*4))>>2)]=0;
          return;
        }
        var id = GL.getNewId(GL.renderbuffers);
        renderbuffer.name = id;
        GL.renderbuffers[id] = renderbuffer;
        HEAP32[(((renderbuffers)+(i*4))>>2)]=id;
      }
    }

  function _emscripten_glFrontFace(x0) { GLctx['frontFace'](x0) }

  function _pthread_mutexattr_init() {}

  function _emscripten_glUniform1iv(location, count, value) {
  
  
      GLctx.uniform1iv(GL.uniforms[location], HEAP32.subarray((value)>>2,(value+count*4)>>2));
    }

  function _emscripten_glTexCoordPointer() {
  Module['printErr']('missing function: emscripten_glTexCoordPointer'); abort(-1);
  }

  function _emscripten_glGetInfoLogARB() {
  Module['printErr']('missing function: emscripten_glGetInfoLogARB'); abort(-1);
  }

  function _pthread_setspecific(key, value) {
      if (!(key in PTHREAD_SPECIFIC)) {
        return ERRNO_CODES.EINVAL;
      }
      PTHREAD_SPECIFIC[key] = value;
      return 0;
    }

  function _emscripten_glDepthMask(flag) {
      GLctx.depthMask(!!flag);
    }

  function _pthread_attr_setstacksize() {}


  function _emscripten_set_keyup_callback(target, userData, useCapture, callbackfunc) {
      JSEvents.registerKeyEventCallback(target, userData, useCapture, callbackfunc, 3, "keyup");
      return 0;
    }

  function _emscripten_glRenderbufferStorage(x0, x1, x2, x3) { GLctx['renderbufferStorage'](x0, x1, x2, x3) }

  var _llvm_ctlz_i32=true;

  function _glCopyTexImage2D(x0, x1, x2, x3, x4, x5, x6, x7) { GLctx['copyTexImage2D'](x0, x1, x2, x3, x4, x5, x6, x7) }

  function _llvm_trap() {
      abort('trap!');
    }

  function _emscripten_glShaderBinary() {
      GL.recordError(0x0500/*GL_INVALID_ENUM*/);
    }

  function _emscripten_glIsProgram(program) {
      var program = GL.programs[program];
      if (!program) return 0;
      return GLctx.isProgram(program);
    }

  function ___cxa_begin_catch(ptr) {
      var info = EXCEPTIONS.infos[ptr];
      if (info && !info.caught) {
        info.caught = true;
        __ZSt18uncaught_exceptionv.uncaught_exception--;
      }
      if (info) info.rethrown = false;
      EXCEPTIONS.caught.push(ptr);
      EXCEPTIONS.addRef(EXCEPTIONS.deAdjust(ptr));
      return ptr;
    }

   

  function _eglInitialize(display, majorVersion, minorVersion) {
      if (display == 62000 /* Magic ID for Emscripten 'default display' */) {
        if (majorVersion) {
          HEAP32[((majorVersion)>>2)]=1; // Advertise EGL Major version: '1'
        }
        if (minorVersion) {
          HEAP32[((minorVersion)>>2)]=4; // Advertise EGL Minor version: '4'
        }
        EGL.defaultDisplayInitialized = true;
        EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
        return 1;
      } 
      else {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0;
      }
    }

  function _emscripten_glBlendColor(x0, x1, x2, x3) { GLctx['blendColor'](x0, x1, x2, x3) }

  function _emscripten_glGetShaderiv(shader, pname, p) {
      if (!p) {
        // GLES2 specification does not specify how to behave if p is a null pointer. Since calling this function does not make sense
        // if p == null, issue a GL error to notify user about it. 
        GL.recordError(0x0501 /* GL_INVALID_VALUE */);
        return;
      }
      if (pname == 0x8B84) { // GL_INFO_LOG_LENGTH
        var log = GLctx.getShaderInfoLog(GL.shaders[shader]);
        if (log === null) log = '(unknown error)';
        HEAP32[((p)>>2)]=log.length + 1;
      } else if (pname == 0x8B88) { // GL_SHADER_SOURCE_LENGTH
        var source = GLctx.getShaderSource(GL.shaders[shader]);
        var sourceLength = (source === null || source.length == 0) ? 0 : source.length + 1;
        HEAP32[((p)>>2)]=sourceLength;
      } else {
        HEAP32[((p)>>2)]=GLctx.getShaderParameter(GL.shaders[shader], pname);
      }
    }

  function _emscripten_glUniformMatrix3fv(location, count, transpose, value) {
  
  
      var view;
      if (9*count <= GL.MINI_TEMP_BUFFER_SIZE) {
        // avoid allocation when uploading few enough uniforms
        view = GL.miniTempBufferViews[9*count-1];
        for (var i = 0; i < 9*count; i += 9) {
          view[i] = HEAPF32[(((value)+(4*i))>>2)];
          view[i+1] = HEAPF32[(((value)+(4*i+4))>>2)];
          view[i+2] = HEAPF32[(((value)+(4*i+8))>>2)];
          view[i+3] = HEAPF32[(((value)+(4*i+12))>>2)];
          view[i+4] = HEAPF32[(((value)+(4*i+16))>>2)];
          view[i+5] = HEAPF32[(((value)+(4*i+20))>>2)];
          view[i+6] = HEAPF32[(((value)+(4*i+24))>>2)];
          view[i+7] = HEAPF32[(((value)+(4*i+28))>>2)];
          view[i+8] = HEAPF32[(((value)+(4*i+32))>>2)];
        }
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*36)>>2);
      }
      GLctx.uniformMatrix3fv(GL.uniforms[location], !!transpose, view);
    }

  function _emscripten_glVertexAttrib2f(x0, x1, x2) { GLctx['vertexAttrib2f'](x0, x1, x2) }

  function _emscripten_glUniform4fv(location, count, value) {
  
  
      var view;
      if (4*count <= GL.MINI_TEMP_BUFFER_SIZE) {
        // avoid allocation when uploading few enough uniforms
        view = GL.miniTempBufferViews[4*count-1];
        for (var i = 0; i < 4*count; i += 4) {
          view[i] = HEAPF32[(((value)+(4*i))>>2)];
          view[i+1] = HEAPF32[(((value)+(4*i+4))>>2)];
          view[i+2] = HEAPF32[(((value)+(4*i+8))>>2)];
          view[i+3] = HEAPF32[(((value)+(4*i+12))>>2)];
        }
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*16)>>2);
      }
      GLctx.uniform4fv(GL.uniforms[location], view);
    }

  function _emscripten_set_keypress_callback(target, userData, useCapture, callbackfunc) {
      JSEvents.registerKeyEventCallback(target, userData, useCapture, callbackfunc, 1, "keypress");
      return 0;
    }

  function ___cxa_call_unexpected(exception) {
      Module.printErr('Unexpected exception thrown, this is not properly supported - aborting');
      ABORT = true;
      throw exception;
    }

  function _emscripten_exit_fullscreen() {
      if (typeof JSEvents.fullscreenEnabled() === 'undefined') return -1;
      // Make sure no queued up calls will fire after this.
      JSEvents.removeDeferredCalls(JSEvents.requestFullscreen);
  
      if (document.exitFullscreen) {
        document.exitFullscreen();
      } else if (document.msExitFullscreen) {
        document.msExitFullscreen();
      } else if (document.mozCancelFullScreen) {
        document.mozCancelFullScreen();
      } else if (document.webkitExitFullscreen) {
        document.webkitExitFullscreen();
      } else {
        return -1;
      }
  
      if (__currentFullscreenStrategy.canvasResizedCallback) {
        Module['dynCall_iiii'](__currentFullscreenStrategy.canvasResizedCallback, 37, 0, __currentFullscreenStrategy.canvasResizedCallbackUserData);
      }
  
      return 0;
    }

  function _emscripten_glGenFramebuffers(n, ids) {
      for (var i = 0; i < n; ++i) {
        var framebuffer = GLctx.createFramebuffer();
        if (!framebuffer) {
          GL.recordError(0x0502 /* GL_INVALID_OPERATION */);
          while(i < n) HEAP32[(((ids)+(i++*4))>>2)]=0;
          return;
        }
        var id = GL.getNewId(GL.framebuffers);
        framebuffer.name = id;
        GL.framebuffers[id] = framebuffer;
        HEAP32[(((ids)+(i*4))>>2)]=id;
      }
    }

  function _emscripten_exit_pointerlock() {
      // Make sure no queued up calls will fire after this.
      JSEvents.removeDeferredCalls(JSEvents.requestPointerLock);
  
      if (document.exitPointerLock) {
        document.exitPointerLock();
      } else if (document.msExitPointerLock) {
        document.msExitPointerLock();
      } else if (document.mozExitPointerLock) {
        document.mozExitPointerLock();
      } else if (document.webkitExitPointerLock) {
        document.webkitExitPointerLock();
      } else {
        return -1;
      }
      return 0;
    }

  function _emscripten_glBlendEquationSeparate(x0, x1) { GLctx['blendEquationSeparate'](x0, x1) }

  function _eglWaitNative(nativeEngineId) {
      EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
      return 1;
    }

  
  function _usleep(useconds) {
      // int usleep(useconds_t useconds);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/usleep.html
      // We're single-threaded, so use a busy loop. Super-ugly.
      var msec = useconds / 1000;
      if ((ENVIRONMENT_IS_WEB || ENVIRONMENT_IS_WORKER) && self['performance'] && self['performance']['now']) {
        var start = self['performance']['now']();
        while (self['performance']['now']() - start < msec) {
          // Do nothing.
        }
      } else {
        var start = Date.now();
        while (Date.now() - start < msec) {
          // Do nothing.
        }
      }
      return 0;
    }function _nanosleep(rqtp, rmtp) {
      // int nanosleep(const struct timespec  *rqtp, struct timespec *rmtp);
      var seconds = HEAP32[((rqtp)>>2)];
      var nanoseconds = HEAP32[(((rqtp)+(4))>>2)];
      if (rmtp !== 0) {
        HEAP32[((rmtp)>>2)]=0;
        HEAP32[(((rmtp)+(4))>>2)]=0;
      }
      return _usleep((seconds * 1e6) + (nanoseconds / 1000));
    }

  function _emscripten_glBindTexture(target, texture) {
      GLctx.bindTexture(target, texture ? GL.textures[texture] : null);
    }

  function _emscripten_glDrawRangeElements() {
  Module['printErr']('missing function: emscripten_glDrawRangeElements'); abort(-1);
  }

  function _emscripten_glGenTextures(n, textures) {
      for (var i = 0; i < n; i++) {
        var texture = GLctx.createTexture();
        if (!texture) {
          GL.recordError(0x0502 /* GL_INVALID_OPERATION */); // GLES + EGL specs don't specify what should happen here, so best to issue an error and create IDs with 0.
          while(i < n) HEAP32[(((textures)+(i++*4))>>2)]=0;
          return;
        }
        var id = GL.getNewId(GL.textures);
        texture.name = id;
        GL.textures[id] = texture;
        HEAP32[(((textures)+(i*4))>>2)]=id;
      }
    }

  function _emscripten_glVertexAttrib2fv(index, v) {
  
      GLctx.vertexAttrib2f(index, HEAPF32[v>>2], HEAPF32[v+4>>2]);
    }

  function _emscripten_glGetActiveUniform(program, index, bufSize, length, size, type, name) {
      program = GL.programs[program];
      var info = GLctx.getActiveUniform(program, index);
      if (!info) return; // If an error occurs, nothing will be written to length, size, type and name.
  
      if (bufSize > 0 && name) {
        var numBytesWrittenExclNull = stringToUTF8(info.name, name, bufSize);
        if (length) HEAP32[((length)>>2)]=numBytesWrittenExclNull;
      } else {
        if (length) HEAP32[((length)>>2)]=0;
      }
  
      if (size) HEAP32[((size)>>2)]=info.size;
      if (type) HEAP32[((type)>>2)]=info.type;
    }

  function _emscripten_glDeleteObjectARB() {
  Module['printErr']('missing function: emscripten_glDeleteObjectARB'); abort(-1);
  }

  function _emscripten_set_touchmove_callback(target, userData, useCapture, callbackfunc) {
      JSEvents.registerTouchEventCallback(target, userData, useCapture, callbackfunc, 24, "touchmove");
      return 0;
    }

  function _pthread_attr_getstacksize() {
  Module['printErr']('missing function: pthread_attr_getstacksize'); abort(-1);
  }

  function _emscripten_glVertexAttribPointer(index, size, type, normalized, stride, ptr) {
      GLctx.vertexAttribPointer(index, size, type, !!normalized, stride, ptr);
    }

  function _pthread_create() {
      return 11;
    }


  function _emscripten_glDrawArrays(mode, first, count) {
  
      GLctx.drawArrays(mode, first, count);
  
    }

  function _emscripten_glGenBuffers(n, buffers) {
      for (var i = 0; i < n; i++) {
        var buffer = GLctx.createBuffer();
        if (!buffer) {
          GL.recordError(0x0502 /* GL_INVALID_OPERATION */);
          while(i < n) HEAP32[(((buffers)+(i++*4))>>2)]=0;
          return;
        }
        var id = GL.getNewId(GL.buffers);
        buffer.name = id;
        GL.buffers[id] = buffer;
        HEAP32[(((buffers)+(i*4))>>2)]=id;
      }
    }

  function _emscripten_glClearDepth(x0) { GLctx['clearDepth'](x0) }


  
  var PTHREAD_SPECIFIC_NEXT_KEY=1;function _pthread_key_create(key, destructor) {
      if (key == 0) {
        return ERRNO_CODES.EINVAL;
      }
      HEAP32[((key)>>2)]=PTHREAD_SPECIFIC_NEXT_KEY;
      // values start at 0
      PTHREAD_SPECIFIC[PTHREAD_SPECIFIC_NEXT_KEY] = 0;
      PTHREAD_SPECIFIC_NEXT_KEY++;
      return 0;
    }

  
  function _glutDestroyWindow(name) {
      Module.ctx = Browser.destroyContext(Module['canvas'], true, true);
      return 1;
    }function _eglDestroyContext(display, context) {
      if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0;
      }
  
      if (context != 62004 /* Magic ID for Emscripten EGLContext */) {
        EGL.setErrorCode(0x3006 /* EGL_BAD_CONTEXT */);
        return 0;
      }
  
      EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
      return 1;
    }

  function _emscripten_glGetUniformLocation(program, name) {
      name = Pointer_stringify(name);
  
      var arrayOffset = 0;
      // If user passed an array accessor "[index]", parse the array index off the accessor.
      if (name.indexOf(']', name.length-1) !== -1) {
        var ls = name.lastIndexOf('[');
        var arrayIndex = name.slice(ls+1, -1);
        if (arrayIndex.length > 0) {
          arrayOffset = parseInt(arrayIndex);
          if (arrayOffset < 0) {
            return -1;
          }
        }
        name = name.slice(0, ls);
      }
  
      var ptable = GL.programInfos[program];
      if (!ptable) {
        return -1;
      }
      var utable = ptable.uniforms;
      var uniformInfo = utable[name]; // returns pair [ dimension_of_uniform_array, uniform_location ]
      if (uniformInfo && arrayOffset < uniformInfo[0]) { // Check if user asked for an out-of-bounds element, i.e. for 'vec4 colors[3];' user could ask for 'colors[10]' which should return -1.
        return uniformInfo[1]+arrayOffset;
      } else {
        return -1;
      }
    }

  function _emscripten_glEnable(x0) { GLctx['enable'](x0) }

  function _emscripten_glScissor(x0, x1, x2, x3) { GLctx['scissor'](x0, x1, x2, x3) }

   

  function _emscripten_glLinkProgram(program) {
      GLctx.linkProgram(GL.programs[program]);
      GL.programInfos[program] = null; // uniforms no longer keep the same names after linking
      GL.populateUniformTable(program);
    }

  function _pthread_cond_timedwait() { return 0; }

  function _sched_yield() {
      return 0;
    }

  function _emscripten_glValidateProgram(program) {
      GLctx.validateProgram(GL.programs[program]);
    }

  function _getenv(name) {
      // char *getenv(const char *name);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/getenv.html
      if (name === 0) return 0;
      name = Pointer_stringify(name);
      if (!ENV.hasOwnProperty(name)) return 0;
  
      if (_getenv.ret) _free(_getenv.ret);
      _getenv.ret = allocate(intArrayFromString(ENV[name]), 'i8', ALLOC_NORMAL);
      return _getenv.ret;
    }

  function _glGetError() {
      // First return any GL error generated by the emscripten library_gl.js interop layer.
      if (GL.lastError) {
        var error = GL.lastError;
        GL.lastError = 0/*GL_NO_ERROR*/;
        return error;
      } else { // If there were none, return the GL error from the browser GL context.
        return GLctx.getError();
      }
    }

  function _emscripten_glDrawBuffers(n, bufs) {
  
      var bufArray = GL.tempFixedLengthArray[n];
      for (var i = 0; i < n; i++) {
        bufArray[i] = HEAP32[(((bufs)+(i*4))>>2)];
      }
  
      GLctx['drawBuffers'](bufArray);
    }

  function ___cxa_find_matching_catch_2() {
          return ___cxa_find_matching_catch.apply(null, arguments);
        }

  function ___cxa_find_matching_catch_3() {
          return ___cxa_find_matching_catch.apply(null, arguments);
        }

   

  function _emscripten_glBindFramebuffer(target, framebuffer) {
      GLctx.bindFramebuffer(target, framebuffer ? GL.framebuffers[framebuffer] : null);
    }

  function _emscripten_glBlendEquation(x0) { GLctx['blendEquation'](x0) }

  function _emscripten_glBufferSubData(target, offset, size, data) {
      GLctx.bufferSubData(target, offset, HEAPU8.subarray(data, data+size));
    }

  function _emscripten_set_keydown_callback(target, userData, useCapture, callbackfunc) {
      JSEvents.registerKeyEventCallback(target, userData, useCapture, callbackfunc, 2, "keydown");
      return 0;
    }

  function _emscripten_glBufferData(target, size, data, usage) {
      if (!data) {
        GLctx.bufferData(target, size, usage);
      } else {
        GLctx.bufferData(target, HEAPU8.subarray(data, data+size), usage);
      }
    }

   


  function _emscripten_glVertexAttrib4fv(index, v) {
  
      GLctx.vertexAttrib4f(index, HEAPF32[v>>2], HEAPF32[v+4>>2], HEAPF32[v+8>>2], HEAPF32[v+12>>2]);
    }

  function _glGetIntegerv(name_, p) {
      emscriptenWebGLGet(name_, p, 'Integer');
    }

  function ___syscall85(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // readlink
      var path = SYSCALLS.getStr(), buf = SYSCALLS.get(), bufsize = SYSCALLS.get();
      return SYSCALLS.doReadlink(path, buf, bufsize);
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function _emscripten_glGetShaderSource(shader, bufSize, length, source) {
      var result = GLctx.getShaderSource(GL.shaders[shader]);
      if (!result) return; // If an error occurs, nothing will be written to length or source.
      if (bufSize > 0 && source) {
        var numBytesWrittenExclNull = stringToUTF8(result, source, bufSize);
        if (length) HEAP32[((length)>>2)]=numBytesWrittenExclNull;
      } else {
        if (length) HEAP32[((length)>>2)]=0;
      }
    }

  function _emscripten_glActiveTexture(x0) { GLctx['activeTexture'](x0) }

   

  function _emscripten_set_gamepadconnected_callback(userData, useCapture, callbackfunc) {
      if (!navigator.getGamepads && !navigator.webkitGetGamepads) return -1;
      JSEvents.registerGamepadEventCallback(window, userData, useCapture, callbackfunc, 26, "gamepadconnected");
      return 0;
    }

  function _emscripten_glGetFloatv(name_, p) {
      emscriptenWebGLGet(name_, p, 'Float');
    }

  function _glTexImage2D(target, level, internalFormat, width, height, border, format, type, pixels) {
  
      var pixelData = null;
      if (pixels) pixelData = emscriptenWebGLGetTexPixelData(type, format, width, height, pixels, internalFormat);
      GLctx.texImage2D(target, level, internalFormat, width, height, border, format, type, pixelData);
    }

  function ___assert_fail(condition, filename, line, func) {
      ABORT = true;
      throw 'Assertion failed: ' + Pointer_stringify(condition) + ', at: ' + [filename ? Pointer_stringify(filename) : 'unknown filename', line, func ? Pointer_stringify(func) : 'unknown function'] + ' at ' + stackTrace();
    }

  function _emscripten_glUniform3fv(location, count, value) {
  
  
      var view;
      if (3*count <= GL.MINI_TEMP_BUFFER_SIZE) {
        // avoid allocation when uploading few enough uniforms
        view = GL.miniTempBufferViews[3*count-1];
        for (var i = 0; i < 3*count; i += 3) {
          view[i] = HEAPF32[(((value)+(4*i))>>2)];
          view[i+1] = HEAPF32[(((value)+(4*i+4))>>2)];
          view[i+2] = HEAPF32[(((value)+(4*i+8))>>2)];
        }
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*12)>>2);
      }
      GLctx.uniform3fv(GL.uniforms[location], view);
    }

  function _emscripten_glDrawElementsInstanced(mode, count, type, indices, primcount) {
      GLctx['drawElementsInstanced'](mode, count, type, indices, primcount);
    }

  function _eglMakeCurrent(display, draw, read, context) { 
      if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0 /* EGL_FALSE */;
      }
      //\todo An EGL_NOT_INITIALIZED error is generated if EGL is not initialized for dpy. 
      if (context != 0 && context != 62004 /* Magic ID for Emscripten EGLContext */) {
        EGL.setErrorCode(0x3006 /* EGL_BAD_CONTEXT */);
        return 0;
      }
      if ((read != 0 && read != 62006) || (draw != 0 && draw != 62006 /* Magic ID for Emscripten 'default surface' */)) {
        EGL.setErrorCode(0x300D /* EGL_BAD_SURFACE */);
        return 0;
      }
      EGL.currentContext = context;
      EGL.currentDrawSurface = draw;
      EGL.currentReadSurface = read;
      EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
      return 1 /* EGL_TRUE */;
    }

  function _emscripten_glDrawElements(mode, count, type, indices) {
  
      GLctx.drawElements(mode, count, type, indices);
  
    }

  function _pthread_mutexattr_settype() {}

  function _pthread_cond_destroy() { return 0; }

  function _emscripten_glCreateProgram() {
      var id = GL.getNewId(GL.programs);
      var program = GLctx.createProgram();
      program.name = id;
      GL.programs[id] = program;
      return id;
    }

  function _pthread_once(ptr, func) {
      if (!_pthread_once.seen) _pthread_once.seen = {};
      if (ptr in _pthread_once.seen) return;
      Module['dynCall_v'](func);
      _pthread_once.seen[ptr] = 1;
    }

  function _emscripten_glDeleteFramebuffers(n, framebuffers) {
      for (var i = 0; i < n; ++i) {
        var id = HEAP32[(((framebuffers)+(i*4))>>2)];
        var framebuffer = GL.framebuffers[id];
        if (!framebuffer) continue; // GL spec: "glDeleteFramebuffers silently ignores 0s and names that do not correspond to existing framebuffer objects".
        GLctx.deleteFramebuffer(framebuffer);
        framebuffer.name = 0;
        GL.framebuffers[id] = null;
      }
    }

  function _emscripten_glClearColor(x0, x1, x2, x3) { GLctx['clearColor'](x0, x1, x2, x3) }

  function _glTexParameterfv(target, pname, params) {
      var param = HEAPF32[((params)>>2)];
      GLctx.texParameterf(target, pname, param);
    }

  function ___unlock() {}

  function _glFinish() { GLctx['finish']() }

  function _emscripten_glLoadMatrixf() {
  Module['printErr']('missing function: emscripten_glLoadMatrixf'); abort(-1);
  }

  function ___cxa_allocate_exception(size) {
      return _malloc(size);
    }

  function _emscripten_glGetProgramiv(program, pname, p) {
      if (!p) {
        // GLES2 specification does not specify how to behave if p is a null pointer. Since calling this function does not make sense
        // if p == null, issue a GL error to notify user about it. 
        GL.recordError(0x0501 /* GL_INVALID_VALUE */);
        return;
      }
  
      if (program >= GL.counter) {
        GL.recordError(0x0501 /* GL_INVALID_VALUE */);
        return;
      }
  
      var ptable = GL.programInfos[program];
      if (!ptable) {
        GL.recordError(0x0502 /* GL_INVALID_OPERATION */);
        return;
      }
  
      if (pname == 0x8B84) { // GL_INFO_LOG_LENGTH
        var log = GLctx.getProgramInfoLog(GL.programs[program]);
        if (log === null) log = '(unknown error)';
        HEAP32[((p)>>2)]=log.length + 1;
      } else if (pname == 0x8B87 /* GL_ACTIVE_UNIFORM_MAX_LENGTH */) {
        HEAP32[((p)>>2)]=ptable.maxUniformLength;
      } else if (pname == 0x8B8A /* GL_ACTIVE_ATTRIBUTE_MAX_LENGTH */) {
        if (ptable.maxAttributeLength == -1) {
          var program = GL.programs[program];
          var numAttribs = GLctx.getProgramParameter(program, GLctx.ACTIVE_ATTRIBUTES);
          ptable.maxAttributeLength = 0; // Spec says if there are no active attribs, 0 must be returned.
          for (var i = 0; i < numAttribs; ++i) {
            var activeAttrib = GLctx.getActiveAttrib(program, i);
            ptable.maxAttributeLength = Math.max(ptable.maxAttributeLength, activeAttrib.name.length+1);
          }
        }
        HEAP32[((p)>>2)]=ptable.maxAttributeLength;
      } else if (pname == 0x8A35 /* GL_ACTIVE_UNIFORM_BLOCK_MAX_NAME_LENGTH */) {
        if (ptable.maxUniformBlockNameLength == -1) {
          var program = GL.programs[program];
          var numBlocks = GLctx.getProgramParameter(program, GLctx.ACTIVE_UNIFORM_BLOCKS);
          ptable.maxUniformBlockNameLength = 0;
          for (var i = 0; i < numBlocks; ++i) {
            var activeBlockName = GLctx.getActiveUniformBlockName(program, i);
            ptable.maxUniformBlockNameLength = Math.max(ptable.maxUniformBlockNameLength, activeBlockName.length+1);
          }
        }
        HEAP32[((p)>>2)]=ptable.maxUniformBlockNameLength;
      } else {
        HEAP32[((p)>>2)]=GLctx.getProgramParameter(GL.programs[program], pname);
      }
    }

  function _emscripten_glGetProgramInfoLog(program, maxLength, length, infoLog) {
      var log = GLctx.getProgramInfoLog(GL.programs[program]);
      if (log === null) log = '(unknown error)';
  
      if (maxLength > 0 && infoLog) {
        var numBytesWrittenExclNull = stringToUTF8(log, infoLog, maxLength);
        if (length) HEAP32[((length)>>2)]=numBytesWrittenExclNull;
      } else {
        if (length) HEAP32[((length)>>2)]=0;
      }
    }

  function _emscripten_glTexImage2D(target, level, internalFormat, width, height, border, format, type, pixels) {
  
      var pixelData = null;
      if (pixels) pixelData = emscriptenWebGLGetTexPixelData(type, format, width, height, pixels, internalFormat);
      GLctx.texImage2D(target, level, internalFormat, width, height, border, format, type, pixelData);
    }

  function _emscripten_glGenVertexArrays(n, arrays) {
  
      for (var i = 0; i < n; i++) {
        var vao = GLctx['createVertexArray']();
        if (!vao) {
          GL.recordError(0x0502 /* GL_INVALID_OPERATION */);
          while(i < n) HEAP32[(((arrays)+(i++*4))>>2)]=0;
          return;
        }
        var id = GL.getNewId(GL.vaos);
        vao.name = id;
        GL.vaos[id] = vao;
        HEAP32[(((arrays)+(i*4))>>2)]=id;
      }
    }

  function _emscripten_glColorPointer() {
  Module['printErr']('missing function: emscripten_glColorPointer'); abort(-1);
  }

  function _glViewport(x0, x1, x2, x3) { GLctx['viewport'](x0, x1, x2, x3) }

  function _emscripten_glFlush() { GLctx['flush']() }

  function _glDepthMask(flag) {
      GLctx.depthMask(!!flag);
    }

  function _emscripten_glCreateShader(shaderType) {
      var id = GL.getNewId(GL.shaders);
      GL.shaders[id] = GLctx.createShader(shaderType);
      return id;
    }

  function _pthread_cond_init() { return 0; }

  function _emscripten_glIsShader(shader) {
      var s = GL.shaders[shader];
      if (!s) return 0;
      return GLctx.isShader(s);
    }

  function _glTexParameterf(x0, x1, x2) { GLctx['texParameterf'](x0, x1, x2) }

  function _glTexParameteri(x0, x1, x2) { GLctx['texParameteri'](x0, x1, x2) }

  function _emscripten_glColorMask(red, green, blue, alpha) {
      GLctx.colorMask(!!red, !!green, !!blue, !!alpha);
    }

  function _emscripten_glPixelStorei(pname, param) {
      if (pname == 0x0D05 /* GL_PACK_ALIGNMENT */) {
        GL.packAlignment = param;
      } else if (pname == 0x0cf5 /* GL_UNPACK_ALIGNMENT */) {
        GL.unpackAlignment = param;
      }
      GLctx.pixelStorei(pname, param);
    }

  function _pthread_cleanup_pop() {
      assert(_pthread_cleanup_push.level == __ATEXIT__.length, 'cannot pop if something else added meanwhile!');
      __ATEXIT__.pop();
      _pthread_cleanup_push.level = __ATEXIT__.length;
    }

  function _emscripten_glDeleteTextures(n, textures) {
      for (var i = 0; i < n; i++) {
        var id = HEAP32[(((textures)+(i*4))>>2)];
        var texture = GL.textures[id];
        if (!texture) continue; // GL spec: "glDeleteTextures silently ignores 0s and names that do not correspond to existing textures".
        GLctx.deleteTexture(texture);
        texture.name = 0;
        GL.textures[id] = null;
      }
    }

  function _eglGetDisplay(nativeDisplayType) {
      EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
      // Note: As a 'conformant' implementation of EGL, we would prefer to init here only if the user
      //       calls this function with EGL_DEFAULT_DISPLAY. Other display IDs would be preferred to be unsupported
      //       and EGL_NO_DISPLAY returned. Uncomment the following code lines to do this.
      // Instead, an alternative route has been preferred, namely that the Emscripten EGL implementation
      // "emulates" X11, and eglGetDisplay is expected to accept/receive a pointer to an X11 Display object.
      // Therefore, be lax and allow anything to be passed in, and return the magic handle to our default EGLDisplay object.
  
  //    if (nativeDisplayType == 0 /* EGL_DEFAULT_DISPLAY */) {
          return 62000; // Magic ID for Emscripten 'default display'
  //    }
  //    else
  //      return 0; // EGL_NO_DISPLAY
    }

  function _emscripten_set_canvas_size(width, height) {
      Browser.setCanvasSize(width, height);
    }

  function ___map_file(pathname, size) {
      ___setErrNo(ERRNO_CODES.EPERM);
      return -1;
    }

  function ___syscall221(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // fcntl64
      var stream = SYSCALLS.getStreamFromFD(), cmd = SYSCALLS.get();
      switch (cmd) {
        case 0: {
          var arg = SYSCALLS.get();
          if (arg < 0) {
            return -ERRNO_CODES.EINVAL;
          }
          var newStream;
          newStream = FS.open(stream.path, stream.flags, 0, arg);
          return newStream.fd;
        }
        case 1:
        case 2:
          return 0;  // FD_CLOEXEC makes no sense for a single process.
        case 3:
          return stream.flags;
        case 4: {
          var arg = SYSCALLS.get();
          stream.flags |= arg;
          return 0;
        }
        case 12:
        case 12: {
          var arg = SYSCALLS.get();
          var offset = 0;
          // We're always unlocked.
          HEAP16[(((arg)+(offset))>>1)]=2;
          return 0;
        }
        case 13:
        case 14:
        case 13:
        case 14:
          return 0; // Pretend that the locking is successful.
        case 16:
        case 8:
          return -ERRNO_CODES.EINVAL; // These are for sockets. We don't have them fully implemented yet.
        case 9:
          // musl trusts getown return values, due to a bug where they must be, as they overlap with errors. just return -1 here, so fnctl() returns that, and we set errno ourselves.
          ___setErrNo(ERRNO_CODES.EINVAL);
          return -1;
        default: {
          return -ERRNO_CODES.EINVAL;
        }
      }
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function _glPixelStorei(pname, param) {
      if (pname == 0x0D05 /* GL_PACK_ALIGNMENT */) {
        GL.packAlignment = param;
      } else if (pname == 0x0cf5 /* GL_UNPACK_ALIGNMENT */) {
        GL.unpackAlignment = param;
      }
      GLctx.pixelStorei(pname, param);
    }

  function _time(ptr) {
      var ret = (Date.now()/1000)|0;
      if (ptr) {
        HEAP32[((ptr)>>2)]=ret;
      }
      return ret;
    }

  function _emscripten_glClearStencil(x0) { GLctx['clearStencil'](x0) }

  function _emscripten_glGetBooleanv(name_, p) {
      emscriptenWebGLGet(name_, p, 'Boolean');
    }

  var _llvm_nacl_atomic_cmpxchg_i32=undefined;

  function ___syscall220(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // SYS_getdents64
      var stream = SYSCALLS.getStreamFromFD(), dirp = SYSCALLS.get(), count = SYSCALLS.get();
      if (!stream.getdents) {
        stream.getdents = FS.readdir(stream.path);
      }
      var pos = 0;
      while (stream.getdents.length > 0 && pos + 268 <= count) {
        var id;
        var type;
        var name = stream.getdents.pop();
        assert(name.length < 256); // limit of dirent struct
        if (name[0] === '.') {
          id = 1;
          type = 4; // DT_DIR
        } else {
          var child = FS.lookupNode(stream.node, name);
          id = child.id;
          type = FS.isChrdev(child.mode) ? 2 :  // DT_CHR, character device.
                 FS.isDir(child.mode) ? 4 :     // DT_DIR, directory.
                 FS.isLink(child.mode) ? 10 :   // DT_LNK, symbolic link.
                 8;                             // DT_REG, regular file.
        }
        HEAP32[((dirp + pos)>>2)]=id;
        HEAP32[(((dirp + pos)+(4))>>2)]=stream.position;
        HEAP16[(((dirp + pos)+(8))>>1)]=268;
        HEAP8[(((dirp + pos)+(10))>>0)]=type;
        for (var i = 0; i < name.length; i++) {
          HEAP8[(((dirp + pos)+(11 + i))>>0)]=name.charCodeAt(i);
        }
        HEAP8[(((dirp + pos)+(11 + i))>>0)]=0;
        pos += 268;
      }
      return pos;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  var ___dso_handle=STATICTOP; STATICTOP += 16;;
JSEvents.staticInit();;
var GLctx; GL.init();
Module["requestFullScreen"] = function Module_requestFullScreen(lockPointer, resizeCanvas, vrDevice) { Module.printErr("Module.requestFullScreen is deprecated. Please call Module.requestFullscreen instead."); Module["requestFullScreen"] = Module["requestFullscreen"]; Browser.requestFullScreen(lockPointer, resizeCanvas, vrDevice) };
  Module["requestFullscreen"] = function Module_requestFullscreen(lockPointer, resizeCanvas, vrDevice) { Browser.requestFullscreen(lockPointer, resizeCanvas, vrDevice) };
  Module["requestAnimationFrame"] = function Module_requestAnimationFrame(func) { Browser.requestAnimationFrame(func) };
  Module["setCanvasSize"] = function Module_setCanvasSize(width, height, noUpdates) { Browser.setCanvasSize(width, height, noUpdates) };
  Module["pauseMainLoop"] = function Module_pauseMainLoop() { Browser.mainLoop.pause() };
  Module["resumeMainLoop"] = function Module_resumeMainLoop() { Browser.mainLoop.resume() };
  Module["getUserMedia"] = function Module_getUserMedia() { Browser.getUserMedia() }
  Module["createContext"] = function Module_createContext(canvas, useWebGL, setInModule, webGLContextAttributes) { return Browser.createContext(canvas, useWebGL, setInModule, webGLContextAttributes) };
if (ENVIRONMENT_IS_NODE) {
    _emscripten_get_now = function _emscripten_get_now_actual() {
      var t = process['hrtime']();
      return t[0] * 1e3 + t[1] / 1e6;
    };
  } else if (typeof dateNow !== 'undefined') {
    _emscripten_get_now = dateNow;
  } else if (typeof self === 'object' && self['performance'] && typeof self['performance']['now'] === 'function') {
    _emscripten_get_now = function() { return self['performance']['now'](); };
  } else if (typeof performance === 'object' && typeof performance['now'] === 'function') {
    _emscripten_get_now = function() { return performance['now'](); };
  } else {
    _emscripten_get_now = Date.now;
  };
FS.staticInit();__ATINIT__.unshift(function() { if (!Module["noFSInit"] && !FS.init.initialized) FS.init() });__ATMAIN__.push(function() { FS.ignorePermissions = false });__ATEXIT__.push(function() { FS.quit() });Module["FS_createFolder"] = FS.createFolder;Module["FS_createPath"] = FS.createPath;Module["FS_createDataFile"] = FS.createDataFile;Module["FS_createPreloadedFile"] = FS.createPreloadedFile;Module["FS_createLazyFile"] = FS.createLazyFile;Module["FS_createLink"] = FS.createLink;Module["FS_createDevice"] = FS.createDevice;Module["FS_unlink"] = FS.unlink;;
__ATINIT__.unshift(function() { TTY.init() });__ATEXIT__.push(function() { TTY.shutdown() });;
if (ENVIRONMENT_IS_NODE) { var fs = require("fs"); var NODEJS_PATH = require("path"); NODEFS.staticInit(); };
___buildEnvironment(ENV);;
DYNAMICTOP_PTR = allocate(1, "i32", ALLOC_STATIC);

STACK_BASE = STACKTOP = Runtime.alignMemory(STATICTOP);

STACK_MAX = STACK_BASE + TOTAL_STACK;

DYNAMIC_BASE = Runtime.alignMemory(STACK_MAX);

HEAP32[DYNAMICTOP_PTR>>2] = DYNAMIC_BASE;

staticSealed = true; // seal the static portion of memory

assert(DYNAMIC_BASE < TOTAL_MEMORY, "TOTAL_MEMORY not big enough for stack");


function nullFunc_iiiiiiii(x) { Module["printErr"]("Invalid function pointer called with signature 'iiiiiiii'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_iiiiiid(x) { Module["printErr"]("Invalid function pointer called with signature 'iiiiiid'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_vd(x) { Module["printErr"]("Invalid function pointer called with signature 'vd'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_vid(x) { Module["printErr"]("Invalid function pointer called with signature 'vid'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_viiiii(x) { Module["printErr"]("Invalid function pointer called with signature 'viiiii'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_iiiiiiiiii(x) { Module["printErr"]("Invalid function pointer called with signature 'iiiiiiiiii'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_vii(x) { Module["printErr"]("Invalid function pointer called with signature 'vii'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_iiiiiii(x) { Module["printErr"]("Invalid function pointer called with signature 'iiiiiii'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_iiiiiiiiid(x) { Module["printErr"]("Invalid function pointer called with signature 'iiiiiiiiid'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_ii(x) { Module["printErr"]("Invalid function pointer called with signature 'ii'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_viidiii(x) { Module["printErr"]("Invalid function pointer called with signature 'viidiii'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_viidd(x) { Module["printErr"]("Invalid function pointer called with signature 'viidd'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_iidd(x) { Module["printErr"]("Invalid function pointer called with signature 'iidd'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_viiiiiiiii(x) { Module["printErr"]("Invalid function pointer called with signature 'viiiiiiiii'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_viiiidiii(x) { Module["printErr"]("Invalid function pointer called with signature 'viiiidiii'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_viddd(x) { Module["printErr"]("Invalid function pointer called with signature 'viddd'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_iiiiii(x) { Module["printErr"]("Invalid function pointer called with signature 'iiiiii'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_vidi(x) { Module["printErr"]("Invalid function pointer called with signature 'vidi'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_viiidiii(x) { Module["printErr"]("Invalid function pointer called with signature 'viiidiii'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_vdddddd(x) { Module["printErr"]("Invalid function pointer called with signature 'vdddddd'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_iiiidddd(x) { Module["printErr"]("Invalid function pointer called with signature 'iiiidddd'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_viddi(x) { Module["printErr"]("Invalid function pointer called with signature 'viddi'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_vidd(x) { Module["printErr"]("Invalid function pointer called with signature 'vidd'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_iiii(x) { Module["printErr"]("Invalid function pointer called with signature 'iiii'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_viiiiiiiiiiiiiii(x) { Module["printErr"]("Invalid function pointer called with signature 'viiiiiiiiiiiiiii'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_vi(x) { Module["printErr"]("Invalid function pointer called with signature 'vi'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_viiiiii(x) { Module["printErr"]("Invalid function pointer called with signature 'viiiiii'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_iiid(x) { Module["printErr"]("Invalid function pointer called with signature 'iiid'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_vdi(x) { Module["printErr"]("Invalid function pointer called with signature 'vdi'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_viid(x) { Module["printErr"]("Invalid function pointer called with signature 'viid'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_viddddd(x) { Module["printErr"]("Invalid function pointer called with signature 'viddddd'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_di(x) { Module["printErr"]("Invalid function pointer called with signature 'di'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_iiiiiiiiiii(x) { Module["printErr"]("Invalid function pointer called with signature 'iiiiiiiiiii'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_viiidi(x) { Module["printErr"]("Invalid function pointer called with signature 'viiidi'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_viiiiiiii(x) { Module["printErr"]("Invalid function pointer called with signature 'viiiiiiii'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_vidddd(x) { Module["printErr"]("Invalid function pointer called with signature 'vidddd'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_iiiiiiiiiiiii(x) { Module["printErr"]("Invalid function pointer called with signature 'iiiiiiiiiiiii'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_iid(x) { Module["printErr"]("Invalid function pointer called with signature 'iid'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_viiiiiii(x) { Module["printErr"]("Invalid function pointer called with signature 'viiiiiii'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_iiddd(x) { Module["printErr"]("Invalid function pointer called with signature 'iiddd'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_viiid(x) { Module["printErr"]("Invalid function pointer called with signature 'viiid'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_viiiiiiiiii(x) { Module["printErr"]("Invalid function pointer called with signature 'viiiiiiiiii'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_iii(x) { Module["printErr"]("Invalid function pointer called with signature 'iii'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_diii(x) { Module["printErr"]("Invalid function pointer called with signature 'diii'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_viiiiiiiiiii(x) { Module["printErr"]("Invalid function pointer called with signature 'viiiiiiiiiii'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_dii(x) { Module["printErr"]("Invalid function pointer called with signature 'dii'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_viii(x) { Module["printErr"]("Invalid function pointer called with signature 'viii'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_i(x) { Module["printErr"]("Invalid function pointer called with signature 'i'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_iiiiidii(x) { Module["printErr"]("Invalid function pointer called with signature 'iiiiidii'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_iiiid(x) { Module["printErr"]("Invalid function pointer called with signature 'iiiid'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_iiiii(x) { Module["printErr"]("Invalid function pointer called with signature 'iiiii'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_iidii(x) { Module["printErr"]("Invalid function pointer called with signature 'iidii'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_iiiiiiiiiiii(x) { Module["printErr"]("Invalid function pointer called with signature 'iiiiiiiiiiii'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_vdddd(x) { Module["printErr"]("Invalid function pointer called with signature 'vdddd'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_vdd(x) { Module["printErr"]("Invalid function pointer called with signature 'vdd'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_v(x) { Module["printErr"]("Invalid function pointer called with signature 'v'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_iiiiiiiii(x) { Module["printErr"]("Invalid function pointer called with signature 'iiiiiiiii'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_iiiiid(x) { Module["printErr"]("Invalid function pointer called with signature 'iiiiid'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_viiii(x) { Module["printErr"]("Invalid function pointer called with signature 'viiii'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function invoke_iiiiiiii(index,a1,a2,a3,a4,a5,a6,a7) {
  try {
    return Module["dynCall_iiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

function invoke_iiiiiid(index,a1,a2,a3,a4,a5,a6) {
  try {
    return Module["dynCall_iiiiiid"](index,a1,a2,a3,a4,a5,a6);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

function invoke_vd(index,a1) {
  try {
    Module["dynCall_vd"](index,a1);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

function invoke_vid(index,a1,a2) {
  try {
    Module["dynCall_vid"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

function invoke_viiiii(index,a1,a2,a3,a4,a5) {
  try {
    Module["dynCall_viiiii"](index,a1,a2,a3,a4,a5);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

function invoke_iiiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9) {
  try {
    return Module["dynCall_iiiiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

function invoke_vii(index,a1,a2) {
  try {
    Module["dynCall_vii"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

function invoke_iiiiiii(index,a1,a2,a3,a4,a5,a6) {
  try {
    return Module["dynCall_iiiiiii"](index,a1,a2,a3,a4,a5,a6);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

function invoke_iiiiiiiiid(index,a1,a2,a3,a4,a5,a6,a7,a8,a9) {
  try {
    return Module["dynCall_iiiiiiiiid"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

function invoke_ii(index,a1) {
  try {
    return Module["dynCall_ii"](index,a1);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

function invoke_viidiii(index,a1,a2,a3,a4,a5,a6) {
  try {
    Module["dynCall_viidiii"](index,a1,a2,a3,a4,a5,a6);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

function invoke_viidd(index,a1,a2,a3,a4) {
  try {
    Module["dynCall_viidd"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

function invoke_iidd(index,a1,a2,a3) {
  try {
    return Module["dynCall_iidd"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

function invoke_viiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9) {
  try {
    Module["dynCall_viiiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

function invoke_viiiidiii(index,a1,a2,a3,a4,a5,a6,a7,a8) {
  try {
    Module["dynCall_viiiidiii"](index,a1,a2,a3,a4,a5,a6,a7,a8);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

function invoke_viddd(index,a1,a2,a3,a4) {
  try {
    Module["dynCall_viddd"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

function invoke_iiiiii(index,a1,a2,a3,a4,a5) {
  try {
    return Module["dynCall_iiiiii"](index,a1,a2,a3,a4,a5);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

function invoke_vidi(index,a1,a2,a3) {
  try {
    Module["dynCall_vidi"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

function invoke_viiidiii(index,a1,a2,a3,a4,a5,a6,a7) {
  try {
    Module["dynCall_viiidiii"](index,a1,a2,a3,a4,a5,a6,a7);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

function invoke_vdddddd(index,a1,a2,a3,a4,a5,a6) {
  try {
    Module["dynCall_vdddddd"](index,a1,a2,a3,a4,a5,a6);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

function invoke_iiiidddd(index,a1,a2,a3,a4,a5,a6,a7) {
  try {
    return Module["dynCall_iiiidddd"](index,a1,a2,a3,a4,a5,a6,a7);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

function invoke_viddi(index,a1,a2,a3,a4) {
  try {
    Module["dynCall_viddi"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

function invoke_vidd(index,a1,a2,a3) {
  try {
    Module["dynCall_vidd"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

function invoke_iiii(index,a1,a2,a3) {
  try {
    return Module["dynCall_iiii"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

function invoke_viiiiiiiiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12,a13,a14,a15) {
  try {
    Module["dynCall_viiiiiiiiiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12,a13,a14,a15);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

function invoke_vi(index,a1) {
  try {
    Module["dynCall_vi"](index,a1);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

function invoke_viiiiii(index,a1,a2,a3,a4,a5,a6) {
  try {
    Module["dynCall_viiiiii"](index,a1,a2,a3,a4,a5,a6);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

function invoke_iiid(index,a1,a2,a3) {
  try {
    return Module["dynCall_iiid"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

function invoke_vdi(index,a1,a2) {
  try {
    Module["dynCall_vdi"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

function invoke_viid(index,a1,a2,a3) {
  try {
    Module["dynCall_viid"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

function invoke_viddddd(index,a1,a2,a3,a4,a5,a6) {
  try {
    Module["dynCall_viddddd"](index,a1,a2,a3,a4,a5,a6);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

function invoke_di(index,a1) {
  try {
    return Module["dynCall_di"](index,a1);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

function invoke_iiiiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10) {
  try {
    return Module["dynCall_iiiiiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

function invoke_viiidi(index,a1,a2,a3,a4,a5) {
  try {
    Module["dynCall_viiidi"](index,a1,a2,a3,a4,a5);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

function invoke_viiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8) {
  try {
    Module["dynCall_viiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

function invoke_vidddd(index,a1,a2,a3,a4,a5) {
  try {
    Module["dynCall_vidddd"](index,a1,a2,a3,a4,a5);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

function invoke_iiiiiiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12) {
  try {
    return Module["dynCall_iiiiiiiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

function invoke_iid(index,a1,a2) {
  try {
    return Module["dynCall_iid"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

function invoke_viiiiiii(index,a1,a2,a3,a4,a5,a6,a7) {
  try {
    Module["dynCall_viiiiiii"](index,a1,a2,a3,a4,a5,a6,a7);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

function invoke_iiddd(index,a1,a2,a3,a4) {
  try {
    return Module["dynCall_iiddd"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

function invoke_viiid(index,a1,a2,a3,a4) {
  try {
    Module["dynCall_viiid"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

function invoke_viiiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10) {
  try {
    Module["dynCall_viiiiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

function invoke_iii(index,a1,a2) {
  try {
    return Module["dynCall_iii"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

function invoke_diii(index,a1,a2,a3) {
  try {
    return Module["dynCall_diii"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

function invoke_viiiiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11) {
  try {
    Module["dynCall_viiiiiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

function invoke_dii(index,a1,a2) {
  try {
    return Module["dynCall_dii"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

function invoke_viii(index,a1,a2,a3) {
  try {
    Module["dynCall_viii"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

function invoke_i(index) {
  try {
    return Module["dynCall_i"](index);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

function invoke_iiiiidii(index,a1,a2,a3,a4,a5,a6,a7) {
  try {
    return Module["dynCall_iiiiidii"](index,a1,a2,a3,a4,a5,a6,a7);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

function invoke_iiiid(index,a1,a2,a3,a4) {
  try {
    return Module["dynCall_iiiid"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

function invoke_iiiii(index,a1,a2,a3,a4) {
  try {
    return Module["dynCall_iiiii"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

function invoke_iidii(index,a1,a2,a3,a4) {
  try {
    return Module["dynCall_iidii"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

function invoke_iiiiiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11) {
  try {
    return Module["dynCall_iiiiiiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

function invoke_vdddd(index,a1,a2,a3,a4) {
  try {
    Module["dynCall_vdddd"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

function invoke_vdd(index,a1,a2) {
  try {
    Module["dynCall_vdd"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

function invoke_v(index) {
  try {
    Module["dynCall_v"](index);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

function invoke_iiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8) {
  try {
    return Module["dynCall_iiiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

function invoke_iiiiid(index,a1,a2,a3,a4,a5) {
  try {
    return Module["dynCall_iiiiid"](index,a1,a2,a3,a4,a5);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

function invoke_viiii(index,a1,a2,a3,a4) {
  try {
    Module["dynCall_viiii"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

Module.asmGlobalArg = { "Math": Math, "Int8Array": Int8Array, "Int16Array": Int16Array, "Int32Array": Int32Array, "Uint8Array": Uint8Array, "Uint16Array": Uint16Array, "Uint32Array": Uint32Array, "Float32Array": Float32Array, "Float64Array": Float64Array, "NaN": NaN, "Infinity": Infinity };

Module.asmLibraryArg = { "abort": abort, "assert": assert, "enlargeMemory": enlargeMemory, "getTotalMemory": getTotalMemory, "abortOnCannotGrowMemory": abortOnCannotGrowMemory, "abortStackOverflow": abortStackOverflow, "nullFunc_iiiiiiii": nullFunc_iiiiiiii, "nullFunc_iiiiiid": nullFunc_iiiiiid, "nullFunc_vd": nullFunc_vd, "nullFunc_vid": nullFunc_vid, "nullFunc_viiiii": nullFunc_viiiii, "nullFunc_iiiiiiiiii": nullFunc_iiiiiiiiii, "nullFunc_vii": nullFunc_vii, "nullFunc_iiiiiii": nullFunc_iiiiiii, "nullFunc_iiiiiiiiid": nullFunc_iiiiiiiiid, "nullFunc_ii": nullFunc_ii, "nullFunc_viidiii": nullFunc_viidiii, "nullFunc_viidd": nullFunc_viidd, "nullFunc_iidd": nullFunc_iidd, "nullFunc_viiiiiiiii": nullFunc_viiiiiiiii, "nullFunc_viiiidiii": nullFunc_viiiidiii, "nullFunc_viddd": nullFunc_viddd, "nullFunc_iiiiii": nullFunc_iiiiii, "nullFunc_vidi": nullFunc_vidi, "nullFunc_viiidiii": nullFunc_viiidiii, "nullFunc_vdddddd": nullFunc_vdddddd, "nullFunc_iiiidddd": nullFunc_iiiidddd, "nullFunc_viddi": nullFunc_viddi, "nullFunc_vidd": nullFunc_vidd, "nullFunc_iiii": nullFunc_iiii, "nullFunc_viiiiiiiiiiiiiii": nullFunc_viiiiiiiiiiiiiii, "nullFunc_vi": nullFunc_vi, "nullFunc_viiiiii": nullFunc_viiiiii, "nullFunc_iiid": nullFunc_iiid, "nullFunc_vdi": nullFunc_vdi, "nullFunc_viid": nullFunc_viid, "nullFunc_viddddd": nullFunc_viddddd, "nullFunc_di": nullFunc_di, "nullFunc_iiiiiiiiiii": nullFunc_iiiiiiiiiii, "nullFunc_viiidi": nullFunc_viiidi, "nullFunc_viiiiiiii": nullFunc_viiiiiiii, "nullFunc_vidddd": nullFunc_vidddd, "nullFunc_iiiiiiiiiiiii": nullFunc_iiiiiiiiiiiii, "nullFunc_iid": nullFunc_iid, "nullFunc_viiiiiii": nullFunc_viiiiiii, "nullFunc_iiddd": nullFunc_iiddd, "nullFunc_viiid": nullFunc_viiid, "nullFunc_viiiiiiiiii": nullFunc_viiiiiiiiii, "nullFunc_iii": nullFunc_iii, "nullFunc_diii": nullFunc_diii, "nullFunc_viiiiiiiiiii": nullFunc_viiiiiiiiiii, "nullFunc_dii": nullFunc_dii, "nullFunc_viii": nullFunc_viii, "nullFunc_i": nullFunc_i, "nullFunc_iiiiidii": nullFunc_iiiiidii, "nullFunc_iiiid": nullFunc_iiiid, "nullFunc_iiiii": nullFunc_iiiii, "nullFunc_iidii": nullFunc_iidii, "nullFunc_iiiiiiiiiiii": nullFunc_iiiiiiiiiiii, "nullFunc_vdddd": nullFunc_vdddd, "nullFunc_vdd": nullFunc_vdd, "nullFunc_v": nullFunc_v, "nullFunc_iiiiiiiii": nullFunc_iiiiiiiii, "nullFunc_iiiiid": nullFunc_iiiiid, "nullFunc_viiii": nullFunc_viiii, "invoke_iiiiiiii": invoke_iiiiiiii, "invoke_iiiiiid": invoke_iiiiiid, "invoke_vd": invoke_vd, "invoke_vid": invoke_vid, "invoke_viiiii": invoke_viiiii, "invoke_iiiiiiiiii": invoke_iiiiiiiiii, "invoke_vii": invoke_vii, "invoke_iiiiiii": invoke_iiiiiii, "invoke_iiiiiiiiid": invoke_iiiiiiiiid, "invoke_ii": invoke_ii, "invoke_viidiii": invoke_viidiii, "invoke_viidd": invoke_viidd, "invoke_iidd": invoke_iidd, "invoke_viiiiiiiii": invoke_viiiiiiiii, "invoke_viiiidiii": invoke_viiiidiii, "invoke_viddd": invoke_viddd, "invoke_iiiiii": invoke_iiiiii, "invoke_vidi": invoke_vidi, "invoke_viiidiii": invoke_viiidiii, "invoke_vdddddd": invoke_vdddddd, "invoke_iiiidddd": invoke_iiiidddd, "invoke_viddi": invoke_viddi, "invoke_vidd": invoke_vidd, "invoke_iiii": invoke_iiii, "invoke_viiiiiiiiiiiiiii": invoke_viiiiiiiiiiiiiii, "invoke_vi": invoke_vi, "invoke_viiiiii": invoke_viiiiii, "invoke_iiid": invoke_iiid, "invoke_vdi": invoke_vdi, "invoke_viid": invoke_viid, "invoke_viddddd": invoke_viddddd, "invoke_di": invoke_di, "invoke_iiiiiiiiiii": invoke_iiiiiiiiiii, "invoke_viiidi": invoke_viiidi, "invoke_viiiiiiii": invoke_viiiiiiii, "invoke_vidddd": invoke_vidddd, "invoke_iiiiiiiiiiiii": invoke_iiiiiiiiiiiii, "invoke_iid": invoke_iid, "invoke_viiiiiii": invoke_viiiiiii, "invoke_iiddd": invoke_iiddd, "invoke_viiid": invoke_viiid, "invoke_viiiiiiiiii": invoke_viiiiiiiiii, "invoke_iii": invoke_iii, "invoke_diii": invoke_diii, "invoke_viiiiiiiiiii": invoke_viiiiiiiiiii, "invoke_dii": invoke_dii, "invoke_viii": invoke_viii, "invoke_i": invoke_i, "invoke_iiiiidii": invoke_iiiiidii, "invoke_iiiid": invoke_iiiid, "invoke_iiiii": invoke_iiiii, "invoke_iidii": invoke_iidii, "invoke_iiiiiiiiiiii": invoke_iiiiiiiiiiii, "invoke_vdddd": invoke_vdddd, "invoke_vdd": invoke_vdd, "invoke_v": invoke_v, "invoke_iiiiiiiii": invoke_iiiiiiiii, "invoke_iiiiid": invoke_iiiiid, "invoke_viiii": invoke_viiii, "_emscripten_glGetTexParameterfv": _emscripten_glGetTexParameterfv, "_glClearStencil": _glClearStencil, "___syscall220": ___syscall220, "_emscripten_glBlendFuncSeparate": _emscripten_glBlendFuncSeparate, "_glTexParameteriv": _glTexParameteriv, "___assert_fail": ___assert_fail, "_emscripten_glDepthFunc": _emscripten_glDepthFunc, "_emscripten_memcpy_big": _emscripten_memcpy_big, "_pthread_attr_init": _pthread_attr_init, "_glStencilFunc": _glStencilFunc, "_emscripten_glUniform1f": _emscripten_glUniform1f, "emscriptenWebGLComputeImageSize": emscriptenWebGLComputeImageSize, "___syscall221": ___syscall221, "_emscripten_glUniform1i": _emscripten_glUniform1i, "_emscripten_glGetIntegerv": _emscripten_glGetIntegerv, "_emscripten_glIsProgram": _emscripten_glIsProgram, "___cxa_rethrow": ___cxa_rethrow, "_emscripten_glTexParameteriv": _emscripten_glTexParameteriv, "___syscall140": ___syscall140, "___syscall145": ___syscall145, "___syscall146": ___syscall146, "_emscripten_glAttachShader": _emscripten_glAttachShader, "_emscripten_get_now_is_monotonic": _emscripten_get_now_is_monotonic, "_emscripten_glStencilFunc": _emscripten_glStencilFunc, "_emscripten_glTexParameterfv": _emscripten_glTexParameterfv, "_emscripten_glUniformMatrix2fv": _emscripten_glUniformMatrix2fv, "_emscripten_glDrawArraysInstanced": _emscripten_glDrawArraysInstanced, "_glDepthMask": _glDepthMask, "_emscripten_glVertexAttrib2fv": _emscripten_glVertexAttrib2fv, "_glViewport": _glViewport, "_emscripten_glFlush": _emscripten_glFlush, "___cxa_call_unexpected": ___cxa_call_unexpected, "_nanosleep": _nanosleep, "___syscall91": ___syscall91, "_pthread_once": _pthread_once, "_dlopen": _dlopen, "_eglWaitClient": _eglWaitClient, "_emscripten_glTexCoordPointer": _emscripten_glTexCoordPointer, "__addDays": __addDays, "_glGenTextures": _glGenTextures, "_emscripten_glStencilFuncSeparate": _emscripten_glStencilFuncSeparate, "_emscripten_glVertexAttrib3f": _emscripten_glVertexAttrib3f, "_dlerror": _dlerror, "_emscripten_get_gamepad_status": _emscripten_get_gamepad_status, "_sched_yield": _sched_yield, "_emscripten_glUniform1iv": _emscripten_glUniform1iv, "emscriptenWebGLGetUniform": emscriptenWebGLGetUniform, "_glClearColor": _glClearColor, "_glFinish": _glFinish, "_emscripten_glGetBufferParameteriv": _emscripten_glGetBufferParameteriv, "_emscripten_glVertexAttrib4fv": _emscripten_glVertexAttrib4fv, "_pthread_getspecific": _pthread_getspecific, "_glDrawArrays": _glDrawArrays, "_pthread_cond_signal": _pthread_cond_signal, "_emscripten_glDepthRange": _emscripten_glDepthRange, "_emscripten_request_pointerlock": _emscripten_request_pointerlock, "_emscripten_asm_const_iii": _emscripten_asm_const_iii, "_eglMakeCurrent": _eglMakeCurrent, "_emscripten_glCopyTexImage2D": _emscripten_glCopyTexImage2D, "_emscripten_glFramebufferTexture2D": _emscripten_glFramebufferTexture2D, "_pthread_cond_timedwait": _pthread_cond_timedwait, "_emscripten_glRenderbufferStorage": _emscripten_glRenderbufferStorage, "_emscripten_set_keydown_callback": _emscripten_set_keydown_callback, "_emscripten_glVertexPointer": _emscripten_glVertexPointer, "_eglInitialize": _eglInitialize, "_emscripten_glBufferSubData": _emscripten_glBufferSubData, "_emscripten_glGetUniformfv": _emscripten_glGetUniformfv, "_emscripten_glStencilOp": _emscripten_glStencilOp, "_emscripten_glBlendEquation": _emscripten_glBlendEquation, "_emscripten_glVertexAttrib1fv": _emscripten_glVertexAttrib1fv, "_dlclose": _dlclose, "_emscripten_glGetProgramInfoLog": _emscripten_glGetProgramInfoLog, "_emscripten_glUniform4fv": _emscripten_glUniform4fv, "___cxa_throw": ___cxa_throw, "_emscripten_glUniform2fv": _emscripten_glUniform2fv, "_emscripten_glBindBuffer": _emscripten_glBindBuffer, "_emscripten_glGetFloatv": _emscripten_glGetFloatv, "_pthread_mutex_init": _pthread_mutex_init, "_glTexSubImage2D": _glTexSubImage2D, "_emscripten_glGenRenderbuffers": _emscripten_glGenRenderbuffers, "_eglGetDisplay": _eglGetDisplay, "_emscripten_glCullFace": _emscripten_glCullFace, "_emscripten_glStencilMaskSeparate": _emscripten_glStencilMaskSeparate, "_emscripten_glUniform3fv": _emscripten_glUniform3fv, "_emscripten_asm_const_ii": _emscripten_asm_const_ii, "_emscripten_glDisableVertexAttribArray": _emscripten_glDisableVertexAttribArray, "_eglBindAPI": _eglBindAPI, "_eglCreateContext": _eglCreateContext, "_emscripten_set_touchstart_callback": _emscripten_set_touchstart_callback, "_emscripten_glGetBooleanv": _emscripten_glGetBooleanv, "_emscripten_glVertexAttribDivisor": _emscripten_glVertexAttribDivisor, "_emscripten_glGenBuffers": _emscripten_glGenBuffers, "_emscripten_glDeleteObjectARB": _emscripten_glDeleteObjectARB, "_emscripten_glGetShaderPrecisionFormat": _emscripten_glGetShaderPrecisionFormat, "_emscripten_request_fullscreen_strategy": _emscripten_request_fullscreen_strategy, "_emscripten_glIsEnabled": _emscripten_glIsEnabled, "_emscripten_glStencilOpSeparate": _emscripten_glStencilOpSeparate, "_pthread_cleanup_pop": _pthread_cleanup_pop, "_emscripten_asm_const_iiiii": _emscripten_asm_const_iiiii, "___cxa_free_exception": ___cxa_free_exception, "___cxa_find_matching_catch": ___cxa_find_matching_catch, "_emscripten_glShaderBinary": _emscripten_glShaderBinary, "_glDrawElements": _glDrawElements, "_emscripten_glValidateProgram": _emscripten_glValidateProgram, "_emscripten_glUniform4iv": _emscripten_glUniform4iv, "___setErrNo": ___setErrNo, "_eglSwapBuffers": _eglSwapBuffers, "_emscripten_glVertexAttrib2f": _emscripten_glVertexAttrib2f, "___resumeException": ___resumeException, "_emscripten_glGetError": _emscripten_glGetError, "_emscripten_glBufferData": _emscripten_glBufferData, "_emscripten_glReadPixels": _emscripten_glReadPixels, "_glGetIntegerv": _glGetIntegerv, "_eglCreateWindowSurface": _eglCreateWindowSurface, "_emscripten_glClearStencil": _emscripten_glClearStencil, "emscriptenWebGLGet": emscriptenWebGLGet, "_emscripten_get_device_pixel_ratio": _emscripten_get_device_pixel_ratio, "_emscripten_set_mouseup_callback": _emscripten_set_mouseup_callback, "_emscripten_glFinish": _emscripten_glFinish, "_emscripten_glClearDepth": _emscripten_glClearDepth, "_emscripten_glUniform1fv": _emscripten_glUniform1fv, "_emscripten_set_resize_callback": _emscripten_set_resize_callback, "_emscripten_glUniform4i": _emscripten_glUniform4i, "_llvm_pow_f64": _llvm_pow_f64, "_emscripten_glUniform4f": _emscripten_glUniform4f, "_emscripten_glBlendFunc": _emscripten_glBlendFunc, "_emscripten_glStencilMask": _emscripten_glStencilMask, "__emscripten_sample_gamepad_data": __emscripten_sample_gamepad_data, "_glBindTexture": _glBindTexture, "_strftime": _strftime, "_emscripten_glGetVertexAttribiv": _emscripten_glGetVertexAttribiv, "_glReadPixels": _glReadPixels, "_emscripten_glUniformMatrix3fv": _emscripten_glUniformMatrix3fv, "___map_file": ___map_file, "___syscall33": ___syscall33, "_pthread_key_create": _pthread_key_create, "_pthread_setspecific": _pthread_setspecific, "__setLetterbox": __setLetterbox, "___syscall39": ___syscall39, "_emscripten_glGetObjectParameterivARB": _emscripten_glGetObjectParameterivARB, "_emscripten_glGetUniformiv": _emscripten_glGetUniformiv, "_glScissor": _glScissor, "_eglDestroySurface": _eglDestroySurface, "_sigaction": _sigaction, "_emscripten_glCreateShader": _emscripten_glCreateShader, "___cxa_find_matching_catch_2": ___cxa_find_matching_catch_2, "___cxa_find_matching_catch_3": ___cxa_find_matching_catch_3, "_emscripten_glDeleteTextures": _emscripten_glDeleteTextures, "_eglDestroyContext": _eglDestroyContext, "_emscripten_exit_fullscreen": _emscripten_exit_fullscreen, "_strftime_l": _strftime_l, "_emscripten_glColorMask": _emscripten_glColorMask, "_pthread_testcancel": _pthread_testcancel, "_emscripten_glBindTexture": _emscripten_glBindTexture, "_glTexParameterfv": _glTexParameterfv, "_emscripten_set_main_loop": _emscripten_set_main_loop, "_emscripten_glIsShader": _emscripten_glIsShader, "_emscripten_asm_const_iiii": _emscripten_asm_const_iiii, "_emscripten_glCompressedTexImage2D": _emscripten_glCompressedTexImage2D, "_glDisable": _glDisable, "_emscripten_glGetInfoLogARB": _emscripten_glGetInfoLogARB, "_atexit": _atexit, "_emscripten_glDeleteVertexArrays": _emscripten_glDeleteVertexArrays, "_emscripten_glReleaseShaderCompiler": _emscripten_glReleaseShaderCompiler, "_dlsym": _dlsym, "_emscripten_glFrontFace": _emscripten_glFrontFace, "__ZSt18uncaught_exceptionv": __ZSt18uncaught_exceptionv, "_emscripten_glUseProgram": _emscripten_glUseProgram, "_clock_gettime": _clock_gettime, "_glShaderBinary": _glShaderBinary, "_emscripten_set_touchmove_callback": _emscripten_set_touchmove_callback, "_glBlendFunc": _glBlendFunc, "_emscripten_glUniform3iv": _emscripten_glUniform3iv, "_pthread_mutexattr_settype": _pthread_mutexattr_settype, "___cxa_atexit": ___cxa_atexit, "_emscripten_glScissor": _emscripten_glScissor, "_pthread_cancel": _pthread_cancel, "_pthread_cleanup_push": _pthread_cleanup_push, "_emscripten_set_element_css_size": _emscripten_set_element_css_size, "_llvm_trap": _llvm_trap, "_glPixelStorei": _glPixelStorei, "_emscripten_glIsBuffer": _emscripten_glIsBuffer, "_emscripten_glVertexAttrib1f": _emscripten_glVertexAttrib1f, "_emscripten_set_keyup_callback": _emscripten_set_keyup_callback, "_emscripten_glCompressedTexSubImage2D": _emscripten_glCompressedTexSubImage2D, "_emscripten_glGetAttachedShaders": _emscripten_glGetAttachedShaders, "_emscripten_glGenTextures": _emscripten_glGenTextures, "_eglGetConfigAttrib": _eglGetConfigAttrib, "_pthread_cond_init": _pthread_cond_init, "_emscripten_glGetTexParameteriv": _emscripten_glGetTexParameteriv, "_glDeleteTextures": _glDeleteTextures, "_emscripten_set_mousedown_callback": _emscripten_set_mousedown_callback, "_emscripten_glClientActiveTexture": _emscripten_glClientActiveTexture, "_emscripten_glCheckFramebufferStatus": _emscripten_glCheckFramebufferStatus, "_eglWaitGL": _eglWaitGL, "_emscripten_glUniform3f": _emscripten_glUniform3f, "_emscripten_glUniform3i": _emscripten_glUniform3i, "_emscripten_glDeleteShader": _emscripten_glDeleteShader, "_glEnable": _glEnable, "_glGetString": _glGetString, "_emscripten_glGetUniformLocation": _emscripten_glGetUniformLocation, "_emscripten_glEnableVertexAttribArray": _emscripten_glEnableVertexAttribArray, "_emscripten_get_now": _emscripten_get_now, "__registerRestoreOldStyle": __registerRestoreOldStyle, "_llvm_exp2_f32": _llvm_exp2_f32, "_gettimeofday": _gettimeofday, "_eglWaitNative": _eglWaitNative, "_emscripten_glEnableClientState": _emscripten_glEnableClientState, "_pthread_join": _pthread_join, "_eglChooseConfig": _eglChooseConfig, "_emscripten_glDrawElements": _emscripten_glDrawElements, "_emscripten_get_num_gamepads": _emscripten_get_num_gamepads, "___buildEnvironment": ___buildEnvironment, "_glClearDepthf": _glClearDepthf, "_emscripten_glGetAttribLocation": _emscripten_glGetAttribLocation, "_emscripten_glDisable": _emscripten_glDisable, "___cxa_end_catch": ___cxa_end_catch, "_emscripten_glDeleteRenderbuffers": _emscripten_glDeleteRenderbuffers, "_emscripten_glDrawElementsInstanced": _emscripten_glDrawElementsInstanced, "_emscripten_glVertexAttrib4f": _emscripten_glVertexAttrib4f, "_emscripten_glPixelStorei": _emscripten_glPixelStorei, "_getenv": _getenv, "_emscripten_set_gamepaddisconnected_callback": _emscripten_set_gamepaddisconnected_callback, "_emscripten_glFramebufferRenderbuffer": _emscripten_glFramebufferRenderbuffer, "_emscripten_glRotatef": _emscripten_glRotatef, "_emscripten_glGetShaderiv": _emscripten_glGetShaderiv, "___cxa_pure_virtual": ___cxa_pure_virtual, "_emscripten_glUniformMatrix4fv": _emscripten_glUniformMatrix4fv, "_emscripten_glGetPointerv": _emscripten_glGetPointerv, "_pthread_cond_wait": _pthread_cond_wait, "_emscripten_set_blur_callback": _emscripten_set_blur_callback, "emscriptenWebGLGetTexPixelData": emscriptenWebGLGetTexPixelData, "_emscripten_glIsRenderbuffer": _emscripten_glIsRenderbuffer, "_emscripten_glLoadMatrixf": _emscripten_glLoadMatrixf, "_emscripten_set_mousemove_callback": _emscripten_set_mousemove_callback, "_emscripten_set_touchcancel_callback": _emscripten_set_touchcancel_callback, "_emscripten_set_focus_callback": _emscripten_set_focus_callback, "_emscripten_glGetVertexAttribfv": _emscripten_glGetVertexAttribfv, "_emscripten_glVertexAttrib3fv": _emscripten_glVertexAttrib3fv, "_emscripten_glCompileShader": _emscripten_glCompileShader, "_glClear": _glClear, "__arraySum": __arraySum, "_emscripten_glLinkProgram": _emscripten_glLinkProgram, "_emscripten_get_pointerlock_status": _emscripten_get_pointerlock_status, "_emscripten_glDrawRangeElements": _emscripten_glDrawRangeElements, "___unlock": ___unlock, "_pthread_create": _pthread_create, "_emscripten_glDeleteFramebuffers": _emscripten_glDeleteFramebuffers, "_glColorMask": _glColorMask, "_emscripten_glClearColor": _emscripten_glClearColor, "_glCopyTexSubImage2D": _glCopyTexSubImage2D, "_emscripten_glCreateProgram": _emscripten_glCreateProgram, "_glTexParameteri": _glTexParameteri, "_emscripten_glDetachShader": _emscripten_glDetachShader, "_glTexParameterf": _glTexParameterf, "_emscripten_do_request_fullscreen": _emscripten_do_request_fullscreen, "_emscripten_set_mouseleave_callback": _emscripten_set_mouseleave_callback, "_emscripten_glGetRenderbufferParameteriv": _emscripten_glGetRenderbufferParameteriv, "_emscripten_set_fullscreenchange_callback": _emscripten_set_fullscreenchange_callback, "_emscripten_glVertexAttribPointer": _emscripten_glVertexAttribPointer, "_emscripten_glDrawArrays": _emscripten_glDrawArrays, "_emscripten_glPolygonOffset": _emscripten_glPolygonOffset, "_emscripten_glBlendColor": _emscripten_glBlendColor, "_signal": _signal, "_emscripten_set_main_loop_timing": _emscripten_set_main_loop_timing, "___cxa_begin_catch": ___cxa_begin_catch, "_emscripten_glGetProgramiv": _emscripten_glGetProgramiv, "_glStencilOp": _glStencilOp, "_emscripten_glGetShaderSource": _emscripten_glGetShaderSource, "_pthread_attr_getstacksize": _pthread_attr_getstacksize, "_emscripten_glTexImage2D": _emscripten_glTexImage2D, "__isLeapYear": __isLeapYear, "_emscripten_glBlendEquationSeparate": _emscripten_glBlendEquationSeparate, "_emscripten_glGetString": _emscripten_glGetString, "_emscripten_glIsFramebuffer": _emscripten_glIsFramebuffer, "_emscripten_glBindProgramARB": _emscripten_glBindProgramARB, "_glutCreateWindow": _glutCreateWindow, "___syscall85": ___syscall85, "_emscripten_glUniform2i": _emscripten_glUniform2i, "_emscripten_glUniform2f": _emscripten_glUniform2f, "_emscripten_glTexParameterf": _emscripten_glTexParameterf, "_emscripten_glTexParameteri": _emscripten_glTexParameteri, "_glutInitDisplayMode": _glutInitDisplayMode, "_emscripten_glGenVertexArrays": _emscripten_glGenVertexArrays, "_pthread_cond_destroy": _pthread_cond_destroy, "_emscripten_set_visibilitychange_callback": _emscripten_set_visibilitychange_callback, "_eglGetProcAddress": _eglGetProcAddress, "_emscripten_glBindAttribLocation": _emscripten_glBindAttribLocation, "___cxa_allocate_exception": ___cxa_allocate_exception, "_emscripten_set_canvas_size": _emscripten_set_canvas_size, "_emscripten_glClearDepthf": _emscripten_glClearDepthf, "_emscripten_set_mouseenter_callback": _emscripten_set_mouseenter_callback, "_emscripten_glMatrixMode": _emscripten_glMatrixMode, "_emscripten_glNormalPointer": _emscripten_glNormalPointer, "_emscripten_glBindVertexArray": _emscripten_glBindVertexArray, "_emscripten_glEnable": _emscripten_glEnable, "___lock": ___lock, "_emscripten_glBindFramebuffer": _emscripten_glBindFramebuffer, "___syscall6": ___syscall6, "___syscall5": ___syscall5, "_emscripten_glBindRenderbuffer": _emscripten_glBindRenderbuffer, "_time": _time, "_emscripten_glGetFramebufferAttachmentParameteriv": _emscripten_glGetFramebufferAttachmentParameteriv, "_emscripten_glGetActiveAttrib": _emscripten_glGetActiveAttrib, "_emscripten_set_keypress_callback": _emscripten_set_keypress_callback, "_emscripten_glClear": _emscripten_glClear, "_emscripten_glGetShaderInfoLog": _emscripten_glGetShaderInfoLog, "_emscripten_glGetVertexAttribPointerv": _emscripten_glGetVertexAttribPointerv, "_emscripten_glGetActiveUniform": _emscripten_glGetActiveUniform, "emscriptenWebGLGetVertexAttrib": emscriptenWebGLGetVertexAttrib, "___syscall197": ___syscall197, "___syscall195": ___syscall195, "_eglSwapInterval": _eglSwapInterval, "_emscripten_glDeleteProgram": _emscripten_glDeleteProgram, "_glutDestroyWindow": _glutDestroyWindow, "_emscripten_glTexSubImage2D": _emscripten_glTexSubImage2D, "_pthread_mutex_destroy": _pthread_mutex_destroy, "_emscripten_glColorPointer": _emscripten_glColorPointer, "_emscripten_glViewport": _emscripten_glViewport, "_emscripten_glDepthMask": _emscripten_glDepthMask, "_emscripten_glDrawBuffers": _emscripten_glDrawBuffers, "_emscripten_glLineWidth": _emscripten_glLineWidth, "_emscripten_exit_pointerlock": _emscripten_exit_pointerlock, "_emscripten_set_gamepadconnected_callback": _emscripten_set_gamepadconnected_callback, "_abort": _abort, "_glTexImage2D": _glTexImage2D, "_emscripten_glGenFramebuffers": _emscripten_glGenFramebuffers, "_glFlush": _glFlush, "_emscripten_glLoadIdentity": _emscripten_glLoadIdentity, "_emscripten_glShaderSource": _emscripten_glShaderSource, "___gxx_personality_v0": ___gxx_personality_v0, "_usleep": _usleep, "_emscripten_set_touchend_callback": _emscripten_set_touchend_callback, "_glGetError": _glGetError, "_eglTerminate": _eglTerminate, "_emscripten_glSampleCoverage": _emscripten_glSampleCoverage, "_emscripten_glFrustum": _emscripten_glFrustum, "_emscripten_glDepthRangef": _emscripten_glDepthRangef, "_emscripten_glGenerateMipmap": _emscripten_glGenerateMipmap, "_glCopyTexImage2D": _glCopyTexImage2D, "_emscripten_glIsTexture": _emscripten_glIsTexture, "_pthread_attr_setstacksize": _pthread_attr_setstacksize, "_emscripten_glHint": _emscripten_glHint, "_emscripten_glActiveTexture": _emscripten_glActiveTexture, "_emscripten_set_wheel_callback": _emscripten_set_wheel_callback, "_emscripten_glDeleteBuffers": _emscripten_glDeleteBuffers, "___syscall54": ___syscall54, "_emscripten_glUniform2iv": _emscripten_glUniform2iv, "_pthread_mutexattr_init": _pthread_mutexattr_init, "_emscripten_asm_const_i": _emscripten_asm_const_i, "_emscripten_get_element_css_size": _emscripten_get_element_css_size, "_emscripten_glCopyTexSubImage2D": _emscripten_glCopyTexSubImage2D, "_glStencilMask": _glStencilMask, "DYNAMICTOP_PTR": DYNAMICTOP_PTR, "tempDoublePtr": tempDoublePtr, "ABORT": ABORT, "STACKTOP": STACKTOP, "STACK_MAX": STACK_MAX, "cttz_i8": cttz_i8, "___dso_handle": ___dso_handle };
// EMSCRIPTEN_START_ASM
var asm = (function(global, env, buffer) {
'almost asm';


  var HEAP8 = new global.Int8Array(buffer);
  var HEAP16 = new global.Int16Array(buffer);
  var HEAP32 = new global.Int32Array(buffer);
  var HEAPU8 = new global.Uint8Array(buffer);
  var HEAPU16 = new global.Uint16Array(buffer);
  var HEAPU32 = new global.Uint32Array(buffer);
  var HEAPF32 = new global.Float32Array(buffer);
  var HEAPF64 = new global.Float64Array(buffer);

  var DYNAMICTOP_PTR=env.DYNAMICTOP_PTR|0;
  var tempDoublePtr=env.tempDoublePtr|0;
  var ABORT=env.ABORT|0;
  var STACKTOP=env.STACKTOP|0;
  var STACK_MAX=env.STACK_MAX|0;
  var cttz_i8=env.cttz_i8|0;
  var ___dso_handle=env.___dso_handle|0;

  var __THREW__ = 0;
  var threwValue = 0;
  var setjmpId = 0;
  var undef = 0;
  var nan = global.NaN, inf = global.Infinity;
  var tempInt = 0, tempBigInt = 0, tempBigIntS = 0, tempValue = 0, tempDouble = 0.0;
  var tempRet0 = 0;

  var Math_floor=global.Math.floor;
  var Math_abs=global.Math.abs;
  var Math_sqrt=global.Math.sqrt;
  var Math_pow=global.Math.pow;
  var Math_cos=global.Math.cos;
  var Math_sin=global.Math.sin;
  var Math_tan=global.Math.tan;
  var Math_acos=global.Math.acos;
  var Math_asin=global.Math.asin;
  var Math_atan=global.Math.atan;
  var Math_atan2=global.Math.atan2;
  var Math_exp=global.Math.exp;
  var Math_log=global.Math.log;
  var Math_ceil=global.Math.ceil;
  var Math_imul=global.Math.imul;
  var Math_min=global.Math.min;
  var Math_max=global.Math.max;
  var Math_clz32=global.Math.clz32;
  var abort=env.abort;
  var assert=env.assert;
  var enlargeMemory=env.enlargeMemory;
  var getTotalMemory=env.getTotalMemory;
  var abortOnCannotGrowMemory=env.abortOnCannotGrowMemory;
  var abortStackOverflow=env.abortStackOverflow;
  var nullFunc_iiiiiiii=env.nullFunc_iiiiiiii;
  var nullFunc_iiiiiid=env.nullFunc_iiiiiid;
  var nullFunc_vd=env.nullFunc_vd;
  var nullFunc_vid=env.nullFunc_vid;
  var nullFunc_viiiii=env.nullFunc_viiiii;
  var nullFunc_iiiiiiiiii=env.nullFunc_iiiiiiiiii;
  var nullFunc_vii=env.nullFunc_vii;
  var nullFunc_iiiiiii=env.nullFunc_iiiiiii;
  var nullFunc_iiiiiiiiid=env.nullFunc_iiiiiiiiid;
  var nullFunc_ii=env.nullFunc_ii;
  var nullFunc_viidiii=env.nullFunc_viidiii;
  var nullFunc_viidd=env.nullFunc_viidd;
  var nullFunc_iidd=env.nullFunc_iidd;
  var nullFunc_viiiiiiiii=env.nullFunc_viiiiiiiii;
  var nullFunc_viiiidiii=env.nullFunc_viiiidiii;
  var nullFunc_viddd=env.nullFunc_viddd;
  var nullFunc_iiiiii=env.nullFunc_iiiiii;
  var nullFunc_vidi=env.nullFunc_vidi;
  var nullFunc_viiidiii=env.nullFunc_viiidiii;
  var nullFunc_vdddddd=env.nullFunc_vdddddd;
  var nullFunc_iiiidddd=env.nullFunc_iiiidddd;
  var nullFunc_viddi=env.nullFunc_viddi;
  var nullFunc_vidd=env.nullFunc_vidd;
  var nullFunc_iiii=env.nullFunc_iiii;
  var nullFunc_viiiiiiiiiiiiiii=env.nullFunc_viiiiiiiiiiiiiii;
  var nullFunc_vi=env.nullFunc_vi;
  var nullFunc_viiiiii=env.nullFunc_viiiiii;
  var nullFunc_iiid=env.nullFunc_iiid;
  var nullFunc_vdi=env.nullFunc_vdi;
  var nullFunc_viid=env.nullFunc_viid;
  var nullFunc_viddddd=env.nullFunc_viddddd;
  var nullFunc_di=env.nullFunc_di;
  var nullFunc_iiiiiiiiiii=env.nullFunc_iiiiiiiiiii;
  var nullFunc_viiidi=env.nullFunc_viiidi;
  var nullFunc_viiiiiiii=env.nullFunc_viiiiiiii;
  var nullFunc_vidddd=env.nullFunc_vidddd;
  var nullFunc_iiiiiiiiiiiii=env.nullFunc_iiiiiiiiiiiii;
  var nullFunc_iid=env.nullFunc_iid;
  var nullFunc_viiiiiii=env.nullFunc_viiiiiii;
  var nullFunc_iiddd=env.nullFunc_iiddd;
  var nullFunc_viiid=env.nullFunc_viiid;
  var nullFunc_viiiiiiiiii=env.nullFunc_viiiiiiiiii;
  var nullFunc_iii=env.nullFunc_iii;
  var nullFunc_diii=env.nullFunc_diii;
  var nullFunc_viiiiiiiiiii=env.nullFunc_viiiiiiiiiii;
  var nullFunc_dii=env.nullFunc_dii;
  var nullFunc_viii=env.nullFunc_viii;
  var nullFunc_i=env.nullFunc_i;
  var nullFunc_iiiiidii=env.nullFunc_iiiiidii;
  var nullFunc_iiiid=env.nullFunc_iiiid;
  var nullFunc_iiiii=env.nullFunc_iiiii;
  var nullFunc_iidii=env.nullFunc_iidii;
  var nullFunc_iiiiiiiiiiii=env.nullFunc_iiiiiiiiiiii;
  var nullFunc_vdddd=env.nullFunc_vdddd;
  var nullFunc_vdd=env.nullFunc_vdd;
  var nullFunc_v=env.nullFunc_v;
  var nullFunc_iiiiiiiii=env.nullFunc_iiiiiiiii;
  var nullFunc_iiiiid=env.nullFunc_iiiiid;
  var nullFunc_viiii=env.nullFunc_viiii;
  var invoke_iiiiiiii=env.invoke_iiiiiiii;
  var invoke_iiiiiid=env.invoke_iiiiiid;
  var invoke_vd=env.invoke_vd;
  var invoke_vid=env.invoke_vid;
  var invoke_viiiii=env.invoke_viiiii;
  var invoke_iiiiiiiiii=env.invoke_iiiiiiiiii;
  var invoke_vii=env.invoke_vii;
  var invoke_iiiiiii=env.invoke_iiiiiii;
  var invoke_iiiiiiiiid=env.invoke_iiiiiiiiid;
  var invoke_ii=env.invoke_ii;
  var invoke_viidiii=env.invoke_viidiii;
  var invoke_viidd=env.invoke_viidd;
  var invoke_iidd=env.invoke_iidd;
  var invoke_viiiiiiiii=env.invoke_viiiiiiiii;
  var invoke_viiiidiii=env.invoke_viiiidiii;
  var invoke_viddd=env.invoke_viddd;
  var invoke_iiiiii=env.invoke_iiiiii;
  var invoke_vidi=env.invoke_vidi;
  var invoke_viiidiii=env.invoke_viiidiii;
  var invoke_vdddddd=env.invoke_vdddddd;
  var invoke_iiiidddd=env.invoke_iiiidddd;
  var invoke_viddi=env.invoke_viddi;
  var invoke_vidd=env.invoke_vidd;
  var invoke_iiii=env.invoke_iiii;
  var invoke_viiiiiiiiiiiiiii=env.invoke_viiiiiiiiiiiiiii;
  var invoke_vi=env.invoke_vi;
  var invoke_viiiiii=env.invoke_viiiiii;
  var invoke_iiid=env.invoke_iiid;
  var invoke_vdi=env.invoke_vdi;
  var invoke_viid=env.invoke_viid;
  var invoke_viddddd=env.invoke_viddddd;
  var invoke_di=env.invoke_di;
  var invoke_iiiiiiiiiii=env.invoke_iiiiiiiiiii;
  var invoke_viiidi=env.invoke_viiidi;
  var invoke_viiiiiiii=env.invoke_viiiiiiii;
  var invoke_vidddd=env.invoke_vidddd;
  var invoke_iiiiiiiiiiiii=env.invoke_iiiiiiiiiiiii;
  var invoke_iid=env.invoke_iid;
  var invoke_viiiiiii=env.invoke_viiiiiii;
  var invoke_iiddd=env.invoke_iiddd;
  var invoke_viiid=env.invoke_viiid;
  var invoke_viiiiiiiiii=env.invoke_viiiiiiiiii;
  var invoke_iii=env.invoke_iii;
  var invoke_diii=env.invoke_diii;
  var invoke_viiiiiiiiiii=env.invoke_viiiiiiiiiii;
  var invoke_dii=env.invoke_dii;
  var invoke_viii=env.invoke_viii;
  var invoke_i=env.invoke_i;
  var invoke_iiiiidii=env.invoke_iiiiidii;
  var invoke_iiiid=env.invoke_iiiid;
  var invoke_iiiii=env.invoke_iiiii;
  var invoke_iidii=env.invoke_iidii;
  var invoke_iiiiiiiiiiii=env.invoke_iiiiiiiiiiii;
  var invoke_vdddd=env.invoke_vdddd;
  var invoke_vdd=env.invoke_vdd;
  var invoke_v=env.invoke_v;
  var invoke_iiiiiiiii=env.invoke_iiiiiiiii;
  var invoke_iiiiid=env.invoke_iiiiid;
  var invoke_viiii=env.invoke_viiii;
  var _emscripten_glGetTexParameterfv=env._emscripten_glGetTexParameterfv;
  var _glClearStencil=env._glClearStencil;
  var ___syscall220=env.___syscall220;
  var _emscripten_glBlendFuncSeparate=env._emscripten_glBlendFuncSeparate;
  var _glTexParameteriv=env._glTexParameteriv;
  var ___assert_fail=env.___assert_fail;
  var _emscripten_glDepthFunc=env._emscripten_glDepthFunc;
  var _emscripten_memcpy_big=env._emscripten_memcpy_big;
  var _pthread_attr_init=env._pthread_attr_init;
  var _glStencilFunc=env._glStencilFunc;
  var _emscripten_glUniform1f=env._emscripten_glUniform1f;
  var emscriptenWebGLComputeImageSize=env.emscriptenWebGLComputeImageSize;
  var ___syscall221=env.___syscall221;
  var _emscripten_glUniform1i=env._emscripten_glUniform1i;
  var _emscripten_glGetIntegerv=env._emscripten_glGetIntegerv;
  var _emscripten_glIsProgram=env._emscripten_glIsProgram;
  var ___cxa_rethrow=env.___cxa_rethrow;
  var _emscripten_glTexParameteriv=env._emscripten_glTexParameteriv;
  var ___syscall140=env.___syscall140;
  var ___syscall145=env.___syscall145;
  var ___syscall146=env.___syscall146;
  var _emscripten_glAttachShader=env._emscripten_glAttachShader;
  var _emscripten_get_now_is_monotonic=env._emscripten_get_now_is_monotonic;
  var _emscripten_glStencilFunc=env._emscripten_glStencilFunc;
  var _emscripten_glTexParameterfv=env._emscripten_glTexParameterfv;
  var _emscripten_glUniformMatrix2fv=env._emscripten_glUniformMatrix2fv;
  var _emscripten_glDrawArraysInstanced=env._emscripten_glDrawArraysInstanced;
  var _glDepthMask=env._glDepthMask;
  var _emscripten_glVertexAttrib2fv=env._emscripten_glVertexAttrib2fv;
  var _glViewport=env._glViewport;
  var _emscripten_glFlush=env._emscripten_glFlush;
  var ___cxa_call_unexpected=env.___cxa_call_unexpected;
  var _nanosleep=env._nanosleep;
  var ___syscall91=env.___syscall91;
  var _pthread_once=env._pthread_once;
  var _dlopen=env._dlopen;
  var _eglWaitClient=env._eglWaitClient;
  var _emscripten_glTexCoordPointer=env._emscripten_glTexCoordPointer;
  var __addDays=env.__addDays;
  var _glGenTextures=env._glGenTextures;
  var _emscripten_glStencilFuncSeparate=env._emscripten_glStencilFuncSeparate;
  var _emscripten_glVertexAttrib3f=env._emscripten_glVertexAttrib3f;
  var _dlerror=env._dlerror;
  var _emscripten_get_gamepad_status=env._emscripten_get_gamepad_status;
  var _sched_yield=env._sched_yield;
  var _emscripten_glUniform1iv=env._emscripten_glUniform1iv;
  var emscriptenWebGLGetUniform=env.emscriptenWebGLGetUniform;
  var _glClearColor=env._glClearColor;
  var _glFinish=env._glFinish;
  var _emscripten_glGetBufferParameteriv=env._emscripten_glGetBufferParameteriv;
  var _emscripten_glVertexAttrib4fv=env._emscripten_glVertexAttrib4fv;
  var _pthread_getspecific=env._pthread_getspecific;
  var _glDrawArrays=env._glDrawArrays;
  var _pthread_cond_signal=env._pthread_cond_signal;
  var _emscripten_glDepthRange=env._emscripten_glDepthRange;
  var _emscripten_request_pointerlock=env._emscripten_request_pointerlock;
  var _emscripten_asm_const_iii=env._emscripten_asm_const_iii;
  var _eglMakeCurrent=env._eglMakeCurrent;
  var _emscripten_glCopyTexImage2D=env._emscripten_glCopyTexImage2D;
  var _emscripten_glFramebufferTexture2D=env._emscripten_glFramebufferTexture2D;
  var _pthread_cond_timedwait=env._pthread_cond_timedwait;
  var _emscripten_glRenderbufferStorage=env._emscripten_glRenderbufferStorage;
  var _emscripten_set_keydown_callback=env._emscripten_set_keydown_callback;
  var _emscripten_glVertexPointer=env._emscripten_glVertexPointer;
  var _eglInitialize=env._eglInitialize;
  var _emscripten_glBufferSubData=env._emscripten_glBufferSubData;
  var _emscripten_glGetUniformfv=env._emscripten_glGetUniformfv;
  var _emscripten_glStencilOp=env._emscripten_glStencilOp;
  var _emscripten_glBlendEquation=env._emscripten_glBlendEquation;
  var _emscripten_glVertexAttrib1fv=env._emscripten_glVertexAttrib1fv;
  var _dlclose=env._dlclose;
  var _emscripten_glGetProgramInfoLog=env._emscripten_glGetProgramInfoLog;
  var _emscripten_glUniform4fv=env._emscripten_glUniform4fv;
  var ___cxa_throw=env.___cxa_throw;
  var _emscripten_glUniform2fv=env._emscripten_glUniform2fv;
  var _emscripten_glBindBuffer=env._emscripten_glBindBuffer;
  var _emscripten_glGetFloatv=env._emscripten_glGetFloatv;
  var _pthread_mutex_init=env._pthread_mutex_init;
  var _glTexSubImage2D=env._glTexSubImage2D;
  var _emscripten_glGenRenderbuffers=env._emscripten_glGenRenderbuffers;
  var _eglGetDisplay=env._eglGetDisplay;
  var _emscripten_glCullFace=env._emscripten_glCullFace;
  var _emscripten_glStencilMaskSeparate=env._emscripten_glStencilMaskSeparate;
  var _emscripten_glUniform3fv=env._emscripten_glUniform3fv;
  var _emscripten_asm_const_ii=env._emscripten_asm_const_ii;
  var _emscripten_glDisableVertexAttribArray=env._emscripten_glDisableVertexAttribArray;
  var _eglBindAPI=env._eglBindAPI;
  var _eglCreateContext=env._eglCreateContext;
  var _emscripten_set_touchstart_callback=env._emscripten_set_touchstart_callback;
  var _emscripten_glGetBooleanv=env._emscripten_glGetBooleanv;
  var _emscripten_glVertexAttribDivisor=env._emscripten_glVertexAttribDivisor;
  var _emscripten_glGenBuffers=env._emscripten_glGenBuffers;
  var _emscripten_glDeleteObjectARB=env._emscripten_glDeleteObjectARB;
  var _emscripten_glGetShaderPrecisionFormat=env._emscripten_glGetShaderPrecisionFormat;
  var _emscripten_request_fullscreen_strategy=env._emscripten_request_fullscreen_strategy;
  var _emscripten_glIsEnabled=env._emscripten_glIsEnabled;
  var _emscripten_glStencilOpSeparate=env._emscripten_glStencilOpSeparate;
  var _pthread_cleanup_pop=env._pthread_cleanup_pop;
  var _emscripten_asm_const_iiiii=env._emscripten_asm_const_iiiii;
  var ___cxa_free_exception=env.___cxa_free_exception;
  var ___cxa_find_matching_catch=env.___cxa_find_matching_catch;
  var _emscripten_glShaderBinary=env._emscripten_glShaderBinary;
  var _glDrawElements=env._glDrawElements;
  var _emscripten_glValidateProgram=env._emscripten_glValidateProgram;
  var _emscripten_glUniform4iv=env._emscripten_glUniform4iv;
  var ___setErrNo=env.___setErrNo;
  var _eglSwapBuffers=env._eglSwapBuffers;
  var _emscripten_glVertexAttrib2f=env._emscripten_glVertexAttrib2f;
  var ___resumeException=env.___resumeException;
  var _emscripten_glGetError=env._emscripten_glGetError;
  var _emscripten_glBufferData=env._emscripten_glBufferData;
  var _emscripten_glReadPixels=env._emscripten_glReadPixels;
  var _glGetIntegerv=env._glGetIntegerv;
  var _eglCreateWindowSurface=env._eglCreateWindowSurface;
  var _emscripten_glClearStencil=env._emscripten_glClearStencil;
  var emscriptenWebGLGet=env.emscriptenWebGLGet;
  var _emscripten_get_device_pixel_ratio=env._emscripten_get_device_pixel_ratio;
  var _emscripten_set_mouseup_callback=env._emscripten_set_mouseup_callback;
  var _emscripten_glFinish=env._emscripten_glFinish;
  var _emscripten_glClearDepth=env._emscripten_glClearDepth;
  var _emscripten_glUniform1fv=env._emscripten_glUniform1fv;
  var _emscripten_set_resize_callback=env._emscripten_set_resize_callback;
  var _emscripten_glUniform4i=env._emscripten_glUniform4i;
  var _llvm_pow_f64=env._llvm_pow_f64;
  var _emscripten_glUniform4f=env._emscripten_glUniform4f;
  var _emscripten_glBlendFunc=env._emscripten_glBlendFunc;
  var _emscripten_glStencilMask=env._emscripten_glStencilMask;
  var __emscripten_sample_gamepad_data=env.__emscripten_sample_gamepad_data;
  var _glBindTexture=env._glBindTexture;
  var _strftime=env._strftime;
  var _emscripten_glGetVertexAttribiv=env._emscripten_glGetVertexAttribiv;
  var _glReadPixels=env._glReadPixels;
  var _emscripten_glUniformMatrix3fv=env._emscripten_glUniformMatrix3fv;
  var ___map_file=env.___map_file;
  var ___syscall33=env.___syscall33;
  var _pthread_key_create=env._pthread_key_create;
  var _pthread_setspecific=env._pthread_setspecific;
  var __setLetterbox=env.__setLetterbox;
  var ___syscall39=env.___syscall39;
  var _emscripten_glGetObjectParameterivARB=env._emscripten_glGetObjectParameterivARB;
  var _emscripten_glGetUniformiv=env._emscripten_glGetUniformiv;
  var _glScissor=env._glScissor;
  var _eglDestroySurface=env._eglDestroySurface;
  var _sigaction=env._sigaction;
  var _emscripten_glCreateShader=env._emscripten_glCreateShader;
  var ___cxa_find_matching_catch_2=env.___cxa_find_matching_catch_2;
  var ___cxa_find_matching_catch_3=env.___cxa_find_matching_catch_3;
  var _emscripten_glDeleteTextures=env._emscripten_glDeleteTextures;
  var _eglDestroyContext=env._eglDestroyContext;
  var _emscripten_exit_fullscreen=env._emscripten_exit_fullscreen;
  var _strftime_l=env._strftime_l;
  var _emscripten_glColorMask=env._emscripten_glColorMask;
  var _pthread_testcancel=env._pthread_testcancel;
  var _emscripten_glBindTexture=env._emscripten_glBindTexture;
  var _glTexParameterfv=env._glTexParameterfv;
  var _emscripten_set_main_loop=env._emscripten_set_main_loop;
  var _emscripten_glIsShader=env._emscripten_glIsShader;
  var _emscripten_asm_const_iiii=env._emscripten_asm_const_iiii;
  var _emscripten_glCompressedTexImage2D=env._emscripten_glCompressedTexImage2D;
  var _glDisable=env._glDisable;
  var _emscripten_glGetInfoLogARB=env._emscripten_glGetInfoLogARB;
  var _atexit=env._atexit;
  var _emscripten_glDeleteVertexArrays=env._emscripten_glDeleteVertexArrays;
  var _emscripten_glReleaseShaderCompiler=env._emscripten_glReleaseShaderCompiler;
  var _dlsym=env._dlsym;
  var _emscripten_glFrontFace=env._emscripten_glFrontFace;
  var __ZSt18uncaught_exceptionv=env.__ZSt18uncaught_exceptionv;
  var _emscripten_glUseProgram=env._emscripten_glUseProgram;
  var _clock_gettime=env._clock_gettime;
  var _glShaderBinary=env._glShaderBinary;
  var _emscripten_set_touchmove_callback=env._emscripten_set_touchmove_callback;
  var _glBlendFunc=env._glBlendFunc;
  var _emscripten_glUniform3iv=env._emscripten_glUniform3iv;
  var _pthread_mutexattr_settype=env._pthread_mutexattr_settype;
  var ___cxa_atexit=env.___cxa_atexit;
  var _emscripten_glScissor=env._emscripten_glScissor;
  var _pthread_cancel=env._pthread_cancel;
  var _pthread_cleanup_push=env._pthread_cleanup_push;
  var _emscripten_set_element_css_size=env._emscripten_set_element_css_size;
  var _llvm_trap=env._llvm_trap;
  var _glPixelStorei=env._glPixelStorei;
  var _emscripten_glIsBuffer=env._emscripten_glIsBuffer;
  var _emscripten_glVertexAttrib1f=env._emscripten_glVertexAttrib1f;
  var _emscripten_set_keyup_callback=env._emscripten_set_keyup_callback;
  var _emscripten_glCompressedTexSubImage2D=env._emscripten_glCompressedTexSubImage2D;
  var _emscripten_glGetAttachedShaders=env._emscripten_glGetAttachedShaders;
  var _emscripten_glGenTextures=env._emscripten_glGenTextures;
  var _eglGetConfigAttrib=env._eglGetConfigAttrib;
  var _pthread_cond_init=env._pthread_cond_init;
  var _emscripten_glGetTexParameteriv=env._emscripten_glGetTexParameteriv;
  var _glDeleteTextures=env._glDeleteTextures;
  var _emscripten_set_mousedown_callback=env._emscripten_set_mousedown_callback;
  var _emscripten_glClientActiveTexture=env._emscripten_glClientActiveTexture;
  var _emscripten_glCheckFramebufferStatus=env._emscripten_glCheckFramebufferStatus;
  var _eglWaitGL=env._eglWaitGL;
  var _emscripten_glUniform3f=env._emscripten_glUniform3f;
  var _emscripten_glUniform3i=env._emscripten_glUniform3i;
  var _emscripten_glDeleteShader=env._emscripten_glDeleteShader;
  var _glEnable=env._glEnable;
  var _glGetString=env._glGetString;
  var _emscripten_glGetUniformLocation=env._emscripten_glGetUniformLocation;
  var _emscripten_glEnableVertexAttribArray=env._emscripten_glEnableVertexAttribArray;
  var _emscripten_get_now=env._emscripten_get_now;
  var __registerRestoreOldStyle=env.__registerRestoreOldStyle;
  var _llvm_exp2_f32=env._llvm_exp2_f32;
  var _gettimeofday=env._gettimeofday;
  var _eglWaitNative=env._eglWaitNative;
  var _emscripten_glEnableClientState=env._emscripten_glEnableClientState;
  var _pthread_join=env._pthread_join;
  var _eglChooseConfig=env._eglChooseConfig;
  var _emscripten_glDrawElements=env._emscripten_glDrawElements;
  var _emscripten_get_num_gamepads=env._emscripten_get_num_gamepads;
  var ___buildEnvironment=env.___buildEnvironment;
  var _glClearDepthf=env._glClearDepthf;
  var _emscripten_glGetAttribLocation=env._emscripten_glGetAttribLocation;
  var _emscripten_glDisable=env._emscripten_glDisable;
  var ___cxa_end_catch=env.___cxa_end_catch;
  var _emscripten_glDeleteRenderbuffers=env._emscripten_glDeleteRenderbuffers;
  var _emscripten_glDrawElementsInstanced=env._emscripten_glDrawElementsInstanced;
  var _emscripten_glVertexAttrib4f=env._emscripten_glVertexAttrib4f;
  var _emscripten_glPixelStorei=env._emscripten_glPixelStorei;
  var _getenv=env._getenv;
  var _emscripten_set_gamepaddisconnected_callback=env._emscripten_set_gamepaddisconnected_callback;
  var _emscripten_glFramebufferRenderbuffer=env._emscripten_glFramebufferRenderbuffer;
  var _emscripten_glRotatef=env._emscripten_glRotatef;
  var _emscripten_glGetShaderiv=env._emscripten_glGetShaderiv;
  var ___cxa_pure_virtual=env.___cxa_pure_virtual;
  var _emscripten_glUniformMatrix4fv=env._emscripten_glUniformMatrix4fv;
  var _emscripten_glGetPointerv=env._emscripten_glGetPointerv;
  var _pthread_cond_wait=env._pthread_cond_wait;
  var _emscripten_set_blur_callback=env._emscripten_set_blur_callback;
  var emscriptenWebGLGetTexPixelData=env.emscriptenWebGLGetTexPixelData;
  var _emscripten_glIsRenderbuffer=env._emscripten_glIsRenderbuffer;
  var _emscripten_glLoadMatrixf=env._emscripten_glLoadMatrixf;
  var _emscripten_set_mousemove_callback=env._emscripten_set_mousemove_callback;
  var _emscripten_set_touchcancel_callback=env._emscripten_set_touchcancel_callback;
  var _emscripten_set_focus_callback=env._emscripten_set_focus_callback;
  var _emscripten_glGetVertexAttribfv=env._emscripten_glGetVertexAttribfv;
  var _emscripten_glVertexAttrib3fv=env._emscripten_glVertexAttrib3fv;
  var _emscripten_glCompileShader=env._emscripten_glCompileShader;
  var _glClear=env._glClear;
  var __arraySum=env.__arraySum;
  var _emscripten_glLinkProgram=env._emscripten_glLinkProgram;
  var _emscripten_get_pointerlock_status=env._emscripten_get_pointerlock_status;
  var _emscripten_glDrawRangeElements=env._emscripten_glDrawRangeElements;
  var ___unlock=env.___unlock;
  var _pthread_create=env._pthread_create;
  var _emscripten_glDeleteFramebuffers=env._emscripten_glDeleteFramebuffers;
  var _glColorMask=env._glColorMask;
  var _emscripten_glClearColor=env._emscripten_glClearColor;
  var _glCopyTexSubImage2D=env._glCopyTexSubImage2D;
  var _emscripten_glCreateProgram=env._emscripten_glCreateProgram;
  var _glTexParameteri=env._glTexParameteri;
  var _emscripten_glDetachShader=env._emscripten_glDetachShader;
  var _glTexParameterf=env._glTexParameterf;
  var _emscripten_do_request_fullscreen=env._emscripten_do_request_fullscreen;
  var _emscripten_set_mouseleave_callback=env._emscripten_set_mouseleave_callback;
  var _emscripten_glGetRenderbufferParameteriv=env._emscripten_glGetRenderbufferParameteriv;
  var _emscripten_set_fullscreenchange_callback=env._emscripten_set_fullscreenchange_callback;
  var _emscripten_glVertexAttribPointer=env._emscripten_glVertexAttribPointer;
  var _emscripten_glDrawArrays=env._emscripten_glDrawArrays;
  var _emscripten_glPolygonOffset=env._emscripten_glPolygonOffset;
  var _emscripten_glBlendColor=env._emscripten_glBlendColor;
  var _signal=env._signal;
  var _emscripten_set_main_loop_timing=env._emscripten_set_main_loop_timing;
  var ___cxa_begin_catch=env.___cxa_begin_catch;
  var _emscripten_glGetProgramiv=env._emscripten_glGetProgramiv;
  var _glStencilOp=env._glStencilOp;
  var _emscripten_glGetShaderSource=env._emscripten_glGetShaderSource;
  var _pthread_attr_getstacksize=env._pthread_attr_getstacksize;
  var _emscripten_glTexImage2D=env._emscripten_glTexImage2D;
  var __isLeapYear=env.__isLeapYear;
  var _emscripten_glBlendEquationSeparate=env._emscripten_glBlendEquationSeparate;
  var _emscripten_glGetString=env._emscripten_glGetString;
  var _emscripten_glIsFramebuffer=env._emscripten_glIsFramebuffer;
  var _emscripten_glBindProgramARB=env._emscripten_glBindProgramARB;
  var _glutCreateWindow=env._glutCreateWindow;
  var ___syscall85=env.___syscall85;
  var _emscripten_glUniform2i=env._emscripten_glUniform2i;
  var _emscripten_glUniform2f=env._emscripten_glUniform2f;
  var _emscripten_glTexParameterf=env._emscripten_glTexParameterf;
  var _emscripten_glTexParameteri=env._emscripten_glTexParameteri;
  var _glutInitDisplayMode=env._glutInitDisplayMode;
  var _emscripten_glGenVertexArrays=env._emscripten_glGenVertexArrays;
  var _pthread_cond_destroy=env._pthread_cond_destroy;
  var _emscripten_set_visibilitychange_callback=env._emscripten_set_visibilitychange_callback;
  var _eglGetProcAddress=env._eglGetProcAddress;
  var _emscripten_glBindAttribLocation=env._emscripten_glBindAttribLocation;
  var ___cxa_allocate_exception=env.___cxa_allocate_exception;
  var _emscripten_set_canvas_size=env._emscripten_set_canvas_size;
  var _emscripten_glClearDepthf=env._emscripten_glClearDepthf;
  var _emscripten_set_mouseenter_callback=env._emscripten_set_mouseenter_callback;
  var _emscripten_glMatrixMode=env._emscripten_glMatrixMode;
  var _emscripten_glNormalPointer=env._emscripten_glNormalPointer;
  var _emscripten_glBindVertexArray=env._emscripten_glBindVertexArray;
  var _emscripten_glEnable=env._emscripten_glEnable;
  var ___lock=env.___lock;
  var _emscripten_glBindFramebuffer=env._emscripten_glBindFramebuffer;
  var ___syscall6=env.___syscall6;
  var ___syscall5=env.___syscall5;
  var _emscripten_glBindRenderbuffer=env._emscripten_glBindRenderbuffer;
  var _time=env._time;
  var _emscripten_glGetFramebufferAttachmentParameteriv=env._emscripten_glGetFramebufferAttachmentParameteriv;
  var _emscripten_glGetActiveAttrib=env._emscripten_glGetActiveAttrib;
  var _emscripten_set_keypress_callback=env._emscripten_set_keypress_callback;
  var _emscripten_glClear=env._emscripten_glClear;
  var _emscripten_glGetShaderInfoLog=env._emscripten_glGetShaderInfoLog;
  var _emscripten_glGetVertexAttribPointerv=env._emscripten_glGetVertexAttribPointerv;
  var _emscripten_glGetActiveUniform=env._emscripten_glGetActiveUniform;
  var emscriptenWebGLGetVertexAttrib=env.emscriptenWebGLGetVertexAttrib;
  var ___syscall197=env.___syscall197;
  var ___syscall195=env.___syscall195;
  var _eglSwapInterval=env._eglSwapInterval;
  var _emscripten_glDeleteProgram=env._emscripten_glDeleteProgram;
  var _glutDestroyWindow=env._glutDestroyWindow;
  var _emscripten_glTexSubImage2D=env._emscripten_glTexSubImage2D;
  var _pthread_mutex_destroy=env._pthread_mutex_destroy;
  var _emscripten_glColorPointer=env._emscripten_glColorPointer;
  var _emscripten_glViewport=env._emscripten_glViewport;
  var _emscripten_glDepthMask=env._emscripten_glDepthMask;
  var _emscripten_glDrawBuffers=env._emscripten_glDrawBuffers;
  var _emscripten_glLineWidth=env._emscripten_glLineWidth;
  var _emscripten_exit_pointerlock=env._emscripten_exit_pointerlock;
  var _emscripten_set_gamepadconnected_callback=env._emscripten_set_gamepadconnected_callback;
  var _abort=env._abort;
  var _glTexImage2D=env._glTexImage2D;
  var _emscripten_glGenFramebuffers=env._emscripten_glGenFramebuffers;
  var _glFlush=env._glFlush;
  var _emscripten_glLoadIdentity=env._emscripten_glLoadIdentity;
  var _emscripten_glShaderSource=env._emscripten_glShaderSource;
  var ___gxx_personality_v0=env.___gxx_personality_v0;
  var _usleep=env._usleep;
  var _emscripten_set_touchend_callback=env._emscripten_set_touchend_callback;
  var _glGetError=env._glGetError;
  var _eglTerminate=env._eglTerminate;
  var _emscripten_glSampleCoverage=env._emscripten_glSampleCoverage;
  var _emscripten_glFrustum=env._emscripten_glFrustum;
  var _emscripten_glDepthRangef=env._emscripten_glDepthRangef;
  var _emscripten_glGenerateMipmap=env._emscripten_glGenerateMipmap;
  var _glCopyTexImage2D=env._glCopyTexImage2D;
  var _emscripten_glIsTexture=env._emscripten_glIsTexture;
  var _pthread_attr_setstacksize=env._pthread_attr_setstacksize;
  var _emscripten_glHint=env._emscripten_glHint;
  var _emscripten_glActiveTexture=env._emscripten_glActiveTexture;
  var _emscripten_set_wheel_callback=env._emscripten_set_wheel_callback;
  var _emscripten_glDeleteBuffers=env._emscripten_glDeleteBuffers;
  var ___syscall54=env.___syscall54;
  var _emscripten_glUniform2iv=env._emscripten_glUniform2iv;
  var _pthread_mutexattr_init=env._pthread_mutexattr_init;
  var _emscripten_asm_const_i=env._emscripten_asm_const_i;
  var _emscripten_get_element_css_size=env._emscripten_get_element_css_size;
  var _emscripten_glCopyTexSubImage2D=env._emscripten_glCopyTexSubImage2D;
  var _glStencilMask=env._glStencilMask;
  var tempFloat = 0.0;

// EMSCRIPTEN_START_FUNCS

function stackAlloc(size) {
  size = size|0;
  var ret = 0;
  ret = STACKTOP;
  STACKTOP = (STACKTOP + size)|0;
  STACKTOP = (STACKTOP + 15)&-16;
  if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(size|0);

  return ret|0;
}
function stackSave() {
  return STACKTOP|0;
}
function stackRestore(top) {
  top = top|0;
  STACKTOP = top;
}
function establishStackSpace(stackBase, stackMax) {
  stackBase = stackBase|0;
  stackMax = stackMax|0;
  STACKTOP = stackBase;
  STACK_MAX = stackMax;
}

function setThrew(threw, value) {
  threw = threw|0;
  value = value|0;
  if ((__THREW__|0) == 0) {
    __THREW__ = threw;
    threwValue = value;
  }
}

function setTempRet0(value) {
  value = value|0;
  tempRet0 = value;
}
function getTempRet0() {
  return tempRet0|0;
}

function ___cxx_global_var_init() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg5Vec3fC2Efff(207696,1.0,0.0,0.0);
 return;
}
function __ZN3osg5Vec3fC2Efff($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = +$1;
 $2 = +$2;
 $3 = +$3;
 var $10 = 0.0, $11 = 0, $12 = 0.0, $13 = 0, $4 = 0, $5 = 0.0, $6 = 0.0, $7 = 0.0, $8 = 0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $4 = $0;
 $5 = $1;
 $6 = $2;
 $7 = $3;
 $8 = $4;
 $9 = $5;
 HEAPF32[$8>>2] = $9;
 $10 = $6;
 $11 = ((($8)) + 4|0);
 HEAPF32[$11>>2] = $10;
 $12 = $7;
 $13 = ((($8)) + 8|0);
 HEAPF32[$13>>2] = $12;
 STACKTOP = sp;return;
}
function ___cxx_global_var_init_1() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg5Vec3fC2Efff(207708,0.0,1.0,0.0);
 return;
}
function ___cxx_global_var_init_2() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg5Vec3fC2Efff(207720,0.0,0.0,1.0);
 return;
}
function __ZN4mjin6player11handleEventER9SDL_EventPN9osgViewer6ViewerE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$expand_i1_val = 0, $$expand_i1_val2 = 0, $$expand_i1_val4 = 0, $$expand_i1_val6 = 0, $$expand_i1_val8 = 0, $$pre_trunc = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0.0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0.0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0.0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0.0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0.0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0.0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $2 = sp + 16|0;
 $3 = $0;
 $4 = $1;
 $7 = $4;
 $8 = ((($7)) + 104|0);
 $9 = (__ZN3osg4View9getCameraEv($8)|0);
 $10 = (__ZN3osg6Camera18getGraphicsContextEv($9)|0);
 $11 = ($10|0)==(0|0);
 if ($11) {
  $13 = 0;
 } else {
  $12 = (___dynamic_cast($10,24816,3888,0)|0);
  $13 = $12;
 }
 $5 = $13;
 $14 = $5;
 $15 = ($14|0)!=(0|0);
 if (!($15)) {
  $$expand_i1_val = 0;
  HEAP8[$2>>0] = $$expand_i1_val;
  $$pre_trunc = HEAP8[$2>>0]|0;
  $64 = $$pre_trunc&1;
  STACKTOP = sp;return ($64|0);
 }
 $16 = $5;
 $17 = (__ZN9osgViewer14GraphicsWindow13getEventQueueEv($16)|0);
 $6 = $17;
 $18 = $3;
 $19 = HEAP32[$18>>2]|0;
 switch ($19|0) {
 case 1024:  {
  $20 = $6;
  $21 = $3;
  $22 = ((($21)) + 20|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (+($23|0));
  $25 = HEAP32[51934]|0;
  $26 = $3;
  $27 = ((($26)) + 24|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (($25) - ($28))|0;
  $30 = (0 - ($29))|0;
  $31 = (+($30|0));
  (__ZN5osgGA10EventQueue11mouseMotionEff($20,$24,$31)|0);
  $$expand_i1_val2 = 1;
  HEAP8[$2>>0] = $$expand_i1_val2;
  $$pre_trunc = HEAP8[$2>>0]|0;
  $64 = $$pre_trunc&1;
  STACKTOP = sp;return ($64|0);
  break;
 }
 case 1025:  {
  $32 = $6;
  $33 = $3;
  $34 = ((($33)) + 20|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = (+($35|0));
  $37 = HEAP32[51934]|0;
  $38 = $3;
  $39 = ((($38)) + 24|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = (($37) - ($40))|0;
  $42 = (0 - ($41))|0;
  $43 = (+($42|0));
  $44 = $3;
  $45 = ((($44)) + 16|0);
  $46 = HEAP8[$45>>0]|0;
  $47 = $46&255;
  (__ZN5osgGA10EventQueue16mouseButtonPressEffj($32,$36,$43,$47)|0);
  $$expand_i1_val4 = 1;
  HEAP8[$2>>0] = $$expand_i1_val4;
  $$pre_trunc = HEAP8[$2>>0]|0;
  $64 = $$pre_trunc&1;
  STACKTOP = sp;return ($64|0);
  break;
 }
 case 1026:  {
  $48 = $6;
  $49 = $3;
  $50 = ((($49)) + 20|0);
  $51 = HEAP32[$50>>2]|0;
  $52 = (+($51|0));
  $53 = HEAP32[51934]|0;
  $54 = $3;
  $55 = ((($54)) + 24|0);
  $56 = HEAP32[$55>>2]|0;
  $57 = (($53) - ($56))|0;
  $58 = (0 - ($57))|0;
  $59 = (+($58|0));
  $60 = $3;
  $61 = ((($60)) + 16|0);
  $62 = HEAP8[$61>>0]|0;
  $63 = $62&255;
  (__ZN5osgGA10EventQueue18mouseButtonReleaseEffj($48,$52,$59,$63)|0);
  $$expand_i1_val6 = 1;
  HEAP8[$2>>0] = $$expand_i1_val6;
  $$pre_trunc = HEAP8[$2>>0]|0;
  $64 = $$pre_trunc&1;
  STACKTOP = sp;return ($64|0);
  break;
 }
 default: {
  $$expand_i1_val8 = 0;
  HEAP8[$2>>0] = $$expand_i1_val8;
  $$pre_trunc = HEAP8[$2>>0]|0;
  $64 = $$pre_trunc&1;
  STACKTOP = sp;return ($64|0);
 }
 }
 return (0)|0;
}
function __ZN3osg4View9getCameraEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 $3 = ((($2)) + 16|0);
 $4 = (__ZNK3osg7ref_ptrINS_6CameraEE3getEv($3)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN3osg6Camera18getGraphicsContextEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 $3 = ((($2)) + 624|0);
 $4 = (__ZNK3osg7ref_ptrINS_15GraphicsContextEE3getEv($3)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN9osgViewer14GraphicsWindow13getEventQueueEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 $3 = ((($2)) + 136|0);
 $4 = (__ZNK3osg7ref_ptrIN5osgGA10EventQueueEE3getEv($3)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN5osgGA10EventQueue11mouseMotionEff($0,$1,$2) {
 $0 = $0|0;
 $1 = +$1;
 $2 = +$2;
 var $10 = 0, $3 = 0, $4 = 0.0, $5 = 0.0, $6 = 0, $7 = 0.0, $8 = 0.0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = $0;
 $4 = $1;
 $5 = $2;
 $6 = $3;
 $7 = $4;
 $8 = $5;
 $9 = (+__ZNK5osgGA10EventQueue7getTimeEv($6));
 $10 = (__ZN5osgGA10EventQueue11mouseMotionEffd($6,$7,$8,$9)|0);
 STACKTOP = sp;return ($10|0);
}
function __ZN5osgGA10EventQueue16mouseButtonPressEffj($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = +$1;
 $2 = +$2;
 $3 = $3|0;
 var $10 = 0.0, $11 = 0, $12 = 0.0, $13 = 0, $4 = 0, $5 = 0.0, $6 = 0.0, $7 = 0, $8 = 0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $4 = $0;
 $5 = $1;
 $6 = $2;
 $7 = $3;
 $8 = $4;
 $9 = $5;
 $10 = $6;
 $11 = $7;
 $12 = (+__ZNK5osgGA10EventQueue7getTimeEv($8));
 $13 = (__ZN5osgGA10EventQueue16mouseButtonPressEffjd($8,$9,$10,$11,$12)|0);
 STACKTOP = sp;return ($13|0);
}
function __ZN5osgGA10EventQueue18mouseButtonReleaseEffj($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = +$1;
 $2 = +$2;
 $3 = $3|0;
 var $10 = 0.0, $11 = 0, $12 = 0.0, $13 = 0, $4 = 0, $5 = 0.0, $6 = 0.0, $7 = 0, $8 = 0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $4 = $0;
 $5 = $1;
 $6 = $2;
 $7 = $3;
 $8 = $4;
 $9 = $5;
 $10 = $6;
 $11 = $7;
 $12 = (+__ZNK5osgGA10EventQueue7getTimeEv($8));
 $13 = (__ZN5osgGA10EventQueue18mouseButtonReleaseEffjd($8,$9,$10,$11,$12)|0);
 STACKTOP = sp;return ($13|0);
}
function __ZN4mjin6player4loopEv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(64|0);
 $0 = sp;
 while(1) {
  $1 = (_SDL_PollEvent($0)|0);
  $2 = ($1|0)!=(0);
  if (!($2)) {
   break;
  }
  $3 = HEAP32[51933]|0;
  (__ZN4mjin6player11handleEventER9SDL_EventPN9osgViewer6ViewerE($0,$3)|0);
 }
 __ZN4mjin11application5frameEv();
 STACKTOP = sp;return;
}
function __ZN4mjin6player4quitEv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 __ZN4mjin3log9logprintfEPKcz(100904,$vararg_buffer);
 __ZN4mjin11application14tearDownViewerEv();
 $0 = HEAP32[51933]|0;
 $1 = ($0|0)!=(0|0);
 if ($1) {
  $2 = HEAP32[51933]|0;
  $3 = ($2|0)==(0|0);
  if (!($3)) {
   $4 = HEAP32[$2>>2]|0;
   $5 = ((($4)) + 132|0);
   $6 = HEAP32[$5>>2]|0;
   FUNCTION_TABLE_vi[$6 & 8191]($2);
  }
 }
 _SDL_Quit();
 __ZN4mjin11application8tearDownEv();
 STACKTOP = sp;return;
}
function __ZN4mjin6player20setupGraphicsContextEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $vararg_buffer = sp;
 (_SDL_GL_SetAttribute(0,5)|0);
 (_SDL_GL_SetAttribute(1,5)|0);
 (_SDL_GL_SetAttribute(2,5)|0);
 (_SDL_GL_SetAttribute(6,16)|0);
 (_SDL_GL_SetAttribute(5,1)|0);
 $1 = 800;
 $2 = 600;
 $7 = $2;
 HEAP32[51934] = $7;
 $8 = $1;
 $9 = $2;
 $10 = (_SDL_CreateWindow(100927,805240832,805240832,$8,$9,2)|0);
 $3 = $10;
 $11 = $3;
 $12 = ($11|0)!=(0|0);
 if (!($12)) {
  $13 = (_SDL_GetError()|0);
  HEAP32[$vararg_buffer>>2] = $13;
  __ZN4mjin3log9logprintfEPKcz(100939,$vararg_buffer);
  $0 = 0;
  $32 = $0;
  STACKTOP = sp;return ($32|0);
 }
 $14 = $3;
 (_SDL_GL_CreateContext($14)|0);
 $15 = (__Znwj(272)|0);
 __THREW__ = 0;
 invoke_vi(3248,($15|0));
 $16 = __THREW__; __THREW__ = 0;
 $17 = $16&1;
 if ($17) {
  $28 = ___cxa_find_matching_catch_2()|0;
  $29 = tempRet0;
  $5 = $28;
  $6 = $29;
  __ZdlPv($15);
  $30 = $5;
  $31 = $6;
  ___resumeException($30|0);
  // unreachable;
 }
 $4 = $15;
 $18 = $4;
 $19 = HEAP32[$18>>2]|0;
 $20 = ((($19)) + 168|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = $1;
 $23 = $2;
 (FUNCTION_TABLE_iiiiii[$21 & 8191]($18,0,0,$22,$23)|0);
 $24 = $4;
 $25 = $1;
 $26 = $2;
 __ZN4mjin11application11setupViewerEPN9osgViewer6ViewerEii($24,$25,$26);
 $27 = $4;
 $0 = $27;
 $32 = $0;
 STACKTOP = sp;return ($32|0);
}
function _main($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $2 = 0;
 $3 = $0;
 $4 = $1;
 $5 = (_SDL_Init(32)|0);
 $6 = ($5|0)<(0);
 if ($6) {
  $7 = (_SDL_GetError()|0);
  HEAP32[$vararg_buffer>>2] = $7;
  __ZN4mjin3log9logprintfEPKcz(100989,$vararg_buffer);
  $2 = 1;
  $11 = $2;
  STACKTOP = sp;return ($11|0);
 }
 (_atexit((3249|0))|0);
 __ZN4mjin11application5setupEv();
 $8 = (__ZN4mjin6player20setupGraphicsContextEv()|0);
 HEAP32[51933] = $8;
 $9 = HEAP32[51933]|0;
 $10 = ($9|0)!=(0|0);
 if ($10) {
  _emscripten_set_main_loop((3250|0),-1,0);
 }
 $2 = 0;
 $11 = $2;
 STACKTOP = sp;return ($11|0);
}
function __ZNK3osg7ref_ptrINS_6CameraEE3getEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 STACKTOP = sp;return ($3|0);
}
function __ZNK3osg7ref_ptrINS_15GraphicsContextEE3getEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 STACKTOP = sp;return ($3|0);
}
function __ZNK3osg7ref_ptrIN5osgGA10EventQueueEE3getEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 STACKTOP = sp;return ($3|0);
}
function __ZNK5osgGA10EventQueue7getTimeEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0.0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 $3 = (__ZN3osg5Timer8instanceEv()|0);
 $4 = ((($2)) + 24|0);
 $5 = $4;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5) + 4)|0;
 $9 = $8;
 $10 = HEAP32[$9>>2]|0;
 $11 = (__ZN3osg5Timer8instanceEv()|0);
 $12 = (__ZNK3osg5Timer4tickEv($11)|0);
 $13 = tempRet0;
 $14 = (+__ZNK3osg5Timer7delta_sEyy($3,$7,$10,$12,$13));
 STACKTOP = sp;return (+$14);
}
function __ZNK3osg5Timer7delta_sEyy($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$sink = 0.0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0.0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0.0, $64 = 0.0, $65 = 0, $66 = 0.0;
 var $67 = 0.0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $6 = sp + 8|0;
 $7 = sp;
 $5 = $0;
 $8 = $6;
 $9 = $8;
 HEAP32[$9>>2] = $1;
 $10 = (($8) + 4)|0;
 $11 = $10;
 HEAP32[$11>>2] = $2;
 $12 = $7;
 $13 = $12;
 HEAP32[$13>>2] = $3;
 $14 = (($12) + 4)|0;
 $15 = $14;
 HEAP32[$15>>2] = $4;
 $16 = $5;
 $17 = $7;
 $18 = $17;
 $19 = HEAP32[$18>>2]|0;
 $20 = (($17) + 4)|0;
 $21 = $20;
 $22 = HEAP32[$21>>2]|0;
 $23 = $6;
 $24 = $23;
 $25 = HEAP32[$24>>2]|0;
 $26 = (($23) + 4)|0;
 $27 = $26;
 $28 = HEAP32[$27>>2]|0;
 $29 = ($22>>>0)>($28>>>0);
 $30 = ($19>>>0)>($25>>>0);
 $31 = ($22|0)==($28|0);
 $32 = $31 & $30;
 $33 = $29 | $32;
 if ($33) {
  $34 = $7;
  $35 = $34;
  $36 = HEAP32[$35>>2]|0;
  $37 = (($34) + 4)|0;
  $38 = $37;
  $39 = HEAP32[$38>>2]|0;
  $40 = $6;
  $41 = $40;
  $42 = HEAP32[$41>>2]|0;
  $43 = (($40) + 4)|0;
  $44 = $43;
  $45 = HEAP32[$44>>2]|0;
  $46 = (_i64Subtract(($36|0),($39|0),($42|0),($45|0))|0);
  $47 = tempRet0;
  $48 = (+($46>>>0)) + (4294967296.0*(+($47>>>0)));
  $$sink = $48;
  $65 = ((($16)) + 8|0);
  $66 = +HEAPF64[$65>>3];
  $67 = $$sink * $66;
  STACKTOP = sp;return (+$67);
 } else {
  $49 = $6;
  $50 = $49;
  $51 = HEAP32[$50>>2]|0;
  $52 = (($49) + 4)|0;
  $53 = $52;
  $54 = HEAP32[$53>>2]|0;
  $55 = $7;
  $56 = $55;
  $57 = HEAP32[$56>>2]|0;
  $58 = (($55) + 4)|0;
  $59 = $58;
  $60 = HEAP32[$59>>2]|0;
  $61 = (_i64Subtract(($51|0),($54|0),($57|0),($60|0))|0);
  $62 = tempRet0;
  $63 = (+($61>>>0)) + (4294967296.0*(+($62>>>0)));
  $64 = -$63;
  $$sink = $64;
  $65 = ((($16)) + 8|0);
  $66 = +HEAPF64[$65>>3];
  $67 = $$sink * $66;
  STACKTOP = sp;return (+$67);
 }
 return +(0.0);
}
function __GLOBAL__sub_I_main_cpp() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 ___cxx_global_var_init();
 ___cxx_global_var_init_1();
 ___cxx_global_var_init_2();
 return;
}
function __ZN3osg10Referenced21setThreadSafeRefUnrefEb($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = $0;
 $4 = $1&1;
 $3 = $4;
 STACKTOP = sp;return;
}
function __ZN4mjin3log6LoggerD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 __ZN4mjin3log6LoggerD2Ev($2);
 __ZdlPv($2);
 STACKTOP = sp;return;
}
function __ZN4mjin3log6Logger6notifyEN3osg14NotifySeverityEPKc($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(112|0);
 $vararg_buffer = sp;
 $21 = sp + 16|0;
 $18 = $0;
 $19 = $1;
 $20 = $2;
 $24 = $18;
 $25 = $20;
 $26 = (__ZN4mjin3log6Logger6ignoreEPKc($24,$25)|0);
 if ($26) {
  STACKTOP = sp;return;
 }
 $27 = $19;
 __ZN4mjin3log16logLevelToStringEN3osg14NotifySeverityE($21,$27);
 $17 = $21;
 $28 = $17;
 $16 = $28;
 $29 = $16;
 $15 = $29;
 $30 = $15;
 $14 = $30;
 $31 = $14;
 $13 = $31;
 $32 = $13;
 $12 = $32;
 $33 = $12;
 $34 = ((($33)) + 11|0);
 $35 = HEAP8[$34>>0]|0;
 $36 = $35&255;
 $37 = $36 & 128;
 $38 = ($37|0)!=(0);
 if ($38) {
  $6 = $30;
  $39 = $6;
  $5 = $39;
  $40 = $5;
  $4 = $40;
  $41 = $4;
  $42 = HEAP32[$41>>2]|0;
  $48 = $42;
 } else {
  $11 = $30;
  $43 = $11;
  $10 = $43;
  $44 = $10;
  $9 = $44;
  $45 = $9;
  $8 = $45;
  $46 = $8;
  $7 = $46;
  $47 = $7;
  $48 = $47;
 }
 $3 = $48;
 $49 = $3;
 $50 = $20;
 __THREW__ = 0;
 HEAP32[$vararg_buffer>>2] = $49;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $50;
 invoke_vii(3251,(101040|0),($vararg_buffer|0));
 $51 = __THREW__; __THREW__ = 0;
 $52 = $51&1;
 if ($52) {
  $53 = ___cxa_find_matching_catch_2()|0;
  $54 = tempRet0;
  $22 = $53;
  $23 = $54;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($21);
  $55 = $22;
  $56 = $23;
  ___resumeException($55|0);
  // unreachable;
 }
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($21);
 STACKTOP = sp;return;
}
function __ZN4mjin3log6Logger6ignoreEPKc($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$expand_i1_val = 0, $$expand_i1_val2 = 0, $$expand_i1_val5 = 0, $$expand_i1_val7 = 0, $$expand_i1_val9 = 0, $$pre_trunc = 0, $$pre_trunc11 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(112|0);
 $vararg_buffer = sp;
 $12 = sp + 109|0;
 $27 = sp + 108|0;
 $28 = $0;
 $29 = $1;
 $30 = HEAP8[205984]|0;
 $31 = ($30<<24>>24)==(0);
 if ($31) {
  $32 = (___cxa_guard_acquire(205984)|0);
  $33 = ($32|0)!=(0);
  if ($33) {
   $26 = 207740;
   $34 = $26;
   $25 = $34;
   $35 = $25;
   $24 = $35;
   $36 = $24;
   $23 = $36;
   ;HEAP32[$36>>2]=0|0;HEAP32[$36+4>>2]=0|0;HEAP32[$36+8>>2]=0|0;
   $20 = $34;
   $37 = $20;
   $19 = $37;
   $38 = $19;
   $18 = $38;
   $39 = $18;
   $21 = $39;
   $22 = 0;
   while(1) {
    $40 = $22;
    $41 = ($40>>>0)<(3);
    if (!($41)) {
     break;
    }
    $42 = $21;
    $43 = $22;
    $44 = (($42) + ($43<<2)|0);
    HEAP32[$44>>2] = 0;
    $45 = $22;
    $46 = (($45) + 1)|0;
    $22 = $46;
   }
   (___cxa_atexit((3252|0),(207740|0),(___dso_handle|0))|0);
  }
 }
 $47 = $29;
 $13 = 207740;
 $14 = $47;
 $48 = $14;
 $49 = (__ZNSt3__211char_traitsIcE6lengthEPKc($48)|0);
 $15 = $49;
 $50 = $15;
 $51 = $13;
 $11 = $51;
 $52 = $11;
 $10 = $52;
 $53 = $10;
 $9 = $53;
 $54 = $9;
 $8 = $54;
 $55 = $8;
 $56 = ((($55)) + 11|0);
 $57 = HEAP8[$56>>0]|0;
 $58 = $57&255;
 $59 = $58 & 128;
 $60 = ($59|0)!=(0);
 if ($60) {
  $4 = $52;
  $61 = $4;
  $3 = $61;
  $62 = $3;
  $2 = $62;
  $63 = $2;
  $64 = ((($63)) + 4|0);
  $65 = HEAP32[$64>>2]|0;
  $73 = $65;
 } else {
  $7 = $52;
  $66 = $7;
  $6 = $66;
  $67 = $6;
  $5 = $67;
  $68 = $5;
  $69 = ((($68)) + 11|0);
  $70 = HEAP8[$69>>0]|0;
  $71 = $70&255;
  $73 = $71;
 }
 $72 = ($50|0)!=($73|0);
 do {
  if ($72) {
   $$expand_i1_val = 0;
   HEAP8[$12>>0] = $$expand_i1_val;
  } else {
   $74 = $13;
   $75 = $14;
   $76 = $15;
   __THREW__ = 0;
   $77 = (invoke_iiiiii(3253,($74|0),0,-1,($75|0),($76|0))|0);
   $78 = __THREW__; __THREW__ = 0;
   $79 = $78&1;
   if ($79) {
    $81 = ___cxa_find_matching_catch_3(0|0)|0;
    $82 = tempRet0;
    ___clang_call_terminate($81);
    // unreachable;
   } else {
    $80 = ($77|0)==(0);
    $$expand_i1_val2 = $80&1;
    HEAP8[$12>>0] = $$expand_i1_val2;
    break;
   }
  }
 } while(0);
 $$pre_trunc = HEAP8[$12>>0]|0;
 $83 = $$pre_trunc&1;
 if (!($83)) {
  $87 = $29;
  $16 = 207740;
  $17 = $87;
  $88 = $16;
  $89 = $17;
  (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($88,$89)|0);
  $$expand_i1_val9 = 0;
  HEAP8[$27>>0] = $$expand_i1_val9;
  $$pre_trunc11 = HEAP8[$27>>0]|0;
  $90 = $$pre_trunc11&1;
  STACKTOP = sp;return ($90|0);
 }
 $84 = HEAP32[51938]|0;
 $85 = (($84) + 1)|0;
 HEAP32[51938] = $85;
 $86 = ($85|0)>(1000);
 if ($86) {
  HEAP32[51938] = 0;
  HEAP32[$vararg_buffer>>2] = 1000;
  __ZN4mjin3log9logprintfEPKcz(101072,$vararg_buffer);
  $$expand_i1_val5 = 0;
  HEAP8[$27>>0] = $$expand_i1_val5;
  $$pre_trunc11 = HEAP8[$27>>0]|0;
  $90 = $$pre_trunc11&1;
  STACKTOP = sp;return ($90|0);
 } else {
  $$expand_i1_val7 = 1;
  HEAP8[$27>>0] = $$expand_i1_val7;
  $$pre_trunc11 = HEAP8[$27>>0]|0;
  $90 = $$pre_trunc11&1;
  STACKTOP = sp;return ($90|0);
 }
 return (0)|0;
}
function __ZN4mjin3log16logLevelToStringEN3osg14NotifySeverityE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0;
 var $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0;
 var $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0;
 var $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0;
 var $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0;
 var $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0;
 var $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0;
 var $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0;
 var $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0;
 var $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0;
 var $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0;
 var $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0;
 var $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0;
 var $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0;
 var $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0;
 var $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0;
 var $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0;
 var $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0;
 var $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0;
 var $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0;
 var $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0;
 var $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0;
 var $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0;
 var $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0;
 var $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0;
 var $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0;
 var $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0;
 var $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0;
 var $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0;
 var $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0;
 var $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1104|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(1104|0);
 $38 = sp + 32|0;
 $40 = sp + 1089|0;
 $51 = sp + 1088|0;
 $93 = sp + 24|0;
 $95 = sp + 1087|0;
 $106 = sp + 1086|0;
 $148 = sp + 16|0;
 $150 = sp + 1085|0;
 $161 = sp + 1084|0;
 $203 = sp + 8|0;
 $205 = sp + 1083|0;
 $216 = sp + 1082|0;
 $258 = sp;
 $260 = sp + 1081|0;
 $271 = sp + 1080|0;
 $277 = $1;
 $278 = $277;
 switch ($278|0) {
 case 6:  {
  $275 = $0;
  $276 = 101062;
  $279 = $275;
  $274 = $279;
  $280 = $274;
  $273 = $280;
  $281 = $273;
  $272 = $281;
  ;HEAP32[$281>>2]=0|0;HEAP32[$281+4>>2]=0|0;HEAP32[$281+8>>2]=0|0;
  $282 = $276;
  $283 = $276;
  $284 = (__ZNSt3__211char_traitsIcE6lengthEPKc($283)|0);
  $266 = $279;
  $267 = $282;
  $268 = $284;
  $285 = $266;
  $286 = $268;
  $264 = $285;
  $287 = $264;
  $263 = $287;
  $288 = $263;
  $262 = $288;
  $289 = $262;
  $261 = $289;
  $290 = $261;
  $259 = $290;
  $291 = $259;
  ;HEAP8[$258>>0]=HEAP8[$260>>0]|0;
  $257 = $291;
  $292 = $257;
  $256 = $292;
  $265 = -1;
  $293 = $265;
  $294 = (($293) - 16)|0;
  $295 = ($286>>>0)>($294>>>0);
  if ($295) {
   __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv($285);
   // unreachable;
  }
  $296 = $268;
  $297 = ($296>>>0)<(11);
  $298 = $268;
  if ($297) {
   $254 = $285;
   $255 = $298;
   $299 = $254;
   $300 = $255;
   $301 = $300&255;
   $253 = $299;
   $302 = $253;
   $252 = $302;
   $303 = $252;
   $304 = ((($303)) + 11|0);
   HEAP8[$304>>0] = $301;
   $251 = $285;
   $305 = $251;
   $250 = $305;
   $306 = $250;
   $249 = $306;
   $307 = $249;
   $248 = $307;
   $308 = $248;
   $247 = $308;
   $309 = $247;
   $269 = $309;
  } else {
   $226 = $298;
   $310 = $226;
   $311 = ($310>>>0)<(11);
   if ($311) {
    $318 = 11;
   } else {
    $312 = $226;
    $313 = (($312) + 1)|0;
    $225 = $313;
    $314 = $225;
    $315 = (($314) + 15)|0;
    $316 = $315 & -16;
    $318 = $316;
   }
   $317 = (($318) - 1)|0;
   $270 = $317;
   $224 = $285;
   $319 = $224;
   $223 = $319;
   $320 = $223;
   $222 = $320;
   $321 = $222;
   $322 = $270;
   $323 = (($322) + 1)|0;
   $232 = $321;
   $233 = $323;
   $324 = $232;
   $325 = $233;
   $229 = $324;
   $230 = $325;
   $231 = 0;
   $326 = $229;
   $228 = $326;
   $327 = $230;
   $227 = $327;
   $328 = $227;
   $329 = (__Znwj($328)|0);
   $269 = $329;
   $330 = $269;
   $236 = $285;
   $237 = $330;
   $331 = $236;
   $332 = $237;
   $235 = $331;
   $333 = $235;
   $234 = $333;
   $334 = $234;
   HEAP32[$334>>2] = $332;
   $335 = $270;
   $336 = (($335) + 1)|0;
   $240 = $285;
   $241 = $336;
   $337 = $240;
   $338 = $241;
   $339 = -2147483648 | $338;
   $239 = $337;
   $340 = $239;
   $238 = $340;
   $341 = $238;
   $342 = ((($341)) + 8|0);
   HEAP32[$342>>2] = $339;
   $343 = $268;
   $244 = $285;
   $245 = $343;
   $344 = $244;
   $345 = $245;
   $243 = $344;
   $346 = $243;
   $242 = $346;
   $347 = $242;
   $348 = ((($347)) + 4|0);
   HEAP32[$348>>2] = $345;
  }
  $349 = $269;
  $246 = $349;
  $350 = $246;
  $351 = $267;
  $352 = $268;
  (__ZNSt3__211char_traitsIcE4copyEPcPKcj($350,$351,$352)|0);
  $353 = $269;
  $354 = $268;
  $355 = (($353) + ($354)|0);
  HEAP8[$271>>0] = 0;
  __ZNSt3__211char_traitsIcE6assignERcRKc($355,$271);
  STACKTOP = sp;return;
  break;
 }
 case 5:  {
  $220 = $0;
  $221 = 101064;
  $356 = $220;
  $219 = $356;
  $357 = $219;
  $218 = $357;
  $358 = $218;
  $217 = $358;
  ;HEAP32[$358>>2]=0|0;HEAP32[$358+4>>2]=0|0;HEAP32[$358+8>>2]=0|0;
  $359 = $221;
  $360 = $221;
  $361 = (__ZNSt3__211char_traitsIcE6lengthEPKc($360)|0);
  $211 = $356;
  $212 = $359;
  $213 = $361;
  $362 = $211;
  $363 = $213;
  $209 = $362;
  $364 = $209;
  $208 = $364;
  $365 = $208;
  $207 = $365;
  $366 = $207;
  $206 = $366;
  $367 = $206;
  $204 = $367;
  $368 = $204;
  ;HEAP8[$203>>0]=HEAP8[$205>>0]|0;
  $202 = $368;
  $369 = $202;
  $201 = $369;
  $210 = -1;
  $370 = $210;
  $371 = (($370) - 16)|0;
  $372 = ($363>>>0)>($371>>>0);
  if ($372) {
   __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv($362);
   // unreachable;
  }
  $373 = $213;
  $374 = ($373>>>0)<(11);
  $375 = $213;
  if ($374) {
   $199 = $362;
   $200 = $375;
   $376 = $199;
   $377 = $200;
   $378 = $377&255;
   $198 = $376;
   $379 = $198;
   $197 = $379;
   $380 = $197;
   $381 = ((($380)) + 11|0);
   HEAP8[$381>>0] = $378;
   $196 = $362;
   $382 = $196;
   $195 = $382;
   $383 = $195;
   $194 = $383;
   $384 = $194;
   $193 = $384;
   $385 = $193;
   $192 = $385;
   $386 = $192;
   $214 = $386;
  } else {
   $171 = $375;
   $387 = $171;
   $388 = ($387>>>0)<(11);
   if ($388) {
    $395 = 11;
   } else {
    $389 = $171;
    $390 = (($389) + 1)|0;
    $170 = $390;
    $391 = $170;
    $392 = (($391) + 15)|0;
    $393 = $392 & -16;
    $395 = $393;
   }
   $394 = (($395) - 1)|0;
   $215 = $394;
   $169 = $362;
   $396 = $169;
   $168 = $396;
   $397 = $168;
   $167 = $397;
   $398 = $167;
   $399 = $215;
   $400 = (($399) + 1)|0;
   $177 = $398;
   $178 = $400;
   $401 = $177;
   $402 = $178;
   $174 = $401;
   $175 = $402;
   $176 = 0;
   $403 = $174;
   $173 = $403;
   $404 = $175;
   $172 = $404;
   $405 = $172;
   $406 = (__Znwj($405)|0);
   $214 = $406;
   $407 = $214;
   $181 = $362;
   $182 = $407;
   $408 = $181;
   $409 = $182;
   $180 = $408;
   $410 = $180;
   $179 = $410;
   $411 = $179;
   HEAP32[$411>>2] = $409;
   $412 = $215;
   $413 = (($412) + 1)|0;
   $185 = $362;
   $186 = $413;
   $414 = $185;
   $415 = $186;
   $416 = -2147483648 | $415;
   $184 = $414;
   $417 = $184;
   $183 = $417;
   $418 = $183;
   $419 = ((($418)) + 8|0);
   HEAP32[$419>>2] = $416;
   $420 = $213;
   $189 = $362;
   $190 = $420;
   $421 = $189;
   $422 = $190;
   $188 = $421;
   $423 = $188;
   $187 = $423;
   $424 = $187;
   $425 = ((($424)) + 4|0);
   HEAP32[$425>>2] = $422;
  }
  $426 = $214;
  $191 = $426;
  $427 = $191;
  $428 = $212;
  $429 = $213;
  (__ZNSt3__211char_traitsIcE4copyEPcPKcj($427,$428,$429)|0);
  $430 = $214;
  $431 = $213;
  $432 = (($430) + ($431)|0);
  HEAP8[$216>>0] = 0;
  __ZNSt3__211char_traitsIcE6assignERcRKc($432,$216);
  STACKTOP = sp;return;
  break;
 }
 case 4: case 3:  {
  $165 = $0;
  $166 = 101066;
  $433 = $165;
  $164 = $433;
  $434 = $164;
  $163 = $434;
  $435 = $163;
  $162 = $435;
  ;HEAP32[$435>>2]=0|0;HEAP32[$435+4>>2]=0|0;HEAP32[$435+8>>2]=0|0;
  $436 = $166;
  $437 = $166;
  $438 = (__ZNSt3__211char_traitsIcE6lengthEPKc($437)|0);
  $156 = $433;
  $157 = $436;
  $158 = $438;
  $439 = $156;
  $440 = $158;
  $154 = $439;
  $441 = $154;
  $153 = $441;
  $442 = $153;
  $152 = $442;
  $443 = $152;
  $151 = $443;
  $444 = $151;
  $149 = $444;
  $445 = $149;
  ;HEAP8[$148>>0]=HEAP8[$150>>0]|0;
  $147 = $445;
  $446 = $147;
  $146 = $446;
  $155 = -1;
  $447 = $155;
  $448 = (($447) - 16)|0;
  $449 = ($440>>>0)>($448>>>0);
  if ($449) {
   __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv($439);
   // unreachable;
  }
  $450 = $158;
  $451 = ($450>>>0)<(11);
  $452 = $158;
  if ($451) {
   $144 = $439;
   $145 = $452;
   $453 = $144;
   $454 = $145;
   $455 = $454&255;
   $143 = $453;
   $456 = $143;
   $142 = $456;
   $457 = $142;
   $458 = ((($457)) + 11|0);
   HEAP8[$458>>0] = $455;
   $141 = $439;
   $459 = $141;
   $140 = $459;
   $460 = $140;
   $139 = $460;
   $461 = $139;
   $138 = $461;
   $462 = $138;
   $137 = $462;
   $463 = $137;
   $159 = $463;
  } else {
   $116 = $452;
   $464 = $116;
   $465 = ($464>>>0)<(11);
   if ($465) {
    $472 = 11;
   } else {
    $466 = $116;
    $467 = (($466) + 1)|0;
    $115 = $467;
    $468 = $115;
    $469 = (($468) + 15)|0;
    $470 = $469 & -16;
    $472 = $470;
   }
   $471 = (($472) - 1)|0;
   $160 = $471;
   $114 = $439;
   $473 = $114;
   $113 = $473;
   $474 = $113;
   $112 = $474;
   $475 = $112;
   $476 = $160;
   $477 = (($476) + 1)|0;
   $122 = $475;
   $123 = $477;
   $478 = $122;
   $479 = $123;
   $119 = $478;
   $120 = $479;
   $121 = 0;
   $480 = $119;
   $118 = $480;
   $481 = $120;
   $117 = $481;
   $482 = $117;
   $483 = (__Znwj($482)|0);
   $159 = $483;
   $484 = $159;
   $126 = $439;
   $127 = $484;
   $485 = $126;
   $486 = $127;
   $125 = $485;
   $487 = $125;
   $124 = $487;
   $488 = $124;
   HEAP32[$488>>2] = $486;
   $489 = $160;
   $490 = (($489) + 1)|0;
   $130 = $439;
   $131 = $490;
   $491 = $130;
   $492 = $131;
   $493 = -2147483648 | $492;
   $129 = $491;
   $494 = $129;
   $128 = $494;
   $495 = $128;
   $496 = ((($495)) + 8|0);
   HEAP32[$496>>2] = $493;
   $497 = $158;
   $134 = $439;
   $135 = $497;
   $498 = $134;
   $499 = $135;
   $133 = $498;
   $500 = $133;
   $132 = $500;
   $501 = $132;
   $502 = ((($501)) + 4|0);
   HEAP32[$502>>2] = $499;
  }
  $503 = $159;
  $136 = $503;
  $504 = $136;
  $505 = $157;
  $506 = $158;
  (__ZNSt3__211char_traitsIcE4copyEPcPKcj($504,$505,$506)|0);
  $507 = $159;
  $508 = $158;
  $509 = (($507) + ($508)|0);
  HEAP8[$161>>0] = 0;
  __ZNSt3__211char_traitsIcE6assignERcRKc($509,$161);
  STACKTOP = sp;return;
  break;
 }
 case 2:  {
  $110 = $0;
  $111 = 101068;
  $510 = $110;
  $109 = $510;
  $511 = $109;
  $108 = $511;
  $512 = $108;
  $107 = $512;
  ;HEAP32[$512>>2]=0|0;HEAP32[$512+4>>2]=0|0;HEAP32[$512+8>>2]=0|0;
  $513 = $111;
  $514 = $111;
  $515 = (__ZNSt3__211char_traitsIcE6lengthEPKc($514)|0);
  $101 = $510;
  $102 = $513;
  $103 = $515;
  $516 = $101;
  $517 = $103;
  $99 = $516;
  $518 = $99;
  $98 = $518;
  $519 = $98;
  $97 = $519;
  $520 = $97;
  $96 = $520;
  $521 = $96;
  $94 = $521;
  $522 = $94;
  ;HEAP8[$93>>0]=HEAP8[$95>>0]|0;
  $92 = $522;
  $523 = $92;
  $91 = $523;
  $100 = -1;
  $524 = $100;
  $525 = (($524) - 16)|0;
  $526 = ($517>>>0)>($525>>>0);
  if ($526) {
   __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv($516);
   // unreachable;
  }
  $527 = $103;
  $528 = ($527>>>0)<(11);
  $529 = $103;
  if ($528) {
   $89 = $516;
   $90 = $529;
   $530 = $89;
   $531 = $90;
   $532 = $531&255;
   $88 = $530;
   $533 = $88;
   $87 = $533;
   $534 = $87;
   $535 = ((($534)) + 11|0);
   HEAP8[$535>>0] = $532;
   $86 = $516;
   $536 = $86;
   $85 = $536;
   $537 = $85;
   $84 = $537;
   $538 = $84;
   $83 = $538;
   $539 = $83;
   $82 = $539;
   $540 = $82;
   $104 = $540;
  } else {
   $61 = $529;
   $541 = $61;
   $542 = ($541>>>0)<(11);
   if ($542) {
    $549 = 11;
   } else {
    $543 = $61;
    $544 = (($543) + 1)|0;
    $60 = $544;
    $545 = $60;
    $546 = (($545) + 15)|0;
    $547 = $546 & -16;
    $549 = $547;
   }
   $548 = (($549) - 1)|0;
   $105 = $548;
   $59 = $516;
   $550 = $59;
   $58 = $550;
   $551 = $58;
   $57 = $551;
   $552 = $57;
   $553 = $105;
   $554 = (($553) + 1)|0;
   $67 = $552;
   $68 = $554;
   $555 = $67;
   $556 = $68;
   $64 = $555;
   $65 = $556;
   $66 = 0;
   $557 = $64;
   $63 = $557;
   $558 = $65;
   $62 = $558;
   $559 = $62;
   $560 = (__Znwj($559)|0);
   $104 = $560;
   $561 = $104;
   $71 = $516;
   $72 = $561;
   $562 = $71;
   $563 = $72;
   $70 = $562;
   $564 = $70;
   $69 = $564;
   $565 = $69;
   HEAP32[$565>>2] = $563;
   $566 = $105;
   $567 = (($566) + 1)|0;
   $75 = $516;
   $76 = $567;
   $568 = $75;
   $569 = $76;
   $570 = -2147483648 | $569;
   $74 = $568;
   $571 = $74;
   $73 = $571;
   $572 = $73;
   $573 = ((($572)) + 8|0);
   HEAP32[$573>>2] = $570;
   $574 = $103;
   $79 = $516;
   $80 = $574;
   $575 = $79;
   $576 = $80;
   $78 = $575;
   $577 = $78;
   $77 = $577;
   $578 = $77;
   $579 = ((($578)) + 4|0);
   HEAP32[$579>>2] = $576;
  }
  $580 = $104;
  $81 = $580;
  $581 = $81;
  $582 = $102;
  $583 = $103;
  (__ZNSt3__211char_traitsIcE4copyEPcPKcj($581,$582,$583)|0);
  $584 = $104;
  $585 = $103;
  $586 = (($584) + ($585)|0);
  HEAP8[$106>>0] = 0;
  __ZNSt3__211char_traitsIcE6assignERcRKc($586,$106);
  STACKTOP = sp;return;
  break;
 }
 case 0: case 1:  {
  $55 = $0;
  $56 = 101070;
  $587 = $55;
  $54 = $587;
  $588 = $54;
  $53 = $588;
  $589 = $53;
  $52 = $589;
  ;HEAP32[$589>>2]=0|0;HEAP32[$589+4>>2]=0|0;HEAP32[$589+8>>2]=0|0;
  $590 = $56;
  $591 = $56;
  $592 = (__ZNSt3__211char_traitsIcE6lengthEPKc($591)|0);
  $46 = $587;
  $47 = $590;
  $48 = $592;
  $593 = $46;
  $594 = $48;
  $44 = $593;
  $595 = $44;
  $43 = $595;
  $596 = $43;
  $42 = $596;
  $597 = $42;
  $41 = $597;
  $598 = $41;
  $39 = $598;
  $599 = $39;
  ;HEAP8[$38>>0]=HEAP8[$40>>0]|0;
  $37 = $599;
  $600 = $37;
  $36 = $600;
  $45 = -1;
  $601 = $45;
  $602 = (($601) - 16)|0;
  $603 = ($594>>>0)>($602>>>0);
  if ($603) {
   __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv($593);
   // unreachable;
  }
  $604 = $48;
  $605 = ($604>>>0)<(11);
  $606 = $48;
  if ($605) {
   $34 = $593;
   $35 = $606;
   $607 = $34;
   $608 = $35;
   $609 = $608&255;
   $33 = $607;
   $610 = $33;
   $32 = $610;
   $611 = $32;
   $612 = ((($611)) + 11|0);
   HEAP8[$612>>0] = $609;
   $31 = $593;
   $613 = $31;
   $30 = $613;
   $614 = $30;
   $29 = $614;
   $615 = $29;
   $28 = $615;
   $616 = $28;
   $27 = $616;
   $617 = $27;
   $49 = $617;
  } else {
   $6 = $606;
   $618 = $6;
   $619 = ($618>>>0)<(11);
   if ($619) {
    $626 = 11;
   } else {
    $620 = $6;
    $621 = (($620) + 1)|0;
    $5 = $621;
    $622 = $5;
    $623 = (($622) + 15)|0;
    $624 = $623 & -16;
    $626 = $624;
   }
   $625 = (($626) - 1)|0;
   $50 = $625;
   $4 = $593;
   $627 = $4;
   $3 = $627;
   $628 = $3;
   $2 = $628;
   $629 = $2;
   $630 = $50;
   $631 = (($630) + 1)|0;
   $12 = $629;
   $13 = $631;
   $632 = $12;
   $633 = $13;
   $9 = $632;
   $10 = $633;
   $11 = 0;
   $634 = $9;
   $8 = $634;
   $635 = $10;
   $7 = $635;
   $636 = $7;
   $637 = (__Znwj($636)|0);
   $49 = $637;
   $638 = $49;
   $16 = $593;
   $17 = $638;
   $639 = $16;
   $640 = $17;
   $15 = $639;
   $641 = $15;
   $14 = $641;
   $642 = $14;
   HEAP32[$642>>2] = $640;
   $643 = $50;
   $644 = (($643) + 1)|0;
   $20 = $593;
   $21 = $644;
   $645 = $20;
   $646 = $21;
   $647 = -2147483648 | $646;
   $19 = $645;
   $648 = $19;
   $18 = $648;
   $649 = $18;
   $650 = ((($649)) + 8|0);
   HEAP32[$650>>2] = $647;
   $651 = $48;
   $24 = $593;
   $25 = $651;
   $652 = $24;
   $653 = $25;
   $23 = $652;
   $654 = $23;
   $22 = $654;
   $655 = $22;
   $656 = ((($655)) + 4|0);
   HEAP32[$656>>2] = $653;
  }
  $657 = $49;
  $26 = $657;
  $658 = $26;
  $659 = $47;
  $660 = $48;
  (__ZNSt3__211char_traitsIcE4copyEPcPKcj($658,$659,$660)|0);
  $661 = $49;
  $662 = $48;
  $663 = (($661) + ($662)|0);
  HEAP8[$51>>0] = 0;
  __ZNSt3__211char_traitsIcE6assignERcRKc($663,$51);
  STACKTOP = sp;return;
  break;
 }
 default: {
  _llvm_trap();
  // unreachable;
 }
 }
}
function __ZN4mjin3log9logprintfEPKcz($0,$varargs) {
 $0 = $0|0;
 $varargs = $varargs|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1056|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(1056|0);
 $3 = sp;
 $4 = sp + 24|0;
 $1 = $0;
 $2 = 1024;
 HEAP32[$3>>2] = $varargs;
 $5 = $1;
 (_vsnprintf($4,1024,$5,$3)|0);
 __ZN4mjin3log3logEPKc($4);
 STACKTOP = sp;return;
}
function __ZNSt3__211char_traitsIcE6lengthEPKc($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 $3 = (_strlen($2)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZNSt3__211char_traitsIcE4copyEPcPKcj($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = $0;
 $4 = $1;
 $5 = $2;
 $6 = $5;
 $7 = ($6|0)==(0);
 $8 = $3;
 if ($7) {
  STACKTOP = sp;return ($8|0);
 }
 $9 = $4;
 $10 = $5;
 _memcpy(($8|0),($9|0),($10|0))|0;
 STACKTOP = sp;return ($8|0);
}
function __ZNSt3__211char_traitsIcE6assignERcRKc($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = $0;
 $3 = $1;
 $4 = $3;
 $5 = HEAP8[$4>>0]|0;
 $6 = $2;
 HEAP8[$6>>0] = $5;
 STACKTOP = sp;return;
}
function ___clang_call_terminate($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (___cxa_begin_catch(($0|0))|0);
 __ZSt9terminatev();
 // unreachable;
}
function __ZN4mjin3log6LoggerD2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 __ZN3osg13NotifyHandlerD2Ev($2);
 STACKTOP = sp;return;
}
function __ZN3osg13NotifyHandlerD2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 __ZN3osg10ReferencedD2Ev($2);
 STACKTOP = sp;return;
}
function __ZN4mjin3log6LoggerC2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 __ZN3osg13NotifyHandlerC2Ev($2);
 HEAP32[$2>>2] = (34728);
 STACKTOP = sp;return;
}
function __ZN3osg13NotifyHandlerC2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 __ZN3osg10ReferencedC2Ev($2);
 HEAP32[$2>>2] = (34752);
 STACKTOP = sp;return;
}
function __ZN3osg13NotifyHandlerD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 __ZN3osg13NotifyHandlerD2Ev($2);
 __ZdlPv($2);
 STACKTOP = sp;return;
}
function __ZN4mjin3log3logEPKc($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = $0;
 $4 = $3;
 $5 = (__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(214316,$4)|0);
 $1 = $5;
 $2 = 3254;
 $6 = $1;
 $7 = $2;
 (FUNCTION_TABLE_ii[$7 & 8191]($6)|0);
 STACKTOP = sp;return;
}
function __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = $0;
 $3 = $1;
 $4 = $2;
 $5 = $3;
 $6 = $3;
 $7 = (__ZNSt3__211char_traitsIcE6lengthEPKc($6)|0);
 $8 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($4,$5,$7)|0);
 STACKTOP = sp;return ($8|0);
}
function __ZNSt3__24endlIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $6 = sp + 12|0;
 $9 = $0;
 $10 = $9;
 $11 = $9;
 $12 = HEAP32[$11>>2]|0;
 $13 = ((($12)) + -12|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($11) + ($14)|0);
 $4 = $15;
 $5 = 10;
 $16 = $4;
 __ZNKSt3__28ios_base6getlocEv($6,$16);
 $3 = $6;
 $17 = $3;
 __THREW__ = 0;
 $18 = (invoke_iii(3255,($17|0),(215188|0))|0);
 $19 = __THREW__; __THREW__ = 0;
 $20 = $19&1;
 if ($20) {
  $30 = ___cxa_find_matching_catch_2()|0;
  $31 = tempRet0;
  $7 = $30;
  $8 = $31;
  __ZNSt3__26localeD2Ev($6);
  $32 = $7;
  $33 = $8;
  ___resumeException($32|0);
  // unreachable;
 }
 $21 = $5;
 $1 = $18;
 $2 = $21;
 $22 = $1;
 $23 = HEAP32[$22>>2]|0;
 $24 = ((($23)) + 28|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = $2;
 __THREW__ = 0;
 $27 = (invoke_iii($25|0,($22|0),($26|0))|0);
 $28 = __THREW__; __THREW__ = 0;
 $29 = $28&1;
 if ($29) {
  $30 = ___cxa_find_matching_catch_2()|0;
  $31 = tempRet0;
  $7 = $30;
  $8 = $31;
  __ZNSt3__26localeD2Ev($6);
  $32 = $7;
  $33 = $8;
  ___resumeException($32|0);
  // unreachable;
 } else {
  __ZNSt3__26localeD2Ev($6);
  (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($10,$27)|0);
  $34 = $9;
  (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($34)|0);
  $35 = $9;
  STACKTOP = sp;return ($35|0);
 }
 return (0)|0;
}
function __ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$byval_copy = 0, $$sink1 = 0, $$sink2 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(128|0);
 $$byval_copy = sp + 108|0;
 $8 = sp + 92|0;
 $26 = sp + 16|0;
 $29 = sp + 4|0;
 $30 = sp;
 $23 = $0;
 $24 = $1;
 $25 = $2;
 $31 = $23;
 __THREW__ = 0;
 invoke_vii(3256,($26|0),($31|0));
 $32 = __THREW__; __THREW__ = 0;
 $33 = $32&1;
 L1: do {
  if ($33) {
   $127 = ___cxa_find_matching_catch_3(0|0)|0;
   $128 = tempRet0;
   $27 = $127;
   $28 = $128;
  } else {
   $22 = $26;
   $34 = $22;
   $35 = HEAP8[$34>>0]|0;
   $36 = $35&1;
   do {
    if ($36) {
     $37 = $23;
     $20 = $30;
     $21 = $37;
     $38 = $20;
     $39 = $21;
     $40 = HEAP32[$39>>2]|0;
     $41 = ((($40)) + -12|0);
     $42 = HEAP32[$41>>2]|0;
     $43 = (($39) + ($42)|0);
     $19 = $43;
     $44 = $19;
     $18 = $44;
     $45 = $18;
     $46 = ((($45)) + 24|0);
     $47 = HEAP32[$46>>2]|0;
     HEAP32[$38>>2] = $47;
     $48 = $24;
     $49 = $23;
     $50 = HEAP32[$49>>2]|0;
     $51 = ((($50)) + -12|0);
     $52 = HEAP32[$51>>2]|0;
     $53 = (($49) + ($52)|0);
     $13 = $53;
     $54 = $13;
     $55 = ((($54)) + 4|0);
     $56 = HEAP32[$55>>2]|0;
     $57 = $56 & 176;
     $58 = ($57|0)==(32);
     $59 = $24;
     $60 = $25;
     $61 = (($59) + ($60)|0);
     $62 = $24;
     $63 = $58 ? $61 : $62;
     $64 = $24;
     $65 = $25;
     $66 = (($64) + ($65)|0);
     $67 = $23;
     $68 = HEAP32[$67>>2]|0;
     $69 = ((($68)) + -12|0);
     $70 = HEAP32[$69>>2]|0;
     $71 = (($67) + ($70)|0);
     $72 = $23;
     $73 = HEAP32[$72>>2]|0;
     $74 = ((($73)) + -12|0);
     $75 = HEAP32[$74>>2]|0;
     $76 = (($72) + ($75)|0);
     $11 = $76;
     $77 = $11;
     $78 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
     $79 = ((($77)) + 76|0);
     $80 = HEAP32[$79>>2]|0;
     $81 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($78,$80)|0);
     do {
      if ($81) {
       $6 = $77;
       $7 = 32;
       $82 = $6;
       __THREW__ = 0;
       invoke_vii(3257,($8|0),($82|0));
       $83 = __THREW__; __THREW__ = 0;
       $84 = $83&1;
       if ($84) {
        label = 13;
       } else {
        $5 = $8;
        $85 = $5;
        __THREW__ = 0;
        $86 = (invoke_iii(3255,($85|0),(215188|0))|0);
        $87 = __THREW__; __THREW__ = 0;
        $88 = $87&1;
        if (!($88)) {
         $89 = $7;
         $3 = $86;
         $4 = $89;
         $90 = $3;
         $91 = HEAP32[$90>>2]|0;
         $92 = ((($91)) + 28|0);
         $93 = HEAP32[$92>>2]|0;
         $94 = $4;
         __THREW__ = 0;
         $95 = (invoke_iii($93|0,($90|0),($94|0))|0);
         $96 = __THREW__; __THREW__ = 0;
         $97 = $96&1;
         if (!($97)) {
          __ZNSt3__26localeD2Ev($8);
          $102 = $95 << 24 >> 24;
          $103 = ((($77)) + 76|0);
          HEAP32[$103>>2] = $102;
          label = 9;
          break;
         }
        }
        $98 = ___cxa_find_matching_catch_3(0|0)|0;
        $99 = tempRet0;
        $9 = $98;
        $10 = $99;
        __ZNSt3__26localeD2Ev($8);
        $100 = $9;
        $101 = $10;
        $$sink1 = $101;$$sink2 = $100;
       }
      } else {
       label = 9;
      }
     } while(0);
     if ((label|0) == 9) {
      $104 = ((($77)) + 76|0);
      $105 = HEAP32[$104>>2]|0;
      $106 = $105&255;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy>>2]=HEAP32[$30>>2]|0;
      $107 = (invoke_iiiiiii(3258,($$byval_copy|0),($48|0),($63|0),($66|0),($71|0),($106|0))|0);
      $108 = __THREW__; __THREW__ = 0;
      $109 = $108&1;
      if ($109) {
       label = 13;
      } else {
       HEAP32[$29>>2] = $107;
       $12 = $29;
       $110 = $12;
       $111 = HEAP32[$110>>2]|0;
       $112 = ($111|0)==(0|0);
       if (!($112)) {
        break;
       }
       $113 = $23;
       $114 = HEAP32[$113>>2]|0;
       $115 = ((($114)) + -12|0);
       $116 = HEAP32[$115>>2]|0;
       $117 = (($113) + ($116)|0);
       $16 = $117;
       $17 = 5;
       $118 = $16;
       $119 = $17;
       $14 = $118;
       $15 = $119;
       $120 = $14;
       $121 = ((($120)) + 16|0);
       $122 = HEAP32[$121>>2]|0;
       $123 = $15;
       $124 = $122 | $123;
       __THREW__ = 0;
       invoke_vii(3259,($120|0),($124|0));
       $125 = __THREW__; __THREW__ = 0;
       $126 = $125&1;
       if ($126) {
        label = 13;
       } else {
        break;
       }
      }
     }
     if ((label|0) == 13) {
      $129 = ___cxa_find_matching_catch_3(0|0)|0;
      $130 = tempRet0;
      $$sink1 = $130;$$sink2 = $129;
     }
     $27 = $$sink2;
     $28 = $$sink1;
     __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE6sentryD2Ev($26);
     break L1;
    }
   } while(0);
   __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE6sentryD2Ev($26);
   $139 = $23;
   STACKTOP = sp;return ($139|0);
  }
 } while(0);
 $131 = $27;
 (___cxa_begin_catch(($131|0))|0);
 $132 = $23;
 $133 = HEAP32[$132>>2]|0;
 $134 = ((($133)) + -12|0);
 $135 = HEAP32[$134>>2]|0;
 $136 = (($132) + ($135)|0);
 __THREW__ = 0;
 invoke_vi(3260,($136|0));
 $137 = __THREW__; __THREW__ = 0;
 $138 = $137&1;
 if (!($138)) {
  ___cxa_end_catch();
  $139 = $23;
  STACKTOP = sp;return ($139|0);
 }
 $140 = ___cxa_find_matching_catch_2()|0;
 $141 = tempRet0;
 $27 = $140;
 $28 = $141;
 __THREW__ = 0;
 invoke_v(3261);
 $142 = __THREW__; __THREW__ = 0;
 $143 = $142&1;
 if ($143) {
  $146 = ___cxa_find_matching_catch_3(0|0)|0;
  $147 = tempRet0;
  ___clang_call_terminate($146);
  // unreachable;
 } else {
  $144 = $27;
  $145 = $28;
  ___resumeException($144|0);
  // unreachable;
 }
 return (0)|0;
}
function __ZNSt3__211char_traitsIcE3eofEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 return -1;
}
function __ZNSt3__211char_traitsIcE11eq_int_typeEii($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = $0;
 $3 = $1;
 $4 = $2;
 $5 = $3;
 $6 = ($4|0)==($5|0);
 STACKTOP = sp;return ($6|0);
}
function __ZNSt3__216__pad_and_outputIcNS_11char_traitsIcEEEENS_19ostreambuf_iteratorIT_T0_EES6_PKS4_S8_S8_RNS_8ios_baseES4_($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0;
 var $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0;
 var $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0;
 var $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0;
 var $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0;
 var $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0;
 var $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0;
 var $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0;
 var $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0;
 var $281 = 0, $282 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $switch = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 384|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(384|0);
 $59 = sp;
 $61 = sp + 376|0;
 $72 = sp + 374|0;
 $89 = sp + 56|0;
 $98 = sp + 16|0;
 $90 = $1;
 $91 = $2;
 $92 = $3;
 $93 = $4;
 $94 = $5;
 $102 = HEAP32[$0>>2]|0;
 $103 = ($102|0)==(0|0);
 if ($103) {
  ;HEAP32[$89>>2]=HEAP32[$0>>2]|0;
  $282 = HEAP32[$89>>2]|0;
  STACKTOP = sp;return ($282|0);
 }
 $104 = $92;
 $105 = $90;
 $106 = $104;
 $107 = $105;
 $108 = (($106) - ($107))|0;
 $95 = $108;
 $109 = $93;
 $88 = $109;
 $110 = $88;
 $111 = ((($110)) + 12|0);
 $112 = HEAP32[$111>>2]|0;
 $96 = $112;
 $113 = $96;
 $114 = $95;
 $115 = ($113|0)>($114|0);
 if ($115) {
  $116 = $95;
  $117 = $96;
  $118 = (($117) - ($116))|0;
  $96 = $118;
 } else {
  $96 = 0;
 }
 $119 = $91;
 $120 = $90;
 $121 = $119;
 $122 = $120;
 $123 = (($121) - ($122))|0;
 $97 = $123;
 $124 = $97;
 $125 = ($124|0)>(0);
 if ($125) {
  $126 = HEAP32[$0>>2]|0;
  $127 = $90;
  $128 = $97;
  $79 = $126;
  $80 = $127;
  $81 = $128;
  $129 = $79;
  $130 = HEAP32[$129>>2]|0;
  $131 = ((($130)) + 48|0);
  $132 = HEAP32[$131>>2]|0;
  $133 = $80;
  $134 = $81;
  $135 = (FUNCTION_TABLE_iiii[$132 & 8191]($129,$133,$134)|0);
  $136 = $97;
  $137 = ($135|0)!=($136|0);
  if ($137) {
   HEAP32[$0>>2] = 0;
   ;HEAP32[$89>>2]=HEAP32[$0>>2]|0;
   $282 = HEAP32[$89>>2]|0;
   STACKTOP = sp;return ($282|0);
  }
 }
 $138 = $96;
 $139 = ($138|0)>(0);
 if ($139) {
  $140 = $96;
  $141 = $94;
  $76 = $98;
  $77 = $140;
  $78 = $141;
  $142 = $76;
  $75 = $142;
  $143 = $75;
  $74 = $143;
  $144 = $74;
  $73 = $144;
  ;HEAP32[$144>>2]=0|0;HEAP32[$144+4>>2]=0|0;HEAP32[$144+8>>2]=0|0;
  $145 = $77;
  $146 = $78;
  $67 = $142;
  $68 = $145;
  $69 = $146;
  $147 = $67;
  $148 = $68;
  $65 = $147;
  $149 = $65;
  $64 = $149;
  $150 = $64;
  $63 = $150;
  $151 = $63;
  $62 = $151;
  $152 = $62;
  $60 = $152;
  $153 = $60;
  ;HEAP8[$59>>0]=HEAP8[$61>>0]|0;
  $58 = $153;
  $154 = $58;
  $57 = $154;
  $66 = -1;
  $155 = $66;
  $156 = (($155) - 16)|0;
  $157 = ($148>>>0)>($156>>>0);
  if ($157) {
   __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv($147);
   // unreachable;
  }
  $158 = $68;
  $159 = ($158>>>0)<(11);
  $160 = $68;
  if ($159) {
   $55 = $147;
   $56 = $160;
   $161 = $55;
   $162 = $56;
   $163 = $162&255;
   $54 = $161;
   $164 = $54;
   $53 = $164;
   $165 = $53;
   $166 = ((($165)) + 11|0);
   HEAP8[$166>>0] = $163;
   $52 = $147;
   $167 = $52;
   $51 = $167;
   $168 = $51;
   $50 = $168;
   $169 = $50;
   $49 = $169;
   $170 = $49;
   $48 = $170;
   $171 = $48;
   $70 = $171;
  } else {
   $27 = $160;
   $172 = $27;
   $173 = ($172>>>0)<(11);
   if ($173) {
    $180 = 11;
   } else {
    $174 = $27;
    $175 = (($174) + 1)|0;
    $26 = $175;
    $176 = $26;
    $177 = (($176) + 15)|0;
    $178 = $177 & -16;
    $180 = $178;
   }
   $179 = (($180) - 1)|0;
   $71 = $179;
   $25 = $147;
   $181 = $25;
   $24 = $181;
   $182 = $24;
   $23 = $182;
   $183 = $23;
   $184 = $71;
   $185 = (($184) + 1)|0;
   $33 = $183;
   $34 = $185;
   $186 = $33;
   $187 = $34;
   $30 = $186;
   $31 = $187;
   $32 = 0;
   $188 = $30;
   $29 = $188;
   $189 = $31;
   $28 = $189;
   $190 = $28;
   $191 = (__Znwj($190)|0);
   $70 = $191;
   $192 = $70;
   $37 = $147;
   $38 = $192;
   $193 = $37;
   $194 = $38;
   $36 = $193;
   $195 = $36;
   $35 = $195;
   $196 = $35;
   HEAP32[$196>>2] = $194;
   $197 = $71;
   $198 = (($197) + 1)|0;
   $41 = $147;
   $42 = $198;
   $199 = $41;
   $200 = $42;
   $201 = -2147483648 | $200;
   $40 = $199;
   $202 = $40;
   $39 = $202;
   $203 = $39;
   $204 = ((($203)) + 8|0);
   HEAP32[$204>>2] = $201;
   $205 = $68;
   $45 = $147;
   $46 = $205;
   $206 = $45;
   $207 = $46;
   $44 = $206;
   $208 = $44;
   $43 = $208;
   $209 = $43;
   $210 = ((($209)) + 4|0);
   HEAP32[$210>>2] = $207;
  }
  $211 = $70;
  $47 = $211;
  $212 = $47;
  $213 = $68;
  $214 = $69;
  (__ZNSt3__211char_traitsIcE6assignEPcjc($212,$213,$214)|0);
  $215 = $70;
  $216 = $68;
  $217 = (($215) + ($216)|0);
  HEAP8[$72>>0] = 0;
  __ZNSt3__211char_traitsIcE6assignERcRKc($217,$72);
  $218 = HEAP32[$0>>2]|0;
  $22 = $98;
  $219 = $22;
  $21 = $219;
  $220 = $21;
  $20 = $220;
  $221 = $20;
  $19 = $221;
  $222 = $19;
  $18 = $222;
  $223 = $18;
  $224 = ((($223)) + 11|0);
  $225 = HEAP8[$224>>0]|0;
  $226 = $225&255;
  $227 = $226 & 128;
  $228 = ($227|0)!=(0);
  if ($228) {
   $12 = $220;
   $229 = $12;
   $11 = $229;
   $230 = $11;
   $10 = $230;
   $231 = $10;
   $232 = HEAP32[$231>>2]|0;
   $238 = $232;
  } else {
   $17 = $220;
   $233 = $17;
   $16 = $233;
   $234 = $16;
   $15 = $234;
   $235 = $15;
   $14 = $235;
   $236 = $14;
   $13 = $236;
   $237 = $13;
   $238 = $237;
  }
  $9 = $238;
  $239 = $9;
  $240 = $96;
  $6 = $218;
  $7 = $239;
  $8 = $240;
  $241 = $6;
  $242 = HEAP32[$241>>2]|0;
  $243 = ((($242)) + 48|0);
  $244 = HEAP32[$243>>2]|0;
  $245 = $7;
  $246 = $8;
  __THREW__ = 0;
  $247 = (invoke_iiii($244|0,($241|0),($245|0),($246|0))|0);
  $248 = __THREW__; __THREW__ = 0;
  $249 = $248&1;
  if ($249) {
   $252 = ___cxa_find_matching_catch_2()|0;
   $253 = tempRet0;
   $99 = $252;
   $100 = $253;
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($98);
   $254 = $99;
   $255 = $100;
   ___resumeException($254|0);
   // unreachable;
  }
  $250 = $96;
  $251 = ($247|0)!=($250|0);
  if ($251) {
   HEAP32[$0>>2] = 0;
   ;HEAP32[$89>>2]=HEAP32[$0>>2]|0;
   $101 = 1;
  } else {
   $101 = 0;
  }
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($98);
  $256 = $101;
  $switch = ($256>>>0)<(1);
  if (!($switch)) {
   $282 = HEAP32[$89>>2]|0;
   STACKTOP = sp;return ($282|0);
  }
 }
 $257 = $92;
 $258 = $91;
 $259 = $257;
 $260 = $258;
 $261 = (($259) - ($260))|0;
 $97 = $261;
 $262 = $97;
 $263 = ($262|0)>(0);
 if ($263) {
  $264 = HEAP32[$0>>2]|0;
  $265 = $91;
  $266 = $97;
  $82 = $264;
  $83 = $265;
  $84 = $266;
  $267 = $82;
  $268 = HEAP32[$267>>2]|0;
  $269 = ((($268)) + 48|0);
  $270 = HEAP32[$269>>2]|0;
  $271 = $83;
  $272 = $84;
  $273 = (FUNCTION_TABLE_iiii[$270 & 8191]($267,$271,$272)|0);
  $274 = $97;
  $275 = ($273|0)!=($274|0);
  if ($275) {
   HEAP32[$0>>2] = 0;
   ;HEAP32[$89>>2]=HEAP32[$0>>2]|0;
   $282 = HEAP32[$89>>2]|0;
   STACKTOP = sp;return ($282|0);
  }
 }
 $276 = $93;
 $85 = $276;
 $86 = 0;
 $277 = $85;
 $278 = ((($277)) + 12|0);
 $279 = HEAP32[$278>>2]|0;
 $87 = $279;
 $280 = $86;
 $281 = ((($277)) + 12|0);
 HEAP32[$281>>2] = $280;
 ;HEAP32[$89>>2]=HEAP32[$0>>2]|0;
 $282 = HEAP32[$89>>2]|0;
 STACKTOP = sp;return ($282|0);
}
function __ZNSt3__211char_traitsIcE6assignEPcjc($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = $0;
 $4 = $1;
 $5 = $2;
 $6 = $4;
 $7 = ($6|0)==(0);
 $8 = $3;
 if ($7) {
  STACKTOP = sp;return ($8|0);
 }
 $9 = $5;
 $10 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($9)|0);
 $11 = $10&255;
 $12 = $4;
 _memset(($8|0),($11|0),($12|0))|0;
 STACKTOP = sp;return ($8|0);
}
function __ZNSt3__211char_traitsIcE11to_int_typeEc($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 $3 = $2&255;
 STACKTOP = sp;return ($3|0);
}
function __ZN9osgViewer14GraphicsWindowD2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (34776);
 $1 = ((($0)) + 132|0);
 HEAP32[$1>>2] = (35040);
 $2 = ((($0)) + 136|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  HEAP32[$2>>2] = 0;
  __ZN3osg15GraphicsContextD2Ev($0);
  return;
 }
 $5 = ((($3)) + 8|0);
 $6 = HEAP32[$5>>2]|0;HEAP32[$5>>2] = (($6-1)|0);
 $7 = ($6|0)==(1);
 if (!($7)) {
  HEAP32[$2>>2] = 0;
  __ZN3osg15GraphicsContextD2Ev($0);
  return;
 }
 __THREW__ = 0;
 invoke_viii(3262,($3|0),1,1);
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if (!($9)) {
  HEAP32[$2>>2] = 0;
  __ZN3osg15GraphicsContextD2Ev($0);
  return;
 }
 $10 = ___cxa_find_matching_catch_2()|0;
 $11 = tempRet0;
 __THREW__ = 0;
 invoke_vi(1871,($0|0));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $14 = ___cxa_find_matching_catch_3(0|0)|0;
  $15 = tempRet0;
  ___clang_call_terminate($14);
  // unreachable;
 } else {
  ___resumeException($10|0);
  // unreachable;
 }
}
function __ZN9osgViewer14GraphicsWindowD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0;
 var $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (34776);
 $1 = ((($0)) + 132|0);
 HEAP32[$1>>2] = (35040);
 $2 = ((($0)) + 136|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = ((($3)) + 8|0);
  $6 = HEAP32[$5>>2]|0;HEAP32[$5>>2] = (($6-1)|0);
  $7 = ($6|0)==(1);
  if ($7) {
   __THREW__ = 0;
   invoke_viii(3262,($3|0),1,1);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if ($9) {
    $12 = ___cxa_find_matching_catch_2()|0;
    $13 = tempRet0;
    __THREW__ = 0;
    invoke_vi(1871,($0|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     $16 = ___cxa_find_matching_catch_3(0|0)|0;
     $17 = tempRet0;
     ___clang_call_terminate($16);
     // unreachable;
    } else {
     $eh$lpad$body$index2Z2D = $13;$eh$lpad$body$indexZ2D = $12;
     __ZdlPv($0);
     ___resumeException($eh$lpad$body$indexZ2D|0);
     // unreachable;
    }
   }
  }
 }
 HEAP32[$2>>2] = 0;
 __THREW__ = 0;
 invoke_vi(1871,($0|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if (!($11)) {
  __ZdlPv($0);
  return;
 }
 $18 = ___cxa_find_matching_catch_2()|0;
 $19 = tempRet0;
 $eh$lpad$body$index2Z2D = $19;$eh$lpad$body$indexZ2D = $18;
 __ZdlPv($0);
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
}
function __ZNK3osg15GraphicsContext9cloneTypeEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZNK3osg15GraphicsContext5cloneERKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZNK9osgViewer14GraphicsWindow12isSameKindAsEPKN3osg6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,3888,0)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK9osgViewer14GraphicsWindow11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (107921|0);
}
function __ZNK9osgViewer14GraphicsWindow9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (102243|0);
}
function __ZN3osg6Object6asNodeEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZNK3osg6Object6asNodeEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZN3osg6Object13asNodeVisitorEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZNK3osg6Object13asNodeVisitorEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZN3osg6Object10asStateSetEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZNK3osg6Object10asStateSetEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZN3osg6Object16asStateAttributeEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZNK3osg6Object16asStateAttributeEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZN3osg6Object9asUniformEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZNK3osg6Object9asUniformEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZN3osg6Object8asCameraEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZNK3osg6Object8asCameraEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZN3osg6Object10asDrawableEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZNK3osg6Object10asDrawableEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZN3osg6Object10asCallbackEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZNK3osg6Object10asCallbackEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZN3osg6Object16asCallbackObjectEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZNK3osg6Object16asCallbackObjectEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZN3osg6Object19asUserDataContainerEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZNK3osg6Object19asUserDataContainerEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZN3osg6Object7setNameERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 12|0);
 (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEaSERKS5_($2,$1)|0);
 return;
}
function __ZN3osg6Object19computeDataVarianceEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN3osg6Object21resizeGLObjectBuffersEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZNK3osg6Object16releaseGLObjectsEPNS_5StateE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZNK9osgViewer14GraphicsWindow5validEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $2 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
 $3 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($2,102202,40)|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($4)) + -12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($3) + ($6)|0);
 __ZNKSt3__28ios_base6getlocEv($1,$7);
 __THREW__ = 0;
 $8 = (invoke_iii(3255,($1|0),(215188|0))|0);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if (!($10)) {
  $11 = HEAP32[$8>>2]|0;
  $12 = ((($11)) + 28|0);
  $13 = HEAP32[$12>>2]|0;
  __THREW__ = 0;
  $14 = (invoke_iii($13|0,($8|0),10)|0);
  $15 = __THREW__; __THREW__ = 0;
  $16 = $15&1;
  if (!($16)) {
   __ZNSt3__26localeD2Ev($1);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($3,$14)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($3)|0);
   STACKTOP = sp;return 0;
  }
 }
 $17 = ___cxa_find_matching_catch_2()|0;
 $18 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($1|0));
 $19 = __THREW__; __THREW__ = 0;
 $20 = $19&1;
 if ($20) {
  $21 = ___cxa_find_matching_catch_3(0|0)|0;
  $22 = tempRet0;
  ___clang_call_terminate($21);
  // unreachable;
 } else {
  ___resumeException($17|0);
  // unreachable;
 }
 return (0)|0;
}
function __ZN9osgViewer14GraphicsWindow21realizeImplementationEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $2 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
 $3 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($2,102145,56)|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($4)) + -12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($3) + ($6)|0);
 __ZNKSt3__28ios_base6getlocEv($1,$7);
 __THREW__ = 0;
 $8 = (invoke_iii(3255,($1|0),(215188|0))|0);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if (!($10)) {
  $11 = HEAP32[$8>>2]|0;
  $12 = ((($11)) + 28|0);
  $13 = HEAP32[$12>>2]|0;
  __THREW__ = 0;
  $14 = (invoke_iii($13|0,($8|0),10)|0);
  $15 = __THREW__; __THREW__ = 0;
  $16 = $15&1;
  if (!($16)) {
   __ZNSt3__26localeD2Ev($1);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($3,$14)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($3)|0);
   STACKTOP = sp;return 0;
  }
 }
 $17 = ___cxa_find_matching_catch_2()|0;
 $18 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($1|0));
 $19 = __THREW__; __THREW__ = 0;
 $20 = $19&1;
 if ($20) {
  $21 = ___cxa_find_matching_catch_3(0|0)|0;
  $22 = tempRet0;
  ___clang_call_terminate($21);
  // unreachable;
 } else {
  ___resumeException($17|0);
  // unreachable;
 }
 return (0)|0;
}
function __ZNK9osgViewer14GraphicsWindow24isRealizedImplementationEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $2 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
 $3 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($2,102085,59)|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($4)) + -12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($3) + ($6)|0);
 __ZNKSt3__28ios_base6getlocEv($1,$7);
 __THREW__ = 0;
 $8 = (invoke_iii(3255,($1|0),(215188|0))|0);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if (!($10)) {
  $11 = HEAP32[$8>>2]|0;
  $12 = ((($11)) + 28|0);
  $13 = HEAP32[$12>>2]|0;
  __THREW__ = 0;
  $14 = (invoke_iii($13|0,($8|0),10)|0);
  $15 = __THREW__; __THREW__ = 0;
  $16 = $15&1;
  if (!($16)) {
   __ZNSt3__26localeD2Ev($1);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($3,$14)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($3)|0);
   STACKTOP = sp;return 0;
  }
 }
 $17 = ___cxa_find_matching_catch_2()|0;
 $18 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($1|0));
 $19 = __THREW__; __THREW__ = 0;
 $20 = $19&1;
 if ($20) {
  $21 = ___cxa_find_matching_catch_3(0|0)|0;
  $22 = tempRet0;
  ___clang_call_terminate($21);
  // unreachable;
 } else {
  ___resumeException($17|0);
  // unreachable;
 }
 return (0)|0;
}
function __ZN9osgViewer14GraphicsWindow19closeImplementationEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $2 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
 $3 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($2,102030,54)|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($4)) + -12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($3) + ($6)|0);
 __ZNKSt3__28ios_base6getlocEv($1,$7);
 __THREW__ = 0;
 $8 = (invoke_iii(3255,($1|0),(215188|0))|0);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if (!($10)) {
  $11 = HEAP32[$8>>2]|0;
  $12 = ((($11)) + 28|0);
  $13 = HEAP32[$12>>2]|0;
  __THREW__ = 0;
  $14 = (invoke_iii($13|0,($8|0),10)|0);
  $15 = __THREW__; __THREW__ = 0;
  $16 = $15&1;
  if (!($16)) {
   __ZNSt3__26localeD2Ev($1);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($3,$14)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($3)|0);
   STACKTOP = sp;return;
  }
 }
 $17 = ___cxa_find_matching_catch_2()|0;
 $18 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($1|0));
 $19 = __THREW__; __THREW__ = 0;
 $20 = $19&1;
 if ($20) {
  $21 = ___cxa_find_matching_catch_3(0|0)|0;
  $22 = tempRet0;
  ___clang_call_terminate($21);
  // unreachable;
 } else {
  ___resumeException($17|0);
  // unreachable;
 }
}
function __ZN9osgViewer14GraphicsWindow25makeCurrentImplementationEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $2 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
 $3 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($2,101969,60)|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($4)) + -12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($3) + ($6)|0);
 __ZNKSt3__28ios_base6getlocEv($1,$7);
 __THREW__ = 0;
 $8 = (invoke_iii(3255,($1|0),(215188|0))|0);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if (!($10)) {
  $11 = HEAP32[$8>>2]|0;
  $12 = ((($11)) + 28|0);
  $13 = HEAP32[$12>>2]|0;
  __THREW__ = 0;
  $14 = (invoke_iii($13|0,($8|0),10)|0);
  $15 = __THREW__; __THREW__ = 0;
  $16 = $15&1;
  if (!($16)) {
   __ZNSt3__26localeD2Ev($1);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($3,$14)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($3)|0);
   STACKTOP = sp;return 0;
  }
 }
 $17 = ___cxa_find_matching_catch_2()|0;
 $18 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($1|0));
 $19 = __THREW__; __THREW__ = 0;
 $20 = $19&1;
 if ($20) {
  $21 = ___cxa_find_matching_catch_3(0|0)|0;
  $22 = tempRet0;
  ___clang_call_terminate($21);
  // unreachable;
 } else {
  ___resumeException($17|0);
  // unreachable;
 }
 return (0)|0;
}
function __ZN9osgViewer14GraphicsWindow32makeContextCurrentImplementationEPN3osg15GraphicsContextE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
 $4 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($3,101899,69)|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($5)) + -12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($4) + ($7)|0);
 __ZNKSt3__28ios_base6getlocEv($2,$8);
 __THREW__ = 0;
 $9 = (invoke_iii(3255,($2|0),(215188|0))|0);
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if (!($11)) {
  $12 = HEAP32[$9>>2]|0;
  $13 = ((($12)) + 28|0);
  $14 = HEAP32[$13>>2]|0;
  __THREW__ = 0;
  $15 = (invoke_iii($14|0,($9|0),10)|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __ZNSt3__26localeD2Ev($2);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($4,$15)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($4)|0);
   STACKTOP = sp;return 0;
  }
 }
 $18 = ___cxa_find_matching_catch_2()|0;
 $19 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($2|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if ($21) {
  $22 = ___cxa_find_matching_catch_3(0|0)|0;
  $23 = tempRet0;
  ___clang_call_terminate($22);
  // unreachable;
 } else {
  ___resumeException($18|0);
  // unreachable;
 }
 return (0)|0;
}
function __ZN9osgViewer14GraphicsWindow28releaseContextImplementationEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $2 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
 $3 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($2,101833,65)|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($4)) + -12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($3) + ($6)|0);
 __ZNKSt3__28ios_base6getlocEv($1,$7);
 __THREW__ = 0;
 $8 = (invoke_iii(3255,($1|0),(215188|0))|0);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if (!($10)) {
  $11 = HEAP32[$8>>2]|0;
  $12 = ((($11)) + 28|0);
  $13 = HEAP32[$12>>2]|0;
  __THREW__ = 0;
  $14 = (invoke_iii($13|0,($8|0),10)|0);
  $15 = __THREW__; __THREW__ = 0;
  $16 = $15&1;
  if (!($16)) {
   __ZNSt3__26localeD2Ev($1);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($3,$14)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($3)|0);
   STACKTOP = sp;return 0;
  }
 }
 $17 = ___cxa_find_matching_catch_2()|0;
 $18 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($1|0));
 $19 = __THREW__; __THREW__ = 0;
 $20 = $19&1;
 if ($20) {
  $21 = ___cxa_find_matching_catch_3(0|0)|0;
  $22 = tempRet0;
  ___clang_call_terminate($21);
  // unreachable;
 } else {
  ___resumeException($17|0);
  // unreachable;
 }
 return (0)|0;
}
function __ZN9osgViewer14GraphicsWindow34bindPBufferToTextureImplementationEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
 $4 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($3,101761,71)|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($5)) + -12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($4) + ($7)|0);
 __ZNKSt3__28ios_base6getlocEv($2,$8);
 __THREW__ = 0;
 $9 = (invoke_iii(3255,($2|0),(215188|0))|0);
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if (!($11)) {
  $12 = HEAP32[$9>>2]|0;
  $13 = ((($12)) + 28|0);
  $14 = HEAP32[$13>>2]|0;
  __THREW__ = 0;
  $15 = (invoke_iii($14|0,($9|0),10)|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __ZNSt3__26localeD2Ev($2);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($4,$15)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($4)|0);
   STACKTOP = sp;return;
  }
 }
 $18 = ___cxa_find_matching_catch_2()|0;
 $19 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($2|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if ($21) {
  $22 = ___cxa_find_matching_catch_3(0|0)|0;
  $23 = tempRet0;
  ___clang_call_terminate($22);
  // unreachable;
 } else {
  ___resumeException($18|0);
  // unreachable;
 }
}
function __ZN9osgViewer14GraphicsWindow25swapBuffersImplementationEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $2 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
 $3 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($2,101699,61)|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($4)) + -12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($3) + ($6)|0);
 __ZNKSt3__28ios_base6getlocEv($1,$7);
 __THREW__ = 0;
 $8 = (invoke_iii(3255,($1|0),(215188|0))|0);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if (!($10)) {
  $11 = HEAP32[$8>>2]|0;
  $12 = ((($11)) + 28|0);
  $13 = HEAP32[$12>>2]|0;
  __THREW__ = 0;
  $14 = (invoke_iii($13|0,($8|0),10)|0);
  $15 = __THREW__; __THREW__ = 0;
  $16 = $15&1;
  if (!($16)) {
   __ZNSt3__26localeD2Ev($1);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($3,$14)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($3)|0);
   STACKTOP = sp;return;
  }
 }
 $17 = ___cxa_find_matching_catch_2()|0;
 $18 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($1|0));
 $19 = __THREW__; __THREW__ = 0;
 $20 = $19&1;
 if ($20) {
  $21 = ___cxa_find_matching_catch_3(0|0)|0;
  $22 = tempRet0;
  ___clang_call_terminate($21);
  // unreachable;
 } else {
  ___resumeException($17|0);
  // unreachable;
 }
}
function __ZN9osgViewer14GraphicsWindow11checkEventsEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 136|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 32|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($4)) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 (FUNCTION_TABLE_ii[$6 & 8191]($3)|0);
 $7 = ((($2)) + 52|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$3>>2]|0;
 $10 = ((($9)) + 12|0);
 $11 = HEAP32[$10>>2]|0;
 (FUNCTION_TABLE_ii[$11 & 8191]($3)|0);
 $12 = ($8|0)!=(0);
 return ($12|0);
}
function __ZN9osgViewer14GraphicsWindow32setWindowRectangleImplementationEiiii($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $5 = sp;
 $6 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
 $7 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($6,101629,69)|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($8)) + -12|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($7) + ($10)|0);
 __ZNKSt3__28ios_base6getlocEv($5,$11);
 __THREW__ = 0;
 $12 = (invoke_iii(3255,($5|0),(215188|0))|0);
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 if (!($14)) {
  $15 = HEAP32[$12>>2]|0;
  $16 = ((($15)) + 28|0);
  $17 = HEAP32[$16>>2]|0;
  __THREW__ = 0;
  $18 = (invoke_iii($17|0,($12|0),10)|0);
  $19 = __THREW__; __THREW__ = 0;
  $20 = $19&1;
  if (!($20)) {
   __ZNSt3__26localeD2Ev($5);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($7,$18)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($7)|0);
   STACKTOP = sp;return 0;
  }
 }
 $21 = ___cxa_find_matching_catch_2()|0;
 $22 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($5|0));
 $23 = __THREW__; __THREW__ = 0;
 $24 = $23&1;
 if ($24) {
  $25 = ___cxa_find_matching_catch_3(0|0)|0;
  $26 = tempRet0;
  ___clang_call_terminate($25);
  // unreachable;
 } else {
  ___resumeException($21|0);
  // unreachable;
 }
 return (0)|0;
}
function __ZN9osgViewer14GraphicsWindow18getWindowRectangleERiS1_S1_S1_($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = ((($0)) + 44|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  return;
 }
 $8 = ((($6)) + 32|0);
 $9 = HEAP32[$8>>2]|0;
 HEAP32[$1>>2] = $9;
 $10 = ((($6)) + 36|0);
 $11 = HEAP32[$10>>2]|0;
 HEAP32[$2>>2] = $11;
 $12 = ((($6)) + 40|0);
 $13 = HEAP32[$12>>2]|0;
 HEAP32[$3>>2] = $13;
 $14 = ((($6)) + 44|0);
 $15 = HEAP32[$14>>2]|0;
 HEAP32[$4>>2] = $15;
 return;
}
function __ZN9osgViewer14GraphicsWindow33setWindowDecorationImplementationEb($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
 $4 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($3,101558,70)|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($5)) + -12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($4) + ($7)|0);
 __ZNKSt3__28ios_base6getlocEv($2,$8);
 __THREW__ = 0;
 $9 = (invoke_iii(3255,($2|0),(215188|0))|0);
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if (!($11)) {
  $12 = HEAP32[$9>>2]|0;
  $13 = ((($12)) + 28|0);
  $14 = HEAP32[$13>>2]|0;
  __THREW__ = 0;
  $15 = (invoke_iii($14|0,($9|0),10)|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __ZNSt3__26localeD2Ev($2);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($4,$15)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($4)|0);
   STACKTOP = sp;return 0;
  }
 }
 $18 = ___cxa_find_matching_catch_2()|0;
 $19 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($2|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if ($21) {
  $22 = ___cxa_find_matching_catch_3(0|0)|0;
  $23 = tempRet0;
  ___clang_call_terminate($22);
  // unreachable;
 } else {
  ___resumeException($18|0);
  // unreachable;
 }
 return (0)|0;
}
function __ZNK9osgViewer14GraphicsWindow19getWindowDecorationEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 44|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  $7 = 0;
  return ($7|0);
 }
 $4 = ((($2)) + 72|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)!=(0);
 $7 = $6;
 return ($7|0);
}
function __ZN9osgViewer14GraphicsWindow9grabFocusEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $2 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
 $3 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($2,101511,46)|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($4)) + -12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($3) + ($6)|0);
 __ZNKSt3__28ios_base6getlocEv($1,$7);
 __THREW__ = 0;
 $8 = (invoke_iii(3255,($1|0),(215188|0))|0);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if (!($10)) {
  $11 = HEAP32[$8>>2]|0;
  $12 = ((($11)) + 28|0);
  $13 = HEAP32[$12>>2]|0;
  __THREW__ = 0;
  $14 = (invoke_iii($13|0,($8|0),10)|0);
  $15 = __THREW__; __THREW__ = 0;
  $16 = $15&1;
  if (!($16)) {
   __ZNSt3__26localeD2Ev($1);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($3,$14)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($3)|0);
   STACKTOP = sp;return;
  }
 }
 $17 = ___cxa_find_matching_catch_2()|0;
 $18 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($1|0));
 $19 = __THREW__; __THREW__ = 0;
 $20 = $19&1;
 if ($20) {
  $21 = ___cxa_find_matching_catch_3(0|0)|0;
  $22 = tempRet0;
  ___clang_call_terminate($21);
  // unreachable;
 } else {
  ___resumeException($17|0);
  // unreachable;
 }
}
function __ZN9osgViewer14GraphicsWindow26grabFocusIfPointerInWindowEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $2 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
 $3 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($2,101447,63)|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($4)) + -12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($3) + ($6)|0);
 __ZNKSt3__28ios_base6getlocEv($1,$7);
 __THREW__ = 0;
 $8 = (invoke_iii(3255,($1|0),(215188|0))|0);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if (!($10)) {
  $11 = HEAP32[$8>>2]|0;
  $12 = ((($11)) + 28|0);
  $13 = HEAP32[$12>>2]|0;
  __THREW__ = 0;
  $14 = (invoke_iii($13|0,($8|0),10)|0);
  $15 = __THREW__; __THREW__ = 0;
  $16 = $15&1;
  if (!($16)) {
   __ZNSt3__26localeD2Ev($1);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($3,$14)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($3)|0);
   STACKTOP = sp;return;
  }
 }
 $17 = ___cxa_find_matching_catch_2()|0;
 $18 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($1|0));
 $19 = __THREW__; __THREW__ = 0;
 $20 = $19&1;
 if ($20) {
  $21 = ___cxa_find_matching_catch_3(0|0)|0;
  $22 = tempRet0;
  ___clang_call_terminate($21);
  // unreachable;
 } else {
  ___resumeException($17|0);
  // unreachable;
 }
}
function __ZN9osgViewer14GraphicsWindow11raiseWindowEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $2 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
 $3 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($2,101398,48)|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($4)) + -12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($3) + ($6)|0);
 __ZNKSt3__28ios_base6getlocEv($1,$7);
 __THREW__ = 0;
 $8 = (invoke_iii(3255,($1|0),(215188|0))|0);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if (!($10)) {
  $11 = HEAP32[$8>>2]|0;
  $12 = ((($11)) + 28|0);
  $13 = HEAP32[$12>>2]|0;
  __THREW__ = 0;
  $14 = (invoke_iii($13|0,($8|0),10)|0);
  $15 = __THREW__; __THREW__ = 0;
  $16 = $15&1;
  if (!($16)) {
   __ZNSt3__26localeD2Ev($1);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($3,$14)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($3)|0);
   STACKTOP = sp;return;
  }
 }
 $17 = ___cxa_find_matching_catch_2()|0;
 $18 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($1|0));
 $19 = __THREW__; __THREW__ = 0;
 $20 = $19&1;
 if ($20) {
  $21 = ___cxa_find_matching_catch_3(0|0)|0;
  $22 = tempRet0;
  ___clang_call_terminate($21);
  // unreachable;
 } else {
  ___resumeException($17|0);
  // unreachable;
 }
}
function __ZN9osgViewer14GraphicsWindow13setWindowNameERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
 $4 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($3,101347,50)|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($5)) + -12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($4) + ($7)|0);
 __ZNKSt3__28ios_base6getlocEv($2,$8);
 __THREW__ = 0;
 $9 = (invoke_iii(3255,($2|0),(215188|0))|0);
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if (!($11)) {
  $12 = HEAP32[$9>>2]|0;
  $13 = ((($12)) + 28|0);
  $14 = HEAP32[$13>>2]|0;
  __THREW__ = 0;
  $15 = (invoke_iii($14|0,($9|0),10)|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __ZNSt3__26localeD2Ev($2);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($4,$15)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($4)|0);
   STACKTOP = sp;return;
  }
 }
 $18 = ___cxa_find_matching_catch_2()|0;
 $19 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($2|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if ($21) {
  $22 = ___cxa_find_matching_catch_3(0|0)|0;
  $23 = tempRet0;
  ___clang_call_terminate($22);
  // unreachable;
 } else {
  ___resumeException($18|0);
  // unreachable;
 }
}
function __ZN9osgViewer14GraphicsWindow13getWindowNameEv($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 44|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  ;HEAP32[$0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;
  return;
 } else {
  $5 = ((($3)) + 60|0);
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_($0,$5);
  return;
 }
}
function __ZN9osgViewer14GraphicsWindow9useCursorEb($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $not$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $3 = ((($2)) + 232|0);
 $4 = HEAP32[$3>>2]|0;
 $not$ = $1 ^ 1;
 $5 = $not$&1;
 FUNCTION_TABLE_vii[$4 & 8191]($0,$5);
 return;
}
function __ZN9osgViewer14GraphicsWindow9setCursorENS0_11MouseCursorE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
 $4 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($3,101300,46)|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($5)) + -12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($4) + ($7)|0);
 __ZNKSt3__28ios_base6getlocEv($2,$8);
 __THREW__ = 0;
 $9 = (invoke_iii(3255,($2|0),(215188|0))|0);
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if (!($11)) {
  $12 = HEAP32[$9>>2]|0;
  $13 = ((($12)) + 28|0);
  $14 = HEAP32[$13>>2]|0;
  __THREW__ = 0;
  $15 = (invoke_iii($14|0,($9|0),10)|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __ZNSt3__26localeD2Ev($2);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($4,$15)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($4)|0);
   STACKTOP = sp;return;
  }
 }
 $18 = ___cxa_find_matching_catch_2()|0;
 $19 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($2|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if ($21) {
  $22 = ___cxa_find_matching_catch_3(0|0)|0;
  $23 = tempRet0;
  ___clang_call_terminate($22);
  // unreachable;
 } else {
  ___resumeException($18|0);
  // unreachable;
 }
}
function __ZN9osgViewer14GraphicsWindow15setSyncToVBlankEb($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
 $4 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($3,101267,32)|0);
 $5 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEb($4,$1)|0);
 $6 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($5,101248,18)|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($7)) + -12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($6) + ($9)|0);
 __ZNKSt3__28ios_base6getlocEv($2,$10);
 __THREW__ = 0;
 $11 = (invoke_iii(3255,($2|0),(215188|0))|0);
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if (!($13)) {
  $14 = HEAP32[$11>>2]|0;
  $15 = ((($14)) + 28|0);
  $16 = HEAP32[$15>>2]|0;
  __THREW__ = 0;
  $17 = (invoke_iii($16|0,($11|0),10)|0);
  $18 = __THREW__; __THREW__ = 0;
  $19 = $18&1;
  if (!($19)) {
   __ZNSt3__26localeD2Ev($2);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($6,$17)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($6)|0);
   STACKTOP = sp;return;
  }
 }
 $20 = ___cxa_find_matching_catch_2()|0;
 $21 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($2|0));
 $22 = __THREW__; __THREW__ = 0;
 $23 = $22&1;
 if ($23) {
  $24 = ___cxa_find_matching_catch_3(0|0)|0;
  $25 = tempRet0;
  ___clang_call_terminate($24);
  // unreachable;
 } else {
  ___resumeException($20|0);
  // unreachable;
 }
}
function __ZN9osgViewer14GraphicsWindow12setSwapGroupEbjj($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $4 = sp;
 $5 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
 $6 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($5,101218,29)|0);
 $7 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEb($6,$1)|0);
 $8 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($7,159071,1)|0);
 $9 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($8,$2)|0);
 $10 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($9,159071,1)|0);
 $11 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($10,$3)|0);
 $12 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($11,101248,18)|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($13)) + -12|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($12) + ($15)|0);
 __ZNKSt3__28ios_base6getlocEv($4,$16);
 __THREW__ = 0;
 $17 = (invoke_iii(3255,($4|0),(215188|0))|0);
 $18 = __THREW__; __THREW__ = 0;
 $19 = $18&1;
 if (!($19)) {
  $20 = HEAP32[$17>>2]|0;
  $21 = ((($20)) + 28|0);
  $22 = HEAP32[$21>>2]|0;
  __THREW__ = 0;
  $23 = (invoke_iii($22|0,($17|0),10)|0);
  $24 = __THREW__; __THREW__ = 0;
  $25 = $24&1;
  if (!($25)) {
   __ZNSt3__26localeD2Ev($4);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($12,$23)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($12)|0);
   STACKTOP = sp;return;
  }
 }
 $26 = ___cxa_find_matching_catch_2()|0;
 $27 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($4|0));
 $28 = __THREW__; __THREW__ = 0;
 $29 = $28&1;
 if ($29) {
  $30 = ___cxa_find_matching_catch_3(0|0)|0;
  $31 = tempRet0;
  ___clang_call_terminate($30);
  // unreachable;
 } else {
  ___resumeException($26|0);
  // unreachable;
 }
}
function __ZN9osgViewer14GraphicsWindow13requestRedrawEv($0) {
 $0 = $0|0;
 var $$023$i$i = 0, $$023$i$i6 = 0, $$sink30$index = 0, $$sink30$index3 = 0, $$sroa$015$0$$sroa$015$0$$sroa$0$0$copyload$i24 = 0, $$sroa$015$0$$sroa$015$0$26 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp + 12|0;
 $2 = sp;
 HEAP32[$2>>2] = $2;
 $3 = ((($2)) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = ((($2)) + 8|0);
 HEAP32[$4>>2] = 0;
 __THREW__ = 0;
 invoke_vii(3264,($0|0),($2|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 L1: do {
  if ($6) {
   label = 16;
  } else {
   $7 = HEAP32[$4>>2]|0;
   $8 = ($7|0)==(0);
   L3: do {
    if ($8) {
     __THREW__ = 0;
     $9 = (invoke_ii(3265,4)|0);
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if ($11) {
      label = 16;
      break L1;
     }
     if ($9) {
      __THREW__ = 0;
      $12 = (invoke_ii(3266,4)|0);
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if ($14) {
       label = 16;
       break L1;
      }
      __THREW__ = 0;
      $15 = (invoke_iiii(3267,($12|0),(101162|0),55)|0);
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if ($17) {
       label = 16;
       break L1;
      }
      $18 = HEAP32[$15>>2]|0;
      $19 = ((($18)) + -12|0);
      $20 = HEAP32[$19>>2]|0;
      $21 = (($15) + ($20)|0);
      __THREW__ = 0;
      invoke_vii(3257,($1|0),($21|0));
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if ($23) {
       label = 16;
       break L1;
      }
      __THREW__ = 0;
      $24 = (invoke_iii(3255,($1|0),(215188|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       $27 = HEAP32[$24>>2]|0;
       $28 = ((($27)) + 28|0);
       $29 = HEAP32[$28>>2]|0;
       __THREW__ = 0;
       $30 = (invoke_iii($29|0,($24|0),10)|0);
       $31 = __THREW__; __THREW__ = 0;
       $32 = $31&1;
       if (!($32)) {
        __THREW__ = 0;
        invoke_vi(3263,($1|0));
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         label = 16;
         break L1;
        }
        __THREW__ = 0;
        (invoke_iii(3268,($15|0),($30|0))|0);
        $41 = __THREW__; __THREW__ = 0;
        $42 = $41&1;
        if ($42) {
         label = 16;
         break L1;
        }
        __THREW__ = 0;
        (invoke_ii(3269,($15|0))|0);
        $43 = __THREW__; __THREW__ = 0;
        $44 = $43&1;
        if ($44) {
         label = 16;
         break L1;
        } else {
         break;
        }
       }
      }
      $35 = ___cxa_find_matching_catch_2()|0;
      $36 = tempRet0;
      __THREW__ = 0;
      invoke_vi(3263,($1|0));
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       $39 = ___cxa_find_matching_catch_3(0|0)|0;
       $40 = tempRet0;
       ___clang_call_terminate($39);
       // unreachable;
      } else {
       $$sink30$index = $35;$$sink30$index3 = $36;
       break L1;
      }
     }
    } else {
     $47 = HEAP32[$3>>2]|0;
     $48 = $47;
     $49 = ($48|0)==($2|0);
     if (!($49)) {
      $$sroa$015$0$$sroa$015$0$$sroa$0$0$copyload$i24 = $48;$$sroa$015$0$$sroa$015$0$26 = $47;
      while(1) {
       $50 = $$sroa$015$0$$sroa$015$0$26;
       $51 = ((($50)) + 8|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = HEAP32[$52>>2]|0;
       $54 = ((($53)) + 56|0);
       $55 = HEAP32[$54>>2]|0;
       __THREW__ = 0;
       invoke_vi($55|0,($52|0));
       $56 = __THREW__; __THREW__ = 0;
       $57 = $56&1;
       if ($57) {
        break;
       }
       $58 = ((($$sroa$015$0$$sroa$015$0$$sroa$0$0$copyload$i24)) + 4|0);
       $59 = HEAP32[$58>>2]|0;
       $60 = $59;
       $61 = ($60|0)==($2|0);
       if ($61) {
        break L3;
       } else {
        $$sroa$015$0$$sroa$015$0$$sroa$0$0$copyload$i24 = $60;$$sroa$015$0$$sroa$015$0$26 = $59;
       }
      }
      $62 = ___cxa_find_matching_catch_2()|0;
      $63 = tempRet0;
      $$sink30$index = $62;$$sink30$index3 = $63;
      break L1;
     }
    }
   } while(0);
   $64 = HEAP32[$4>>2]|0;
   $65 = ($64|0)==(0);
   if ($65) {
    STACKTOP = sp;return;
   }
   $66 = HEAP32[$3>>2]|0;
   $67 = HEAP32[$2>>2]|0;
   $68 = ((($67)) + 4|0);
   $69 = HEAP32[$68>>2]|0;
   $70 = HEAP32[$66>>2]|0;
   $71 = ((($70)) + 4|0);
   HEAP32[$71>>2] = $69;
   $72 = HEAP32[$68>>2]|0;
   HEAP32[$72>>2] = $70;
   HEAP32[$4>>2] = 0;
   $73 = ($66|0)==($2|0);
   if ($73) {
    STACKTOP = sp;return;
   } else {
    $$023$i$i6 = $66;
   }
   while(1) {
    $74 = ((($$023$i$i6)) + 4|0);
    $75 = HEAP32[$74>>2]|0;
    __ZdlPv($$023$i$i6);
    $76 = ($75|0)==($2|0);
    if ($76) {
     break;
    } else {
     $$023$i$i6 = $75;
    }
   }
   STACKTOP = sp;return;
  }
 } while(0);
 if ((label|0) == 16) {
  $45 = ___cxa_find_matching_catch_2()|0;
  $46 = tempRet0;
  $$sink30$index = $45;$$sink30$index3 = $46;
 }
 $77 = HEAP32[$4>>2]|0;
 $78 = ($77|0)==(0);
 if ($78) {
  ___resumeException($$sink30$index|0);
  // unreachable;
 }
 $79 = HEAP32[$3>>2]|0;
 $80 = HEAP32[$2>>2]|0;
 $81 = ((($80)) + 4|0);
 $82 = HEAP32[$81>>2]|0;
 $83 = HEAP32[$79>>2]|0;
 $84 = ((($83)) + 4|0);
 HEAP32[$84>>2] = $82;
 $85 = HEAP32[$81>>2]|0;
 HEAP32[$85>>2] = $83;
 HEAP32[$4>>2] = 0;
 $86 = ($79|0)==($2|0);
 if ($86) {
  ___resumeException($$sink30$index|0);
  // unreachable;
 } else {
  $$023$i$i = $79;
 }
 while(1) {
  $87 = ((($$023$i$i)) + 4|0);
  $88 = HEAP32[$87>>2]|0;
  __ZdlPv($$023$i$i);
  $89 = ($88|0)==($2|0);
  if ($89) {
   break;
  } else {
   $$023$i$i = $88;
  }
 }
 ___resumeException($$sink30$index|0);
 // unreachable;
}
function __ZN9osgViewer14GraphicsWindow23requestContinuousUpdateEb($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN9osgViewer14GraphicsWindow18requestWarpPointerEff($0,$1,$2) {
 $0 = $0|0;
 $1 = +$1;
 $2 = +$2;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZThn132_N9osgViewer14GraphicsWindowD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -132|0);
 HEAP32[$1>>2] = (34776);
 $2 = ((($1)) + 132|0);
 HEAP32[$2>>2] = (35040);
 $3 = ((($1)) + 136|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  HEAP32[$3>>2] = 0;
  __ZN3osg15GraphicsContextD2Ev($1);
  return;
 }
 $6 = ((($4)) + 8|0);
 $7 = HEAP32[$6>>2]|0;HEAP32[$6>>2] = (($7-1)|0);
 $8 = ($7|0)==(1);
 if (!($8)) {
  HEAP32[$3>>2] = 0;
  __ZN3osg15GraphicsContextD2Ev($1);
  return;
 }
 __THREW__ = 0;
 invoke_viii(3262,($4|0),1,1);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if (!($10)) {
  HEAP32[$3>>2] = 0;
  __ZN3osg15GraphicsContextD2Ev($1);
  return;
 }
 $11 = ___cxa_find_matching_catch_2()|0;
 $12 = tempRet0;
 __THREW__ = 0;
 invoke_vi(1871,($1|0));
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 if ($14) {
  $15 = ___cxa_find_matching_catch_3(0|0)|0;
  $16 = tempRet0;
  ___clang_call_terminate($15);
  // unreachable;
 } else {
  ___resumeException($11|0);
  // unreachable;
 }
}
function __ZThn132_N9osgViewer14GraphicsWindowD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $eh$lpad$body$i$index2Z2D = 0, $eh$lpad$body$i$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -132|0);
 HEAP32[$1>>2] = (34776);
 $2 = ((($1)) + 132|0);
 HEAP32[$2>>2] = (35040);
 $3 = ((($1)) + 136|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if (!($5)) {
  $6 = ((($4)) + 8|0);
  $7 = HEAP32[$6>>2]|0;HEAP32[$6>>2] = (($7-1)|0);
  $8 = ($7|0)==(1);
  if ($8) {
   __THREW__ = 0;
   invoke_viii(3262,($4|0),1,1);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if ($10) {
    $13 = ___cxa_find_matching_catch_2()|0;
    $14 = tempRet0;
    __THREW__ = 0;
    invoke_vi(1871,($1|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     $17 = ___cxa_find_matching_catch_3(0|0)|0;
     $18 = tempRet0;
     ___clang_call_terminate($17);
     // unreachable;
    } else {
     $eh$lpad$body$i$index2Z2D = $14;$eh$lpad$body$i$indexZ2D = $13;
     __ZdlPv($1);
     ___resumeException($eh$lpad$body$i$indexZ2D|0);
     // unreachable;
    }
   }
  }
 }
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vi(1871,($1|0));
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if (!($12)) {
  __ZdlPv($1);
  return;
 }
 $19 = ___cxa_find_matching_catch_2()|0;
 $20 = tempRet0;
 $eh$lpad$body$i$index2Z2D = $20;$eh$lpad$body$i$indexZ2D = $19;
 __ZdlPv($1);
 ___resumeException($eh$lpad$body$i$indexZ2D|0);
 // unreachable;
}
function __ZN5osgGA16GUIActionAdapter6asViewEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZThn132_N9osgViewer14GraphicsWindow13requestRedrawEv($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -132|0);
 __ZN9osgViewer14GraphicsWindow13requestRedrawEv($1);
 return;
}
function __ZThn132_N9osgViewer14GraphicsWindow23requestContinuousUpdateEb($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZThn132_N9osgViewer14GraphicsWindow18requestWarpPointerEff($0,$1,$2) {
 $0 = $0|0;
 $1 = +$1;
 $2 = +$2;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN5osgGA16GUIActionAdapter20computeIntersectionsERKNS_15GUIEventAdapterERNSt3__28multisetIN7osgUtil22LineSegmentIntersector12IntersectionENS4_4lessIS8_EENS4_9allocatorIS8_EEEEj($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function __ZN5osgGA16GUIActionAdapter20computeIntersectionsERKNS_15GUIEventAdapterERKNSt3__26vectorIPN3osg4NodeENS4_9allocatorIS8_EEEERNS4_8multisetIN7osgUtil22LineSegmentIntersector12IntersectionENS4_4lessISH_EENS9_ISH_EEEEj($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function __ZN9osgViewer14GraphicsWindow8getViewsERNSt3__24listIPNS_4ViewENS1_9allocatorIS4_EEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$023$i$i = 0, $$byval_copy = 0, $$byval_copy1 = 0, $$lcssa24$i$i = 0, $$sroa$012$0$be$i$i = 0, $$sroa$012$029$i$i = 0, $$sroa$015$0$$sroa$015$0$$sroa$0$0$copyload$i22 = 0, $$sroa$015$0$$sroa$015$0$1624 = 0, $$sroa$04$0$lcssa$i$i = 0, $$sroa$04$025$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $$byval_copy1 = sp + 16|0;
 $$byval_copy = sp + 12|0;
 $2 = sp + 8|0;
 $3 = sp + 4|0;
 $4 = sp;
 $5 = ((($1)) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if (!($7)) {
  $8 = ((($1)) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = HEAP32[$1>>2]|0;
  $11 = ((($10)) + 4|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = HEAP32[$9>>2]|0;
  $14 = ((($13)) + 4|0);
  HEAP32[$14>>2] = $12;
  $15 = HEAP32[$11>>2]|0;
  HEAP32[$15>>2] = $13;
  HEAP32[$5>>2] = 0;
  $16 = ($9|0)==($1|0);
  if (!($16)) {
   $$023$i$i = $9;
   while(1) {
    $17 = ((($$023$i$i)) + 4|0);
    $18 = HEAP32[$17>>2]|0;
    __ZdlPv($$023$i$i);
    $19 = ($18|0)==($1|0);
    if ($19) {
     break;
    } else {
     $$023$i$i = $18;
    }
   }
  }
 }
 $20 = ((($0)) + 36|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ((($0)) + 32|0);
 $23 = $21;
 $24 = ($23|0)==($22|0);
 if (!($24)) {
  $$sroa$015$0$$sroa$015$0$$sroa$0$0$copyload$i22 = $23;$$sroa$015$0$$sroa$015$0$1624 = $21;
  while(1) {
   $63 = $$sroa$015$0$$sroa$015$0$1624;
   $64 = ((($63)) + 8|0);
   $65 = HEAP32[$64>>2]|0;
   $66 = ((($65)) + 220|0);
   $67 = HEAP32[$66>>2]|0;
   $68 = ($67|0)==(0|0);
   if (!($68)) {
    $69 = (___dynamic_cast($67,27072,3928,0)|0);
    $70 = ($69|0)==(0|0);
    if (!($70)) {
     $71 = $69;
     $72 = (__Znwj(12)|0);
     $73 = ((($72)) + 8|0);
     HEAP32[$73>>2] = $71;
     $74 = ((($72)) + 4|0);
     HEAP32[$74>>2] = $1;
     $75 = HEAP32[$1>>2]|0;
     HEAP32[$72>>2] = $75;
     $76 = ((($75)) + 4|0);
     HEAP32[$76>>2] = $72;
     HEAP32[$1>>2] = $72;
     $77 = HEAP32[$5>>2]|0;
     $78 = (($77) + 1)|0;
     HEAP32[$5>>2] = $78;
    }
   }
   $79 = ((($$sroa$015$0$$sroa$015$0$$sroa$0$0$copyload$i22)) + 4|0);
   $80 = HEAP32[$79>>2]|0;
   $81 = $80;
   $82 = ($81|0)==($22|0);
   if ($82) {
    break;
   } else {
    $$sroa$015$0$$sroa$015$0$$sroa$0$0$copyload$i22 = $81;$$sroa$015$0$$sroa$015$0$1624 = $80;
   }
  }
 }
 $25 = ((($1)) + 4|0);
 $26 = HEAP32[$25>>2]|0;
 HEAP32[$2>>2] = $26;
 HEAP32[$3>>2] = $1;
 $27 = HEAP32[$5>>2]|0;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$2>>2]|0;
 ;HEAP32[$$byval_copy1>>2]=HEAP32[$3>>2]|0;
 (__ZNSt3__24listIPN9osgViewer4ViewENS_9allocatorIS3_EEE6__sortINS_6__lessIS3_S3_EEEENS_15__list_iteratorIS3_PvEESC_SC_jRT_($$byval_copy,$$byval_copy1,$27,$4)|0);
 $28 = HEAP32[$25>>2]|0;
 $29 = $28;
 $30 = ($29|0)==($1|0);
 if ($30) {
  STACKTOP = sp;return;
 } else {
  $$sroa$012$029$i$i = $28;$32 = $29;
 }
 while(1) {
  $31 = ((($32)) + 4|0);
  $33 = HEAP32[$31>>2]|0;
  $34 = $33;
  $35 = ($34|0)==($1|0);
  L19: do {
   if ($35) {
    $$lcssa24$i$i = $1;$$sroa$04$0$lcssa$i$i = $33;
   } else {
    $36 = $$sroa$012$029$i$i;
    $37 = ((($36)) + 8|0);
    $38 = HEAP32[$37>>2]|0;
    $$sroa$04$025$i$i = $33;$44 = $34;
    while(1) {
     $39 = $$sroa$04$025$i$i;
     $40 = ((($39)) + 8|0);
     $41 = HEAP32[$40>>2]|0;
     $42 = ($38|0)==($41|0);
     if (!($42)) {
      $$lcssa24$i$i = $44;$$sroa$04$0$lcssa$i$i = $$sroa$04$025$i$i;
      break L19;
     }
     $43 = ((($44)) + 4|0);
     $45 = HEAP32[$43>>2]|0;
     $46 = $45;
     $47 = ($46|0)==($1|0);
     if ($47) {
      $$lcssa24$i$i = $1;$$sroa$04$0$lcssa$i$i = $45;
      break;
     } else {
      $$sroa$04$025$i$i = $45;$44 = $46;
     }
    }
   }
  } while(0);
  $48 = ($34|0)==($$lcssa24$i$i|0);
  if ($48) {
   $$sroa$012$0$be$i$i = $33;
  } else {
   $51 = HEAP32[$$lcssa24$i$i>>2]|0;
   $52 = ((($51)) + 4|0);
   $53 = HEAP32[$52>>2]|0;
   $54 = HEAP32[$34>>2]|0;
   $55 = ((($54)) + 4|0);
   HEAP32[$55>>2] = $53;
   $56 = HEAP32[$52>>2]|0;
   HEAP32[$56>>2] = $54;
   $58 = $34;
   while(1) {
    $57 = ((($58)) + 4|0);
    $59 = HEAP32[$57>>2]|0;
    $60 = HEAP32[$5>>2]|0;
    $61 = (($60) + -1)|0;
    HEAP32[$5>>2] = $61;
    __ZdlPv($58);
    $62 = ($59|0)==($$lcssa24$i$i|0);
    if ($62) {
     $$sroa$012$0$be$i$i = $$sroa$04$0$lcssa$i$i;
     break;
    } else {
     $58 = $59;
    }
   }
  }
  $49 = $$sroa$012$0$be$i$i;
  $50 = ($49|0)==($1|0);
  if ($50) {
   break;
  } else {
   $$sroa$012$029$i$i = $$sroa$012$0$be$i$i;$32 = $49;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__24listIPN9osgViewer4ViewENS_9allocatorIS3_EEE6__sortINS_6__lessIS3_S3_EEEENS_15__list_iteratorIS3_PvEESC_SC_jRT_($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$08$i$i$i74 = 0, $$byval_copy = 0, $$byval_copy1 = 0, $$byval_copy2 = 0, $$byval_copy3 = 0, $$cast = 0, $$cast114 = 0, $$cast114129 = 0, $$cast114129137 = 0, $$in = 0, $$in158 = 0, $$lcssa123 = 0, $$lcssa126 = 0, $$sink$ph = 0, $$sroa$0$0$copyload$i = 0, $$sroa$0101$0$ph = 0, $$sroa$0101$0$ph116138 = 0, $$sroa$024$0$ph = 0, $$sroa$050$0 = 0, $$sroa$050$0$copyload = 0;
 var $$sroa$050$0$copyload52 = 0, $$sroa$078$0$$sroa$0101$0 = 0, $$sroa$078$0$lcssa = 0, $$sroa$078$0132 = 0, $$sroa$087$0$lcssa = 0, $$sroa$087$0141 = 0, $$sroa$092$0$ph117139 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $$byval_copy3 = sp + 28|0;
 $$byval_copy2 = sp + 24|0;
 $$byval_copy1 = sp + 20|0;
 $$byval_copy = sp + 16|0;
 $4 = sp + 12|0;
 $5 = sp + 8|0;
 $6 = sp + 4|0;
 $7 = sp;
 switch ($2|0) {
 case 1: case 0:  {
  $$sroa$050$0$copyload = HEAP32[$0>>2]|0;
  $$sroa$050$0 = $$sroa$050$0$copyload;
  STACKTOP = sp;return ($$sroa$050$0|0);
  break;
 }
 case 2:  {
  $8 = HEAP32[$1>>2]|0;
  $9 = HEAP32[$8>>2]|0;
  HEAP32[$1>>2] = $9;
  $$cast = $9;
  $10 = ((($$cast)) + 8|0);
  $11 = HEAP32[$0>>2]|0;
  $12 = ((($11)) + 8|0);
  $13 = HEAP32[$10>>2]|0;
  $14 = HEAP32[$12>>2]|0;
  $15 = ($13>>>0)<($14>>>0);
  $16 = $9;
  if (!($15)) {
   $$sroa$050$0 = $11;
   STACKTOP = sp;return ($$sroa$050$0|0);
  }
  $17 = ((($16)) + 4|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = HEAP32[$16>>2]|0;
  $20 = ((($19)) + 4|0);
  HEAP32[$20>>2] = $18;
  $21 = HEAP32[$17>>2]|0;
  HEAP32[$21>>2] = $19;
  $22 = HEAP32[$11>>2]|0;
  $23 = ((($22)) + 4|0);
  HEAP32[$23>>2] = $16;
  HEAP32[$16>>2] = $22;
  HEAP32[$11>>2] = $16;
  HEAP32[$17>>2] = $11;
  $$sroa$050$0$copyload52 = HEAP32[$1>>2]|0;
  $$sroa$050$0 = $$sroa$050$0$copyload52;
  STACKTOP = sp;return ($$sroa$050$0|0);
  break;
 }
 default: {
  $24 = $2 >>> 1;
  $25 = HEAP32[$0>>2]|0;
  $26 = ($24|0)==(0);
  $27 = $25;
  if ($26) {
   $$sroa$0$0$copyload$i = $25;
  } else {
   $$08$i$i$i74 = $24;$29 = $25;
   while(1) {
    $28 = ((($29)) + 4|0);
    $30 = HEAP32[$28>>2]|0;
    $31 = (($$08$i$i$i74) + -1)|0;
    $32 = ($$08$i$i$i74|0)>(1);
    if ($32) {
     $$08$i$i$i74 = $31;$29 = $30;
    } else {
     $$sroa$0$0$copyload$i = $30;
     break;
    }
   }
  }
  $33 = $$sroa$0$0$copyload$i;
  HEAP32[$4>>2] = $27;
  HEAP32[$5>>2] = $33;
  ;HEAP32[$$byval_copy>>2]=HEAP32[$4>>2]|0;
  ;HEAP32[$$byval_copy1>>2]=HEAP32[$5>>2]|0;
  $34 = (__ZNSt3__24listIPN9osgViewer4ViewENS_9allocatorIS3_EEE6__sortINS_6__lessIS3_S3_EEEENS_15__list_iteratorIS3_PvEESC_SC_jRT_($$byval_copy,$$byval_copy1,$24,$3)|0);
  HEAP32[$0>>2] = $34;
  HEAP32[$6>>2] = $33;
  $35 = HEAP32[$1>>2]|0;
  HEAP32[$7>>2] = $35;
  $36 = (($2) - ($24))|0;
  ;HEAP32[$$byval_copy2>>2]=HEAP32[$6>>2]|0;
  ;HEAP32[$$byval_copy3>>2]=HEAP32[$7>>2]|0;
  $37 = (__ZNSt3__24listIPN9osgViewer4ViewENS_9allocatorIS3_EEE6__sortINS_6__lessIS3_S3_EEEENS_15__list_iteratorIS3_PvEESC_SC_jRT_($$byval_copy2,$$byval_copy3,$36,$3)|0);
  $38 = ((($37)) + 8|0);
  $39 = ((($34)) + 8|0);
  $40 = HEAP32[$38>>2]|0;
  $41 = HEAP32[$39>>2]|0;
  $42 = ($40>>>0)<($41>>>0);
  $43 = $35;
  if ($42) {
   $44 = ((($37)) + 4|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = $45;
   $47 = ($46|0)==($43|0);
   L9: do {
    if ($47) {
     $$lcssa126 = $43;$$sroa$087$0$lcssa = $45;
    } else {
     $$sroa$087$0141 = $45;$53 = $46;
     while(1) {
      $48 = $$sroa$087$0141;
      $49 = ((($48)) + 8|0);
      $50 = HEAP32[$49>>2]|0;
      $51 = ($50>>>0)<($41>>>0);
      if (!($51)) {
       $$lcssa126 = $53;$$sroa$087$0$lcssa = $$sroa$087$0141;
       break L9;
      }
      $52 = ((($53)) + 4|0);
      $54 = HEAP32[$52>>2]|0;
      $55 = $54;
      $56 = ($55|0)==($43|0);
      if ($56) {
       $$lcssa126 = $43;$$sroa$087$0$lcssa = $54;
       break;
      } else {
       $$sroa$087$0141 = $54;$53 = $55;
      }
     }
    }
   } while(0);
   $57 = HEAP32[$$lcssa126>>2]|0;
   $58 = ((($57)) + 4|0);
   $59 = HEAP32[$58>>2]|0;
   $60 = HEAP32[$37>>2]|0;
   $61 = ((($60)) + 4|0);
   HEAP32[$61>>2] = $59;
   $62 = HEAP32[$58>>2]|0;
   HEAP32[$62>>2] = $60;
   $63 = ((($34)) + 4|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = HEAP32[$34>>2]|0;
   $66 = ((($65)) + 4|0);
   HEAP32[$66>>2] = $37;
   HEAP32[$37>>2] = $65;
   HEAP32[$34>>2] = $57;
   HEAP32[$58>>2] = $34;
   $$sink$ph = $64;$$sroa$0101$0$ph = $$sroa$087$0$lcssa;$$sroa$024$0$ph = $37;
  } else {
   $67 = $37;
   $68 = ((($34)) + 4|0);
   $69 = HEAP32[$68>>2]|0;
   $$sink$ph = $69;$$sroa$0101$0$ph = $67;$$sroa$024$0$ph = $34;
  }
  HEAP32[$0>>2] = $$sink$ph;
  $$cast114129137 = $$sink$ph;
  $70 = $$sroa$0101$0$ph;
  $71 = ($$cast114129137|0)==($70|0);
  if ($71) {
   $$sroa$050$0 = $$sroa$024$0$ph;
   STACKTOP = sp;return ($$sroa$050$0|0);
  } else {
   $$in = $$sink$ph;$$sroa$0101$0$ph116138 = $$sroa$0101$0$ph;$$sroa$092$0$ph117139 = $$sroa$0101$0$ph;$114 = $$cast114129137;$97 = $70;
  }
  L18: while(1) {
   $72 = $$sroa$092$0$ph117139;
   $73 = $$sroa$092$0$ph117139;
   $74 = ((($73)) + 8|0);
   $75 = ($72|0)==($43|0);
   $$in158 = $$in;$105 = $114;
   while(1) {
    $76 = $$in158;
    if ($75) {
     $$sroa$050$0 = $$sroa$024$0$ph;
     label = 23;
     break L18;
    }
    $77 = ((($76)) + 8|0);
    $78 = HEAP32[$74>>2]|0;
    $79 = HEAP32[$77>>2]|0;
    $80 = ($78>>>0)<($79>>>0);
    if ($80) {
     break;
    }
    $111 = ((($105)) + 4|0);
    $112 = HEAP32[$111>>2]|0;
    HEAP32[$0>>2] = $112;
    $$cast114 = $112;
    $113 = ($$cast114|0)==($97|0);
    if ($113) {
     $$sroa$050$0 = $$sroa$024$0$ph;
     label = 23;
     break L18;
    } else {
     $$in158 = $112;$105 = $$cast114;
    }
   }
   $81 = ((($72)) + 4|0);
   $82 = HEAP32[$81>>2]|0;
   $83 = $82;
   $84 = ($83|0)==($43|0);
   L25: do {
    if ($84) {
     $$lcssa123 = $43;$$sroa$078$0$lcssa = $82;
    } else {
     $85 = ((($76)) + 8|0);
     $86 = HEAP32[$85>>2]|0;
     $$sroa$078$0132 = $82;$92 = $83;
     while(1) {
      $87 = $$sroa$078$0132;
      $88 = ((($87)) + 8|0);
      $89 = HEAP32[$88>>2]|0;
      $90 = ($89>>>0)<($86>>>0);
      if (!($90)) {
       $$lcssa123 = $92;$$sroa$078$0$lcssa = $$sroa$078$0132;
       break L25;
      }
      $91 = ((($92)) + 4|0);
      $93 = HEAP32[$91>>2]|0;
      $94 = $93;
      $95 = ($94|0)==($43|0);
      if ($95) {
       $$lcssa123 = $43;$$sroa$078$0$lcssa = $93;
       break;
      } else {
       $$sroa$078$0132 = $93;$92 = $94;
      }
     }
    }
   } while(0);
   $96 = HEAP32[$$lcssa123>>2]|0;
   $98 = ($97|0)==($72|0);
   $99 = ((($96)) + 4|0);
   $100 = HEAP32[$99>>2]|0;
   $101 = HEAP32[$72>>2]|0;
   $102 = ((($101)) + 4|0);
   HEAP32[$102>>2] = $100;
   $103 = HEAP32[$99>>2]|0;
   HEAP32[$103>>2] = $101;
   $104 = ((($105)) + 4|0);
   $106 = HEAP32[$104>>2]|0;
   $$sroa$078$0$$sroa$0101$0 = $98 ? $$sroa$078$0$lcssa : $$sroa$0101$0$ph116138;
   $107 = HEAP32[$105>>2]|0;
   $108 = ((($107)) + 4|0);
   HEAP32[$108>>2] = $72;
   HEAP32[$72>>2] = $107;
   HEAP32[$105>>2] = $96;
   HEAP32[$99>>2] = $105;
   HEAP32[$0>>2] = $106;
   $$cast114129 = $106;
   $109 = $$sroa$078$0$$sroa$0101$0;
   $110 = ($$cast114129|0)==($109|0);
   if ($110) {
    $$sroa$050$0 = $$sroa$024$0$ph;
    label = 23;
    break;
   } else {
    $$in = $106;$$sroa$0101$0$ph116138 = $$sroa$078$0$$sroa$0101$0;$$sroa$092$0$ph117139 = $$sroa$078$0$lcssa;$114 = $$cast114129;$97 = $109;
   }
  }
  if ((label|0) == 23) {
   STACKTOP = sp;return ($$sroa$050$0|0);
  }
 }
 }
 return (0)|0;
}
function __ZNK9osgViewer4View9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(168)|0);
 __THREW__ = 0;
 invoke_vi(3270,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $8 = ___cxa_find_matching_catch_2()|0;
  $9 = tempRet0;
  __ZdlPv($1);
  ___resumeException($8|0);
  // unreachable;
 } else {
  $4 = HEAP32[$1>>2]|0;
  $5 = ((($4)) + -12|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($1) + ($6)|0);
  return ($7|0);
 }
 return (0)|0;
}
function __ZNK9osgViewer4View5cloneERKN3osg6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(168)|0);
 __THREW__ = 0;
 invoke_viii(3271,($2|0),($0|0),($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $9 = ___cxa_find_matching_catch_2()|0;
  $10 = tempRet0;
  __ZdlPv($2);
  ___resumeException($9|0);
  // unreachable;
 } else {
  $5 = HEAP32[$2>>2]|0;
  $6 = ((($5)) + -12|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($2) + ($7)|0);
  return ($8|0);
 }
 return (0)|0;
}
function __ZNK9osgViewer4View12isSameKindAsEPKN3osg6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,3928,-1)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK9osgViewer4View11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (107921|0);
}
function __ZNK9osgViewer4View9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (102314|0);
}
function __ZN9osgViewer4View4takeERN3osg4ViewE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$023$i$i = 0, $$byval_copy = 0, $$byval_copy1 = 0, $$byval_copy2 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $$byval_copy2 = sp + 20|0;
 $$byval_copy1 = sp + 16|0;
 $$byval_copy = sp + 12|0;
 $2 = sp + 8|0;
 $3 = sp + 4|0;
 $4 = sp;
 __ZN3osg4View4takeERS0_($0,$1);
 $5 = (___dynamic_cast($1,27072,3928,0)|0);
 $6 = ($5|0)==(0|0);
 if ($6) {
  __ZN9osgViewer4View37computeActiveCoordinateSystemNodePathEv($0);
  __ZN9osgViewer4View24assignSceneDataToCamerasEv($0);
  STACKTOP = sp;return;
 }
 $7 = ((($5)) + 48|0);
 $8 = $7;
 $9 = $8;
 $10 = HEAP32[$9>>2]|0;
 $11 = (($8) + 4)|0;
 $12 = $11;
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($0)) + 48|0);
 $15 = $14;
 $16 = $15;
 HEAP32[$16>>2] = $10;
 $17 = (($15) + 4)|0;
 $18 = $17;
 HEAP32[$18>>2] = $13;
 $19 = ((($5)) + 32|0);
 $20 = ((($0)) + 32|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = HEAP32[$19>>2]|0;
 $23 = ($21|0)==($22|0);
 if (!($23)) {
  HEAP32[$20>>2] = $22;
  $24 = ($22|0)==(0|0);
  if (!($24)) {
   $25 = ((($22)) + 8|0);
   $26 = HEAP32[$25>>2]|0;HEAP32[$25>>2] = (($26+1)|0);
  }
  $27 = ($21|0)==(0|0);
  if (!($27)) {
   $28 = ((($21)) + 8|0);
   $29 = HEAP32[$28>>2]|0;HEAP32[$28>>2] = (($29-1)|0);
   $30 = ($29|0)==(1);
   if ($30) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($21,1,1);
   }
  }
 }
 $31 = ((($5)) + 68|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = ($32|0)==(0|0);
 if (!($33)) {
  $34 = (__ZN9osgViewer5Scene12getSceneDataEv($32)|0);
  $35 = ($34|0)==(0|0);
  if (!($35)) {
   $36 = ((($0)) + 68|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = HEAP32[$31>>2]|0;
   $39 = ($37|0)==($38|0);
   if (!($39)) {
    HEAP32[$36>>2] = $38;
    $40 = ($38|0)==(0|0);
    if (!($40)) {
     $41 = ((($38)) + 8|0);
     $42 = HEAP32[$41>>2]|0;HEAP32[$41>>2] = (($42+1)|0);
    }
    $43 = ($37|0)==(0|0);
    if (!($43)) {
     $44 = ((($37)) + 8|0);
     $45 = HEAP32[$44>>2]|0;HEAP32[$44>>2] = (($45-1)|0);
     $46 = ($45|0)==(1);
     if ($46) {
      __ZNK3osg10Referenced24signalObserversAndDeleteEbb($37,1,1);
     }
    }
   }
  }
 }
 $47 = ((($5)) + 76|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = ($48|0)==(0|0);
 if (!($49)) {
  $50 = ((($0)) + 76|0);
  $51 = HEAP32[$50>>2]|0;
  $52 = ($51|0)==($48|0);
  if (!($52)) {
   HEAP32[$50>>2] = $48;
   $53 = HEAP32[$48>>2]|0;
   $54 = ((($53)) + -16|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = (($48) + ($55)|0);
   $57 = ((($56)) + 8|0);
   $58 = HEAP32[$57>>2]|0;HEAP32[$57>>2] = (($58+1)|0);
   $59 = ($51|0)==(0|0);
   if (!($59)) {
    $60 = HEAP32[$51>>2]|0;
    $61 = ((($60)) + -16|0);
    $62 = HEAP32[$61>>2]|0;
    $63 = (($51) + ($62)|0);
    $64 = ((($63)) + 8|0);
    $65 = HEAP32[$64>>2]|0;HEAP32[$64>>2] = (($65-1)|0);
    $66 = ($65|0)==(1);
    if ($66) {
     __ZNK3osg10Referenced24signalObserversAndDeleteEbb($63,1,1);
    }
   }
  }
 }
 $67 = ((($0)) + 80|0);
 $68 = $67;
 HEAP32[$2>>2] = $68;
 $69 = ((($5)) + 80|0);
 $70 = ((($5)) + 84|0);
 $71 = HEAP32[$70>>2]|0;
 HEAP32[$3>>2] = $71;
 HEAP32[$4>>2] = $69;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$2>>2]|0;
 ;HEAP32[$$byval_copy1>>2]=HEAP32[$3>>2]|0;
 ;HEAP32[$$byval_copy2>>2]=HEAP32[$4>>2]|0;
 (__ZNSt3__24listIN3osg7ref_ptrIN5osgGA12EventHandlerEEENS_9allocatorIS5_EEE6insertINS_15__list_iteratorIS5_PvEEEESC_NS_21__list_const_iteratorIS5_SB_EET_SF_PNS_9enable_ifIXsr19__is_input_iteratorISF_EE5valueEvE4typeE($67,$$byval_copy,$$byval_copy1,$$byval_copy2,0)|0);
 $72 = ((($5)) + 92|0);
 $73 = ((($0)) + 92|0);
 (__ZN3osg16ObserverNodePathaSERKS0_($73,$72)|0);
 $74 = ((($5)) + 116|0);
 $75 = ((($0)) + 116|0);
 $76 = HEAP32[$75>>2]|0;
 $77 = HEAP32[$74>>2]|0;
 $78 = ($76|0)==($77|0);
 if (!($78)) {
  HEAP32[$75>>2] = $77;
  $79 = ($77|0)==(0|0);
  if (!($79)) {
   $80 = ((($77)) + 8|0);
   $81 = HEAP32[$80>>2]|0;HEAP32[$80>>2] = (($81+1)|0);
  }
  $82 = ($76|0)==(0|0);
  if (!($82)) {
   $83 = ((($76)) + 8|0);
   $84 = HEAP32[$83>>2]|0;HEAP32[$83>>2] = (($84-1)|0);
   $85 = ($84|0)==(1);
   if ($85) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($76,1,1);
   }
  }
 }
 $86 = ((($5)) + 120|0);
 $87 = HEAP32[$86>>2]|0;
 $88 = ((($0)) + 120|0);
 HEAP32[$88>>2] = $87;
 $89 = ((($5)) + 124|0);
 $90 = HEAP32[$89>>2]|0;
 $91 = ((($0)) + 124|0);
 HEAP32[$91>>2] = $90;
 $92 = HEAP32[$19>>2]|0;
 $93 = ($92|0)==(0|0);
 if (!($93)) {
  HEAP32[$19>>2] = 0;
  $94 = ((($92)) + 8|0);
  $95 = HEAP32[$94>>2]|0;HEAP32[$94>>2] = (($95-1)|0);
  $96 = ($95|0)==(1);
  if ($96) {
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($92,1,1);
  }
 }
 $97 = HEAP32[$31>>2]|0;
 $98 = ($97|0)==(0|0);
 if (!($98)) {
  HEAP32[$31>>2] = 0;
  $99 = ((($97)) + 8|0);
  $100 = HEAP32[$99>>2]|0;HEAP32[$99>>2] = (($100-1)|0);
  $101 = ($100|0)==(1);
  if ($101) {
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($97,1,1);
  }
 }
 $102 = HEAP32[$47>>2]|0;
 $103 = ($102|0)==(0|0);
 if (!($103)) {
  HEAP32[$47>>2] = 0;
  $104 = HEAP32[$102>>2]|0;
  $105 = ((($104)) + -16|0);
  $106 = HEAP32[$105>>2]|0;
  $107 = (($102) + ($106)|0);
  $108 = ((($107)) + 8|0);
  $109 = HEAP32[$108>>2]|0;HEAP32[$108>>2] = (($109-1)|0);
  $110 = ($109|0)==(1);
  if ($110) {
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($107,1,1);
  }
 }
 $111 = ((($5)) + 88|0);
 $112 = HEAP32[$111>>2]|0;
 $113 = ($112|0)==(0);
 L48: do {
  if (!($113)) {
   $114 = HEAP32[$70>>2]|0;
   $115 = HEAP32[$69>>2]|0;
   $116 = ((($115)) + 4|0);
   $117 = HEAP32[$116>>2]|0;
   $118 = HEAP32[$114>>2]|0;
   $119 = ((($118)) + 4|0);
   HEAP32[$119>>2] = $117;
   $120 = HEAP32[$116>>2]|0;
   HEAP32[$120>>2] = $118;
   HEAP32[$111>>2] = 0;
   $121 = ($114|0)==($69|0);
   if (!($121)) {
    $$023$i$i = $114;
    while(1) {
     $122 = ((($$023$i$i)) + 4|0);
     $123 = HEAP32[$122>>2]|0;
     $124 = ((($$023$i$i)) + 8|0);
     $125 = HEAP32[$124>>2]|0;
     $126 = ($125|0)==(0|0);
     if (!($126)) {
      $127 = HEAP32[$125>>2]|0;
      $128 = ((($127)) + -16|0);
      $129 = HEAP32[$128>>2]|0;
      $130 = (($125) + ($129)|0);
      $131 = ((($130)) + 8|0);
      $132 = HEAP32[$131>>2]|0;HEAP32[$131>>2] = (($132-1)|0);
      $133 = ($132|0)==(1);
      if ($133) {
       __THREW__ = 0;
       invoke_viii(3262,($130|0),1,1);
       $134 = __THREW__; __THREW__ = 0;
       $135 = $134&1;
       if ($135) {
        break;
       }
      }
     }
     __ZdlPv($$023$i$i);
     $136 = ($123|0)==($69|0);
     if ($136) {
      break L48;
     } else {
      $$023$i$i = $123;
     }
    }
    $137 = ___cxa_find_matching_catch_2()|0;
    $138 = tempRet0;
    ___cxa_call_unexpected(($137|0));
    // unreachable;
   }
  }
 } while(0);
 __ZN3osg16ObserverNodePath13clearNodePathEv($72);
 $139 = HEAP32[$74>>2]|0;
 $140 = ($139|0)==(0|0);
 if ($140) {
  __ZN9osgViewer4View37computeActiveCoordinateSystemNodePathEv($0);
  __ZN9osgViewer4View24assignSceneDataToCamerasEv($0);
  STACKTOP = sp;return;
 }
 HEAP32[$74>>2] = 0;
 $141 = ((($139)) + 8|0);
 $142 = HEAP32[$141>>2]|0;HEAP32[$141>>2] = (($142-1)|0);
 $143 = ($142|0)==(1);
 if (!($143)) {
  __ZN9osgViewer4View37computeActiveCoordinateSystemNodePathEv($0);
  __ZN9osgViewer4View24assignSceneDataToCamerasEv($0);
  STACKTOP = sp;return;
 }
 __ZNK3osg10Referenced24signalObserversAndDeleteEbb($139,1,1);
 __ZN9osgViewer4View37computeActiveCoordinateSystemNodePathEv($0);
 __ZN9osgViewer4View24assignSceneDataToCamerasEv($0);
 STACKTOP = sp;return;
}
function __ZN9osgViewer4ViewD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vii(3272,($0|0),(35484|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  $3 = ((($0)) + 132|0);
  __ZN3osg6ObjectD2Ev($3);
  return;
 }
 $4 = ___cxa_find_matching_catch_2()|0;
 $5 = tempRet0;
 $6 = ((($0)) + 132|0);
 __THREW__ = 0;
 invoke_vi(388,($6|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch_3(0|0)|0;
  $10 = tempRet0;
  ___clang_call_terminate($9);
  // unreachable;
 } else {
  ___resumeException($4|0);
  // unreachable;
 }
}
function __ZN9osgViewer4ViewD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vii(3272,($0|0),(35484|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $6 = ___cxa_find_matching_catch_2()|0;
  $7 = tempRet0;
  $8 = ((($0)) + 132|0);
  __THREW__ = 0;
  invoke_vi(388,($8|0));
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if ($10) {
   $11 = ___cxa_find_matching_catch_3(0|0)|0;
   $12 = tempRet0;
   ___clang_call_terminate($11);
   // unreachable;
  } else {
   $eh$lpad$body$index2Z2D = $7;$eh$lpad$body$indexZ2D = $6;
   __ZdlPv($0);
   ___resumeException($eh$lpad$body$indexZ2D|0);
   // unreachable;
  }
 }
 $3 = ((($0)) + 132|0);
 __THREW__ = 0;
 invoke_vi(388,($3|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  __ZdlPv($0);
  return;
 }
 $13 = ___cxa_find_matching_catch_2()|0;
 $14 = tempRet0;
 $eh$lpad$body$index2Z2D = $14;$eh$lpad$body$indexZ2D = $13;
 __ZdlPv($0);
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
}
function __ZN9osgViewer4View14createRendererEPN3osg6CameraE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$111 = 0, $$19 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = (__Znwj(144)|0);
 __THREW__ = 0;
 invoke_vii(3273,($3|0),($1|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $25 = ___cxa_find_matching_catch_2()|0;
  $26 = tempRet0;
  __ZdlPv($3);
  $$111 = $25;$$19 = $26;
  ___resumeException($$111|0);
  // unreachable;
 }
 $6 = (__Znwj(80)|0);
 ;HEAP32[$2>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;
 $7 = ((($2)) + 11|0);
 HEAP8[$7>>0] = 6;
 ;HEAP8[$2>>0]=HEAP8[120371>>0]|0;HEAP8[$2+1>>0]=HEAP8[120371+1>>0]|0;HEAP8[$2+2>>0]=HEAP8[120371+2>>0]|0;HEAP8[$2+3>>0]=HEAP8[120371+3>>0]|0;HEAP8[$2+4>>0]=HEAP8[120371+4>>0]|0;HEAP8[$2+5>>0]=HEAP8[120371+5>>0]|0;
 $8 = ((($2)) + 6|0);
 HEAP8[$8>>0] = 0;
 __THREW__ = 0;
 invoke_vii(3274,($6|0),($2|0));
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 do {
  if ($10) {
   $$0 = 1;
  } else {
   $11 = ((($1)) + 224|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = ($12|0)==($6|0);
   if (!($13)) {
    HEAP32[$11>>2] = $6;
    $14 = ((($6)) + 8|0);
    $15 = HEAP32[$14>>2]|0;HEAP32[$14>>2] = (($15+1)|0);
    $16 = ($12|0)==(0|0);
    if (!($16)) {
     $17 = ((($12)) + 8|0);
     $18 = HEAP32[$17>>2]|0;HEAP32[$17>>2] = (($18-1)|0);
     $19 = ($18|0)==(1);
     if ($19) {
      __THREW__ = 0;
      invoke_viii(3262,($12|0),1,1);
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if ($21) {
       $$0 = 0;
       break;
      }
     }
    }
   }
   $22 = HEAP8[$7>>0]|0;
   $23 = ($22<<24>>24)<(0);
   if (!($23)) {
    STACKTOP = sp;return ($3|0);
   }
   $24 = HEAP32[$2>>2]|0;
   __ZdlPv($24);
   STACKTOP = sp;return ($3|0);
  }
 } while(0);
 $27 = ___cxa_find_matching_catch_2()|0;
 $28 = tempRet0;
 $29 = HEAP8[$7>>0]|0;
 $30 = ($29<<24>>24)<(0);
 if ($30) {
  $31 = HEAP32[$2>>2]|0;
  __ZdlPv($31);
  if (!($$0)) {
   $$111 = $27;$$19 = $28;
   ___resumeException($$111|0);
   // unreachable;
  }
 } else {
  if (!($$0)) {
   $$111 = $27;$$19 = $28;
   ___resumeException($$111|0);
   // unreachable;
  }
 }
 __ZdlPv($6);
 $$111 = $27;$$19 = $28;
 ___resumeException($$111|0);
 // unreachable;
 return (0)|0;
}
function __ZN9osgViewer4View6asViewEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ($0|0);
}
function __ZN9osgViewer4View12setStartTickEy($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 48|0);
 $4 = $3;
 $5 = $4;
 HEAP32[$5>>2] = $1;
 $6 = (($4) + 4)|0;
 $7 = $6;
 HEAP32[$7>>2] = $2;
 $8 = ((($0)) + 56|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($0)) + 60|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($9|0)==($11|0);
 if ($12) {
  return;
 }
 $13 = HEAP32[$9>>2]|0;
 $14 = ((($13)) + 32|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ((($15)) + 24|0);
 $17 = $16;
 $18 = $17;
 HEAP32[$18>>2] = $1;
 $19 = (($17) + 4)|0;
 $20 = $19;
 HEAP32[$20>>2] = $2;
 __ZN5osgGA10EventQueue5clearEv($15);
 $21 = ((($9)) + 4|0);
 $22 = HEAP32[$10>>2]|0;
 $23 = ($21|0)==($22|0);
 if ($23) {
  return;
 } else {
  $31 = $21;
 }
 while(1) {
  $24 = $3;
  $25 = $24;
  $26 = HEAP32[$25>>2]|0;
  $27 = (($24) + 4)|0;
  $28 = $27;
  $29 = HEAP32[$28>>2]|0;
  $30 = HEAP32[$31>>2]|0;
  $32 = ((($30)) + 32|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = ((($33)) + 24|0);
  $35 = $34;
  $36 = $35;
  HEAP32[$36>>2] = $26;
  $37 = (($35) + 4)|0;
  $38 = $37;
  HEAP32[$38>>2] = $29;
  __ZN5osgGA10EventQueue5clearEv($33);
  $39 = ((($31)) + 4|0);
  $40 = HEAP32[$10>>2]|0;
  $41 = ($39|0)==($40|0);
  if ($41) {
   break;
  } else {
   $31 = $39;
  }
 }
 return;
}
function __ZN9osgViewer4View12setSceneDataEPN3osg4NodeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$05 = 0, $$1 = 0, $$16 = 0, $$2 = 0, $$27 = 0, $$3 = 0, $$379 = 0, $$38 = 0, $$3878 = 0, $$cast$i$i = 0, $$pr = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0;
 var $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0;
 var $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0;
 var $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0;
 var $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0;
 var $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0;
 var $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0;
 var $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0;
 var $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0;
 var $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0;
 var $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0;
 var $323 = 0, $324 = 0, $325 = 0, $326 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index4Z2D = 0, $eh$lpad$body$indexZ2D = 0, $eh$lpad$body49$index11Z2D = 0;
 var $eh$lpad$body49$indexZ2D = 0, $eh$lpad$body57$indexZ2D = 0, $eh$lpad$body63$index16Z2D = 0, $eh$lpad$body63$indexZ2D = 0, $eh$lpad$body67$index21Z2D = 0, $eh$lpad$body67$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 208|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(208|0);
 $2 = sp + 204|0;
 $3 = sp + 200|0;
 $4 = sp + 196|0;
 $5 = sp + 96|0;
 $6 = sp;
 $7 = ((($0)) + 68|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (__ZN9osgViewer5Scene12getSceneDataEv($8)|0);
 $10 = ($9|0)==($1|0);
 if ($10) {
  STACKTOP = sp;return;
 }
 $11 = (__ZN9osgViewer5Scene8getSceneEPN3osg4NodeE($1)|0);
 $12 = ($11|0)==(0|0);
 L4: do {
  if ($12) {
   $65 = HEAP32[$7>>2]|0;
   /* fence */;
   $66 = ((($65)) + 8|0);
   $67 = HEAP32[$66>>2]|0;
   $68 = ($67|0)==(1);
   do {
    if ($68) {
     __THREW__ = 0;
     $126 = (invoke_ii(3265,4)|0);
     $127 = __THREW__; __THREW__ = 0;
     $128 = $127&1;
     if ($128) {
      label = 17;
      break L4;
     }
     if ($126) {
      __THREW__ = 0;
      $129 = (invoke_ii(3266,4)|0);
      $130 = __THREW__; __THREW__ = 0;
      $131 = $130&1;
      if ($131) {
       label = 17;
       break L4;
      }
      __THREW__ = 0;
      $132 = (invoke_iiii(3267,($129|0),(102710|0),43)|0);
      $133 = __THREW__; __THREW__ = 0;
      $134 = $133&1;
      if ($134) {
       label = 17;
       break L4;
      }
      $135 = HEAP32[$7>>2]|0;
      __THREW__ = 0;
      $136 = (invoke_iii(3275,($132|0),($135|0))|0);
      $137 = __THREW__; __THREW__ = 0;
      $138 = $137&1;
      if ($138) {
       label = 17;
       break L4;
      }
      $139 = HEAP32[$136>>2]|0;
      $140 = ((($139)) + -12|0);
      $141 = HEAP32[$140>>2]|0;
      $142 = (($136) + ($141)|0);
      __THREW__ = 0;
      invoke_vii(3257,($2|0),($142|0));
      $143 = __THREW__; __THREW__ = 0;
      $144 = $143&1;
      if ($144) {
       label = 17;
       break L4;
      }
      __THREW__ = 0;
      $145 = (invoke_iii(3255,($2|0),(215188|0))|0);
      $146 = __THREW__; __THREW__ = 0;
      $147 = $146&1;
      if (!($147)) {
       $148 = HEAP32[$145>>2]|0;
       $149 = ((($148)) + 28|0);
       $150 = HEAP32[$149>>2]|0;
       __THREW__ = 0;
       $151 = (invoke_iii($150|0,($145|0),10)|0);
       $152 = __THREW__; __THREW__ = 0;
       $153 = $152&1;
       if (!($153)) {
        __THREW__ = 0;
        invoke_vi(3263,($2|0));
        $160 = __THREW__; __THREW__ = 0;
        $161 = $160&1;
        if ($161) {
         label = 17;
         break L4;
        }
        __THREW__ = 0;
        (invoke_iii(3268,($136|0),($151|0))|0);
        $162 = __THREW__; __THREW__ = 0;
        $163 = $162&1;
        if ($163) {
         label = 17;
         break L4;
        }
        __THREW__ = 0;
        (invoke_ii(3269,($136|0))|0);
        $164 = __THREW__; __THREW__ = 0;
        $165 = $164&1;
        if ($165) {
         label = 17;
         break L4;
        } else {
         break;
        }
       }
      }
      $154 = ___cxa_find_matching_catch_2()|0;
      $155 = tempRet0;
      __THREW__ = 0;
      invoke_vi(3263,($2|0));
      $156 = __THREW__; __THREW__ = 0;
      $157 = $156&1;
      if ($157) {
       $158 = ___cxa_find_matching_catch_3(0|0)|0;
       $159 = tempRet0;
       ___clang_call_terminate($158);
       // unreachable;
      } else {
       $eh$lpad$body$index4Z2D = $155;$eh$lpad$body$indexZ2D = $154;
       label = 18;
       break L4;
      }
     }
    } else {
     __THREW__ = 0;
     $69 = (invoke_ii(3276,24)|0);
     $70 = __THREW__; __THREW__ = 0;
     $71 = $70&1;
     if ($71) {
      label = 17;
      break L4;
     }
     __THREW__ = 0;
     invoke_vi(3277,($69|0));
     $72 = __THREW__; __THREW__ = 0;
     $73 = $72&1;
     if ($73) {
      $124 = ___cxa_find_matching_catch_2()|0;
      $125 = tempRet0;
      __ZdlPv($69);
      $$379 = $125;$$3878 = $124;
      ___resumeException($$3878|0);
      // unreachable;
     }
     $74 = HEAP32[$7>>2]|0;
     $75 = ($74|0)==($69|0);
     if (!($75)) {
      HEAP32[$7>>2] = $69;
      $76 = ((($69)) + 8|0);
      $77 = HEAP32[$76>>2]|0;HEAP32[$76>>2] = (($77+1)|0);
      $78 = ($74|0)==(0|0);
      if (!($78)) {
       $79 = ((($74)) + 8|0);
       $80 = HEAP32[$79>>2]|0;HEAP32[$79>>2] = (($80-1)|0);
       $81 = ($80|0)==(1);
       if ($81) {
        __THREW__ = 0;
        invoke_viii(3262,($74|0),1,1);
        $82 = __THREW__; __THREW__ = 0;
        $83 = $82&1;
        if ($83) {
         label = 17;
         break L4;
        }
       }
      }
     }
     __THREW__ = 0;
     $84 = (invoke_ii(3265,4)|0);
     $85 = __THREW__; __THREW__ = 0;
     $86 = $85&1;
     if ($86) {
      label = 17;
      break L4;
     }
     if ($84) {
      __THREW__ = 0;
      $87 = (invoke_ii(3266,4)|0);
      $88 = __THREW__; __THREW__ = 0;
      $89 = $88&1;
      if ($89) {
       label = 17;
       break L4;
      }
      __THREW__ = 0;
      $90 = (invoke_iiii(3267,($87|0),(102668|0),41)|0);
      $91 = __THREW__; __THREW__ = 0;
      $92 = $91&1;
      if ($92) {
       label = 17;
       break L4;
      }
      $93 = HEAP32[$7>>2]|0;
      __THREW__ = 0;
      $94 = (invoke_iii(3275,($90|0),($93|0))|0);
      $95 = __THREW__; __THREW__ = 0;
      $96 = $95&1;
      if ($96) {
       label = 17;
       break L4;
      }
      $97 = HEAP32[$94>>2]|0;
      $98 = ((($97)) + -12|0);
      $99 = HEAP32[$98>>2]|0;
      $100 = (($94) + ($99)|0);
      __THREW__ = 0;
      invoke_vii(3257,($3|0),($100|0));
      $101 = __THREW__; __THREW__ = 0;
      $102 = $101&1;
      if ($102) {
       label = 17;
       break L4;
      }
      __THREW__ = 0;
      $103 = (invoke_iii(3255,($3|0),(215188|0))|0);
      $104 = __THREW__; __THREW__ = 0;
      $105 = $104&1;
      if (!($105)) {
       $106 = HEAP32[$103>>2]|0;
       $107 = ((($106)) + 28|0);
       $108 = HEAP32[$107>>2]|0;
       __THREW__ = 0;
       $109 = (invoke_iii($108|0,($103|0),10)|0);
       $110 = __THREW__; __THREW__ = 0;
       $111 = $110&1;
       if (!($111)) {
        __THREW__ = 0;
        invoke_vi(3263,($3|0));
        $118 = __THREW__; __THREW__ = 0;
        $119 = $118&1;
        if ($119) {
         label = 17;
         break L4;
        }
        __THREW__ = 0;
        (invoke_iii(3268,($94|0),($109|0))|0);
        $120 = __THREW__; __THREW__ = 0;
        $121 = $120&1;
        if ($121) {
         label = 17;
         break L4;
        }
        __THREW__ = 0;
        (invoke_ii(3269,($94|0))|0);
        $122 = __THREW__; __THREW__ = 0;
        $123 = $122&1;
        if ($123) {
         label = 17;
         break L4;
        } else {
         break;
        }
       }
      }
      $112 = ___cxa_find_matching_catch_2()|0;
      $113 = tempRet0;
      __THREW__ = 0;
      invoke_vi(3263,($3|0));
      $114 = __THREW__; __THREW__ = 0;
      $115 = $114&1;
      if ($115) {
       $116 = ___cxa_find_matching_catch_3(0|0)|0;
       $117 = tempRet0;
       ___clang_call_terminate($116);
       // unreachable;
      } else {
       $eh$lpad$body$index4Z2D = $113;$eh$lpad$body$indexZ2D = $112;
       label = 18;
       break L4;
      }
     }
    }
   } while(0);
   $166 = HEAP32[$7>>2]|0;
   __THREW__ = 0;
   invoke_vii(3278,($166|0),($1|0));
   $167 = __THREW__; __THREW__ = 0;
   $168 = $167&1;
   if ($168) {
    label = 17;
   } else {
    label = 60;
   }
  } else {
   $13 = ((($11)) + 8|0);
   $14 = HEAP32[$13>>2]|0;HEAP32[$13>>2] = (($14+1)|0);
   __THREW__ = 0;
   $15 = (invoke_ii(3265,4)|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if ($17) {
    label = 17;
   } else {
    do {
     if ($15) {
      __THREW__ = 0;
      $18 = (invoke_ii(3266,4)|0);
      $19 = __THREW__; __THREW__ = 0;
      $20 = $19&1;
      if ($20) {
       label = 17;
       break L4;
      }
      __THREW__ = 0;
      $21 = (invoke_iiii(3267,($18|0),(102632|0),35)|0);
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if ($23) {
       label = 17;
       break L4;
      }
      __THREW__ = 0;
      $24 = (invoke_iii(3275,($21|0),($11|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if ($26) {
       label = 17;
       break L4;
      }
      $27 = HEAP32[$24>>2]|0;
      $28 = ((($27)) + -12|0);
      $29 = HEAP32[$28>>2]|0;
      $30 = (($24) + ($29)|0);
      __THREW__ = 0;
      invoke_vii(3257,($4|0),($30|0));
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if ($32) {
       label = 17;
       break L4;
      }
      __THREW__ = 0;
      $33 = (invoke_iii(3255,($4|0),(215188|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if (!($35)) {
       $36 = HEAP32[$33>>2]|0;
       $37 = ((($36)) + 28|0);
       $38 = HEAP32[$37>>2]|0;
       __THREW__ = 0;
       $39 = (invoke_iii($38|0,($33|0),10)|0);
       $40 = __THREW__; __THREW__ = 0;
       $41 = $40&1;
       if (!($41)) {
        __THREW__ = 0;
        invoke_vi(3263,($4|0));
        $48 = __THREW__; __THREW__ = 0;
        $49 = $48&1;
        if ($49) {
         label = 17;
         break L4;
        }
        __THREW__ = 0;
        (invoke_iii(3268,($24|0),($39|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 17;
         break L4;
        }
        __THREW__ = 0;
        (invoke_ii(3269,($24|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 17;
         break L4;
        } else {
         break;
        }
       }
      }
      $42 = ___cxa_find_matching_catch_2()|0;
      $43 = tempRet0;
      __THREW__ = 0;
      invoke_vi(3263,($4|0));
      $44 = __THREW__; __THREW__ = 0;
      $45 = $44&1;
      if ($45) {
       $46 = ___cxa_find_matching_catch_3(0|0)|0;
       $47 = tempRet0;
       ___clang_call_terminate($46);
       // unreachable;
      } else {
       $eh$lpad$body$index4Z2D = $43;$eh$lpad$body$indexZ2D = $42;
       label = 18;
       break L4;
      }
     }
    } while(0);
    $56 = HEAP32[$7>>2]|0;
    $57 = ($56|0)==($11|0);
    if ($57) {
     $169 = $56;
     label = 61;
    } else {
     HEAP32[$7>>2] = $11;
     $58 = HEAP32[$13>>2]|0;HEAP32[$13>>2] = (($58+1)|0);
     $59 = ($56|0)==(0|0);
     if ($59) {
      label = 60;
     } else {
      $60 = ((($56)) + 8|0);
      $61 = HEAP32[$60>>2]|0;HEAP32[$60>>2] = (($61-1)|0);
      $62 = ($61|0)==(1);
      if ($62) {
       __THREW__ = 0;
       invoke_viii(3262,($56|0),1,1);
       $63 = __THREW__; __THREW__ = 0;
       $64 = $63&1;
       if ($64) {
        label = 17;
       } else {
        label = 60;
       }
      } else {
       label = 60;
      }
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 60) {
  $$pr = HEAP32[$7>>2]|0;
  $169 = $$pr;
  label = 61;
 }
 L73: do {
  if ((label|0) == 61) {
   $170 = ($169|0)==(0|0);
   L75: do {
    if (!($170)) {
     __THREW__ = 0;
     $171 = (invoke_ii(3279,($169|0))|0);
     $172 = __THREW__; __THREW__ = 0;
     $173 = $172&1;
     if ($173) {
      label = 17;
      break L73;
     }
     $174 = ($171|0)==(0|0);
     if (!($174)) {
      __THREW__ = 0;
      invoke_vi(3280,($5|0));
      $175 = __THREW__; __THREW__ = 0;
      $176 = $175&1;
      if ($176) {
       label = 17;
       break L73;
      }
      $177 = HEAP32[$7>>2]|0;
      $178 = ($177|0)==(0|0);
      if ($178) {
       $182 = 0;
       label = 67;
      } else {
       __THREW__ = 0;
       $179 = (invoke_ii(3279,($177|0))|0);
       $180 = __THREW__; __THREW__ = 0;
       $181 = $180&1;
       if ($181) {
        label = 82;
       } else {
        $182 = $179;
        label = 67;
       }
      }
      L82: do {
       if ((label|0) == 67) {
        __THREW__ = 0;
        (invoke_ii(3281,($182|0))|0);
        $183 = __THREW__; __THREW__ = 0;
        $184 = $183&1;
        if ($184) {
         label = 82;
        } else {
         $185 = HEAP32[$7>>2]|0;
         __THREW__ = 0;
         $186 = (invoke_ii(3279,($185|0))|0);
         $187 = __THREW__; __THREW__ = 0;
         $188 = $187&1;
         if ($188) {
          label = 82;
         } else {
          $189 = HEAP32[$186>>2]|0;
          $190 = ((($189)) + 188|0);
          $191 = HEAP32[$190>>2]|0;
          __THREW__ = 0;
          invoke_vii($191|0,($186|0),($5|0));
          $192 = __THREW__; __THREW__ = 0;
          $193 = $192&1;
          if ($193) {
           label = 82;
          } else {
           $194 = ((($6)) + 64|0);
           __THREW__ = 0;
           invoke_vi(3282,($194|0));
           $195 = __THREW__; __THREW__ = 0;
           $196 = $195&1;
           if ($196) {
            label = 82;
           } else {
            HEAP32[$194>>2] = (63412);
            $197 = ((($6)) + 76|0);
            ;HEAP32[$197>>2]=0|0;HEAP32[$197+4>>2]=0|0;HEAP32[$197+8>>2]=0|0;
            $198 = ((($6)) + 88|0);
            HEAP32[$198>>2] = 2;
            $199 = ((($6)) + 92|0);
            HEAP32[$199>>2] = 0;
            __THREW__ = 0;
            invoke_viii(3283,($6|0),((48688)|0),2);
            $200 = __THREW__; __THREW__ = 0;
            $201 = $200&1;
            if ($201) {
             $202 = ___cxa_find_matching_catch_2()|0;
             $203 = tempRet0;
             __THREW__ = 0;
             invoke_vi(388,($194|0));
             $204 = __THREW__; __THREW__ = 0;
             $205 = $204&1;
             if (!($205)) {
              $eh$lpad$body49$index11Z2D = $203;$eh$lpad$body49$indexZ2D = $202;
              label = 83;
              break;
             }
             $206 = ___cxa_find_matching_catch_3(0|0)|0;
             $207 = tempRet0;
             ___clang_call_terminate($206);
             // unreachable;
            }
            $208 = HEAP32[(48684)>>2]|0;
            HEAP32[$6>>2] = $208;
            $209 = HEAP32[(48696)>>2]|0;
            $$cast$i$i = $208;
            $210 = ((($$cast$i$i)) + -12|0);
            $211 = HEAP32[$210>>2]|0;
            $212 = (($6) + ($211)|0);
            HEAP32[$212>>2] = $209;
            $213 = ((($6)) + 56|0);
            HEAP32[$213>>2] = 0;
            $214 = ((($6)) + 60|0);
            HEAP32[$214>>2] = 65536;
            $215 = ((($6)) + 24|0);
            HEAP32[$215>>2] = -1;
            HEAP32[$6>>2] = (48716);
            HEAP32[$194>>2] = (49060);
            $216 = HEAP32[$7>>2]|0;
            __THREW__ = 0;
            $217 = (invoke_ii(3279,($216|0))|0);
            $218 = __THREW__; __THREW__ = 0;
            $219 = $218&1;
            L92: do {
             if ($219) {
              label = 84;
             } else {
              $220 = HEAP32[$217>>2]|0;
              $221 = ((($220)) + 188|0);
              $222 = HEAP32[$221>>2]|0;
              __THREW__ = 0;
              invoke_vii($222|0,($217|0),($6|0));
              $223 = __THREW__; __THREW__ = 0;
              $224 = $223&1;
              if ($224) {
               label = 84;
              } else {
               $225 = ((($0)) + 40|0);
               $226 = HEAP32[$225>>2]|0;
               $227 = ($226|0)==(0|0);
               do {
                if (!($227)) {
                 $228 = ((($226)) + 24|0);
                 $229 = HEAP32[$228>>2]|0;
                 $230 = ($229|0)==(0|0);
                 if ($230) {
                  break;
                 }
                 $231 = ((($0)) + 44|0);
                 $232 = HEAP32[$231>>2]|0;
                 $233 = ($232|0)==(0|0);
                 if ($233) {
                  break;
                 }
                 $234 = ((($232)) + 28|0);
                 $235 = HEAP32[$234>>2]|0;
                 $236 = ($235|0)==(0);
                 if ($236) {
                  break;
                 }
                 $237 = HEAP32[$7>>2]|0;
                 __THREW__ = 0;
                 $238 = (invoke_ii(3279,($237|0))|0);
                 $239 = __THREW__; __THREW__ = 0;
                 $240 = $239&1;
                 if ($240) {
                  label = 84;
                  break L92;
                 }
                 $241 = HEAP32[$238>>2]|0;
                 $242 = HEAP32[$241>>2]|0;
                 __THREW__ = 0;
                 invoke_vii($242|0,($238|0),1);
                 $243 = __THREW__; __THREW__ = 0;
                 $244 = $243&1;
                 if ($244) {
                  label = 84;
                  break L92;
                 }
                }
               } while(0);
               $259 = HEAP32[$7>>2]|0;
               __THREW__ = 0;
               $260 = (invoke_ii(3279,($259|0))|0);
               $261 = __THREW__; __THREW__ = 0;
               $262 = $261&1;
               if ($262) {
                label = 84;
               } else {
                $263 = HEAP32[$260>>2]|0;
                $264 = ((($263)) + 132|0);
                $265 = HEAP32[$264>>2]|0;
                __THREW__ = 0;
                $266 = (invoke_i(3285)|0);
                $267 = __THREW__; __THREW__ = 0;
                $268 = $267&1;
                if ($268) {
                 label = 84;
                 break;
                }
                $269 = HEAP32[$266>>2]|0;
                __THREW__ = 0;
                $270 = (invoke_ii(3286,($269|0))|0);
                $271 = __THREW__; __THREW__ = 0;
                $272 = $271&1;
                if ($272) {
                 label = 84;
                 break;
                }
                __THREW__ = 0;
                invoke_vii($265|0,($260|0),($270|0));
                $273 = __THREW__; __THREW__ = 0;
                $274 = $273&1;
                if ($274) {
                 label = 84;
                 break;
                }
                __THREW__ = 0;
                invoke_vii(3284,($6|0),((48688)|0));
                $275 = __THREW__; __THREW__ = 0;
                $276 = $275&1;
                do {
                 if ($276) {
                  $279 = ___cxa_find_matching_catch_2()|0;
                  $280 = tempRet0;
                  __THREW__ = 0;
                  invoke_vi(388,($194|0));
                  $281 = __THREW__; __THREW__ = 0;
                  $282 = $281&1;
                  if (!($282)) {
                   $eh$lpad$body63$index16Z2D = $280;$eh$lpad$body63$indexZ2D = $279;
                   break;
                  }
                  $283 = ___cxa_find_matching_catch_3(0|0)|0;
                  $284 = tempRet0;
                  ___clang_call_terminate($283);
                  // unreachable;
                 } else {
                  __THREW__ = 0;
                  invoke_vi(388,($194|0));
                  $277 = __THREW__; __THREW__ = 0;
                  $278 = $277&1;
                  if ($278) {
                   $297 = ___cxa_find_matching_catch_2()|0;
                   $298 = tempRet0;
                   $eh$lpad$body63$index16Z2D = $298;$eh$lpad$body63$indexZ2D = $297;
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vii(3287,($5|0),(50128|0));
                  $285 = __THREW__; __THREW__ = 0;
                  $286 = $285&1;
                  do {
                   if ($286) {
                    $290 = ___cxa_find_matching_catch_2()|0;
                    $291 = tempRet0;
                    $292 = ((($5)) + 68|0);
                    __THREW__ = 0;
                    invoke_vi(388,($292|0));
                    $293 = __THREW__; __THREW__ = 0;
                    $294 = $293&1;
                    if (!($294)) {
                     $eh$lpad$body67$index21Z2D = $291;$eh$lpad$body67$indexZ2D = $290;
                     break;
                    }
                    $295 = ___cxa_find_matching_catch_3(0|0)|0;
                    $296 = tempRet0;
                    ___clang_call_terminate($295);
                    // unreachable;
                   } else {
                    $287 = ((($5)) + 68|0);
                    __THREW__ = 0;
                    invoke_vi(388,($287|0));
                    $288 = __THREW__; __THREW__ = 0;
                    $289 = $288&1;
                    if ($289) {
                     $299 = ___cxa_find_matching_catch_2()|0;
                     $300 = tempRet0;
                     $eh$lpad$body67$index21Z2D = $300;$eh$lpad$body67$indexZ2D = $299;
                     break;
                    } else {
                     break L75;
                    }
                   }
                  } while(0);
                  $$2 = $eh$lpad$body67$index21Z2D;$$27 = $eh$lpad$body67$indexZ2D;
                  break L82;
                 }
                } while(0);
                $$0 = $eh$lpad$body63$index16Z2D;$$05 = $eh$lpad$body63$indexZ2D;
               }
              }
             }
            } while(0);
            do {
             if ((label|0) == 84) {
              $247 = ___cxa_find_matching_catch_2()|0;
              $248 = tempRet0;
              __THREW__ = 0;
              invoke_vii(3284,($6|0),((48688)|0));
              $249 = __THREW__; __THREW__ = 0;
              $250 = $249&1;
              if (!($250)) {
               __THREW__ = 0;
               invoke_vi(388,($194|0));
               $251 = __THREW__; __THREW__ = 0;
               $252 = $251&1;
               if ($252) {
                break L73;
               } else {
                $$0 = $248;$$05 = $247;
                break;
               }
              }
              $253 = ___cxa_find_matching_catch_3(0|0)|0;
              $254 = tempRet0;
              __THREW__ = 0;
              invoke_vi(388,($194|0));
              $255 = __THREW__; __THREW__ = 0;
              $256 = $255&1;
              if ($256) {
               $257 = ___cxa_find_matching_catch_3(0|0)|0;
               $258 = tempRet0;
               ___clang_call_terminate($257);
               // unreachable;
              } else {
               $eh$lpad$body57$indexZ2D = $253;
               ___clang_call_terminate($eh$lpad$body57$indexZ2D);
               // unreachable;
              }
             }
            } while(0);
            $$1 = $$0;$$16 = $$05;
            label = 106;
           }
          }
         }
        }
       }
      } while(0);
      if ((label|0) == 82) {
       $245 = ___cxa_find_matching_catch_2()|0;
       $246 = tempRet0;
       $eh$lpad$body49$index11Z2D = $246;$eh$lpad$body49$indexZ2D = $245;
       label = 83;
      }
      if ((label|0) == 83) {
       $$1 = $eh$lpad$body49$index11Z2D;$$16 = $eh$lpad$body49$indexZ2D;
       label = 106;
      }
      do {
       if ((label|0) == 106) {
        __THREW__ = 0;
        invoke_vii(3287,($5|0),(50128|0));
        $301 = __THREW__; __THREW__ = 0;
        $302 = $301&1;
        if (!($302)) {
         $303 = ((($5)) + 68|0);
         __THREW__ = 0;
         invoke_vi(388,($303|0));
         $304 = __THREW__; __THREW__ = 0;
         $305 = $304&1;
         if ($305) {
          break L73;
         } else {
          $$2 = $$1;$$27 = $$16;
          break;
         }
        }
        $306 = ___cxa_find_matching_catch_3(0|0)|0;
        $307 = tempRet0;
        $308 = ((($5)) + 68|0);
        __THREW__ = 0;
        invoke_vi(388,($308|0));
        $309 = __THREW__; __THREW__ = 0;
        $310 = $309&1;
        if ($310) {
         $311 = ___cxa_find_matching_catch_3(0|0)|0;
         $312 = tempRet0;
         ___clang_call_terminate($311);
         // unreachable;
        } else {
         $eh$lpad$body57$indexZ2D = $306;
         ___clang_call_terminate($eh$lpad$body57$indexZ2D);
         // unreachable;
        }
       }
      } while(0);
      $$3 = $$2;$$38 = $$27;
      label = 117;
      break L73;
     }
    }
   } while(0);
   __THREW__ = 0;
   invoke_vi(3288,($0|0));
   $313 = __THREW__; __THREW__ = 0;
   $314 = $313&1;
   if ($314) {
    label = 17;
   } else {
    __THREW__ = 0;
    invoke_vi(3289,($0|0));
    $315 = __THREW__; __THREW__ = 0;
    $316 = $315&1;
    if ($316) {
     label = 17;
    } else {
     if ($12) {
      STACKTOP = sp;return;
     }
     $317 = ((($11)) + 8|0);
     $318 = HEAP32[$317>>2]|0;HEAP32[$317>>2] = (($318-1)|0);
     $319 = ($318|0)==(1);
     if (!($319)) {
      STACKTOP = sp;return;
     }
     __ZNK3osg10Referenced24signalObserversAndDeleteEbb($11,1,1);
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 if ((label|0) == 17) {
  $54 = ___cxa_find_matching_catch_2()|0;
  $55 = tempRet0;
  $eh$lpad$body$index4Z2D = $55;$eh$lpad$body$indexZ2D = $54;
  label = 18;
 }
 if ((label|0) == 18) {
  $$3 = $eh$lpad$body$index4Z2D;$$38 = $eh$lpad$body$indexZ2D;
  label = 117;
 }
 if ((label|0) == 117) {
  if ($12) {
   $$379 = $$3;$$3878 = $$38;
   ___resumeException($$3878|0);
   // unreachable;
  }
  $320 = ((($11)) + 8|0);
  $321 = HEAP32[$320>>2]|0;HEAP32[$320>>2] = (($321-1)|0);
  $322 = ($321|0)==(1);
  if (!($322)) {
   $$379 = $$3;$$3878 = $$38;
   ___resumeException($$3878|0);
   // unreachable;
  }
  __THREW__ = 0;
  invoke_viii(3262,($11|0),1,1);
  $323 = __THREW__; __THREW__ = 0;
  $324 = $323&1;
  if (!($324)) {
   $$379 = $$3;$$3878 = $$38;
   ___resumeException($$3878|0);
   // unreachable;
  }
 }
 $325 = ___cxa_find_matching_catch_3(0|0)|0;
 $326 = tempRet0;
 $eh$lpad$body57$indexZ2D = $325;
 ___clang_call_terminate($eh$lpad$body57$indexZ2D);
 // unreachable;
}
function __ZN9osgViewer4View20computeIntersectionsERKN5osgGA15GUIEventAdapterERNSt3__28multisetIN7osgUtil22LineSegmentIntersector12IntersectionENS5_4lessIS9_EENS5_9allocatorIS9_EEEEj($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0.0, $30 = 0, $31 = 0.0, $32 = 0.0, $33 = 0, $34 = 0.0, $35 = 0.0, $36 = 0.0, $37 = 0.0, $38 = 0.0, $39 = 0, $4 = 0, $40 = 0.0, $41 = 0, $42 = 0.0, $43 = 0.0, $44 = 0, $45 = 0.0, $46 = 0.0, $47 = 0.0;
 var $48 = 0.0, $49 = 0.0, $5 = 0, $50 = 0, $51 = 0, $52 = 0.0, $53 = 0, $54 = 0.0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ((($1)) + 160|0);
 $5 = ((($1)) + 164|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$4>>2]|0;
 $8 = (($6) - ($7))|0;
 $9 = $8 >> 2;
 $10 = ($9|0)==(0);
 if (!($10)) {
  $11 = $7;
  $12 = (($9) + -1)|0;
  $13 = (($11) + ($12<<2)|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = ((($14)) + 12|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($16|0)==(0|0);
  if (!($17)) {
   $18 = ((($16)) + 24|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ($19|0)==(0|0);
   if (!($20)) {
    $21 = ((($14)) + 16|0);
    $22 = HEAP32[$21>>2]|0;
    $phitmp$i = ($22|0)==(0|0);
    if (!($phitmp$i)) {
     $23 = HEAP32[$22>>2]|0;
     $24 = ((($23)) + 72|0);
     $25 = HEAP32[$24>>2]|0;
     $26 = (FUNCTION_TABLE_ii[$25 & 8191]($22)|0);
     $27 = ($26|0)==(0|0);
     if (!($27)) {
      $28 = ((($14)) + 20|0);
      $29 = +HEAPF32[$28>>2];
      $30 = ((($14)) + 24|0);
      $31 = +HEAPF32[$30>>2];
      $32 = $29 - $31;
      $33 = ((($14)) + 28|0);
      $34 = +HEAPF32[$33>>2];
      $35 = $34 - $31;
      $36 = $32 / $35;
      $37 = $36 * 2.0;
      $38 = $37 + -1.0;
      $39 = ((($14)) + 32|0);
      $40 = +HEAPF32[$39>>2];
      $41 = ((($14)) + 36|0);
      $42 = +HEAPF32[$41>>2];
      $43 = $40 - $42;
      $44 = ((($14)) + 40|0);
      $45 = +HEAPF32[$44>>2];
      $46 = $45 - $42;
      $47 = $43 / $46;
      $48 = $47 * 2.0;
      $49 = $48 + -1.0;
      $50 = (__ZN9osgViewer4View20computeIntersectionsEPKN3osg6CameraEN7osgUtil11Intersector15CoordinateFrameEffRNSt3__28multisetINS5_22LineSegmentIntersector12IntersectionENS8_4lessISB_EENS8_9allocatorISB_EEEEj(0,$26,1,$38,$49,$2,$3)|0);
      $$1 = $50;
      return ($$1|0);
     }
    }
   }
  }
 }
 $51 = ((($1)) + 104|0);
 $52 = +HEAPF32[$51>>2];
 $53 = ((($1)) + 108|0);
 $54 = +HEAPF32[$53>>2];
 $55 = (__ZN9osgViewer4View20computeIntersectionsEffRNSt3__28multisetIN7osgUtil22LineSegmentIntersector12IntersectionENS1_4lessIS5_EENS1_9allocatorIS5_EEEEj($0,$52,$54,$2,$3)|0);
 $$1 = $55;
 return ($$1|0);
}
function __ZN9osgViewer4View20computeIntersectionsERKN5osgGA15GUIEventAdapterERKNSt3__26vectorIPN3osg4NodeENS5_9allocatorIS9_EEEERNS5_8multisetIN7osgUtil22LineSegmentIntersector12IntersectionENS5_4lessISI_EENSA_ISI_EEEEj($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $30 = 0.0, $31 = 0, $32 = 0.0, $33 = 0.0, $34 = 0, $35 = 0.0, $36 = 0.0, $37 = 0.0, $38 = 0.0, $39 = 0.0, $40 = 0, $41 = 0.0, $42 = 0, $43 = 0.0, $44 = 0.0, $45 = 0, $46 = 0.0, $47 = 0.0, $48 = 0.0;
 var $49 = 0.0, $5 = 0, $50 = 0.0, $51 = 0, $52 = 0, $53 = 0.0, $54 = 0, $55 = 0.0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = ((($1)) + 160|0);
 $6 = ((($1)) + 164|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$5>>2]|0;
 $9 = (($7) - ($8))|0;
 $10 = $9 >> 2;
 $11 = ($10|0)==(0);
 if (!($11)) {
  $12 = $8;
  $13 = (($10) + -1)|0;
  $14 = (($12) + ($13<<2)|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = ((($15)) + 12|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = ($17|0)==(0|0);
  if (!($18)) {
   $19 = ((($17)) + 24|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = ($20|0)==(0|0);
   if (!($21)) {
    $22 = ((($15)) + 16|0);
    $23 = HEAP32[$22>>2]|0;
    $phitmp$i = ($23|0)==(0|0);
    if (!($phitmp$i)) {
     $24 = HEAP32[$23>>2]|0;
     $25 = ((($24)) + 72|0);
     $26 = HEAP32[$25>>2]|0;
     $27 = (FUNCTION_TABLE_ii[$26 & 8191]($23)|0);
     $28 = ($27|0)==(0|0);
     if (!($28)) {
      $29 = ((($15)) + 20|0);
      $30 = +HEAPF32[$29>>2];
      $31 = ((($15)) + 24|0);
      $32 = +HEAPF32[$31>>2];
      $33 = $30 - $32;
      $34 = ((($15)) + 28|0);
      $35 = +HEAPF32[$34>>2];
      $36 = $35 - $32;
      $37 = $33 / $36;
      $38 = $37 * 2.0;
      $39 = $38 + -1.0;
      $40 = ((($15)) + 32|0);
      $41 = +HEAPF32[$40>>2];
      $42 = ((($15)) + 36|0);
      $43 = +HEAPF32[$42>>2];
      $44 = $41 - $43;
      $45 = ((($15)) + 40|0);
      $46 = +HEAPF32[$45>>2];
      $47 = $46 - $43;
      $48 = $44 / $47;
      $49 = $48 * 2.0;
      $50 = $49 + -1.0;
      $51 = (__ZN9osgViewer4View20computeIntersectionsEPKN3osg6CameraEN7osgUtil11Intersector15CoordinateFrameEffRKNSt3__26vectorIPNS1_4NodeENS8_9allocatorISB_EEEERNS8_8multisetINS5_22LineSegmentIntersector12IntersectionENS8_4lessISJ_EENSC_ISJ_EEEEj(0,$27,1,$39,$50,$2,$3,$4)|0);
      $$1 = $51;
      return ($$1|0);
     }
    }
   }
  }
 }
 $52 = ((($1)) + 104|0);
 $53 = +HEAPF32[$52>>2];
 $54 = ((($1)) + 108|0);
 $55 = +HEAPF32[$54>>2];
 $56 = (__ZN9osgViewer4View20computeIntersectionsEffRKNSt3__26vectorIPN3osg4NodeENS1_9allocatorIS5_EEEERNS1_8multisetIN7osgUtil22LineSegmentIntersector12IntersectionENS1_4lessISE_EENS6_ISE_EEEEj($0,$53,$55,$2,$3,$4)|0);
 $$1 = $56;
 return ($$1|0);
}
function __ZN9osgViewer4View13requestRedrawEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $2 = ((($0)) + 40|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = ((($3)) + 24|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==(0|0);
  if (!($7)) {
   $8 = ((($0)) + 44|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = ($9|0)==(0|0);
   if (!($10)) {
    $11 = ((($9)) + 33|0);
    HEAP8[$11>>0] = 1;
    STACKTOP = sp;return;
   }
  }
 }
 $12 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
 if (!($12)) {
  STACKTOP = sp;return;
 }
 $13 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
 $14 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($13,102527,60)|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ((($15)) + -12|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($14) + ($17)|0);
 __ZNKSt3__28ios_base6getlocEv($1,$18);
 __THREW__ = 0;
 $19 = (invoke_iii(3255,($1|0),(215188|0))|0);
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if (!($21)) {
  $22 = HEAP32[$19>>2]|0;
  $23 = ((($22)) + 28|0);
  $24 = HEAP32[$23>>2]|0;
  __THREW__ = 0;
  $25 = (invoke_iii($24|0,($19|0),10)|0);
  $26 = __THREW__; __THREW__ = 0;
  $27 = $26&1;
  if (!($27)) {
   __ZNSt3__26localeD2Ev($1);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($14,$25)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($14)|0);
   STACKTOP = sp;return;
  }
 }
 $28 = ___cxa_find_matching_catch_2()|0;
 $29 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($1|0));
 $30 = __THREW__; __THREW__ = 0;
 $31 = $30&1;
 if ($31) {
  $32 = ___cxa_find_matching_catch_3(0|0)|0;
  $33 = tempRet0;
  ___clang_call_terminate($32);
  // unreachable;
 } else {
  ___resumeException($28|0);
  // unreachable;
 }
}
function __ZN9osgViewer4View23requestContinuousUpdateEb($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = ((($0)) + 40|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if (!($5)) {
  $6 = ((($4)) + 24|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)==(0|0);
  if (!($8)) {
   $9 = ((($0)) + 44|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($10|0)==(0|0);
   if (!($11)) {
    $12 = $1&1;
    $13 = ((($10)) + 34|0);
    HEAP8[$13>>0] = $12;
    STACKTOP = sp;return;
   }
  }
 }
 $14 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
 if (!($14)) {
  STACKTOP = sp;return;
 }
 $15 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
 $16 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($15,102456,70)|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ((($17)) + -12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($16) + ($19)|0);
 __ZNKSt3__28ios_base6getlocEv($2,$20);
 __THREW__ = 0;
 $21 = (invoke_iii(3255,($2|0),(215188|0))|0);
 $22 = __THREW__; __THREW__ = 0;
 $23 = $22&1;
 if (!($23)) {
  $24 = HEAP32[$21>>2]|0;
  $25 = ((($24)) + 28|0);
  $26 = HEAP32[$25>>2]|0;
  __THREW__ = 0;
  $27 = (invoke_iii($26|0,($21|0),10)|0);
  $28 = __THREW__; __THREW__ = 0;
  $29 = $28&1;
  if (!($29)) {
   __ZNSt3__26localeD2Ev($2);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($16,$27)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($16)|0);
   STACKTOP = sp;return;
  }
 }
 $30 = ___cxa_find_matching_catch_2()|0;
 $31 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($2|0));
 $32 = __THREW__; __THREW__ = 0;
 $33 = $32&1;
 if ($33) {
  $34 = ___cxa_find_matching_catch_3(0|0)|0;
  $35 = tempRet0;
  ___clang_call_terminate($34);
  // unreachable;
 } else {
  ___resumeException($30|0);
  // unreachable;
 }
}
function __ZN9osgViewer4View18requestWarpPointerEff($0,$1,$2) {
 $0 = $0|0;
 $1 = +$1;
 $2 = +$2;
 var $$pre = 0.0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0.0, $54 = 0.0, $55 = 0.0, $56 = 0.0, $57 = 0.0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp + 12|0;
 $4 = sp + 8|0;
 $5 = sp + 4|0;
 $6 = sp;
 $7 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
 do {
  if ($7) {
   $8 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
   $9 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($8,102347,25)|0);
   $10 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEf($9,$1)|0);
   $11 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($10,155405,1)|0);
   $12 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEf($11,$2)|0);
   $13 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($12,174996,1)|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = ((($14)) + -12|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (($13) + ($16)|0);
   __ZNKSt3__28ios_base6getlocEv($4,$17);
   __THREW__ = 0;
   $18 = (invoke_iii(3255,($4|0),(215188|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    $21 = HEAP32[$18>>2]|0;
    $22 = ((($21)) + 28|0);
    $23 = HEAP32[$22>>2]|0;
    __THREW__ = 0;
    $24 = (invoke_iii($23|0,($18|0),10)|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     __ZNSt3__26localeD2Ev($4);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($13,$24)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($13)|0);
     break;
    }
   }
   $27 = ___cxa_find_matching_catch_2()|0;
   $28 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($4|0));
   $29 = __THREW__; __THREW__ = 0;
   $30 = $29&1;
   if ($30) {
    $31 = ___cxa_find_matching_catch_3(0|0)|0;
    $32 = tempRet0;
    ___clang_call_terminate($31);
    // unreachable;
   } else {
    ___resumeException($27|0);
    // unreachable;
   }
  }
 } while(0);
 $33 = (__ZNK9osgViewer4View27getCameraContainingPositionEffRfS1_($0,$1,$2,$5,$6)|0);
 $34 = ($33|0)==(0|0);
 if ($34) {
  $61 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
  if (!($61)) {
   STACKTOP = sp;return;
  }
  $62 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
  $63 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($62,102373,60)|0);
  $64 = HEAP32[$63>>2]|0;
  $65 = ((($64)) + -12|0);
  $66 = HEAP32[$65>>2]|0;
  $67 = (($63) + ($66)|0);
  __ZNKSt3__28ios_base6getlocEv($3,$67);
  __THREW__ = 0;
  $68 = (invoke_iii(3255,($3|0),(215188|0))|0);
  $69 = __THREW__; __THREW__ = 0;
  $70 = $69&1;
  if (!($70)) {
   $71 = HEAP32[$68>>2]|0;
   $72 = ((($71)) + 28|0);
   $73 = HEAP32[$72>>2]|0;
   __THREW__ = 0;
   $74 = (invoke_iii($73|0,($68|0),10)|0);
   $75 = __THREW__; __THREW__ = 0;
   $76 = $75&1;
   if (!($76)) {
    __ZNSt3__26localeD2Ev($3);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($63,$74)|0);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($63)|0);
    STACKTOP = sp;return;
   }
  }
  $77 = ___cxa_find_matching_catch_2()|0;
  $78 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3263,($3|0));
  $79 = __THREW__; __THREW__ = 0;
  $80 = $79&1;
  if ($80) {
   $81 = ___cxa_find_matching_catch_3(0|0)|0;
   $82 = tempRet0;
   ___clang_call_terminate($81);
   // unreachable;
  } else {
   ___resumeException($77|0);
   // unreachable;
  }
 } else {
  $35 = ((($33)) + 624|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = ($36|0)==(0|0);
  if ($37) {
   STACKTOP = sp;return;
  }
  $38 = (___dynamic_cast($36,24816,3888,0)|0);
  $39 = ($38|0)==(0|0);
  if ($39) {
   STACKTOP = sp;return;
  }
  $40 = ((($0)) + 72|0);
  $41 = HEAP32[$40>>2]|0;
  __ZN5osgGA10EventQueue11mouseWarpedEff($41,$1,$2);
  $42 = ((($38)) + 136|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = ((($43)) + 12|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = ((($45)) + 120|0);
  $47 = HEAP32[$46>>2]|0;
  $48 = ($47|0)==(1);
  if ($48) {
   $49 = ((($38)) + 44|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = ((($50)) + 44|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = (+($52|0));
   $54 = +HEAPF32[$6>>2];
   $55 = $53 - $54;
   HEAPF32[$6>>2] = $55;
   $57 = $55;
  } else {
   $$pre = +HEAPF32[$6>>2];
   $57 = $$pre;
  }
  $56 = +HEAPF32[$5>>2];
  __ZN5osgGA10EventQueue11mouseWarpedEff($43,$56,$57);
  $58 = HEAP32[$38>>2]|0;
  $59 = ((($58)) + 252|0);
  $60 = HEAP32[$59>>2]|0;
  FUNCTION_TABLE_vidd[$60 & 8191]($38,$56,$57);
  STACKTOP = sp;return;
 }
}
function __ZNK9osgViewer4View24requiresUpdateSceneGraphEv($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 84|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if (!($5)) {
  $$0 = 1;
  return ($$0|0);
 }
 $6 = ((($0)) + 68|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = ((($9)) + 16|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (FUNCTION_TABLE_ii[$11 & 8191]($7)|0);
  if ($12) {
   $$0 = 1;
   return ($$0|0);
  }
 }
 $$0 = 0;
 return ($$0|0);
}
function __ZNK9osgViewer4View14requiresRedrawEv($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 68|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = HEAP32[$2>>2]|0;
  $5 = ((($4)) + 24|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (FUNCTION_TABLE_ii[$6 & 8191]($2)|0);
  if ($7) {
   $$0 = 1;
   return ($$0|0);
  }
 }
 $$0 = 0;
 return ($$0|0);
}
function __ZThn36_N9osgViewer4ViewD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -36|0);
 __THREW__ = 0;
 invoke_vii(3272,($1|0),(35484|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  $11 = ((($1)) + 132|0);
  __ZN3osg6ObjectD2Ev($11);
  return;
 }
 $4 = ___cxa_find_matching_catch_2()|0;
 $5 = tempRet0;
 $6 = ((($1)) + 132|0);
 __THREW__ = 0;
 invoke_vi(388,($6|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch_3(0|0)|0;
  $10 = tempRet0;
  ___clang_call_terminate($9);
  // unreachable;
 } else {
  ___resumeException($4|0);
  // unreachable;
 }
}
function __ZThn36_N9osgViewer4ViewD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$i$index2Z2D = 0, $eh$lpad$body$i$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -36|0);
 __THREW__ = 0;
 invoke_vii(3272,($1|0),(35484|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $7 = ___cxa_find_matching_catch_2()|0;
  $8 = tempRet0;
  $9 = ((($1)) + 132|0);
  __THREW__ = 0;
  invoke_vi(388,($9|0));
  $10 = __THREW__; __THREW__ = 0;
  $11 = $10&1;
  if ($11) {
   $12 = ___cxa_find_matching_catch_3(0|0)|0;
   $13 = tempRet0;
   ___clang_call_terminate($12);
   // unreachable;
  } else {
   $eh$lpad$body$i$index2Z2D = $8;$eh$lpad$body$i$indexZ2D = $7;
   __ZdlPv($1);
   ___resumeException($eh$lpad$body$i$indexZ2D|0);
   // unreachable;
  }
 }
 $4 = ((($1)) + 132|0);
 __THREW__ = 0;
 invoke_vi(388,($4|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if (!($6)) {
  __ZdlPv($1);
  return;
 }
 $14 = ___cxa_find_matching_catch_2()|0;
 $15 = tempRet0;
 $eh$lpad$body$i$index2Z2D = $15;$eh$lpad$body$i$indexZ2D = $14;
 __ZdlPv($1);
 ___resumeException($eh$lpad$body$i$indexZ2D|0);
 // unreachable;
}
function __ZThn36_N9osgViewer4View6asViewEv($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -36|0);
 return ($1|0);
}
function __ZThn36_N9osgViewer4View13requestRedrawEv($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -36|0);
 __ZN9osgViewer4View13requestRedrawEv($1);
 return;
}
function __ZThn36_N9osgViewer4View23requestContinuousUpdateEb($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + -36|0);
 __ZN9osgViewer4View23requestContinuousUpdateEb($2,$1);
 return;
}
function __ZThn36_N9osgViewer4View18requestWarpPointerEff($0,$1,$2) {
 $0 = $0|0;
 $1 = +$1;
 $2 = +$2;
 var $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + -36|0);
 __ZN9osgViewer4View18requestWarpPointerEff($3,$1,$2);
 return;
}
function __ZThn36_N9osgViewer4View20computeIntersectionsERKN5osgGA15GUIEventAdapterERNSt3__28multisetIN7osgUtil22LineSegmentIntersector12IntersectionENS5_4lessIS9_EENS5_9allocatorIS9_EEEEj($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ((($0)) + -36|0);
 $5 = (__ZN9osgViewer4View20computeIntersectionsERKN5osgGA15GUIEventAdapterERNSt3__28multisetIN7osgUtil22LineSegmentIntersector12IntersectionENS5_4lessIS9_EENS5_9allocatorIS9_EEEEj($4,$1,$2,$3)|0);
 return ($5|0);
}
function __ZThn36_N9osgViewer4View20computeIntersectionsERKN5osgGA15GUIEventAdapterERKNSt3__26vectorIPN3osg4NodeENS5_9allocatorIS9_EEEERNS5_8multisetIN7osgUtil22LineSegmentIntersector12IntersectionENS5_4lessISI_EENSA_ISI_EEEEj($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = ((($0)) + -36|0);
 $6 = (__ZN9osgViewer4View20computeIntersectionsERKN5osgGA15GUIEventAdapterERKNSt3__26vectorIPN3osg4NodeENS5_9allocatorIS9_EEEERNS5_8multisetIN7osgUtil22LineSegmentIntersector12IntersectionENS5_4lessISI_EENSA_ISI_EEEEj($5,$1,$2,$3,$4)|0);
 return ($6|0);
}
function __ZTv0_n16_N9osgViewer4ViewD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __THREW__ = 0;
 invoke_vii(3272,($4|0),(35484|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if (!($6)) {
  $14 = ((($4)) + 132|0);
  __ZN3osg6ObjectD2Ev($14);
  return;
 }
 $7 = ___cxa_find_matching_catch_2()|0;
 $8 = tempRet0;
 $9 = ((($4)) + 132|0);
 __THREW__ = 0;
 invoke_vi(388,($9|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if ($11) {
  $12 = ___cxa_find_matching_catch_3(0|0)|0;
  $13 = tempRet0;
  ___clang_call_terminate($12);
  // unreachable;
 } else {
  ___resumeException($7|0);
  // unreachable;
 }
}
function __ZTv0_n16_N9osgViewer4ViewD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$i$index2Z2D = 0, $eh$lpad$body$i$indexZ2D = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __THREW__ = 0;
 invoke_vii(3272,($4|0),(35484|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $10 = ___cxa_find_matching_catch_2()|0;
  $11 = tempRet0;
  $12 = ((($4)) + 132|0);
  __THREW__ = 0;
  invoke_vi(388,($12|0));
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if ($14) {
   $15 = ___cxa_find_matching_catch_3(0|0)|0;
   $16 = tempRet0;
   ___clang_call_terminate($15);
   // unreachable;
  } else {
   $eh$lpad$body$i$index2Z2D = $11;$eh$lpad$body$i$indexZ2D = $10;
   __ZdlPv($4);
   ___resumeException($eh$lpad$body$i$indexZ2D|0);
   // unreachable;
  }
 }
 $7 = ((($4)) + 132|0);
 __THREW__ = 0;
 invoke_vi(388,($7|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if (!($9)) {
  __ZdlPv($4);
  return;
 }
 $17 = ___cxa_find_matching_catch_2()|0;
 $18 = tempRet0;
 $eh$lpad$body$i$index2Z2D = $18;$eh$lpad$body$i$indexZ2D = $17;
 __ZdlPv($4);
 ___resumeException($eh$lpad$body$i$indexZ2D|0);
 // unreachable;
}
function __ZTv0_n20_NK9osgViewer4View9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(168)|0);
 __THREW__ = 0;
 invoke_vi(3270,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch_2()|0;
  $5 = tempRet0;
  __ZdlPv($1);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $6 = HEAP32[$1>>2]|0;
  $7 = ((($6)) + -12|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($1) + ($8)|0);
  return ($9|0);
 }
 return (0)|0;
}
function __ZTv0_n24_NK9osgViewer4View5cloneERKN3osg6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $3 = ((($2)) + -24|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($0) + ($4)|0);
 $6 = (__Znwj(168)|0);
 __THREW__ = 0;
 invoke_viii(3271,($6|0),($5|0),($1|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch_2()|0;
  $10 = tempRet0;
  __ZdlPv($6);
  ___resumeException($9|0);
  // unreachable;
 } else {
  $11 = HEAP32[$6>>2]|0;
  $12 = ((($11)) + -12|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($6) + ($13)|0);
  return ($14|0);
 }
 return (0)|0;
}
function __ZTv0_n28_NK9osgViewer4View12isSameKindAsEPKN3osg6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,3928,-1)|0);
 $phitmp$i = ($3|0)!=(0|0);
 $4 = $phitmp$i;
 return ($4|0);
}
function __ZTv0_n32_NK9osgViewer4View11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (107921|0);
}
function __ZTv0_n36_NK9osgViewer4View9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (102314|0);
}
function __ZN9osgViewer4ViewC1ERKS0_RKN3osg6CopyOpE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$023$i$i = 0, $$110 = 0, $$112 = 0, $$2 = 0, $$213 = 0, $$6 = 0, $$617 = 0, $$pre$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0;
 var $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0;
 var $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0;
 var $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0;
 var $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = ((($0)) + 132|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = ((($5)) + -12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($1) + ($7)|0);
 __ZN3osg6ObjectC2ERKS0_RKNS_6CopyOpE($4,$8,$2);
 __THREW__ = 0;
 invoke_viiii(3290,($0|0),((35488)|0),($1|0),($2|0));
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if ($10) {
  $111 = ___cxa_find_matching_catch_2()|0;
  $112 = tempRet0;
  $$6 = $112;$$617 = $111;
 } else {
  $11 = ((($0)) + 36|0);
  HEAP32[$0>>2] = (35084);
  HEAP32[$4>>2] = (35344);
  HEAP32[$11>>2] = (35168);
  $12 = ((($0)) + 40|0);
  $13 = ((($0)) + 56|0);
  $14 = ((($0)) + 60|0);
  $15 = ((($0)) + 68|0);
  $16 = ((($0)) + 72|0);
  $17 = ((($0)) + 76|0);
  $18 = ((($0)) + 80|0);
  dest=$12; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
  HEAP32[$18>>2] = $18;
  $19 = ((($0)) + 84|0);
  HEAP32[$19>>2] = $18;
  $20 = ((($0)) + 88|0);
  HEAP32[$20>>2] = 0;
  $21 = ((($0)) + 92|0);
  __THREW__ = 0;
  invoke_vi(3291,($21|0));
  $22 = __THREW__; __THREW__ = 0;
  $23 = $22&1;
  if ($23) {
   $113 = ___cxa_find_matching_catch_2()|0;
   $114 = tempRet0;
   $$2 = $114;$$213 = $113;
  } else {
   $24 = ((($0)) + 116|0);
   HEAP32[$24>>2] = 0;
   $25 = ((($0)) + 120|0);
   $26 = ((($1)) + 120|0);
   $27 = HEAP32[$26>>2]|0;
   HEAP32[$25>>2] = $27;
   $28 = ((($0)) + 124|0);
   $29 = ((($1)) + 124|0);
   $30 = HEAP32[$29>>2]|0;
   HEAP32[$28>>2] = $30;
   $31 = ((($0)) + 128|0);
   HEAP32[$31>>2] = 0;
   __THREW__ = 0;
   $32 = (invoke_ii(3276,24)|0);
   $33 = __THREW__; __THREW__ = 0;
   $34 = $33&1;
   do {
    if ($34) {
     label = 33;
    } else {
     __THREW__ = 0;
     invoke_vi(3277,($32|0));
     $35 = __THREW__; __THREW__ = 0;
     $36 = $35&1;
     if ($36) {
      $117 = ___cxa_find_matching_catch_2()|0;
      $118 = tempRet0;
      __ZdlPv($32);
      $$110 = $118;$$112 = $117;
      break;
     }
     $37 = HEAP32[$15>>2]|0;
     $38 = ($37|0)==($32|0);
     if (!($38)) {
      HEAP32[$15>>2] = $32;
      $39 = ((($32)) + 8|0);
      $40 = HEAP32[$39>>2]|0;HEAP32[$39>>2] = (($40+1)|0);
      $41 = ($37|0)==(0|0);
      if (!($41)) {
       $42 = ((($37)) + 8|0);
       $43 = HEAP32[$42>>2]|0;HEAP32[$42>>2] = (($43-1)|0);
       $44 = ($43|0)==(1);
       if ($44) {
        __THREW__ = 0;
        invoke_viii(3262,($37|0),1,1);
        $45 = __THREW__; __THREW__ = 0;
        $46 = $45&1;
        if ($46) {
         label = 33;
         break;
        }
       }
      }
     }
     $47 = ((($0)) + 16|0);
     $48 = HEAP32[$47>>2]|0;
     $49 = HEAP32[$0>>2]|0;
     $50 = ((($49)) + 32|0);
     $51 = HEAP32[$50>>2]|0;
     __THREW__ = 0;
     $52 = (invoke_iii($51|0,($0|0),($48|0))|0);
     $53 = __THREW__; __THREW__ = 0;
     $54 = $53&1;
     if ($54) {
      label = 33;
     } else {
      $55 = ((($48)) + 628|0);
      $56 = HEAP32[$55>>2]|0;
      $57 = ($56|0)==($52|0);
      if (!($57)) {
       HEAP32[$55>>2] = $52;
       $58 = ($52|0)==(0|0);
       if (!($58)) {
        $59 = HEAP32[$52>>2]|0;
        $60 = ((($59)) + -12|0);
        $61 = HEAP32[$60>>2]|0;
        $62 = (($52) + ($61)|0);
        $63 = ((($62)) + 8|0);
        $64 = HEAP32[$63>>2]|0;HEAP32[$63>>2] = (($64+1)|0);
       }
       $65 = ($56|0)==(0|0);
       if (!($65)) {
        $66 = HEAP32[$56>>2]|0;
        $67 = ((($66)) + -12|0);
        $68 = HEAP32[$67>>2]|0;
        $69 = (($56) + ($68)|0);
        $70 = ((($69)) + 8|0);
        $71 = HEAP32[$70>>2]|0;HEAP32[$70>>2] = (($71-1)|0);
        $72 = ($71|0)==(1);
        if ($72) {
         __THREW__ = 0;
         invoke_viii(3262,($69|0),1,1);
         $73 = __THREW__; __THREW__ = 0;
         $74 = $73&1;
         if ($74) {
          label = 33;
          break;
         }
        }
       }
      }
      __THREW__ = 0;
      $75 = (invoke_ii(3276,64)|0);
      $76 = __THREW__; __THREW__ = 0;
      $77 = $76&1;
      if ($77) {
       label = 33;
      } else {
       __THREW__ = 0;
       invoke_vii(3292,($75|0),1);
       $78 = __THREW__; __THREW__ = 0;
       $79 = $78&1;
       if ($79) {
        $119 = ___cxa_find_matching_catch_2()|0;
        $120 = tempRet0;
        __ZdlPv($75);
        $$110 = $120;$$112 = $119;
        break;
       }
       $80 = HEAP32[$16>>2]|0;
       $81 = ($80|0)==($75|0);
       if (!($81)) {
        HEAP32[$16>>2] = $75;
        $82 = ((($75)) + 8|0);
        $83 = HEAP32[$82>>2]|0;HEAP32[$82>>2] = (($83+1)|0);
        $84 = ($80|0)==(0|0);
        if (!($84)) {
         $85 = ((($80)) + 8|0);
         $86 = HEAP32[$85>>2]|0;HEAP32[$85>>2] = (($86-1)|0);
         $87 = ($86|0)==(1);
         if ($87) {
          __THREW__ = 0;
          invoke_viii(3262,($80|0),1,1);
          $88 = __THREW__; __THREW__ = 0;
          $89 = $88&1;
          if ($89) {
           label = 33;
           break;
          }
         }
        }
       }
       __THREW__ = 0;
       $90 = (invoke_ii(3276,80)|0);
       $91 = __THREW__; __THREW__ = 0;
       $92 = $91&1;
       if ($92) {
        label = 33;
       } else {
        ;HEAP32[$3>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;
        $93 = ((($3)) + 11|0);
        HEAP8[$93>>0] = 4;
        HEAP32[$3>>2] = 2003134806;
        $94 = ((($3)) + 4|0);
        HEAP8[$94>>0] = 0;
        __THREW__ = 0;
        invoke_vii(3274,($90|0),($3|0));
        $95 = __THREW__; __THREW__ = 0;
        $96 = $95&1;
        do {
         if ($96) {
          $$0 = 1;
         } else {
          $97 = ((($0)) + 4|0);
          $98 = HEAP32[$97>>2]|0;
          $99 = ($98|0)==($90|0);
          if (!($99)) {
           HEAP32[$97>>2] = $90;
           $100 = ((($90)) + 8|0);
           $101 = HEAP32[$100>>2]|0;HEAP32[$100>>2] = (($101+1)|0);
           $102 = ($98|0)==(0|0);
           if (!($102)) {
            $103 = ((($98)) + 8|0);
            $104 = HEAP32[$103>>2]|0;HEAP32[$103>>2] = (($104-1)|0);
            $105 = ($104|0)==(1);
            if ($105) {
             __THREW__ = 0;
             invoke_viii(3262,($98|0),1,1);
             $106 = __THREW__; __THREW__ = 0;
             $107 = $106&1;
             if ($107) {
              $$0 = 0;
              break;
             }
            }
           }
          }
          $108 = HEAP8[$93>>0]|0;
          $109 = ($108<<24>>24)<(0);
          if (!($109)) {
           STACKTOP = sp;return;
          }
          $110 = HEAP32[$3>>2]|0;
          __ZdlPv($110);
          STACKTOP = sp;return;
         }
        } while(0);
        $121 = ___cxa_find_matching_catch_2()|0;
        $122 = tempRet0;
        $123 = HEAP8[$93>>0]|0;
        $124 = ($123<<24>>24)<(0);
        if ($124) {
         $125 = HEAP32[$3>>2]|0;
         __ZdlPv($125);
         if (!($$0)) {
          $$110 = $122;$$112 = $121;
          break;
         }
        } else {
         if (!($$0)) {
          $$110 = $122;$$112 = $121;
          break;
         }
        }
        __ZdlPv($90);
        $$110 = $122;$$112 = $121;
       }
      }
     }
    }
   } while(0);
   if ((label|0) == 33) {
    $115 = ___cxa_find_matching_catch_2()|0;
    $116 = tempRet0;
    $$110 = $116;$$112 = $115;
   }
   $126 = HEAP32[$31>>2]|0;
   $127 = ($126|0)==(0|0);
   if (!($127)) {
    $128 = ((($126)) + 8|0);
    $129 = HEAP32[$128>>2]|0;HEAP32[$128>>2] = (($129-1)|0);
    $130 = ($129|0)==(1);
    if ($130) {
     __THREW__ = 0;
     invoke_viii(3262,($126|0),1,1);
     $131 = __THREW__; __THREW__ = 0;
     $132 = $131&1;
     if ($132) {
      $223 = ___cxa_find_matching_catch_3(0|0)|0;
      $224 = tempRet0;
      ___clang_call_terminate($223);
      // unreachable;
     }
    }
   }
   HEAP32[$31>>2] = 0;
   $133 = HEAP32[$24>>2]|0;
   $134 = ($133|0)==(0|0);
   if (!($134)) {
    $135 = ((($133)) + 8|0);
    $136 = HEAP32[$135>>2]|0;HEAP32[$135>>2] = (($136-1)|0);
    $137 = ($136|0)==(1);
    if ($137) {
     __THREW__ = 0;
     invoke_viii(3262,($133|0),1,1);
     $138 = __THREW__; __THREW__ = 0;
     $139 = $138&1;
     if ($139) {
      $223 = ___cxa_find_matching_catch_3(0|0)|0;
      $224 = tempRet0;
      ___clang_call_terminate($223);
      // unreachable;
     }
    }
   }
   HEAP32[$24>>2] = 0;
   __THREW__ = 0;
   invoke_vi(3293,($21|0));
   $140 = __THREW__; __THREW__ = 0;
   $141 = $140&1;
   if ($141) {
    $223 = ___cxa_find_matching_catch_3(0|0)|0;
    $224 = tempRet0;
    ___clang_call_terminate($223);
    // unreachable;
   } else {
    $$2 = $$110;$$213 = $$112;
   }
  }
  $142 = HEAP32[$20>>2]|0;
  $143 = ($142|0)==(0);
  L67: do {
   if (!($143)) {
    $144 = HEAP32[$19>>2]|0;
    $145 = HEAP32[$18>>2]|0;
    $146 = ((($145)) + 4|0);
    $147 = HEAP32[$146>>2]|0;
    $148 = HEAP32[$144>>2]|0;
    $149 = ((($148)) + 4|0);
    HEAP32[$149>>2] = $147;
    $150 = HEAP32[$146>>2]|0;
    HEAP32[$150>>2] = $148;
    HEAP32[$20>>2] = 0;
    $151 = ($144|0)==($18|0);
    if (!($151)) {
     $$023$i$i = $144;
     while(1) {
      $152 = ((($$023$i$i)) + 4|0);
      $153 = HEAP32[$152>>2]|0;
      $154 = ((($$023$i$i)) + 8|0);
      $155 = HEAP32[$154>>2]|0;
      $156 = ($155|0)==(0|0);
      if (!($156)) {
       $157 = HEAP32[$155>>2]|0;
       $158 = ((($157)) + -16|0);
       $159 = HEAP32[$158>>2]|0;
       $160 = (($155) + ($159)|0);
       $161 = ((($160)) + 8|0);
       $162 = HEAP32[$161>>2]|0;HEAP32[$161>>2] = (($162-1)|0);
       $163 = ($162|0)==(1);
       if ($163) {
        __THREW__ = 0;
        invoke_viii(3262,($160|0),1,1);
        $164 = __THREW__; __THREW__ = 0;
        $165 = $164&1;
        if ($165) {
         break;
        }
       }
      }
      __ZdlPv($$023$i$i);
      $166 = ($153|0)==($18|0);
      if ($166) {
       break L67;
      } else {
       $$023$i$i = $153;
      }
     }
     $167 = ___cxa_find_matching_catch_2()|0;
     $168 = tempRet0;
     ___cxa_call_unexpected(($167|0));
     // unreachable;
    }
   }
  } while(0);
  $169 = HEAP32[$17>>2]|0;
  $170 = ($169|0)==(0|0);
  if (!($170)) {
   $171 = HEAP32[$169>>2]|0;
   $172 = ((($171)) + -16|0);
   $173 = HEAP32[$172>>2]|0;
   $174 = (($169) + ($173)|0);
   $175 = ((($174)) + 8|0);
   $176 = HEAP32[$175>>2]|0;HEAP32[$175>>2] = (($176-1)|0);
   $177 = ($176|0)==(1);
   if ($177) {
    __THREW__ = 0;
    invoke_viii(3262,($174|0),1,1);
    $178 = __THREW__; __THREW__ = 0;
    $179 = $178&1;
    if ($179) {
     $223 = ___cxa_find_matching_catch_3(0|0)|0;
     $224 = tempRet0;
     ___clang_call_terminate($223);
     // unreachable;
    }
   }
  }
  HEAP32[$17>>2] = 0;
  $180 = HEAP32[$16>>2]|0;
  $181 = ($180|0)==(0|0);
  if (!($181)) {
   $182 = ((($180)) + 8|0);
   $183 = HEAP32[$182>>2]|0;HEAP32[$182>>2] = (($183-1)|0);
   $184 = ($183|0)==(1);
   if ($184) {
    __THREW__ = 0;
    invoke_viii(3262,($180|0),1,1);
    $185 = __THREW__; __THREW__ = 0;
    $186 = $185&1;
    if ($186) {
     $223 = ___cxa_find_matching_catch_3(0|0)|0;
     $224 = tempRet0;
     ___clang_call_terminate($223);
     // unreachable;
    }
   }
  }
  HEAP32[$16>>2] = 0;
  $187 = HEAP32[$15>>2]|0;
  $188 = ($187|0)==(0|0);
  if (!($188)) {
   $189 = ((($187)) + 8|0);
   $190 = HEAP32[$189>>2]|0;HEAP32[$189>>2] = (($190-1)|0);
   $191 = ($190|0)==(1);
   if ($191) {
    __THREW__ = 0;
    invoke_viii(3262,($187|0),1,1);
    $192 = __THREW__; __THREW__ = 0;
    $193 = $192&1;
    if ($193) {
     $223 = ___cxa_find_matching_catch_3(0|0)|0;
     $224 = tempRet0;
     ___clang_call_terminate($223);
     // unreachable;
    }
   }
  }
  HEAP32[$15>>2] = 0;
  $194 = HEAP32[$13>>2]|0;
  $195 = ($194|0)==(0|0);
  if (!($195)) {
   $196 = HEAP32[$14>>2]|0;
   $197 = ($196|0)==($194|0);
   do {
    if ($197) {
     $211 = $194;
    } else {
     $199 = $196;
     while(1) {
      $198 = ((($199)) + -4|0);
      HEAP32[$14>>2] = $198;
      $200 = HEAP32[$198>>2]|0;
      $201 = ($200|0)==(0|0);
      if (!($201)) {
       $202 = ((($200)) + 8|0);
       $203 = HEAP32[$202>>2]|0;HEAP32[$202>>2] = (($203-1)|0);
       $204 = ($203|0)==(1);
       if ($204) {
        __THREW__ = 0;
        invoke_viii(3262,($200|0),1,1);
        $205 = __THREW__; __THREW__ = 0;
        $206 = $205&1;
        if ($206) {
         label = 69;
         break;
        }
       }
      }
      HEAP32[$198>>2] = 0;
      $207 = HEAP32[$14>>2]|0;
      $208 = ($207|0)==($194|0);
      if ($208) {
       label = 70;
       break;
      } else {
       $199 = $207;
      }
     }
     if ((label|0) == 69) {
      $209 = ___cxa_find_matching_catch_2()|0;
      $210 = tempRet0;
      ___cxa_call_unexpected(($209|0));
      // unreachable;
     }
     else if ((label|0) == 70) {
      $$pre$i = HEAP32[$13>>2]|0;
      $211 = $$pre$i;
      break;
     }
    }
   } while(0);
   __ZdlPv($211);
  }
  $212 = HEAP32[$12>>2]|0;
  $213 = ($212|0)==(0|0);
  if (!($213)) {
   $214 = ((($212)) + 8|0);
   $215 = HEAP32[$214>>2]|0;HEAP32[$214>>2] = (($215-1)|0);
   $216 = ($215|0)==(1);
   if ($216) {
    __THREW__ = 0;
    invoke_viii(3262,($212|0),1,1);
    $217 = __THREW__; __THREW__ = 0;
    $218 = $217&1;
    if ($218) {
     $223 = ___cxa_find_matching_catch_3(0|0)|0;
     $224 = tempRet0;
     ___clang_call_terminate($223);
     // unreachable;
    }
   }
  }
  HEAP32[$12>>2] = 0;
  __THREW__ = 0;
  invoke_vii(3294,($0|0),((35488)|0));
  $219 = __THREW__; __THREW__ = 0;
  $220 = $219&1;
  if ($220) {
   $223 = ___cxa_find_matching_catch_3(0|0)|0;
   $224 = tempRet0;
   ___clang_call_terminate($223);
   // unreachable;
  } else {
   $$6 = $$2;$$617 = $$213;
  }
 }
 __THREW__ = 0;
 invoke_vi(388,($4|0));
 $221 = __THREW__; __THREW__ = 0;
 $222 = $221&1;
 if ($222) {
  $223 = ___cxa_find_matching_catch_3(0|0)|0;
  $224 = tempRet0;
  ___clang_call_terminate($223);
  // unreachable;
 } else {
  ___resumeException($$617|0);
  // unreachable;
 }
}
function __ZNK3osg4View9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(68)|0);
 __THREW__ = 0;
 invoke_vi(3295,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $8 = ___cxa_find_matching_catch_2()|0;
  $9 = tempRet0;
  __ZdlPv($1);
  ___resumeException($8|0);
  // unreachable;
 } else {
  $4 = HEAP32[$1>>2]|0;
  $5 = ((($4)) + -12|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($1) + ($6)|0);
  return ($7|0);
 }
 return (0)|0;
}
function __ZNK3osg4View5cloneERKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(68)|0);
 __THREW__ = 0;
 invoke_viii(3296,($2|0),($0|0),($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $9 = ___cxa_find_matching_catch_2()|0;
  $10 = tempRet0;
  __ZdlPv($2);
  ___resumeException($9|0);
  // unreachable;
 } else {
  $5 = HEAP32[$2>>2]|0;
  $6 = ((($5)) + -12|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($2) + ($7)|0);
  return ($8|0);
 }
 return (0)|0;
}
function __ZNK3osg4View12isSameKindAsEPKNS_6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,27072,-1)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK3osg4View11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175113|0);
}
function __ZNK3osg4View9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (102314|0);
}
function __ZN3osg4View14createRendererEPNS_6CameraE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZTv0_n20_NK3osg4View9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(68)|0);
 __THREW__ = 0;
 invoke_vi(3295,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch_2()|0;
  $5 = tempRet0;
  __ZdlPv($1);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $6 = HEAP32[$1>>2]|0;
  $7 = ((($6)) + -12|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($1) + ($8)|0);
  return ($9|0);
 }
 return (0)|0;
}
function __ZTv0_n24_NK3osg4View5cloneERKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $3 = ((($2)) + -24|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($0) + ($4)|0);
 $6 = (__Znwj(68)|0);
 __THREW__ = 0;
 invoke_viii(3296,($6|0),($5|0),($1|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch_2()|0;
  $10 = tempRet0;
  __ZdlPv($6);
  ___resumeException($9|0);
  // unreachable;
 } else {
  $11 = HEAP32[$6>>2]|0;
  $12 = ((($11)) + -12|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($6) + ($13)|0);
  return ($14|0);
 }
 return (0)|0;
}
function __ZTv0_n28_NK3osg4View12isSameKindAsEPKNS_6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,27072,-1)|0);
 $phitmp$i = ($3|0)!=(0|0);
 $4 = $phitmp$i;
 return ($4|0);
}
function __ZTv0_n32_NK3osg4View11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175113|0);
}
function __ZTv0_n36_NK3osg4View9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (102314|0);
}
function __ZN9osgViewer4ViewC1Ev($0) {
 $0 = $0|0;
 var $$0 = 0, $$023$i$i = 0, $$14 = 0, $$16 = 0, $$2 = 0, $$27 = 0, $$6 = 0, $$611 = 0, $$pre$i = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0;
 var $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0;
 var $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0;
 var $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0;
 var $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0;
 var $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $2 = ((($0)) + 132|0);
 __ZN3osg10ReferencedC2Ev($2);
 HEAP32[$2>>2] = (63412);
 $3 = ((($0)) + 144|0);
 ;HEAP32[$3>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;
 $4 = ((($0)) + 156|0);
 HEAP32[$4>>2] = 2;
 $5 = ((($0)) + 160|0);
 HEAP32[$5>>2] = 0;
 __THREW__ = 0;
 invoke_vii(3297,($0|0),((35488)|0));
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if ($7) {
  $136 = ___cxa_find_matching_catch_2()|0;
  $137 = tempRet0;
  $$6 = $137;$$611 = $136;
 } else {
  $8 = ((($0)) + 36|0);
  HEAP32[$0>>2] = (35084);
  HEAP32[$2>>2] = (35344);
  HEAP32[$8>>2] = (35168);
  $9 = ((($0)) + 40|0);
  HEAP32[$9>>2] = 0;
  $10 = ((($0)) + 44|0);
  HEAP32[$10>>2] = 0;
  $11 = ((($0)) + 56|0);
  $12 = ((($0)) + 60|0);
  $13 = ((($0)) + 68|0);
  $14 = ((($0)) + 72|0);
  $15 = ((($0)) + 76|0);
  $16 = ((($0)) + 80|0);
  ;HEAP32[$11>>2]=0|0;HEAP32[$11+4>>2]=0|0;HEAP32[$11+8>>2]=0|0;HEAP32[$11+12>>2]=0|0;HEAP32[$11+16>>2]=0|0;HEAP32[$11+20>>2]=0|0;
  HEAP32[$16>>2] = $16;
  $17 = ((($0)) + 84|0);
  HEAP32[$17>>2] = $16;
  $18 = ((($0)) + 88|0);
  HEAP32[$18>>2] = 0;
  $19 = ((($0)) + 92|0);
  __THREW__ = 0;
  invoke_vi(3291,($19|0));
  $20 = __THREW__; __THREW__ = 0;
  $21 = $20&1;
  if ($21) {
   $138 = ___cxa_find_matching_catch_2()|0;
   $139 = tempRet0;
   $$2 = $139;$$27 = $138;
  } else {
   $22 = ((($0)) + 116|0);
   HEAP32[$22>>2] = 0;
   $23 = ((($0)) + 120|0);
   HEAP32[$23>>2] = 1;
   $24 = ((($0)) + 124|0);
   HEAPF32[$24>>2] = 1.0;
   $25 = ((($0)) + 128|0);
   HEAP32[$25>>2] = 0;
   $26 = ((($0)) + 48|0);
   $27 = $26;
   $28 = $27;
   HEAP32[$28>>2] = 0;
   $29 = (($27) + 4)|0;
   $30 = $29;
   HEAP32[$30>>2] = 0;
   __THREW__ = 0;
   $31 = (invoke_ii(3276,72)|0);
   $32 = __THREW__; __THREW__ = 0;
   $33 = $32&1;
   do {
    if ($33) {
     label = 40;
    } else {
     __THREW__ = 0;
     invoke_vi(3298,($31|0));
     $34 = __THREW__; __THREW__ = 0;
     $35 = $34&1;
     if ($35) {
      $142 = ___cxa_find_matching_catch_2()|0;
      $143 = tempRet0;
      __ZdlPv($31);
      $$14 = $143;$$16 = $142;
      break;
     }
     $36 = ((($0)) + 32|0);
     $37 = HEAP32[$36>>2]|0;
     $38 = ($37|0)==($31|0);
     if (!($38)) {
      HEAP32[$36>>2] = $31;
      $39 = ((($31)) + 8|0);
      $40 = HEAP32[$39>>2]|0;HEAP32[$39>>2] = (($40+1)|0);
      $41 = ($37|0)==(0|0);
      if (!($41)) {
       $42 = ((($37)) + 8|0);
       $43 = HEAP32[$42>>2]|0;HEAP32[$42>>2] = (($43-1)|0);
       $44 = ($43|0)==(1);
       if ($44) {
        __THREW__ = 0;
        invoke_viii(3262,($37|0),1,1);
        $45 = __THREW__; __THREW__ = 0;
        $46 = $45&1;
        if ($46) {
         label = 40;
         break;
        }
       }
      }
     }
     $47 = HEAP32[$36>>2]|0;
     $48 = ((($47)) + 12|0);
     ;HEAP32[$48>>2]=0|0;HEAP32[$48+4>>2]=0|0;HEAP32[$48+8>>2]=0|0;HEAP32[$48+12>>2]=0|0;HEAP32[$48+16>>2]=0|0;
     __THREW__ = 0;
     $49 = (invoke_ii(3276,24)|0);
     $50 = __THREW__; __THREW__ = 0;
     $51 = $50&1;
     if ($51) {
      label = 40;
     } else {
      __THREW__ = 0;
      invoke_vi(3277,($49|0));
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       $144 = ___cxa_find_matching_catch_2()|0;
       $145 = tempRet0;
       __ZdlPv($49);
       $$14 = $145;$$16 = $144;
       break;
      }
      $54 = HEAP32[$13>>2]|0;
      $55 = ($54|0)==($49|0);
      if (!($55)) {
       HEAP32[$13>>2] = $49;
       $56 = ((($49)) + 8|0);
       $57 = HEAP32[$56>>2]|0;HEAP32[$56>>2] = (($57+1)|0);
       $58 = ($54|0)==(0|0);
       if (!($58)) {
        $59 = ((($54)) + 8|0);
        $60 = HEAP32[$59>>2]|0;HEAP32[$59>>2] = (($60-1)|0);
        $61 = ($60|0)==(1);
        if ($61) {
         __THREW__ = 0;
         invoke_viii(3262,($54|0),1,1);
         $62 = __THREW__; __THREW__ = 0;
         $63 = $62&1;
         if ($63) {
          label = 40;
          break;
         }
        }
       }
      }
      $64 = HEAP32[$0>>2]|0;
      $65 = ((($64)) + -12|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = (($0) + ($66)|0);
      $68 = HEAP32[$67>>2]|0;
      $69 = HEAP32[$68>>2]|0;
      __THREW__ = 0;
      invoke_vii($69|0,($67|0),1);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 40;
      } else {
       $72 = ((($0)) + 16|0);
       $73 = HEAP32[$72>>2]|0;
       $74 = HEAP32[$0>>2]|0;
       $75 = ((($74)) + 32|0);
       $76 = HEAP32[$75>>2]|0;
       __THREW__ = 0;
       $77 = (invoke_iii($76|0,($0|0),($73|0))|0);
       $78 = __THREW__; __THREW__ = 0;
       $79 = $78&1;
       if ($79) {
        label = 40;
       } else {
        $80 = ((($73)) + 628|0);
        $81 = HEAP32[$80>>2]|0;
        $82 = ($81|0)==($77|0);
        if (!($82)) {
         HEAP32[$80>>2] = $77;
         $83 = ($77|0)==(0|0);
         if (!($83)) {
          $84 = HEAP32[$77>>2]|0;
          $85 = ((($84)) + -12|0);
          $86 = HEAP32[$85>>2]|0;
          $87 = (($77) + ($86)|0);
          $88 = ((($87)) + 8|0);
          $89 = HEAP32[$88>>2]|0;HEAP32[$88>>2] = (($89+1)|0);
         }
         $90 = ($81|0)==(0|0);
         if (!($90)) {
          $91 = HEAP32[$81>>2]|0;
          $92 = ((($91)) + -12|0);
          $93 = HEAP32[$92>>2]|0;
          $94 = (($81) + ($93)|0);
          $95 = ((($94)) + 8|0);
          $96 = HEAP32[$95>>2]|0;HEAP32[$95>>2] = (($96-1)|0);
          $97 = ($96|0)==(1);
          if ($97) {
           __THREW__ = 0;
           invoke_viii(3262,($94|0),1,1);
           $98 = __THREW__; __THREW__ = 0;
           $99 = $98&1;
           if ($99) {
            label = 40;
            break;
           }
          }
         }
        }
        __THREW__ = 0;
        $100 = (invoke_ii(3276,64)|0);
        $101 = __THREW__; __THREW__ = 0;
        $102 = $101&1;
        if ($102) {
         label = 40;
        } else {
         __THREW__ = 0;
         invoke_vii(3292,($100|0),1);
         $103 = __THREW__; __THREW__ = 0;
         $104 = $103&1;
         if ($104) {
          $146 = ___cxa_find_matching_catch_2()|0;
          $147 = tempRet0;
          __ZdlPv($100);
          $$14 = $147;$$16 = $146;
          break;
         }
         $105 = HEAP32[$14>>2]|0;
         $106 = ($105|0)==($100|0);
         if (!($106)) {
          HEAP32[$14>>2] = $100;
          $107 = ((($100)) + 8|0);
          $108 = HEAP32[$107>>2]|0;HEAP32[$107>>2] = (($108+1)|0);
          $109 = ($105|0)==(0|0);
          if (!($109)) {
           $110 = ((($105)) + 8|0);
           $111 = HEAP32[$110>>2]|0;HEAP32[$110>>2] = (($111-1)|0);
           $112 = ($111|0)==(1);
           if ($112) {
            __THREW__ = 0;
            invoke_viii(3262,($105|0),1,1);
            $113 = __THREW__; __THREW__ = 0;
            $114 = $113&1;
            if ($114) {
             label = 40;
             break;
            }
           }
          }
         }
         __THREW__ = 0;
         $115 = (invoke_ii(3276,80)|0);
         $116 = __THREW__; __THREW__ = 0;
         $117 = $116&1;
         if ($117) {
          label = 40;
         } else {
          ;HEAP32[$1>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;
          $118 = ((($1)) + 11|0);
          HEAP8[$118>>0] = 4;
          HEAP32[$1>>2] = 2003134806;
          $119 = ((($1)) + 4|0);
          HEAP8[$119>>0] = 0;
          __THREW__ = 0;
          invoke_vii(3274,($115|0),($1|0));
          $120 = __THREW__; __THREW__ = 0;
          $121 = $120&1;
          L46: do {
           if ($121) {
            $$0 = 1;
           } else {
            $122 = ((($0)) + 4|0);
            $123 = HEAP32[$122>>2]|0;
            $124 = ($123|0)==($115|0);
            do {
             if (!($124)) {
              HEAP32[$122>>2] = $115;
              $125 = ((($115)) + 8|0);
              $126 = HEAP32[$125>>2]|0;HEAP32[$125>>2] = (($126+1)|0);
              $127 = ($123|0)==(0|0);
              if ($127) {
               break;
              }
              $128 = ((($123)) + 8|0);
              $129 = HEAP32[$128>>2]|0;HEAP32[$128>>2] = (($129-1)|0);
              $130 = ($129|0)==(1);
              if (!($130)) {
               break;
              }
              __THREW__ = 0;
              invoke_viii(3262,($123|0),1,1);
              $131 = __THREW__; __THREW__ = 0;
              $132 = $131&1;
              if ($132) {
               $$0 = 0;
               break L46;
              }
             }
            } while(0);
            $133 = HEAP8[$118>>0]|0;
            $134 = ($133<<24>>24)<(0);
            if (!($134)) {
             STACKTOP = sp;return;
            }
            $135 = HEAP32[$1>>2]|0;
            __ZdlPv($135);
            STACKTOP = sp;return;
           }
          } while(0);
          $148 = ___cxa_find_matching_catch_2()|0;
          $149 = tempRet0;
          $150 = HEAP8[$118>>0]|0;
          $151 = ($150<<24>>24)<(0);
          if ($151) {
           $152 = HEAP32[$1>>2]|0;
           __ZdlPv($152);
           if (!($$0)) {
            $$14 = $149;$$16 = $148;
            break;
           }
          } else {
           if (!($$0)) {
            $$14 = $149;$$16 = $148;
            break;
           }
          }
          __ZdlPv($115);
          $$14 = $149;$$16 = $148;
         }
        }
       }
      }
     }
    }
   } while(0);
   if ((label|0) == 40) {
    $140 = ___cxa_find_matching_catch_2()|0;
    $141 = tempRet0;
    $$14 = $141;$$16 = $140;
   }
   $153 = HEAP32[$25>>2]|0;
   $154 = ($153|0)==(0|0);
   if (!($154)) {
    $155 = ((($153)) + 8|0);
    $156 = HEAP32[$155>>2]|0;HEAP32[$155>>2] = (($156-1)|0);
    $157 = ($156|0)==(1);
    if ($157) {
     __THREW__ = 0;
     invoke_viii(3262,($153|0),1,1);
     $158 = __THREW__; __THREW__ = 0;
     $159 = $158&1;
     if ($159) {
      $250 = ___cxa_find_matching_catch_3(0|0)|0;
      $251 = tempRet0;
      ___clang_call_terminate($250);
      // unreachable;
     }
    }
   }
   HEAP32[$25>>2] = 0;
   $160 = HEAP32[$22>>2]|0;
   $161 = ($160|0)==(0|0);
   if (!($161)) {
    $162 = ((($160)) + 8|0);
    $163 = HEAP32[$162>>2]|0;HEAP32[$162>>2] = (($163-1)|0);
    $164 = ($163|0)==(1);
    if ($164) {
     __THREW__ = 0;
     invoke_viii(3262,($160|0),1,1);
     $165 = __THREW__; __THREW__ = 0;
     $166 = $165&1;
     if ($166) {
      $250 = ___cxa_find_matching_catch_3(0|0)|0;
      $251 = tempRet0;
      ___clang_call_terminate($250);
      // unreachable;
     }
    }
   }
   HEAP32[$22>>2] = 0;
   __THREW__ = 0;
   invoke_vi(3293,($19|0));
   $167 = __THREW__; __THREW__ = 0;
   $168 = $167&1;
   if ($168) {
    $250 = ___cxa_find_matching_catch_3(0|0)|0;
    $251 = tempRet0;
    ___clang_call_terminate($250);
    // unreachable;
   } else {
    $$2 = $$14;$$27 = $$16;
   }
  }
  $169 = HEAP32[$18>>2]|0;
  $170 = ($169|0)==(0);
  L77: do {
   if (!($170)) {
    $171 = HEAP32[$17>>2]|0;
    $172 = HEAP32[$16>>2]|0;
    $173 = ((($172)) + 4|0);
    $174 = HEAP32[$173>>2]|0;
    $175 = HEAP32[$171>>2]|0;
    $176 = ((($175)) + 4|0);
    HEAP32[$176>>2] = $174;
    $177 = HEAP32[$173>>2]|0;
    HEAP32[$177>>2] = $175;
    HEAP32[$18>>2] = 0;
    $178 = ($171|0)==($16|0);
    if (!($178)) {
     $$023$i$i = $171;
     while(1) {
      $179 = ((($$023$i$i)) + 4|0);
      $180 = HEAP32[$179>>2]|0;
      $181 = ((($$023$i$i)) + 8|0);
      $182 = HEAP32[$181>>2]|0;
      $183 = ($182|0)==(0|0);
      if (!($183)) {
       $184 = HEAP32[$182>>2]|0;
       $185 = ((($184)) + -16|0);
       $186 = HEAP32[$185>>2]|0;
       $187 = (($182) + ($186)|0);
       $188 = ((($187)) + 8|0);
       $189 = HEAP32[$188>>2]|0;HEAP32[$188>>2] = (($189-1)|0);
       $190 = ($189|0)==(1);
       if ($190) {
        __THREW__ = 0;
        invoke_viii(3262,($187|0),1,1);
        $191 = __THREW__; __THREW__ = 0;
        $192 = $191&1;
        if ($192) {
         break;
        }
       }
      }
      __ZdlPv($$023$i$i);
      $193 = ($180|0)==($16|0);
      if ($193) {
       break L77;
      } else {
       $$023$i$i = $180;
      }
     }
     $194 = ___cxa_find_matching_catch_2()|0;
     $195 = tempRet0;
     ___cxa_call_unexpected(($194|0));
     // unreachable;
    }
   }
  } while(0);
  $196 = HEAP32[$15>>2]|0;
  $197 = ($196|0)==(0|0);
  if (!($197)) {
   $198 = HEAP32[$196>>2]|0;
   $199 = ((($198)) + -16|0);
   $200 = HEAP32[$199>>2]|0;
   $201 = (($196) + ($200)|0);
   $202 = ((($201)) + 8|0);
   $203 = HEAP32[$202>>2]|0;HEAP32[$202>>2] = (($203-1)|0);
   $204 = ($203|0)==(1);
   if ($204) {
    __THREW__ = 0;
    invoke_viii(3262,($201|0),1,1);
    $205 = __THREW__; __THREW__ = 0;
    $206 = $205&1;
    if ($206) {
     $250 = ___cxa_find_matching_catch_3(0|0)|0;
     $251 = tempRet0;
     ___clang_call_terminate($250);
     // unreachable;
    }
   }
  }
  HEAP32[$15>>2] = 0;
  $207 = HEAP32[$14>>2]|0;
  $208 = ($207|0)==(0|0);
  if (!($208)) {
   $209 = ((($207)) + 8|0);
   $210 = HEAP32[$209>>2]|0;HEAP32[$209>>2] = (($210-1)|0);
   $211 = ($210|0)==(1);
   if ($211) {
    __THREW__ = 0;
    invoke_viii(3262,($207|0),1,1);
    $212 = __THREW__; __THREW__ = 0;
    $213 = $212&1;
    if ($213) {
     $250 = ___cxa_find_matching_catch_3(0|0)|0;
     $251 = tempRet0;
     ___clang_call_terminate($250);
     // unreachable;
    }
   }
  }
  HEAP32[$14>>2] = 0;
  $214 = HEAP32[$13>>2]|0;
  $215 = ($214|0)==(0|0);
  if (!($215)) {
   $216 = ((($214)) + 8|0);
   $217 = HEAP32[$216>>2]|0;HEAP32[$216>>2] = (($217-1)|0);
   $218 = ($217|0)==(1);
   if ($218) {
    __THREW__ = 0;
    invoke_viii(3262,($214|0),1,1);
    $219 = __THREW__; __THREW__ = 0;
    $220 = $219&1;
    if ($220) {
     $250 = ___cxa_find_matching_catch_3(0|0)|0;
     $251 = tempRet0;
     ___clang_call_terminate($250);
     // unreachable;
    }
   }
  }
  HEAP32[$13>>2] = 0;
  $221 = HEAP32[$11>>2]|0;
  $222 = ($221|0)==(0|0);
  if (!($222)) {
   $223 = HEAP32[$12>>2]|0;
   $224 = ($223|0)==($221|0);
   do {
    if ($224) {
     $238 = $221;
    } else {
     $226 = $223;
     while(1) {
      $225 = ((($226)) + -4|0);
      HEAP32[$12>>2] = $225;
      $227 = HEAP32[$225>>2]|0;
      $228 = ($227|0)==(0|0);
      if (!($228)) {
       $229 = ((($227)) + 8|0);
       $230 = HEAP32[$229>>2]|0;HEAP32[$229>>2] = (($230-1)|0);
       $231 = ($230|0)==(1);
       if ($231) {
        __THREW__ = 0;
        invoke_viii(3262,($227|0),1,1);
        $232 = __THREW__; __THREW__ = 0;
        $233 = $232&1;
        if ($233) {
         label = 77;
         break;
        }
       }
      }
      HEAP32[$225>>2] = 0;
      $234 = HEAP32[$12>>2]|0;
      $235 = ($234|0)==($221|0);
      if ($235) {
       label = 78;
       break;
      } else {
       $226 = $234;
      }
     }
     if ((label|0) == 77) {
      $236 = ___cxa_find_matching_catch_2()|0;
      $237 = tempRet0;
      ___cxa_call_unexpected(($236|0));
      // unreachable;
     }
     else if ((label|0) == 78) {
      $$pre$i = HEAP32[$11>>2]|0;
      $238 = $$pre$i;
      break;
     }
    }
   } while(0);
   __ZdlPv($238);
  }
  $239 = HEAP32[$9>>2]|0;
  $240 = ($239|0)==(0|0);
  if (!($240)) {
   $241 = ((($239)) + 8|0);
   $242 = HEAP32[$241>>2]|0;HEAP32[$241>>2] = (($242-1)|0);
   $243 = ($242|0)==(1);
   if ($243) {
    __THREW__ = 0;
    invoke_viii(3262,($239|0),1,1);
    $244 = __THREW__; __THREW__ = 0;
    $245 = $244&1;
    if ($245) {
     $250 = ___cxa_find_matching_catch_3(0|0)|0;
     $251 = tempRet0;
     ___clang_call_terminate($250);
     // unreachable;
    }
   }
  }
  HEAP32[$9>>2] = 0;
  __THREW__ = 0;
  invoke_vii(3294,($0|0),((35488)|0));
  $246 = __THREW__; __THREW__ = 0;
  $247 = $246&1;
  if ($247) {
   $250 = ___cxa_find_matching_catch_3(0|0)|0;
   $251 = tempRet0;
   ___clang_call_terminate($250);
   // unreachable;
  } else {
   $$6 = $$2;$$611 = $$27;
  }
 }
 __THREW__ = 0;
 invoke_vi(388,($2|0));
 $248 = __THREW__; __THREW__ = 0;
 $249 = $248&1;
 if ($249) {
  $250 = ___cxa_find_matching_catch_3(0|0)|0;
  $251 = tempRet0;
  ___clang_call_terminate($250);
  // unreachable;
 } else {
  ___resumeException($$611|0);
  // unreachable;
 }
}
function __ZN9osgViewer4ViewD2Ev($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$023$i$i = 0, $$023$i$i24 = 0, $$03 = 0, $$1 = 0, $$14 = 0, $$2 = 0, $$25 = 0, $$4 = 0, $$47 = 0, $$5 = 0, $$58 = 0, $$6 = 0, $$69 = 0, $$8 = 0, $$811 = 0, $$cast = 0, $$pre$i = 0, $$pre$i36 = 0, $10 = 0;
 var $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0;
 var $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0;
 var $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0;
 var $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0;
 var $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0;
 var $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0;
 var $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0;
 var $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0;
 var $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0;
 var $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $3;
 $4 = ((($1)) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $$cast = $3;
 $6 = ((($$cast)) + -12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($0) + ($7)|0);
 HEAP32[$8>>2] = $5;
 $9 = ((($0)) + 36|0);
 HEAP32[$9>>2] = (35168);
 __THREW__ = 0;
 $10 = (invoke_ii(3265,4)|0);
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 L1: do {
  if ($12) {
   label = 14;
  } else {
   do {
    if ($10) {
     __THREW__ = 0;
     $13 = (invoke_ii(3266,4)|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      label = 14;
      break L1;
     }
     __THREW__ = 0;
     $16 = (invoke_iiii(3267,($13|0),(102319|0),27)|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      label = 14;
      break L1;
     }
     $19 = HEAP32[$16>>2]|0;
     $20 = ((($19)) + -12|0);
     $21 = HEAP32[$20>>2]|0;
     $22 = (($16) + ($21)|0);
     __THREW__ = 0;
     invoke_vii(3257,($2|0),($22|0));
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      label = 14;
      break L1;
     }
     __THREW__ = 0;
     $25 = (invoke_iii(3255,($2|0),(215188|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if (!($27)) {
      $28 = HEAP32[$25>>2]|0;
      $29 = ((($28)) + 28|0);
      $30 = HEAP32[$29>>2]|0;
      __THREW__ = 0;
      $31 = (invoke_iii($30|0,($25|0),10)|0);
      $32 = __THREW__; __THREW__ = 0;
      $33 = $32&1;
      if (!($33)) {
       __THREW__ = 0;
       invoke_vi(3263,($2|0));
       $34 = __THREW__; __THREW__ = 0;
       $35 = $34&1;
       if ($35) {
        label = 14;
        break L1;
       }
       __THREW__ = 0;
       (invoke_iii(3268,($16|0),($31|0))|0);
       $42 = __THREW__; __THREW__ = 0;
       $43 = $42&1;
       if ($43) {
        label = 14;
        break L1;
       }
       __THREW__ = 0;
       (invoke_ii(3269,($16|0))|0);
       $44 = __THREW__; __THREW__ = 0;
       $45 = $44&1;
       if ($45) {
        label = 14;
        break L1;
       } else {
        break;
       }
      }
     }
     $36 = ___cxa_find_matching_catch_2()|0;
     $37 = tempRet0;
     __THREW__ = 0;
     invoke_vi(3263,($2|0));
     $38 = __THREW__; __THREW__ = 0;
     $39 = $38&1;
     if ($39) {
      $40 = ___cxa_find_matching_catch_3(0|0)|0;
      $41 = tempRet0;
      ___clang_call_terminate($40);
      // unreachable;
     } else {
      $eh$lpad$body$index2Z2D = $37;$eh$lpad$body$indexZ2D = $36;
      label = 15;
      break L1;
     }
    }
   } while(0);
   $56 = ((($0)) + 128|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = ($57|0)==(0|0);
   if (!($58)) {
    $59 = ((($57)) + 8|0);
    $60 = HEAP32[$59>>2]|0;HEAP32[$59>>2] = (($60-1)|0);
    $61 = ($60|0)==(1);
    if ($61) {
     __THREW__ = 0;
     invoke_viii(3262,($57|0),1,1);
     $62 = __THREW__; __THREW__ = 0;
     $63 = $62&1;
     if ($63) {
      $162 = ___cxa_find_matching_catch_2()|0;
      $163 = tempRet0;
      $$0 = $163;$$03 = $162;
      label = 57;
      break;
     }
    }
   }
   HEAP32[$56>>2] = 0;
   $64 = ((($0)) + 116|0);
   $65 = HEAP32[$64>>2]|0;
   $66 = ($65|0)==(0|0);
   if (!($66)) {
    $67 = ((($65)) + 8|0);
    $68 = HEAP32[$67>>2]|0;HEAP32[$67>>2] = (($68-1)|0);
    $69 = ($68|0)==(1);
    if ($69) {
     __THREW__ = 0;
     invoke_viii(3262,($65|0),1,1);
     $70 = __THREW__; __THREW__ = 0;
     $71 = $70&1;
     if ($71) {
      $164 = ___cxa_find_matching_catch_2()|0;
      $165 = tempRet0;
      $$1 = $165;$$14 = $164;
      label = 62;
      break;
     }
    }
   }
   HEAP32[$64>>2] = 0;
   $72 = ((($0)) + 92|0);
   __THREW__ = 0;
   invoke_vi(3293,($72|0));
   $73 = __THREW__; __THREW__ = 0;
   $74 = $73&1;
   if ($74) {
    $174 = ___cxa_find_matching_catch_2()|0;
    $175 = tempRet0;
    $$2 = $175;$$25 = $174;
    label = 63;
    break;
   }
   $75 = ((($0)) + 80|0);
   $76 = ((($0)) + 88|0);
   $77 = HEAP32[$76>>2]|0;
   $78 = ($77|0)==(0);
   L31: do {
    if (!($78)) {
     $79 = ((($0)) + 84|0);
     $80 = HEAP32[$79>>2]|0;
     $81 = HEAP32[$75>>2]|0;
     $82 = ((($81)) + 4|0);
     $83 = HEAP32[$82>>2]|0;
     $84 = HEAP32[$80>>2]|0;
     $85 = ((($84)) + 4|0);
     HEAP32[$85>>2] = $83;
     $86 = HEAP32[$82>>2]|0;
     HEAP32[$86>>2] = $84;
     HEAP32[$76>>2] = 0;
     $87 = ($80|0)==($75|0);
     if (!($87)) {
      $$023$i$i = $80;
      while(1) {
       $88 = ((($$023$i$i)) + 4|0);
       $89 = HEAP32[$88>>2]|0;
       $90 = ((($$023$i$i)) + 8|0);
       $91 = HEAP32[$90>>2]|0;
       $92 = ($91|0)==(0|0);
       if (!($92)) {
        $93 = HEAP32[$91>>2]|0;
        $94 = ((($93)) + -16|0);
        $95 = HEAP32[$94>>2]|0;
        $96 = (($91) + ($95)|0);
        $97 = ((($96)) + 8|0);
        $98 = HEAP32[$97>>2]|0;HEAP32[$97>>2] = (($98-1)|0);
        $99 = ($98|0)==(1);
        if ($99) {
         __THREW__ = 0;
         invoke_viii(3262,($96|0),1,1);
         $100 = __THREW__; __THREW__ = 0;
         $101 = $100&1;
         if ($101) {
          break;
         }
        }
       }
       __ZdlPv($$023$i$i);
       $102 = ($89|0)==($75|0);
       if ($102) {
        break L31;
       } else {
        $$023$i$i = $89;
       }
      }
      $103 = ___cxa_find_matching_catch_2()|0;
      $104 = tempRet0;
      ___cxa_call_unexpected(($103|0));
      // unreachable;
     }
    }
   } while(0);
   $105 = ((($0)) + 76|0);
   $106 = HEAP32[$105>>2]|0;
   $107 = ($106|0)==(0|0);
   if (!($107)) {
    $108 = HEAP32[$106>>2]|0;
    $109 = ((($108)) + -16|0);
    $110 = HEAP32[$109>>2]|0;
    $111 = (($106) + ($110)|0);
    $112 = ((($111)) + 8|0);
    $113 = HEAP32[$112>>2]|0;HEAP32[$112>>2] = (($113-1)|0);
    $114 = ($113|0)==(1);
    if ($114) {
     __THREW__ = 0;
     invoke_viii(3262,($111|0),1,1);
     $115 = __THREW__; __THREW__ = 0;
     $116 = $115&1;
     if ($116) {
      $221 = ___cxa_find_matching_catch_2()|0;
      $222 = tempRet0;
      $$4 = $222;$$47 = $221;
      label = 76;
      break;
     }
    }
   }
   HEAP32[$105>>2] = 0;
   $117 = ((($0)) + 72|0);
   $118 = HEAP32[$117>>2]|0;
   $119 = ($118|0)==(0|0);
   if (!($119)) {
    $120 = ((($118)) + 8|0);
    $121 = HEAP32[$120>>2]|0;HEAP32[$120>>2] = (($121-1)|0);
    $122 = ($121|0)==(1);
    if ($122) {
     __THREW__ = 0;
     invoke_viii(3262,($118|0),1,1);
     $123 = __THREW__; __THREW__ = 0;
     $124 = $123&1;
     if ($124) {
      $223 = ___cxa_find_matching_catch_2()|0;
      $224 = tempRet0;
      $$5 = $224;$$58 = $223;
      label = 81;
      break;
     }
    }
   }
   HEAP32[$117>>2] = 0;
   $125 = ((($0)) + 68|0);
   $126 = HEAP32[$125>>2]|0;
   $127 = ($126|0)==(0|0);
   if (!($127)) {
    $128 = ((($126)) + 8|0);
    $129 = HEAP32[$128>>2]|0;HEAP32[$128>>2] = (($129-1)|0);
    $130 = ($129|0)==(1);
    if ($130) {
     __THREW__ = 0;
     invoke_viii(3262,($126|0),1,1);
     $131 = __THREW__; __THREW__ = 0;
     $132 = $131&1;
     if ($132) {
      $233 = ___cxa_find_matching_catch_2()|0;
      $234 = tempRet0;
      $$6 = $234;$$69 = $233;
      label = 85;
      break;
     }
    }
   }
   HEAP32[$125>>2] = 0;
   $133 = ((($0)) + 56|0);
   $134 = HEAP32[$133>>2]|0;
   $135 = ($134|0)==(0|0);
   if (!($135)) {
    $136 = ((($0)) + 60|0);
    $137 = HEAP32[$136>>2]|0;
    $138 = ($137|0)==($134|0);
    do {
     if ($138) {
      $152 = $134;
     } else {
      $140 = $137;
      while(1) {
       $139 = ((($140)) + -4|0);
       HEAP32[$136>>2] = $139;
       $141 = HEAP32[$139>>2]|0;
       $142 = ($141|0)==(0|0);
       if (!($142)) {
        $143 = ((($141)) + 8|0);
        $144 = HEAP32[$143>>2]|0;HEAP32[$143>>2] = (($144-1)|0);
        $145 = ($144|0)==(1);
        if ($145) {
         __THREW__ = 0;
         invoke_viii(3262,($141|0),1,1);
         $146 = __THREW__; __THREW__ = 0;
         $147 = $146&1;
         if ($147) {
          label = 48;
          break;
         }
        }
       }
       HEAP32[$139>>2] = 0;
       $148 = HEAP32[$136>>2]|0;
       $149 = ($148|0)==($134|0);
       if ($149) {
        label = 49;
        break;
       } else {
        $140 = $148;
       }
      }
      if ((label|0) == 48) {
       $150 = ___cxa_find_matching_catch_2()|0;
       $151 = tempRet0;
       ___cxa_call_unexpected(($150|0));
       // unreachable;
      }
      else if ((label|0) == 49) {
       $$pre$i = HEAP32[$133>>2]|0;
       $152 = $$pre$i;
       break;
      }
     }
    } while(0);
    __ZdlPv($152);
   }
   $153 = ((($0)) + 40|0);
   $154 = HEAP32[$153>>2]|0;
   $155 = ($154|0)==(0|0);
   if ($155) {
    HEAP32[$153>>2] = 0;
    $161 = ((($1)) + 4|0);
    __ZN3osg4ViewD2Ev($0,$161);
    STACKTOP = sp;return;
   }
   $156 = ((($154)) + 8|0);
   $157 = HEAP32[$156>>2]|0;HEAP32[$156>>2] = (($157-1)|0);
   $158 = ($157|0)==(1);
   if (!($158)) {
    HEAP32[$153>>2] = 0;
    $161 = ((($1)) + 4|0);
    __ZN3osg4ViewD2Ev($0,$161);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   invoke_viii(3262,($154|0),1,1);
   $159 = __THREW__; __THREW__ = 0;
   $160 = $159&1;
   if ($160) {
    $263 = ___cxa_find_matching_catch_2()|0;
    $264 = tempRet0;
    $$8 = $264;$$811 = $263;
    break;
   } else {
    HEAP32[$153>>2] = 0;
    $161 = ((($1)) + 4|0);
    __ZN3osg4ViewD2Ev($0,$161);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 14) {
  $46 = ___cxa_find_matching_catch_2()|0;
  $47 = tempRet0;
  $eh$lpad$body$index2Z2D = $47;$eh$lpad$body$indexZ2D = $46;
  label = 15;
 }
 if ((label|0) == 15) {
  $48 = ((($0)) + 128|0);
  $49 = HEAP32[$48>>2]|0;
  $50 = ($49|0)==(0|0);
  if (!($50)) {
   $51 = ((($49)) + 8|0);
   $52 = HEAP32[$51>>2]|0;HEAP32[$51>>2] = (($52-1)|0);
   $53 = ($52|0)==(1);
   if ($53) {
    __THREW__ = 0;
    invoke_viii(3262,($49|0),1,1);
    $54 = __THREW__; __THREW__ = 0;
    $55 = $54&1;
    if ($55) {
     $276 = ___cxa_find_matching_catch_3(0|0)|0;
     $277 = tempRet0;
     ___clang_call_terminate($276);
     // unreachable;
    }
   }
  }
  HEAP32[$48>>2] = 0;
  $$0 = $eh$lpad$body$index2Z2D;$$03 = $eh$lpad$body$indexZ2D;
  label = 57;
 }
 if ((label|0) == 57) {
  $166 = ((($0)) + 116|0);
  $167 = HEAP32[$166>>2]|0;
  $168 = ($167|0)==(0|0);
  if (!($168)) {
   $169 = ((($167)) + 8|0);
   $170 = HEAP32[$169>>2]|0;HEAP32[$169>>2] = (($170-1)|0);
   $171 = ($170|0)==(1);
   if ($171) {
    __THREW__ = 0;
    invoke_viii(3262,($167|0),1,1);
    $172 = __THREW__; __THREW__ = 0;
    $173 = $172&1;
    if ($173) {
     $276 = ___cxa_find_matching_catch_3(0|0)|0;
     $277 = tempRet0;
     ___clang_call_terminate($276);
     // unreachable;
    }
   }
  }
  HEAP32[$166>>2] = 0;
  $$1 = $$0;$$14 = $$03;
  label = 62;
 }
 if ((label|0) == 62) {
  $176 = ((($0)) + 92|0);
  __THREW__ = 0;
  invoke_vi(3293,($176|0));
  $177 = __THREW__; __THREW__ = 0;
  $178 = $177&1;
  if ($178) {
   $276 = ___cxa_find_matching_catch_3(0|0)|0;
   $277 = tempRet0;
   ___clang_call_terminate($276);
   // unreachable;
  } else {
   $$2 = $$1;$$25 = $$14;
   label = 63;
  }
 }
 if ((label|0) == 63) {
  $179 = ((($0)) + 80|0);
  $180 = ((($0)) + 88|0);
  $181 = HEAP32[$180>>2]|0;
  $182 = ($181|0)==(0);
  L100: do {
   if (!($182)) {
    $183 = ((($0)) + 84|0);
    $184 = HEAP32[$183>>2]|0;
    $185 = HEAP32[$179>>2]|0;
    $186 = ((($185)) + 4|0);
    $187 = HEAP32[$186>>2]|0;
    $188 = HEAP32[$184>>2]|0;
    $189 = ((($188)) + 4|0);
    HEAP32[$189>>2] = $187;
    $190 = HEAP32[$186>>2]|0;
    HEAP32[$190>>2] = $188;
    HEAP32[$180>>2] = 0;
    $191 = ($184|0)==($179|0);
    if (!($191)) {
     $$023$i$i24 = $184;
     while(1) {
      $192 = ((($$023$i$i24)) + 4|0);
      $193 = HEAP32[$192>>2]|0;
      $194 = ((($$023$i$i24)) + 8|0);
      $195 = HEAP32[$194>>2]|0;
      $196 = ($195|0)==(0|0);
      if (!($196)) {
       $197 = HEAP32[$195>>2]|0;
       $198 = ((($197)) + -16|0);
       $199 = HEAP32[$198>>2]|0;
       $200 = (($195) + ($199)|0);
       $201 = ((($200)) + 8|0);
       $202 = HEAP32[$201>>2]|0;HEAP32[$201>>2] = (($202-1)|0);
       $203 = ($202|0)==(1);
       if ($203) {
        __THREW__ = 0;
        invoke_viii(3262,($200|0),1,1);
        $204 = __THREW__; __THREW__ = 0;
        $205 = $204&1;
        if ($205) {
         break;
        }
       }
      }
      __ZdlPv($$023$i$i24);
      $206 = ($193|0)==($179|0);
      if ($206) {
       break L100;
      } else {
       $$023$i$i24 = $193;
      }
     }
     $207 = ___cxa_find_matching_catch_2()|0;
     $208 = tempRet0;
     ___cxa_call_unexpected(($207|0));
     // unreachable;
    }
   }
  } while(0);
  $209 = ((($0)) + 76|0);
  $210 = HEAP32[$209>>2]|0;
  $211 = ($210|0)==(0|0);
  if (!($211)) {
   $212 = HEAP32[$210>>2]|0;
   $213 = ((($212)) + -16|0);
   $214 = HEAP32[$213>>2]|0;
   $215 = (($210) + ($214)|0);
   $216 = ((($215)) + 8|0);
   $217 = HEAP32[$216>>2]|0;HEAP32[$216>>2] = (($217-1)|0);
   $218 = ($217|0)==(1);
   if ($218) {
    __THREW__ = 0;
    invoke_viii(3262,($215|0),1,1);
    $219 = __THREW__; __THREW__ = 0;
    $220 = $219&1;
    if ($220) {
     $276 = ___cxa_find_matching_catch_3(0|0)|0;
     $277 = tempRet0;
     ___clang_call_terminate($276);
     // unreachable;
    }
   }
  }
  HEAP32[$209>>2] = 0;
  $$4 = $$2;$$47 = $$25;
  label = 76;
 }
 if ((label|0) == 76) {
  $225 = ((($0)) + 72|0);
  $226 = HEAP32[$225>>2]|0;
  $227 = ($226|0)==(0|0);
  if (!($227)) {
   $228 = ((($226)) + 8|0);
   $229 = HEAP32[$228>>2]|0;HEAP32[$228>>2] = (($229-1)|0);
   $230 = ($229|0)==(1);
   if ($230) {
    __THREW__ = 0;
    invoke_viii(3262,($226|0),1,1);
    $231 = __THREW__; __THREW__ = 0;
    $232 = $231&1;
    if ($232) {
     $276 = ___cxa_find_matching_catch_3(0|0)|0;
     $277 = tempRet0;
     ___clang_call_terminate($276);
     // unreachable;
    }
   }
  }
  HEAP32[$225>>2] = 0;
  $$5 = $$4;$$58 = $$47;
  label = 81;
 }
 if ((label|0) == 81) {
  $235 = ((($0)) + 68|0);
  $236 = HEAP32[$235>>2]|0;
  $237 = ($236|0)==(0|0);
  if (!($237)) {
   $238 = ((($236)) + 8|0);
   $239 = HEAP32[$238>>2]|0;HEAP32[$238>>2] = (($239-1)|0);
   $240 = ($239|0)==(1);
   if ($240) {
    __THREW__ = 0;
    invoke_viii(3262,($236|0),1,1);
    $241 = __THREW__; __THREW__ = 0;
    $242 = $241&1;
    if ($242) {
     $276 = ___cxa_find_matching_catch_3(0|0)|0;
     $277 = tempRet0;
     ___clang_call_terminate($276);
     // unreachable;
    }
   }
  }
  HEAP32[$235>>2] = 0;
  $$6 = $$5;$$69 = $$58;
  label = 85;
 }
 if ((label|0) == 85) {
  $243 = ((($0)) + 56|0);
  $244 = HEAP32[$243>>2]|0;
  $245 = ($244|0)==(0|0);
  if (!($245)) {
   $246 = ((($0)) + 60|0);
   $247 = HEAP32[$246>>2]|0;
   $248 = ($247|0)==($244|0);
   do {
    if ($248) {
     $262 = $244;
    } else {
     $250 = $247;
     while(1) {
      $249 = ((($250)) + -4|0);
      HEAP32[$246>>2] = $249;
      $251 = HEAP32[$249>>2]|0;
      $252 = ($251|0)==(0|0);
      if (!($252)) {
       $253 = ((($251)) + 8|0);
       $254 = HEAP32[$253>>2]|0;HEAP32[$253>>2] = (($254-1)|0);
       $255 = ($254|0)==(1);
       if ($255) {
        __THREW__ = 0;
        invoke_viii(3262,($251|0),1,1);
        $256 = __THREW__; __THREW__ = 0;
        $257 = $256&1;
        if ($257) {
         label = 91;
         break;
        }
       }
      }
      HEAP32[$249>>2] = 0;
      $258 = HEAP32[$246>>2]|0;
      $259 = ($258|0)==($244|0);
      if ($259) {
       label = 92;
       break;
      } else {
       $250 = $258;
      }
     }
     if ((label|0) == 91) {
      $260 = ___cxa_find_matching_catch_2()|0;
      $261 = tempRet0;
      ___cxa_call_unexpected(($260|0));
      // unreachable;
     }
     else if ((label|0) == 92) {
      $$pre$i36 = HEAP32[$243>>2]|0;
      $262 = $$pre$i36;
      break;
     }
    }
   } while(0);
   __ZdlPv($262);
  }
  $265 = ((($0)) + 40|0);
  $266 = HEAP32[$265>>2]|0;
  $267 = ($266|0)==(0|0);
  if (!($267)) {
   $268 = ((($266)) + 8|0);
   $269 = HEAP32[$268>>2]|0;HEAP32[$268>>2] = (($269-1)|0);
   $270 = ($269|0)==(1);
   if ($270) {
    __THREW__ = 0;
    invoke_viii(3262,($266|0),1,1);
    $271 = __THREW__; __THREW__ = 0;
    $272 = $271&1;
    if ($272) {
     $276 = ___cxa_find_matching_catch_3(0|0)|0;
     $277 = tempRet0;
     ___clang_call_terminate($276);
     // unreachable;
    }
   }
  }
  HEAP32[$265>>2] = 0;
  $$8 = $$6;$$811 = $$69;
 }
 $273 = ((($1)) + 4|0);
 __THREW__ = 0;
 invoke_vii(3294,($0|0),($273|0));
 $274 = __THREW__; __THREW__ = 0;
 $275 = $274&1;
 if ($275) {
  $276 = ___cxa_find_matching_catch_3(0|0)|0;
  $277 = tempRet0;
  ___clang_call_terminate($276);
  // unreachable;
 } else {
  ___resumeException($$811|0);
  // unreachable;
 }
}
function __ZNK9osgViewer4View27getCameraContainingPositionEffRfS1_($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = +$1;
 $2 = +$2;
 $3 = $3|0;
 $4 = $4|0;
 var $$ = 0.0, $$0117 = 0, $$0117198 = 0, $$0117199 = 0, $$1119 = 0, $$1125 = 0, $$136 = 0.0, $$5123 = 0, $$5129 = 0, $$7 = 0, $$8 = 0, $$not135 = 0, $$pre = 0, $10 = 0, $100 = 0.0, $101 = 0.0, $102 = 0.0, $103 = 0, $104 = 0.0, $105 = 0.0;
 var $106 = 0.0, $107 = 0.0, $108 = 0, $109 = 0.0, $11 = 0, $110 = 0.0, $111 = 0.0, $112 = 0.0, $113 = 0.0, $114 = 0.0, $115 = 0.0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0.0, $13 = 0, $130 = 0.0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0;
 var $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0;
 var $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0;
 var $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0;
 var $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0.0, $227 = 0, $228 = 0.0, $229 = 0, $23 = 0, $230 = 0.0, $231 = 0, $232 = 0.0;
 var $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0.0, $243 = 0.0, $244 = 0.0, $245 = 0.0, $246 = 0.0, $247 = 0.0, $248 = 0.0, $249 = 0.0, $25 = 0, $250 = 0.0;
 var $251 = 0.0, $252 = 0.0, $253 = 0.0, $254 = 0.0, $255 = 0.0, $256 = 0.0, $257 = 0.0, $258 = 0.0, $259 = 0.0, $26 = 0, $260 = 0.0, $261 = 0.0, $262 = 0.0, $263 = 0.0, $264 = 0.0, $265 = 0.0, $266 = 0.0, $267 = 0.0, $268 = 0.0, $269 = 0.0;
 var $27 = 0, $270 = 0.0, $271 = 0.0, $272 = 0.0, $273 = 0.0, $274 = 0.0, $275 = 0, $276 = 0.0, $277 = 0.0, $278 = 0, $279 = 0, $28 = 0, $280 = 0.0, $281 = 0.0, $282 = 0, $283 = 0, $284 = 0.0, $285 = 0.0, $286 = 0.0, $287 = 0.0;
 var $288 = 0, $289 = 0, $29 = 0, $290 = 0.0, $291 = 0.0, $292 = 0.0, $293 = 0.0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $30 = 0, $300 = 0.0, $301 = 0.0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0.0, $42 = 0.0, $43 = 0, $44 = 0.0, $45 = 0.0, $46 = 0.0, $47 = 0.0, $48 = 0, $49 = 0.0, $5 = 0, $50 = 0.0, $51 = 0, $52 = 0.0, $53 = 0.0;
 var $54 = 0.0, $55 = 0.0, $56 = 0.0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0.0, $62 = 0.0, $63 = 0, $64 = 0, $65 = 0.0, $66 = 0.0, $67 = 0, $68 = 0.0, $69 = 0.0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0.0, $73 = 0.0, $74 = 0, $75 = 0, $76 = 0.0, $77 = 0.0, $78 = 0.0, $79 = 0.0, $8 = 0, $80 = 0, $81 = 0, $82 = 0.0, $83 = 0.0, $84 = 0.0, $85 = 0.0, $86 = 0, $87 = 0.0, $88 = 0.0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0.0, $93 = 0.0, $94 = 0.0, $95 = 0.0, $96 = 0, $97 = 0.0, $98 = 0.0, $99 = 0.0, $brmerge = 0, $eh$lpad$body$index4Z2D = 0, $eh$lpad$body$indexZ2D = 0, $or$cond = 0, $or$cond202 = 0, $or$cond204 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 656|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(656|0);
 $5 = sp + 640|0;
 $6 = sp + 512|0;
 $7 = sp + 384|0;
 $8 = sp + 256|0;
 $9 = sp + 128|0;
 $10 = sp;
 $11 = ((($0)) + 72|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ((($12)) + 12|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ((($14)) + 52|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==(0|0);
 if ($17) {
  $35 = 0;
 } else {
  $18 = ((($16)) + 24|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = ($19|0)==(0|0);
  if ($20) {
   $35 = 0;
  } else {
   $21 = ((($14)) + 56|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = ($22|0)==(0|0);
   if ($23) {
    $35 = 0;
   } else {
    $24 = (___dynamic_cast($22,24816,3888,0)|0);
    $35 = $24;
   }
  }
 }
 $25 = ((($14)) + 120|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($26|0)==(1);
 $28 = ((($0)) + 16|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ((($29)) + 624|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ($31|0)==(0|0);
 if ($32) {
  $37 = 1;
 } else {
  $33 = ((($29)) + 288|0);
  $34 = HEAP32[$33>>2]|0;
  $phitmp = ($34|0)==(0|0);
  $37 = $phitmp;
 }
 $36 = ($35|0)==(0|0);
 if (!($36)) {
  $$not135 = ($31|0)!=($35|0);
  $brmerge = $$not135 | $37;
  if (!($brmerge)) {
   $38 = ((($29)) + 288|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = ((($14)) + 88|0);
   $41 = +HEAPF32[$40>>2];
   $42 = $1 - $41;
   $43 = ((($14)) + 92|0);
   $44 = +HEAPF32[$43>>2];
   $45 = $44 - $41;
   $46 = $42 / $45;
   $47 = $46;
   $48 = ((($14)) + 96|0);
   $49 = +HEAPF32[$48>>2];
   $50 = $2 - $49;
   $51 = ((($14)) + 100|0);
   $52 = +HEAPF32[$51>>2];
   $53 = $52 - $49;
   $54 = $50 / $53;
   $55 = $54;
   $56 = 1.0 - $55;
   $$ = $27 ? $56 : $55;
   $57 = ((($31)) + 44|0);
   $58 = HEAP32[$57>>2]|0;
   $59 = ((($58)) + 40|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = (+($60|0));
   $62 = $47 * $61;
   $63 = ((($58)) + 44|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = (+($64|0));
   $66 = $$ * $65;
   $67 = ((($39)) + 56|0);
   $68 = +HEAPF64[$67>>3];
   $69 = $68 + -0.5;
   $70 = !($62 >= $69);
   if (!($70)) {
    $71 = ((($39)) + 64|0);
    $72 = +HEAPF64[$71>>3];
    $73 = $72 + -0.5;
    $74 = !($66 >= $73);
    if (!($74)) {
     $75 = ((($39)) + 72|0);
     $76 = +HEAPF64[$75>>3];
     $77 = $68 + $76;
     $78 = $77 + -1.0;
     $79 = $78 + 0.5;
     $80 = $62 < $79;
     if ($80) {
      $81 = ((($39)) + 80|0);
      $82 = +HEAPF64[$81>>3];
      $83 = $72 + $82;
      $84 = $83 + -1.0;
      $85 = $84 + 0.5;
      $86 = !($66 <= $85);
      if (!($86)) {
       $87 = $66;
       $88 = $62;
       HEAPF32[$3>>2] = $88;
       HEAPF32[$4>>2] = $87;
       $$8 = $29;
       STACKTOP = sp;return ($$8|0);
      }
     }
    }
   }
  }
 }
 $89 = ((($29)) + 432|0);
 $90 = ((($29)) + 304|0);
 __ZN3osg7Matrixd12makeIdentityEv($6);
 __ZN3osg7Matrixd4multERKS0_S2_($6,$89,$90);
 $91 = ((($14)) + 88|0);
 $92 = +HEAPF32[$91>>2];
 $93 = $1 - $92;
 $94 = $93;
 $95 = $94 * 2.0;
 $96 = ((($14)) + 92|0);
 $97 = +HEAPF32[$96>>2];
 $98 = $97 - $92;
 $99 = $98;
 $100 = $95 / $99;
 $101 = $100 + -1.0;
 $102 = $101;
 $103 = ((($14)) + 96|0);
 $104 = +HEAPF32[$103>>2];
 $105 = $2 - $104;
 $106 = $105;
 $107 = $106 * 2.0;
 $108 = ((($14)) + 100|0);
 $109 = +HEAPF32[$108>>2];
 $110 = $109 - $104;
 $111 = $110;
 $112 = $107 / $111;
 $113 = $112 + -1.0;
 $114 = $113;
 $115 = -$114;
 $$136 = $27 ? $115 : $114;
 $116 = ((($0)) + 20|0);
 $117 = ((($0)) + 24|0);
 $118 = HEAP32[$117>>2]|0;
 $119 = HEAP32[$116>>2]|0;
 $120 = (($118) - ($119))|0;
 $121 = ($120|0)>(0);
 L18: do {
  if ($121) {
   $122 = $119;
   $123 = (($120>>>0) / 272)&-1;
   $$0117198 = (($123) + -1)|0;
   $124 = ((($0)) + 20|0);
   $125 = ((($6)) + 24|0);
   $126 = ((($6)) + 56|0);
   $127 = ((($6)) + 88|0);
   $128 = ((($6)) + 120|0);
   $129 = $102;
   $130 = $$136;
   $131 = ((($9)) + 24|0);
   $132 = ((($9)) + 56|0);
   $133 = ((($9)) + 88|0);
   $134 = ((($9)) + 120|0);
   $135 = ((($9)) + 32|0);
   $136 = ((($9)) + 64|0);
   $137 = ((($9)) + 96|0);
   $138 = ((($9)) + 8|0);
   $139 = ((($9)) + 40|0);
   $140 = ((($9)) + 72|0);
   $141 = ((($9)) + 104|0);
   $$0117199 = $$0117198;$143 = $122;
   L20: while(1) {
    $142 = (((($143) + (($$0117199*272)|0)|0)) + 4|0);
    $144 = HEAP32[$142>>2]|0;
    $145 = ($144|0)==(0|0);
    if (!($145)) {
     $146 = ((($144)) + 228|0);
     $147 = HEAP8[$146>>0]|0;
     $148 = ($147<<24>>24)==(0);
     if (!($148)) {
      $149 = ((($144)) + 576|0);
      $150 = HEAP32[$149>>2]|0;
      $151 = ($150|0)==(3);
      if ($151) {
       __THREW__ = 0;
       $152 = (invoke_ii(3265,4)|0);
       $153 = __THREW__; __THREW__ = 0;
       $154 = $153&1;
       if ($154) {
        label = 33;
        break;
       }
       if ($152) {
        __THREW__ = 0;
        $155 = (invoke_ii(3266,4)|0);
        $156 = __THREW__; __THREW__ = 0;
        $157 = $156&1;
        if ($157) {
         label = 33;
         break;
        }
        __THREW__ = 0;
        $158 = (invoke_iiii(3267,($155|0),(102434|0),21)|0);
        $159 = __THREW__; __THREW__ = 0;
        $160 = $159&1;
        if ($160) {
         label = 33;
         break;
        }
        $161 = HEAP32[$142>>2]|0;
        $162 = ((($161)) + 12|0);
        $163 = ((($162)) + 11|0);
        $164 = HEAP8[$163>>0]|0;
        $165 = ($164<<24>>24)<(0);
        $166 = HEAP32[$162>>2]|0;
        $167 = $165 ? $166 : $162;
        $168 = ((($161)) + 16|0);
        $169 = HEAP32[$168>>2]|0;
        $170 = $164&255;
        $171 = $165 ? $169 : $170;
        __THREW__ = 0;
        $172 = (invoke_iiii(3267,($158|0),($167|0),($171|0))|0);
        $173 = __THREW__; __THREW__ = 0;
        $174 = $173&1;
        if ($174) {
         label = 33;
         break;
        }
        $175 = HEAP32[$172>>2]|0;
        $176 = ((($175)) + -12|0);
        $177 = HEAP32[$176>>2]|0;
        $178 = (($172) + ($177)|0);
        __THREW__ = 0;
        invoke_vii(3257,($5|0),($178|0));
        $179 = __THREW__; __THREW__ = 0;
        $180 = $179&1;
        if ($180) {
         label = 33;
         break;
        }
        __THREW__ = 0;
        $181 = (invoke_iii(3255,($5|0),(215188|0))|0);
        $182 = __THREW__; __THREW__ = 0;
        $183 = $182&1;
        if ($183) {
         label = 27;
         break;
        }
        $184 = HEAP32[$181>>2]|0;
        $185 = ((($184)) + 28|0);
        $186 = HEAP32[$185>>2]|0;
        __THREW__ = 0;
        $187 = (invoke_iii($186|0,($181|0),10)|0);
        $188 = __THREW__; __THREW__ = 0;
        $189 = $188&1;
        if ($189) {
         label = 27;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3263,($5|0));
        $196 = __THREW__; __THREW__ = 0;
        $197 = $196&1;
        if ($197) {
         label = 33;
         break;
        }
        __THREW__ = 0;
        (invoke_iii(3268,($172|0),($187|0))|0);
        $198 = __THREW__; __THREW__ = 0;
        $199 = $198&1;
        if ($199) {
         label = 33;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(3269,($172|0))|0);
        $200 = __THREW__; __THREW__ = 0;
        $201 = $200&1;
        if ($201) {
         label = 33;
         break;
        }
       }
       $204 = HEAP32[$142>>2]|0;
       $205 = ($204|0)==(0|0);
       if ($205) {
        $214 = 0;
       } else {
        $206 = ((($204)) + 288|0);
        $207 = HEAP32[$206>>2]|0;
        $214 = $207;
       }
       __THREW__ = 0;
       invoke_vi(3299,($7|0));
       $208 = __THREW__; __THREW__ = 0;
       $209 = $208&1;
       if ($209) {
        label = 43;
        break;
       }
       $210 = ((($204)) + 304|0);
       $211 = ((($204)) + 432|0);
       __THREW__ = 0;
       invoke_viii(3300,($7|0),($211|0),($210|0));
       $212 = __THREW__; __THREW__ = 0;
       $213 = $212&1;
       if ($213) {
        label = 43;
        break;
       }
       $215 = ($214|0)!=(0|0);
       if ($215) {
        __THREW__ = 0;
        invoke_vii(3301,($8|0),($214|0));
        $216 = __THREW__; __THREW__ = 0;
        $217 = $216&1;
        if ($217) {
         label = 44;
         break;
        }
        __THREW__ = 0;
        invoke_vii(3302,($7|0),($8|0));
        $218 = __THREW__; __THREW__ = 0;
        $219 = $218&1;
        if ($219) {
         label = 44;
         break;
        }
       }
       __THREW__ = 0;
       invoke_vi(3299,($10|0));
       $224 = __THREW__; __THREW__ = 0;
       $225 = $224&1;
       if ($225) {
        label = 56;
        break;
       }
       $226 = +HEAPF64[$125>>3];
       $227 = $226 == 0.0;
       $228 = +HEAPF64[$126>>3];
       $229 = $228 == 0.0;
       $or$cond = $227 & $229;
       $230 = +HEAPF64[$127>>3];
       $231 = $230 == 0.0;
       $or$cond202 = $or$cond & $231;
       $232 = +HEAPF64[$128>>3];
       $233 = $232 == 1.0;
       $or$cond204 = $or$cond202 & $233;
       if ($or$cond204) {
        __THREW__ = 0;
        (invoke_iii(3303,($10|0),($6|0))|0);
        $234 = __THREW__; __THREW__ = 0;
        $235 = $234&1;
        if ($235) {
         label = 56;
         break;
        }
       } else {
        __THREW__ = 0;
        (invoke_iii(3304,($10|0),($6|0))|0);
        $236 = __THREW__; __THREW__ = 0;
        $237 = $236&1;
        if ($237) {
         label = 56;
         break;
        }
       }
       __THREW__ = 0;
       invoke_vi(3299,($9|0));
       $238 = __THREW__; __THREW__ = 0;
       $239 = $238&1;
       if ($239) {
        label = 57;
        break;
       }
       __THREW__ = 0;
       invoke_viii(3300,($9|0),($10|0),($7|0));
       $240 = __THREW__; __THREW__ = 0;
       $241 = $240&1;
       if ($241) {
        label = 57;
        break;
       }
       $242 = +HEAPF64[$131>>3];
       $243 = $129 * $242;
       $244 = +HEAPF64[$132>>3];
       $245 = $130 * $244;
       $246 = $243 + $245;
       $247 = +HEAPF64[$133>>3];
       $248 = $247 * 0.0;
       $249 = $246 + $248;
       $250 = +HEAPF64[$134>>3];
       $251 = $250 + $249;
       $252 = 1.0 / $251;
       $253 = +HEAPF64[$9>>3];
       $254 = $129 * $253;
       $255 = +HEAPF64[$135>>3];
       $256 = $130 * $255;
       $257 = $254 + $256;
       $258 = +HEAPF64[$136>>3];
       $259 = $258 * 0.0;
       $260 = $257 + $259;
       $261 = +HEAPF64[$137>>3];
       $262 = $261 + $260;
       $263 = $252 * $262;
       $264 = +HEAPF64[$138>>3];
       $265 = $129 * $264;
       $266 = +HEAPF64[$139>>3];
       $267 = $130 * $266;
       $268 = $265 + $267;
       $269 = +HEAPF64[$140>>3];
       $270 = $269 * 0.0;
       $271 = $268 + $270;
       $272 = +HEAPF64[$141>>3];
       $273 = $272 + $271;
       $274 = $252 * $273;
       do {
        if ($215) {
         $275 = ((($214)) + 56|0);
         $276 = +HEAPF64[$275>>3];
         $277 = $276 + -0.5;
         $278 = !($263 >= $277);
         if ($278) {
          break;
         }
         $279 = ((($214)) + 64|0);
         $280 = +HEAPF64[$279>>3];
         $281 = $280 + -0.5;
         $282 = !($274 >= $281);
         if ($282) {
          break;
         }
         $283 = ((($214)) + 72|0);
         $284 = +HEAPF64[$283>>3];
         $285 = $276 + $284;
         $286 = $285 + -1.0;
         $287 = $286 + 0.5;
         $288 = $263 < $287;
         if (!($288)) {
          break;
         }
         $289 = ((($214)) + 80|0);
         $290 = +HEAPF64[$289>>3];
         $291 = $280 + $290;
         $292 = $291 + -1.0;
         $293 = $292 + 0.5;
         $294 = !($274 <= $293);
         if (!($294)) {
          label = 62;
          break L20;
         }
        }
       } while(0);
      }
     }
    }
    $$0117 = (($$0117199) + -1)|0;
    $299 = ($$0117|0)>(-1);
    if (!($299)) {
     label = 64;
     break L18;
    }
    $$pre = HEAP32[$124>>2]|0;
    $$0117199 = $$0117;$143 = $$pre;
   }
   do {
    if ((label|0) == 27) {
     $190 = ___cxa_find_matching_catch_2()|0;
     $191 = tempRet0;
     __THREW__ = 0;
     invoke_vi(3263,($5|0));
     $192 = __THREW__; __THREW__ = 0;
     $193 = $192&1;
     if ($193) {
      $194 = ___cxa_find_matching_catch_3(0|0)|0;
      $195 = tempRet0;
      ___clang_call_terminate($194);
      // unreachable;
     } else {
      $eh$lpad$body$index4Z2D = $191;$eh$lpad$body$indexZ2D = $190;
      label = 34;
      break;
     }
    }
    else if ((label|0) == 33) {
     $202 = ___cxa_find_matching_catch_2()|0;
     $203 = tempRet0;
     $eh$lpad$body$index4Z2D = $203;$eh$lpad$body$indexZ2D = $202;
     label = 34;
    }
    else if ((label|0) == 43) {
     $220 = ___cxa_find_matching_catch_2()|0;
     $221 = tempRet0;
     $$5123 = $221;$$5129 = $220;
     ___resumeException($$5129|0);
     // unreachable;
    }
    else if ((label|0) == 44) {
     $222 = ___cxa_find_matching_catch_2()|0;
     $223 = tempRet0;
     $$1119 = $223;$$1125 = $222;
     label = 61;
    }
    else if ((label|0) == 56) {
     $295 = ___cxa_find_matching_catch_2()|0;
     $296 = tempRet0;
     $$1119 = $296;$$1125 = $295;
     label = 61;
    }
    else if ((label|0) == 57) {
     $297 = ___cxa_find_matching_catch_2()|0;
     $298 = tempRet0;
     $$1119 = $298;$$1125 = $297;
     label = 61;
    }
    else if ((label|0) == 62) {
     $300 = $274;
     $301 = $263;
     HEAPF32[$3>>2] = $301;
     HEAPF32[$4>>2] = $300;
     $$7 = $204;
     break L18;
    }
   } while(0);
   if ((label|0) == 34) {
    $$5123 = $eh$lpad$body$index4Z2D;$$5129 = $eh$lpad$body$indexZ2D;
    ___resumeException($$5129|0);
    // unreachable;
   }
   else if ((label|0) == 61) {
    $$5123 = $$1119;$$5129 = $$1125;
    ___resumeException($$5129|0);
    // unreachable;
   }
  } else {
   label = 64;
  }
 } while(0);
 if ((label|0) == 64) {
  HEAPF32[$3>>2] = $102;
  HEAPF32[$4>>2] = $$136;
  $$7 = 0;
 }
 $$8 = $$7;
 STACKTOP = sp;return ($$8|0);
}
function __ZNK3osg8Viewport19computeWindowMatrixEv($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$2 = 0, $$24 = 0, $10 = 0, $11 = 0, $12 = 0.0, $13 = 0.0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0.0, $22 = 0, $23 = 0.0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0.0, $8 = 0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 512|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(512|0);
 $2 = sp + 384|0;
 $3 = sp + 256|0;
 $4 = sp + 128|0;
 $5 = sp;
 __ZN3osg7Matrixd12makeIdentityEv($3);
 __ZN3osg7Matrixd13makeTranslateEddd($3,1.0,1.0,1.0);
 $6 = ((($1)) + 72|0);
 $7 = +HEAPF64[$6>>3];
 $8 = ((($1)) + 80|0);
 $9 = +HEAPF64[$8>>3];
 __THREW__ = 0;
 invoke_vi(3299,($4|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if (!($11)) {
  $12 = $9 * 0.5;
  $13 = $7 * 0.5;
  __THREW__ = 0;
  invoke_viddd(3305,($4|0),(+$13),(+$12),0.5);
  $14 = __THREW__; __THREW__ = 0;
  $15 = $14&1;
  if (!($15)) {
   __THREW__ = 0;
   invoke_vi(3299,($2|0));
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    __THREW__ = 0;
    invoke_viii(3300,($2|0),($3|0),($4|0));
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     $20 = ((($1)) + 56|0);
     $21 = +HEAPF64[$20>>3];
     $22 = ((($1)) + 64|0);
     $23 = +HEAPF64[$22>>3];
     __THREW__ = 0;
     invoke_vi(3299,($5|0));
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if (!($25)) {
      __THREW__ = 0;
      invoke_viddd(3306,($5|0),(+$21),(+$23),0.0);
      $26 = __THREW__; __THREW__ = 0;
      $27 = $26&1;
      if (!($27)) {
       __THREW__ = 0;
       invoke_vi(3299,($0|0));
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_viii(3300,($0|0),($2|0),($5|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         STACKTOP = sp;return;
        }
       }
      }
     }
     $36 = ___cxa_find_matching_catch_2()|0;
     $37 = tempRet0;
     $$2 = $37;$$24 = $36;
     ___resumeException($$24|0);
     // unreachable;
    }
   }
   $34 = ___cxa_find_matching_catch_2()|0;
   $35 = tempRet0;
   $$2 = $35;$$24 = $34;
   ___resumeException($$24|0);
   // unreachable;
  }
 }
 $32 = ___cxa_find_matching_catch_2()|0;
 $33 = tempRet0;
 $$2 = $33;$$24 = $32;
 ___resumeException($$24|0);
 // unreachable;
}
function __ZN9osgViewer4View20computeIntersectionsEPKN3osg6CameraEN7osgUtil11Intersector15CoordinateFrameEffRKNSt3__26vectorIPNS1_4NodeENS8_9allocatorISB_EEEERNS8_8multisetINS5_22LineSegmentIntersector12IntersectionENS8_4lessISJ_EENSC_ISJ_EEEEj($0,$1,$2,$3,$4,$5,$6,$7) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = +$3;
 $4 = +$4;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 var $$$i = 0, $$028 = 0.0, $$040 = 0, $$141 = 0, $$2 = 0, $$232 = 0, $$3 = 0, $$333 = 0, $$5 = 0, $$535 = 0, $$7 = 0, $$737 = 0, $$9 = 0, $$939 = 0, $$byval_copy = 0, $$byval_copy20 = 0, $10 = 0, $100 = 0.0, $101 = 0, $102 = 0;
 var $103 = 0.0, $104 = 0, $105 = 0, $106 = 0.0, $107 = 0, $108 = 0, $109 = 0.0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0;
 var $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0.0, $155 = 0, $156 = 0, $157 = 0.0;
 var $158 = 0, $159 = 0, $16 = 0, $160 = 0.0, $161 = 0, $162 = 0, $163 = 0.0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0.0, $17 = 0, $170 = 0.0, $171 = 0, $172 = 0.0, $173 = 0.0, $174 = 0, $175 = 0.0;
 var $176 = 0.0, $177 = 0.0, $178 = 0, $179 = 0.0, $18 = 0, $180 = 0.0, $181 = 0.0, $182 = 0, $183 = 0.0, $184 = 0.0, $185 = 0.0, $186 = 0.0, $187 = 0.0, $188 = 0, $189 = 0.0, $19 = 0, $190 = 0.0, $191 = 0.0, $192 = 0, $193 = 0.0;
 var $194 = 0.0, $195 = 0.0, $196 = 0, $197 = 0.0, $198 = 0.0, $199 = 0.0, $20 = 0, $200 = 0, $201 = 0.0, $202 = 0.0, $203 = 0, $204 = 0.0, $205 = 0.0, $206 = 0.0, $207 = 0, $208 = 0.0, $209 = 0.0, $21 = 0, $210 = 0.0, $211 = 0;
 var $212 = 0.0, $213 = 0.0, $214 = 0.0, $215 = 0, $216 = 0.0, $217 = 0.0, $218 = 0, $219 = 0.0, $22 = 0, $220 = 0.0, $221 = 0.0, $222 = 0, $223 = 0.0, $224 = 0.0, $225 = 0.0, $226 = 0, $227 = 0.0, $228 = 0.0, $229 = 0.0, $23 = 0;
 var $230 = 0, $231 = 0, $232 = 0.0, $233 = 0.0, $234 = 0.0, $235 = 0.0, $236 = 0.0, $237 = 0.0, $238 = 0.0, $239 = 0.0, $24 = 0, $240 = 0.0, $241 = 0.0, $242 = 0.0, $243 = 0.0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0;
 var $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0;
 var $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0;
 var $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0;
 var $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0;
 var $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0.0, $66 = 0, $67 = 0.0, $68 = 0, $69 = 0, $70 = 0.0, $71 = 0, $72 = 0, $73 = 0.0, $74 = 0, $75 = 0, $76 = 0.0, $77 = 0, $78 = 0, $79 = 0.0, $8 = 0, $80 = 0, $81 = 0, $82 = 0.0;
 var $83 = 0, $84 = 0, $85 = 0.0, $86 = 0, $87 = 0, $88 = 0.0, $89 = 0, $9 = 0, $90 = 0, $91 = 0.0, $92 = 0, $93 = 0, $94 = 0.0, $95 = 0, $96 = 0, $97 = 0.0, $98 = 0, $99 = 0, $eh$lpad$body$index11Z2D = 0, $eh$lpad$body$indexZ2D = 0;
 var $eh$lpad$body46$index5Z2D = 0, $eh$lpad$body46$indexZ2D = 0, $eh$lpad$body54$indexZ2D = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i$i47 = 0, $scevgep5$i$i$i = 0, $scevgep5$i$i$i$i = 0, $scevgep5$i$i$i48 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 784|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(784|0);
 $$byval_copy20 = sp + 776|0;
 $$byval_copy = sp + 772|0;
 $8 = sp + 768|0;
 $9 = sp + 764|0;
 $10 = sp + 432|0;
 $11 = sp + 752|0;
 $12 = sp + 304|0;
 $13 = sp + 176|0;
 $14 = sp + 48|0;
 $15 = sp + 24|0;
 $16 = sp;
 $17 = sp + 560|0;
 $18 = ($1|0)==(0|0);
 if ($18) {
  $$141 = 0;
  STACKTOP = sp;return ($$141|0);
 }
 $19 = HEAP32[$5>>2]|0;
 $20 = ((($5)) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($19|0)==($21|0);
 if ($22) {
  $$141 = 0;
  STACKTOP = sp;return ($$141|0);
 }
 __ZN3osg7Matrixd12makeIdentityEv($10);
 $23 = HEAP32[$20>>2]|0;
 $24 = HEAP32[$5>>2]|0;
 $25 = (($23) - ($24))|0;
 $26 = $25 >> 2;
 $27 = ($26>>>0)>(1);
 $28 = $24;
 L7: do {
  if ($27) {
   $29 = $23;
   $30 = ((($29)) + -4|0);
   $31 = $30;
   HEAP32[$11>>2] = 0;
   $32 = ((($11)) + 4|0);
   HEAP32[$32>>2] = 0;
   $33 = ((($11)) + 8|0);
   HEAP32[$33>>2] = 0;
   $34 = (($31) - ($24))|0;
   $35 = $34 >> 2;
   $36 = ($35|0)==(0);
   L9: do {
    if (!($36)) {
     $37 = ($35>>>0)>(1073741823);
     if ($37) {
      __THREW__ = 0;
      invoke_vi(3307,($11|0));
      $38 = __THREW__; __THREW__ = 0;
     } else {
      __THREW__ = 0;
      $39 = (invoke_ii(3276,($34|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if (!($41)) {
       HEAP32[$32>>2] = $39;
       HEAP32[$11>>2] = $39;
       $42 = (($39) + ($35<<2)|0);
       $43 = ((($11)) + 8|0);
       HEAP32[$43>>2] = $42;
       $44 = ($28|0)==($30|0);
       if ($44) {
        break;
       }
       $46 = $28;$47 = $39;
       while(1) {
        $45 = HEAP32[$46>>2]|0;
        HEAP32[$47>>2] = $45;
        $48 = ((($46)) + 4|0);
        $49 = HEAP32[$32>>2]|0;
        $50 = ((($49)) + 4|0);
        HEAP32[$32>>2] = $50;
        $51 = ($48|0)==($30|0);
        if ($51) {
         break L9;
        } else {
         $46 = $48;$47 = $50;
        }
       }
      }
     }
     $52 = ___cxa_find_matching_catch_2()|0;
     $53 = tempRet0;
     $54 = HEAP32[$11>>2]|0;
     $55 = ($54|0)==(0|0);
     if ($55) {
      $eh$lpad$body46$index5Z2D = $53;$eh$lpad$body46$indexZ2D = $52;
      break L7;
     }
     $56 = HEAP32[$32>>2]|0;
     $57 = ($56|0)==($54|0);
     if (!($57)) {
      $scevgep$i$i$i$i = ((($56)) + -4|0);
      $58 = $scevgep$i$i$i$i;
      $59 = $54;
      $60 = (($58) - ($59))|0;
      $61 = $60 >>> 2;
      $62 = $61 ^ -1;
      $scevgep5$i$i$i$i = (($56) + ($62<<2)|0);
      HEAP32[$32>>2] = $scevgep5$i$i$i$i;
     }
     __ZdlPv($54);
     $eh$lpad$body46$index5Z2D = $53;$eh$lpad$body46$indexZ2D = $52;
     break L7;
    }
   } while(0);
   __THREW__ = 0;
   invoke_viii(3308,($12|0),($11|0),1);
   $63 = __THREW__; __THREW__ = 0;
   $64 = $63&1;
   if (!($64)) {
    $65 = +HEAPF64[$12>>3];
    HEAPF64[$10>>3] = $65;
    $66 = ((($12)) + 8|0);
    $67 = +HEAPF64[$66>>3];
    $68 = ((($10)) + 8|0);
    HEAPF64[$68>>3] = $67;
    $69 = ((($12)) + 16|0);
    $70 = +HEAPF64[$69>>3];
    $71 = ((($10)) + 16|0);
    HEAPF64[$71>>3] = $70;
    $72 = ((($12)) + 24|0);
    $73 = +HEAPF64[$72>>3];
    $74 = ((($10)) + 24|0);
    HEAPF64[$74>>3] = $73;
    $75 = ((($12)) + 32|0);
    $76 = +HEAPF64[$75>>3];
    $77 = ((($10)) + 32|0);
    HEAPF64[$77>>3] = $76;
    $78 = ((($12)) + 40|0);
    $79 = +HEAPF64[$78>>3];
    $80 = ((($10)) + 40|0);
    HEAPF64[$80>>3] = $79;
    $81 = ((($12)) + 48|0);
    $82 = +HEAPF64[$81>>3];
    $83 = ((($10)) + 48|0);
    HEAPF64[$83>>3] = $82;
    $84 = ((($12)) + 56|0);
    $85 = +HEAPF64[$84>>3];
    $86 = ((($10)) + 56|0);
    HEAPF64[$86>>3] = $85;
    $87 = ((($12)) + 64|0);
    $88 = +HEAPF64[$87>>3];
    $89 = ((($10)) + 64|0);
    HEAPF64[$89>>3] = $88;
    $90 = ((($12)) + 72|0);
    $91 = +HEAPF64[$90>>3];
    $92 = ((($10)) + 72|0);
    HEAPF64[$92>>3] = $91;
    $93 = ((($12)) + 80|0);
    $94 = +HEAPF64[$93>>3];
    $95 = ((($10)) + 80|0);
    HEAPF64[$95>>3] = $94;
    $96 = ((($12)) + 88|0);
    $97 = +HEAPF64[$96>>3];
    $98 = ((($10)) + 88|0);
    HEAPF64[$98>>3] = $97;
    $99 = ((($12)) + 96|0);
    $100 = +HEAPF64[$99>>3];
    $101 = ((($10)) + 96|0);
    HEAPF64[$101>>3] = $100;
    $102 = ((($12)) + 104|0);
    $103 = +HEAPF64[$102>>3];
    $104 = ((($10)) + 104|0);
    HEAPF64[$104>>3] = $103;
    $105 = ((($12)) + 112|0);
    $106 = +HEAPF64[$105>>3];
    $107 = ((($10)) + 112|0);
    HEAPF64[$107>>3] = $106;
    $108 = ((($12)) + 120|0);
    $109 = +HEAPF64[$108>>3];
    $110 = ((($10)) + 120|0);
    HEAPF64[$110>>3] = $109;
    $111 = HEAP32[$11>>2]|0;
    $112 = ($111|0)==(0|0);
    if (!($112)) {
     $113 = HEAP32[$32>>2]|0;
     $114 = ($113|0)==($111|0);
     if (!($114)) {
      $scevgep$i$i$i = ((($113)) + -4|0);
      $115 = $scevgep$i$i$i;
      $116 = $111;
      $117 = (($115) - ($116))|0;
      $118 = $117 >>> 2;
      $119 = $118 ^ -1;
      $scevgep5$i$i$i = (($113) + ($119<<2)|0);
      HEAP32[$32>>2] = $scevgep5$i$i$i;
     }
     __ZdlPv($111);
    }
    label = 28;
    break;
   }
   $122 = ___cxa_find_matching_catch_2()|0;
   $123 = tempRet0;
   $124 = HEAP32[$11>>2]|0;
   $125 = ($124|0)==(0|0);
   if (!($125)) {
    $126 = HEAP32[$32>>2]|0;
    $127 = ($126|0)==($124|0);
    if (!($127)) {
     $scevgep$i$i$i47 = ((($126)) + -4|0);
     $128 = $scevgep$i$i$i47;
     $129 = $124;
     $130 = (($128) - ($129))|0;
     $131 = $130 >>> 2;
     $132 = $131 ^ -1;
     $scevgep5$i$i$i48 = (($126) + ($132<<2)|0);
     HEAP32[$32>>2] = $scevgep5$i$i$i48;
    }
    __ZdlPv($124);
   }
   $$9 = $123;$$939 = $122;
   ___resumeException($$939|0);
   // unreachable;
  } else {
   label = 28;
  }
 } while(0);
 if ((label|0) == 28) {
  $133 = ((($1)) + 432|0);
  __THREW__ = 0;
  invoke_vii(3302,($10|0),($133|0));
  $134 = __THREW__; __THREW__ = 0;
  $135 = $134&1;
  if (!($135)) {
   $136 = ((($1)) + 304|0);
   __THREW__ = 0;
   invoke_vii(3302,($10|0),($136|0));
   $137 = __THREW__; __THREW__ = 0;
   $138 = $137&1;
   if (!($138)) {
    $139 = ($2|0)==(0);
    do {
     if ($139) {
      $140 = ((($1)) + 288|0);
      $141 = HEAP32[$140>>2]|0;
      $142 = ($141|0)==(0|0);
      if ($142) {
       $$028 = -1.0;
      } else {
       __THREW__ = 0;
       invoke_vii(3301,($13|0),($141|0));
       $143 = __THREW__; __THREW__ = 0;
       $144 = $143&1;
       if (!($144)) {
        __THREW__ = 0;
        invoke_vii(3302,($10|0),($13|0));
        $145 = __THREW__; __THREW__ = 0;
        $146 = $145&1;
        if (!($146)) {
         $$028 = 0.0;
         break;
        }
       }
       $149 = ___cxa_find_matching_catch_2()|0;
       $150 = tempRet0;
       $$9 = $150;$$939 = $149;
       ___resumeException($$939|0);
       // unreachable;
      }
     } else {
      $$028 = -1.0;
     }
    } while(0);
    __THREW__ = 0;
    invoke_vi(3299,($14|0));
    $151 = __THREW__; __THREW__ = 0;
    $152 = $151&1;
    if ($152) {
     $147 = ___cxa_find_matching_catch_2()|0;
     $148 = tempRet0;
     $$9 = $148;$$939 = $147;
     ___resumeException($$939|0);
     // unreachable;
    }
    $153 = ((($10)) + 24|0);
    $154 = +HEAPF64[$153>>3];
    $155 = $154 == 0.0;
    if ($155) {
     $156 = ((($10)) + 56|0);
     $157 = +HEAPF64[$156>>3];
     $158 = $157 == 0.0;
     if ($158) {
      $159 = ((($10)) + 88|0);
      $160 = +HEAPF64[$159>>3];
      $161 = $160 == 0.0;
      if ($161) {
       $162 = ((($10)) + 120|0);
       $163 = +HEAPF64[$162>>3];
       $164 = $163 == 1.0;
       if ($164) {
        __THREW__ = 0;
        (invoke_iii(3303,($14|0),($10|0))|0);
        $165 = __THREW__; __THREW__ = 0;
        $166 = $165&1;
        if ($166) {
         label = 53;
        } else {
         label = 44;
        }
       } else {
        label = 43;
       }
      } else {
       label = 43;
      }
     } else {
      label = 43;
     }
    } else {
     label = 43;
    }
    if ((label|0) == 43) {
     __THREW__ = 0;
     (invoke_iii(3304,($14|0),($10|0))|0);
     $167 = __THREW__; __THREW__ = 0;
     $168 = $167&1;
     if ($168) {
      label = 53;
     } else {
      label = 44;
     }
    }
    if ((label|0) == 44) {
     $169 = $3;
     $170 = $4;
     $171 = ((($14)) + 24|0);
     $172 = +HEAPF64[$171>>3];
     $173 = $169 * $172;
     $174 = ((($14)) + 56|0);
     $175 = +HEAPF64[$174>>3];
     $176 = $170 * $175;
     $177 = $173 + $176;
     $178 = ((($14)) + 88|0);
     $179 = +HEAPF64[$178>>3];
     $180 = $$028 * $179;
     $181 = $177 + $180;
     $182 = ((($14)) + 120|0);
     $183 = +HEAPF64[$182>>3];
     $184 = $183 + $181;
     $185 = 1.0 / $184;
     $186 = +HEAPF64[$14>>3];
     $187 = $169 * $186;
     $188 = ((($14)) + 32|0);
     $189 = +HEAPF64[$188>>3];
     $190 = $170 * $189;
     $191 = $187 + $190;
     $192 = ((($14)) + 64|0);
     $193 = +HEAPF64[$192>>3];
     $194 = $$028 * $193;
     $195 = $191 + $194;
     $196 = ((($14)) + 96|0);
     $197 = +HEAPF64[$196>>3];
     $198 = $197 + $195;
     $199 = $185 * $198;
     $200 = ((($14)) + 8|0);
     $201 = +HEAPF64[$200>>3];
     $202 = $169 * $201;
     $203 = ((($14)) + 40|0);
     $204 = +HEAPF64[$203>>3];
     $205 = $170 * $204;
     $206 = $202 + $205;
     $207 = ((($14)) + 72|0);
     $208 = +HEAPF64[$207>>3];
     $209 = $$028 * $208;
     $210 = $206 + $209;
     $211 = ((($14)) + 104|0);
     $212 = +HEAPF64[$211>>3];
     $213 = $212 + $210;
     $214 = $185 * $213;
     $215 = ((($14)) + 16|0);
     $216 = +HEAPF64[$215>>3];
     $217 = $169 * $216;
     $218 = ((($14)) + 48|0);
     $219 = +HEAPF64[$218>>3];
     $220 = $170 * $219;
     $221 = $217 + $220;
     $222 = ((($14)) + 80|0);
     $223 = +HEAPF64[$222>>3];
     $224 = $$028 * $223;
     $225 = $221 + $224;
     $226 = ((($14)) + 112|0);
     $227 = +HEAPF64[$226>>3];
     $228 = $227 + $225;
     $229 = $185 * $228;
     HEAPF64[$15>>3] = $199;
     $230 = ((($15)) + 8|0);
     HEAPF64[$230>>3] = $214;
     $231 = ((($15)) + 16|0);
     HEAPF64[$231>>3] = $229;
     $232 = $179 + $177;
     $233 = $183 + $232;
     $234 = 1.0 / $233;
     $235 = $193 + $191;
     $236 = $197 + $235;
     $237 = $234 * $236;
     $238 = $208 + $206;
     $239 = $212 + $238;
     $240 = $234 * $239;
     $241 = $223 + $221;
     $242 = $227 + $241;
     $243 = $234 * $242;
     HEAPF64[$16>>3] = $237;
     $244 = ((($16)) + 8|0);
     HEAPF64[$244>>3] = $240;
     $245 = ((($16)) + 16|0);
     HEAPF64[$245>>3] = $243;
     __THREW__ = 0;
     $246 = (invoke_ii(3276,96)|0);
     $247 = __THREW__; __THREW__ = 0;
     $248 = $247&1;
     L68: do {
      if ($248) {
       $281 = ___cxa_find_matching_catch_2()|0;
       $282 = tempRet0;
       $$5 = $282;$$535 = $281;
      } else {
       __THREW__ = 0;
       invoke_viiiiii(3309,($246|0),3,($15|0),($16|0),(0|0),0);
       $249 = __THREW__; __THREW__ = 0;
       $250 = $249&1;
       if ($250) {
        $283 = ___cxa_find_matching_catch_2()|0;
        $284 = tempRet0;
        __ZdlPv($246);
        $$5 = $284;$$535 = $283;
        break;
       }
       $251 = ((($246)) + 8|0);
       $252 = HEAP32[$251>>2]|0;HEAP32[$251>>2] = (($252+1)|0);
       __THREW__ = 0;
       invoke_viii(3310,($17|0),($246|0),(0|0));
       $253 = __THREW__; __THREW__ = 0;
       $254 = $253&1;
       L74: do {
        if ($254) {
         $285 = ___cxa_find_matching_catch_2()|0;
         $286 = tempRet0;
         $$3 = $286;$$333 = $285;
         label = 73;
        } else {
         $255 = ((($17)) + 20|0);
         HEAP32[$255>>2] = $7;
         $256 = HEAP32[$20>>2]|0;
         $257 = ((($256)) + -4|0);
         $258 = HEAP32[$257>>2]|0;
         $259 = HEAP32[$258>>2]|0;
         $260 = ((($259)) + 188|0);
         $261 = HEAP32[$260>>2]|0;
         __THREW__ = 0;
         invoke_vii($261|0,($258|0),($17|0));
         $262 = __THREW__; __THREW__ = 0;
         $263 = $262&1;
         do {
          if ($263) {
           label = 57;
          } else {
           $264 = HEAP32[$246>>2]|0;
           $265 = ((($264)) + 32|0);
           $266 = HEAP32[$265>>2]|0;
           __THREW__ = 0;
           $267 = (invoke_ii($266|0,($246|0))|0);
           $268 = __THREW__; __THREW__ = 0;
           $269 = $268&1;
           if ($269) {
            label = 57;
           } else {
            if ($267) {
             $270 = ((($246)) + 28|0);
             $271 = HEAP32[$270>>2]|0;
             $272 = ($271|0)==(0|0);
             $$$i = $272 ? $246 : $271;
             $273 = ((($$$i)) + 80|0);
             $274 = ($273|0)==($6|0);
             if (!($274)) {
              $275 = HEAP32[$273>>2]|0;
              HEAP32[$8>>2] = $275;
              $276 = ((($$$i)) + 84|0);
              HEAP32[$9>>2] = $276;
              __THREW__ = 0;
              ;HEAP32[$$byval_copy>>2]=HEAP32[$8>>2]|0;
              ;HEAP32[$$byval_copy20>>2]=HEAP32[$9>>2]|0;
              invoke_viii(3311,($6|0),($$byval_copy|0),($$byval_copy20|0));
              $277 = __THREW__; __THREW__ = 0;
              $278 = $277&1;
              if ($278) {
               label = 57;
               break;
              }
             }
             $$040 = 1;
            } else {
             $301 = ((($6)) + 4|0);
             $302 = HEAP32[$301>>2]|0;
             __ZNSt3__26__treeIN7osgUtil22LineSegmentIntersector12IntersectionENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($6,$302);
             $303 = ((($6)) + 8|0);
             HEAP32[$303>>2] = 0;
             HEAP32[$6>>2] = $301;
             HEAP32[$301>>2] = 0;
             $$040 = 0;
            }
            __THREW__ = 0;
            invoke_vii(3312,($17|0),(47564|0));
            $304 = __THREW__; __THREW__ = 0;
            $305 = $304&1;
            do {
             if ($305) {
              $309 = ___cxa_find_matching_catch_2()|0;
              $310 = tempRet0;
              $311 = ((($17)) + 160|0);
              __THREW__ = 0;
              invoke_vi(388,($311|0));
              $312 = __THREW__; __THREW__ = 0;
              $313 = $312&1;
              if (!($313)) {
               $eh$lpad$body$index11Z2D = $310;$eh$lpad$body$indexZ2D = $309;
               break;
              }
              $314 = ___cxa_find_matching_catch_3(0|0)|0;
              $315 = tempRet0;
              ___clang_call_terminate($314);
              // unreachable;
             } else {
              $306 = ((($17)) + 160|0);
              __THREW__ = 0;
              invoke_vi(388,($306|0));
              $307 = __THREW__; __THREW__ = 0;
              $308 = $307&1;
              if ($308) {
               $320 = ___cxa_find_matching_catch_2()|0;
               $321 = tempRet0;
               $eh$lpad$body$index11Z2D = $321;$eh$lpad$body$indexZ2D = $320;
               break;
              }
              $316 = HEAP32[$251>>2]|0;HEAP32[$251>>2] = (($316-1)|0);
              $317 = ($316|0)==(1);
              do {
               if ($317) {
                __THREW__ = 0;
                invoke_viii(3262,($246|0),1,1);
                $318 = __THREW__; __THREW__ = 0;
                $319 = $318&1;
                if (!($319)) {
                 break;
                }
                $322 = ___cxa_find_matching_catch_2()|0;
                $323 = tempRet0;
                $$5 = $323;$$535 = $322;
                break L68;
               }
              } while(0);
              $$141 = $$040;
              STACKTOP = sp;return ($$141|0);
             }
            } while(0);
            $$2 = $eh$lpad$body$index11Z2D;$$232 = $eh$lpad$body$indexZ2D;
           }
          }
         } while(0);
         do {
          if ((label|0) == 57) {
           $287 = ___cxa_find_matching_catch_2()|0;
           $288 = tempRet0;
           __THREW__ = 0;
           invoke_vii(3312,($17|0),(47564|0));
           $289 = __THREW__; __THREW__ = 0;
           $290 = $289&1;
           if (!($290)) {
            $291 = ((($17)) + 160|0);
            __THREW__ = 0;
            invoke_vi(388,($291|0));
            $292 = __THREW__; __THREW__ = 0;
            $293 = $292&1;
            if ($293) {
             break L74;
            } else {
             $$2 = $288;$$232 = $287;
             break;
            }
           }
           $294 = ___cxa_find_matching_catch_3(0|0)|0;
           $295 = tempRet0;
           $296 = ((($17)) + 160|0);
           __THREW__ = 0;
           invoke_vi(388,($296|0));
           $297 = __THREW__; __THREW__ = 0;
           $298 = $297&1;
           if ($298) {
            $299 = ___cxa_find_matching_catch_3(0|0)|0;
            $300 = tempRet0;
            ___clang_call_terminate($299);
            // unreachable;
           } else {
            $eh$lpad$body54$indexZ2D = $294;
            ___clang_call_terminate($eh$lpad$body54$indexZ2D);
            // unreachable;
           }
          }
         } while(0);
         $$3 = $$2;$$333 = $$232;
         label = 73;
        }
       } while(0);
       if ((label|0) == 73) {
        $324 = HEAP32[$251>>2]|0;HEAP32[$251>>2] = (($324-1)|0);
        $325 = ($324|0)==(1);
        if (!($325)) {
         $$5 = $$3;$$535 = $$333;
         break;
        }
        __THREW__ = 0;
        invoke_viii(3262,($246|0),1,1);
        $326 = __THREW__; __THREW__ = 0;
        $327 = $326&1;
        if (!($327)) {
         $$5 = $$3;$$535 = $$333;
         break;
        }
       }
       $328 = ___cxa_find_matching_catch_3(0|0)|0;
       $329 = tempRet0;
       $eh$lpad$body54$indexZ2D = $328;
       ___clang_call_terminate($eh$lpad$body54$indexZ2D);
       // unreachable;
      }
     } while(0);
     $$7 = $$5;$$737 = $$535;
    }
    else if ((label|0) == 53) {
     $279 = ___cxa_find_matching_catch_2()|0;
     $280 = tempRet0;
     $$7 = $280;$$737 = $279;
    }
    $$9 = $$7;$$939 = $$737;
    ___resumeException($$939|0);
    // unreachable;
   }
  }
  $120 = ___cxa_find_matching_catch_2()|0;
  $121 = tempRet0;
  $eh$lpad$body46$index5Z2D = $121;$eh$lpad$body46$indexZ2D = $120;
 }
 $$9 = $eh$lpad$body46$index5Z2D;$$939 = $eh$lpad$body46$indexZ2D;
 ___resumeException($$939|0);
 // unreachable;
 return (0)|0;
}
function __ZN9osgViewer4View20computeIntersectionsEffRKNSt3__26vectorIPN3osg4NodeENS1_9allocatorIS5_EEEERNS1_8multisetIN7osgUtil22LineSegmentIntersector12IntersectionENS1_4lessISE_EENS6_ISE_EEEEj($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = +$1;
 $2 = +$2;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0.0, $18 = 0, $19 = 0, $20 = 0.0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0.0, $47 = 0.0, $48 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $6 = sp + 8|0;
 $7 = sp + 4|0;
 $8 = sp;
 $9 = (__ZNK9osgViewer4View27getCameraContainingPositionEffRfS1_($0,$1,$2,$7,$8)|0);
 $10 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
 do {
  if ($10) {
   $11 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
   $12 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($11,102588,21)|0);
   $13 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEf($12,$1)|0);
   $14 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($13,146554,2)|0);
   $15 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEf($14,$2)|0);
   $16 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($15,102610,10)|0);
   $17 = +HEAPF32[$7>>2];
   $18 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEf($16,$17)|0);
   $19 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($18,102621,10)|0);
   $20 = +HEAPF32[$8>>2];
   $21 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEf($19,$20)|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = ((($22)) + -12|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = (($21) + ($24)|0);
   __ZNKSt3__28ios_base6getlocEv($6,$25);
   __THREW__ = 0;
   $26 = (invoke_iii(3255,($6|0),(215188|0))|0);
   $27 = __THREW__; __THREW__ = 0;
   $28 = $27&1;
   if (!($28)) {
    $29 = HEAP32[$26>>2]|0;
    $30 = ((($29)) + 28|0);
    $31 = HEAP32[$30>>2]|0;
    __THREW__ = 0;
    $32 = (invoke_iii($31|0,($26|0),10)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     __ZNSt3__26localeD2Ev($6);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($21,$32)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($21)|0);
     break;
    }
   }
   $35 = ___cxa_find_matching_catch_2()|0;
   $36 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($6|0));
   $37 = __THREW__; __THREW__ = 0;
   $38 = $37&1;
   if ($38) {
    $39 = ___cxa_find_matching_catch_3(0|0)|0;
    $40 = tempRet0;
    ___clang_call_terminate($39);
    // unreachable;
   } else {
    ___resumeException($35|0);
    // unreachable;
   }
  }
 } while(0);
 $41 = ($9|0)==(0|0);
 if ($41) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $42 = ((($9)) + 288|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = ($43|0)==(0|0);
 $45 = $44&1;
 $46 = +HEAPF32[$7>>2];
 $47 = +HEAPF32[$8>>2];
 $48 = (__ZN9osgViewer4View20computeIntersectionsEPKN3osg6CameraEN7osgUtil11Intersector15CoordinateFrameEffRKNSt3__26vectorIPNS1_4NodeENS8_9allocatorISB_EEEERNS8_8multisetINS5_22LineSegmentIntersector12IntersectionENS8_4lessISJ_EENSC_ISJ_EEEEj(0,$9,$45,$46,$47,$3,$4,$5)|0);
 $$0 = $48;
 STACKTOP = sp;return ($$0|0);
}
function __ZNSt3__26__treeIN7osgUtil22LineSegmentIntersector12IntersectionENS_4lessIS3_EENS_9allocatorIS3_EEE14__assign_multiINS_21__tree_const_iteratorIS3_PNS_11__tree_nodeIS3_PvEEiEEEEvT_SG_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$$i = 0, $$0$be$in$i$i = 0, $$0$be$in$i$i27 = 0, $$0$i = 0, $$0$i$i = 0, $$0$i$i$i = 0, $$0$i$i$i35 = 0, $$0$i$i21 = 0, $$0$i$i22 = 0, $$0$i$i25 = 0, $$0$i$i39 = 0, $$0$i11$i = 0, $$0$i30 = 0, $$015$i$i = 0, $$015$i$i31 = 0, $$030$i = 0, $$057 = 0, $$1$lcssa = 0, $$2$lcssa = 0, $$in74 = 0;
 var $$in76 = 0, $$pre = 0, $$pre$i$i = 0, $$pre$i$i33 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0.0, $11 = 0, $110 = 0, $111 = 0.0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0.0, $48 = 0, $49 = 0.0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 L1: do {
  if (!($5)) {
   $6 = HEAP32[$0>>2]|0;
   $7 = ((($0)) + 4|0);
   HEAP32[$0>>2] = $7;
   $8 = HEAP32[$7>>2]|0;
   $9 = ((($8)) + 8|0);
   HEAP32[$9>>2] = 0;
   HEAP32[$7>>2] = 0;
   HEAP32[$3>>2] = 0;
   $10 = ((($6)) + 4|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = ($11|0)==(0|0);
   $$$i = $12 ? $6 : $11;
   $13 = ($$$i|0)==(0|0);
   if (!($13)) {
    $14 = ((($0)) + 4|0);
    $$pre = HEAP32[$1>>2]|0;
    $$057 = $$$i;$$in74 = $$pre;
    while(1) {
     $15 = HEAP32[$2>>2]|0;
     $16 = ($$in74|0)==($15|0);
     if ($16) {
      label = 5;
      break;
     }
     $20 = ((($$in74)) + 16|0);
     $21 = ((($$057)) + 16|0);
     __THREW__ = 0;
     (invoke_iii(3313,($21|0),($20|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     $24 = ((($$057)) + 8|0);
     $25 = HEAP32[$24>>2]|0;
     $26 = ($25|0)==(0|0);
     do {
      if ($26) {
       $$0$i = 0;
      } else {
       $27 = HEAP32[$25>>2]|0;
       $28 = ($27|0)==($$057|0);
       if ($28) {
        HEAP32[$25>>2] = 0;
        $29 = ((($25)) + 4|0);
        $30 = HEAP32[$29>>2]|0;
        $31 = ($30|0)==(0|0);
        if ($31) {
         $$0$i = $25;
         break;
        } else {
         $$0$i11$i = $30;
        }
        while(1) {
         $32 = HEAP32[$$0$i11$i>>2]|0;
         $33 = ($32|0)==(0|0);
         if (!($33)) {
          $$0$i11$i = $32;
          continue;
         }
         $34 = ((($$0$i11$i)) + 4|0);
         $35 = HEAP32[$34>>2]|0;
         $36 = ($35|0)==(0|0);
         if ($36) {
          break;
         } else {
          $$0$i11$i = $35;
         }
        }
        $$0$i = $$0$i11$i;
        break;
       } else {
        $37 = ((($25)) + 4|0);
        HEAP32[$37>>2] = 0;
        $38 = ($27|0)==(0|0);
        if ($38) {
         $$0$i = $25;
         break;
        } else {
         $$0$i$i22 = $27;
        }
        while(1) {
         $39 = HEAP32[$$0$i$i22>>2]|0;
         $40 = ($39|0)==(0|0);
         if (!($40)) {
          $$0$i$i22 = $39;
          continue;
         }
         $41 = ((($$0$i$i22)) + 4|0);
         $42 = HEAP32[$41>>2]|0;
         $43 = ($42|0)==(0|0);
         if ($43) {
          break;
         } else {
          $$0$i$i22 = $42;
         }
        }
        $$0$i = $$0$i$i22;
        break;
       }
      }
     } while(0);
     $44 = HEAP32[$7>>2]|0;
     $45 = ($44|0)==(0|0);
     do {
      if ($45) {
       $$0$i30 = $7;$$015$i$i31 = $7;
      } else {
       $46 = ((($$057)) + 16|0);
       $47 = +HEAPF64[$46>>3];
       $$0$i$i25 = $44;
       while(1) {
        $48 = ((($$0$i$i25)) + 16|0);
        $49 = +HEAPF64[$48>>3];
        $50 = $47 < $49;
        if ($50) {
         $51 = HEAP32[$$0$i$i25>>2]|0;
         $52 = ($51|0)==(0|0);
         if ($52) {
          label = 21;
          break;
         } else {
          $$0$be$in$i$i27 = $51;
         }
        } else {
         $53 = ((($$0$i$i25)) + 4|0);
         $54 = HEAP32[$53>>2]|0;
         $55 = ($54|0)==(0|0);
         if ($55) {
          label = 24;
          break;
         } else {
          $$0$be$in$i$i27 = $54;
         }
        }
        $$0$i$i25 = $$0$be$in$i$i27;
       }
       if ((label|0) == 21) {
        label = 0;
        $$0$i30 = $$0$i$i25;$$015$i$i31 = $$0$i$i25;
        break;
       }
       else if ((label|0) == 24) {
        label = 0;
        $$0$i30 = $$0$i$i25;$$015$i$i31 = $53;
        break;
       }
      }
     } while(0);
     HEAP32[$$057>>2] = 0;
     $56 = ((($$057)) + 4|0);
     HEAP32[$56>>2] = 0;
     HEAP32[$24>>2] = $$0$i30;
     HEAP32[$$015$i$i31>>2] = $$057;
     $57 = HEAP32[$0>>2]|0;
     $58 = HEAP32[$57>>2]|0;
     $59 = ($58|0)==(0|0);
     if ($59) {
      $62 = $$057;
     } else {
      $60 = $58;
      HEAP32[$0>>2] = $60;
      $$pre$i$i33 = HEAP32[$$015$i$i31>>2]|0;
      $62 = $$pre$i$i33;
     }
     $61 = HEAP32[$14>>2]|0;
     __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($61,$62);
     $63 = HEAP32[$3>>2]|0;
     $64 = (($63) + 1)|0;
     HEAP32[$3>>2] = $64;
     $65 = ((($$in74)) + 4|0);
     $66 = HEAP32[$65>>2]|0;
     $67 = ($66|0)==(0|0);
     if ($67) {
      $68 = ((($$in74)) + 8|0);
      $69 = HEAP32[$68>>2]|0;
      $70 = HEAP32[$69>>2]|0;
      $71 = ($70|0)==($$in74|0);
      if ($71) {
       $$0$i$i39 = $69;
      } else {
       $75 = $68;
       while(1) {
        $74 = HEAP32[$75>>2]|0;
        $76 = ((($74)) + 8|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = HEAP32[$77>>2]|0;
        $79 = ($78|0)==($74|0);
        if ($79) {
         $$0$i$i39 = $77;
         break;
        } else {
         $75 = $76;
        }
       }
      }
     } else {
      $$0$i$i$i35 = $66;
      while(1) {
       $72 = HEAP32[$$0$i$i$i35>>2]|0;
       $73 = ($72|0)==(0|0);
       if ($73) {
        break;
       } else {
        $$0$i$i$i35 = $72;
       }
      }
      $$0$i$i39 = $$0$i$i$i35;
     }
     HEAP32[$1>>2] = $$0$i$i39;
     $80 = ($$0$i|0)==(0|0);
     if ($80) {
      break L1;
     } else {
      $$057 = $$0$i;$$in74 = $$0$i$i39;
     }
    }
    if ((label|0) == 5) {
     $17 = ((($$057)) + 8|0);
     $18 = HEAP32[$17>>2]|0;
     $19 = ($18|0)==(0|0);
     if ($19) {
      $$2$lcssa = $$057;
     } else {
      $97 = $17;
      while(1) {
       $96 = HEAP32[$97>>2]|0;
       $98 = ((($96)) + 8|0);
       $99 = HEAP32[$98>>2]|0;
       $100 = ($99|0)==(0|0);
       if ($100) {
        $$2$lcssa = $96;
        break;
       } else {
        $97 = $98;
       }
      }
     }
     __ZNSt3__26__treeIN7osgUtil22LineSegmentIntersector12IntersectionENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($0,$$2$lcssa);
     break;
    }
    $81 = ___cxa_find_matching_catch_3(0|0)|0;
    $82 = tempRet0;
    (___cxa_begin_catch(($81|0))|0);
    $83 = ((($$057)) + 8|0);
    $84 = HEAP32[$83>>2]|0;
    $85 = ($84|0)==(0|0);
    if ($85) {
     $$1$lcssa = $$057;
    } else {
     $87 = $83;
     while(1) {
      $86 = HEAP32[$87>>2]|0;
      $88 = ((($86)) + 8|0);
      $89 = HEAP32[$88>>2]|0;
      $90 = ($89|0)==(0|0);
      if ($90) {
       $$1$lcssa = $86;
       break;
      } else {
       $87 = $88;
      }
     }
    }
    __ZNSt3__26__treeIN7osgUtil22LineSegmentIntersector12IntersectionENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($0,$$1$lcssa);
    __THREW__ = 0;
    invoke_v(3314);
    $91 = __THREW__; __THREW__ = 0;
    $92 = ___cxa_find_matching_catch_2()|0;
    $93 = tempRet0;
    __THREW__ = 0;
    invoke_v(3261);
    $94 = __THREW__; __THREW__ = 0;
    $95 = $94&1;
    if ($95) {
     $150 = ___cxa_find_matching_catch_3(0|0)|0;
     $151 = tempRet0;
     ___clang_call_terminate($150);
     // unreachable;
    } else {
     ___resumeException($92|0);
     // unreachable;
    }
   }
  }
 } while(0);
 $101 = HEAP32[$1>>2]|0;
 $102 = HEAP32[$2>>2]|0;
 $103 = ($101|0)==($102|0);
 if ($103) {
  return;
 }
 $104 = ((($0)) + 4|0);
 $105 = ((($0)) + 4|0);
 $$in76 = $101;
 while(1) {
  $106 = ((($$in76)) + 16|0);
  $107 = HEAP32[$104>>2]|0;
  $108 = ($107|0)==(0|0);
  do {
   if ($108) {
    $$015$i$i = $104;$$030$i = $104;
   } else {
    $109 = +HEAPF64[$106>>3];
    $$0$i$i21 = $107;
    while(1) {
     $110 = ((($$0$i$i21)) + 16|0);
     $111 = +HEAPF64[$110>>3];
     $112 = $109 < $111;
     if ($112) {
      $113 = HEAP32[$$0$i$i21>>2]|0;
      $114 = ($113|0)==(0|0);
      if ($114) {
       label = 45;
       break;
      } else {
       $$0$be$in$i$i = $113;
      }
     } else {
      $115 = ((($$0$i$i21)) + 4|0);
      $116 = HEAP32[$115>>2]|0;
      $117 = ($116|0)==(0|0);
      if ($117) {
       label = 48;
       break;
      } else {
       $$0$be$in$i$i = $116;
      }
     }
     $$0$i$i21 = $$0$be$in$i$i;
    }
    if ((label|0) == 45) {
     label = 0;
     $$015$i$i = $$0$i$i21;$$030$i = $$0$i$i21;
     break;
    }
    else if ((label|0) == 48) {
     label = 0;
     $$015$i$i = $115;$$030$i = $$0$i$i21;
     break;
    }
   }
  } while(0);
  $118 = (__Znwj(112)|0);
  $119 = ((($118)) + 16|0);
  __THREW__ = 0;
  invoke_vii(3315,($119|0),($106|0));
  $120 = __THREW__; __THREW__ = 0;
  $121 = $120&1;
  if ($121) {
   label = 50;
   break;
  }
  HEAP32[$118>>2] = 0;
  $124 = ((($118)) + 4|0);
  HEAP32[$124>>2] = 0;
  $125 = ((($118)) + 8|0);
  HEAP32[$125>>2] = $$030$i;
  HEAP32[$$015$i$i>>2] = $118;
  $126 = HEAP32[$0>>2]|0;
  $127 = HEAP32[$126>>2]|0;
  $128 = ($127|0)==(0|0);
  if ($128) {
   $131 = $118;
  } else {
   $129 = $127;
   HEAP32[$0>>2] = $129;
   $$pre$i$i = HEAP32[$$015$i$i>>2]|0;
   $131 = $$pre$i$i;
  }
  $130 = HEAP32[$105>>2]|0;
  __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($130,$131);
  $132 = HEAP32[$3>>2]|0;
  $133 = (($132) + 1)|0;
  HEAP32[$3>>2] = $133;
  $134 = ((($$in76)) + 4|0);
  $135 = HEAP32[$134>>2]|0;
  $136 = ($135|0)==(0|0);
  if ($136) {
   $137 = ((($$in76)) + 8|0);
   $138 = HEAP32[$137>>2]|0;
   $139 = HEAP32[$138>>2]|0;
   $140 = ($139|0)==($$in76|0);
   if ($140) {
    $$0$i$i = $138;
   } else {
    $144 = $137;
    while(1) {
     $143 = HEAP32[$144>>2]|0;
     $145 = ((($143)) + 8|0);
     $146 = HEAP32[$145>>2]|0;
     $147 = HEAP32[$146>>2]|0;
     $148 = ($147|0)==($143|0);
     if ($148) {
      $$0$i$i = $146;
      break;
     } else {
      $144 = $145;
     }
    }
   }
  } else {
   $$0$i$i$i = $135;
   while(1) {
    $141 = HEAP32[$$0$i$i$i>>2]|0;
    $142 = ($141|0)==(0|0);
    if ($142) {
     break;
    } else {
     $$0$i$i$i = $141;
    }
   }
   $$0$i$i = $$0$i$i$i;
  }
  HEAP32[$1>>2] = $$0$i$i;
  $149 = ($$0$i$i|0)==($102|0);
  if ($149) {
   label = 59;
   break;
  } else {
   $$in76 = $$0$i$i;
  }
 }
 if ((label|0) == 50) {
  $122 = ___cxa_find_matching_catch_2()|0;
  $123 = tempRet0;
  __ZdlPv($118);
  ___resumeException($122|0);
  // unreachable;
 }
 else if ((label|0) == 59) {
  return;
 }
}
function __ZN7osgUtil19IntersectionVisitorD2Ev($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$023$i$i = 0, $$023$i$i11 = 0, $$023$i$i14 = 0, $$023$i$i17 = 0, $$023$i$i19 = 0, $$023$i$i8 = 0, $$cast = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $2;
 $3 = ((($1)) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $$cast = $2;
 $5 = ((($$cast)) + -12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($0) + ($6)|0);
 HEAP32[$7>>2] = $4;
 $8 = ((($0)) + 112|0);
 $9 = ((($0)) + 120|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0);
 L1: do {
  if (!($11)) {
   $12 = ((($0)) + 116|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = HEAP32[$8>>2]|0;
   $15 = ((($14)) + 4|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = HEAP32[$13>>2]|0;
   $18 = ((($17)) + 4|0);
   HEAP32[$18>>2] = $16;
   $19 = HEAP32[$15>>2]|0;
   HEAP32[$19>>2] = $17;
   HEAP32[$9>>2] = 0;
   $20 = ($13|0)==($8|0);
   if (!($20)) {
    $$023$i$i = $13;
    while(1) {
     $21 = ((($$023$i$i)) + 4|0);
     $22 = HEAP32[$21>>2]|0;
     $23 = ((($$023$i$i)) + 8|0);
     $24 = HEAP32[$23>>2]|0;
     $25 = ($24|0)==(0|0);
     if (!($25)) {
      $26 = ((($24)) + 8|0);
      $27 = HEAP32[$26>>2]|0;HEAP32[$26>>2] = (($27-1)|0);
      $28 = ($27|0)==(1);
      if ($28) {
       __THREW__ = 0;
       invoke_viii(3262,($24|0),1,1);
       $29 = __THREW__; __THREW__ = 0;
       $30 = $29&1;
       if ($30) {
        break;
       }
      }
     }
     __ZdlPv($$023$i$i);
     $31 = ($22|0)==($8|0);
     if ($31) {
      break L1;
     } else {
      $$023$i$i = $22;
     }
    }
    $32 = ___cxa_find_matching_catch_2()|0;
    $33 = tempRet0;
    ___cxa_call_unexpected(($32|0));
    // unreachable;
   }
  }
 } while(0);
 $34 = ((($0)) + 100|0);
 $35 = ((($0)) + 108|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = ($36|0)==(0);
 L11: do {
  if (!($37)) {
   $38 = ((($0)) + 104|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = HEAP32[$34>>2]|0;
   $41 = ((($40)) + 4|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = HEAP32[$39>>2]|0;
   $44 = ((($43)) + 4|0);
   HEAP32[$44>>2] = $42;
   $45 = HEAP32[$41>>2]|0;
   HEAP32[$45>>2] = $43;
   HEAP32[$35>>2] = 0;
   $46 = ($39|0)==($34|0);
   if (!($46)) {
    $$023$i$i8 = $39;
    while(1) {
     $47 = ((($$023$i$i8)) + 4|0);
     $48 = HEAP32[$47>>2]|0;
     $49 = ((($$023$i$i8)) + 8|0);
     $50 = HEAP32[$49>>2]|0;
     $51 = ($50|0)==(0|0);
     if (!($51)) {
      $52 = ((($50)) + 8|0);
      $53 = HEAP32[$52>>2]|0;HEAP32[$52>>2] = (($53-1)|0);
      $54 = ($53|0)==(1);
      if ($54) {
       __THREW__ = 0;
       invoke_viii(3262,($50|0),1,1);
       $55 = __THREW__; __THREW__ = 0;
       $56 = $55&1;
       if ($56) {
        break;
       }
      }
     }
     __ZdlPv($$023$i$i8);
     $57 = ($48|0)==($34|0);
     if ($57) {
      break L11;
     } else {
      $$023$i$i8 = $48;
     }
    }
    $58 = ___cxa_find_matching_catch_2()|0;
    $59 = tempRet0;
    ___cxa_call_unexpected(($58|0));
    // unreachable;
   }
  }
 } while(0);
 $60 = ((($0)) + 88|0);
 $61 = ((($0)) + 96|0);
 $62 = HEAP32[$61>>2]|0;
 $63 = ($62|0)==(0);
 L21: do {
  if (!($63)) {
   $64 = ((($0)) + 92|0);
   $65 = HEAP32[$64>>2]|0;
   $66 = HEAP32[$60>>2]|0;
   $67 = ((($66)) + 4|0);
   $68 = HEAP32[$67>>2]|0;
   $69 = HEAP32[$65>>2]|0;
   $70 = ((($69)) + 4|0);
   HEAP32[$70>>2] = $68;
   $71 = HEAP32[$67>>2]|0;
   HEAP32[$71>>2] = $69;
   HEAP32[$61>>2] = 0;
   $72 = ($65|0)==($60|0);
   if (!($72)) {
    $$023$i$i11 = $65;
    while(1) {
     $73 = ((($$023$i$i11)) + 4|0);
     $74 = HEAP32[$73>>2]|0;
     $75 = ((($$023$i$i11)) + 8|0);
     $76 = HEAP32[$75>>2]|0;
     $77 = ($76|0)==(0|0);
     if (!($77)) {
      $78 = ((($76)) + 8|0);
      $79 = HEAP32[$78>>2]|0;HEAP32[$78>>2] = (($79-1)|0);
      $80 = ($79|0)==(1);
      if ($80) {
       __THREW__ = 0;
       invoke_viii(3262,($76|0),1,1);
       $81 = __THREW__; __THREW__ = 0;
       $82 = $81&1;
       if ($82) {
        break;
       }
      }
     }
     __ZdlPv($$023$i$i11);
     $83 = ($74|0)==($60|0);
     if ($83) {
      break L21;
     } else {
      $$023$i$i11 = $74;
     }
    }
    $84 = ___cxa_find_matching_catch_2()|0;
    $85 = tempRet0;
    ___cxa_call_unexpected(($84|0));
    // unreachable;
   }
  }
 } while(0);
 $86 = ((($0)) + 76|0);
 $87 = ((($0)) + 84|0);
 $88 = HEAP32[$87>>2]|0;
 $89 = ($88|0)==(0);
 L31: do {
  if (!($89)) {
   $90 = ((($0)) + 80|0);
   $91 = HEAP32[$90>>2]|0;
   $92 = HEAP32[$86>>2]|0;
   $93 = ((($92)) + 4|0);
   $94 = HEAP32[$93>>2]|0;
   $95 = HEAP32[$91>>2]|0;
   $96 = ((($95)) + 4|0);
   HEAP32[$96>>2] = $94;
   $97 = HEAP32[$93>>2]|0;
   HEAP32[$97>>2] = $95;
   HEAP32[$87>>2] = 0;
   $98 = ($91|0)==($86|0);
   if (!($98)) {
    $$023$i$i14 = $91;
    while(1) {
     $99 = ((($$023$i$i14)) + 4|0);
     $100 = HEAP32[$99>>2]|0;
     $101 = ((($$023$i$i14)) + 8|0);
     $102 = HEAP32[$101>>2]|0;
     $103 = ($102|0)==(0|0);
     if (!($103)) {
      $104 = ((($102)) + 8|0);
      $105 = HEAP32[$104>>2]|0;HEAP32[$104>>2] = (($105-1)|0);
      $106 = ($105|0)==(1);
      if ($106) {
       __THREW__ = 0;
       invoke_viii(3262,($102|0),1,1);
       $107 = __THREW__; __THREW__ = 0;
       $108 = $107&1;
       if ($108) {
        break;
       }
      }
     }
     __ZdlPv($$023$i$i14);
     $109 = ($100|0)==($86|0);
     if ($109) {
      break L31;
     } else {
      $$023$i$i14 = $100;
     }
    }
    $110 = ___cxa_find_matching_catch_2()|0;
    $111 = tempRet0;
    ___cxa_call_unexpected(($110|0));
    // unreachable;
   }
  }
 } while(0);
 $112 = ((($0)) + 72|0);
 $113 = HEAP32[$112>>2]|0;
 $114 = ($113|0)==(0|0);
 if (!($114)) {
  $115 = ((($113)) + 8|0);
  $116 = HEAP32[$115>>2]|0;HEAP32[$115>>2] = (($116-1)|0);
  $117 = ($116|0)==(1);
  if ($117) {
   __THREW__ = 0;
   invoke_viii(3262,($113|0),1,1);
   $118 = __THREW__; __THREW__ = 0;
   $119 = $118&1;
   if ($119) {
    $147 = ___cxa_find_matching_catch_2()|0;
    $148 = tempRet0;
    $149 = ((($0)) + 56|0);
    $150 = ((($0)) + 64|0);
    $151 = HEAP32[$150>>2]|0;
    $152 = ($151|0)==(0);
    L45: do {
     if (!($152)) {
      $153 = ((($0)) + 60|0);
      $154 = HEAP32[$153>>2]|0;
      $155 = HEAP32[$149>>2]|0;
      $156 = ((($155)) + 4|0);
      $157 = HEAP32[$156>>2]|0;
      $158 = HEAP32[$154>>2]|0;
      $159 = ((($158)) + 4|0);
      HEAP32[$159>>2] = $157;
      $160 = HEAP32[$156>>2]|0;
      HEAP32[$160>>2] = $158;
      HEAP32[$150>>2] = 0;
      $161 = ($154|0)==($149|0);
      if (!($161)) {
       $$023$i$i19 = $154;
       while(1) {
        $162 = ((($$023$i$i19)) + 4|0);
        $163 = HEAP32[$162>>2]|0;
        $164 = ((($$023$i$i19)) + 8|0);
        $165 = HEAP32[$164>>2]|0;
        $166 = ($165|0)==(0|0);
        if (!($166)) {
         $167 = ((($165)) + 8|0);
         $168 = HEAP32[$167>>2]|0;HEAP32[$167>>2] = (($168-1)|0);
         $169 = ($168|0)==(1);
         if ($169) {
          __THREW__ = 0;
          invoke_viii(3262,($165|0),1,1);
          $170 = __THREW__; __THREW__ = 0;
          $171 = $170&1;
          if ($171) {
           break;
          }
         }
        }
        __ZdlPv($$023$i$i19);
        $172 = ($163|0)==($149|0);
        if ($172) {
         break L45;
        } else {
         $$023$i$i19 = $163;
        }
       }
       $173 = ___cxa_find_matching_catch_2()|0;
       $174 = tempRet0;
       ___cxa_call_unexpected(($173|0));
       // unreachable;
      }
     }
    } while(0);
    $175 = ((($1)) + 4|0);
    __THREW__ = 0;
    invoke_vii(3284,($0|0),($175|0));
    $176 = __THREW__; __THREW__ = 0;
    $177 = $176&1;
    if ($177) {
     $178 = ___cxa_find_matching_catch_3(0|0)|0;
     $179 = tempRet0;
     ___clang_call_terminate($178);
     // unreachable;
    } else {
     ___resumeException($147|0);
     // unreachable;
    }
   }
  }
 }
 HEAP32[$112>>2] = 0;
 $120 = ((($0)) + 56|0);
 $121 = ((($0)) + 64|0);
 $122 = HEAP32[$121>>2]|0;
 $123 = ($122|0)==(0);
 if ($123) {
  $146 = ((($1)) + 4|0);
  __ZN3osg11NodeVisitorD2Ev($0,$146);
  return;
 }
 $124 = ((($0)) + 60|0);
 $125 = HEAP32[$124>>2]|0;
 $126 = HEAP32[$120>>2]|0;
 $127 = ((($126)) + 4|0);
 $128 = HEAP32[$127>>2]|0;
 $129 = HEAP32[$125>>2]|0;
 $130 = ((($129)) + 4|0);
 HEAP32[$130>>2] = $128;
 $131 = HEAP32[$127>>2]|0;
 HEAP32[$131>>2] = $129;
 HEAP32[$121>>2] = 0;
 $132 = ($125|0)==($120|0);
 if ($132) {
  $146 = ((($1)) + 4|0);
  __ZN3osg11NodeVisitorD2Ev($0,$146);
  return;
 } else {
  $$023$i$i17 = $125;
 }
 while(1) {
  $133 = ((($$023$i$i17)) + 4|0);
  $134 = HEAP32[$133>>2]|0;
  $135 = ((($$023$i$i17)) + 8|0);
  $136 = HEAP32[$135>>2]|0;
  $137 = ($136|0)==(0|0);
  if (!($137)) {
   $138 = ((($136)) + 8|0);
   $139 = HEAP32[$138>>2]|0;HEAP32[$138>>2] = (($139-1)|0);
   $140 = ($139|0)==(1);
   if ($140) {
    __THREW__ = 0;
    invoke_viii(3262,($136|0),1,1);
    $141 = __THREW__; __THREW__ = 0;
    $142 = $141&1;
    if ($142) {
     label = 38;
     break;
    }
   }
  }
  __ZdlPv($$023$i$i17);
  $143 = ($134|0)==($120|0);
  if ($143) {
   label = 39;
   break;
  } else {
   $$023$i$i17 = $134;
  }
 }
 if ((label|0) == 38) {
  $144 = ___cxa_find_matching_catch_2()|0;
  $145 = tempRet0;
  ___cxa_call_unexpected(($144|0));
  // unreachable;
 }
 else if ((label|0) == 39) {
  $146 = ((($1)) + 4|0);
  __ZN3osg11NodeVisitorD2Ev($0,$146);
  return;
 }
}
function __ZNSt3__26__treeIN7osgUtil22LineSegmentIntersector12IntersectionENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 }
 $3 = HEAP32[$1>>2]|0;
 __ZNSt3__26__treeIN7osgUtil22LineSegmentIntersector12IntersectionENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($0,$3);
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 __ZNSt3__26__treeIN7osgUtil22LineSegmentIntersector12IntersectionENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($0,$5);
 $6 = ((($1)) + 16|0);
 __THREW__ = 0;
 invoke_vi(3316,($6|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch_2()|0;
  $10 = tempRet0;
  ___cxa_call_unexpected(($9|0));
  // unreachable;
 }
 __ZdlPv($1);
 return;
}
function __ZN7osgUtil22LineSegmentIntersector12IntersectionD2Ev($0) {
 $0 = $0|0;
 var $$2 = 0, $$24 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i21 = 0, $scevgep$i$i$i5 = 0, $scevgep$i$i$i9 = 0;
 var $scevgep5$i$i$i = 0, $scevgep5$i$i$i10 = 0, $scevgep5$i$i$i22 = 0, $scevgep5$i$i$i6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = ((($0)) + 84|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==($2|0);
  if (!($6)) {
   $scevgep$i$i$i = ((($5)) + -8|0);
   $7 = $scevgep$i$i$i;
   $8 = $2;
   $9 = (($7) - ($8))|0;
   $10 = $9 >>> 3;
   $11 = $10 ^ -1;
   $scevgep5$i$i$i = (($5) + ($11<<3)|0);
   HEAP32[$4>>2] = $scevgep5$i$i$i;
  }
  __ZdlPv($2);
 }
 $12 = ((($0)) + 68|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0|0);
 if (!($14)) {
  $15 = ((($0)) + 72|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($16|0)==($13|0);
  if (!($17)) {
   $scevgep$i$i$i5 = ((($16)) + -4|0);
   $18 = $scevgep$i$i$i5;
   $19 = $13;
   $20 = (($18) - ($19))|0;
   $21 = $20 >>> 2;
   $22 = $21 ^ -1;
   $scevgep5$i$i$i6 = (($16) + ($22<<2)|0);
   HEAP32[$15>>2] = $scevgep5$i$i$i6;
  }
  __ZdlPv($13);
 }
 $23 = ((($0)) + 24|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)==(0|0);
 if ($25) {
  label = 12;
 } else {
  $26 = ((($24)) + 8|0);
  $27 = HEAP32[$26>>2]|0;HEAP32[$26>>2] = (($27-1)|0);
  $28 = ($27|0)==(1);
  if ($28) {
   __THREW__ = 0;
   invoke_viii(3262,($24|0),1,1);
   $29 = __THREW__; __THREW__ = 0;
   $30 = $29&1;
   if ($30) {
    $52 = ___cxa_find_matching_catch_2()|0;
    $53 = tempRet0;
    $54 = ((($0)) + 20|0);
    $55 = HEAP32[$54>>2]|0;
    $56 = ($55|0)==(0|0);
    if (!($56)) {
     $57 = ((($55)) + 8|0);
     $58 = HEAP32[$57>>2]|0;HEAP32[$57>>2] = (($58-1)|0);
     $59 = ($58|0)==(1);
     if ($59) {
      __THREW__ = 0;
      invoke_viii(3262,($55|0),1,1);
      $60 = __THREW__; __THREW__ = 0;
      $61 = $60&1;
      if ($61) {
       $73 = ___cxa_find_matching_catch_3(0|0)|0;
       $74 = tempRet0;
       ___clang_call_terminate($73);
       // unreachable;
      }
     }
    }
    HEAP32[$54>>2] = 0;
    $$2 = $53;$$24 = $52;
   } else {
    label = 12;
   }
  } else {
   label = 12;
  }
 }
 do {
  if ((label|0) == 12) {
   HEAP32[$23>>2] = 0;
   $31 = ((($0)) + 20|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ($32|0)==(0|0);
   if (!($33)) {
    $34 = ((($32)) + 8|0);
    $35 = HEAP32[$34>>2]|0;HEAP32[$34>>2] = (($35-1)|0);
    $36 = ($35|0)==(1);
    if ($36) {
     __THREW__ = 0;
     invoke_viii(3262,($32|0),1,1);
     $37 = __THREW__; __THREW__ = 0;
     $38 = $37&1;
     if ($38) {
      $50 = ___cxa_find_matching_catch_2()|0;
      $51 = tempRet0;
      $$2 = $51;$$24 = $50;
      break;
     }
    }
   }
   HEAP32[$31>>2] = 0;
   $39 = ((($0)) + 8|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = ($40|0)==(0|0);
   if ($41) {
    return;
   }
   $42 = ((($0)) + 12|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = ($43|0)==($40|0);
   if (!($44)) {
    $scevgep$i$i$i9 = ((($43)) + -4|0);
    $45 = $scevgep$i$i$i9;
    $46 = $40;
    $47 = (($45) - ($46))|0;
    $48 = $47 >>> 2;
    $49 = $48 ^ -1;
    $scevgep5$i$i$i10 = (($43) + ($49<<2)|0);
    HEAP32[$42>>2] = $scevgep5$i$i$i10;
   }
   __ZdlPv($40);
   return;
  }
 } while(0);
 $62 = ((($0)) + 8|0);
 $63 = HEAP32[$62>>2]|0;
 $64 = ($63|0)==(0|0);
 if ($64) {
  ___resumeException($$24|0);
  // unreachable;
 }
 $65 = ((($0)) + 12|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = ($66|0)==($63|0);
 if (!($67)) {
  $scevgep$i$i$i21 = ((($66)) + -4|0);
  $68 = $scevgep$i$i$i21;
  $69 = $63;
  $70 = (($68) - ($69))|0;
  $71 = $70 >>> 2;
  $72 = $71 ^ -1;
  $scevgep5$i$i$i22 = (($66) + ($72<<2)|0);
  HEAP32[$65>>2] = $scevgep5$i$i$i22;
 }
 __ZdlPv($63);
 ___resumeException($$24|0);
 // unreachable;
}
function __ZN7osgUtil22LineSegmentIntersector12IntersectionaSERKS1_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0.0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $2 = +HEAPF64[$1>>3];
 HEAPF64[$0>>3] = $2;
 $3 = ($0|0)==($1|0);
 if (!($3)) {
  $4 = ((($0)) + 8|0);
  $5 = ((($1)) + 8|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ((($1)) + 12|0);
  $8 = HEAP32[$7>>2]|0;
  __ZNSt3__26vectorIPN3osg4NodeENS_9allocatorIS3_EEE6assignIPS3_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS3_NS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_($4,$6,$8);
 }
 $9 = ((($0)) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ((($1)) + 20|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($10|0)==($12|0);
 if (!($13)) {
  HEAP32[$9>>2] = $12;
  $14 = ($12|0)==(0|0);
  if (!($14)) {
   $15 = ((($12)) + 8|0);
   $16 = HEAP32[$15>>2]|0;HEAP32[$15>>2] = (($16+1)|0);
  }
  $17 = ($10|0)==(0|0);
  if (!($17)) {
   $18 = ((($10)) + 8|0);
   $19 = HEAP32[$18>>2]|0;HEAP32[$18>>2] = (($19-1)|0);
   $20 = ($19|0)==(1);
   if ($20) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($10,1,1);
   }
  }
 }
 $21 = ((($0)) + 24|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ((($1)) + 24|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($22|0)==($24|0);
 if (!($25)) {
  HEAP32[$21>>2] = $24;
  $26 = ($24|0)==(0|0);
  if (!($26)) {
   $27 = ((($24)) + 8|0);
   $28 = HEAP32[$27>>2]|0;HEAP32[$27>>2] = (($28+1)|0);
  }
  $29 = ($22|0)==(0|0);
  if (!($29)) {
   $30 = ((($22)) + 8|0);
   $31 = HEAP32[$30>>2]|0;HEAP32[$30>>2] = (($31-1)|0);
   $32 = ($31|0)==(1);
   if ($32) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($22,1,1);
   }
  }
 }
 $33 = ((($0)) + 32|0);
 $34 = ((($1)) + 32|0);
 dest=$33; src=$34; stop=dest+36|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 if ($3) {
  $45 = ((($1)) + 92|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = ((($0)) + 92|0);
  HEAP32[$47>>2] = $46;
  return ($0|0);
 }
 $35 = ((($0)) + 68|0);
 $36 = ((($1)) + 68|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = ((($1)) + 72|0);
 $39 = HEAP32[$38>>2]|0;
 __ZNSt3__26vectorIjNS_9allocatorIjEEE6assignIPjEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIjNS_15iterator_traitsIS7_E9referenceEEE5valueEvE4typeES7_S7_($35,$37,$39);
 $40 = ((($0)) + 80|0);
 $41 = ((($1)) + 80|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ((($1)) + 84|0);
 $44 = HEAP32[$43>>2]|0;
 __ZNSt3__26vectorIdNS_9allocatorIdEEE6assignIPdEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIdNS_15iterator_traitsIS7_E9referenceEEE5valueEvE4typeES7_S7_($40,$42,$44);
 $45 = ((($1)) + 92|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = ((($0)) + 92|0);
 HEAP32[$47>>2] = $46;
 return ($0|0);
}
function __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$$i = 0, $$$i54 = 0, $$$i55 = 0, $$$i57 = 0, $$066 = 0, $$phi$trans$insert81 = 0, $$phi$trans$insert87 = 0, $$pre = 0, $$pre83 = 0, $$pre86 = 0, $$pre89 = 0, $$sink = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==($0|0);
 $3 = ((($1)) + 12|0);
 $4 = $2&1;
 HEAP8[$3>>0] = $4;
 if ($2) {
  return;
 } else {
  $$066 = $1;
 }
 while(1) {
  $5 = ((($$066)) + 8|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ((($6)) + 12|0);
  $8 = HEAP8[$7>>0]|0;
  $9 = ($8<<24>>24)==(0);
  if (!($9)) {
   label = 23;
   break;
  }
  $10 = ((($6)) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = HEAP32[$11>>2]|0;
  $13 = ($12|0)==($6|0);
  if ($13) {
   $14 = ((($11)) + 4|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = ($15|0)==(0|0);
   if ($16) {
    label = 7;
    break;
   }
   $17 = ((($15)) + 12|0);
   $18 = HEAP8[$17>>0]|0;
   $19 = ($18<<24>>24)==(0);
   if ($19) {
    $$sink = $17;
   } else {
    label = 7;
    break;
   }
  } else {
   $53 = ($12|0)==(0|0);
   if ($53) {
    label = 16;
    break;
   }
   $54 = ((($12)) + 12|0);
   $55 = HEAP8[$54>>0]|0;
   $56 = ($55<<24>>24)==(0);
   if ($56) {
    $$sink = $54;
   } else {
    label = 16;
    break;
   }
  }
  HEAP8[$7>>0] = 1;
  $20 = ($11|0)==($0|0);
  $21 = ((($11)) + 12|0);
  $22 = $20&1;
  HEAP8[$21>>0] = $22;
  HEAP8[$$sink>>0] = 1;
  if ($20) {
   label = 23;
   break;
  } else {
   $$066 = $11;
  }
 }
 if ((label|0) == 7) {
  $23 = HEAP32[$6>>2]|0;
  $24 = ($23|0)==($$066|0);
  if ($24) {
   $38 = $6;$40 = $11;
  } else {
   $25 = $11;
   $26 = ((($6)) + 4|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = HEAP32[$27>>2]|0;
   HEAP32[$26>>2] = $28;
   $29 = ($28|0)==(0|0);
   if ($29) {
    $32 = $25;
   } else {
    $30 = ((($28)) + 8|0);
    HEAP32[$30>>2] = $6;
    $$pre86 = HEAP32[$10>>2]|0;
    $32 = $$pre86;
   }
   $31 = ((($27)) + 8|0);
   HEAP32[$31>>2] = $32;
   $33 = HEAP32[$10>>2]|0;
   $34 = HEAP32[$33>>2]|0;
   $35 = ($34|0)==($6|0);
   $36 = ((($33)) + 4|0);
   $$$i57 = $35 ? $33 : $36;
   HEAP32[$$$i57>>2] = $27;
   HEAP32[$27>>2] = $6;
   HEAP32[$10>>2] = $27;
   $$phi$trans$insert87 = ((($27)) + 8|0);
   $$pre89 = HEAP32[$$phi$trans$insert87>>2]|0;
   $38 = $27;$40 = $$pre89;
  }
  $37 = ((($38)) + 12|0);
  HEAP8[$37>>0] = 1;
  $39 = ((($40)) + 12|0);
  HEAP8[$39>>0] = 0;
  $41 = HEAP32[$40>>2]|0;
  $42 = ((($41)) + 4|0);
  $43 = HEAP32[$42>>2]|0;
  HEAP32[$40>>2] = $43;
  $44 = ($43|0)==(0|0);
  if (!($44)) {
   $45 = ((($43)) + 8|0);
   HEAP32[$45>>2] = $40;
  }
  $46 = ((($40)) + 8|0);
  $47 = HEAP32[$46>>2]|0;
  $48 = ((($41)) + 8|0);
  HEAP32[$48>>2] = $47;
  $49 = HEAP32[$46>>2]|0;
  $50 = HEAP32[$49>>2]|0;
  $51 = ($50|0)==($40|0);
  $52 = ((($49)) + 4|0);
  $$$i55 = $51 ? $49 : $52;
  HEAP32[$$$i55>>2] = $41;
  HEAP32[$42>>2] = $40;
  HEAP32[$46>>2] = $41;
  return;
 }
 else if ((label|0) == 16) {
  $57 = HEAP32[$6>>2]|0;
  $58 = ($57|0)==($$066|0);
  if ($58) {
   $59 = $11;
   $60 = HEAP32[$6>>2]|0;
   $61 = ((($60)) + 4|0);
   $62 = HEAP32[$61>>2]|0;
   HEAP32[$6>>2] = $62;
   $63 = ($62|0)==(0|0);
   if ($63) {
    $66 = $59;
   } else {
    $64 = ((($62)) + 8|0);
    HEAP32[$64>>2] = $6;
    $$pre = HEAP32[$10>>2]|0;
    $66 = $$pre;
   }
   $65 = ((($60)) + 8|0);
   HEAP32[$65>>2] = $66;
   $67 = HEAP32[$10>>2]|0;
   $68 = HEAP32[$67>>2]|0;
   $69 = ($68|0)==($6|0);
   $70 = ((($67)) + 4|0);
   $$$i54 = $69 ? $67 : $70;
   HEAP32[$$$i54>>2] = $60;
   HEAP32[$61>>2] = $6;
   HEAP32[$10>>2] = $60;
   $$phi$trans$insert81 = ((($60)) + 8|0);
   $$pre83 = HEAP32[$$phi$trans$insert81>>2]|0;
   $72 = $60;$74 = $$pre83;
  } else {
   $72 = $6;$74 = $11;
  }
  $71 = ((($72)) + 12|0);
  HEAP8[$71>>0] = 1;
  $73 = ((($74)) + 12|0);
  HEAP8[$73>>0] = 0;
  $75 = ((($74)) + 4|0);
  $76 = HEAP32[$75>>2]|0;
  $77 = HEAP32[$76>>2]|0;
  HEAP32[$75>>2] = $77;
  $78 = ($77|0)==(0|0);
  if (!($78)) {
   $79 = ((($77)) + 8|0);
   HEAP32[$79>>2] = $74;
  }
  $80 = ((($74)) + 8|0);
  $81 = HEAP32[$80>>2]|0;
  $82 = ((($76)) + 8|0);
  HEAP32[$82>>2] = $81;
  $83 = HEAP32[$80>>2]|0;
  $84 = HEAP32[$83>>2]|0;
  $85 = ($84|0)==($74|0);
  $86 = ((($83)) + 4|0);
  $$$i = $85 ? $83 : $86;
  HEAP32[$$$i>>2] = $76;
  HEAP32[$76>>2] = $74;
  HEAP32[$80>>2] = $76;
  return;
 }
 else if ((label|0) == 23) {
  return;
 }
}
function __ZN7osgUtil22LineSegmentIntersector12IntersectionC2ERKS1_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$010 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0.0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i13 = 0, $scevgep5$i$i$i = 0, $scevgep5$i$i$i14 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $2 = +HEAPF64[$1>>3];
 HEAPF64[$0>>3] = $2;
 $3 = ((($0)) + 8|0);
 $4 = ((($1)) + 8|0);
 __ZNSt3__26vectorIPN3osg4NodeENS_9allocatorIS3_EEEC2ERKS6_($3,$4);
 $5 = ((($0)) + 20|0);
 $6 = ((($1)) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 HEAP32[$5>>2] = $7;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = ((($7)) + 8|0);
  $10 = HEAP32[$9>>2]|0;HEAP32[$9>>2] = (($10+1)|0);
 }
 $11 = ((($0)) + 24|0);
 $12 = ((($1)) + 24|0);
 $13 = HEAP32[$12>>2]|0;
 HEAP32[$11>>2] = $13;
 $14 = ($13|0)==(0|0);
 if (!($14)) {
  $15 = ((($13)) + 8|0);
  $16 = HEAP32[$15>>2]|0;HEAP32[$15>>2] = (($16+1)|0);
 }
 $17 = ((($0)) + 32|0);
 $18 = ((($1)) + 32|0);
 dest=$17; src=$18; stop=dest+36|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $19 = ((($0)) + 68|0);
 $20 = ((($1)) + 68|0);
 __THREW__ = 0;
 invoke_vii(3317,($19|0),($20|0));
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if ($22) {
  $30 = ___cxa_find_matching_catch_2()|0;
  $31 = tempRet0;
  $$0 = $31;$$010 = $30;
 } else {
  $23 = ((($0)) + 80|0);
  $24 = ((($1)) + 80|0);
  __THREW__ = 0;
  invoke_vii(3318,($23|0),($24|0));
  $25 = __THREW__; __THREW__ = 0;
  $26 = $25&1;
  if (!($26)) {
   $27 = ((($0)) + 92|0);
   $28 = ((($1)) + 92|0);
   $29 = HEAP32[$28>>2]|0;
   HEAP32[$27>>2] = $29;
   return;
  }
  $32 = ___cxa_find_matching_catch_2()|0;
  $33 = tempRet0;
  $34 = HEAP32[$19>>2]|0;
  $35 = ($34|0)==(0|0);
  if ($35) {
   $$0 = $33;$$010 = $32;
  } else {
   $36 = ((($0)) + 72|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = ($37|0)==($34|0);
   if (!($38)) {
    $scevgep$i$i$i13 = ((($37)) + -4|0);
    $39 = $scevgep$i$i$i13;
    $40 = $34;
    $41 = (($39) - ($40))|0;
    $42 = $41 >>> 2;
    $43 = $42 ^ -1;
    $scevgep5$i$i$i14 = (($37) + ($43<<2)|0);
    HEAP32[$36>>2] = $scevgep5$i$i$i14;
   }
   __ZdlPv($34);
   $$0 = $33;$$010 = $32;
  }
 }
 $44 = HEAP32[$11>>2]|0;
 $45 = ($44|0)==(0|0);
 if (!($45)) {
  $46 = ((($44)) + 8|0);
  $47 = HEAP32[$46>>2]|0;HEAP32[$46>>2] = (($47-1)|0);
  $48 = ($47|0)==(1);
  if ($48) {
   __THREW__ = 0;
   invoke_viii(3262,($44|0),1,1);
   $49 = __THREW__; __THREW__ = 0;
   $50 = $49&1;
   if ($50) {
    $68 = ___cxa_find_matching_catch_3(0|0)|0;
    $69 = tempRet0;
    ___clang_call_terminate($68);
    // unreachable;
   }
  }
 }
 HEAP32[$11>>2] = 0;
 $51 = HEAP32[$5>>2]|0;
 $52 = ($51|0)==(0|0);
 if (!($52)) {
  $53 = ((($51)) + 8|0);
  $54 = HEAP32[$53>>2]|0;HEAP32[$53>>2] = (($54-1)|0);
  $55 = ($54|0)==(1);
  if ($55) {
   __THREW__ = 0;
   invoke_viii(3262,($51|0),1,1);
   $56 = __THREW__; __THREW__ = 0;
   $57 = $56&1;
   if ($57) {
    $68 = ___cxa_find_matching_catch_3(0|0)|0;
    $69 = tempRet0;
    ___clang_call_terminate($68);
    // unreachable;
   }
  }
 }
 HEAP32[$5>>2] = 0;
 $58 = HEAP32[$3>>2]|0;
 $59 = ($58|0)==(0|0);
 if ($59) {
  ___resumeException($$010|0);
  // unreachable;
 }
 $60 = ((($0)) + 12|0);
 $61 = HEAP32[$60>>2]|0;
 $62 = ($61|0)==($58|0);
 if (!($62)) {
  $scevgep$i$i$i = ((($61)) + -4|0);
  $63 = $scevgep$i$i$i;
  $64 = $58;
  $65 = (($63) - ($64))|0;
  $66 = $65 >>> 2;
  $67 = $66 ^ -1;
  $scevgep5$i$i$i = (($61) + ($67<<2)|0);
  HEAP32[$60>>2] = $scevgep5$i$i$i;
 }
 __ZdlPv($58);
 ___resumeException($$010|0);
 // unreachable;
}
function __ZNSt3__26vectorIPN3osg4NodeENS_9allocatorIS3_EEEC2ERKS6_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i = 0, $scevgep5$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = 0;
 $2 = ((($0)) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = ((($0)) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$1>>2]|0;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 2;
 $9 = ($8|0)==(0);
 if ($9) {
  return;
 }
 $10 = ($8>>>0)>(1073741823);
 if ($10) {
  __THREW__ = 0;
  invoke_vi(3307,($0|0));
  $11 = __THREW__; __THREW__ = 0;
 } else {
  __THREW__ = 0;
  $12 = (invoke_ii(3276,($7|0))|0);
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if (!($14)) {
   HEAP32[$2>>2] = $12;
   HEAP32[$0>>2] = $12;
   $15 = (($12) + ($8<<2)|0);
   $16 = ((($0)) + 8|0);
   HEAP32[$16>>2] = $15;
   $17 = HEAP32[$1>>2]|0;
   $18 = HEAP32[$4>>2]|0;
   $19 = $17;
   $20 = (($18) - ($19))|0;
   $21 = ($20|0)>(0);
   if (!($21)) {
    return;
   }
   $22 = $20 >>> 2;
   _memcpy(($12|0),($17|0),($20|0))|0;
   $23 = (($12) + ($22<<2)|0);
   HEAP32[$2>>2] = $23;
   return;
  }
 }
 $24 = ___cxa_find_matching_catch_2()|0;
 $25 = tempRet0;
 $26 = HEAP32[$0>>2]|0;
 $27 = ($26|0)==(0|0);
 if ($27) {
  ___resumeException($24|0);
  // unreachable;
 }
 $28 = HEAP32[$2>>2]|0;
 $29 = ($28|0)==($26|0);
 if (!($29)) {
  $scevgep$i$i$i = ((($28)) + -4|0);
  $30 = $scevgep$i$i$i;
  $31 = $26;
  $32 = (($30) - ($31))|0;
  $33 = $32 >>> 2;
  $34 = $33 ^ -1;
  $scevgep5$i$i$i = (($28) + ($34<<2)|0);
  HEAP32[$2>>2] = $scevgep5$i$i$i;
 }
 __ZdlPv($26);
 ___resumeException($24|0);
 // unreachable;
}
function __ZNSt3__26vectorIjNS_9allocatorIjEEEC2ERKS3_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i = 0, $scevgep5$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = 0;
 $2 = ((($0)) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = ((($0)) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$1>>2]|0;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 2;
 $9 = ($8|0)==(0);
 if ($9) {
  return;
 }
 $10 = ($8>>>0)>(1073741823);
 if ($10) {
  __THREW__ = 0;
  invoke_vi(3307,($0|0));
  $11 = __THREW__; __THREW__ = 0;
 } else {
  __THREW__ = 0;
  $12 = (invoke_ii(3276,($7|0))|0);
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if (!($14)) {
   HEAP32[$2>>2] = $12;
   HEAP32[$0>>2] = $12;
   $15 = (($12) + ($8<<2)|0);
   $16 = ((($0)) + 8|0);
   HEAP32[$16>>2] = $15;
   $17 = HEAP32[$1>>2]|0;
   $18 = HEAP32[$4>>2]|0;
   $19 = $17;
   $20 = (($18) - ($19))|0;
   $21 = ($20|0)>(0);
   if (!($21)) {
    return;
   }
   $22 = $20 >>> 2;
   _memcpy(($12|0),($17|0),($20|0))|0;
   $23 = (($12) + ($22<<2)|0);
   HEAP32[$2>>2] = $23;
   return;
  }
 }
 $24 = ___cxa_find_matching_catch_2()|0;
 $25 = tempRet0;
 $26 = HEAP32[$0>>2]|0;
 $27 = ($26|0)==(0|0);
 if ($27) {
  ___resumeException($24|0);
  // unreachable;
 }
 $28 = HEAP32[$2>>2]|0;
 $29 = ($28|0)==($26|0);
 if (!($29)) {
  $scevgep$i$i$i = ((($28)) + -4|0);
  $30 = $scevgep$i$i$i;
  $31 = $26;
  $32 = (($30) - ($31))|0;
  $33 = $32 >>> 2;
  $34 = $33 ^ -1;
  $scevgep5$i$i$i = (($28) + ($34<<2)|0);
  HEAP32[$2>>2] = $scevgep5$i$i$i;
 }
 __ZdlPv($26);
 ___resumeException($24|0);
 // unreachable;
}
function __ZNSt3__26vectorIdNS_9allocatorIdEEEC2ERKS3_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i = 0, $scevgep5$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = 0;
 $2 = ((($0)) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = ((($0)) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$1>>2]|0;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 3;
 $9 = ($8|0)==(0);
 if ($9) {
  return;
 }
 $10 = ($8>>>0)>(536870911);
 if ($10) {
  __THREW__ = 0;
  invoke_vi(3307,($0|0));
  $11 = __THREW__; __THREW__ = 0;
 } else {
  __THREW__ = 0;
  $12 = (invoke_ii(3276,($7|0))|0);
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if (!($14)) {
   HEAP32[$2>>2] = $12;
   HEAP32[$0>>2] = $12;
   $15 = (($12) + ($8<<3)|0);
   $16 = ((($0)) + 8|0);
   HEAP32[$16>>2] = $15;
   $17 = HEAP32[$1>>2]|0;
   $18 = HEAP32[$4>>2]|0;
   $19 = $17;
   $20 = (($18) - ($19))|0;
   $21 = ($20|0)>(0);
   if (!($21)) {
    return;
   }
   $22 = $20 >>> 3;
   _memcpy(($12|0),($17|0),($20|0))|0;
   $23 = (($12) + ($22<<3)|0);
   HEAP32[$2>>2] = $23;
   return;
  }
 }
 $24 = ___cxa_find_matching_catch_2()|0;
 $25 = tempRet0;
 $26 = HEAP32[$0>>2]|0;
 $27 = ($26|0)==(0|0);
 if ($27) {
  ___resumeException($24|0);
  // unreachable;
 }
 $28 = HEAP32[$2>>2]|0;
 $29 = ($28|0)==($26|0);
 if (!($29)) {
  $scevgep$i$i$i = ((($28)) + -8|0);
  $30 = $scevgep$i$i$i;
  $31 = $26;
  $32 = (($30) - ($31))|0;
  $33 = $32 >>> 3;
  $34 = $33 ^ -1;
  $scevgep5$i$i$i = (($28) + ($34<<3)|0);
  HEAP32[$2>>2] = $scevgep5$i$i$i;
 }
 __ZdlPv($26);
 ___resumeException($24|0);
 // unreachable;
}
function __ZNSt3__26vectorIPN3osg4NodeENS_9allocatorIS3_EEE6assignIPS3_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS3_NS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$ = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $scevgep$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep5$i$i = 0, $scevgep5$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = $2;
 $4 = $1;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 $7 = ((($0)) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$0>>2]|0;
 $10 = (($8) - ($9))|0;
 $11 = $10 >> 2;
 $12 = ($6>>>0)>($11>>>0);
 $13 = $9;
 if (!($12)) {
  $14 = ((($0)) + 4|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (($15) - ($9))|0;
  $17 = $16 >> 2;
  $18 = ($6>>>0)>($17>>>0);
  $19 = (($1) + ($17<<2)|0);
  $$ = $18 ? $19 : $2;
  $20 = $$;
  $21 = (($20) - ($4))|0;
  $22 = $21 >> 2;
  $23 = ($22|0)==(0);
  if (!($23)) {
   $24 = $9;
   _memmove(($24|0),($1|0),($21|0))|0;
  }
  $25 = (($13) + ($22<<2)|0);
  if ($18) {
   $26 = (($3) - ($20))|0;
   $27 = ($26|0)>(0);
   if (!($27)) {
    return;
   }
   $28 = $26 >>> 2;
   $29 = HEAP32[$14>>2]|0;
   _memcpy(($29|0),($$|0),($26|0))|0;
   $30 = HEAP32[$14>>2]|0;
   $31 = (($30) + ($28<<2)|0);
   HEAP32[$14>>2] = $31;
   return;
  } else {
   $32 = HEAP32[$14>>2]|0;
   $33 = ($32|0)==($25|0);
   if ($33) {
    return;
   }
   $scevgep$i$i = ((($32)) + -4|0);
   $34 = $scevgep$i$i;
   $35 = $25;
   $36 = (($34) - ($35))|0;
   $37 = $36 >>> 2;
   $38 = $37 ^ -1;
   $scevgep5$i$i = (($32) + ($38<<2)|0);
   HEAP32[$14>>2] = $scevgep5$i$i;
   return;
  }
 }
 $39 = ($9|0)==(0);
 $40 = $9;
 if ($39) {
  $50 = $8;
 } else {
  $41 = ((($0)) + 4|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = ($42|0)==($13|0);
  if (!($43)) {
   $scevgep$i$i$i$i = ((($42)) + -4|0);
   $44 = $scevgep$i$i$i$i;
   $45 = (($44) - ($9))|0;
   $46 = $45 >>> 2;
   $47 = $46 ^ -1;
   $scevgep5$i$i$i$i = (($42) + ($47<<2)|0);
   HEAP32[$41>>2] = $scevgep5$i$i$i$i;
  }
  __ZdlPv($40);
  HEAP32[$7>>2] = 0;
  HEAP32[$41>>2] = 0;
  HEAP32[$0>>2] = 0;
  $50 = 0;
 }
 $48 = ($6>>>0)>(1073741823);
 if ($48) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $49 = $50 >> 2;
 $51 = ($49>>>0)<(536870911);
 $52 = $50 >> 1;
 $53 = ($52>>>0)<($6>>>0);
 $$sroa$speculated$i = $53 ? $6 : $52;
 $$sroa$speculated$$i = $51 ? $$sroa$speculated$i : 1073741823;
 $54 = ($$sroa$speculated$$i>>>0)>(1073741823);
 if ($54) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $55 = $$sroa$speculated$$i << 2;
 $56 = (__Znwj($55)|0);
 $57 = ((($0)) + 4|0);
 HEAP32[$57>>2] = $56;
 HEAP32[$0>>2] = $56;
 $58 = (($56) + ($$sroa$speculated$$i<<2)|0);
 HEAP32[$7>>2] = $58;
 $59 = ($5|0)>(0);
 if (!($59)) {
  return;
 }
 $60 = $5 >>> 2;
 _memcpy(($56|0),($1|0),($5|0))|0;
 $61 = (($56) + ($60<<2)|0);
 HEAP32[$57>>2] = $61;
 return;
}
function __ZNSt3__26vectorIjNS_9allocatorIjEEE6assignIPjEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIjNS_15iterator_traitsIS7_E9referenceEEE5valueEvE4typeES7_S7_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$ = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $scevgep$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep5$i$i = 0, $scevgep5$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = $2;
 $4 = $1;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 $7 = ((($0)) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$0>>2]|0;
 $10 = (($8) - ($9))|0;
 $11 = $10 >> 2;
 $12 = ($6>>>0)>($11>>>0);
 $13 = $9;
 if (!($12)) {
  $14 = ((($0)) + 4|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (($15) - ($9))|0;
  $17 = $16 >> 2;
  $18 = ($6>>>0)>($17>>>0);
  $19 = (($1) + ($17<<2)|0);
  $$ = $18 ? $19 : $2;
  $20 = $$;
  $21 = (($20) - ($4))|0;
  $22 = $21 >> 2;
  $23 = ($22|0)==(0);
  if (!($23)) {
   $24 = $9;
   _memmove(($24|0),($1|0),($21|0))|0;
  }
  $25 = (($13) + ($22<<2)|0);
  if ($18) {
   $26 = (($3) - ($20))|0;
   $27 = ($26|0)>(0);
   if (!($27)) {
    return;
   }
   $28 = $26 >>> 2;
   $29 = HEAP32[$14>>2]|0;
   _memcpy(($29|0),($$|0),($26|0))|0;
   $30 = HEAP32[$14>>2]|0;
   $31 = (($30) + ($28<<2)|0);
   HEAP32[$14>>2] = $31;
   return;
  } else {
   $32 = HEAP32[$14>>2]|0;
   $33 = ($32|0)==($25|0);
   if ($33) {
    return;
   }
   $scevgep$i$i = ((($32)) + -4|0);
   $34 = $scevgep$i$i;
   $35 = $25;
   $36 = (($34) - ($35))|0;
   $37 = $36 >>> 2;
   $38 = $37 ^ -1;
   $scevgep5$i$i = (($32) + ($38<<2)|0);
   HEAP32[$14>>2] = $scevgep5$i$i;
   return;
  }
 }
 $39 = ($9|0)==(0);
 $40 = $9;
 if ($39) {
  $50 = $8;
 } else {
  $41 = ((($0)) + 4|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = ($42|0)==($13|0);
  if (!($43)) {
   $scevgep$i$i$i$i = ((($42)) + -4|0);
   $44 = $scevgep$i$i$i$i;
   $45 = (($44) - ($9))|0;
   $46 = $45 >>> 2;
   $47 = $46 ^ -1;
   $scevgep5$i$i$i$i = (($42) + ($47<<2)|0);
   HEAP32[$41>>2] = $scevgep5$i$i$i$i;
  }
  __ZdlPv($40);
  HEAP32[$7>>2] = 0;
  HEAP32[$41>>2] = 0;
  HEAP32[$0>>2] = 0;
  $50 = 0;
 }
 $48 = ($6>>>0)>(1073741823);
 if ($48) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $49 = $50 >> 2;
 $51 = ($49>>>0)<(536870911);
 $52 = $50 >> 1;
 $53 = ($52>>>0)<($6>>>0);
 $$sroa$speculated$i = $53 ? $6 : $52;
 $$sroa$speculated$$i = $51 ? $$sroa$speculated$i : 1073741823;
 $54 = ($$sroa$speculated$$i>>>0)>(1073741823);
 if ($54) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $55 = $$sroa$speculated$$i << 2;
 $56 = (__Znwj($55)|0);
 $57 = ((($0)) + 4|0);
 HEAP32[$57>>2] = $56;
 HEAP32[$0>>2] = $56;
 $58 = (($56) + ($$sroa$speculated$$i<<2)|0);
 HEAP32[$7>>2] = $58;
 $59 = ($5|0)>(0);
 if (!($59)) {
  return;
 }
 $60 = $5 >>> 2;
 _memcpy(($56|0),($1|0),($5|0))|0;
 $61 = (($56) + ($60<<2)|0);
 HEAP32[$57>>2] = $61;
 return;
}
function __ZNSt3__26vectorIdNS_9allocatorIdEEE6assignIPdEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIdNS_15iterator_traitsIS7_E9referenceEEE5valueEvE4typeES7_S7_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$ = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $scevgep$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep5$i$i = 0, $scevgep5$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = $2;
 $4 = $1;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 3;
 $7 = ((($0)) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$0>>2]|0;
 $10 = (($8) - ($9))|0;
 $11 = $10 >> 3;
 $12 = ($6>>>0)>($11>>>0);
 $13 = $9;
 if (!($12)) {
  $14 = ((($0)) + 4|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (($15) - ($9))|0;
  $17 = $16 >> 3;
  $18 = ($6>>>0)>($17>>>0);
  $19 = (($1) + ($17<<3)|0);
  $$ = $18 ? $19 : $2;
  $20 = $$;
  $21 = (($20) - ($4))|0;
  $22 = $21 >> 3;
  $23 = ($22|0)==(0);
  if (!($23)) {
   $24 = $9;
   _memmove(($24|0),($1|0),($21|0))|0;
  }
  $25 = (($13) + ($22<<3)|0);
  if ($18) {
   $26 = (($3) - ($20))|0;
   $27 = ($26|0)>(0);
   if (!($27)) {
    return;
   }
   $28 = $26 >>> 3;
   $29 = HEAP32[$14>>2]|0;
   _memcpy(($29|0),($$|0),($26|0))|0;
   $30 = HEAP32[$14>>2]|0;
   $31 = (($30) + ($28<<3)|0);
   HEAP32[$14>>2] = $31;
   return;
  } else {
   $32 = HEAP32[$14>>2]|0;
   $33 = ($32|0)==($25|0);
   if ($33) {
    return;
   }
   $scevgep$i$i = ((($32)) + -8|0);
   $34 = $scevgep$i$i;
   $35 = $25;
   $36 = (($34) - ($35))|0;
   $37 = $36 >>> 3;
   $38 = $37 ^ -1;
   $scevgep5$i$i = (($32) + ($38<<3)|0);
   HEAP32[$14>>2] = $scevgep5$i$i;
   return;
  }
 }
 $39 = ($9|0)==(0);
 $40 = $9;
 if ($39) {
  $50 = $8;
 } else {
  $41 = ((($0)) + 4|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = ($42|0)==($13|0);
  if (!($43)) {
   $scevgep$i$i$i$i = ((($42)) + -8|0);
   $44 = $scevgep$i$i$i$i;
   $45 = (($44) - ($9))|0;
   $46 = $45 >>> 3;
   $47 = $46 ^ -1;
   $scevgep5$i$i$i$i = (($42) + ($47<<3)|0);
   HEAP32[$41>>2] = $scevgep5$i$i$i$i;
  }
  __ZdlPv($40);
  HEAP32[$7>>2] = 0;
  HEAP32[$41>>2] = 0;
  HEAP32[$0>>2] = 0;
  $50 = 0;
 }
 $48 = ($6>>>0)>(536870911);
 if ($48) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $49 = $50 >> 3;
 $51 = ($49>>>0)<(268435455);
 $52 = $50 >> 2;
 $53 = ($52>>>0)<($6>>>0);
 $$sroa$speculated$i = $53 ? $6 : $52;
 $$sroa$speculated$$i = $51 ? $$sroa$speculated$i : 536870911;
 $54 = ($$sroa$speculated$$i>>>0)>(536870911);
 if ($54) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $55 = $$sroa$speculated$$i << 3;
 $56 = (__Znwj($55)|0);
 $57 = ((($0)) + 4|0);
 HEAP32[$57>>2] = $56;
 HEAP32[$0>>2] = $56;
 $58 = (($56) + ($$sroa$speculated$$i<<3)|0);
 HEAP32[$7>>2] = $58;
 $59 = ($5|0)>(0);
 if (!($59)) {
  return;
 }
 $60 = $5 >>> 3;
 _memcpy(($56|0),($1|0),($5|0))|0;
 $61 = (($56) + ($60<<3)|0);
 HEAP32[$57>>2] = $61;
 return;
}
function __ZN9osgViewer4View20computeIntersectionsEPKN3osg6CameraEN7osgUtil11Intersector15CoordinateFrameEffRNSt3__28multisetINS5_22LineSegmentIntersector12IntersectionENS8_4lessISB_EENS8_9allocatorISB_EEEEj($0,$1,$2,$3,$4,$5,$6) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = +$3;
 $4 = +$4;
 $5 = $5|0;
 $6 = $6|0;
 var $$$i = 0, $$0 = 0, $$011 = 0, $$014 = 0, $$1 = 0, $$112 = 0, $$115 = 0, $$2 = 0, $$213 = 0, $$byval_copy = 0, $$byval_copy11 = 0, $10 = 0, $11 = 0, $12 = 0.0, $13 = 0.0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, $eh$lpad$body21$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 208|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(208|0);
 $$byval_copy11 = sp + 204|0;
 $$byval_copy = sp + 200|0;
 $7 = sp + 196|0;
 $8 = sp + 192|0;
 $9 = sp;
 $10 = ($1|0)==(0|0);
 if ($10) {
  $$115 = 0;
  STACKTOP = sp;return ($$115|0);
 }
 $11 = (__Znwj(96)|0);
 $12 = $3;
 $13 = $4;
 __THREW__ = 0;
 invoke_viidd(3319,($11|0),($2|0),(+$12),(+$13));
 $14 = __THREW__; __THREW__ = 0;
 $15 = $14&1;
 if ($15) {
  $41 = ___cxa_find_matching_catch_2()|0;
  $42 = tempRet0;
  __ZdlPv($11);
  $$2 = $42;$$213 = $41;
  ___resumeException($$213|0);
  // unreachable;
 }
 $16 = ((($11)) + 8|0);
 $17 = HEAP32[$16>>2]|0;HEAP32[$16>>2] = (($17+1)|0);
 __THREW__ = 0;
 invoke_viii(3310,($9|0),($11|0),(0|0));
 $18 = __THREW__; __THREW__ = 0;
 $19 = $18&1;
 L8: do {
  if ($19) {
   $43 = ___cxa_find_matching_catch_2()|0;
   $44 = tempRet0;
   $$1 = $44;$$112 = $43;
   label = 26;
  } else {
   $20 = ((($9)) + 20|0);
   HEAP32[$20>>2] = $6;
   $21 = HEAP32[$1>>2]|0;
   $22 = ((($21)) + 188|0);
   $23 = HEAP32[$22>>2]|0;
   __THREW__ = 0;
   invoke_vii($23|0,($1|0),($9|0));
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   do {
    if ($25) {
     label = 12;
    } else {
     $26 = HEAP32[$11>>2]|0;
     $27 = ((($26)) + 32|0);
     $28 = HEAP32[$27>>2]|0;
     __THREW__ = 0;
     $29 = (invoke_ii($28|0,($11|0))|0);
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      label = 12;
     } else {
      if ($29) {
       $32 = ((($11)) + 28|0);
       $33 = HEAP32[$32>>2]|0;
       $34 = ($33|0)==(0|0);
       $$$i = $34 ? $11 : $33;
       $35 = ((($$$i)) + 80|0);
       $36 = ($35|0)==($5|0);
       if (!($36)) {
        $37 = HEAP32[$35>>2]|0;
        HEAP32[$7>>2] = $37;
        $38 = ((($$$i)) + 84|0);
        HEAP32[$8>>2] = $38;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy>>2]=HEAP32[$7>>2]|0;
        ;HEAP32[$$byval_copy11>>2]=HEAP32[$8>>2]|0;
        invoke_viii(3311,($5|0),($$byval_copy|0),($$byval_copy11|0));
        $39 = __THREW__; __THREW__ = 0;
        $40 = $39&1;
        if ($40) {
         label = 12;
         break;
        }
       }
       $$014 = 1;
      } else {
       $59 = ((($5)) + 4|0);
       $60 = HEAP32[$59>>2]|0;
       __ZNSt3__26__treeIN7osgUtil22LineSegmentIntersector12IntersectionENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($5,$60);
       $61 = ((($5)) + 8|0);
       HEAP32[$61>>2] = 0;
       HEAP32[$5>>2] = $59;
       HEAP32[$59>>2] = 0;
       $$014 = 0;
      }
      __THREW__ = 0;
      invoke_vii(3312,($9|0),(47564|0));
      $62 = __THREW__; __THREW__ = 0;
      $63 = $62&1;
      do {
       if ($63) {
        $67 = ___cxa_find_matching_catch_2()|0;
        $68 = tempRet0;
        $69 = ((($9)) + 160|0);
        __THREW__ = 0;
        invoke_vi(388,($69|0));
        $70 = __THREW__; __THREW__ = 0;
        $71 = $70&1;
        if ($71) {
         $72 = ___cxa_find_matching_catch_3(0|0)|0;
         $73 = tempRet0;
         ___clang_call_terminate($72);
         // unreachable;
        } else {
         $eh$lpad$body$index2Z2D = $68;$eh$lpad$body$indexZ2D = $67;
        }
       } else {
        $64 = ((($9)) + 160|0);
        __THREW__ = 0;
        invoke_vi(388,($64|0));
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         $76 = ___cxa_find_matching_catch_2()|0;
         $77 = tempRet0;
         $eh$lpad$body$index2Z2D = $77;$eh$lpad$body$indexZ2D = $76;
         break;
        }
        $74 = HEAP32[$16>>2]|0;HEAP32[$16>>2] = (($74-1)|0);
        $75 = ($74|0)==(1);
        if (!($75)) {
         $$115 = $$014;
         STACKTOP = sp;return ($$115|0);
        }
        __ZNK3osg10Referenced24signalObserversAndDeleteEbb($11,1,1);
        $$115 = $$014;
        STACKTOP = sp;return ($$115|0);
       }
      } while(0);
      $$0 = $eh$lpad$body$index2Z2D;$$011 = $eh$lpad$body$indexZ2D;
     }
    }
   } while(0);
   do {
    if ((label|0) == 12) {
     $45 = ___cxa_find_matching_catch_2()|0;
     $46 = tempRet0;
     __THREW__ = 0;
     invoke_vii(3312,($9|0),(47564|0));
     $47 = __THREW__; __THREW__ = 0;
     $48 = $47&1;
     if (!($48)) {
      $49 = ((($9)) + 160|0);
      __THREW__ = 0;
      invoke_vi(388,($49|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       break L8;
      } else {
       $$0 = $46;$$011 = $45;
       break;
      }
     }
     $52 = ___cxa_find_matching_catch_3(0|0)|0;
     $53 = tempRet0;
     $54 = ((($9)) + 160|0);
     __THREW__ = 0;
     invoke_vi(388,($54|0));
     $55 = __THREW__; __THREW__ = 0;
     $56 = $55&1;
     if ($56) {
      $57 = ___cxa_find_matching_catch_3(0|0)|0;
      $58 = tempRet0;
      ___clang_call_terminate($57);
      // unreachable;
     } else {
      $eh$lpad$body21$indexZ2D = $52;
      ___clang_call_terminate($eh$lpad$body21$indexZ2D);
      // unreachable;
     }
    }
   } while(0);
   $$1 = $$0;$$112 = $$011;
   label = 26;
  }
 } while(0);
 if ((label|0) == 26) {
  $78 = HEAP32[$16>>2]|0;HEAP32[$16>>2] = (($78-1)|0);
  $79 = ($78|0)==(1);
  if (!($79)) {
   $$2 = $$1;$$213 = $$112;
   ___resumeException($$213|0);
   // unreachable;
  }
  __THREW__ = 0;
  invoke_viii(3262,($11|0),1,1);
  $80 = __THREW__; __THREW__ = 0;
  $81 = $80&1;
  if (!($81)) {
   $$2 = $$1;$$213 = $$112;
   ___resumeException($$213|0);
   // unreachable;
  }
 }
 $82 = ___cxa_find_matching_catch_3(0|0)|0;
 $83 = tempRet0;
 $eh$lpad$body21$indexZ2D = $82;
 ___clang_call_terminate($eh$lpad$body21$indexZ2D);
 // unreachable;
 return (0)|0;
}
function __ZN9osgViewer4View20computeIntersectionsEffRNSt3__28multisetIN7osgUtil22LineSegmentIntersector12IntersectionENS1_4lessIS5_EENS1_9allocatorIS5_EEEEj($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = +$1;
 $2 = +$2;
 $3 = $3|0;
 $4 = $4|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0.0, $17 = 0, $18 = 0, $19 = 0.0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0.0, $46 = 0.0, $47 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $5 = sp + 8|0;
 $6 = sp + 4|0;
 $7 = sp;
 $8 = (__ZNK9osgViewer4View27getCameraContainingPositionEffRfS1_($0,$1,$2,$6,$7)|0);
 $9 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
 do {
  if ($9) {
   $10 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
   $11 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($10,102588,21)|0);
   $12 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEf($11,$1)|0);
   $13 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($12,146554,2)|0);
   $14 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEf($13,$2)|0);
   $15 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($14,102610,10)|0);
   $16 = +HEAPF32[$6>>2];
   $17 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEf($15,$16)|0);
   $18 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($17,102621,10)|0);
   $19 = +HEAPF32[$7>>2];
   $20 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEf($18,$19)|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = ((($21)) + -12|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = (($20) + ($23)|0);
   __ZNKSt3__28ios_base6getlocEv($5,$24);
   __THREW__ = 0;
   $25 = (invoke_iii(3255,($5|0),(215188|0))|0);
   $26 = __THREW__; __THREW__ = 0;
   $27 = $26&1;
   if (!($27)) {
    $28 = HEAP32[$25>>2]|0;
    $29 = ((($28)) + 28|0);
    $30 = HEAP32[$29>>2]|0;
    __THREW__ = 0;
    $31 = (invoke_iii($30|0,($25|0),10)|0);
    $32 = __THREW__; __THREW__ = 0;
    $33 = $32&1;
    if (!($33)) {
     __ZNSt3__26localeD2Ev($5);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($20,$31)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($20)|0);
     break;
    }
   }
   $34 = ___cxa_find_matching_catch_2()|0;
   $35 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($5|0));
   $36 = __THREW__; __THREW__ = 0;
   $37 = $36&1;
   if ($37) {
    $38 = ___cxa_find_matching_catch_3(0|0)|0;
    $39 = tempRet0;
    ___clang_call_terminate($38);
    // unreachable;
   } else {
    ___resumeException($34|0);
    // unreachable;
   }
  }
 } while(0);
 $40 = ($8|0)==(0|0);
 if ($40) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $41 = ((($8)) + 288|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ($42|0)==(0|0);
 $44 = $43&1;
 $45 = +HEAPF32[$6>>2];
 $46 = +HEAPF32[$7>>2];
 $47 = (__ZN9osgViewer4View20computeIntersectionsEPKN3osg6CameraEN7osgUtil11Intersector15CoordinateFrameEffRNSt3__28multisetINS5_22LineSegmentIntersector12IntersectionENS8_4lessISB_EENS8_9allocatorISB_EEEEj(0,$8,$44,$45,$46,$3,$4)|0);
 $$0 = $47;
 STACKTOP = sp;return ($$0|0);
}
function __ZN7osgUtil16ShaderGenVisitorD2Ev($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$03 = 0, $$1 = 0, $$14 = 0, $$cast = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $2;
 $3 = ((($1)) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $$cast = $2;
 $5 = ((($$cast)) + -12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($0) + ($6)|0);
 HEAP32[$7>>2] = $4;
 $8 = ((($0)) + 64|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if ($10) {
  label = 4;
 } else {
  $11 = ((($9)) + 8|0);
  $12 = HEAP32[$11>>2]|0;HEAP32[$11>>2] = (($12-1)|0);
  $13 = ($12|0)==(1);
  if ($13) {
   __THREW__ = 0;
   invoke_viii(3262,($9|0),1,1);
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if ($15) {
    $33 = ___cxa_find_matching_catch_2()|0;
    $34 = tempRet0;
    $35 = ((($0)) + 60|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = ($36|0)==(0|0);
    if (!($37)) {
     $38 = ((($36)) + 8|0);
     $39 = HEAP32[$38>>2]|0;HEAP32[$38>>2] = (($39-1)|0);
     $40 = ($39|0)==(1);
     if ($40) {
      __THREW__ = 0;
      invoke_viii(3262,($36|0),1,1);
      $41 = __THREW__; __THREW__ = 0;
      $42 = $41&1;
      if ($42) {
       $58 = ___cxa_find_matching_catch_3(0|0)|0;
       $59 = tempRet0;
       ___clang_call_terminate($58);
       // unreachable;
      }
     }
    }
    HEAP32[$35>>2] = 0;
    $$0 = $34;$$03 = $33;
    label = 17;
   } else {
    label = 4;
   }
  } else {
   label = 4;
  }
 }
 do {
  if ((label|0) == 4) {
   HEAP32[$8>>2] = 0;
   $16 = ((($0)) + 60|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = ($17|0)==(0|0);
   if (!($18)) {
    $19 = ((($17)) + 8|0);
    $20 = HEAP32[$19>>2]|0;HEAP32[$19>>2] = (($20-1)|0);
    $21 = ($20|0)==(1);
    if ($21) {
     __THREW__ = 0;
     invoke_viii(3262,($17|0),1,1);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      $43 = ___cxa_find_matching_catch_2()|0;
      $44 = tempRet0;
      $$0 = $44;$$03 = $43;
      label = 17;
      break;
     }
    }
   }
   HEAP32[$16>>2] = 0;
   $24 = ((($0)) + 56|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = ($25|0)==(0|0);
   if ($26) {
    HEAP32[$24>>2] = 0;
    $32 = ((($1)) + 4|0);
    __ZN3osg11NodeVisitorD2Ev($0,$32);
    return;
   }
   $27 = ((($25)) + 8|0);
   $28 = HEAP32[$27>>2]|0;HEAP32[$27>>2] = (($28-1)|0);
   $29 = ($28|0)==(1);
   if (!($29)) {
    HEAP32[$24>>2] = 0;
    $32 = ((($1)) + 4|0);
    __ZN3osg11NodeVisitorD2Ev($0,$32);
    return;
   }
   __THREW__ = 0;
   invoke_viii(3262,($25|0),1,1);
   $30 = __THREW__; __THREW__ = 0;
   $31 = $30&1;
   if ($31) {
    $45 = ___cxa_find_matching_catch_2()|0;
    $46 = tempRet0;
    $$1 = $46;$$14 = $45;
    break;
   } else {
    HEAP32[$24>>2] = 0;
    $32 = ((($1)) + 4|0);
    __ZN3osg11NodeVisitorD2Ev($0,$32);
    return;
   }
  }
 } while(0);
 if ((label|0) == 17) {
  $47 = ((($0)) + 56|0);
  $48 = HEAP32[$47>>2]|0;
  $49 = ($48|0)==(0|0);
  if (!($49)) {
   $50 = ((($48)) + 8|0);
   $51 = HEAP32[$50>>2]|0;HEAP32[$50>>2] = (($51-1)|0);
   $52 = ($51|0)==(1);
   if ($52) {
    __THREW__ = 0;
    invoke_viii(3262,($48|0),1,1);
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if ($54) {
     $58 = ___cxa_find_matching_catch_3(0|0)|0;
     $59 = tempRet0;
     ___clang_call_terminate($58);
     // unreachable;
    }
   }
  }
  HEAP32[$47>>2] = 0;
  $$1 = $$0;$$14 = $$03;
 }
 $55 = ((($1)) + 4|0);
 __THREW__ = 0;
 invoke_vii(3284,($0|0),($55|0));
 $56 = __THREW__; __THREW__ = 0;
 $57 = $56&1;
 if ($57) {
  $58 = ___cxa_find_matching_catch_3(0|0)|0;
  $59 = tempRet0;
  ___clang_call_terminate($58);
  // unreachable;
 } else {
  ___resumeException($$14|0);
  // unreachable;
 }
}
function __ZN9osgViewer4View37computeActiveCoordinateSystemNodePathEv($0) {
 $0 = $0|0;
 var $$07 = 0, $$08 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$indexZ2D = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i17 = 0, $scevgep$i$i$i24 = 0, $scevgep5$i$i$i = 0, $scevgep5$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i18 = 0, $scevgep5$i$i$i25 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(112|0);
 $1 = sp + 12|0;
 $2 = sp;
 $3 = ((($0)) + 68|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 do {
  if (!($5)) {
   $6 = (__ZN9osgViewer5Scene12getSceneDataEv($4)|0);
   $7 = ($6|0)==(0|0);
   if (!($7)) {
    $8 = ((($1)) + 68|0);
    __ZN3osg10ReferencedC2Ev($8);
    HEAP32[$8>>2] = (63412);
    $9 = ((($1)) + 80|0);
    ;HEAP32[$9>>2]=0|0;HEAP32[$9+4>>2]=0|0;HEAP32[$9+8>>2]=0|0;
    $10 = ((($1)) + 92|0);
    HEAP32[$10>>2] = 2;
    $11 = ((($1)) + 96|0);
    HEAP32[$11>>2] = 0;
    __THREW__ = 0;
    invoke_viii(3283,($1|0),((35504)|0),3);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     $14 = ___cxa_find_matching_catch_2()|0;
     $15 = tempRet0;
     __THREW__ = 0;
     invoke_vi(388,($8|0));
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      $18 = ___cxa_find_matching_catch_3(0|0)|0;
      $19 = tempRet0;
      ___clang_call_terminate($18);
      // unreachable;
     } else {
      ___resumeException($14|0);
      // unreachable;
     }
    }
    HEAP32[$1>>2] = (35528);
    HEAP32[$8>>2] = (35872);
    $20 = ((($1)) + 56|0);
    HEAP32[$20>>2] = 0;
    $21 = ((($1)) + 60|0);
    HEAP32[$21>>2] = 0;
    $22 = ((($1)) + 64|0);
    HEAP32[$22>>2] = 0;
    $23 = HEAP32[$6>>2]|0;
    $24 = ((($23)) + 188|0);
    $25 = HEAP32[$24>>2]|0;
    __THREW__ = 0;
    invoke_vii($25|0,($6|0),($1|0));
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if (!($27)) {
     $28 = ((($1)) + 56|0);
     $29 = HEAP32[$28>>2]|0;
     $30 = HEAP32[$21>>2]|0;
     $31 = ($29|0)==($30|0);
     if ($31) {
      HEAP32[$1>>2] = ((35528));
      HEAP32[$8>>2] = ((35872));
      $56 = ($29|0)==(0|0);
      if (!($56)) {
       __ZdlPv($29);
      }
      __THREW__ = 0;
      invoke_vii(3284,($1|0),((35504)|0));
      $57 = __THREW__; __THREW__ = 0;
      $58 = $57&1;
      if (!($58)) {
       __ZN3osg6ObjectD2Ev($8);
       break;
      }
      $59 = ___cxa_find_matching_catch_2()|0;
      $60 = tempRet0;
      __THREW__ = 0;
      invoke_vi(388,($8|0));
      $61 = __THREW__; __THREW__ = 0;
      $62 = $61&1;
      if ($62) {
       $63 = ___cxa_find_matching_catch_3(0|0)|0;
       $64 = tempRet0;
       ___clang_call_terminate($63);
       // unreachable;
      } else {
       ___resumeException($59|0);
       // unreachable;
      }
     }
     $32 = ((($0)) + 92|0);
     __THREW__ = 0;
     invoke_vii(3320,($32|0),($28|0));
     $33 = __THREW__; __THREW__ = 0;
     $34 = $33&1;
     if (!($34)) {
      HEAP32[$1>>2] = ((35528));
      HEAP32[$8>>2] = ((35872));
      $79 = HEAP32[$20>>2]|0;
      $80 = ($79|0)==(0|0);
      if (!($80)) {
       $81 = HEAP32[$21>>2]|0;
       $82 = ($81|0)==($79|0);
       if (!($82)) {
        $scevgep$i$i$i$i$i17 = ((($81)) + -4|0);
        $83 = $scevgep$i$i$i$i$i17;
        $84 = $79;
        $85 = (($83) - ($84))|0;
        $86 = $85 >>> 2;
        $87 = $86 ^ -1;
        $scevgep5$i$i$i$i$i18 = (($81) + ($87<<2)|0);
        HEAP32[$21>>2] = $scevgep5$i$i$i$i$i18;
       }
       __ZdlPv($79);
      }
      __THREW__ = 0;
      invoke_vii(3284,($1|0),((35504)|0));
      $88 = __THREW__; __THREW__ = 0;
      $89 = $88&1;
      if (!($89)) {
       __ZN3osg6ObjectD2Ev($8);
       STACKTOP = sp;return;
      }
      $90 = ___cxa_find_matching_catch_2()|0;
      $91 = tempRet0;
      __THREW__ = 0;
      invoke_vi(388,($8|0));
      $92 = __THREW__; __THREW__ = 0;
      $93 = $92&1;
      if ($93) {
       $94 = ___cxa_find_matching_catch_3(0|0)|0;
       $95 = tempRet0;
       ___clang_call_terminate($94);
       // unreachable;
      } else {
       ___resumeException($90|0);
       // unreachable;
      }
     }
    }
    $35 = ___cxa_find_matching_catch_2()|0;
    $36 = tempRet0;
    HEAP32[$1>>2] = ((35528));
    HEAP32[$8>>2] = ((35872));
    $37 = HEAP32[$20>>2]|0;
    $38 = ($37|0)==(0|0);
    if (!($38)) {
     $39 = HEAP32[$21>>2]|0;
     $40 = ($39|0)==($37|0);
     if (!($40)) {
      $scevgep$i$i$i$i$i = ((($39)) + -4|0);
      $41 = $scevgep$i$i$i$i$i;
      $42 = $37;
      $43 = (($41) - ($42))|0;
      $44 = $43 >>> 2;
      $45 = $44 ^ -1;
      $scevgep5$i$i$i$i$i = (($39) + ($45<<2)|0);
      HEAP32[$21>>2] = $scevgep5$i$i$i$i$i;
     }
     __ZdlPv($37);
    }
    __THREW__ = 0;
    invoke_vii(3284,($1|0),((35504)|0));
    $46 = __THREW__; __THREW__ = 0;
    $47 = $46&1;
    if ($47) {
     $50 = ___cxa_find_matching_catch_3(0|0)|0;
     $51 = tempRet0;
     __THREW__ = 0;
     invoke_vi(388,($8|0));
     $52 = __THREW__; __THREW__ = 0;
     $53 = $52&1;
     if ($53) {
      $54 = ___cxa_find_matching_catch_3(0|0)|0;
      $55 = tempRet0;
      ___clang_call_terminate($54);
      // unreachable;
     } else {
      $eh$lpad$body$indexZ2D = $50;
      ___clang_call_terminate($eh$lpad$body$indexZ2D);
      // unreachable;
     }
    }
    __THREW__ = 0;
    invoke_vi(388,($8|0));
    $48 = __THREW__; __THREW__ = 0;
    $49 = $48&1;
    if ($49) {
     $107 = ___cxa_find_matching_catch_3(0|0)|0;
     $108 = tempRet0;
     $eh$lpad$body$indexZ2D = $107;
     ___clang_call_terminate($eh$lpad$body$indexZ2D);
     // unreachable;
    } else {
     $$07 = $36;$$08 = $35;
     ___resumeException($$08|0);
     // unreachable;
    }
   }
  }
 } while(0);
 HEAP32[$2>>2] = 0;
 $65 = ((($2)) + 4|0);
 HEAP32[$65>>2] = 0;
 $66 = ((($2)) + 8|0);
 HEAP32[$66>>2] = 0;
 $67 = ((($0)) + 92|0);
 __THREW__ = 0;
 invoke_vii(3320,($67|0),($2|0));
 $68 = __THREW__; __THREW__ = 0;
 $69 = $68&1;
 if ($69) {
  $96 = ___cxa_find_matching_catch_2()|0;
  $97 = tempRet0;
  $98 = HEAP32[$2>>2]|0;
  $99 = ($98|0)==(0|0);
  if (!($99)) {
   $100 = HEAP32[$65>>2]|0;
   $101 = ($100|0)==($98|0);
   if (!($101)) {
    $scevgep$i$i$i24 = ((($100)) + -4|0);
    $102 = $scevgep$i$i$i24;
    $103 = $98;
    $104 = (($102) - ($103))|0;
    $105 = $104 >>> 2;
    $106 = $105 ^ -1;
    $scevgep5$i$i$i25 = (($100) + ($106<<2)|0);
    HEAP32[$65>>2] = $scevgep5$i$i$i25;
   }
   __ZdlPv($98);
  }
  $$07 = $97;$$08 = $96;
  ___resumeException($$08|0);
  // unreachable;
 } else {
  $70 = HEAP32[$2>>2]|0;
  $71 = ($70|0)==(0|0);
  if (!($71)) {
   $72 = HEAP32[$65>>2]|0;
   $73 = ($72|0)==($70|0);
   if (!($73)) {
    $scevgep$i$i$i = ((($72)) + -4|0);
    $74 = $scevgep$i$i$i;
    $75 = $70;
    $76 = (($74) - ($75))|0;
    $77 = $76 >>> 2;
    $78 = $77 ^ -1;
    $scevgep5$i$i$i = (($72) + ($78<<2)|0);
    HEAP32[$65>>2] = $scevgep5$i$i$i;
   }
   __ZdlPv($70);
  }
  STACKTOP = sp;return;
 }
}
function __ZN9osgViewer4View24assignSceneDataToCamerasEv($0) {
 $0 = $0|0;
 var $$038 = 0, $$038$us = 0, $$pr$pre = 0, $$pr41 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 68|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 do {
  if ($3) {
   $26 = 0;
  } else {
   $4 = ((($2)) + 16|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = ($5|0)==(0|0);
   if ($6) {
    $$pr41 = $2;
   } else {
    $7 = ((($0)) + 40|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = ($8|0)==(0|0);
    if ($9) {
     $$pr41 = $2;
    } else {
     $10 = ((($8)) + 24|0);
     $11 = HEAP32[$10>>2]|0;
     $12 = ($11|0)==(0|0);
     if ($12) {
      $$pr41 = $2;
     } else {
      $13 = ((($0)) + 44|0);
      $14 = HEAP32[$13>>2]|0;
      $15 = ($14|0)==(0|0);
      if ($15) {
       $$pr41 = $2;
      } else {
       $16 = ((($14)) + 88|0);
       $17 = HEAP32[$16>>2]|0;
       __ZN5osgDB13DatabasePager30setIncrementalCompileOperationEPN7osgUtil27IncrementalCompileOperationE($5,$17);
       $$pr$pre = HEAP32[$1>>2]|0;
       $18 = ($$pr$pre|0)==(0|0);
       if ($18) {
        $26 = 0;
        break;
       } else {
        $$pr41 = $$pr$pre;
       }
      }
     }
    }
   }
   $19 = (__ZN9osgViewer5Scene12getSceneDataEv($$pr41)|0);
   $26 = $19;
  }
 } while(0);
 $20 = ((($0)) + 76|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0|0);
 do {
  if (!($22)) {
   $23 = HEAP32[$21>>2]|0;
   $24 = ((($23)) + 112|0);
   $25 = HEAP32[$24>>2]|0;
   FUNCTION_TABLE_vii[$25 & 8191]($21,$26);
   $27 = ((($0)) + 72|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = (__ZN5osgGA10EventQueue11createEventEv($28)|0);
   $30 = ($29|0)==(0|0);
   if (!($30)) {
    $31 = ((($29)) + 8|0);
    $32 = HEAP32[$31>>2]|0;HEAP32[$31>>2] = (($32+1)|0);
   }
   $33 = HEAP32[$20>>2]|0;
   $34 = HEAP32[$33>>2]|0;
   $35 = ((($34)) + 144|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = ((($0)) + 36|0);
   __THREW__ = 0;
   invoke_viii($36|0,($33|0),($29|0),($37|0));
   $38 = __THREW__; __THREW__ = 0;
   $39 = $38&1;
   if (!($39)) {
    if ($30) {
     break;
    }
    $40 = ((($29)) + 8|0);
    $41 = HEAP32[$40>>2]|0;HEAP32[$40>>2] = (($41-1)|0);
    $42 = ($41|0)==(1);
    if (!($42)) {
     break;
    }
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($29,1,1);
    break;
   }
   $43 = ___cxa_find_matching_catch_2()|0;
   $44 = tempRet0;
   if ($30) {
    ___resumeException($43|0);
    // unreachable;
   }
   $45 = ((($29)) + 8|0);
   $46 = HEAP32[$45>>2]|0;HEAP32[$45>>2] = (($46-1)|0);
   $47 = ($46|0)==(1);
   if (!($47)) {
    ___resumeException($43|0);
    // unreachable;
   }
   __THREW__ = 0;
   invoke_viii(3262,($29|0),1,1);
   $48 = __THREW__; __THREW__ = 0;
   $49 = $48&1;
   if ($49) {
    $136 = ___cxa_find_matching_catch_3(0|0)|0;
    $137 = tempRet0;
    ___clang_call_terminate($136);
    // unreachable;
   } else {
    ___resumeException($43|0);
    // unreachable;
   }
  }
 } while(0);
 $50 = ((($0)) + 16|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = ($51|0)==(0|0);
 if (!($52)) {
  $53 = HEAP32[$51>>2]|0;
  $54 = ((($53)) + 216|0);
  $55 = HEAP32[$54>>2]|0;
  $56 = ((($53)) + 224|0);
  $57 = HEAP32[$56>>2]|0;
  $58 = (FUNCTION_TABLE_ii[$57 & 8191]($51)|0);
  (FUNCTION_TABLE_iiii[$55 & 8191]($51,0,$58)|0);
  $59 = ($26|0)==(0|0);
  if (!($59)) {
   $60 = HEAP32[$50>>2]|0;
   $61 = HEAP32[$60>>2]|0;
   $62 = ((($61)) + 204|0);
   $63 = HEAP32[$62>>2]|0;
   (FUNCTION_TABLE_iii[$63 & 8191]($60,$26)|0);
  }
  $64 = HEAP32[$50>>2]|0;
  $65 = ((($64)) + 628|0);
  $66 = HEAP32[$65>>2]|0;
  $67 = ($66|0)==(0|0);
  if (!($67)) {
   $68 = (___dynamic_cast($66,25048,8160,0)|0);
   $69 = ($68|0)==(0|0);
   if (!($69)) {
    $70 = ((($68)) + 30|0);
    HEAP8[$70>>0] = 1;
   }
  }
 }
 $71 = ((($0)) + 20|0);
 $72 = ((($0)) + 24|0);
 $73 = HEAP32[$72>>2]|0;
 $74 = HEAP32[$71>>2]|0;
 $75 = ($73|0)==($74|0);
 $76 = $74;
 if ($75) {
  return;
 }
 $77 = ($26|0)==(0|0);
 if ($77) {
  $$038$us = 0;$79 = $76;
  while(1) {
   $78 = (((($79) + (($$038$us*272)|0)|0)) + 4|0);
   $80 = HEAP32[$78>>2]|0;
   $81 = ($80|0)==(0|0);
   if (!($81)) {
    $82 = (((($79) + (($$038$us*272)|0)|0)) + 264|0);
    $83 = HEAP8[$82>>0]|0;
    $84 = ($83<<24>>24)==(0);
    if (!($84)) {
     $85 = HEAP32[$80>>2]|0;
     $86 = ((($85)) + 216|0);
     $87 = HEAP32[$86>>2]|0;
     $88 = ((($85)) + 224|0);
     $89 = HEAP32[$88>>2]|0;
     $90 = (FUNCTION_TABLE_ii[$89 & 8191]($80)|0);
     (FUNCTION_TABLE_iiii[$87 & 8191]($80,0,$90)|0);
     $91 = HEAP32[$78>>2]|0;
     $92 = ((($91)) + 628|0);
     $93 = HEAP32[$92>>2]|0;
     $94 = ($93|0)==(0|0);
     if (!($94)) {
      $95 = (___dynamic_cast($93,25048,8160,0)|0);
      $96 = ($95|0)==(0|0);
      if (!($96)) {
       $97 = ((($95)) + 30|0);
       HEAP8[$97>>0] = 1;
      }
     }
    }
   }
   $98 = (($$038$us) + 1)|0;
   $99 = HEAP32[$72>>2]|0;
   $100 = HEAP32[$71>>2]|0;
   $101 = (($99) - ($100))|0;
   $102 = (($101|0) / 272)&-1;
   $103 = ($98>>>0)<($102>>>0);
   $104 = $100;
   if ($103) {
    $$038$us = $98;$79 = $104;
   } else {
    break;
   }
  }
  return;
 } else {
  $$038 = 0;$106 = $76;
  while(1) {
   $105 = (((($106) + (($$038*272)|0)|0)) + 4|0);
   $107 = HEAP32[$105>>2]|0;
   $108 = ($107|0)==(0|0);
   if (!($108)) {
    $109 = (((($106) + (($$038*272)|0)|0)) + 264|0);
    $110 = HEAP8[$109>>0]|0;
    $111 = ($110<<24>>24)==(0);
    if (!($111)) {
     $112 = HEAP32[$107>>2]|0;
     $113 = ((($112)) + 216|0);
     $114 = HEAP32[$113>>2]|0;
     $115 = ((($112)) + 224|0);
     $116 = HEAP32[$115>>2]|0;
     $117 = (FUNCTION_TABLE_ii[$116 & 8191]($107)|0);
     (FUNCTION_TABLE_iiii[$114 & 8191]($107,0,$117)|0);
     $118 = HEAP32[$105>>2]|0;
     $119 = HEAP32[$118>>2]|0;
     $120 = ((($119)) + 204|0);
     $121 = HEAP32[$120>>2]|0;
     (FUNCTION_TABLE_iii[$121 & 8191]($118,$26)|0);
     $122 = HEAP32[$105>>2]|0;
     $123 = ((($122)) + 628|0);
     $124 = HEAP32[$123>>2]|0;
     $125 = ($124|0)==(0|0);
     if (!($125)) {
      $126 = (___dynamic_cast($124,25048,8160,0)|0);
      $127 = ($126|0)==(0|0);
      if (!($127)) {
       $128 = ((($126)) + 30|0);
       HEAP8[$128>>0] = 1;
      }
     }
    }
   }
   $129 = (($$038) + 1)|0;
   $130 = HEAP32[$72>>2]|0;
   $131 = HEAP32[$71>>2]|0;
   $132 = (($130) - ($131))|0;
   $133 = (($132|0) / 272)&-1;
   $134 = ($129>>>0)<($133>>>0);
   $135 = $131;
   if ($134) {
    $$038 = $129;$106 = $135;
   } else {
    break;
   }
  }
  return;
 }
}
function __ZN37CollectedCoordinateSystemNodesVisitorD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $scevgep$i$i$i$i = 0, $scevgep5$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = ((35528));
 $1 = ((($0)) + 68|0);
 HEAP32[$1>>2] = ((35872));
 $2 = ((($0)) + 56|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = ((($0)) + 60|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==($3|0);
  if (!($7)) {
   $scevgep$i$i$i$i = ((($6)) + -4|0);
   $8 = $scevgep$i$i$i$i;
   $9 = $3;
   $10 = (($8) - ($9))|0;
   $11 = $10 >>> 2;
   $12 = $11 ^ -1;
   $scevgep5$i$i$i$i = (($6) + ($12<<2)|0);
   HEAP32[$5>>2] = $scevgep5$i$i$i$i;
  }
  __ZdlPv($3);
 }
 __THREW__ = 0;
 invoke_vii(3284,($0|0),((35504)|0));
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 if (!($14)) {
  __ZN3osg6ObjectD2Ev($1);
  return;
 }
 $15 = ___cxa_find_matching_catch_2()|0;
 $16 = tempRet0;
 __THREW__ = 0;
 invoke_vi(388,($1|0));
 $17 = __THREW__; __THREW__ = 0;
 $18 = $17&1;
 if ($18) {
  $19 = ___cxa_find_matching_catch_3(0|0)|0;
  $20 = tempRet0;
  ___clang_call_terminate($19);
  // unreachable;
 } else {
  ___resumeException($15|0);
  // unreachable;
 }
}
function __ZN37CollectedCoordinateSystemNodesVisitorD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, $scevgep$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = ((35528));
 $1 = ((($0)) + 68|0);
 HEAP32[$1>>2] = ((35872));
 $2 = ((($0)) + 56|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = ((($0)) + 60|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==($3|0);
  if (!($7)) {
   $scevgep$i$i$i$i$i = ((($6)) + -4|0);
   $8 = $scevgep$i$i$i$i$i;
   $9 = $3;
   $10 = (($8) - ($9))|0;
   $11 = $10 >>> 2;
   $12 = $11 ^ -1;
   $scevgep5$i$i$i$i$i = (($6) + ($12<<2)|0);
   HEAP32[$5>>2] = $scevgep5$i$i$i$i$i;
  }
  __ZdlPv($3);
 }
 __THREW__ = 0;
 invoke_vii(3284,($0|0),((35504)|0));
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 if ($14) {
  $17 = ___cxa_find_matching_catch_2()|0;
  $18 = tempRet0;
  __THREW__ = 0;
  invoke_vi(388,($1|0));
  $19 = __THREW__; __THREW__ = 0;
  $20 = $19&1;
  if ($20) {
   $21 = ___cxa_find_matching_catch_3(0|0)|0;
   $22 = tempRet0;
   ___clang_call_terminate($21);
   // unreachable;
  } else {
   $eh$lpad$body$index2Z2D = $18;$eh$lpad$body$indexZ2D = $17;
   __ZdlPv($0);
   ___resumeException($eh$lpad$body$indexZ2D|0);
   // unreachable;
  }
 }
 __THREW__ = 0;
 invoke_vi(388,($1|0));
 $15 = __THREW__; __THREW__ = 0;
 $16 = $15&1;
 if (!($16)) {
  __ZdlPv($0);
  return;
 }
 $23 = ___cxa_find_matching_catch_2()|0;
 $24 = tempRet0;
 $eh$lpad$body$index2Z2D = $24;$eh$lpad$body$indexZ2D = $23;
 __ZdlPv($0);
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
}
function __ZNK3osg11NodeVisitor9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(88)|0);
 __THREW__ = 0;
 invoke_vii(3321,($1|0),0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $8 = ___cxa_find_matching_catch_2()|0;
  $9 = tempRet0;
  __ZdlPv($1);
  ___resumeException($8|0);
  // unreachable;
 } else {
  $4 = HEAP32[$1>>2]|0;
  $5 = ((($4)) + -12|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($1) + ($6)|0);
  return ($7|0);
 }
 return (0)|0;
}
function __ZNK3osg11NodeVisitor5cloneERKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(88)|0);
 __THREW__ = 0;
 invoke_viii(3322,($2|0),($0|0),($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $9 = ___cxa_find_matching_catch_2()|0;
  $10 = tempRet0;
  __ZdlPv($2);
  ___resumeException($9|0);
  // unreachable;
 } else {
  $5 = HEAP32[$2>>2]|0;
  $6 = ((($5)) + -12|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($2) + ($7)|0);
  return ($8|0);
 }
 return (0)|0;
}
function __ZNK3osg11NodeVisitor12isSameKindAsEPKNS_6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,25968,-1)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK37CollectedCoordinateSystemNodesVisitor11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (102794|0);
}
function __ZNK37CollectedCoordinateSystemNodesVisitor9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (102754|0);
}
function __ZN3osg11NodeVisitor13asNodeVisitorEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ($0|0);
}
function __ZNK3osg11NodeVisitor13asNodeVisitorEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ($0|0);
}
function __ZN3osg11NodeVisitor15asUpdateVisitorEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZNK3osg11NodeVisitor15asUpdateVisitorEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZN3osg11NodeVisitor13asCullVisitorEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZNK3osg11NodeVisitor13asCullVisitorEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZN3osg11NodeVisitor14asEventVisitorEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZNK3osg11NodeVisitor14asEventVisitorEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZN3osg11NodeVisitor21asIntersectionVisitorEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZNK3osg11NodeVisitor21asIntersectionVisitorEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZN3osg11NodeVisitor11asCullStackEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZNK3osg11NodeVisitor11asCullStackEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZN3osg11NodeVisitor5resetEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZNK3osg11NodeVisitor11getEyePointEv($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF32[$0>>2] = 0.0;
 $2 = ((($0)) + 4|0);
 HEAPF32[$2>>2] = 0.0;
 $3 = ((($0)) + 8|0);
 HEAPF32[$3>>2] = 0.0;
 return;
}
function __ZNK3osg11NodeVisitor12getViewPointEv($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 80|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 8191]($0,$1);
 return;
}
function __ZNK3osg11NodeVisitor21getDistanceToEyePointERKNS_5Vec3fEb($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return +0;
}
function __ZNK3osg11NodeVisitor23getDistanceFromEyePointERKNS_5Vec3fEb($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return +0;
}
function __ZNK3osg11NodeVisitor22getDistanceToViewPointERKNS_5Vec3fEb($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return +0;
}
function __ZN37CollectedCoordinateSystemNodesVisitor5applyERN3osg4NodeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 switch ($3|0) {
 case 1:  {
  $4 = HEAP32[$1>>2]|0;
  $5 = ((($4)) + 192|0);
  $6 = HEAP32[$5>>2]|0;
  FUNCTION_TABLE_vii[$6 & 8191]($1,$0);
  return;
  break;
 }
 case 0:  {
  return;
  break;
 }
 default: {
  $7 = HEAP32[$1>>2]|0;
  $8 = ((($7)) + 196|0);
  $9 = HEAP32[$8>>2]|0;
  FUNCTION_TABLE_vii[$9 & 8191]($1,$0);
  return;
 }
 }
}
function __ZN37CollectedCoordinateSystemNodesVisitor5applyERN3osg20CoordinateSystemNodeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp + 12|0;
 $3 = sp + 8|0;
 $4 = sp + 4|0;
 $5 = sp;
 $6 = ((($0)) + 56|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($0)) + 60|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($7|0)==($9|0);
 $11 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(5)|0);
 do {
  if ($10) {
   do {
    if ($11) {
     $12 = (__ZN3osg6notifyENS_14NotifySeverityE(5)|0);
     $13 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($12,102806,31)|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = ((($14)) + -12|0);
     $16 = HEAP32[$15>>2]|0;
     $17 = (($13) + ($16)|0);
     __ZNKSt3__28ios_base6getlocEv($5,$17);
     __THREW__ = 0;
     $18 = (invoke_iii(3255,($5|0),(215188|0))|0);
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if (!($20)) {
      $21 = HEAP32[$18>>2]|0;
      $22 = ((($21)) + 28|0);
      $23 = HEAP32[$22>>2]|0;
      __THREW__ = 0;
      $24 = (invoke_iii($23|0,($18|0),10)|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __ZNSt3__26localeD2Ev($5);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($13,$24)|0);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($13)|0);
       break;
      }
     }
     $27 = ___cxa_find_matching_catch_2()|0;
     $28 = tempRet0;
     __THREW__ = 0;
     invoke_vi(3263,($5|0));
     $29 = __THREW__; __THREW__ = 0;
     $30 = $29&1;
     if ($30) {
      $31 = ___cxa_find_matching_catch_3(0|0)|0;
      $32 = tempRet0;
      ___clang_call_terminate($31);
      // unreachable;
     } else {
      ___resumeException($27|0);
      // unreachable;
     }
    }
   } while(0);
   $33 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(5)|0);
   do {
    if ($33) {
     $34 = (__ZN3osg6notifyENS_14NotifySeverityE(5)|0);
     $35 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($34,102838,24)|0);
     $36 = ((($1)) + 148|0);
     $37 = ((($36)) + 11|0);
     $38 = HEAP8[$37>>0]|0;
     $39 = ($38<<24>>24)<(0);
     $40 = HEAP32[$36>>2]|0;
     $41 = $39 ? $40 : $36;
     $42 = ((($1)) + 152|0);
     $43 = HEAP32[$42>>2]|0;
     $44 = $38&255;
     $45 = $39 ? $43 : $44;
     $46 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($35,$41,$45)|0);
     $47 = HEAP32[$46>>2]|0;
     $48 = ((($47)) + -12|0);
     $49 = HEAP32[$48>>2]|0;
     $50 = (($46) + ($49)|0);
     __ZNKSt3__28ios_base6getlocEv($4,$50);
     __THREW__ = 0;
     $51 = (invoke_iii(3255,($4|0),(215188|0))|0);
     $52 = __THREW__; __THREW__ = 0;
     $53 = $52&1;
     if (!($53)) {
      $54 = HEAP32[$51>>2]|0;
      $55 = ((($54)) + 28|0);
      $56 = HEAP32[$55>>2]|0;
      __THREW__ = 0;
      $57 = (invoke_iii($56|0,($51|0),10)|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if (!($59)) {
       __ZNSt3__26localeD2Ev($4);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($46,$57)|0);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($46)|0);
       break;
      }
     }
     $60 = ___cxa_find_matching_catch_2()|0;
     $61 = tempRet0;
     __THREW__ = 0;
     invoke_vi(3263,($4|0));
     $62 = __THREW__; __THREW__ = 0;
     $63 = $62&1;
     if ($63) {
      $64 = ___cxa_find_matching_catch_3(0|0)|0;
      $65 = tempRet0;
      ___clang_call_terminate($64);
      // unreachable;
     } else {
      ___resumeException($60|0);
      // unreachable;
     }
    }
   } while(0);
   $66 = ((($0)) + 28|0);
   $67 = HEAP32[$66>>2]|0;
   $68 = ((($0)) + 32|0);
   $69 = HEAP32[$68>>2]|0;
   __ZNSt3__26vectorIPN3osg4NodeENS_9allocatorIS3_EEE6assignIPS3_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS3_NS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_($6,$67,$69);
  } else {
   do {
    if ($11) {
     $70 = (__ZN3osg6notifyENS_14NotifySeverityE(5)|0);
     $71 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($70,102863,56)|0);
     $72 = HEAP32[$71>>2]|0;
     $73 = ((($72)) + -12|0);
     $74 = HEAP32[$73>>2]|0;
     $75 = (($71) + ($74)|0);
     __ZNKSt3__28ios_base6getlocEv($3,$75);
     __THREW__ = 0;
     $76 = (invoke_iii(3255,($3|0),(215188|0))|0);
     $77 = __THREW__; __THREW__ = 0;
     $78 = $77&1;
     if (!($78)) {
      $79 = HEAP32[$76>>2]|0;
      $80 = ((($79)) + 28|0);
      $81 = HEAP32[$80>>2]|0;
      __THREW__ = 0;
      $82 = (invoke_iii($81|0,($76|0),10)|0);
      $83 = __THREW__; __THREW__ = 0;
      $84 = $83&1;
      if (!($84)) {
       __ZNSt3__26localeD2Ev($3);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($71,$82)|0);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($71)|0);
       break;
      }
     }
     $85 = ___cxa_find_matching_catch_2()|0;
     $86 = tempRet0;
     __THREW__ = 0;
     invoke_vi(3263,($3|0));
     $87 = __THREW__; __THREW__ = 0;
     $88 = $87&1;
     if ($88) {
      $89 = ___cxa_find_matching_catch_3(0|0)|0;
      $90 = tempRet0;
      ___clang_call_terminate($89);
      // unreachable;
     } else {
      ___resumeException($85|0);
      // unreachable;
     }
    }
   } while(0);
   $91 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(5)|0);
   if ($91) {
    $92 = (__ZN3osg6notifyENS_14NotifySeverityE(5)|0);
    $93 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($92,102838,24)|0);
    $94 = ((($1)) + 148|0);
    $95 = ((($94)) + 11|0);
    $96 = HEAP8[$95>>0]|0;
    $97 = ($96<<24>>24)<(0);
    $98 = HEAP32[$94>>2]|0;
    $99 = $97 ? $98 : $94;
    $100 = ((($1)) + 152|0);
    $101 = HEAP32[$100>>2]|0;
    $102 = $96&255;
    $103 = $97 ? $101 : $102;
    $104 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($93,$99,$103)|0);
    $105 = HEAP32[$104>>2]|0;
    $106 = ((($105)) + -12|0);
    $107 = HEAP32[$106>>2]|0;
    $108 = (($104) + ($107)|0);
    __ZNKSt3__28ios_base6getlocEv($2,$108);
    __THREW__ = 0;
    $109 = (invoke_iii(3255,($2|0),(215188|0))|0);
    $110 = __THREW__; __THREW__ = 0;
    $111 = $110&1;
    if (!($111)) {
     $112 = HEAP32[$109>>2]|0;
     $113 = ((($112)) + 28|0);
     $114 = HEAP32[$113>>2]|0;
     __THREW__ = 0;
     $115 = (invoke_iii($114|0,($109|0),10)|0);
     $116 = __THREW__; __THREW__ = 0;
     $117 = $116&1;
     if (!($117)) {
      __ZNSt3__26localeD2Ev($2);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($104,$115)|0);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($104)|0);
      break;
     }
    }
    $118 = ___cxa_find_matching_catch_2()|0;
    $119 = tempRet0;
    __THREW__ = 0;
    invoke_vi(3263,($2|0));
    $120 = __THREW__; __THREW__ = 0;
    $121 = $120&1;
    if ($121) {
     $122 = ___cxa_find_matching_catch_3(0|0)|0;
     $123 = tempRet0;
     ___clang_call_terminate($122);
     // unreachable;
    } else {
     ___resumeException($118|0);
     // unreachable;
    }
   }
  }
 } while(0);
 $124 = ((($0)) + 16|0);
 $125 = HEAP32[$124>>2]|0;
 switch ($125|0) {
 case 1:  {
  $126 = HEAP32[$1>>2]|0;
  $127 = ((($126)) + 192|0);
  $128 = HEAP32[$127>>2]|0;
  FUNCTION_TABLE_vii[$128 & 8191]($1,$0);
  STACKTOP = sp;return;
  break;
 }
 case 0:  {
  STACKTOP = sp;return;
  break;
 }
 default: {
  $129 = HEAP32[$1>>2]|0;
  $130 = ((($129)) + 196|0);
  $131 = HEAP32[$130>>2]|0;
  FUNCTION_TABLE_vii[$131 & 8191]($1,$0);
  STACKTOP = sp;return;
 }
 }
}
function __ZTv0_n16_N37CollectedCoordinateSystemNodesVisitorD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 HEAP32[$4>>2] = ((35528));
 $5 = ((($4)) + 68|0);
 HEAP32[$5>>2] = ((35872));
 $6 = ((($4)) + 56|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = ((($4)) + 60|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10|0)==($7|0);
  if (!($11)) {
   $scevgep$i$i$i$i$i = ((($10)) + -4|0);
   $12 = $scevgep$i$i$i$i$i;
   $13 = $7;
   $14 = (($12) - ($13))|0;
   $15 = $14 >>> 2;
   $16 = $15 ^ -1;
   $scevgep5$i$i$i$i$i = (($10) + ($16<<2)|0);
   HEAP32[$9>>2] = $scevgep5$i$i$i$i$i;
  }
  __ZdlPv($7);
 }
 __THREW__ = 0;
 invoke_vii(3284,($4|0),((35504)|0));
 $17 = __THREW__; __THREW__ = 0;
 $18 = $17&1;
 if (!($18)) {
  __ZN3osg6ObjectD2Ev($5);
  return;
 }
 $19 = ___cxa_find_matching_catch_2()|0;
 $20 = tempRet0;
 __THREW__ = 0;
 invoke_vi(388,($5|0));
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if ($22) {
  $23 = ___cxa_find_matching_catch_3(0|0)|0;
  $24 = tempRet0;
  ___clang_call_terminate($23);
  // unreachable;
 } else {
  ___resumeException($19|0);
  // unreachable;
 }
}
function __ZTv0_n16_N37CollectedCoordinateSystemNodesVisitorD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$i$index2Z2D = 0, $eh$lpad$body$i$indexZ2D = 0, $scevgep$i$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 HEAP32[$4>>2] = ((35528));
 $5 = ((($4)) + 68|0);
 HEAP32[$5>>2] = ((35872));
 $6 = ((($4)) + 56|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = ((($4)) + 60|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10|0)==($7|0);
  if (!($11)) {
   $scevgep$i$i$i$i$i$i = ((($10)) + -4|0);
   $12 = $scevgep$i$i$i$i$i$i;
   $13 = $7;
   $14 = (($12) - ($13))|0;
   $15 = $14 >>> 2;
   $16 = $15 ^ -1;
   $scevgep5$i$i$i$i$i$i = (($10) + ($16<<2)|0);
   HEAP32[$9>>2] = $scevgep5$i$i$i$i$i$i;
  }
  __ZdlPv($7);
 }
 __THREW__ = 0;
 invoke_vii(3284,($4|0),((35504)|0));
 $17 = __THREW__; __THREW__ = 0;
 $18 = $17&1;
 if ($18) {
  $21 = ___cxa_find_matching_catch_2()|0;
  $22 = tempRet0;
  __THREW__ = 0;
  invoke_vi(388,($5|0));
  $23 = __THREW__; __THREW__ = 0;
  $24 = $23&1;
  if ($24) {
   $25 = ___cxa_find_matching_catch_3(0|0)|0;
   $26 = tempRet0;
   ___clang_call_terminate($25);
   // unreachable;
  } else {
   $eh$lpad$body$i$index2Z2D = $22;$eh$lpad$body$i$indexZ2D = $21;
   __ZdlPv($4);
   ___resumeException($eh$lpad$body$i$indexZ2D|0);
   // unreachable;
  }
 }
 __THREW__ = 0;
 invoke_vi(388,($5|0));
 $19 = __THREW__; __THREW__ = 0;
 $20 = $19&1;
 if (!($20)) {
  __ZdlPv($4);
  return;
 }
 $27 = ___cxa_find_matching_catch_2()|0;
 $28 = tempRet0;
 $eh$lpad$body$i$index2Z2D = $28;$eh$lpad$body$i$indexZ2D = $27;
 __ZdlPv($4);
 ___resumeException($eh$lpad$body$i$indexZ2D|0);
 // unreachable;
}
function __ZTv0_n20_NK3osg11NodeVisitor9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(88)|0);
 __THREW__ = 0;
 invoke_vii(3321,($1|0),0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch_2()|0;
  $5 = tempRet0;
  __ZdlPv($1);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $6 = HEAP32[$1>>2]|0;
  $7 = ((($6)) + -12|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($1) + ($8)|0);
  return ($9|0);
 }
 return (0)|0;
}
function __ZTv0_n24_NK3osg11NodeVisitor5cloneERKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $3 = ((($2)) + -24|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($0) + ($4)|0);
 $6 = (__Znwj(88)|0);
 __THREW__ = 0;
 invoke_viii(3322,($6|0),($5|0),($1|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch_2()|0;
  $10 = tempRet0;
  __ZdlPv($6);
  ___resumeException($9|0);
  // unreachable;
 } else {
  $11 = HEAP32[$6>>2]|0;
  $12 = ((($11)) + -12|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($6) + ($13)|0);
  return ($14|0);
 }
 return (0)|0;
}
function __ZTv0_n28_NK3osg11NodeVisitor12isSameKindAsEPKNS_6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,25968,-1)|0);
 $phitmp$i = ($3|0)!=(0|0);
 $4 = $phitmp$i;
 return ($4|0);
}
function __ZTv0_n32_NK37CollectedCoordinateSystemNodesVisitor11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (102794|0);
}
function __ZTv0_n36_NK37CollectedCoordinateSystemNodesVisitor9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (102754|0);
}
function __ZTv0_n48_N3osg11NodeVisitor13asNodeVisitorEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 return ($4|0);
}
function __ZTv0_n52_NK3osg11NodeVisitor13asNodeVisitorEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -52|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 return ($4|0);
}
function __ZNK3osg11NodeVisitor11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175113|0);
}
function __ZNK3osg11NodeVisitor9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (102960|0);
}
function __ZTv0_n32_NK3osg11NodeVisitor11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175113|0);
}
function __ZTv0_n36_NK3osg11NodeVisitor9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (102960|0);
}
function __ZNSt3__24listIN3osg7ref_ptrIN5osgGA12EventHandlerEEENS_9allocatorIS5_EEE6insertINS_15__list_iteratorIS5_PvEEEESC_NS_21__list_const_iteratorIS5_SB_EET_SF_PNS_9enable_ifIXsr19__is_input_iteratorISF_EE5valueEvE4typeE($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$023$lcssa = 0, $$02369 = 0, $$cast = 0, $$cast71 = 0, $$in = 0, $$pre = 0, $$pre74 = 0, $$pre75 = 0, $$pre76 = 0, $$sroa$030$0$lcssa = 0, $$sroa$030$068 = 0, $$sroa$030$1 = 0, $$sroa$056$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = HEAP32[$1>>2]|0;
 $6 = HEAP32[$2>>2]|0;
 $7 = HEAP32[$3>>2]|0;
 $8 = ($6|0)==($7|0);
 if ($8) {
  $$sroa$056$0 = $5;
  $82 = $$sroa$056$0;
  return ($82|0);
 }
 $9 = (__Znwj(12)|0);
 HEAP32[$9>>2] = 0;
 $10 = ((($9)) + 8|0);
 $11 = ((($6)) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 HEAP32[$10>>2] = $12;
 $13 = ($12|0)==(0|0);
 if ($13) {
  $22 = $6;$25 = $7;
 } else {
  $14 = HEAP32[$12>>2]|0;
  $15 = ((($14)) + -16|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (($12) + ($16)|0);
  $18 = ((($17)) + 8|0);
  $19 = HEAP32[$18>>2]|0;HEAP32[$18>>2] = (($19+1)|0);
  $$pre = HEAP32[$2>>2]|0;
  $$pre74 = HEAP32[$3>>2]|0;
  $22 = $$pre;$25 = $$pre74;
 }
 $20 = $9;
 $21 = ((($22)) + 4|0);
 $23 = HEAP32[$21>>2]|0;
 HEAP32[$2>>2] = $23;
 $$cast = $23;
 $24 = ($$cast|0)==($25|0);
 L7: do {
  if ($24) {
   $$023$lcssa = 1;$$sroa$030$0$lcssa = $20;
  } else {
   $$02369 = 1;$$in = $23;$$sroa$030$068 = $20;$85 = $25;$86 = $$cast;
   while(1) {
    __THREW__ = 0;
    $26 = (invoke_ii(3276,12)|0);
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    $29 = $$in;
    $30 = ((($26)) + 8|0);
    $31 = ((($29)) + 8|0);
    $32 = HEAP32[$31>>2]|0;
    HEAP32[$30>>2] = $32;
    $33 = ($32|0)==(0|0);
    if ($33) {
     $43 = $86;$48 = $85;
    } else {
     $34 = HEAP32[$32>>2]|0;
     $35 = ((($34)) + -16|0);
     $36 = HEAP32[$35>>2]|0;
     $37 = (($32) + ($36)|0);
     $38 = ((($37)) + 8|0);
     $39 = HEAP32[$38>>2]|0;HEAP32[$38>>2] = (($39+1)|0);
     $$pre75 = HEAP32[$2>>2]|0;
     $$pre76 = HEAP32[$3>>2]|0;
     $43 = $$pre75;$48 = $$pre76;
    }
    $40 = $$sroa$030$068;
    $41 = ((($40)) + 4|0);
    HEAP32[$41>>2] = $26;
    HEAP32[$26>>2] = $$sroa$030$068;
    $42 = ((($43)) + 4|0);
    $44 = HEAP32[$42>>2]|0;
    HEAP32[$2>>2] = $44;
    $45 = $26;
    $46 = (($$02369) + 1)|0;
    $$cast71 = $44;
    $47 = ($$cast71|0)==($48|0);
    if ($47) {
     $$023$lcssa = $46;$$sroa$030$0$lcssa = $45;
     break L7;
    } else {
     $$02369 = $46;$$in = $44;$$sroa$030$068 = $45;$85 = $48;$86 = $$cast71;
    }
   }
   $49 = ___cxa_find_matching_catch_3(0|0)|0;
   $50 = tempRet0;
   (___cxa_begin_catch(($49|0))|0);
   $$sroa$030$1 = $$sroa$030$068;
   while(1) {
    $51 = $$sroa$030$1;
    $52 = ((($51)) + 8|0);
    $53 = HEAP32[$52>>2]|0;
    $54 = ($53|0)==(0|0);
    if (!($54)) {
     $55 = HEAP32[$53>>2]|0;
     $56 = ((($55)) + -16|0);
     $57 = HEAP32[$56>>2]|0;
     $58 = (($53) + ($57)|0);
     $59 = ((($58)) + 8|0);
     $60 = HEAP32[$59>>2]|0;HEAP32[$59>>2] = (($60-1)|0);
     $61 = ($60|0)==(1);
     if ($61) {
      __THREW__ = 0;
      invoke_viii(3262,($58|0),1,1);
      $62 = __THREW__; __THREW__ = 0;
      $63 = $62&1;
      if ($63) {
       break;
      }
     }
    }
    HEAP32[$52>>2] = 0;
    $64 = $$sroa$030$1;
    $65 = HEAP32[$64>>2]|0;
    $66 = $$sroa$030$1;
    __ZdlPv($66);
    $67 = ($65|0)==(0|0);
    if ($67) {
     label = 16;
     break;
    }
    $72 = $65;
    $$sroa$030$1 = $72;
   }
   if ((label|0) == 16) {
    __THREW__ = 0;
    invoke_v(3314);
    $73 = __THREW__; __THREW__ = 0;
   }
   $68 = ___cxa_find_matching_catch_2()|0;
   $69 = tempRet0;
   __THREW__ = 0;
   invoke_v(3261);
   $70 = __THREW__; __THREW__ = 0;
   $71 = $70&1;
   if ($71) {
    $83 = ___cxa_find_matching_catch_3(0|0)|0;
    $84 = tempRet0;
    ___clang_call_terminate($83);
    // unreachable;
   } else {
    ___resumeException($68|0);
    // unreachable;
   }
  }
 } while(0);
 $74 = HEAP32[$1>>2]|0;
 $75 = $$sroa$030$0$lcssa;
 $76 = HEAP32[$74>>2]|0;
 $77 = ((($76)) + 4|0);
 HEAP32[$77>>2] = $9;
 HEAP32[$9>>2] = $76;
 HEAP32[$74>>2] = $75;
 $78 = ((($75)) + 4|0);
 HEAP32[$78>>2] = $74;
 $79 = ((($0)) + 8|0);
 $80 = HEAP32[$79>>2]|0;
 $81 = (($80) + ($$023$lcssa))|0;
 HEAP32[$79>>2] = $81;
 $$sroa$056$0 = $20;
 $82 = $$sroa$056$0;
 return ($82|0);
}
function __ZNK9osgViewer10ViewConfig23getActiveDisplaySettingERNS_4ViewE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 116|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $7 = $3;
  return ($7|0);
 }
 $5 = (__ZN3osg15DisplaySettings8instanceEv()|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $6;
 return ($7|0);
}
function __ZN9osgViewer4View19StereoSlaveCallback11updateSlaveERN3osg4ViewERNS3_5SlaveE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$045 = 0.0, $$046 = 0, $$sink = 0.0, $$sink49 = 0.0, $$sink50 = 0.0, $10 = 0, $100 = 0, $101 = 0.0, $102 = 0, $103 = 0, $104 = 0.0, $105 = 0, $106 = 0, $107 = 0.0, $108 = 0, $109 = 0, $11 = 0, $110 = 0.0, $111 = 0;
 var $112 = 0, $113 = 0.0, $114 = 0, $115 = 0, $116 = 0.0, $117 = 0, $118 = 0, $119 = 0.0, $12 = 0, $120 = 0, $121 = 0, $122 = 0.0, $123 = 0, $124 = 0, $125 = 0.0, $126 = 0, $127 = 0, $128 = 0.0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0.0, $132 = 0, $133 = 0, $134 = 0.0, $135 = 0, $136 = 0, $137 = 0.0, $138 = 0, $139 = 0.0, $14 = 0, $140 = 0, $141 = 0.0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0.0, $148 = 0.0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0.0, $153 = 0.0, $154 = 0, $155 = 0.0, $156 = 0.0, $157 = 0.0, $158 = 0.0, $159 = 0, $16 = 0, $160 = 0.0, $161 = 0.0, $162 = 0.0, $163 = 0.0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0.0, $17 = 0, $170 = 0, $171 = 0, $172 = 0.0, $173 = 0, $174 = 0, $175 = 0.0, $176 = 0, $177 = 0, $178 = 0.0, $179 = 0, $18 = 0, $180 = 0, $181 = 0.0, $182 = 0, $183 = 0, $184 = 0.0;
 var $185 = 0, $186 = 0, $187 = 0.0, $188 = 0, $189 = 0, $19 = 0, $190 = 0.0, $191 = 0, $192 = 0, $193 = 0.0, $194 = 0, $195 = 0, $196 = 0.0, $197 = 0, $198 = 0, $199 = 0.0, $20 = 0, $200 = 0, $201 = 0, $202 = 0.0;
 var $203 = 0, $204 = 0, $205 = 0.0, $206 = 0, $207 = 0, $208 = 0.0, $209 = 0, $21 = 0, $210 = 0, $211 = 0.0, $212 = 0, $213 = 0, $214 = 0.0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0;
 var $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0.0, $226 = 0, $227 = 0, $228 = 0.0, $229 = 0, $23 = 0, $230 = 0, $231 = 0.0, $232 = 0, $233 = 0, $234 = 0.0, $235 = 0, $236 = 0, $237 = 0.0, $238 = 0, $239 = 0;
 var $24 = 0.0, $240 = 0.0, $241 = 0, $242 = 0, $243 = 0.0, $244 = 0, $245 = 0, $246 = 0.0, $247 = 0, $248 = 0, $249 = 0.0, $25 = 0, $250 = 0, $251 = 0, $252 = 0.0, $253 = 0, $254 = 0, $255 = 0.0, $256 = 0, $257 = 0;
 var $258 = 0.0, $259 = 0, $26 = 0, $260 = 0, $261 = 0.0, $262 = 0, $263 = 0, $264 = 0.0, $265 = 0, $266 = 0, $267 = 0.0, $268 = 0, $269 = 0, $27 = 0, $270 = 0.0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0;
 var $276 = 0, $277 = 0, $278 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0.0, $49 = 0, $5 = 0, $50 = 0, $51 = 0.0, $52 = 0, $53 = 0, $54 = 0.0, $55 = 0, $56 = 0, $57 = 0.0, $58 = 0, $59 = 0, $6 = 0, $60 = 0.0;
 var $61 = 0, $62 = 0, $63 = 0.0, $64 = 0, $65 = 0, $66 = 0.0, $67 = 0, $68 = 0, $69 = 0.0, $7 = 0, $70 = 0, $71 = 0, $72 = 0.0, $73 = 0, $74 = 0, $75 = 0.0, $76 = 0, $77 = 0, $78 = 0.0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0.0, $82 = 0, $83 = 0, $84 = 0.0, $85 = 0, $86 = 0, $87 = 0.0, $88 = 0, $89 = 0.0, $9 = 0, $90 = 0, $91 = 0.0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0.0, $99 = 0, $or$cond = 0, $or$cond3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 512|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(512|0);
 $3 = sp + 384|0;
 $4 = sp + 256|0;
 $5 = sp + 128|0;
 $6 = sp;
 $7 = ((($2)) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (___dynamic_cast($1,27072,3928,0)|0);
 $10 = ((($0)) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)!=(0|0);
 $13 = ($8|0)!=(0|0);
 $or$cond = $13 & $12;
 $14 = ($9|0)!=(0|0);
 $or$cond3 = $14 & $or$cond;
 if (!($or$cond3)) {
  $276 = HEAP32[$2>>2]|0;
  $277 = ((($276)) + 8|0);
  $278 = HEAP32[$277>>2]|0;
  FUNCTION_TABLE_vii[$278 & 8191]($2,$1);
  STACKTOP = sp;return;
 }
 $15 = HEAP32[$8>>2]|0;
 $16 = ((($15)) + 272|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ((($1)) + 16|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ((($19)) + 144|0);
 $21 = ((($8)) + 148|0);
 $22 = HEAP32[$21>>2]|0;
 FUNCTION_TABLE_viii[$17 & 8191]($8,$20,$22);
 $23 = ((($0)) + 8|0);
 $24 = +HEAPF64[$23>>3];
 $25 = $24 < 0.0;
 if ($25) {
  $26 = ((($8)) + 200|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = ((($8)) + 196|0);
  HEAP32[$28>>2] = $27;
  $29 = ((($8)) + 152|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = ($30|0)==(0);
  if ($31) {
   $32 = HEAP32[$21>>2]|0;
   $33 = $32 & -1025;
   HEAP32[$21>>2] = $33;
  }
  $42 = HEAP32[$10>>2]|0;
  $43 = HEAP32[$42>>2]|0;
  $44 = ((($43)) + 12|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = HEAP32[$18>>2]|0;
  $47 = ((($46)) + 304|0);
  FUNCTION_TABLE_viii[$45 & 8191]($3,$42,$47);
  $48 = +HEAPF64[$3>>3];
  $49 = ((($8)) + 304|0);
  HEAPF64[$49>>3] = $48;
  $50 = ((($3)) + 8|0);
  $51 = +HEAPF64[$50>>3];
  $52 = ((($8)) + 312|0);
  HEAPF64[$52>>3] = $51;
  $53 = ((($3)) + 16|0);
  $54 = +HEAPF64[$53>>3];
  $55 = ((($8)) + 320|0);
  HEAPF64[$55>>3] = $54;
  $56 = ((($3)) + 24|0);
  $57 = +HEAPF64[$56>>3];
  $58 = ((($8)) + 328|0);
  HEAPF64[$58>>3] = $57;
  $59 = ((($3)) + 32|0);
  $60 = +HEAPF64[$59>>3];
  $61 = ((($8)) + 336|0);
  HEAPF64[$61>>3] = $60;
  $62 = ((($3)) + 40|0);
  $63 = +HEAPF64[$62>>3];
  $64 = ((($8)) + 344|0);
  HEAPF64[$64>>3] = $63;
  $65 = ((($3)) + 48|0);
  $66 = +HEAPF64[$65>>3];
  $67 = ((($8)) + 352|0);
  HEAPF64[$67>>3] = $66;
  $68 = ((($3)) + 56|0);
  $69 = +HEAPF64[$68>>3];
  $70 = ((($8)) + 360|0);
  HEAPF64[$70>>3] = $69;
  $71 = ((($3)) + 64|0);
  $72 = +HEAPF64[$71>>3];
  $73 = ((($8)) + 368|0);
  HEAPF64[$73>>3] = $72;
  $74 = ((($3)) + 72|0);
  $75 = +HEAPF64[$74>>3];
  $76 = ((($8)) + 376|0);
  HEAPF64[$76>>3] = $75;
  $77 = ((($3)) + 80|0);
  $78 = +HEAPF64[$77>>3];
  $79 = ((($8)) + 384|0);
  HEAPF64[$79>>3] = $78;
  $80 = ((($3)) + 88|0);
  $81 = +HEAPF64[$80>>3];
  $82 = ((($8)) + 392|0);
  HEAPF64[$82>>3] = $81;
  $83 = ((($3)) + 96|0);
  $84 = +HEAPF64[$83>>3];
  $85 = ((($8)) + 400|0);
  HEAPF64[$85>>3] = $84;
  $86 = ((($3)) + 104|0);
  $87 = +HEAPF64[$86>>3];
  $88 = ((($3)) + 112|0);
  $89 = +HEAPF64[$88>>3];
  $90 = ((($3)) + 120|0);
  $91 = +HEAPF64[$90>>3];
  $$sink = $91;$$sink49 = $89;$$sink50 = $87;
 } else {
  $34 = ((($8)) + 204|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = ((($8)) + 196|0);
  HEAP32[$36>>2] = $35;
  $37 = ((($8)) + 152|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = ($38|0)==(0);
  if ($39) {
   $40 = HEAP32[$21>>2]|0;
   $41 = $40 & -1025;
   HEAP32[$21>>2] = $41;
  }
  $92 = HEAP32[$10>>2]|0;
  $93 = HEAP32[$92>>2]|0;
  $94 = ((($93)) + 20|0);
  $95 = HEAP32[$94>>2]|0;
  $96 = HEAP32[$18>>2]|0;
  $97 = ((($96)) + 304|0);
  FUNCTION_TABLE_viii[$95 & 8191]($4,$92,$97);
  $98 = +HEAPF64[$4>>3];
  $99 = ((($8)) + 304|0);
  HEAPF64[$99>>3] = $98;
  $100 = ((($4)) + 8|0);
  $101 = +HEAPF64[$100>>3];
  $102 = ((($8)) + 312|0);
  HEAPF64[$102>>3] = $101;
  $103 = ((($4)) + 16|0);
  $104 = +HEAPF64[$103>>3];
  $105 = ((($8)) + 320|0);
  HEAPF64[$105>>3] = $104;
  $106 = ((($4)) + 24|0);
  $107 = +HEAPF64[$106>>3];
  $108 = ((($8)) + 328|0);
  HEAPF64[$108>>3] = $107;
  $109 = ((($4)) + 32|0);
  $110 = +HEAPF64[$109>>3];
  $111 = ((($8)) + 336|0);
  HEAPF64[$111>>3] = $110;
  $112 = ((($4)) + 40|0);
  $113 = +HEAPF64[$112>>3];
  $114 = ((($8)) + 344|0);
  HEAPF64[$114>>3] = $113;
  $115 = ((($4)) + 48|0);
  $116 = +HEAPF64[$115>>3];
  $117 = ((($8)) + 352|0);
  HEAPF64[$117>>3] = $116;
  $118 = ((($4)) + 56|0);
  $119 = +HEAPF64[$118>>3];
  $120 = ((($8)) + 360|0);
  HEAPF64[$120>>3] = $119;
  $121 = ((($4)) + 64|0);
  $122 = +HEAPF64[$121>>3];
  $123 = ((($8)) + 368|0);
  HEAPF64[$123>>3] = $122;
  $124 = ((($4)) + 72|0);
  $125 = +HEAPF64[$124>>3];
  $126 = ((($8)) + 376|0);
  HEAPF64[$126>>3] = $125;
  $127 = ((($4)) + 80|0);
  $128 = +HEAPF64[$127>>3];
  $129 = ((($8)) + 384|0);
  HEAPF64[$129>>3] = $128;
  $130 = ((($4)) + 88|0);
  $131 = +HEAPF64[$130>>3];
  $132 = ((($8)) + 392|0);
  HEAPF64[$132>>3] = $131;
  $133 = ((($4)) + 96|0);
  $134 = +HEAPF64[$133>>3];
  $135 = ((($8)) + 400|0);
  HEAPF64[$135>>3] = $134;
  $136 = ((($4)) + 104|0);
  $137 = +HEAPF64[$136>>3];
  $138 = ((($4)) + 112|0);
  $139 = +HEAPF64[$138>>3];
  $140 = ((($4)) + 120|0);
  $141 = +HEAPF64[$140>>3];
  $$sink = $141;$$sink49 = $139;$$sink50 = $137;
 }
 $142 = ((($8)) + 408|0);
 HEAPF64[$142>>3] = $$sink50;
 $143 = ((($8)) + 416|0);
 HEAPF64[$143>>3] = $$sink49;
 $144 = ((($8)) + 424|0);
 HEAPF64[$144>>3] = $$sink;
 $145 = HEAP32[$10>>2]|0;
 $146 = ((($145)) + 36|0);
 $147 = +HEAPF32[$146>>2];
 $148 = $147;
 $149 = ((($9)) + 120|0);
 $150 = HEAP32[$149>>2]|0;
 switch ($150|0) {
 case 0:  {
  $151 = ((($9)) + 124|0);
  $152 = +HEAPF32[$151>>2];
  $153 = $152;
  $$045 = $153;
  break;
 }
 case 1:  {
  $154 = ((($9)) + 124|0);
  $155 = +HEAPF32[$154>>2];
  $156 = $155;
  $157 = $148 * $156;
  $$045 = $157;
  break;
 }
 default: {
  $$045 = $148;
 }
 }
 $158 = +HEAPF64[$23>>3];
 $159 = $158 < 0.0;
 $160 = -$158;
 $161 = $159 ? $160 : $158;
 $162 = $$045 / $148;
 $163 = $162 * $161;
 if ($159) {
  $164 = HEAP32[$145>>2]|0;
  $165 = ((($164)) + 16|0);
  $166 = HEAP32[$165>>2]|0;
  $167 = HEAP32[$18>>2]|0;
  $168 = ((($167)) + 432|0);
  FUNCTION_TABLE_viiid[$166 & 2047]($5,$145,$168,$163);
  $169 = +HEAPF64[$5>>3];
  $170 = ((($8)) + 432|0);
  HEAPF64[$170>>3] = $169;
  $171 = ((($5)) + 8|0);
  $172 = +HEAPF64[$171>>3];
  $173 = ((($8)) + 440|0);
  HEAPF64[$173>>3] = $172;
  $174 = ((($5)) + 16|0);
  $175 = +HEAPF64[$174>>3];
  $176 = ((($8)) + 448|0);
  HEAPF64[$176>>3] = $175;
  $177 = ((($5)) + 24|0);
  $178 = +HEAPF64[$177>>3];
  $179 = ((($8)) + 456|0);
  HEAPF64[$179>>3] = $178;
  $180 = ((($5)) + 32|0);
  $181 = +HEAPF64[$180>>3];
  $182 = ((($8)) + 464|0);
  HEAPF64[$182>>3] = $181;
  $183 = ((($5)) + 40|0);
  $184 = +HEAPF64[$183>>3];
  $185 = ((($8)) + 472|0);
  HEAPF64[$185>>3] = $184;
  $186 = ((($5)) + 48|0);
  $187 = +HEAPF64[$186>>3];
  $188 = ((($8)) + 480|0);
  HEAPF64[$188>>3] = $187;
  $189 = ((($5)) + 56|0);
  $190 = +HEAPF64[$189>>3];
  $191 = ((($8)) + 488|0);
  HEAPF64[$191>>3] = $190;
  $192 = ((($5)) + 64|0);
  $193 = +HEAPF64[$192>>3];
  $194 = ((($8)) + 496|0);
  HEAPF64[$194>>3] = $193;
  $195 = ((($5)) + 72|0);
  $196 = +HEAPF64[$195>>3];
  $197 = ((($8)) + 504|0);
  HEAPF64[$197>>3] = $196;
  $198 = ((($5)) + 80|0);
  $199 = +HEAPF64[$198>>3];
  $200 = ((($8)) + 512|0);
  HEAPF64[$200>>3] = $199;
  $201 = ((($5)) + 88|0);
  $202 = +HEAPF64[$201>>3];
  $203 = ((($8)) + 520|0);
  HEAPF64[$203>>3] = $202;
  $204 = ((($5)) + 96|0);
  $205 = +HEAPF64[$204>>3];
  $206 = ((($8)) + 528|0);
  HEAPF64[$206>>3] = $205;
  $207 = ((($5)) + 104|0);
  $208 = +HEAPF64[$207>>3];
  $209 = ((($8)) + 536|0);
  HEAPF64[$209>>3] = $208;
  $210 = ((($5)) + 112|0);
  $211 = +HEAPF64[$210>>3];
  $212 = ((($8)) + 544|0);
  HEAPF64[$212>>3] = $211;
  $213 = ((($5)) + 120|0);
  $214 = +HEAPF64[$213>>3];
  $215 = ((($8)) + 552|0);
  HEAPF64[$215>>3] = $214;
  __THREW__ = 0;
  invoke_vi(3323,($8|0));
  $216 = __THREW__; __THREW__ = 0;
  $217 = $216&1;
  if ($217) {
   $218 = ___cxa_find_matching_catch_2()|0;
   $219 = tempRet0;
   $$0 = $218;$$046 = $219;
   ___resumeException($$0|0);
   // unreachable;
  } else {
   STACKTOP = sp;return;
  }
 } else {
  $220 = HEAP32[$145>>2]|0;
  $221 = ((($220)) + 24|0);
  $222 = HEAP32[$221>>2]|0;
  $223 = HEAP32[$18>>2]|0;
  $224 = ((($223)) + 432|0);
  FUNCTION_TABLE_viiid[$222 & 2047]($6,$145,$224,$163);
  $225 = +HEAPF64[$6>>3];
  $226 = ((($8)) + 432|0);
  HEAPF64[$226>>3] = $225;
  $227 = ((($6)) + 8|0);
  $228 = +HEAPF64[$227>>3];
  $229 = ((($8)) + 440|0);
  HEAPF64[$229>>3] = $228;
  $230 = ((($6)) + 16|0);
  $231 = +HEAPF64[$230>>3];
  $232 = ((($8)) + 448|0);
  HEAPF64[$232>>3] = $231;
  $233 = ((($6)) + 24|0);
  $234 = +HEAPF64[$233>>3];
  $235 = ((($8)) + 456|0);
  HEAPF64[$235>>3] = $234;
  $236 = ((($6)) + 32|0);
  $237 = +HEAPF64[$236>>3];
  $238 = ((($8)) + 464|0);
  HEAPF64[$238>>3] = $237;
  $239 = ((($6)) + 40|0);
  $240 = +HEAPF64[$239>>3];
  $241 = ((($8)) + 472|0);
  HEAPF64[$241>>3] = $240;
  $242 = ((($6)) + 48|0);
  $243 = +HEAPF64[$242>>3];
  $244 = ((($8)) + 480|0);
  HEAPF64[$244>>3] = $243;
  $245 = ((($6)) + 56|0);
  $246 = +HEAPF64[$245>>3];
  $247 = ((($8)) + 488|0);
  HEAPF64[$247>>3] = $246;
  $248 = ((($6)) + 64|0);
  $249 = +HEAPF64[$248>>3];
  $250 = ((($8)) + 496|0);
  HEAPF64[$250>>3] = $249;
  $251 = ((($6)) + 72|0);
  $252 = +HEAPF64[$251>>3];
  $253 = ((($8)) + 504|0);
  HEAPF64[$253>>3] = $252;
  $254 = ((($6)) + 80|0);
  $255 = +HEAPF64[$254>>3];
  $256 = ((($8)) + 512|0);
  HEAPF64[$256>>3] = $255;
  $257 = ((($6)) + 88|0);
  $258 = +HEAPF64[$257>>3];
  $259 = ((($8)) + 520|0);
  HEAPF64[$259>>3] = $258;
  $260 = ((($6)) + 96|0);
  $261 = +HEAPF64[$260>>3];
  $262 = ((($8)) + 528|0);
  HEAPF64[$262>>3] = $261;
  $263 = ((($6)) + 104|0);
  $264 = +HEAPF64[$263>>3];
  $265 = ((($8)) + 536|0);
  HEAPF64[$265>>3] = $264;
  $266 = ((($6)) + 112|0);
  $267 = +HEAPF64[$266>>3];
  $268 = ((($8)) + 544|0);
  HEAPF64[$268>>3] = $267;
  $269 = ((($6)) + 120|0);
  $270 = +HEAPF64[$269>>3];
  $271 = ((($8)) + 552|0);
  HEAPF64[$271>>3] = $270;
  __THREW__ = 0;
  invoke_vi(3323,($8|0));
  $272 = __THREW__; __THREW__ = 0;
  $273 = $272&1;
  if ($273) {
   $274 = ___cxa_find_matching_catch_2()|0;
   $275 = tempRet0;
   $$0 = $274;$$046 = $275;
   ___resumeException($$0|0);
   // unreachable;
  } else {
   STACKTOP = sp;return;
  }
 }
}
function __ZN9osgViewer4View19StereoSlaveCallbackD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = ((36024));
 $1 = ((($0)) + 16|0);
 HEAP32[$1>>2] = ((36052));
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  HEAP32[$2>>2] = 0;
  __ZN3osg10ReferencedD2Ev($1);
  return;
 }
 $5 = ((($3)) + 8|0);
 $6 = HEAP32[$5>>2]|0;HEAP32[$5>>2] = (($6-1)|0);
 $7 = ($6|0)==(1);
 if (!($7)) {
  HEAP32[$2>>2] = 0;
  __ZN3osg10ReferencedD2Ev($1);
  return;
 }
 __THREW__ = 0;
 invoke_viii(3262,($3|0),1,1);
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if (!($9)) {
  HEAP32[$2>>2] = 0;
  __ZN3osg10ReferencedD2Ev($1);
  return;
 }
 $10 = ___cxa_find_matching_catch_2()|0;
 $11 = tempRet0;
 __THREW__ = 0;
 invoke_vi(712,($1|0));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $14 = ___cxa_find_matching_catch_3(0|0)|0;
  $15 = tempRet0;
  ___clang_call_terminate($14);
  // unreachable;
 } else {
  ___resumeException($10|0);
  // unreachable;
 }
}
function __ZN9osgViewer4View19StereoSlaveCallbackD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0;
 var $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = ((36024));
 $1 = ((($0)) + 16|0);
 HEAP32[$1>>2] = ((36052));
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = ((($3)) + 8|0);
  $6 = HEAP32[$5>>2]|0;HEAP32[$5>>2] = (($6-1)|0);
  $7 = ($6|0)==(1);
  if ($7) {
   __THREW__ = 0;
   invoke_viii(3262,($3|0),1,1);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if ($9) {
    $12 = ___cxa_find_matching_catch_2()|0;
    $13 = tempRet0;
    __THREW__ = 0;
    invoke_vi(712,($1|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     $16 = ___cxa_find_matching_catch_3(0|0)|0;
     $17 = tempRet0;
     ___clang_call_terminate($16);
     // unreachable;
    } else {
     $eh$lpad$body$index2Z2D = $13;$eh$lpad$body$indexZ2D = $12;
     __ZdlPv($0);
     ___resumeException($eh$lpad$body$indexZ2D|0);
     // unreachable;
    }
   }
  }
 }
 HEAP32[$2>>2] = 0;
 __THREW__ = 0;
 invoke_vi(712,($1|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if (!($11)) {
  __ZdlPv($0);
  return;
 }
 $18 = ___cxa_find_matching_catch_2()|0;
 $19 = tempRet0;
 $eh$lpad$body$index2Z2D = $19;$eh$lpad$body$indexZ2D = $18;
 __ZdlPv($0);
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
}
function __ZTv0_n16_N9osgViewer4View19StereoSlaveCallbackD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 HEAP32[$4>>2] = ((36024));
 $5 = ((($4)) + 16|0);
 HEAP32[$5>>2] = ((36052));
 $6 = ((($4)) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if ($8) {
  HEAP32[$6>>2] = 0;
  __ZN3osg10ReferencedD2Ev($5);
  return;
 }
 $9 = ((($7)) + 8|0);
 $10 = HEAP32[$9>>2]|0;HEAP32[$9>>2] = (($10-1)|0);
 $11 = ($10|0)==(1);
 if (!($11)) {
  HEAP32[$6>>2] = 0;
  __ZN3osg10ReferencedD2Ev($5);
  return;
 }
 __THREW__ = 0;
 invoke_viii(3262,($7|0),1,1);
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if (!($13)) {
  HEAP32[$6>>2] = 0;
  __ZN3osg10ReferencedD2Ev($5);
  return;
 }
 $14 = ___cxa_find_matching_catch_2()|0;
 $15 = tempRet0;
 __THREW__ = 0;
 invoke_vi(712,($5|0));
 $16 = __THREW__; __THREW__ = 0;
 $17 = $16&1;
 if ($17) {
  $18 = ___cxa_find_matching_catch_3(0|0)|0;
  $19 = tempRet0;
  ___clang_call_terminate($18);
  // unreachable;
 } else {
  ___resumeException($14|0);
  // unreachable;
 }
}
function __ZTv0_n16_N9osgViewer4View19StereoSlaveCallbackD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$i$index2Z2D = 0, $eh$lpad$body$i$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 HEAP32[$4>>2] = ((36024));
 $5 = ((($4)) + 16|0);
 HEAP32[$5>>2] = ((36052));
 $6 = ((($4)) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = ((($7)) + 8|0);
  $10 = HEAP32[$9>>2]|0;HEAP32[$9>>2] = (($10-1)|0);
  $11 = ($10|0)==(1);
  if ($11) {
   __THREW__ = 0;
   invoke_viii(3262,($7|0),1,1);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if ($13) {
    $16 = ___cxa_find_matching_catch_2()|0;
    $17 = tempRet0;
    __THREW__ = 0;
    invoke_vi(712,($5|0));
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     $20 = ___cxa_find_matching_catch_3(0|0)|0;
     $21 = tempRet0;
     ___clang_call_terminate($20);
     // unreachable;
    } else {
     $eh$lpad$body$i$index2Z2D = $17;$eh$lpad$body$i$indexZ2D = $16;
     __ZdlPv($4);
     ___resumeException($eh$lpad$body$i$indexZ2D|0);
     // unreachable;
    }
   }
  }
 }
 HEAP32[$6>>2] = 0;
 __THREW__ = 0;
 invoke_vi(712,($5|0));
 $14 = __THREW__; __THREW__ = 0;
 $15 = $14&1;
 if (!($15)) {
  __ZdlPv($4);
  return;
 }
 $22 = ___cxa_find_matching_catch_2()|0;
 $23 = tempRet0;
 $eh$lpad$body$i$index2Z2D = $23;$eh$lpad$body$i$indexZ2D = $22;
 __ZdlPv($4);
 ___resumeException($eh$lpad$body$i$indexZ2D|0);
 // unreachable;
}
function __ZN9osgViewer4ViewC2Ev($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$023$i$i = 0, $$15 = 0, $$17 = 0, $$2 = 0, $$28 = 0, $$cast = 0, $$pre$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0;
 var $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0;
 var $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0;
 var $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0;
 var $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0;
 var $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = ((($1)) + 4|0);
 __ZN3osg4ViewC2Ev($0,$3);
 $4 = ((($0)) + 36|0);
 HEAP32[$4>>2] = (36072);
 $5 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $5;
 $6 = ((($1)) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $$cast = $5;
 $8 = ((($$cast)) + -12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($0) + ($9)|0);
 HEAP32[$10>>2] = $7;
 HEAP32[$4>>2] = (35168);
 $11 = ((($0)) + 40|0);
 HEAP32[$11>>2] = 0;
 $12 = ((($0)) + 44|0);
 HEAP32[$12>>2] = 0;
 $13 = ((($0)) + 56|0);
 $14 = ((($0)) + 60|0);
 $15 = ((($0)) + 68|0);
 $16 = ((($0)) + 72|0);
 $17 = ((($0)) + 76|0);
 $18 = ((($0)) + 80|0);
 ;HEAP32[$13>>2]=0|0;HEAP32[$13+4>>2]=0|0;HEAP32[$13+8>>2]=0|0;HEAP32[$13+12>>2]=0|0;HEAP32[$13+16>>2]=0|0;HEAP32[$13+20>>2]=0|0;
 HEAP32[$18>>2] = $18;
 $19 = ((($0)) + 84|0);
 HEAP32[$19>>2] = $18;
 $20 = ((($0)) + 88|0);
 HEAP32[$20>>2] = 0;
 $21 = ((($0)) + 92|0);
 __THREW__ = 0;
 invoke_vi(3291,($21|0));
 $22 = __THREW__; __THREW__ = 0;
 $23 = $22&1;
 if ($23) {
  $138 = ___cxa_find_matching_catch_2()|0;
  $139 = tempRet0;
  $$2 = $139;$$28 = $138;
 } else {
  $24 = ((($0)) + 116|0);
  HEAP32[$24>>2] = 0;
  $25 = ((($0)) + 120|0);
  HEAP32[$25>>2] = 1;
  $26 = ((($0)) + 124|0);
  HEAPF32[$26>>2] = 1.0;
  $27 = ((($0)) + 128|0);
  HEAP32[$27>>2] = 0;
  $28 = ((($0)) + 48|0);
  $29 = $28;
  $30 = $29;
  HEAP32[$30>>2] = 0;
  $31 = (($29) + 4)|0;
  $32 = $31;
  HEAP32[$32>>2] = 0;
  __THREW__ = 0;
  $33 = (invoke_ii(3276,72)|0);
  $34 = __THREW__; __THREW__ = 0;
  $35 = $34&1;
  do {
   if ($35) {
    label = 38;
   } else {
    __THREW__ = 0;
    invoke_vi(3298,($33|0));
    $36 = __THREW__; __THREW__ = 0;
    $37 = $36&1;
    if ($37) {
     $142 = ___cxa_find_matching_catch_2()|0;
     $143 = tempRet0;
     __ZdlPv($33);
     $$15 = $143;$$17 = $142;
     break;
    }
    $38 = ((($0)) + 32|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = ($39|0)==($33|0);
    if (!($40)) {
     HEAP32[$38>>2] = $33;
     $41 = ((($33)) + 8|0);
     $42 = HEAP32[$41>>2]|0;HEAP32[$41>>2] = (($42+1)|0);
     $43 = ($39|0)==(0|0);
     if (!($43)) {
      $44 = ((($39)) + 8|0);
      $45 = HEAP32[$44>>2]|0;HEAP32[$44>>2] = (($45-1)|0);
      $46 = ($45|0)==(1);
      if ($46) {
       __THREW__ = 0;
       invoke_viii(3262,($39|0),1,1);
       $47 = __THREW__; __THREW__ = 0;
       $48 = $47&1;
       if ($48) {
        label = 38;
        break;
       }
      }
     }
    }
    $49 = HEAP32[$38>>2]|0;
    $50 = ((($49)) + 12|0);
    ;HEAP32[$50>>2]=0|0;HEAP32[$50+4>>2]=0|0;HEAP32[$50+8>>2]=0|0;HEAP32[$50+12>>2]=0|0;HEAP32[$50+16>>2]=0|0;
    __THREW__ = 0;
    $51 = (invoke_ii(3276,24)|0);
    $52 = __THREW__; __THREW__ = 0;
    $53 = $52&1;
    if ($53) {
     label = 38;
    } else {
     __THREW__ = 0;
     invoke_vi(3277,($51|0));
     $54 = __THREW__; __THREW__ = 0;
     $55 = $54&1;
     if ($55) {
      $144 = ___cxa_find_matching_catch_2()|0;
      $145 = tempRet0;
      __ZdlPv($51);
      $$15 = $145;$$17 = $144;
      break;
     }
     $56 = HEAP32[$15>>2]|0;
     $57 = ($56|0)==($51|0);
     if (!($57)) {
      HEAP32[$15>>2] = $51;
      $58 = ((($51)) + 8|0);
      $59 = HEAP32[$58>>2]|0;HEAP32[$58>>2] = (($59+1)|0);
      $60 = ($56|0)==(0|0);
      if (!($60)) {
       $61 = ((($56)) + 8|0);
       $62 = HEAP32[$61>>2]|0;HEAP32[$61>>2] = (($62-1)|0);
       $63 = ($62|0)==(1);
       if ($63) {
        __THREW__ = 0;
        invoke_viii(3262,($56|0),1,1);
        $64 = __THREW__; __THREW__ = 0;
        $65 = $64&1;
        if ($65) {
         label = 38;
         break;
        }
       }
      }
     }
     $66 = HEAP32[$0>>2]|0;
     $67 = ((($66)) + -12|0);
     $68 = HEAP32[$67>>2]|0;
     $69 = (($0) + ($68)|0);
     $70 = HEAP32[$69>>2]|0;
     $71 = HEAP32[$70>>2]|0;
     __THREW__ = 0;
     invoke_vii($71|0,($69|0),1);
     $72 = __THREW__; __THREW__ = 0;
     $73 = $72&1;
     if ($73) {
      label = 38;
     } else {
      $74 = ((($0)) + 16|0);
      $75 = HEAP32[$74>>2]|0;
      $76 = HEAP32[$0>>2]|0;
      $77 = ((($76)) + 32|0);
      $78 = HEAP32[$77>>2]|0;
      __THREW__ = 0;
      $79 = (invoke_iii($78|0,($0|0),($75|0))|0);
      $80 = __THREW__; __THREW__ = 0;
      $81 = $80&1;
      if ($81) {
       label = 38;
      } else {
       $82 = ((($75)) + 628|0);
       $83 = HEAP32[$82>>2]|0;
       $84 = ($83|0)==($79|0);
       if (!($84)) {
        HEAP32[$82>>2] = $79;
        $85 = ($79|0)==(0|0);
        if (!($85)) {
         $86 = HEAP32[$79>>2]|0;
         $87 = ((($86)) + -12|0);
         $88 = HEAP32[$87>>2]|0;
         $89 = (($79) + ($88)|0);
         $90 = ((($89)) + 8|0);
         $91 = HEAP32[$90>>2]|0;HEAP32[$90>>2] = (($91+1)|0);
        }
        $92 = ($83|0)==(0|0);
        if (!($92)) {
         $93 = HEAP32[$83>>2]|0;
         $94 = ((($93)) + -12|0);
         $95 = HEAP32[$94>>2]|0;
         $96 = (($83) + ($95)|0);
         $97 = ((($96)) + 8|0);
         $98 = HEAP32[$97>>2]|0;HEAP32[$97>>2] = (($98-1)|0);
         $99 = ($98|0)==(1);
         if ($99) {
          __THREW__ = 0;
          invoke_viii(3262,($96|0),1,1);
          $100 = __THREW__; __THREW__ = 0;
          $101 = $100&1;
          if ($101) {
           label = 38;
           break;
          }
         }
        }
       }
       __THREW__ = 0;
       $102 = (invoke_ii(3276,64)|0);
       $103 = __THREW__; __THREW__ = 0;
       $104 = $103&1;
       if ($104) {
        label = 38;
       } else {
        __THREW__ = 0;
        invoke_vii(3292,($102|0),1);
        $105 = __THREW__; __THREW__ = 0;
        $106 = $105&1;
        if ($106) {
         $146 = ___cxa_find_matching_catch_2()|0;
         $147 = tempRet0;
         __ZdlPv($102);
         $$15 = $147;$$17 = $146;
         break;
        }
        $107 = HEAP32[$16>>2]|0;
        $108 = ($107|0)==($102|0);
        if (!($108)) {
         HEAP32[$16>>2] = $102;
         $109 = ((($102)) + 8|0);
         $110 = HEAP32[$109>>2]|0;HEAP32[$109>>2] = (($110+1)|0);
         $111 = ($107|0)==(0|0);
         if (!($111)) {
          $112 = ((($107)) + 8|0);
          $113 = HEAP32[$112>>2]|0;HEAP32[$112>>2] = (($113-1)|0);
          $114 = ($113|0)==(1);
          if ($114) {
           __THREW__ = 0;
           invoke_viii(3262,($107|0),1,1);
           $115 = __THREW__; __THREW__ = 0;
           $116 = $115&1;
           if ($116) {
            label = 38;
            break;
           }
          }
         }
        }
        __THREW__ = 0;
        $117 = (invoke_ii(3276,80)|0);
        $118 = __THREW__; __THREW__ = 0;
        $119 = $118&1;
        if ($119) {
         label = 38;
        } else {
         ;HEAP32[$2>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;
         $120 = ((($2)) + 11|0);
         HEAP8[$120>>0] = 4;
         HEAP32[$2>>2] = 2003134806;
         $121 = ((($2)) + 4|0);
         HEAP8[$121>>0] = 0;
         __THREW__ = 0;
         invoke_vii(3274,($117|0),($2|0));
         $122 = __THREW__; __THREW__ = 0;
         $123 = $122&1;
         L43: do {
          if ($123) {
           $$0 = 1;
          } else {
           $124 = ((($0)) + 4|0);
           $125 = HEAP32[$124>>2]|0;
           $126 = ($125|0)==($117|0);
           do {
            if (!($126)) {
             HEAP32[$124>>2] = $117;
             $127 = ((($117)) + 8|0);
             $128 = HEAP32[$127>>2]|0;HEAP32[$127>>2] = (($128+1)|0);
             $129 = ($125|0)==(0|0);
             if ($129) {
              break;
             }
             $130 = ((($125)) + 8|0);
             $131 = HEAP32[$130>>2]|0;HEAP32[$130>>2] = (($131-1)|0);
             $132 = ($131|0)==(1);
             if (!($132)) {
              break;
             }
             __THREW__ = 0;
             invoke_viii(3262,($125|0),1,1);
             $133 = __THREW__; __THREW__ = 0;
             $134 = $133&1;
             if ($134) {
              $$0 = 0;
              break L43;
             }
            }
           } while(0);
           $135 = HEAP8[$120>>0]|0;
           $136 = ($135<<24>>24)<(0);
           if (!($136)) {
            STACKTOP = sp;return;
           }
           $137 = HEAP32[$2>>2]|0;
           __ZdlPv($137);
           STACKTOP = sp;return;
          }
         } while(0);
         $148 = ___cxa_find_matching_catch_2()|0;
         $149 = tempRet0;
         $150 = HEAP8[$120>>0]|0;
         $151 = ($150<<24>>24)<(0);
         if ($151) {
          $152 = HEAP32[$2>>2]|0;
          __ZdlPv($152);
          if (!($$0)) {
           $$15 = $149;$$17 = $148;
           break;
          }
         } else {
          if (!($$0)) {
           $$15 = $149;$$17 = $148;
           break;
          }
         }
         __ZdlPv($117);
         $$15 = $149;$$17 = $148;
        }
       }
      }
     }
    }
   }
  } while(0);
  if ((label|0) == 38) {
   $140 = ___cxa_find_matching_catch_2()|0;
   $141 = tempRet0;
   $$15 = $141;$$17 = $140;
  }
  $153 = HEAP32[$27>>2]|0;
  $154 = ($153|0)==(0|0);
  if (!($154)) {
   $155 = ((($153)) + 8|0);
   $156 = HEAP32[$155>>2]|0;HEAP32[$155>>2] = (($156-1)|0);
   $157 = ($156|0)==(1);
   if ($157) {
    __THREW__ = 0;
    invoke_viii(3262,($153|0),1,1);
    $158 = __THREW__; __THREW__ = 0;
    $159 = $158&1;
    if ($159) {
     $248 = ___cxa_find_matching_catch_3(0|0)|0;
     $249 = tempRet0;
     ___clang_call_terminate($248);
     // unreachable;
    }
   }
  }
  HEAP32[$27>>2] = 0;
  $160 = HEAP32[$24>>2]|0;
  $161 = ($160|0)==(0|0);
  if (!($161)) {
   $162 = ((($160)) + 8|0);
   $163 = HEAP32[$162>>2]|0;HEAP32[$162>>2] = (($163-1)|0);
   $164 = ($163|0)==(1);
   if ($164) {
    __THREW__ = 0;
    invoke_viii(3262,($160|0),1,1);
    $165 = __THREW__; __THREW__ = 0;
    $166 = $165&1;
    if ($166) {
     $248 = ___cxa_find_matching_catch_3(0|0)|0;
     $249 = tempRet0;
     ___clang_call_terminate($248);
     // unreachable;
    }
   }
  }
  HEAP32[$24>>2] = 0;
  __THREW__ = 0;
  invoke_vi(3293,($21|0));
  $167 = __THREW__; __THREW__ = 0;
  $168 = $167&1;
  if ($168) {
   $248 = ___cxa_find_matching_catch_3(0|0)|0;
   $249 = tempRet0;
   ___clang_call_terminate($248);
   // unreachable;
  } else {
   $$2 = $$15;$$28 = $$17;
  }
 }
 $169 = HEAP32[$20>>2]|0;
 $170 = ($169|0)==(0);
 L74: do {
  if (!($170)) {
   $171 = HEAP32[$19>>2]|0;
   $172 = HEAP32[$18>>2]|0;
   $173 = ((($172)) + 4|0);
   $174 = HEAP32[$173>>2]|0;
   $175 = HEAP32[$171>>2]|0;
   $176 = ((($175)) + 4|0);
   HEAP32[$176>>2] = $174;
   $177 = HEAP32[$173>>2]|0;
   HEAP32[$177>>2] = $175;
   HEAP32[$20>>2] = 0;
   $178 = ($171|0)==($18|0);
   if (!($178)) {
    $$023$i$i = $171;
    while(1) {
     $179 = ((($$023$i$i)) + 4|0);
     $180 = HEAP32[$179>>2]|0;
     $181 = ((($$023$i$i)) + 8|0);
     $182 = HEAP32[$181>>2]|0;
     $183 = ($182|0)==(0|0);
     if (!($183)) {
      $184 = HEAP32[$182>>2]|0;
      $185 = ((($184)) + -16|0);
      $186 = HEAP32[$185>>2]|0;
      $187 = (($182) + ($186)|0);
      $188 = ((($187)) + 8|0);
      $189 = HEAP32[$188>>2]|0;HEAP32[$188>>2] = (($189-1)|0);
      $190 = ($189|0)==(1);
      if ($190) {
       __THREW__ = 0;
       invoke_viii(3262,($187|0),1,1);
       $191 = __THREW__; __THREW__ = 0;
       $192 = $191&1;
       if ($192) {
        break;
       }
      }
     }
     __ZdlPv($$023$i$i);
     $193 = ($180|0)==($18|0);
     if ($193) {
      break L74;
     } else {
      $$023$i$i = $180;
     }
    }
    $194 = ___cxa_find_matching_catch_2()|0;
    $195 = tempRet0;
    ___cxa_call_unexpected(($194|0));
    // unreachable;
   }
  }
 } while(0);
 $196 = HEAP32[$17>>2]|0;
 $197 = ($196|0)==(0|0);
 if (!($197)) {
  $198 = HEAP32[$196>>2]|0;
  $199 = ((($198)) + -16|0);
  $200 = HEAP32[$199>>2]|0;
  $201 = (($196) + ($200)|0);
  $202 = ((($201)) + 8|0);
  $203 = HEAP32[$202>>2]|0;HEAP32[$202>>2] = (($203-1)|0);
  $204 = ($203|0)==(1);
  if ($204) {
   __THREW__ = 0;
   invoke_viii(3262,($201|0),1,1);
   $205 = __THREW__; __THREW__ = 0;
   $206 = $205&1;
   if ($206) {
    $248 = ___cxa_find_matching_catch_3(0|0)|0;
    $249 = tempRet0;
    ___clang_call_terminate($248);
    // unreachable;
   }
  }
 }
 HEAP32[$17>>2] = 0;
 $207 = HEAP32[$16>>2]|0;
 $208 = ($207|0)==(0|0);
 if (!($208)) {
  $209 = ((($207)) + 8|0);
  $210 = HEAP32[$209>>2]|0;HEAP32[$209>>2] = (($210-1)|0);
  $211 = ($210|0)==(1);
  if ($211) {
   __THREW__ = 0;
   invoke_viii(3262,($207|0),1,1);
   $212 = __THREW__; __THREW__ = 0;
   $213 = $212&1;
   if ($213) {
    $248 = ___cxa_find_matching_catch_3(0|0)|0;
    $249 = tempRet0;
    ___clang_call_terminate($248);
    // unreachable;
   }
  }
 }
 HEAP32[$16>>2] = 0;
 $214 = HEAP32[$15>>2]|0;
 $215 = ($214|0)==(0|0);
 if (!($215)) {
  $216 = ((($214)) + 8|0);
  $217 = HEAP32[$216>>2]|0;HEAP32[$216>>2] = (($217-1)|0);
  $218 = ($217|0)==(1);
  if ($218) {
   __THREW__ = 0;
   invoke_viii(3262,($214|0),1,1);
   $219 = __THREW__; __THREW__ = 0;
   $220 = $219&1;
   if ($220) {
    $248 = ___cxa_find_matching_catch_3(0|0)|0;
    $249 = tempRet0;
    ___clang_call_terminate($248);
    // unreachable;
   }
  }
 }
 HEAP32[$15>>2] = 0;
 $221 = HEAP32[$13>>2]|0;
 $222 = ($221|0)==(0|0);
 if (!($222)) {
  $223 = HEAP32[$14>>2]|0;
  $224 = ($223|0)==($221|0);
  do {
   if ($224) {
    $238 = $221;
   } else {
    $226 = $223;
    while(1) {
     $225 = ((($226)) + -4|0);
     HEAP32[$14>>2] = $225;
     $227 = HEAP32[$225>>2]|0;
     $228 = ($227|0)==(0|0);
     if (!($228)) {
      $229 = ((($227)) + 8|0);
      $230 = HEAP32[$229>>2]|0;HEAP32[$229>>2] = (($230-1)|0);
      $231 = ($230|0)==(1);
      if ($231) {
       __THREW__ = 0;
       invoke_viii(3262,($227|0),1,1);
       $232 = __THREW__; __THREW__ = 0;
       $233 = $232&1;
       if ($233) {
        label = 75;
        break;
       }
      }
     }
     HEAP32[$225>>2] = 0;
     $234 = HEAP32[$14>>2]|0;
     $235 = ($234|0)==($221|0);
     if ($235) {
      label = 76;
      break;
     } else {
      $226 = $234;
     }
    }
    if ((label|0) == 75) {
     $236 = ___cxa_find_matching_catch_2()|0;
     $237 = tempRet0;
     ___cxa_call_unexpected(($236|0));
     // unreachable;
    }
    else if ((label|0) == 76) {
     $$pre$i = HEAP32[$13>>2]|0;
     $238 = $$pre$i;
     break;
    }
   }
  } while(0);
  __ZdlPv($238);
 }
 $239 = HEAP32[$11>>2]|0;
 $240 = ($239|0)==(0|0);
 if (!($240)) {
  $241 = ((($239)) + 8|0);
  $242 = HEAP32[$241>>2]|0;HEAP32[$241>>2] = (($242-1)|0);
  $243 = ($242|0)==(1);
  if ($243) {
   __THREW__ = 0;
   invoke_viii(3262,($239|0),1,1);
   $244 = __THREW__; __THREW__ = 0;
   $245 = $244&1;
   if ($245) {
    $248 = ___cxa_find_matching_catch_3(0|0)|0;
    $249 = tempRet0;
    ___clang_call_terminate($248);
    // unreachable;
   }
  }
 }
 HEAP32[$11>>2] = 0;
 __THREW__ = 0;
 invoke_vii(3294,($0|0),($3|0));
 $246 = __THREW__; __THREW__ = 0;
 $247 = $246&1;
 if ($247) {
  $248 = ___cxa_find_matching_catch_3(0|0)|0;
  $249 = tempRet0;
  ___clang_call_terminate($248);
  // unreachable;
 } else {
  ___resumeException($$28|0);
  // unreachable;
 }
}
function __ZN5osgGA16GUIActionAdapterD2Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN5osgGA16GUIActionAdapterD0Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($0);
 return;
}
function __ZN9osgViewer4ViewC2ERKS0_RKN3osg6CopyOpE($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $$023$i$i = 0, $$111 = 0, $$19 = 0, $$2 = 0, $$212 = 0, $$cast = 0, $$pre$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0;
 var $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0;
 var $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0;
 var $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0;
 var $22 = 0, $220 = 0, $221 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $4 = sp;
 $5 = ((($1)) + 4|0);
 __ZN3osg4ViewC2ERKS0_RKNS_6CopyOpE($0,$5,$2,$3);
 $6 = ((($0)) + 36|0);
 HEAP32[$6>>2] = (36072);
 $7 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $7;
 $8 = ((($1)) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $$cast = $7;
 $10 = ((($$cast)) + -12|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($0) + ($11)|0);
 HEAP32[$12>>2] = $9;
 HEAP32[$6>>2] = (35168);
 $13 = ((($0)) + 40|0);
 $14 = ((($0)) + 56|0);
 $15 = ((($0)) + 60|0);
 $16 = ((($0)) + 68|0);
 $17 = ((($0)) + 72|0);
 $18 = ((($0)) + 76|0);
 $19 = ((($0)) + 80|0);
 dest=$13; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAP32[$19>>2] = $19;
 $20 = ((($0)) + 84|0);
 HEAP32[$20>>2] = $19;
 $21 = ((($0)) + 88|0);
 HEAP32[$21>>2] = 0;
 $22 = ((($0)) + 92|0);
 __THREW__ = 0;
 invoke_vi(3291,($22|0));
 $23 = __THREW__; __THREW__ = 0;
 $24 = $23&1;
 if ($24) {
  $112 = ___cxa_find_matching_catch_2()|0;
  $113 = tempRet0;
  $$2 = $113;$$212 = $112;
 } else {
  $25 = ((($0)) + 116|0);
  HEAP32[$25>>2] = 0;
  $26 = ((($0)) + 120|0);
  $27 = ((($2)) + 120|0);
  $28 = HEAP32[$27>>2]|0;
  HEAP32[$26>>2] = $28;
  $29 = ((($0)) + 124|0);
  $30 = ((($2)) + 124|0);
  $31 = HEAP32[$30>>2]|0;
  HEAP32[$29>>2] = $31;
  $32 = ((($0)) + 128|0);
  HEAP32[$32>>2] = 0;
  __THREW__ = 0;
  $33 = (invoke_ii(3276,24)|0);
  $34 = __THREW__; __THREW__ = 0;
  $35 = $34&1;
  do {
   if ($35) {
    label = 31;
   } else {
    __THREW__ = 0;
    invoke_vi(3277,($33|0));
    $36 = __THREW__; __THREW__ = 0;
    $37 = $36&1;
    if ($37) {
     $116 = ___cxa_find_matching_catch_2()|0;
     $117 = tempRet0;
     __ZdlPv($33);
     $$111 = $116;$$19 = $117;
     break;
    }
    $38 = HEAP32[$16>>2]|0;
    $39 = ($38|0)==($33|0);
    if (!($39)) {
     HEAP32[$16>>2] = $33;
     $40 = ((($33)) + 8|0);
     $41 = HEAP32[$40>>2]|0;HEAP32[$40>>2] = (($41+1)|0);
     $42 = ($38|0)==(0|0);
     if (!($42)) {
      $43 = ((($38)) + 8|0);
      $44 = HEAP32[$43>>2]|0;HEAP32[$43>>2] = (($44-1)|0);
      $45 = ($44|0)==(1);
      if ($45) {
       __THREW__ = 0;
       invoke_viii(3262,($38|0),1,1);
       $46 = __THREW__; __THREW__ = 0;
       $47 = $46&1;
       if ($47) {
        label = 31;
        break;
       }
      }
     }
    }
    $48 = ((($0)) + 16|0);
    $49 = HEAP32[$48>>2]|0;
    $50 = HEAP32[$0>>2]|0;
    $51 = ((($50)) + 32|0);
    $52 = HEAP32[$51>>2]|0;
    __THREW__ = 0;
    $53 = (invoke_iii($52|0,($0|0),($49|0))|0);
    $54 = __THREW__; __THREW__ = 0;
    $55 = $54&1;
    if ($55) {
     label = 31;
    } else {
     $56 = ((($49)) + 628|0);
     $57 = HEAP32[$56>>2]|0;
     $58 = ($57|0)==($53|0);
     if (!($58)) {
      HEAP32[$56>>2] = $53;
      $59 = ($53|0)==(0|0);
      if (!($59)) {
       $60 = HEAP32[$53>>2]|0;
       $61 = ((($60)) + -12|0);
       $62 = HEAP32[$61>>2]|0;
       $63 = (($53) + ($62)|0);
       $64 = ((($63)) + 8|0);
       $65 = HEAP32[$64>>2]|0;HEAP32[$64>>2] = (($65+1)|0);
      }
      $66 = ($57|0)==(0|0);
      if (!($66)) {
       $67 = HEAP32[$57>>2]|0;
       $68 = ((($67)) + -12|0);
       $69 = HEAP32[$68>>2]|0;
       $70 = (($57) + ($69)|0);
       $71 = ((($70)) + 8|0);
       $72 = HEAP32[$71>>2]|0;HEAP32[$71>>2] = (($72-1)|0);
       $73 = ($72|0)==(1);
       if ($73) {
        __THREW__ = 0;
        invoke_viii(3262,($70|0),1,1);
        $74 = __THREW__; __THREW__ = 0;
        $75 = $74&1;
        if ($75) {
         label = 31;
         break;
        }
       }
      }
     }
     __THREW__ = 0;
     $76 = (invoke_ii(3276,64)|0);
     $77 = __THREW__; __THREW__ = 0;
     $78 = $77&1;
     if ($78) {
      label = 31;
     } else {
      __THREW__ = 0;
      invoke_vii(3292,($76|0),1);
      $79 = __THREW__; __THREW__ = 0;
      $80 = $79&1;
      if ($80) {
       $118 = ___cxa_find_matching_catch_2()|0;
       $119 = tempRet0;
       __ZdlPv($76);
       $$111 = $118;$$19 = $119;
       break;
      }
      $81 = HEAP32[$17>>2]|0;
      $82 = ($81|0)==($76|0);
      if (!($82)) {
       HEAP32[$17>>2] = $76;
       $83 = ((($76)) + 8|0);
       $84 = HEAP32[$83>>2]|0;HEAP32[$83>>2] = (($84+1)|0);
       $85 = ($81|0)==(0|0);
       if (!($85)) {
        $86 = ((($81)) + 8|0);
        $87 = HEAP32[$86>>2]|0;HEAP32[$86>>2] = (($87-1)|0);
        $88 = ($87|0)==(1);
        if ($88) {
         __THREW__ = 0;
         invoke_viii(3262,($81|0),1,1);
         $89 = __THREW__; __THREW__ = 0;
         $90 = $89&1;
         if ($90) {
          label = 31;
          break;
         }
        }
       }
      }
      __THREW__ = 0;
      $91 = (invoke_ii(3276,80)|0);
      $92 = __THREW__; __THREW__ = 0;
      $93 = $92&1;
      if ($93) {
       label = 31;
      } else {
       ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;
       $94 = ((($4)) + 11|0);
       HEAP8[$94>>0] = 4;
       HEAP32[$4>>2] = 2003134806;
       $95 = ((($4)) + 4|0);
       HEAP8[$95>>0] = 0;
       __THREW__ = 0;
       invoke_vii(3274,($91|0),($4|0));
       $96 = __THREW__; __THREW__ = 0;
       $97 = $96&1;
       do {
        if ($97) {
         $$0 = 1;
        } else {
         $98 = ((($0)) + 4|0);
         $99 = HEAP32[$98>>2]|0;
         $100 = ($99|0)==($91|0);
         if (!($100)) {
          HEAP32[$98>>2] = $91;
          $101 = ((($91)) + 8|0);
          $102 = HEAP32[$101>>2]|0;HEAP32[$101>>2] = (($102+1)|0);
          $103 = ($99|0)==(0|0);
          if (!($103)) {
           $104 = ((($99)) + 8|0);
           $105 = HEAP32[$104>>2]|0;HEAP32[$104>>2] = (($105-1)|0);
           $106 = ($105|0)==(1);
           if ($106) {
            __THREW__ = 0;
            invoke_viii(3262,($99|0),1,1);
            $107 = __THREW__; __THREW__ = 0;
            $108 = $107&1;
            if ($108) {
             $$0 = 0;
             break;
            }
           }
          }
         }
         $109 = HEAP8[$94>>0]|0;
         $110 = ($109<<24>>24)<(0);
         if (!($110)) {
          STACKTOP = sp;return;
         }
         $111 = HEAP32[$4>>2]|0;
         __ZdlPv($111);
         STACKTOP = sp;return;
        }
       } while(0);
       $120 = ___cxa_find_matching_catch_2()|0;
       $121 = tempRet0;
       $122 = HEAP8[$94>>0]|0;
       $123 = ($122<<24>>24)<(0);
       if ($123) {
        $124 = HEAP32[$4>>2]|0;
        __ZdlPv($124);
        if (!($$0)) {
         $$111 = $120;$$19 = $121;
         break;
        }
       } else {
        if (!($$0)) {
         $$111 = $120;$$19 = $121;
         break;
        }
       }
       __ZdlPv($91);
       $$111 = $120;$$19 = $121;
      }
     }
    }
   }
  } while(0);
  if ((label|0) == 31) {
   $114 = ___cxa_find_matching_catch_2()|0;
   $115 = tempRet0;
   $$111 = $114;$$19 = $115;
  }
  $125 = HEAP32[$32>>2]|0;
  $126 = ($125|0)==(0|0);
  if (!($126)) {
   $127 = ((($125)) + 8|0);
   $128 = HEAP32[$127>>2]|0;HEAP32[$127>>2] = (($128-1)|0);
   $129 = ($128|0)==(1);
   if ($129) {
    __THREW__ = 0;
    invoke_viii(3262,($125|0),1,1);
    $130 = __THREW__; __THREW__ = 0;
    $131 = $130&1;
    if ($131) {
     $220 = ___cxa_find_matching_catch_3(0|0)|0;
     $221 = tempRet0;
     ___clang_call_terminate($220);
     // unreachable;
    }
   }
  }
  HEAP32[$32>>2] = 0;
  $132 = HEAP32[$25>>2]|0;
  $133 = ($132|0)==(0|0);
  if (!($133)) {
   $134 = ((($132)) + 8|0);
   $135 = HEAP32[$134>>2]|0;HEAP32[$134>>2] = (($135-1)|0);
   $136 = ($135|0)==(1);
   if ($136) {
    __THREW__ = 0;
    invoke_viii(3262,($132|0),1,1);
    $137 = __THREW__; __THREW__ = 0;
    $138 = $137&1;
    if ($138) {
     $220 = ___cxa_find_matching_catch_3(0|0)|0;
     $221 = tempRet0;
     ___clang_call_terminate($220);
     // unreachable;
    }
   }
  }
  HEAP32[$25>>2] = 0;
  __THREW__ = 0;
  invoke_vi(3293,($22|0));
  $139 = __THREW__; __THREW__ = 0;
  $140 = $139&1;
  if ($140) {
   $220 = ___cxa_find_matching_catch_3(0|0)|0;
   $221 = tempRet0;
   ___clang_call_terminate($220);
   // unreachable;
  } else {
   $$2 = $$19;$$212 = $$111;
  }
 }
 $141 = HEAP32[$21>>2]|0;
 $142 = ($141|0)==(0);
 L64: do {
  if (!($142)) {
   $143 = HEAP32[$20>>2]|0;
   $144 = HEAP32[$19>>2]|0;
   $145 = ((($144)) + 4|0);
   $146 = HEAP32[$145>>2]|0;
   $147 = HEAP32[$143>>2]|0;
   $148 = ((($147)) + 4|0);
   HEAP32[$148>>2] = $146;
   $149 = HEAP32[$145>>2]|0;
   HEAP32[$149>>2] = $147;
   HEAP32[$21>>2] = 0;
   $150 = ($143|0)==($19|0);
   if (!($150)) {
    $$023$i$i = $143;
    while(1) {
     $151 = ((($$023$i$i)) + 4|0);
     $152 = HEAP32[$151>>2]|0;
     $153 = ((($$023$i$i)) + 8|0);
     $154 = HEAP32[$153>>2]|0;
     $155 = ($154|0)==(0|0);
     if (!($155)) {
      $156 = HEAP32[$154>>2]|0;
      $157 = ((($156)) + -16|0);
      $158 = HEAP32[$157>>2]|0;
      $159 = (($154) + ($158)|0);
      $160 = ((($159)) + 8|0);
      $161 = HEAP32[$160>>2]|0;HEAP32[$160>>2] = (($161-1)|0);
      $162 = ($161|0)==(1);
      if ($162) {
       __THREW__ = 0;
       invoke_viii(3262,($159|0),1,1);
       $163 = __THREW__; __THREW__ = 0;
       $164 = $163&1;
       if ($164) {
        break;
       }
      }
     }
     __ZdlPv($$023$i$i);
     $165 = ($152|0)==($19|0);
     if ($165) {
      break L64;
     } else {
      $$023$i$i = $152;
     }
    }
    $166 = ___cxa_find_matching_catch_2()|0;
    $167 = tempRet0;
    ___cxa_call_unexpected(($166|0));
    // unreachable;
   }
  }
 } while(0);
 $168 = HEAP32[$18>>2]|0;
 $169 = ($168|0)==(0|0);
 if (!($169)) {
  $170 = HEAP32[$168>>2]|0;
  $171 = ((($170)) + -16|0);
  $172 = HEAP32[$171>>2]|0;
  $173 = (($168) + ($172)|0);
  $174 = ((($173)) + 8|0);
  $175 = HEAP32[$174>>2]|0;HEAP32[$174>>2] = (($175-1)|0);
  $176 = ($175|0)==(1);
  if ($176) {
   __THREW__ = 0;
   invoke_viii(3262,($173|0),1,1);
   $177 = __THREW__; __THREW__ = 0;
   $178 = $177&1;
   if ($178) {
    $220 = ___cxa_find_matching_catch_3(0|0)|0;
    $221 = tempRet0;
    ___clang_call_terminate($220);
    // unreachable;
   }
  }
 }
 HEAP32[$18>>2] = 0;
 $179 = HEAP32[$17>>2]|0;
 $180 = ($179|0)==(0|0);
 if (!($180)) {
  $181 = ((($179)) + 8|0);
  $182 = HEAP32[$181>>2]|0;HEAP32[$181>>2] = (($182-1)|0);
  $183 = ($182|0)==(1);
  if ($183) {
   __THREW__ = 0;
   invoke_viii(3262,($179|0),1,1);
   $184 = __THREW__; __THREW__ = 0;
   $185 = $184&1;
   if ($185) {
    $220 = ___cxa_find_matching_catch_3(0|0)|0;
    $221 = tempRet0;
    ___clang_call_terminate($220);
    // unreachable;
   }
  }
 }
 HEAP32[$17>>2] = 0;
 $186 = HEAP32[$16>>2]|0;
 $187 = ($186|0)==(0|0);
 if (!($187)) {
  $188 = ((($186)) + 8|0);
  $189 = HEAP32[$188>>2]|0;HEAP32[$188>>2] = (($189-1)|0);
  $190 = ($189|0)==(1);
  if ($190) {
   __THREW__ = 0;
   invoke_viii(3262,($186|0),1,1);
   $191 = __THREW__; __THREW__ = 0;
   $192 = $191&1;
   if ($192) {
    $220 = ___cxa_find_matching_catch_3(0|0)|0;
    $221 = tempRet0;
    ___clang_call_terminate($220);
    // unreachable;
   }
  }
 }
 HEAP32[$16>>2] = 0;
 $193 = HEAP32[$14>>2]|0;
 $194 = ($193|0)==(0|0);
 if (!($194)) {
  $195 = HEAP32[$15>>2]|0;
  $196 = ($195|0)==($193|0);
  do {
   if ($196) {
    $210 = $193;
   } else {
    $198 = $195;
    while(1) {
     $197 = ((($198)) + -4|0);
     HEAP32[$15>>2] = $197;
     $199 = HEAP32[$197>>2]|0;
     $200 = ($199|0)==(0|0);
     if (!($200)) {
      $201 = ((($199)) + 8|0);
      $202 = HEAP32[$201>>2]|0;HEAP32[$201>>2] = (($202-1)|0);
      $203 = ($202|0)==(1);
      if ($203) {
       __THREW__ = 0;
       invoke_viii(3262,($199|0),1,1);
       $204 = __THREW__; __THREW__ = 0;
       $205 = $204&1;
       if ($205) {
        label = 67;
        break;
       }
      }
     }
     HEAP32[$197>>2] = 0;
     $206 = HEAP32[$15>>2]|0;
     $207 = ($206|0)==($193|0);
     if ($207) {
      label = 68;
      break;
     } else {
      $198 = $206;
     }
    }
    if ((label|0) == 67) {
     $208 = ___cxa_find_matching_catch_2()|0;
     $209 = tempRet0;
     ___cxa_call_unexpected(($208|0));
     // unreachable;
    }
    else if ((label|0) == 68) {
     $$pre$i = HEAP32[$14>>2]|0;
     $210 = $$pre$i;
     break;
    }
   }
  } while(0);
  __ZdlPv($210);
 }
 $211 = HEAP32[$13>>2]|0;
 $212 = ($211|0)==(0|0);
 if (!($212)) {
  $213 = ((($211)) + 8|0);
  $214 = HEAP32[$213>>2]|0;HEAP32[$213>>2] = (($214-1)|0);
  $215 = ($214|0)==(1);
  if ($215) {
   __THREW__ = 0;
   invoke_viii(3262,($211|0),1,1);
   $216 = __THREW__; __THREW__ = 0;
   $217 = $216&1;
   if ($217) {
    $220 = ___cxa_find_matching_catch_3(0|0)|0;
    $221 = tempRet0;
    ___clang_call_terminate($220);
    // unreachable;
   }
  }
 }
 HEAP32[$13>>2] = 0;
 __THREW__ = 0;
 invoke_vii(3294,($0|0),($5|0));
 $218 = __THREW__; __THREW__ = 0;
 $219 = $218&1;
 if ($219) {
  $220 = ___cxa_find_matching_catch_3(0|0)|0;
  $221 = tempRet0;
  ___clang_call_terminate($220);
  // unreachable;
 } else {
  ___resumeException($$212|0);
  // unreachable;
 }
}
function __ZN9osgViewer4View4initEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $2 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
 do {
  if ($2) {
   $3 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
   $4 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($3,103093,12)|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = ((($5)) + -12|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = (($4) + ($7)|0);
   __ZNKSt3__28ios_base6getlocEv($1,$8);
   __THREW__ = 0;
   $9 = (invoke_iii(3255,($1|0),(215188|0))|0);
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    $12 = HEAP32[$9>>2]|0;
    $13 = ((($12)) + 28|0);
    $14 = HEAP32[$13>>2]|0;
    __THREW__ = 0;
    $15 = (invoke_iii($14|0,($9|0),10)|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if (!($17)) {
     __ZNSt3__26localeD2Ev($1);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($4,$15)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($4)|0);
     break;
    }
   }
   $18 = ___cxa_find_matching_catch_2()|0;
   $19 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($1|0));
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if ($21) {
    $22 = ___cxa_find_matching_catch_3(0|0)|0;
    $23 = tempRet0;
    ___clang_call_terminate($22);
    // unreachable;
   } else {
    ___resumeException($18|0);
    // unreachable;
   }
  }
 } while(0);
 $24 = ((($0)) + 72|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (__ZN5osgGA10EventQueue11createEventEv($25)|0);
 $27 = ($26|0)==(0|0);
 if (!($27)) {
  $28 = ((($26)) + 8|0);
  $29 = HEAP32[$28>>2]|0;HEAP32[$28>>2] = (($29+1)|0);
 }
 $30 = ((($26)) + 48|0);
 HEAP32[$30>>2] = 128;
 $31 = ((($0)) + 76|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = ($32|0)==(0|0);
 if (!($33)) {
  $34 = HEAP32[$32>>2]|0;
  $35 = ((($34)) + 152|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = ((($0)) + 36|0);
  __THREW__ = 0;
  invoke_viii($36|0,($32|0),($26|0),($37|0));
  $38 = __THREW__; __THREW__ = 0;
  $39 = $38&1;
  if ($39) {
   $40 = ___cxa_find_matching_catch_2()|0;
   $41 = tempRet0;
   $42 = ((($26)) + 8|0);
   $43 = HEAP32[$42>>2]|0;HEAP32[$42>>2] = (($43-1)|0);
   $44 = ($43|0)==(1);
   if (!($44)) {
    ___resumeException($40|0);
    // unreachable;
   }
   __THREW__ = 0;
   invoke_viii(3262,($26|0),1,1);
   $45 = __THREW__; __THREW__ = 0;
   $46 = $45&1;
   if ($46) {
    $50 = ___cxa_find_matching_catch_3(0|0)|0;
    $51 = tempRet0;
    ___clang_call_terminate($50);
    // unreachable;
   } else {
    ___resumeException($40|0);
    // unreachable;
   }
  }
 }
 $47 = ((($26)) + 8|0);
 $48 = HEAP32[$47>>2]|0;HEAP32[$47>>2] = (($48-1)|0);
 $49 = ($48|0)==(1);
 if (!($49)) {
  STACKTOP = sp;return;
 }
 __ZNK3osg10Referenced24signalObserversAndDeleteEbb($26,1,1);
 STACKTOP = sp;return;
}
function __ZN9osgViewer4View16getDatabasePagerEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 68|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 return ($4|0);
}
function __ZN9osgViewer4View13getImagePagerEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 68|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 return ($4|0);
}
function __ZN9osgViewer4View20setCameraManipulatorEPN5osgGA17CameraManipulatorEb($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$04 = 0, $$pr = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 76|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==($1|0);
 if ($5) {
  $21 = $1;
 } else {
  HEAP32[$3>>2] = $1;
  $6 = ($1|0)==(0|0);
  if (!($6)) {
   $7 = HEAP32[$1>>2]|0;
   $8 = ((($7)) + -16|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($1) + ($9)|0);
   $11 = ((($10)) + 8|0);
   $12 = HEAP32[$11>>2]|0;HEAP32[$11>>2] = (($12+1)|0);
  }
  $13 = ($4|0)==(0|0);
  if (!($13)) {
   $14 = HEAP32[$4>>2]|0;
   $15 = ((($14)) + -16|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (($4) + ($16)|0);
   $18 = ((($17)) + 8|0);
   $19 = HEAP32[$18>>2]|0;HEAP32[$18>>2] = (($19-1)|0);
   $20 = ($19|0)==(1);
   if ($20) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($17,1,1);
   }
  }
  $$pr = HEAP32[$3>>2]|0;
  $21 = $$pr;
 }
 $22 = ($21|0)==(0|0);
 if ($22) {
  return;
 }
 $23 = HEAP32[$21>>2]|0;
 $24 = ((($23)) + 80|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (__Znwj(20)|0);
 __THREW__ = 0;
 invoke_vi(3282,($26|0));
 $27 = __THREW__; __THREW__ = 0;
 $28 = $27&1;
 do {
  if ($28) {
   $51 = ___cxa_find_matching_catch_2()|0;
   $52 = tempRet0;
   $eh$lpad$body$index2Z2D = $52;$eh$lpad$body$indexZ2D = $51;
  } else {
   HEAP32[$26>>2] = (36112);
   $29 = ((($26)) + 12|0);
   __THREW__ = 0;
   invoke_vii(3324,($29|0),($0|0));
   $30 = __THREW__; __THREW__ = 0;
   $31 = $30&1;
   if ($31) {
    $32 = ___cxa_find_matching_catch_2()|0;
    $33 = tempRet0;
    __THREW__ = 0;
    invoke_vi(712,($26|0));
    $34 = __THREW__; __THREW__ = 0;
    $35 = $34&1;
    if (!($35)) {
     $eh$lpad$body$index2Z2D = $33;$eh$lpad$body$indexZ2D = $32;
     break;
    }
    $36 = ___cxa_find_matching_catch_3(0|0)|0;
    $37 = tempRet0;
    ___clang_call_terminate($36);
    // unreachable;
   }
   FUNCTION_TABLE_vii[$25 & 8191]($21,$26);
   $38 = ((($0)) + 68|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = ($39|0)==(0|0);
   if (!($40)) {
    $41 = (__ZN9osgViewer5Scene12getSceneDataEv($39)|0);
    $42 = ($41|0)==(0|0);
    if (!($42)) {
     $43 = HEAP32[$3>>2]|0;
     $44 = HEAP32[$43>>2]|0;
     $45 = ((($44)) + 112|0);
     $46 = HEAP32[$45>>2]|0;
     $47 = HEAP32[$38>>2]|0;
     $48 = ($47|0)==(0|0);
     if ($48) {
      $50 = 0;
     } else {
      $49 = (__ZN9osgViewer5Scene12getSceneDataEv($47)|0);
      $50 = $49;
     }
     FUNCTION_TABLE_vii[$46 & 8191]($43,$50);
    }
   }
   if (!($2)) {
    return;
   }
   $53 = ((($0)) + 72|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = (__ZN5osgGA10EventQueue11createEventEv($54)|0);
   $56 = ($55|0)==(0|0);
   if (!($56)) {
    $57 = ((($55)) + 8|0);
    $58 = HEAP32[$57>>2]|0;HEAP32[$57>>2] = (($58+1)|0);
   }
   $59 = HEAP32[$3>>2]|0;
   $60 = HEAP32[$59>>2]|0;
   $61 = ((($60)) + 144|0);
   $62 = HEAP32[$61>>2]|0;
   $63 = ((($0)) + 36|0);
   __THREW__ = 0;
   invoke_viii($62|0,($59|0),($55|0),($63|0));
   $64 = __THREW__; __THREW__ = 0;
   $65 = $64&1;
   if ($65) {
    $69 = ___cxa_find_matching_catch_2()|0;
    $70 = tempRet0;
    if (!($56)) {
     $71 = ((($55)) + 8|0);
     $72 = HEAP32[$71>>2]|0;HEAP32[$71>>2] = (($72-1)|0);
     $73 = ($72|0)==(1);
     if ($73) {
      __THREW__ = 0;
      invoke_viii(3262,($55|0),1,1);
      $74 = __THREW__; __THREW__ = 0;
      $75 = $74&1;
      if ($75) {
       $76 = ___cxa_find_matching_catch_3(0|0)|0;
       $77 = tempRet0;
       ___clang_call_terminate($76);
       // unreachable;
      }
     }
    }
    $$0 = $70;$$04 = $69;
    ___resumeException($$04|0);
    // unreachable;
   } else {
    if ($56) {
     return;
    }
    $66 = ((($55)) + 8|0);
    $67 = HEAP32[$66>>2]|0;HEAP32[$66>>2] = (($67-1)|0);
    $68 = ($67|0)==(1);
    if (!($68)) {
     return;
    }
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($55,1,1);
    return;
   }
  }
 } while(0);
 __ZdlPv($26);
 $$0 = $eh$lpad$body$index2Z2D;$$04 = $eh$lpad$body$indexZ2D;
 ___resumeException($$04|0);
 // unreachable;
}
function __ZN3osg12observer_ptrIN9osgViewer4ViewEEC2EPS2_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$ = 0, $$pr = 0, $$pr6 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = 0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   label = 9;
  } else {
   $3 = HEAP32[$1>>2]|0;
   $4 = ((($3)) + -12|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = (($1) + ($5)|0);
   __THREW__ = 0;
   $7 = (invoke_ii(3325,($6|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    $$pr = HEAP32[$0>>2]|0;
    $10 = ($$pr|0)==($7|0);
    if ($10) {
     $20 = $7;
     break;
    }
    HEAP32[$0>>2] = $7;
    $11 = ($7|0)==(0|0);
    if (!($11)) {
     $12 = ((($7)) + 8|0);
     $13 = HEAP32[$12>>2]|0;HEAP32[$12>>2] = (($13+1)|0);
    }
    $14 = ($$pr|0)==(0|0);
    if ($14) {
     label = 9;
     break;
    }
    $15 = ((($$pr)) + 8|0);
    $16 = HEAP32[$15>>2]|0;HEAP32[$15>>2] = (($16-1)|0);
    $17 = ($16|0)==(1);
    if (!($17)) {
     label = 9;
     break;
    }
    __THREW__ = 0;
    invoke_viii(3262,($$pr|0),1,1);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     label = 9;
     break;
    }
   }
   $27 = ___cxa_find_matching_catch_2()|0;
   $28 = tempRet0;
   $29 = HEAP32[$0>>2]|0;
   $30 = ($29|0)==(0|0);
   if ($30) {
    HEAP32[$0>>2] = 0;
    ___resumeException($27|0);
    // unreachable;
   }
   $31 = ((($29)) + 8|0);
   $32 = HEAP32[$31>>2]|0;HEAP32[$31>>2] = (($32-1)|0);
   $33 = ($32|0)==(1);
   if (!($33)) {
    HEAP32[$0>>2] = 0;
    ___resumeException($27|0);
    // unreachable;
   }
   __THREW__ = 0;
   invoke_viii(3262,($29|0),1,1);
   $34 = __THREW__; __THREW__ = 0;
   $35 = $34&1;
   if ($35) {
    $36 = ___cxa_find_matching_catch_3(0|0)|0;
    $37 = tempRet0;
    ___clang_call_terminate($36);
    // unreachable;
   } else {
    HEAP32[$0>>2] = 0;
    ___resumeException($27|0);
    // unreachable;
   }
  }
 } while(0);
 if ((label|0) == 9) {
  $$pr6 = HEAP32[$0>>2]|0;
  $20 = $$pr6;
 }
 $21 = ($20|0)==(0|0);
 if ($21) {
  $26 = 0;
  $25 = ((($0)) + 4|0);
  HEAP32[$25>>2] = $26;
  return;
 }
 $22 = ((($20)) + 24|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)!=(0|0);
 $$ = $24 ? $1 : 0;
 $26 = $$;
 $25 = ((($0)) + 4|0);
 HEAP32[$25>>2] = $26;
 return;
}
function __ZN29ViewerCoordinateFrameCallbackD2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (36112);
 $1 = ((($0)) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  HEAP32[$1>>2] = 0;
  __ZN3osg10ReferencedD2Ev($0);
  return;
 }
 $4 = ((($2)) + 8|0);
 $5 = HEAP32[$4>>2]|0;HEAP32[$4>>2] = (($5-1)|0);
 $6 = ($5|0)==(1);
 if (!($6)) {
  HEAP32[$1>>2] = 0;
  __ZN3osg10ReferencedD2Ev($0);
  return;
 }
 __THREW__ = 0;
 invoke_viii(3262,($2|0),1,1);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if (!($8)) {
  HEAP32[$1>>2] = 0;
  __ZN3osg10ReferencedD2Ev($0);
  return;
 }
 $9 = ___cxa_find_matching_catch_2()|0;
 $10 = tempRet0;
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if ($12) {
  $13 = ___cxa_find_matching_catch_3(0|0)|0;
  $14 = tempRet0;
  ___clang_call_terminate($13);
  // unreachable;
 } else {
  ___resumeException($9|0);
  // unreachable;
 }
}
function __ZN29ViewerCoordinateFrameCallbackD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (36112);
 $1 = ((($0)) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = ((($2)) + 8|0);
  $5 = HEAP32[$4>>2]|0;HEAP32[$4>>2] = (($5-1)|0);
  $6 = ($5|0)==(1);
  if ($6) {
   __THREW__ = 0;
   invoke_viii(3262,($2|0),1,1);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch_2()|0;
    $12 = tempRet0;
    __THREW__ = 0;
    invoke_vi(712,($0|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     $15 = ___cxa_find_matching_catch_3(0|0)|0;
     $16 = tempRet0;
     ___clang_call_terminate($15);
     // unreachable;
    } else {
     $eh$lpad$body$index2Z2D = $12;$eh$lpad$body$indexZ2D = $11;
     __ZdlPv($0);
     ___resumeException($eh$lpad$body$indexZ2D|0);
     // unreachable;
    }
   }
  }
 }
 HEAP32[$1>>2] = 0;
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if (!($10)) {
  __ZdlPv($0);
  return;
 }
 $17 = ___cxa_find_matching_catch_2()|0;
 $18 = tempRet0;
 $eh$lpad$body$index2Z2D = $18;$eh$lpad$body$indexZ2D = $17;
 __ZdlPv($0);
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
}
function __ZNK29ViewerCoordinateFrameCallback18getCoordinateFrameERKN3osg5Vec3dE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$2 = 0, $$212 = 0, $$6 = 0, $$616 = 0, $$phi$trans$insert = 0, $$phi$trans$insert148 = 0, $$phi$trans$insert150 = 0, $$phi$trans$insert154 = 0, $$phi$trans$insert156 = 0, $$phi$trans$insert158 = 0, $$phi$trans$insert160 = 0, $$phi$trans$insert162 = 0, $$phi$trans$insert164 = 0, $$phi$trans$insert166 = 0, $$phi$trans$insert168 = 0, $$phi$trans$insert170 = 0, $$pre = 0.0, $$pre$phi177Z2D = 0, $$pre$phi179Z2D = 0, $$pre$phi181Z2D = 0;
 var $$pre$phi182Z2D = 0, $$pre$phi184Z2D = 0, $$pre$phi186Z2D = 0, $$pre$phi187Z2D = 0, $$pre$phi189Z2D = 0, $$pre$phi191Z2D = 0, $$pre$phi192Z2D = 0, $$pre149 = 0.0, $$pre151 = 0.0, $$pre153 = 0.0, $$pre155 = 0.0, $$pre157 = 0.0, $$pre159 = 0.0, $$pre161 = 0.0, $$pre163 = 0.0, $$pre165 = 0.0, $$pre167 = 0.0, $$pre169 = 0.0, $$pre171 = 0.0, $$pre178 = 0;
 var $$pre180 = 0, $$pre183 = 0, $$pre185 = 0, $$pre188 = 0, $$pre190 = 0, $10 = 0, $100 = 0.0, $101 = 0.0, $102 = 0, $103 = 0.0, $104 = 0.0, $105 = 0.0, $106 = 0, $107 = 0.0, $108 = 0.0, $109 = 0.0, $11 = 0, $110 = 0, $111 = 0.0, $112 = 0.0;
 var $113 = 0.0, $114 = 0, $115 = 0.0, $116 = 0.0, $117 = 0, $118 = 0.0, $119 = 0.0, $12 = 0, $120 = 0.0, $121 = 0, $122 = 0.0, $123 = 0.0, $124 = 0.0, $125 = 0, $126 = 0.0, $127 = 0.0, $128 = 0.0, $129 = 0, $13 = 0, $130 = 0.0;
 var $131 = 0.0, $132 = 0, $133 = 0.0, $134 = 0.0, $135 = 0.0, $136 = 0, $137 = 0.0, $138 = 0.0, $139 = 0.0, $14 = 0, $140 = 0, $141 = 0.0, $142 = 0.0, $143 = 0.0, $144 = 0.0, $145 = 0.0, $146 = 0.0, $147 = 0.0, $148 = 0.0, $149 = 0;
 var $15 = 0, $150 = 0.0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0.0, $162 = 0, $163 = 0.0, $164 = 0, $165 = 0, $166 = 0.0, $167 = 0;
 var $168 = 0, $169 = 0.0, $17 = 0, $170 = 0, $171 = 0, $172 = 0.0, $173 = 0, $174 = 0, $175 = 0.0, $176 = 0, $177 = 0, $178 = 0.0, $179 = 0, $18 = 0.0, $180 = 0, $181 = 0.0, $182 = 0, $183 = 0, $184 = 0.0, $185 = 0;
 var $186 = 0, $187 = 0.0, $188 = 0, $189 = 0, $19 = 0, $190 = 0.0, $191 = 0, $192 = 0, $193 = 0.0, $194 = 0, $195 = 0, $196 = 0.0, $197 = 0, $198 = 0, $199 = 0.0, $20 = 0, $200 = 0, $201 = 0, $202 = 0.0, $203 = 0;
 var $204 = 0, $205 = 0.0, $206 = 0, $207 = 0.0, $208 = 0, $209 = 0.0, $21 = 0, $210 = 0, $211 = 0.0, $212 = 0.0, $213 = 0.0, $214 = 0.0, $215 = 0.0, $216 = 0.0, $217 = 0.0, $218 = 0.0, $219 = 0.0, $22 = 0.0, $220 = 0.0, $221 = 0.0;
 var $222 = 0.0, $223 = 0.0, $224 = 0.0, $225 = 0.0, $226 = 0.0, $227 = 0.0, $228 = 0.0, $229 = 0.0, $23 = 0, $230 = 0.0, $231 = 0.0, $232 = 0.0, $233 = 0.0, $234 = 0.0, $235 = 0.0, $236 = 0.0, $237 = 0.0, $238 = 0.0, $239 = 0.0, $24 = 0;
 var $240 = 0.0, $241 = 0.0, $242 = 0.0, $243 = 0.0, $244 = 0.0, $245 = 0.0, $246 = 0.0, $247 = 0.0, $248 = 0.0, $249 = 0.0, $25 = 0, $250 = 0.0, $251 = 0.0, $252 = 0.0, $253 = 0.0, $254 = 0.0, $255 = 0.0, $256 = 0.0, $257 = 0.0, $258 = 0.0;
 var $259 = 0.0, $26 = 0.0, $260 = 0.0, $261 = 0.0, $262 = 0.0, $263 = 0.0, $264 = 0.0, $265 = 0.0, $266 = 0.0, $267 = 0.0, $268 = 0.0, $269 = 0.0, $27 = 0, $270 = 0.0, $271 = 0.0, $272 = 0.0, $273 = 0.0, $274 = 0.0, $275 = 0.0, $276 = 0.0;
 var $277 = 0, $278 = 0.0, $279 = 0.0, $28 = 0, $280 = 0.0, $281 = 0.0, $282 = 0.0, $283 = 0.0, $284 = 0.0, $285 = 0.0, $286 = 0, $287 = 0.0, $288 = 0.0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0;
 var $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0;
 var $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0;
 var $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0;
 var $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0;
 var $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0.0, $38 = 0, $380 = 0, $381 = 0.0, $382 = 0, $383 = 0, $384 = 0.0;
 var $385 = 0, $386 = 0, $387 = 0.0, $388 = 0, $389 = 0, $39 = 0, $390 = 0.0, $391 = 0, $392 = 0, $393 = 0.0, $394 = 0, $395 = 0, $396 = 0.0, $397 = 0, $398 = 0, $399 = 0.0, $4 = 0, $40 = 0, $400 = 0, $401 = 0;
 var $402 = 0.0, $403 = 0, $404 = 0, $405 = 0.0, $406 = 0, $407 = 0, $408 = 0.0, $409 = 0, $41 = 0, $410 = 0, $411 = 0.0, $412 = 0, $413 = 0, $414 = 0.0, $415 = 0, $416 = 0, $417 = 0.0, $418 = 0, $419 = 0, $42 = 0;
 var $420 = 0.0, $421 = 0, $422 = 0, $423 = 0.0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0;
 var $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0;
 var $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0.0, $464 = 0, $465 = 0.0, $466 = 0, $467 = 0.0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0;
 var $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0.0, $82 = 0.0, $83 = 0.0, $84 = 0, $85 = 0.0, $86 = 0, $87 = 0.0, $88 = 0.0;
 var $89 = 0.0, $9 = 0, $90 = 0, $91 = 0.0, $92 = 0, $93 = 0.0, $94 = 0.0, $95 = 0.0, $96 = 0, $97 = 0.0, $98 = 0.0, $99 = 0.0, $eh$lpad$body$index9Z2D = 0, $eh$lpad$body$indexZ2D = 0, $eh$lpad$body39$index14Z2D = 0, $eh$lpad$body39$indexZ2D = 0, $eh$lpad$body52$index4Z2D = 0, $eh$lpad$body52$indexZ2D = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i$i = 0;
 var $scevgep$i$i$i18 = 0, $scevgep5$i$i$i = 0, $scevgep5$i$i$i$i = 0, $scevgep5$i$i$i19 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 720|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(720|0);
 $3 = sp + 712|0;
 $4 = sp + 708|0;
 $5 = sp + 704|0;
 $6 = sp + 700|0;
 $7 = sp + 688|0;
 $8 = sp + 560|0;
 $9 = sp + 432|0;
 $10 = sp + 304|0;
 $11 = sp + 280|0;
 $12 = sp + 152|0;
 $13 = sp + 128|0;
 $14 = sp;
 $15 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(5)|0);
 do {
  if ($15) {
   $16 = (__ZN3osg6notifyENS_14NotifySeverityE(5)|0);
   $17 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($16,103106,19)|0);
   $18 = +HEAPF64[$2>>3];
   $19 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEd($17,$18)|0);
   $20 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($19,159071,1)|0);
   $21 = ((($2)) + 8|0);
   $22 = +HEAPF64[$21>>3];
   $23 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEd($20,$22)|0);
   $24 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($23,159071,1)|0);
   $25 = ((($2)) + 16|0);
   $26 = +HEAPF64[$25>>3];
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEd($24,$26)|0);
   $27 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($17,174996,1)|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = ((($28)) + -12|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = (($27) + ($30)|0);
   __ZNKSt3__28ios_base6getlocEv($6,$31);
   __THREW__ = 0;
   $32 = (invoke_iii(3255,($6|0),(215188|0))|0);
   $33 = __THREW__; __THREW__ = 0;
   $34 = $33&1;
   if (!($34)) {
    $35 = HEAP32[$32>>2]|0;
    $36 = ((($35)) + 28|0);
    $37 = HEAP32[$36>>2]|0;
    __THREW__ = 0;
    $38 = (invoke_iii($37|0,($32|0),10)|0);
    $39 = __THREW__; __THREW__ = 0;
    $40 = $39&1;
    if (!($40)) {
     __ZNSt3__26localeD2Ev($6);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($27,$38)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($27)|0);
     break;
    }
   }
   $41 = ___cxa_find_matching_catch_2()|0;
   $42 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($6|0));
   $43 = __THREW__; __THREW__ = 0;
   $44 = $43&1;
   if ($44) {
    $45 = ___cxa_find_matching_catch_3(0|0)|0;
    $46 = tempRet0;
    ___clang_call_terminate($45);
    // unreachable;
   } else {
    ___resumeException($41|0);
    // unreachable;
   }
  }
 } while(0);
 $47 = ((($1)) + 16|0);
 $48 = HEAP32[$47>>2]|0;
 HEAP32[$7>>2] = 0;
 $49 = ((($7)) + 4|0);
 HEAP32[$49>>2] = 0;
 $50 = ((($7)) + 8|0);
 HEAP32[$50>>2] = 0;
 $51 = ((($48)) + 92|0);
 __THREW__ = 0;
 (invoke_iii(3326,($51|0),($7|0))|0);
 $52 = __THREW__; __THREW__ = 0;
 $53 = $52&1;
 if ($53) {
  $54 = ___cxa_find_matching_catch_2()|0;
  $55 = tempRet0;
  $56 = HEAP32[$7>>2]|0;
  $57 = ($56|0)==(0|0);
  if ($57) {
   ___resumeException($54|0);
   // unreachable;
  }
  $58 = HEAP32[$49>>2]|0;
  $59 = ($58|0)==($56|0);
  if (!($59)) {
   $scevgep$i$i$i$i = ((($58)) + -4|0);
   $60 = $scevgep$i$i$i$i;
   $61 = $56;
   $62 = (($60) - ($61))|0;
   $63 = $62 >>> 2;
   $64 = $63 ^ -1;
   $scevgep5$i$i$i$i = (($58) + ($64<<2)|0);
   HEAP32[$49>>2] = $scevgep5$i$i$i$i;
  }
  __ZdlPv($56);
  ___resumeException($54|0);
  // unreachable;
 }
 $65 = HEAP32[$7>>2]|0;
 $66 = HEAP32[$49>>2]|0;
 $67 = ($65|0)==($66|0);
 L21: do {
  if ($67) {
   __THREW__ = 0;
   $427 = (invoke_ii(3265,5)|0);
   $428 = __THREW__; __THREW__ = 0;
   $429 = $428&1;
   if ($429) {
    label = 17;
   } else {
    do {
     if ($427) {
      __THREW__ = 0;
      $430 = (invoke_ii(3266,5)|0);
      $431 = __THREW__; __THREW__ = 0;
      $432 = $431&1;
      if ($432) {
       label = 17;
       break L21;
      }
      __THREW__ = 0;
      $433 = (invoke_iiii(3267,($430|0),(103238|0),56)|0);
      $434 = __THREW__; __THREW__ = 0;
      $435 = $434&1;
      if ($435) {
       label = 17;
       break L21;
      }
      $436 = HEAP32[$433>>2]|0;
      $437 = ((($436)) + -12|0);
      $438 = HEAP32[$437>>2]|0;
      $439 = (($433) + ($438)|0);
      __THREW__ = 0;
      invoke_vii(3257,($3|0),($439|0));
      $440 = __THREW__; __THREW__ = 0;
      $441 = $440&1;
      if ($441) {
       label = 17;
       break L21;
      }
      __THREW__ = 0;
      $442 = (invoke_iii(3255,($3|0),(215188|0))|0);
      $443 = __THREW__; __THREW__ = 0;
      $444 = $443&1;
      if (!($444)) {
       $445 = HEAP32[$442>>2]|0;
       $446 = ((($445)) + 28|0);
       $447 = HEAP32[$446>>2]|0;
       __THREW__ = 0;
       $448 = (invoke_iii($447|0,($442|0),10)|0);
       $449 = __THREW__; __THREW__ = 0;
       $450 = $449&1;
       if (!($450)) {
        __THREW__ = 0;
        invoke_vi(3263,($3|0));
        $457 = __THREW__; __THREW__ = 0;
        $458 = $457&1;
        if ($458) {
         label = 17;
         break L21;
        }
        __THREW__ = 0;
        (invoke_iii(3268,($433|0),($448|0))|0);
        $459 = __THREW__; __THREW__ = 0;
        $460 = $459&1;
        if ($460) {
         label = 17;
         break L21;
        }
        __THREW__ = 0;
        (invoke_ii(3269,($433|0))|0);
        $461 = __THREW__; __THREW__ = 0;
        $462 = $461&1;
        if ($462) {
         label = 17;
         break L21;
        } else {
         break;
        }
       }
      }
      $451 = ___cxa_find_matching_catch_2()|0;
      $452 = tempRet0;
      __THREW__ = 0;
      invoke_vi(3263,($3|0));
      $453 = __THREW__; __THREW__ = 0;
      $454 = $453&1;
      if ($454) {
       $455 = ___cxa_find_matching_catch_3(0|0)|0;
       $456 = tempRet0;
       ___clang_call_terminate($455);
       // unreachable;
      } else {
       $eh$lpad$body52$index4Z2D = $452;$eh$lpad$body52$indexZ2D = $451;
       label = 18;
       break L21;
      }
     }
    } while(0);
    $463 = +HEAPF64[$2>>3];
    $464 = ((($2)) + 8|0);
    $465 = +HEAPF64[$464>>3];
    $466 = ((($2)) + 16|0);
    $467 = +HEAPF64[$466>>3];
    __THREW__ = 0;
    invoke_vi(3299,($0|0));
    $468 = __THREW__; __THREW__ = 0;
    $469 = $468&1;
    if ($469) {
     label = 17;
    } else {
     __THREW__ = 0;
     invoke_viddd(3306,($0|0),(+$463),(+$465),(+$467));
     $470 = __THREW__; __THREW__ = 0;
     $471 = $470&1;
     if ($471) {
      label = 17;
     } else {
      label = 85;
     }
    }
   }
  } else {
   __THREW__ = 0;
   invoke_vi(3299,($0|0));
   $68 = __THREW__; __THREW__ = 0;
   $69 = $68&1;
   if ($69) {
    label = 17;
   } else {
    $70 = HEAP32[$49>>2]|0;
    $71 = ((($70)) + -4|0);
    $72 = HEAP32[$71>>2]|0;
    $73 = ($72|0)==(0|0);
    if (!($73)) {
     $76 = (___dynamic_cast($72,25952,4048,0)|0);
     $77 = ($76|0)==(0|0);
     if (!($77)) {
      __THREW__ = 0;
      invoke_viii(3327,($8|0),($7|0),1);
      $78 = __THREW__; __THREW__ = 0;
      $79 = $78&1;
      if ($79) {
       $330 = ___cxa_find_matching_catch_2()|0;
       $331 = tempRet0;
       $$6 = $331;$$616 = $330;
       break;
      }
      $80 = ((($8)) + 24|0);
      $81 = +HEAPF64[$80>>3];
      $82 = +HEAPF64[$2>>3];
      $83 = $81 * $82;
      $84 = ((($8)) + 56|0);
      $85 = +HEAPF64[$84>>3];
      $86 = ((($2)) + 8|0);
      $87 = +HEAPF64[$86>>3];
      $88 = $85 * $87;
      $89 = $83 + $88;
      $90 = ((($8)) + 88|0);
      $91 = +HEAPF64[$90>>3];
      $92 = ((($2)) + 16|0);
      $93 = +HEAPF64[$92>>3];
      $94 = $91 * $93;
      $95 = $89 + $94;
      $96 = ((($8)) + 120|0);
      $97 = +HEAPF64[$96>>3];
      $98 = $97 + $95;
      $99 = 1.0 / $98;
      $100 = +HEAPF64[$8>>3];
      $101 = $82 * $100;
      $102 = ((($8)) + 32|0);
      $103 = +HEAPF64[$102>>3];
      $104 = $87 * $103;
      $105 = $101 + $104;
      $106 = ((($8)) + 64|0);
      $107 = +HEAPF64[$106>>3];
      $108 = $93 * $107;
      $109 = $105 + $108;
      $110 = ((($8)) + 96|0);
      $111 = +HEAPF64[$110>>3];
      $112 = $111 + $109;
      $113 = $99 * $112;
      $114 = ((($8)) + 8|0);
      $115 = +HEAPF64[$114>>3];
      $116 = $82 * $115;
      $117 = ((($8)) + 40|0);
      $118 = +HEAPF64[$117>>3];
      $119 = $87 * $118;
      $120 = $116 + $119;
      $121 = ((($8)) + 72|0);
      $122 = +HEAPF64[$121>>3];
      $123 = $93 * $122;
      $124 = $120 + $123;
      $125 = ((($8)) + 104|0);
      $126 = +HEAPF64[$125>>3];
      $127 = $126 + $124;
      $128 = $99 * $127;
      $129 = ((($8)) + 16|0);
      $130 = +HEAPF64[$129>>3];
      $131 = $82 * $130;
      $132 = ((($8)) + 48|0);
      $133 = +HEAPF64[$132>>3];
      $134 = $87 * $133;
      $135 = $131 + $134;
      $136 = ((($8)) + 80|0);
      $137 = +HEAPF64[$136>>3];
      $138 = $93 * $137;
      $139 = $135 + $138;
      $140 = ((($8)) + 112|0);
      $141 = +HEAPF64[$140>>3];
      $142 = $141 + $139;
      $143 = $99 * $142;
      $144 = $113;
      $145 = $128;
      $146 = $143;
      $147 = $144;
      HEAPF64[$11>>3] = $147;
      $148 = $145;
      $149 = ((($11)) + 8|0);
      HEAPF64[$149>>3] = $148;
      $150 = $146;
      $151 = ((($11)) + 16|0);
      HEAPF64[$151>>3] = $150;
      __THREW__ = 0;
      invoke_viii(3328,($10|0),($76|0),($11|0));
      $152 = __THREW__; __THREW__ = 0;
      $153 = $152&1;
      if ($153) {
       $332 = ___cxa_find_matching_catch_2()|0;
       $333 = tempRet0;
       $$2 = $333;$$212 = $332;
      } else {
       __THREW__ = 0;
       invoke_viii(3308,($12|0),($7|0),1);
       $154 = __THREW__; __THREW__ = 0;
       $155 = $154&1;
       if (!($155)) {
        __THREW__ = 0;
        invoke_vi(3299,($9|0));
        $156 = __THREW__; __THREW__ = 0;
        $157 = $156&1;
        if (!($157)) {
         __THREW__ = 0;
         invoke_viii(3300,($9|0),($10|0),($12|0));
         $158 = __THREW__; __THREW__ = 0;
         $159 = $158&1;
         if (!($159)) {
          $160 = ($9|0)==($0|0);
          if ($160) {
           $$phi$trans$insert = ((($0)) + 96|0);
           $$pre = +HEAPF64[$$phi$trans$insert>>3];
           $$phi$trans$insert148 = ((($0)) + 104|0);
           $$pre149 = +HEAPF64[$$phi$trans$insert148>>3];
           $$phi$trans$insert150 = ((($0)) + 112|0);
           $$pre151 = +HEAPF64[$$phi$trans$insert150>>3];
           $$pre153 = +HEAPF64[$0>>3];
           $$phi$trans$insert154 = ((($0)) + 32|0);
           $$pre155 = +HEAPF64[$$phi$trans$insert154>>3];
           $$phi$trans$insert156 = ((($0)) + 64|0);
           $$pre157 = +HEAPF64[$$phi$trans$insert156>>3];
           $$phi$trans$insert158 = ((($0)) + 8|0);
           $$pre159 = +HEAPF64[$$phi$trans$insert158>>3];
           $$phi$trans$insert160 = ((($0)) + 40|0);
           $$pre161 = +HEAPF64[$$phi$trans$insert160>>3];
           $$phi$trans$insert162 = ((($0)) + 72|0);
           $$pre163 = +HEAPF64[$$phi$trans$insert162>>3];
           $$phi$trans$insert164 = ((($0)) + 16|0);
           $$pre165 = +HEAPF64[$$phi$trans$insert164>>3];
           $$phi$trans$insert166 = ((($0)) + 48|0);
           $$pre167 = +HEAPF64[$$phi$trans$insert166>>3];
           $$phi$trans$insert168 = ((($0)) + 80|0);
           $$pre169 = +HEAPF64[$$phi$trans$insert168>>3];
           $$phi$trans$insert170 = ((($0)) + 24|0);
           $$pre171 = +HEAPF64[$$phi$trans$insert170>>3];
           $$pre$phi177Z2D = $0;$$pre$phi179Z2D = $$phi$trans$insert154;$$pre$phi181Z2D = $$phi$trans$insert156;$$pre$phi182Z2D = $$phi$trans$insert158;$$pre$phi184Z2D = $$phi$trans$insert160;$$pre$phi186Z2D = $$phi$trans$insert162;$$pre$phi187Z2D = $$phi$trans$insert164;$$pre$phi189Z2D = $$phi$trans$insert166;$$pre$phi191Z2D = $$phi$trans$insert168;$$pre$phi192Z2D = $$phi$trans$insert170;$207 = $$pre;$209 = $$pre149;$211 = $$pre151;$213 = $$pre155;$215 = $$pre153;$217 = $$pre157;$220 = $$pre161;$222 = $$pre159;$224 = $$pre163;$227 = $$pre167;$229 = $$pre165;$231 = $$pre169;$273 = $$pre171;
          } else {
           $161 = +HEAPF64[$9>>3];
           HEAPF64[$0>>3] = $161;
           $162 = ((($9)) + 8|0);
           $163 = +HEAPF64[$162>>3];
           $164 = ((($0)) + 8|0);
           HEAPF64[$164>>3] = $163;
           $165 = ((($9)) + 16|0);
           $166 = +HEAPF64[$165>>3];
           $167 = ((($0)) + 16|0);
           HEAPF64[$167>>3] = $166;
           $168 = ((($9)) + 24|0);
           $169 = +HEAPF64[$168>>3];
           $170 = ((($0)) + 24|0);
           HEAPF64[$170>>3] = $169;
           $171 = ((($9)) + 32|0);
           $172 = +HEAPF64[$171>>3];
           $173 = ((($0)) + 32|0);
           HEAPF64[$173>>3] = $172;
           $174 = ((($9)) + 40|0);
           $175 = +HEAPF64[$174>>3];
           $176 = ((($0)) + 40|0);
           HEAPF64[$176>>3] = $175;
           $177 = ((($9)) + 48|0);
           $178 = +HEAPF64[$177>>3];
           $179 = ((($0)) + 48|0);
           HEAPF64[$179>>3] = $178;
           $180 = ((($9)) + 56|0);
           $181 = +HEAPF64[$180>>3];
           $182 = ((($0)) + 56|0);
           HEAPF64[$182>>3] = $181;
           $183 = ((($9)) + 64|0);
           $184 = +HEAPF64[$183>>3];
           $185 = ((($0)) + 64|0);
           HEAPF64[$185>>3] = $184;
           $186 = ((($9)) + 72|0);
           $187 = +HEAPF64[$186>>3];
           $188 = ((($0)) + 72|0);
           HEAPF64[$188>>3] = $187;
           $189 = ((($9)) + 80|0);
           $190 = +HEAPF64[$189>>3];
           $191 = ((($0)) + 80|0);
           HEAPF64[$191>>3] = $190;
           $192 = ((($9)) + 88|0);
           $193 = +HEAPF64[$192>>3];
           $194 = ((($0)) + 88|0);
           HEAPF64[$194>>3] = $193;
           $195 = ((($9)) + 96|0);
           $196 = +HEAPF64[$195>>3];
           $197 = ((($0)) + 96|0);
           HEAPF64[$197>>3] = $196;
           $198 = ((($9)) + 104|0);
           $199 = +HEAPF64[$198>>3];
           $200 = ((($0)) + 104|0);
           HEAPF64[$200>>3] = $199;
           $201 = ((($9)) + 112|0);
           $202 = +HEAPF64[$201>>3];
           $203 = ((($0)) + 112|0);
           HEAPF64[$203>>3] = $202;
           $204 = ((($9)) + 120|0);
           $205 = +HEAPF64[$204>>3];
           $206 = ((($0)) + 120|0);
           HEAPF64[$206>>3] = $205;
           $$pre178 = ((($0)) + 32|0);
           $$pre180 = ((($0)) + 64|0);
           $$pre183 = ((($0)) + 40|0);
           $$pre185 = ((($0)) + 72|0);
           $$pre188 = ((($0)) + 48|0);
           $$pre190 = ((($0)) + 80|0);
           $$pre$phi177Z2D = $0;$$pre$phi179Z2D = $$pre178;$$pre$phi181Z2D = $$pre180;$$pre$phi182Z2D = $164;$$pre$phi184Z2D = $$pre183;$$pre$phi186Z2D = $$pre185;$$pre$phi187Z2D = $167;$$pre$phi189Z2D = $$pre188;$$pre$phi191Z2D = $$pre190;$$pre$phi192Z2D = $170;$207 = $196;$209 = $199;$211 = $202;$213 = $172;$215 = $161;$217 = $184;$220 = $175;$222 = $163;$224 = $187;$227 = $178;$229 = $166;$231 = $190;$273 = $169;
          }
          HEAPF64[$13>>3] = $207;
          $208 = ((($13)) + 8|0);
          HEAPF64[$208>>3] = $209;
          $210 = ((($13)) + 16|0);
          HEAPF64[$210>>3] = $211;
          $212 = $213 * 0.0;
          $214 = $215 + $212;
          $216 = $217 * 0.0;
          $218 = $214 + $216;
          $219 = $220 * 0.0;
          $221 = $222 + $219;
          $223 = $224 * 0.0;
          $225 = $221 + $223;
          $226 = $227 * 0.0;
          $228 = $229 + $226;
          $230 = $231 * 0.0;
          $232 = $228 + $230;
          $233 = $215 * 0.0;
          $234 = $233 + $213;
          $235 = $234 + $216;
          $236 = $222 * 0.0;
          $237 = $236 + $220;
          $238 = $237 + $223;
          $239 = $229 * 0.0;
          $240 = $239 + $227;
          $241 = $240 + $230;
          $242 = $233 + $212;
          $243 = $217 + $242;
          $244 = $236 + $219;
          $245 = $224 + $244;
          $246 = $239 + $226;
          $247 = $231 + $246;
          $248 = $218 * $218;
          $249 = $225 * $225;
          $250 = $248 + $249;
          $251 = $232 * $232;
          $252 = $250 + $251;
          $253 = (+Math_sqrt((+$252)));
          $254 = 1.0 / $253;
          $255 = $235 * $235;
          $256 = $238 * $238;
          $257 = $255 + $256;
          $258 = $241 * $241;
          $259 = $257 + $258;
          $260 = (+Math_sqrt((+$259)));
          $261 = 1.0 / $260;
          $262 = $243 * $243;
          $263 = $245 * $245;
          $264 = $262 + $263;
          $265 = $247 * $247;
          $266 = $264 + $265;
          $267 = (+Math_sqrt((+$266)));
          $268 = 1.0 / $267;
          $269 = $215 * $254;
          HEAPF64[$$pre$phi177Z2D>>3] = $269;
          $270 = $254 * $222;
          HEAPF64[$$pre$phi182Z2D>>3] = $270;
          $271 = $254 * $229;
          HEAPF64[$$pre$phi187Z2D>>3] = $271;
          $272 = $254 * $273;
          HEAPF64[$$pre$phi192Z2D>>3] = $272;
          $274 = $261 * $213;
          HEAPF64[$$pre$phi179Z2D>>3] = $274;
          $275 = $261 * $220;
          HEAPF64[$$pre$phi184Z2D>>3] = $275;
          $276 = $261 * $227;
          HEAPF64[$$pre$phi189Z2D>>3] = $276;
          $277 = ((($0)) + 56|0);
          $278 = +HEAPF64[$277>>3];
          $279 = $261 * $278;
          HEAPF64[$277>>3] = $279;
          $280 = +HEAPF64[$$pre$phi181Z2D>>3];
          $281 = $268 * $280;
          HEAPF64[$$pre$phi181Z2D>>3] = $281;
          $282 = +HEAPF64[$$pre$phi186Z2D>>3];
          $283 = $268 * $282;
          HEAPF64[$$pre$phi186Z2D>>3] = $283;
          $284 = +HEAPF64[$$pre$phi191Z2D>>3];
          $285 = $268 * $284;
          HEAPF64[$$pre$phi191Z2D>>3] = $285;
          $286 = ((($0)) + 88|0);
          $287 = +HEAPF64[$286>>3];
          $288 = $268 * $287;
          HEAPF64[$286>>3] = $288;
          __THREW__ = 0;
          invoke_vii(3329,($0|0),($13|0));
          $289 = __THREW__; __THREW__ = 0;
          $290 = $289&1;
          L59: do {
           if ($290) {
            label = 47;
           } else {
            __THREW__ = 0;
            $291 = (invoke_ii(3265,5)|0);
            $292 = __THREW__; __THREW__ = 0;
            $293 = $292&1;
            if ($293) {
             label = 47;
            } else {
             L62: do {
              if ($291) {
               __THREW__ = 0;
               $294 = (invoke_ii(3266,5)|0);
               $295 = __THREW__; __THREW__ = 0;
               $296 = $295&1;
               if ($296) {
                label = 47;
                break L59;
               }
               __THREW__ = 0;
               $297 = (invoke_iiii(3267,($294|0),(103126|0),77)|0);
               $298 = __THREW__; __THREW__ = 0;
               $299 = $298&1;
               if ($299) {
                label = 47;
                break L59;
               }
               __THREW__ = 0;
               $300 = (invoke_iii(3330,($297|0),($0|0))|0);
               $301 = __THREW__; __THREW__ = 0;
               $302 = $301&1;
               if ($302) {
                label = 47;
                break L59;
               }
               $303 = HEAP32[$300>>2]|0;
               $304 = ((($303)) + -12|0);
               $305 = HEAP32[$304>>2]|0;
               $306 = (($300) + ($305)|0);
               __THREW__ = 0;
               invoke_vii(3257,($5|0),($306|0));
               $307 = __THREW__; __THREW__ = 0;
               $308 = $307&1;
               if ($308) {
                label = 47;
                break L59;
               }
               __THREW__ = 0;
               $309 = (invoke_iii(3255,($5|0),(215188|0))|0);
               $310 = __THREW__; __THREW__ = 0;
               $311 = $310&1;
               do {
                if (!($311)) {
                 $312 = HEAP32[$309>>2]|0;
                 $313 = ((($312)) + 28|0);
                 $314 = HEAP32[$313>>2]|0;
                 __THREW__ = 0;
                 $315 = (invoke_iii($314|0,($309|0),10)|0);
                 $316 = __THREW__; __THREW__ = 0;
                 $317 = $316&1;
                 if ($317) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3263,($5|0));
                 $324 = __THREW__; __THREW__ = 0;
                 $325 = $324&1;
                 if ($325) {
                  label = 47;
                  break L59;
                 }
                 __THREW__ = 0;
                 (invoke_iii(3268,($300|0),($315|0))|0);
                 $326 = __THREW__; __THREW__ = 0;
                 $327 = $326&1;
                 if ($327) {
                  label = 47;
                  break L59;
                 }
                 __THREW__ = 0;
                 (invoke_ii(3269,($300|0))|0);
                 $328 = __THREW__; __THREW__ = 0;
                 $329 = $328&1;
                 if ($329) {
                  label = 47;
                  break L59;
                 } else {
                  break L62;
                 }
                }
               } while(0);
               $318 = ___cxa_find_matching_catch_2()|0;
               $319 = tempRet0;
               __THREW__ = 0;
               invoke_vi(3263,($5|0));
               $320 = __THREW__; __THREW__ = 0;
               $321 = $320&1;
               if ($321) {
                $322 = ___cxa_find_matching_catch_3(0|0)|0;
                $323 = tempRet0;
                ___clang_call_terminate($322);
                // unreachable;
               } else {
                $eh$lpad$body$index9Z2D = $319;$eh$lpad$body$indexZ2D = $318;
                break L59;
               }
              }
             } while(0);
             label = 85;
             break L21;
            }
           }
          } while(0);
          if ((label|0) == 47) {
           $336 = ___cxa_find_matching_catch_2()|0;
           $337 = tempRet0;
           $eh$lpad$body$index9Z2D = $337;$eh$lpad$body$indexZ2D = $336;
          }
          $$6 = $eh$lpad$body$index9Z2D;$$616 = $eh$lpad$body$indexZ2D;
          break;
         }
        }
       }
       $334 = ___cxa_find_matching_catch_2()|0;
       $335 = tempRet0;
       $$2 = $335;$$212 = $334;
      }
      $$6 = $$2;$$616 = $$212;
      break;
     }
    }
    __THREW__ = 0;
    $338 = (invoke_ii(3265,5)|0);
    $339 = __THREW__; __THREW__ = 0;
    $340 = $339&1;
    L84: do {
     if ($340) {
      label = 63;
     } else {
      do {
       if ($338) {
        __THREW__ = 0;
        $341 = (invoke_ii(3266,5)|0);
        $342 = __THREW__; __THREW__ = 0;
        $343 = $342&1;
        if ($343) {
         label = 63;
         break L84;
        }
        __THREW__ = 0;
        $344 = (invoke_iiii(3267,($341|0),(103204|0),33)|0);
        $345 = __THREW__; __THREW__ = 0;
        $346 = $345&1;
        if ($346) {
         label = 63;
         break L84;
        }
        $347 = HEAP32[$344>>2]|0;
        $348 = ((($347)) + -12|0);
        $349 = HEAP32[$348>>2]|0;
        $350 = (($344) + ($349)|0);
        __THREW__ = 0;
        invoke_vii(3257,($4|0),($350|0));
        $351 = __THREW__; __THREW__ = 0;
        $352 = $351&1;
        if ($352) {
         label = 63;
         break L84;
        }
        __THREW__ = 0;
        $353 = (invoke_iii(3255,($4|0),(215188|0))|0);
        $354 = __THREW__; __THREW__ = 0;
        $355 = $354&1;
        if (!($355)) {
         $356 = HEAP32[$353>>2]|0;
         $357 = ((($356)) + 28|0);
         $358 = HEAP32[$357>>2]|0;
         __THREW__ = 0;
         $359 = (invoke_iii($358|0,($353|0),10)|0);
         $360 = __THREW__; __THREW__ = 0;
         $361 = $360&1;
         if (!($361)) {
          __THREW__ = 0;
          invoke_vi(3263,($4|0));
          $368 = __THREW__; __THREW__ = 0;
          $369 = $368&1;
          if ($369) {
           label = 63;
           break L84;
          }
          __THREW__ = 0;
          (invoke_iii(3268,($344|0),($359|0))|0);
          $370 = __THREW__; __THREW__ = 0;
          $371 = $370&1;
          if ($371) {
           label = 63;
           break L84;
          }
          __THREW__ = 0;
          (invoke_ii(3269,($344|0))|0);
          $372 = __THREW__; __THREW__ = 0;
          $373 = $372&1;
          if ($373) {
           label = 63;
           break L84;
          } else {
           break;
          }
         }
        }
        $362 = ___cxa_find_matching_catch_2()|0;
        $363 = tempRet0;
        __THREW__ = 0;
        invoke_vi(3263,($4|0));
        $364 = __THREW__; __THREW__ = 0;
        $365 = $364&1;
        if ($365) {
         $366 = ___cxa_find_matching_catch_3(0|0)|0;
         $367 = tempRet0;
         ___clang_call_terminate($366);
         // unreachable;
        } else {
         $eh$lpad$body39$index14Z2D = $363;$eh$lpad$body39$indexZ2D = $362;
         break L84;
        }
       }
      } while(0);
      __THREW__ = 0;
      invoke_viii(3308,($14|0),($7|0),1);
      $376 = __THREW__; __THREW__ = 0;
      $377 = $376&1;
      if ($377) {
       $425 = ___cxa_find_matching_catch_2()|0;
       $426 = tempRet0;
       $$6 = $426;$$616 = $425;
       break L21;
      }
      $378 = ($14|0)==($0|0);
      if (!($378)) {
       $379 = +HEAPF64[$14>>3];
       HEAPF64[$0>>3] = $379;
       $380 = ((($14)) + 8|0);
       $381 = +HEAPF64[$380>>3];
       $382 = ((($0)) + 8|0);
       HEAPF64[$382>>3] = $381;
       $383 = ((($14)) + 16|0);
       $384 = +HEAPF64[$383>>3];
       $385 = ((($0)) + 16|0);
       HEAPF64[$385>>3] = $384;
       $386 = ((($14)) + 24|0);
       $387 = +HEAPF64[$386>>3];
       $388 = ((($0)) + 24|0);
       HEAPF64[$388>>3] = $387;
       $389 = ((($14)) + 32|0);
       $390 = +HEAPF64[$389>>3];
       $391 = ((($0)) + 32|0);
       HEAPF64[$391>>3] = $390;
       $392 = ((($14)) + 40|0);
       $393 = +HEAPF64[$392>>3];
       $394 = ((($0)) + 40|0);
       HEAPF64[$394>>3] = $393;
       $395 = ((($14)) + 48|0);
       $396 = +HEAPF64[$395>>3];
       $397 = ((($0)) + 48|0);
       HEAPF64[$397>>3] = $396;
       $398 = ((($14)) + 56|0);
       $399 = +HEAPF64[$398>>3];
       $400 = ((($0)) + 56|0);
       HEAPF64[$400>>3] = $399;
       $401 = ((($14)) + 64|0);
       $402 = +HEAPF64[$401>>3];
       $403 = ((($0)) + 64|0);
       HEAPF64[$403>>3] = $402;
       $404 = ((($14)) + 72|0);
       $405 = +HEAPF64[$404>>3];
       $406 = ((($0)) + 72|0);
       HEAPF64[$406>>3] = $405;
       $407 = ((($14)) + 80|0);
       $408 = +HEAPF64[$407>>3];
       $409 = ((($0)) + 80|0);
       HEAPF64[$409>>3] = $408;
       $410 = ((($14)) + 88|0);
       $411 = +HEAPF64[$410>>3];
       $412 = ((($0)) + 88|0);
       HEAPF64[$412>>3] = $411;
       $413 = ((($14)) + 96|0);
       $414 = +HEAPF64[$413>>3];
       $415 = ((($0)) + 96|0);
       HEAPF64[$415>>3] = $414;
       $416 = ((($14)) + 104|0);
       $417 = +HEAPF64[$416>>3];
       $418 = ((($0)) + 104|0);
       HEAPF64[$418>>3] = $417;
       $419 = ((($14)) + 112|0);
       $420 = +HEAPF64[$419>>3];
       $421 = ((($0)) + 112|0);
       HEAPF64[$421>>3] = $420;
       $422 = ((($14)) + 120|0);
       $423 = +HEAPF64[$422>>3];
       $424 = ((($0)) + 120|0);
       HEAPF64[$424>>3] = $423;
      }
      label = 85;
      break L21;
     }
    } while(0);
    if ((label|0) == 63) {
     $374 = ___cxa_find_matching_catch_2()|0;
     $375 = tempRet0;
     $eh$lpad$body39$index14Z2D = $375;$eh$lpad$body39$indexZ2D = $374;
    }
    $$6 = $eh$lpad$body39$index14Z2D;$$616 = $eh$lpad$body39$indexZ2D;
   }
  }
 } while(0);
 if ((label|0) == 17) {
  $74 = ___cxa_find_matching_catch_2()|0;
  $75 = tempRet0;
  $eh$lpad$body52$index4Z2D = $75;$eh$lpad$body52$indexZ2D = $74;
  label = 18;
 }
 else if ((label|0) == 85) {
  $472 = HEAP32[$7>>2]|0;
  $473 = ($472|0)==(0|0);
  if ($473) {
   STACKTOP = sp;return;
  }
  $474 = HEAP32[$49>>2]|0;
  $475 = ($474|0)==($472|0);
  if (!($475)) {
   $scevgep$i$i$i18 = ((($474)) + -4|0);
   $476 = $scevgep$i$i$i18;
   $477 = $472;
   $478 = (($476) - ($477))|0;
   $479 = $478 >>> 2;
   $480 = $479 ^ -1;
   $scevgep5$i$i$i19 = (($474) + ($480<<2)|0);
   HEAP32[$49>>2] = $scevgep5$i$i$i19;
  }
  __ZdlPv($472);
  STACKTOP = sp;return;
 }
 if ((label|0) == 18) {
  $$6 = $eh$lpad$body52$index4Z2D;$$616 = $eh$lpad$body52$indexZ2D;
 }
 $481 = HEAP32[$7>>2]|0;
 $482 = ($481|0)==(0|0);
 if ($482) {
  ___resumeException($$616|0);
  // unreachable;
 }
 $483 = HEAP32[$49>>2]|0;
 $484 = ($483|0)==($481|0);
 if (!($484)) {
  $scevgep$i$i$i = ((($483)) + -4|0);
  $485 = $scevgep$i$i$i;
  $486 = $481;
  $487 = (($485) - ($486))|0;
  $488 = $487 >>> 2;
  $489 = $488 ^ -1;
  $scevgep5$i$i$i = (($483) + ($489<<2)|0);
  HEAP32[$49>>2] = $scevgep5$i$i$i;
 }
 __ZdlPv($481);
 ___resumeException($$616|0);
 // unreachable;
}
function __ZN3osglsERNSt3__213basic_ostreamIcNS0_11char_traitsIcEEEERKNS_7MatrixdE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$01519 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0.0, $47 = 0, $48 = 0, $49 = 0.0, $5 = 0, $50 = 0, $51 = 0, $52 = 0.0, $53 = 0, $54 = 0, $55 = 0.0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp + 8|0;
 $3 = sp + 4|0;
 $4 = sp;
 $5 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($0,103295,1)|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($6)) + -12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($5) + ($8)|0);
 __ZNKSt3__28ios_base6getlocEv($4,$9);
 __THREW__ = 0;
 $10 = (invoke_iii(3255,($4|0),(215188|0))|0);
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if (!($12)) {
  $13 = HEAP32[$10>>2]|0;
  $14 = ((($13)) + 28|0);
  $15 = HEAP32[$14>>2]|0;
  __THREW__ = 0;
  $16 = (invoke_iii($15|0,($10|0),10)|0);
  $17 = __THREW__; __THREW__ = 0;
  $18 = $17&1;
  if (!($18)) {
   __ZNSt3__26localeD2Ev($4);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($5,$16)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($5)|0);
   $$01519 = 0;
   while(1) {
    (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($0,103299,1)|0);
    $45 = (($1) + ($$01519<<5)|0);
    $46 = +HEAPF64[$45>>3];
    $47 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEd($0,$46)|0);
    (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($47,159071,1)|0);
    $48 = (((($1) + ($$01519<<5)|0)) + 8|0);
    $49 = +HEAPF64[$48>>3];
    $50 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEd($0,$49)|0);
    (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($50,159071,1)|0);
    $51 = (((($1) + ($$01519<<5)|0)) + 16|0);
    $52 = +HEAPF64[$51>>3];
    $53 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEd($0,$52)|0);
    (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($53,159071,1)|0);
    $54 = (((($1) + ($$01519<<5)|0)) + 24|0);
    $55 = +HEAPF64[$54>>3];
    $56 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEd($0,$55)|0);
    (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($56,159071,1)|0);
    $57 = HEAP32[$0>>2]|0;
    $58 = ((($57)) + -12|0);
    $59 = HEAP32[$58>>2]|0;
    $60 = (($0) + ($59)|0);
    __ZNKSt3__28ios_base6getlocEv($2,$60);
    __THREW__ = 0;
    $61 = (invoke_iii(3255,($2|0),(215188|0))|0);
    $62 = __THREW__; __THREW__ = 0;
    $63 = $62&1;
    if ($63) {
     label = 15;
     break;
    }
    $64 = HEAP32[$61>>2]|0;
    $65 = ((($64)) + 28|0);
    $66 = HEAP32[$65>>2]|0;
    __THREW__ = 0;
    $67 = (invoke_iii($66|0,($61|0),10)|0);
    $68 = __THREW__; __THREW__ = 0;
    $69 = $68&1;
    if ($69) {
     label = 15;
     break;
    }
    __ZNSt3__26localeD2Ev($2);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($0,$67)|0);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($0)|0);
    $76 = (($$01519) + 1)|0;
    $77 = ($76|0)<(4);
    if ($77) {
     $$01519 = $76;
    } else {
     break;
    }
   }
   if ((label|0) == 15) {
    $70 = ___cxa_find_matching_catch_2()|0;
    $71 = tempRet0;
    __THREW__ = 0;
    invoke_vi(3263,($2|0));
    $72 = __THREW__; __THREW__ = 0;
    $73 = $72&1;
    if ($73) {
     $74 = ___cxa_find_matching_catch_3(0|0)|0;
     $75 = tempRet0;
     ___clang_call_terminate($74);
     // unreachable;
    } else {
     ___resumeException($70|0);
     // unreachable;
    }
   }
   $25 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($0,103297,1)|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = ((($26)) + -12|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = (($25) + ($28)|0);
   __ZNKSt3__28ios_base6getlocEv($3,$29);
   __THREW__ = 0;
   $30 = (invoke_iii(3255,($3|0),(215188|0))|0);
   $31 = __THREW__; __THREW__ = 0;
   $32 = $31&1;
   if (!($32)) {
    $33 = HEAP32[$30>>2]|0;
    $34 = ((($33)) + 28|0);
    $35 = HEAP32[$34>>2]|0;
    __THREW__ = 0;
    $36 = (invoke_iii($35|0,($30|0),10)|0);
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if (!($38)) {
     __ZNSt3__26localeD2Ev($3);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($25,$36)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($25)|0);
     STACKTOP = sp;return ($0|0);
    }
   }
   $39 = ___cxa_find_matching_catch_2()|0;
   $40 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($3|0));
   $41 = __THREW__; __THREW__ = 0;
   $42 = $41&1;
   if ($42) {
    $43 = ___cxa_find_matching_catch_3(0|0)|0;
    $44 = tempRet0;
    ___clang_call_terminate($43);
    // unreachable;
   } else {
    ___resumeException($39|0);
    // unreachable;
   }
  }
 }
 $19 = ___cxa_find_matching_catch_2()|0;
 $20 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($4|0));
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if ($22) {
  $23 = ___cxa_find_matching_catch_3(0|0)|0;
  $24 = tempRet0;
  ___clang_call_terminate($23);
  // unreachable;
 } else {
  ___resumeException($19|0);
  // unreachable;
 }
 return (0)|0;
}
function __ZN9osgViewer4View15addEventHandlerEPN5osgGA12EventHandlerE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$cast$i = 0, $$sroa$0$0$copyload$i = 0, $$sroa$0$0$copyload4$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 80|0);
 $3 = ((($0)) + 84|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==($2|0);
 L1: do {
  if ($5) {
   $$sroa$0$0$copyload$i = $4;
   label = 5;
  } else {
   $$sroa$0$0$copyload4$i = $4;$7 = $4;
   while(1) {
    $6 = ((($7)) + 8|0);
    $8 = HEAP32[$6>>2]|0;
    $9 = ($8|0)==($1|0);
    if ($9) {
     $$sroa$0$0$copyload$i = $$sroa$0$0$copyload4$i;
     label = 5;
     break L1;
    }
    $10 = ((($$sroa$0$0$copyload4$i)) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $$cast$i = $11;
    $12 = ($$cast$i|0)==($2|0);
    $13 = $11;
    if ($12) {
     break;
    } else {
     $$sroa$0$0$copyload4$i = $$cast$i;$7 = $13;
    }
   }
  }
 } while(0);
 if ((label|0) == 5) {
  $14 = ($$sroa$0$0$copyload$i|0)==($2|0);
  if (!($14)) {
   return;
  }
 }
 $15 = ($1|0)==(0|0);
 if (!($15)) {
  $16 = HEAP32[$1>>2]|0;
  $17 = ((($16)) + -16|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (($1) + ($18)|0);
  $20 = ((($19)) + 8|0);
  $21 = HEAP32[$20>>2]|0;HEAP32[$20>>2] = (($21+1)|0);
 }
 __THREW__ = 0;
 $22 = (invoke_ii(3276,12)|0);
 $23 = __THREW__; __THREW__ = 0;
 $24 = $23&1;
 if ($24) {
  $45 = ___cxa_find_matching_catch_2()|0;
  $46 = tempRet0;
  if ($15) {
   ___resumeException($45|0);
   // unreachable;
  }
  $47 = HEAP32[$1>>2]|0;
  $48 = ((($47)) + -16|0);
  $49 = HEAP32[$48>>2]|0;
  $50 = (($1) + ($49)|0);
  $51 = ((($50)) + 8|0);
  $52 = HEAP32[$51>>2]|0;HEAP32[$51>>2] = (($52-1)|0);
  $53 = ($52|0)==(1);
  if (!($53)) {
   ___resumeException($45|0);
   // unreachable;
  }
  __THREW__ = 0;
  invoke_viii(3262,($50|0),1,1);
  $54 = __THREW__; __THREW__ = 0;
  $55 = $54&1;
  if ($55) {
   $56 = ___cxa_find_matching_catch_3(0|0)|0;
   $57 = tempRet0;
   ___clang_call_terminate($56);
   // unreachable;
  } else {
   ___resumeException($45|0);
   // unreachable;
  }
 }
 $25 = ((($22)) + 8|0);
 HEAP32[$25>>2] = $1;
 if (!($15)) {
  $26 = HEAP32[$1>>2]|0;
  $27 = ((($26)) + -16|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (($1) + ($28)|0);
  $30 = ((($29)) + 8|0);
  $31 = HEAP32[$30>>2]|0;HEAP32[$30>>2] = (($31+1)|0);
 }
 $32 = ((($22)) + 4|0);
 HEAP32[$32>>2] = $2;
 $33 = HEAP32[$2>>2]|0;
 HEAP32[$22>>2] = $33;
 $34 = ((($33)) + 4|0);
 HEAP32[$34>>2] = $22;
 HEAP32[$2>>2] = $22;
 $35 = ((($0)) + 88|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = (($36) + 1)|0;
 HEAP32[$35>>2] = $37;
 if ($15) {
  return;
 }
 $38 = HEAP32[$1>>2]|0;
 $39 = ((($38)) + -16|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = (($1) + ($40)|0);
 $42 = ((($41)) + 8|0);
 $43 = HEAP32[$42>>2]|0;HEAP32[$42>>2] = (($43-1)|0);
 $44 = ($43|0)==(1);
 if (!($44)) {
  return;
 }
 __ZNK3osg10Referenced24signalObserversAndDeleteEbb($41,1,1);
 return;
}
function __ZN9osgViewer4View18removeEventHandlerEPN5osgGA12EventHandlerE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$cast$i1 = 0, $$sroa$0$0$copyload$i = 0, $$sroa$0$0$copyload4$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 84|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 80|0);
 $5 = ($3|0)==($4|0);
 L1: do {
  if ($5) {
   $$sroa$0$0$copyload$i = $3;
  } else {
   $$sroa$0$0$copyload4$i = $3;$7 = $3;
   while(1) {
    $6 = ((($7)) + 8|0);
    $8 = HEAP32[$6>>2]|0;
    $9 = ($8|0)==($1|0);
    if ($9) {
     $$sroa$0$0$copyload$i = $$sroa$0$0$copyload4$i;
     break L1;
    }
    $10 = ((($$sroa$0$0$copyload4$i)) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $$cast$i1 = $11;
    $12 = ($$cast$i1|0)==($4|0);
    $13 = $11;
    if ($12) {
     break;
    } else {
     $$sroa$0$0$copyload4$i = $$cast$i1;$7 = $13;
    }
   }
   return;
  }
 } while(0);
 $14 = ($$sroa$0$0$copyload$i|0)==($4|0);
 if ($14) {
  return;
 }
 $15 = ((($$sroa$0$0$copyload$i)) + 4|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = HEAP32[$$sroa$0$0$copyload$i>>2]|0;
 $18 = ((($17)) + 4|0);
 HEAP32[$18>>2] = $16;
 $19 = HEAP32[$15>>2]|0;
 HEAP32[$19>>2] = $17;
 $20 = ((($0)) + 88|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($21) + -1)|0;
 HEAP32[$20>>2] = $22;
 $23 = ((($$sroa$0$0$copyload$i)) + 8|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)==(0|0);
 if (!($25)) {
  $26 = HEAP32[$24>>2]|0;
  $27 = ((($26)) + -16|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (($24) + ($28)|0);
  $30 = ((($29)) + 8|0);
  $31 = HEAP32[$30>>2]|0;HEAP32[$30>>2] = (($31-1)|0);
  $32 = ($31|0)==(1);
  if ($32) {
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($29,1,1);
  }
 }
 __ZdlPv($$sroa$0$0$copyload$i);
 return;
}
function __ZN9osgViewer4View5applyEPNS_10ViewConfigE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = ($1|0)==(0|0);
 if (!($3)) {
  $4 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
  do {
   if ($4) {
    $5 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
    $6 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($5,103415,33)|0);
    $7 = HEAP32[$1>>2]|0;
    $8 = ((($7)) + 28|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = (FUNCTION_TABLE_ii[$9 & 8191]($1)|0);
    $11 = (_strlen($10)|0);
    $12 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($6,$10,$11)|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = ((($13)) + -12|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = (($12) + ($15)|0);
    __ZNKSt3__28ios_base6getlocEv($2,$16);
    __THREW__ = 0;
    $17 = (invoke_iii(3255,($2|0),(215188|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     $20 = HEAP32[$17>>2]|0;
     $21 = ((($20)) + 28|0);
     $22 = HEAP32[$21>>2]|0;
     __THREW__ = 0;
     $23 = (invoke_iii($22|0,($17|0),10)|0);
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if (!($25)) {
      __ZNSt3__26localeD2Ev($2);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($12,$23)|0);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($12)|0);
      break;
     }
    }
    $26 = ___cxa_find_matching_catch_2()|0;
    $27 = tempRet0;
    __THREW__ = 0;
    invoke_vi(3263,($2|0));
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if ($29) {
     $30 = ___cxa_find_matching_catch_3(0|0)|0;
     $31 = tempRet0;
     ___clang_call_terminate($30);
     // unreachable;
    } else {
     ___resumeException($26|0);
     // unreachable;
    }
   }
  } while(0);
  $32 = HEAP32[$1>>2]|0;
  $33 = ((($32)) + 140|0);
  $34 = HEAP32[$33>>2]|0;
  FUNCTION_TABLE_vii[$34 & 8191]($1,$0);
 }
 $35 = ((($0)) + 128|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = ($36|0)==($1|0);
 if ($37) {
  STACKTOP = sp;return;
 }
 HEAP32[$35>>2] = $1;
 if (!($3)) {
  $38 = ((($1)) + 8|0);
  $39 = HEAP32[$38>>2]|0;HEAP32[$38>>2] = (($39+1)|0);
 }
 $40 = ($36|0)==(0|0);
 if ($40) {
  STACKTOP = sp;return;
 }
 $41 = ((($36)) + 8|0);
 $42 = HEAP32[$41>>2]|0;HEAP32[$41>>2] = (($42-1)|0);
 $43 = ($42|0)==(1);
 if (!($43)) {
  STACKTOP = sp;return;
 }
 __ZNK3osg10Referenced24signalObserversAndDeleteEbb($36,1,1);
 STACKTOP = sp;return;
}
function __ZN9osgViewer4View25setUpViewAcrossAllScreensEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(32)|0);
 __THREW__ = 0;
 invoke_vi(3282,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $7 = ___cxa_find_matching_catch_2()|0;
  $8 = tempRet0;
  __ZdlPv($1);
  ___resumeException($7|0);
  // unreachable;
 } else {
  $4 = ((($1)) + 12|0);
  ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;
  $5 = ((($1)) + 24|0);
  HEAP32[$5>>2] = 2;
  $6 = ((($1)) + 28|0);
  HEAP32[$6>>2] = 0;
  HEAP32[$1>>2] = (38880);
  __ZN9osgViewer4View5applyEPNS_10ViewConfigE($0,$1);
  return;
 }
}
function __ZN9osgViewer4View17setUpViewInWindowEiiiij($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $6 = (__Znwj(56)|0);
 __THREW__ = 0;
 invoke_vi(3282,($6|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $19 = ___cxa_find_matching_catch_2()|0;
  $20 = tempRet0;
  __ZdlPv($6);
  ___resumeException($19|0);
  // unreachable;
 } else {
  $9 = ((($6)) + 12|0);
  ;HEAP32[$9>>2]=0|0;HEAP32[$9+4>>2]=0|0;HEAP32[$9+8>>2]=0|0;
  $10 = ((($6)) + 24|0);
  HEAP32[$10>>2] = 2;
  $11 = ((($6)) + 28|0);
  HEAP32[$11>>2] = 0;
  HEAP32[$6>>2] = (38568);
  $12 = ((($6)) + 32|0);
  HEAP32[$12>>2] = $1;
  $13 = ((($6)) + 36|0);
  HEAP32[$13>>2] = $2;
  $14 = ((($6)) + 40|0);
  HEAP32[$14>>2] = $3;
  $15 = ((($6)) + 44|0);
  HEAP32[$15>>2] = $4;
  $16 = ((($6)) + 48|0);
  HEAP32[$16>>2] = $5;
  $17 = ((($6)) + 52|0);
  HEAP8[$17>>0] = 1;
  $18 = ((($6)) + 53|0);
  HEAP8[$18>>0] = 0;
  __ZN9osgViewer4View5applyEPNS_10ViewConfigE($0,$6);
  return;
 }
}
function __ZN9osgViewer4View23setUpViewOnSingleScreenEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(36)|0);
 __THREW__ = 0;
 invoke_vi(3282,($2|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $9 = ___cxa_find_matching_catch_2()|0;
  $10 = tempRet0;
  __ZdlPv($2);
  ___resumeException($9|0);
  // unreachable;
 } else {
  $5 = ((($2)) + 12|0);
  ;HEAP32[$5>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;
  $6 = ((($2)) + 24|0);
  HEAP32[$6>>2] = 2;
  $7 = ((($2)) + 28|0);
  HEAP32[$7>>2] = 0;
  HEAP32[$2>>2] = (38724);
  $8 = ((($2)) + 32|0);
  HEAP32[$8>>2] = $1;
  __ZN9osgViewer4View5applyEPNS_10ViewConfigE($0,$2);
  return;
 }
}
function __ZN9osgViewer4View23createDistortionTextureEii($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$04 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (__Znwj(272)|0);
 __THREW__ = 0;
 invoke_vi(3331,($3|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $24 = ___cxa_find_matching_catch_2()|0;
  $25 = tempRet0;
  __ZdlPv($3);
  $$0 = $25;$$04 = $24;
  ___resumeException($$04|0);
  // unreachable;
 }
 $6 = ((($3)) + 8|0);
 $7 = HEAP32[$6>>2]|0;HEAP32[$6>>2] = (($7+1)|0);
 $8 = ((($3)) + 244|0);
 HEAP32[$8>>2] = $1;
 $9 = ((($3)) + 248|0);
 HEAP32[$9>>2] = $2;
 $10 = ((($3)) + 164|0);
 HEAP32[$10>>2] = 1;
 $11 = ((($3)) + 172|0);
 HEAP32[$11>>2] = 6407;
 __THREW__ = 0;
 invoke_vi(3332,($3|0));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if (!($13)) {
  __THREW__ = 0;
  invoke_viii(3333,($3|0),0,9729);
  $14 = __THREW__; __THREW__ = 0;
  $15 = $14&1;
  if (!($15)) {
   __THREW__ = 0;
   invoke_viii(3333,($3|0),1,9729);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    __THREW__ = 0;
    invoke_viii(3334,($3|0),0,33071);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     __THREW__ = 0;
     invoke_viii(3334,($3|0),1,33071);
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if (!($21)) {
      __THREW__ = 0;
      (invoke_ii(3335,($3|0))|0);
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if (!($23)) {
       return ($3|0);
      }
     }
    }
   }
  }
 }
 $26 = ___cxa_find_matching_catch_2()|0;
 $27 = tempRet0;
 $28 = HEAP32[$6>>2]|0;HEAP32[$6>>2] = (($28-1)|0);
 $29 = ($28|0)==(1);
 if ($29) {
  __THREW__ = 0;
  invoke_viii(3262,($3|0),1,1);
  $30 = __THREW__; __THREW__ = 0;
  $31 = $30&1;
  if ($31) {
   $32 = ___cxa_find_matching_catch_3(0|0)|0;
   $33 = tempRet0;
   ___clang_call_terminate($32);
   // unreachable;
  }
 }
 $$0 = $27;$$04 = $26;
 ___resumeException($$04|0);
 // unreachable;
 return (0)|0;
}
function __ZN9osgViewer4View27assignRenderToTextureCameraEPN3osg15GraphicsContextEiiPNS1_7TextureE($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$1 = 0, $$17 = 0, $$2 = 0, $$28 = 0, $$3 = 0, $$39 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0.0, $22 = 0.0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 256|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(256|0);
 $5 = sp + 128|0;
 $6 = sp;
 $7 = (__Znwj(656)|0);
 __THREW__ = 0;
 invoke_vi(3336,($7|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $51 = ___cxa_find_matching_catch_2()|0;
  $52 = tempRet0;
  __ZdlPv($7);
  $$3 = $52;$$39 = $51;
  ___resumeException($$39|0);
  // unreachable;
 }
 $10 = ((($7)) + 8|0);
 $11 = HEAP32[$10>>2]|0;HEAP32[$10>>2] = (($11+1)|0);
 __THREW__ = 0;
 invoke_vii(3337,($7|0),(103449|0));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 do {
  if ($13) {
   label = 18;
  } else {
   __THREW__ = 0;
   invoke_vii(3338,($7|0),($1|0));
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if ($15) {
    label = 18;
   } else {
    __THREW__ = 0;
    $16 = (invoke_ii(3276,88)|0);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     label = 18;
    } else {
     __THREW__ = 0;
     invoke_vi(3339,($16|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      $55 = ___cxa_find_matching_catch_2()|0;
      $56 = tempRet0;
      __ZdlPv($16);
      $$2 = $56;$$28 = $55;
      break;
     }
     $21 = (+($3|0));
     $22 = (+($2|0));
     HEAP32[$16>>2] = (70172);
     $23 = ((($16)) + 56|0);
     $24 = ((($16)) + 72|0);
     ;HEAP32[$23>>2]=0|0;HEAP32[$23+4>>2]=0|0;HEAP32[$23+8>>2]=0|0;HEAP32[$23+12>>2]=0|0;
     HEAPF64[$24>>3] = $22;
     $25 = ((($16)) + 80|0);
     HEAPF64[$25>>3] = $21;
     __THREW__ = 0;
     invoke_vii(3340,($7|0),($16|0));
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      label = 18;
     } else {
      $28 = ((($7)) + 568|0);
      HEAP32[$28>>2] = 1028;
      $29 = ((($7)) + 152|0);
      $30 = HEAP32[$29>>2]|0;
      $31 = ($30|0)==(0);
      $32 = ((($7)) + 148|0);
      if ($31) {
       $34 = HEAP32[$32>>2]|0;
       $35 = $34 & -131073;
       HEAP32[$32>>2] = $35;
       $36 = ((($7)) + 572|0);
       HEAP32[$36>>2] = 1028;
       $37 = $34 & -393217;
       HEAP32[$32>>2] = $37;
      } else {
       $33 = ((($7)) + 572|0);
       HEAP32[$33>>2] = 1028;
      }
      $38 = ((($7)) + 228|0);
      HEAP8[$38>>0] = 0;
      __THREW__ = 0;
      invoke_vii(3341,($7|0),0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if ($40) {
       label = 18;
      } else {
       __THREW__ = 0;
       invoke_viiiiiiii(3342,($7|0),3,($4|0),0,0,0,0,0);
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if ($42) {
        label = 18;
       } else {
        __THREW__ = 0;
        invoke_vi(3299,($5|0));
        $43 = __THREW__; __THREW__ = 0;
        $44 = $43&1;
        if ($44) {
         $57 = ___cxa_find_matching_catch_2()|0;
         $58 = tempRet0;
         $$1 = $58;$$17 = $57;
        } else {
         __THREW__ = 0;
         invoke_vi(3299,($6|0));
         $45 = __THREW__; __THREW__ = 0;
         $46 = $45&1;
         if (!($46)) {
          __THREW__ = 0;
          (invoke_iiiiii(3343,($0|0),($7|0),($5|0),($6|0),1)|0);
          $47 = __THREW__; __THREW__ = 0;
          $48 = $47&1;
          if (!($48)) {
           __THREW__ = 0;
           (invoke_ii(3335,($7|0))|0);
           $49 = __THREW__; __THREW__ = 0;
           $50 = $49&1;
           if ($50) {
            label = 18;
            break;
           }
           STACKTOP = sp;return ($7|0);
          }
         }
         $59 = ___cxa_find_matching_catch_2()|0;
         $60 = tempRet0;
         $$1 = $60;$$17 = $59;
        }
        $$2 = $$1;$$28 = $$17;
       }
      }
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 18) {
  $53 = ___cxa_find_matching_catch_2()|0;
  $54 = tempRet0;
  $$2 = $54;$$28 = $53;
 }
 $61 = HEAP32[$10>>2]|0;HEAP32[$10>>2] = (($61-1)|0);
 $62 = ($61|0)==(1);
 if (!($62)) {
  $$3 = $$2;$$39 = $$28;
  ___resumeException($$39|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(3262,($7|0),1,1);
 $63 = __THREW__; __THREW__ = 0;
 $64 = $63&1;
 if ($64) {
  $65 = ___cxa_find_matching_catch_3(0|0)|0;
  $66 = tempRet0;
  ___clang_call_terminate($65);
  // unreachable;
 } else {
  $$3 = $$2;$$39 = $$28;
  ___resumeException($$39|0);
  // unreachable;
 }
 return (0)|0;
}
function __ZN3osg6Object7setNameEPKc($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$016$i$i = 0, $$017$i$i = 0, $$04 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $2 = sp + 12|0;
 $3 = sp;
 $4 = ($1|0)==(0|0);
 $5 = HEAP32[$0>>2]|0;
 $6 = ((($5)) + 112|0);
 $7 = HEAP32[$6>>2]|0;
 if ($4) {
  ;HEAP32[$3>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;
  __THREW__ = 0;
  invoke_vii($7|0,($0|0),($3|0));
  $33 = __THREW__; __THREW__ = 0;
  $34 = $33&1;
  if ($34) {
   $39 = ___cxa_find_matching_catch_2()|0;
   $40 = tempRet0;
   $41 = ((($3)) + 11|0);
   $42 = HEAP8[$41>>0]|0;
   $43 = ($42<<24>>24)<(0);
   if ($43) {
    $44 = HEAP32[$3>>2]|0;
    __ZdlPv($44);
   }
   $$0 = $40;$$04 = $39;
   ___resumeException($$04|0);
   // unreachable;
  } else {
   $35 = ((($3)) + 11|0);
   $36 = HEAP8[$35>>0]|0;
   $37 = ($36<<24>>24)<(0);
   if ($37) {
    $38 = HEAP32[$3>>2]|0;
    __ZdlPv($38);
   }
   STACKTOP = sp;return;
  }
 }
 ;HEAP32[$2>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;
 $8 = (_strlen($1)|0);
 $9 = ($8>>>0)>(4294967279);
 if ($9) {
  __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv($2);
  // unreachable;
 }
 $10 = ($8>>>0)<(11);
 if ($10) {
  $17 = $8&255;
  $18 = ((($2)) + 11|0);
  HEAP8[$18>>0] = $17;
  $19 = ($8|0)==(0);
  if ($19) {
   $$017$i$i = $2;
  } else {
   $$016$i$i = $2;
   label = 7;
  }
 } else {
  $11 = (($8) + 16)|0;
  $12 = $11 & -16;
  $13 = (__Znwj($12)|0);
  HEAP32[$2>>2] = $13;
  $14 = $12 | -2147483648;
  $15 = ((($2)) + 8|0);
  HEAP32[$15>>2] = $14;
  $16 = ((($2)) + 4|0);
  HEAP32[$16>>2] = $8;
  $$016$i$i = $13;
  label = 7;
 }
 if ((label|0) == 7) {
  _memcpy(($$016$i$i|0),($1|0),($8|0))|0;
  $$017$i$i = $$016$i$i;
 }
 $20 = (($$017$i$i) + ($8)|0);
 HEAP8[$20>>0] = 0;
 __THREW__ = 0;
 invoke_vii($7|0,($0|0),($2|0));
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if ($22) {
  $27 = ___cxa_find_matching_catch_2()|0;
  $28 = tempRet0;
  $29 = ((($2)) + 11|0);
  $30 = HEAP8[$29>>0]|0;
  $31 = ($30<<24>>24)<(0);
  if ($31) {
   $32 = HEAP32[$2>>2]|0;
   __ZdlPv($32);
  }
  $$0 = $28;$$04 = $27;
  ___resumeException($$04|0);
  // unreachable;
 } else {
  $23 = ((($2)) + 11|0);
  $24 = HEAP8[$23>>0]|0;
  $25 = ($24<<24>>24)<(0);
  if ($25) {
   $26 = HEAP32[$2>>2]|0;
   __ZdlPv($26);
  }
  STACKTOP = sp;return;
 }
}
function __ZN9osgViewer4View30assignKeystoneDistortionCameraEPN3osg15DisplaySettingsEPNS1_15GraphicsContextEiiiijPNS1_7TextureEPNS_8KeystoneE($0,$1,$2,$3,$4,$5,$6,$7,$8,$9) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 $8 = $8|0;
 $9 = $9|0;
 var $$2 = 0, $$253 = 0, $$3 = 0, $$354 = 0, $$5 = 0, $$556 = 0, $$sroa$0$0$$sroa_idx = 0, $$sroa$4$0$$sroa_idx68 = 0, $$sroa$5$0$$sroa_idx70 = 0, $$sroa$6$0$$sroa_idx72 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0.0, $103 = 0, $104 = 0, $105 = 0.0, $106 = 0, $107 = 0, $108 = 0.0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0.0, $112 = 0, $113 = 0, $114 = 0.0, $115 = 0, $116 = 0, $117 = 0.0, $118 = 0, $119 = 0, $12 = 0, $120 = 0.0, $121 = 0, $122 = 0, $123 = 0.0, $124 = 0, $125 = 0, $126 = 0.0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0.0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0.0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0;
 var $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0.0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $18 = 0.0, $19 = 0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0.0;
 var $25 = 0.0, $26 = 0.0, $27 = 0.0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0.0, $56 = 0.0, $57 = 0.0, $58 = 0.0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0.0, $82 = 0, $83 = 0, $84 = 0.0;
 var $85 = 0, $86 = 0, $87 = 0.0, $88 = 0, $89 = 0, $90 = 0.0, $91 = 0, $92 = 0, $93 = 0.0, $94 = 0, $95 = 0, $96 = 0.0, $97 = 0, $98 = 0, $99 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 384|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(384|0);
 $10 = sp + 256|0;
 $11 = sp + 128|0;
 $12 = sp;
 $13 = ((($1)) + 36|0);
 $14 = +HEAPF32[$13>>2];
 $15 = $14;
 $16 = ((($1)) + 28|0);
 $17 = +HEAPF32[$16>>2];
 $18 = $17;
 $19 = ((($1)) + 32|0);
 $20 = +HEAPF32[$19>>2];
 $21 = $20;
 $22 = $21 * 0.5;
 $23 = (+Math_atan2((+$22),(+$15)));
 $24 = $23 * 2.0;
 $25 = $24 * 180.0;
 $26 = $25 / 3.1415926535897931;
 $27 = $18 / $21;
 $28 = (__ZN9osgViewer8Keystone28createKeystoneDistortionMeshEv($9)|0);
 $29 = (__ZN3osg4Node19getOrCreateStateSetEv($28)|0);
 __ZN3osg8StateSet27setTextureAttributeAndModesEjPNS_14StateAttributeEj($29,0,$8,1);
 __ZN3osg8StateSet7setModeEjj($29,2896,0);
 $30 = (__Znwj(192)|0);
 __THREW__ = 0;
 invoke_vi(3344,($30|0));
 $31 = __THREW__; __THREW__ = 0;
 $32 = $31&1;
 if ($32) {
  $155 = ___cxa_find_matching_catch_2()|0;
  $156 = tempRet0;
  __ZdlPv($30);
  $$5 = $156;$$556 = $155;
  ___resumeException($$556|0);
  // unreachable;
 }
 $33 = ((($30)) + 184|0);
 HEAP8[$33>>0] = 1;
 __ZN3osg8StateSet27setTextureAttributeAndModesEjPNS_14StateAttributeEj($29,0,$30,1);
 $34 = (__Znwj(656)|0);
 __THREW__ = 0;
 invoke_vi(3336,($34|0));
 $35 = __THREW__; __THREW__ = 0;
 $36 = $35&1;
 if ($36) {
  $157 = ___cxa_find_matching_catch_2()|0;
  $158 = tempRet0;
  __ZdlPv($34);
  $$5 = $158;$$556 = $157;
  ___resumeException($$556|0);
  // unreachable;
 }
 $37 = ((($34)) + 8|0);
 $38 = HEAP32[$37>>2]|0;HEAP32[$37>>2] = (($38+1)|0);
 __THREW__ = 0;
 invoke_vii(3338,($34|0),($2|0));
 $39 = __THREW__; __THREW__ = 0;
 $40 = $39&1;
 L9: do {
  if ($40) {
   label = 30;
  } else {
   $41 = ((($34)) + 236|0);
   HEAP32[$41>>2] = 16640;
   $42 = ((($34)) + 152|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = ($43|0)==(0);
   $45 = ((($34)) + 148|0);
   if ($44) {
    $46 = HEAP32[$45>>2]|0;
    $47 = $46 & -16385;
    HEAP32[$45>>2] = $47;
   }
   $$sroa$0$0$$sroa_idx = ((($34)) + 240|0);
   HEAPF32[$$sroa$0$0$$sroa_idx>>2] = 0.0;
   $$sroa$4$0$$sroa_idx68 = ((($34)) + 244|0);
   HEAPF32[$$sroa$4$0$$sroa_idx68>>2] = 0.0;
   $$sroa$5$0$$sroa_idx70 = ((($34)) + 248|0);
   HEAPF32[$$sroa$5$0$$sroa_idx70>>2] = 0.0;
   $$sroa$6$0$$sroa_idx72 = ((($34)) + 252|0);
   HEAPF32[$$sroa$6$0$$sroa_idx72>>2] = 1.0;
   if ($44) {
    $48 = HEAP32[$45>>2]|0;
    $49 = $48 & -8193;
    HEAP32[$45>>2] = $49;
   }
   __THREW__ = 0;
   $50 = (invoke_ii(3276,88)|0);
   $51 = __THREW__; __THREW__ = 0;
   $52 = $51&1;
   if ($52) {
    label = 30;
   } else {
    __THREW__ = 0;
    invoke_vi(3339,($50|0));
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if ($54) {
     $161 = ___cxa_find_matching_catch_2()|0;
     $162 = tempRet0;
     __ZdlPv($50);
     $$3 = $162;$$354 = $161;
     break;
    }
    $55 = (+($6|0));
    $56 = (+($5|0));
    $57 = (+($4|0));
    $58 = (+($3|0));
    HEAP32[$50>>2] = (70172);
    $59 = ((($50)) + 56|0);
    HEAPF64[$59>>3] = $58;
    $60 = ((($50)) + 64|0);
    HEAPF64[$60>>3] = $57;
    $61 = ((($50)) + 72|0);
    HEAPF64[$61>>3] = $56;
    $62 = ((($50)) + 80|0);
    HEAPF64[$62>>3] = $55;
    __THREW__ = 0;
    invoke_vii(3340,($34|0),($50|0));
    $63 = __THREW__; __THREW__ = 0;
    $64 = $63&1;
    if ($64) {
     label = 30;
    } else {
     $65 = ((($34)) + 568|0);
     HEAP32[$65>>2] = $7;
     $66 = HEAP32[$42>>2]|0;
     $67 = ($66|0)==(0);
     if ($67) {
      $69 = HEAP32[$45>>2]|0;
      $70 = $69 & -131073;
      HEAP32[$45>>2] = $70;
      $71 = ((($34)) + 572|0);
      HEAP32[$71>>2] = $7;
      $72 = $69 & -393217;
      HEAP32[$45>>2] = $72;
     } else {
      $68 = ((($34)) + 572|0);
      HEAP32[$68>>2] = $7;
     }
     __THREW__ = 0;
     invoke_vii(3345,($34|0),1);
     $73 = __THREW__; __THREW__ = 0;
     $74 = $73&1;
     if ($74) {
      label = 30;
     } else {
      $75 = HEAP32[$45>>2]|0;
      $76 = $75 & -8194;
      HEAP32[$45>>2] = $76;
      __THREW__ = 0;
      invoke_vi(3299,($10|0));
      $77 = __THREW__; __THREW__ = 0;
      $78 = $77&1;
      if (!($78)) {
       __THREW__ = 0;
       invoke_vi(3299,($10|0));
       $79 = __THREW__; __THREW__ = 0;
       $80 = $79&1;
       if (!($80)) {
        $81 = +HEAPF64[$10>>3];
        $82 = ((($34)) + 432|0);
        HEAPF64[$82>>3] = $81;
        $83 = ((($10)) + 8|0);
        $84 = +HEAPF64[$83>>3];
        $85 = ((($34)) + 440|0);
        HEAPF64[$85>>3] = $84;
        $86 = ((($10)) + 16|0);
        $87 = +HEAPF64[$86>>3];
        $88 = ((($34)) + 448|0);
        HEAPF64[$88>>3] = $87;
        $89 = ((($10)) + 24|0);
        $90 = +HEAPF64[$89>>3];
        $91 = ((($34)) + 456|0);
        HEAPF64[$91>>3] = $90;
        $92 = ((($10)) + 32|0);
        $93 = +HEAPF64[$92>>3];
        $94 = ((($34)) + 464|0);
        HEAPF64[$94>>3] = $93;
        $95 = ((($10)) + 40|0);
        $96 = +HEAPF64[$95>>3];
        $97 = ((($34)) + 472|0);
        HEAPF64[$97>>3] = $96;
        $98 = ((($10)) + 48|0);
        $99 = +HEAPF64[$98>>3];
        $100 = ((($34)) + 480|0);
        HEAPF64[$100>>3] = $99;
        $101 = ((($10)) + 56|0);
        $102 = +HEAPF64[$101>>3];
        $103 = ((($34)) + 488|0);
        HEAPF64[$103>>3] = $102;
        $104 = ((($10)) + 64|0);
        $105 = +HEAPF64[$104>>3];
        $106 = ((($34)) + 496|0);
        HEAPF64[$106>>3] = $105;
        $107 = ((($10)) + 72|0);
        $108 = +HEAPF64[$107>>3];
        $109 = ((($34)) + 504|0);
        HEAPF64[$109>>3] = $108;
        $110 = ((($10)) + 80|0);
        $111 = +HEAPF64[$110>>3];
        $112 = ((($34)) + 512|0);
        HEAPF64[$112>>3] = $111;
        $113 = ((($10)) + 88|0);
        $114 = +HEAPF64[$113>>3];
        $115 = ((($34)) + 520|0);
        HEAPF64[$115>>3] = $114;
        $116 = ((($10)) + 96|0);
        $117 = +HEAPF64[$116>>3];
        $118 = ((($34)) + 528|0);
        HEAPF64[$118>>3] = $117;
        $119 = ((($10)) + 104|0);
        $120 = +HEAPF64[$119>>3];
        $121 = ((($34)) + 536|0);
        HEAPF64[$121>>3] = $120;
        $122 = ((($10)) + 112|0);
        $123 = +HEAPF64[$122>>3];
        $124 = ((($34)) + 544|0);
        HEAPF64[$124>>3] = $123;
        $125 = ((($10)) + 120|0);
        $126 = +HEAPF64[$125>>3];
        $127 = ((($34)) + 552|0);
        HEAPF64[$127>>3] = $126;
        __THREW__ = 0;
        invoke_vi(3323,($34|0));
        $128 = __THREW__; __THREW__ = 0;
        $129 = $128&1;
        if (!($129)) {
         __THREW__ = 0;
         invoke_vidddd(3346,($34|0),(+$26),(+$27),0.10000000000000001,1000.0);
         $130 = __THREW__; __THREW__ = 0;
         $131 = $130&1;
         if ($131) {
          label = 30;
          break;
         }
         $132 = HEAP32[$34>>2]|0;
         $133 = ((($132)) + 204|0);
         $134 = HEAP32[$133>>2]|0;
         __THREW__ = 0;
         (invoke_iii($134|0,($34|0),($28|0))|0);
         $135 = __THREW__; __THREW__ = 0;
         $136 = $135&1;
         if ($136) {
          label = 30;
          break;
         }
         $137 = HEAP32[$34>>2]|0;
         $138 = ((($137)) + 204|0);
         $139 = HEAP32[$138>>2]|0;
         __THREW__ = 0;
         $140 = (invoke_ii(3347,($9|0))|0);
         $141 = __THREW__; __THREW__ = 0;
         $142 = $141&1;
         if ($142) {
          label = 30;
          break;
         }
         __THREW__ = 0;
         (invoke_iii($139|0,($34|0),($140|0))|0);
         $143 = __THREW__; __THREW__ = 0;
         $144 = $143&1;
         if ($144) {
          label = 30;
          break;
         }
         __THREW__ = 0;
         invoke_vii(3337,($34|0),(103474|0));
         $145 = __THREW__; __THREW__ = 0;
         $146 = $145&1;
         if ($146) {
          label = 30;
          break;
         }
         __THREW__ = 0;
         invoke_vi(3299,($11|0));
         $147 = __THREW__; __THREW__ = 0;
         $148 = $147&1;
         if ($148) {
          $165 = ___cxa_find_matching_catch_2()|0;
          $166 = tempRet0;
          $$2 = $166;$$253 = $165;
         } else {
          __THREW__ = 0;
          invoke_vi(3299,($12|0));
          $149 = __THREW__; __THREW__ = 0;
          $150 = $149&1;
          do {
           if (!($150)) {
            __THREW__ = 0;
            (invoke_iiiiii(3343,($0|0),($34|0),($11|0),($12|0),0)|0);
            $151 = __THREW__; __THREW__ = 0;
            $152 = $151&1;
            if ($152) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(3335,($34|0))|0);
            $153 = __THREW__; __THREW__ = 0;
            $154 = $153&1;
            if ($154) {
             label = 30;
             break L9;
            }
            STACKTOP = sp;return ($34|0);
           }
          } while(0);
          $167 = ___cxa_find_matching_catch_2()|0;
          $168 = tempRet0;
          $$2 = $168;$$253 = $167;
         }
         $$3 = $$2;$$354 = $$253;
         break;
        }
       }
      }
      $163 = ___cxa_find_matching_catch_2()|0;
      $164 = tempRet0;
      $$3 = $164;$$354 = $163;
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 30) {
  $159 = ___cxa_find_matching_catch_2()|0;
  $160 = tempRet0;
  $$3 = $160;$$354 = $159;
 }
 $169 = HEAP32[$37>>2]|0;HEAP32[$37>>2] = (($169-1)|0);
 $170 = ($169|0)==(1);
 if (!($170)) {
  $$5 = $$3;$$556 = $$354;
  ___resumeException($$556|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(3262,($34|0),1,1);
 $171 = __THREW__; __THREW__ = 0;
 $172 = $171&1;
 if ($172) {
  $173 = ___cxa_find_matching_catch_3(0|0)|0;
  $174 = tempRet0;
  ___clang_call_terminate($173);
  // unreachable;
 } else {
  $$5 = $$3;$$556 = $$354;
  ___resumeException($$556|0);
  // unreachable;
 }
 return (0)|0;
}
function __ZN9osgViewer4View18assignStereoCameraEPN3osg15DisplaySettingsEPNS1_15GraphicsContextEiiiijd($0,$1,$2,$3,$4,$5,$6,$7,$8) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 $8 = +$8;
 var $$1 = 0, $$115 = 0, $$3 = 0, $$317 = 0, $$4 = 0, $$418 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0.0, $24 = 0.0, $25 = 0.0, $26 = 0.0, $27 = 0, $28 = 0, $29 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 256|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(256|0);
 $9 = sp + 128|0;
 $10 = sp;
 $11 = (__Znwj(656)|0);
 __THREW__ = 0;
 invoke_vi(3336,($11|0));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $93 = ___cxa_find_matching_catch_2()|0;
  $94 = tempRet0;
  __ZdlPv($11);
  $$4 = $93;$$418 = $94;
  ___resumeException($$4|0);
  // unreachable;
 }
 $14 = ((($11)) + 8|0);
 $15 = HEAP32[$14>>2]|0;HEAP32[$14>>2] = (($15+1)|0);
 __THREW__ = 0;
 invoke_vii(3338,($11|0),($2|0));
 $16 = __THREW__; __THREW__ = 0;
 $17 = $16&1;
 L5: do {
  if ($17) {
   label = 25;
  } else {
   __THREW__ = 0;
   $18 = (invoke_ii(3276,88)|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if ($20) {
    label = 25;
   } else {
    __THREW__ = 0;
    invoke_vi(3339,($18|0));
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if ($22) {
     $97 = ___cxa_find_matching_catch_2()|0;
     $98 = tempRet0;
     __ZdlPv($18);
     $$3 = $97;$$317 = $98;
     break;
    }
    $23 = (+($6|0));
    $24 = (+($5|0));
    $25 = (+($4|0));
    $26 = (+($3|0));
    HEAP32[$18>>2] = (70172);
    $27 = ((($18)) + 56|0);
    HEAPF64[$27>>3] = $26;
    $28 = ((($18)) + 64|0);
    HEAPF64[$28>>3] = $25;
    $29 = ((($18)) + 72|0);
    HEAPF64[$29>>3] = $24;
    $30 = ((($18)) + 80|0);
    HEAPF64[$30>>3] = $23;
    __THREW__ = 0;
    invoke_vii(3340,($11|0),($18|0));
    $31 = __THREW__; __THREW__ = 0;
    $32 = $31&1;
    if ($32) {
     label = 25;
    } else {
     $33 = ((($11)) + 568|0);
     HEAP32[$33>>2] = $7;
     $34 = ((($11)) + 152|0);
     $35 = HEAP32[$34>>2]|0;
     $36 = ($35|0)==(0);
     $37 = ((($11)) + 148|0);
     if ($36) {
      $39 = HEAP32[$37>>2]|0;
      $40 = $39 & -131073;
      HEAP32[$37>>2] = $40;
      $41 = ((($11)) + 572|0);
      HEAP32[$41>>2] = $7;
      $42 = $39 & -393217;
      HEAP32[$37>>2] = $42;
     } else {
      $38 = ((($11)) + 572|0);
      HEAP32[$38>>2] = $7;
     }
     __THREW__ = 0;
     invoke_vi(3299,($9|0));
     $43 = __THREW__; __THREW__ = 0;
     $44 = $43&1;
     if ($44) {
      label = 27;
     } else {
      __THREW__ = 0;
      invoke_vi(3299,($9|0));
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 27;
      } else {
       __THREW__ = 0;
       invoke_vi(3299,($10|0));
       $47 = __THREW__; __THREW__ = 0;
       $48 = $47&1;
       if (!($48)) {
        __THREW__ = 0;
        invoke_vi(3299,($10|0));
        $49 = __THREW__; __THREW__ = 0;
        $50 = $49&1;
        if (!($50)) {
         __THREW__ = 0;
         (invoke_iiiiii(3343,($0|0),($11|0),($9|0),($10|0),1)|0);
         $51 = __THREW__; __THREW__ = 0;
         $52 = $51&1;
         if (!($52)) {
          $53 = ((($0)) + 20|0);
          $54 = ((($0)) + 24|0);
          $55 = HEAP32[$54>>2]|0;
          $56 = HEAP32[$53>>2]|0;
          $57 = (($55) - ($56))|0;
          $58 = (($57|0) / 272)&-1;
          $59 = (($58) + -1)|0;
          $60 = $56;
          __THREW__ = 0;
          $61 = (invoke_ii(3276,32)|0);
          $62 = __THREW__; __THREW__ = 0;
          $63 = $62&1;
          L23: do {
           if (!($63)) {
            $64 = ((($61)) + 16|0);
            __THREW__ = 0;
            invoke_vi(3282,($64|0));
            $65 = __THREW__; __THREW__ = 0;
            $66 = $65&1;
            if ($66) {
             $105 = ___cxa_find_matching_catch_2()|0;
             $106 = tempRet0;
             __ZdlPv($61);
             $$3 = $105;$$317 = $106;
             break L5;
            }
            HEAP32[$61>>2] = (36024);
            HEAP32[$64>>2] = (36052);
            $67 = ((($61)) + 4|0);
            HEAP32[$67>>2] = $1;
            $68 = ($1|0)==(0|0);
            if (!($68)) {
             $69 = ((($1)) + 8|0);
             $70 = HEAP32[$69>>2]|0;HEAP32[$69>>2] = (($70+1)|0);
            }
            $71 = ((($61)) + 8|0);
            HEAPF64[$71>>3] = $8;
            $72 = (((($60) + (($59*272)|0)|0)) + 268|0);
            $73 = HEAP32[$72>>2]|0;
            $74 = ($73|0)==($61|0);
            do {
             if (!($74)) {
              HEAP32[$72>>2] = $61;
              $75 = HEAP32[$61>>2]|0;
              $76 = ((($75)) + -12|0);
              $77 = HEAP32[$76>>2]|0;
              $78 = (($61) + ($77)|0);
              $79 = ((($78)) + 8|0);
              $80 = HEAP32[$79>>2]|0;HEAP32[$79>>2] = (($80+1)|0);
              $81 = ($73|0)==(0|0);
              if ($81) {
               break;
              }
              $82 = HEAP32[$73>>2]|0;
              $83 = ((($82)) + -12|0);
              $84 = HEAP32[$83>>2]|0;
              $85 = (($73) + ($84)|0);
              $86 = ((($85)) + 8|0);
              $87 = HEAP32[$86>>2]|0;HEAP32[$86>>2] = (($87-1)|0);
              $88 = ($87|0)==(1);
              if (!($88)) {
               break;
              }
              __THREW__ = 0;
              invoke_viii(3262,($85|0),1,1);
              $89 = __THREW__; __THREW__ = 0;
              $90 = $89&1;
              if ($90) {
               break L23;
              }
             }
            } while(0);
            __THREW__ = 0;
            (invoke_ii(3335,($11|0))|0);
            $91 = __THREW__; __THREW__ = 0;
            $92 = $91&1;
            if (!($92)) {
             STACKTOP = sp;return ($11|0);
            }
           }
          } while(0);
          $103 = ___cxa_find_matching_catch_2()|0;
          $104 = tempRet0;
          $$3 = $103;$$317 = $104;
          break;
         }
        }
       }
       $101 = ___cxa_find_matching_catch_2()|0;
       $102 = tempRet0;
       $$1 = $101;$$115 = $102;
      }
     }
     if ((label|0) == 27) {
      $99 = ___cxa_find_matching_catch_2()|0;
      $100 = tempRet0;
      $$1 = $99;$$115 = $100;
     }
     $$3 = $$1;$$317 = $$115;
    }
   }
  }
 } while(0);
 if ((label|0) == 25) {
  $95 = ___cxa_find_matching_catch_2()|0;
  $96 = tempRet0;
  $$3 = $95;$$317 = $96;
 }
 $107 = HEAP32[$14>>2]|0;HEAP32[$14>>2] = (($107-1)|0);
 $108 = ($107|0)==(1);
 if (!($108)) {
  $$4 = $$3;$$418 = $$317;
  ___resumeException($$4|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(3262,($11|0),1,1);
 $109 = __THREW__; __THREW__ = 0;
 $110 = $109&1;
 if ($110) {
  $111 = ___cxa_find_matching_catch_3(0|0)|0;
  $112 = tempRet0;
  ___clang_call_terminate($111);
  // unreachable;
 } else {
  $$4 = $$3;$$418 = $$317;
  ___resumeException($$4|0);
  // unreachable;
 }
 return (0)|0;
}
function __ZN9osgViewer4View30assignStereoOrKeystoneToCameraEPN3osg6CameraEPNS1_15DisplaySettingsE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$ = 0, $$0 = 0, $$0108 = 0, $$1 = 0, $$10 = 0, $$10118 = 0, $$102 = 0, $$102210 = 0, $$104 = 0, $$104212 = 0, $$105 = 0, $$105213 = 0, $$108 = 0, $$108216 = 0, $$1109 = 0, $$1155 = 0, $$1156 = 0, $$1157 = 0, $$12 = 0, $$12120 = 0;
 var $$14 = 0, $$14122 = 0, $$15 = 0, $$15123 = 0, $$18 = 0, $$18126 = 0, $$2 = 0, $$20 = 0, $$20128 = 0, $$2110 = 0, $$22 = 0, $$22130 = 0, $$24 = 0, $$24132 = 0, $$26 = 0, $$26134 = 0, $$32 = 0, $$32140 = 0, $$34 = 0, $$34142 = 0;
 var $$36 = 0, $$36144 = 0, $$38 = 0, $$38146 = 0, $$4 = 0, $$40 = 0, $$40148 = 0, $$4112 = 0, $$42 = 0, $$42150 = 0, $$44 = 0, $$44152 = 0, $$46 = 0, $$46154 = 0, $$47 = 0, $$47155 = 0, $$49 = 0, $$49157 = 0, $$52 = 0, $$52160 = 0;
 var $$55 = 0, $$55163 = 0, $$57 = 0, $$57165 = 0, $$59 = 0, $$59167 = 0, $$6 = 0, $$61 = 0, $$6114 = 0, $$61169 = 0, $$63 = 0, $$63171 = 0, $$64 = 0, $$64172 = 0, $$66 = 0, $$66174 = 0, $$69 = 0, $$69177 = 0, $$72 = 0, $$72180 = 0;
 var $$74 = 0, $$74182 = 0, $$76 = 0, $$76184 = 0, $$77 = 0, $$77185 = 0, $$8 = 0, $$80 = 0, $$80188 = 0, $$8116 = 0, $$82 = 0, $$82190 = 0, $$84 = 0, $$84192 = 0, $$85 = 0, $$85193 = 0, $$88 = 0, $$88196 = 0, $$90 = 0, $$90198 = 0;
 var $$92 = 0, $$92200 = 0, $$94 = 0, $$94202 = 0, $$96 = 0, $$96204 = 0, $$99 = 0, $$99207 = 0, $$pr$pre = 0, $$pre$i = 0, $$pre$i221 = 0, $$pre$i237 = 0, $$pre$i247 = 0, $$pre1190 = 0, $$pre1192 = 0, $$pre1193 = 0, $$pre1194 = 0, $$sroa$01144$01177 = 0, $$sroa$0692$0$$sroa_idx = 0, $$sroa$0706$0$$sroa_idx = 0;
 var $$sroa$0771$0$$sroa_idx = 0, $$sroa$0788$0$$sroa_idx = 0, $$sroa$0922$0$$sroa_idx = 0, $$sroa$0988$0 = 0, $$sroa$0988$4 = 0, $$sroa$0988$5 = 0, $$sroa$4$0$$sroa_idx695 = 0, $$sroa$4708$0$$sroa_idx710 = 0, $$sroa$4773$0$$sroa_idx775 = 0, $$sroa$4790$0$$sroa_idx792 = 0, $$sroa$4924$0$$sroa_idx926 = 0, $$sroa$5$0$$sroa_idx697 = 0, $$sroa$5711$0$$sroa_idx713 = 0, $$sroa$5776$0$$sroa_idx778 = 0, $$sroa$5793$0$$sroa_idx795 = 0, $$sroa$5927$0$$sroa_idx929 = 0, $$sroa$6$0$$sroa_idx699 = 0, $$sroa$6714$0$$sroa_idx716 = 0, $$sroa$6779$0$$sroa_idx781 = 0, $$sroa$6796$0$$sroa_idx798 = 0;
 var $$sroa$6930$0$$sroa_idx932 = 0, $$tr$i$i = 0, $$tr$i$i310 = 0, $$tr$i$i338 = 0, $$tr$i$i386 = 0, $$tr$i$i392 = 0, $$tr$i$i445 = 0, $$tr$i$i451 = 0, $$tr$i$i486 = 0, $$tr$i$i501 = 0, $10 = 0, $100 = 0, $1000 = 0, $1001 = 0, $1002 = 0, $1003 = 0, $1004 = 0, $1005 = 0, $1006 = 0, $1007 = 0;
 var $1008 = 0, $1009 = 0, $101 = 0, $1010 = 0, $1011 = 0, $1012 = 0, $1013 = 0, $1014 = 0, $1015 = 0, $1016 = 0, $1017 = 0, $1018 = 0, $1019 = 0, $102 = 0, $1020 = 0, $1021 = 0, $1022 = 0, $1023 = 0, $1024 = 0, $1025 = 0;
 var $1026 = 0, $1027 = 0, $1028 = 0, $1029 = 0, $103 = 0, $1030 = 0, $1031 = 0, $1032 = 0, $1033 = 0, $1034 = 0, $1035 = 0, $1036 = 0, $1037 = 0, $1038 = 0, $1039 = 0, $104 = 0, $1040 = 0, $1041 = 0, $1042 = 0, $1043 = 0;
 var $1044 = 0, $1045 = 0, $1046 = 0, $1047 = 0, $1048 = 0, $1049 = 0, $105 = 0, $1050 = 0, $1051 = 0, $1052 = 0, $1053 = 0, $1054 = 0, $1055 = 0, $1056 = 0, $1057 = 0, $1058 = 0, $1059 = 0, $106 = 0, $1060 = 0, $1061 = 0;
 var $1062 = 0, $1063 = 0, $1064 = 0, $1065 = 0, $1066 = 0, $1067 = 0, $1068 = 0, $1069 = 0, $107 = 0, $1070 = 0, $1071 = 0, $1072 = 0, $1073 = 0, $1074 = 0, $1075 = 0, $1076 = 0, $1077 = 0, $1078 = 0, $1079 = 0, $108 = 0;
 var $1080 = 0, $1081 = 0, $1082 = 0, $1083 = 0, $1084 = 0, $1085 = 0, $1086 = 0, $1087 = 0, $1088 = 0, $1089 = 0, $109 = 0, $1090 = 0, $1091 = 0, $1092 = 0, $1093 = 0, $1094 = 0, $1095 = 0, $1096 = 0, $1097 = 0, $1098 = 0;
 var $1099 = 0, $11 = 0, $110 = 0, $1100 = 0, $1101 = 0, $1102 = 0, $1103 = 0, $1104 = 0, $1105 = 0, $1106 = 0, $1107 = 0, $1108 = 0, $1109 = 0, $111 = 0, $1110 = 0, $1111 = 0, $1112 = 0, $1113 = 0, $1114 = 0, $1115 = 0;
 var $1116 = 0, $1117 = 0, $1118 = 0, $1119 = 0, $112 = 0, $1120 = 0, $1121 = 0, $1122 = 0, $1123 = 0, $1124 = 0, $1125 = 0, $1126 = 0, $1127 = 0, $1128 = 0, $1129 = 0, $113 = 0, $1130 = 0, $1131 = 0, $1132 = 0, $1133 = 0;
 var $1134 = 0, $1135 = 0, $1136 = 0, $1137 = 0, $1138 = 0, $1139 = 0, $114 = 0, $1140 = 0, $1141 = 0, $1142 = 0, $1143 = 0, $1144 = 0, $1145 = 0, $1146 = 0, $1147 = 0, $1148 = 0, $1149 = 0, $115 = 0, $1150 = 0, $1151 = 0;
 var $1152 = 0, $1153 = 0, $1154 = 0, $1155 = 0, $1156 = 0, $1157 = 0, $1158 = 0, $1159 = 0, $116 = 0, $1160 = 0, $1161 = 0, $1162 = 0, $1163 = 0, $1164 = 0, $1165 = 0, $1166 = 0, $1167 = 0, $1168 = 0, $1169 = 0, $117 = 0;
 var $1170 = 0, $1171 = 0, $1172 = 0, $1173 = 0, $1174 = 0, $1175 = 0, $1176 = 0, $1177 = 0, $1178 = 0, $1179 = 0, $118 = 0, $1180 = 0, $1181 = 0, $1182 = 0, $1183 = 0, $1184 = 0, $1185 = 0, $1186 = 0, $1187 = 0, $1188 = 0;
 var $1189 = 0, $119 = 0, $1190 = 0, $1191 = 0, $1192 = 0, $1193 = 0, $1194 = 0, $1195 = 0, $1196 = 0, $1197 = 0, $1198 = 0, $1199 = 0, $12 = 0, $120 = 0, $1200 = 0, $1201 = 0, $1202 = 0, $1203 = 0, $1204 = 0, $1205 = 0;
 var $1206 = 0, $1207 = 0, $1208 = 0, $1209 = 0, $121 = 0.0, $1210 = 0, $1211 = 0, $1212 = 0, $1213 = 0, $1214 = 0, $1215 = 0, $1216 = 0, $1217 = 0, $1218 = 0, $1219 = 0, $122 = 0.0, $1220 = 0, $1221 = 0, $1222 = 0, $1223 = 0;
 var $1224 = 0, $1225 = 0, $1226 = 0, $1227 = 0, $1228 = 0, $1229 = 0, $123 = 0, $1230 = 0, $1231 = 0, $1232 = 0, $1233 = 0, $1234 = 0, $1235 = 0, $1236 = 0, $1237 = 0, $1238 = 0, $1239 = 0, $124 = 0.0, $1240 = 0, $1241 = 0;
 var $1242 = 0, $1243 = 0, $1244 = 0, $1245 = 0, $1246 = 0, $1247 = 0, $1248 = 0, $1249 = 0, $125 = 0.0, $1250 = 0, $1251 = 0, $1252 = 0, $1253 = 0, $1254 = 0, $1255 = 0, $1256 = 0, $1257 = 0, $1258 = 0, $1259 = 0, $126 = 0;
 var $1260 = 0, $1261 = 0, $1262 = 0, $1263 = 0, $1264 = 0, $1265 = 0, $1266 = 0, $1267 = 0, $1268 = 0, $1269 = 0, $127 = 0.0, $1270 = 0, $1271 = 0, $1272 = 0, $1273 = 0, $1274 = 0, $1275 = 0, $1276 = 0, $1277 = 0, $1278 = 0;
 var $1279 = 0, $128 = 0.0, $1280 = 0, $1281 = 0, $1282 = 0, $1283 = 0, $1284 = 0, $1285 = 0, $1286 = 0, $1287 = 0, $1288 = 0, $1289 = 0, $129 = 0.0, $1290 = 0, $1291 = 0, $1292 = 0, $1293 = 0, $1294 = 0, $1295 = 0, $1296 = 0;
 var $1297 = 0, $1298 = 0, $1299 = 0, $13 = 0, $130 = 0.0, $1300 = 0, $1301 = 0, $1302 = 0, $1303 = 0, $1304 = 0, $1305 = 0, $1306 = 0, $1307 = 0, $1308 = 0, $1309 = 0, $131 = 0.0, $1310 = 0, $1311 = 0, $1312 = 0, $1313 = 0;
 var $1314 = 0, $1315 = 0, $1316 = 0, $1317 = 0, $1318 = 0, $1319 = 0, $132 = 0.0, $1320 = 0, $1321 = 0, $1322 = 0, $1323 = 0, $1324 = 0, $1325 = 0, $1326 = 0, $1327 = 0, $1328 = 0, $1329 = 0, $133 = 0.0, $1330 = 0, $1331 = 0;
 var $1332 = 0, $1333 = 0, $1334 = 0, $1335 = 0, $1336 = 0, $1337 = 0, $1338 = 0, $1339 = 0, $134 = 0.0, $1340 = 0, $1341 = 0, $1342 = 0, $1343 = 0, $1344 = 0, $1345 = 0, $1346 = 0, $1347 = 0, $1348 = 0, $1349 = 0, $135 = 0;
 var $1350 = 0, $1351 = 0, $1352 = 0, $1353 = 0, $1354 = 0, $1355 = 0, $1356 = 0, $1357 = 0, $1358 = 0, $1359 = 0, $136 = 0, $1360 = 0, $1361 = 0, $1362 = 0, $1363 = 0, $1364 = 0, $1365 = 0, $1366 = 0, $1367 = 0, $1368 = 0;
 var $1369 = 0, $137 = 0, $1370 = 0, $1371 = 0, $1372 = 0, $1373 = 0, $1374 = 0, $1375 = 0, $1376 = 0, $1377 = 0, $1378 = 0, $1379 = 0, $138 = 0, $1380 = 0, $1381 = 0, $1382 = 0, $1383 = 0, $1384 = 0, $1385 = 0, $1386 = 0;
 var $1387 = 0, $1388 = 0, $1389 = 0, $139 = 0, $1390 = 0, $1391 = 0, $1392 = 0, $1393 = 0, $1394 = 0, $1395 = 0, $1396 = 0, $1397 = 0, $1398 = 0, $1399 = 0, $14 = 0, $140 = 0, $1400 = 0, $1401 = 0, $1402 = 0, $1403 = 0;
 var $1404 = 0, $1405 = 0, $1406 = 0, $1407 = 0, $1408 = 0, $1409 = 0, $141 = 0, $1410 = 0, $1411 = 0, $1412 = 0, $1413 = 0, $1414 = 0, $1415 = 0, $1416 = 0, $1417 = 0, $1418 = 0, $1419 = 0, $142 = 0, $1420 = 0, $1421 = 0;
 var $1422 = 0, $1423 = 0, $1424 = 0, $1425 = 0, $1426 = 0, $1427 = 0, $1428 = 0, $1429 = 0, $143 = 0, $1430 = 0, $1431 = 0, $1432 = 0, $1433 = 0, $1434 = 0, $1435 = 0, $1436 = 0, $1437 = 0, $1438 = 0, $1439 = 0, $144 = 0;
 var $1440 = 0, $1441 = 0, $1442 = 0, $1443 = 0, $1444 = 0, $1445 = 0, $1446 = 0, $1447 = 0, $1448 = 0, $1449 = 0, $145 = 0, $1450 = 0, $1451 = 0, $1452 = 0, $1453 = 0, $1454 = 0, $1455 = 0, $1456 = 0, $1457 = 0, $1458 = 0;
 var $1459 = 0, $146 = 0, $1460 = 0, $1461 = 0, $1462 = 0, $1463 = 0, $1464 = 0, $1465 = 0, $1466 = 0, $1467 = 0, $1468 = 0, $1469 = 0, $147 = 0, $1470 = 0, $1471 = 0, $1472 = 0, $1473 = 0, $1474 = 0, $1475 = 0, $1476 = 0;
 var $1477 = 0, $1478 = 0, $1479 = 0, $148 = 0, $1480 = 0, $1481 = 0, $1482 = 0, $1483 = 0, $1484 = 0, $1485 = 0, $1486 = 0, $1487 = 0, $1488 = 0, $1489 = 0, $149 = 0, $1490 = 0, $1491 = 0, $1492 = 0, $1493 = 0, $1494 = 0;
 var $1495 = 0, $1496 = 0, $1497 = 0, $1498 = 0, $1499 = 0, $15 = 0, $150 = 0, $1500 = 0, $1501 = 0, $1502 = 0, $1503 = 0, $1504 = 0, $1505 = 0, $1506 = 0, $1507 = 0, $1508 = 0, $1509 = 0, $151 = 0, $1510 = 0, $1511 = 0;
 var $1512 = 0, $1513 = 0, $1514 = 0, $1515 = 0, $1516 = 0, $1517 = 0, $1518 = 0, $1519 = 0, $152 = 0, $1520 = 0, $1521 = 0, $1522 = 0, $1523 = 0, $1524 = 0, $1525 = 0, $1526 = 0, $1527 = 0, $1528 = 0, $1529 = 0, $153 = 0;
 var $1530 = 0, $1531 = 0, $1532 = 0, $1533 = 0, $1534 = 0, $1535 = 0, $1536 = 0, $1537 = 0, $1538 = 0, $1539 = 0, $154 = 0, $1540 = 0, $1541 = 0, $1542 = 0, $1543 = 0, $1544 = 0, $1545 = 0, $1546 = 0, $1547 = 0, $1548 = 0;
 var $1549 = 0, $155 = 0, $1550 = 0, $1551 = 0, $1552 = 0, $1553 = 0, $1554 = 0, $1555 = 0, $1556 = 0, $1557 = 0, $1558 = 0, $1559 = 0, $156 = 0, $1560 = 0, $1561 = 0, $1562 = 0, $1563 = 0, $1564 = 0, $1565 = 0, $1566 = 0;
 var $1567 = 0, $1568 = 0, $1569 = 0, $157 = 0, $1570 = 0, $1571 = 0, $1572 = 0, $1573 = 0, $1574 = 0, $1575 = 0, $1576 = 0, $1577 = 0, $1578 = 0, $1579 = 0, $158 = 0, $1580 = 0, $1581 = 0, $1582 = 0, $1583 = 0, $1584 = 0;
 var $1585 = 0, $1586 = 0, $1587 = 0, $1588 = 0, $1589 = 0, $159 = 0, $1590 = 0, $1591 = 0, $1592 = 0, $1593 = 0, $1594 = 0, $1595 = 0, $1596 = 0, $1597 = 0, $1598 = 0, $1599 = 0, $16 = 0, $160 = 0, $1600 = 0, $1601 = 0;
 var $1602 = 0, $1603 = 0, $1604 = 0, $1605 = 0, $1606 = 0, $1607 = 0, $1608 = 0, $1609 = 0, $161 = 0, $1610 = 0, $1611 = 0, $1612 = 0, $1613 = 0, $1614 = 0, $1615 = 0, $1616 = 0, $1617 = 0, $1618 = 0, $1619 = 0, $162 = 0;
 var $1620 = 0, $1621 = 0, $1622 = 0, $1623 = 0, $1624 = 0, $1625 = 0, $1626 = 0, $1627 = 0, $1628 = 0, $1629 = 0, $163 = 0, $1630 = 0, $1631 = 0, $1632 = 0, $1633 = 0, $1634 = 0, $1635 = 0, $1636 = 0, $1637 = 0, $1638 = 0;
 var $1639 = 0, $164 = 0, $1640 = 0, $1641 = 0, $1642 = 0, $1643 = 0, $1644 = 0, $1645 = 0, $1646 = 0, $1647 = 0, $1648 = 0, $1649 = 0, $165 = 0, $1650 = 0, $1651 = 0, $1652 = 0, $1653 = 0, $1654 = 0, $1655 = 0, $1656 = 0;
 var $1657 = 0, $1658 = 0, $1659 = 0, $166 = 0, $1660 = 0, $1661 = 0, $1662 = 0, $1663 = 0, $1664 = 0, $1665 = 0, $1666 = 0, $1667 = 0, $1668 = 0, $1669 = 0, $167 = 0, $1670 = 0, $1671 = 0, $1672 = 0, $1673 = 0, $1674 = 0;
 var $1675 = 0, $1676 = 0, $1677 = 0, $1678 = 0, $1679 = 0, $168 = 0, $1680 = 0, $1681 = 0, $1682 = 0, $1683 = 0, $1684 = 0, $1685 = 0, $1686 = 0, $1687 = 0, $1688 = 0, $1689 = 0, $169 = 0, $1690 = 0, $1691 = 0, $1692 = 0;
 var $1693 = 0, $1694 = 0, $1695 = 0, $1696 = 0, $1697 = 0, $1698 = 0, $1699 = 0, $17 = 0, $170 = 0, $1700 = 0, $1701 = 0, $1702 = 0, $1703 = 0, $1704 = 0, $1705 = 0, $1706 = 0, $1707 = 0, $1708 = 0, $1709 = 0, $171 = 0;
 var $1710 = 0, $1711 = 0, $1712 = 0, $1713 = 0, $1714 = 0, $1715 = 0, $1716 = 0, $1717 = 0, $1718 = 0, $1719 = 0, $172 = 0, $1720 = 0, $1721 = 0, $1722 = 0, $1723 = 0, $1724 = 0, $1725 = 0, $1726 = 0, $1727 = 0, $1728 = 0;
 var $1729 = 0, $173 = 0, $1730 = 0, $1731 = 0, $1732 = 0, $1733 = 0, $1734 = 0, $1735 = 0, $1736 = 0, $1737 = 0, $1738 = 0, $1739 = 0, $174 = 0, $1740 = 0, $1741 = 0, $1742 = 0, $1743 = 0, $1744 = 0, $1745 = 0, $1746 = 0;
 var $1747 = 0, $1748 = 0, $1749 = 0, $175 = 0, $1750 = 0, $1751 = 0, $1752 = 0, $1753 = 0, $1754 = 0, $1755 = 0, $1756 = 0, $1757 = 0, $1758 = 0, $1759 = 0, $176 = 0, $1760 = 0, $1761 = 0, $1762 = 0, $1763 = 0, $1764 = 0;
 var $1765 = 0, $1766 = 0, $1767 = 0, $1768 = 0, $1769 = 0, $177 = 0, $1770 = 0, $1771 = 0, $1772 = 0, $1773 = 0, $1774 = 0, $1775 = 0, $1776 = 0, $1777 = 0, $1778 = 0, $1779 = 0, $178 = 0, $1780 = 0, $1781 = 0, $1782 = 0;
 var $1783 = 0, $1784 = 0, $1785 = 0, $1786 = 0, $1787 = 0, $1788 = 0, $1789 = 0, $179 = 0, $1790 = 0, $1791 = 0, $1792 = 0, $1793 = 0, $1794 = 0, $1795 = 0, $1796 = 0, $1797 = 0, $1798 = 0, $1799 = 0, $18 = 0, $180 = 0;
 var $1800 = 0, $1801 = 0, $1802 = 0, $1803 = 0, $1804 = 0, $1805 = 0, $1806 = 0, $1807 = 0, $1808 = 0, $1809 = 0, $181 = 0, $1810 = 0, $1811 = 0, $1812 = 0, $1813 = 0, $1814 = 0, $1815 = 0, $1816 = 0, $1817 = 0, $1818 = 0;
 var $1819 = 0, $182 = 0, $1820 = 0, $1821 = 0, $1822 = 0, $1823 = 0, $1824 = 0, $1825 = 0, $1826 = 0, $1827 = 0, $1828 = 0, $1829 = 0, $183 = 0, $1830 = 0, $1831 = 0, $1832 = 0, $1833 = 0, $1834 = 0, $1835 = 0, $1836 = 0;
 var $1837 = 0, $1838 = 0, $1839 = 0, $184 = 0, $1840 = 0, $1841 = 0, $1842 = 0, $1843 = 0, $1844 = 0, $1845 = 0, $1846 = 0, $1847 = 0, $1848 = 0, $1849 = 0, $185 = 0, $1850 = 0, $1851 = 0, $1852 = 0, $1853 = 0, $1854 = 0;
 var $1855 = 0, $1856 = 0, $1857 = 0, $1858 = 0, $1859 = 0, $186 = 0, $1860 = 0, $1861 = 0, $1862 = 0, $1863 = 0, $1864 = 0, $1865 = 0, $1866 = 0, $1867 = 0, $1868 = 0, $1869 = 0, $187 = 0, $1870 = 0, $1871 = 0, $1872 = 0;
 var $1873 = 0, $1874 = 0, $1875 = 0, $1876 = 0, $1877 = 0, $1878 = 0, $1879 = 0, $188 = 0, $1880 = 0, $1881 = 0, $1882 = 0, $1883 = 0, $1884 = 0, $1885 = 0, $1886 = 0, $1887 = 0, $1888 = 0, $1889 = 0, $189 = 0, $1890 = 0;
 var $1891 = 0, $1892 = 0, $1893 = 0, $1894 = 0, $1895 = 0, $1896 = 0, $1897 = 0, $1898 = 0, $1899 = 0, $19 = 0, $190 = 0, $1900 = 0, $1901 = 0, $1902 = 0, $1903 = 0, $1904 = 0, $1905 = 0, $1906 = 0, $1907 = 0, $1908 = 0;
 var $1909 = 0, $191 = 0, $1910 = 0, $1911 = 0, $1912 = 0, $1913 = 0, $1914 = 0, $1915 = 0, $1916 = 0, $1917 = 0, $1918 = 0, $1919 = 0, $192 = 0, $1920 = 0, $1921 = 0, $1922 = 0, $1923 = 0, $1924 = 0, $1925 = 0, $1926 = 0;
 var $1927 = 0, $1928 = 0, $1929 = 0, $193 = 0, $1930 = 0, $1931 = 0, $1932 = 0, $1933 = 0, $1934 = 0, $1935 = 0, $1936 = 0, $1937 = 0, $1938 = 0, $1939 = 0, $194 = 0, $1940 = 0, $1941 = 0, $1942 = 0, $1943 = 0, $1944 = 0;
 var $1945 = 0, $1946 = 0, $1947 = 0, $1948 = 0, $1949 = 0, $195 = 0, $1950 = 0, $1951 = 0, $1952 = 0, $1953 = 0, $1954 = 0, $1955 = 0, $1956 = 0, $1957 = 0, $1958 = 0, $1959 = 0, $196 = 0, $1960 = 0, $1961 = 0, $1962 = 0;
 var $1963 = 0, $1964 = 0, $1965 = 0, $1966 = 0, $1967 = 0, $1968 = 0, $1969 = 0, $197 = 0, $1970 = 0, $1971 = 0, $1972 = 0, $1973 = 0, $1974 = 0, $1975 = 0, $1976 = 0, $1977 = 0, $1978 = 0, $1979 = 0, $198 = 0, $1980 = 0;
 var $1981 = 0, $1982 = 0, $1983 = 0, $1984 = 0, $1985 = 0, $1986 = 0, $1987 = 0, $1988 = 0, $1989 = 0, $199 = 0, $1990 = 0, $1991 = 0, $1992 = 0, $1993 = 0, $1994 = 0, $1995 = 0, $1996 = 0, $1997 = 0, $1998 = 0, $1999 = 0;
 var $20 = 0, $200 = 0, $2000 = 0, $2001 = 0, $2002 = 0, $2003 = 0, $2004 = 0, $2005 = 0, $2006 = 0, $2007 = 0, $2008 = 0, $2009 = 0, $201 = 0, $2010 = 0, $2011 = 0, $2012 = 0, $2013 = 0, $2014 = 0, $2015 = 0, $2016 = 0;
 var $2017 = 0, $2018 = 0, $2019 = 0, $202 = 0, $2020 = 0, $2021 = 0, $2022 = 0, $2023 = 0, $2024 = 0, $2025 = 0, $2026 = 0, $2027 = 0, $2028 = 0, $2029 = 0, $203 = 0, $2030 = 0, $2031 = 0, $2032 = 0, $2033 = 0, $2034 = 0;
 var $2035 = 0, $2036 = 0, $2037 = 0, $2038 = 0, $2039 = 0, $204 = 0, $2040 = 0, $2041 = 0, $2042 = 0, $2043 = 0, $2044 = 0, $2045 = 0, $2046 = 0, $2047 = 0, $2048 = 0, $2049 = 0, $205 = 0, $2050 = 0, $2051 = 0, $2052 = 0;
 var $2053 = 0, $2054 = 0, $2055 = 0, $2056 = 0, $2057 = 0, $2058 = 0, $2059 = 0, $206 = 0, $2060 = 0, $2061 = 0, $2062 = 0, $2063 = 0, $2064 = 0, $2065 = 0, $2066 = 0, $2067 = 0, $2068 = 0, $2069 = 0, $207 = 0, $2070 = 0;
 var $2071 = 0, $2072 = 0, $2073 = 0, $2074 = 0, $2075 = 0, $2076 = 0, $2077 = 0, $2078 = 0, $2079 = 0, $208 = 0, $2080 = 0, $2081 = 0, $2082 = 0, $2083 = 0, $2084 = 0, $2085 = 0, $2086 = 0, $2087 = 0, $2088 = 0, $2089 = 0;
 var $209 = 0, $2090 = 0, $2091 = 0, $2092 = 0, $2093 = 0, $2094 = 0, $2095 = 0, $2096 = 0, $2097 = 0, $2098 = 0, $2099 = 0, $21 = 0, $210 = 0, $2100 = 0, $2101 = 0, $2102 = 0, $2103 = 0, $2104 = 0, $2105 = 0, $2106 = 0;
 var $2107 = 0, $2108 = 0, $2109 = 0, $211 = 0, $2110 = 0, $2111 = 0, $2112 = 0, $2113 = 0, $2114 = 0, $2115 = 0, $2116 = 0, $2117 = 0, $2118 = 0, $2119 = 0, $212 = 0, $2120 = 0, $2121 = 0, $2122 = 0, $2123 = 0, $2124 = 0;
 var $2125 = 0, $2126 = 0, $2127 = 0, $2128 = 0, $2129 = 0, $213 = 0, $2130 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0;
 var $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0;
 var $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0;
 var $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0;
 var $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0;
 var $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0;
 var $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0;
 var $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0;
 var $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0;
 var $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0;
 var $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0;
 var $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0;
 var $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0;
 var $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0;
 var $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0;
 var $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0;
 var $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0;
 var $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0;
 var $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0;
 var $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0;
 var $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0;
 var $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0;
 var $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0;
 var $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0;
 var $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0;
 var $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0;
 var $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0;
 var $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0;
 var $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0;
 var $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0;
 var $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0;
 var $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0;
 var $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0;
 var $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0;
 var $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = 0, $834 = 0, $835 = 0, $836 = 0, $837 = 0, $838 = 0;
 var $839 = 0, $84 = 0, $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0, $850 = 0, $851 = 0, $852 = 0, $853 = 0, $854 = 0, $855 = 0, $856 = 0;
 var $857 = 0, $858 = 0, $859 = 0, $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0, $869 = 0, $87 = 0, $870 = 0, $871 = 0, $872 = 0, $873 = 0, $874 = 0;
 var $875 = 0, $876 = 0, $877 = 0, $878 = 0, $879 = 0, $88 = 0, $880 = 0, $881 = 0, $882 = 0, $883 = 0, $884 = 0, $885 = 0, $886 = 0, $887 = 0, $888 = 0, $889 = 0, $89 = 0, $890 = 0, $891 = 0, $892 = 0;
 var $893 = 0, $894 = 0, $895 = 0, $896 = 0, $897 = 0, $898 = 0, $899 = 0, $9 = 0, $90 = 0, $900 = 0, $901 = 0, $902 = 0, $903 = 0, $904 = 0, $905 = 0, $906 = 0, $907 = 0, $908 = 0, $909 = 0, $91 = 0;
 var $910 = 0, $911 = 0, $912 = 0, $913 = 0, $914 = 0, $915 = 0, $916 = 0, $917 = 0, $918 = 0, $919 = 0, $92 = 0, $920 = 0, $921 = 0, $922 = 0, $923 = 0, $924 = 0, $925 = 0, $926 = 0, $927 = 0, $928 = 0;
 var $929 = 0, $93 = 0, $930 = 0, $931 = 0, $932 = 0, $933 = 0, $934 = 0, $935 = 0, $936 = 0, $937 = 0, $938 = 0, $939 = 0, $94 = 0, $940 = 0, $941 = 0, $942 = 0, $943 = 0, $944 = 0, $945 = 0, $946 = 0;
 var $947 = 0, $948 = 0, $949 = 0, $95 = 0, $950 = 0, $951 = 0, $952 = 0, $953 = 0, $954 = 0, $955 = 0, $956 = 0, $957 = 0, $958 = 0, $959 = 0, $96 = 0, $960 = 0, $961 = 0, $962 = 0, $963 = 0, $964 = 0;
 var $965 = 0, $966 = 0, $967 = 0, $968 = 0, $969 = 0, $97 = 0, $970 = 0, $971 = 0, $972 = 0, $973 = 0, $974 = 0, $975 = 0, $976 = 0, $977 = 0, $978 = 0, $979 = 0, $98 = 0, $980 = 0, $981 = 0, $982 = 0;
 var $983 = 0, $984 = 0, $985 = 0, $986 = 0, $987 = 0, $988 = 0, $989 = 0, $99 = 0, $990 = 0, $991 = 0, $992 = 0, $993 = 0, $994 = 0, $995 = 0, $996 = 0, $997 = 0, $998 = 0, $999 = 0, $eh$lpad$body$index4Z2D = 0, $eh$lpad$body$indexZ2D = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 320|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(320|0);
 $3 = sp + 128|0;
 $4 = sp;
 $5 = sp + 300|0;
 $6 = sp + 296|0;
 $7 = sp + 292|0;
 $8 = sp + 280|0;
 $9 = sp + 268|0;
 $10 = sp + 256|0;
 $11 = ($1|0)==(0|0);
 if ($11) {
  STACKTOP = sp;return;
 }
 $12 = ((($1)) + 624|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  STACKTOP = sp;return;
 }
 $15 = ((($2)) + 16|0);
 $16 = HEAP8[$15>>0]|0;
 $17 = ($16<<24>>24)==(0);
 $18 = ((($2)) + 168|0);
 $19 = HEAP8[$18>>0]|0;
 if ($17) {
  $20 = ($19<<24>>24)==(0);
  if ($20) {
   STACKTOP = sp;return;
  } else {
   $24 = 1;
  }
 } else {
  $24 = $19;
 }
 $21 = ((($2)) + 94|0);
 HEAP8[$21>>0] = 0;
 HEAP32[$5>>2] = 0;
 $22 = ((($5)) + 4|0);
 HEAP32[$22>>2] = 0;
 $23 = ((($5)) + 8|0);
 HEAP32[$23>>2] = 0;
 $25 = ($24<<24>>24)==(0);
 L11: do {
  if ($25) {
   label = 47;
  } else {
   $26 = ((($2)) + 184|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = ((($2)) + 188|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = ($27|0)==($29|0);
   do {
    if (!($30)) {
     $31 = ((($5)) + 8|0);
     $$sroa$01144$01177 = $27;$2130 = $29;
     while(1) {
      $32 = HEAP32[$$sroa$01144$01177>>2]|0;
      $33 = ($32|0)==(0|0);
      if ($33) {
       $69 = $2130;
      } else {
       $34 = (___dynamic_cast($32,26112,4080,0)|0);
       $35 = ($34|0)==(0|0);
       if ($35) {
        $69 = $2130;
       } else {
        HEAP32[$6>>2] = $34;
        $36 = ((($34)) + 8|0);
        $37 = HEAP32[$36>>2]|0;HEAP32[$36>>2] = (($37+1)|0);
        $38 = HEAP32[$22>>2]|0;
        $39 = HEAP32[$31>>2]|0;
        $40 = ($38|0)==($39|0);
        if ($40) {
         __THREW__ = 0;
         invoke_vii(3348,($5|0),($6|0));
         $47 = __THREW__; __THREW__ = 0;
         $48 = $47&1;
         if ($48) {
          label = 20;
          break;
         }
        } else {
         $41 = HEAP32[$6>>2]|0;
         HEAP32[$38>>2] = $41;
         $42 = ($41|0)==(0|0);
         if ($42) {
          $46 = $38;
         } else {
          $43 = ((($41)) + 8|0);
          $44 = HEAP32[$43>>2]|0;HEAP32[$43>>2] = (($44+1)|0);
          $$pre$i237 = HEAP32[$22>>2]|0;
          $46 = $$pre$i237;
         }
         $45 = ((($46)) + 4|0);
         HEAP32[$22>>2] = $45;
        }
        $49 = HEAP32[$6>>2]|0;
        $50 = ($49|0)==(0|0);
        if (!($50)) {
         $51 = ((($49)) + 8|0);
         $52 = HEAP32[$51>>2]|0;HEAP32[$51>>2] = (($52-1)|0);
         $53 = ($52|0)==(1);
         if ($53) {
          __THREW__ = 0;
          invoke_viii(3262,($49|0),1,1);
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           label = 19;
           break;
          }
         }
        }
        $$pre1190 = HEAP32[$28>>2]|0;
        $69 = $$pre1190;
       }
      }
      $67 = ((($$sroa$01144$01177)) + 4|0);
      $68 = ($67|0)==($69|0);
      if ($68) {
       label = 26;
       break;
      } else {
       $$sroa$01144$01177 = $67;$2130 = $69;
      }
     }
     if ((label|0) == 19) {
      $56 = ___cxa_find_matching_catch_2()|0;
      $57 = tempRet0;
      $$0 = $56;$$0108 = $57;
     }
     else if ((label|0) == 20) {
      $58 = ___cxa_find_matching_catch_2()|0;
      $59 = tempRet0;
      $60 = HEAP32[$6>>2]|0;
      $61 = ($60|0)==(0|0);
      if (!($61)) {
       $62 = ((($60)) + 8|0);
       $63 = HEAP32[$62>>2]|0;HEAP32[$62>>2] = (($63-1)|0);
       $64 = ($63|0)==(1);
       if ($64) {
        __THREW__ = 0;
        invoke_viii(3262,($60|0),1,1);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         $2128 = ___cxa_find_matching_catch_3(0|0)|0;
         $2129 = tempRet0;
         ___clang_call_terminate($2128);
         // unreachable;
        }
       }
      }
      HEAP32[$6>>2] = 0;
      $$0 = $58;$$0108 = $59;
     }
     else if ((label|0) == 26) {
      $$pr$pre = HEAP8[$18>>0]|0;
      $70 = ($$pr$pre<<24>>24)==(0);
      if ($70) {
       label = 47;
       break L11;
      } else {
       break;
      }
     }
     $$108 = $$0;$$108216 = $$0108;
     break L11;
    }
   } while(0);
   $71 = HEAP32[$22>>2]|0;
   $72 = HEAP32[$5>>2]|0;
   $73 = (($71) - ($72))|0;
   $74 = $73 >> 2;
   $75 = ($74>>>0)<(2);
   if ($75) {
    $76 = ((($5)) + 8|0);
    while(1) {
     __THREW__ = 0;
     $77 = (invoke_ii(3276,120)|0);
     $78 = __THREW__; __THREW__ = 0;
     $79 = $78&1;
     if ($79) {
      label = 40;
      break;
     }
     __THREW__ = 0;
     invoke_vi(3349,($77|0));
     $80 = __THREW__; __THREW__ = 0;
     $81 = $80&1;
     if ($81) {
      label = 41;
      break;
     }
     HEAP32[$7>>2] = $77;
     $82 = ((($77)) + 8|0);
     $83 = HEAP32[$82>>2]|0;HEAP32[$82>>2] = (($83+1)|0);
     $84 = HEAP32[$22>>2]|0;
     $85 = HEAP32[$76>>2]|0;
     $86 = ($84|0)==($85|0);
     if ($86) {
      __THREW__ = 0;
      invoke_vii(3348,($5|0),($7|0));
      $93 = __THREW__; __THREW__ = 0;
      $94 = $93&1;
      if ($94) {
       label = 42;
       break;
      }
     } else {
      $87 = HEAP32[$7>>2]|0;
      HEAP32[$84>>2] = $87;
      $88 = ($87|0)==(0|0);
      if ($88) {
       $92 = $84;
      } else {
       $89 = ((($87)) + 8|0);
       $90 = HEAP32[$89>>2]|0;HEAP32[$89>>2] = (($90+1)|0);
       $$pre$i247 = HEAP32[$22>>2]|0;
       $92 = $$pre$i247;
      }
      $91 = ((($92)) + 4|0);
      HEAP32[$22>>2] = $91;
     }
     $95 = HEAP32[$7>>2]|0;
     $96 = ($95|0)==(0|0);
     if (!($96)) {
      $97 = ((($95)) + 8|0);
      $98 = HEAP32[$97>>2]|0;HEAP32[$97>>2] = (($98-1)|0);
      $99 = ($98|0)==(1);
      if ($99) {
       __THREW__ = 0;
       invoke_viii(3262,($95|0),1,1);
       $100 = __THREW__; __THREW__ = 0;
       $101 = $100&1;
       if ($101) {
        label = 40;
        break;
       }
      }
     }
     $102 = HEAP32[$22>>2]|0;
     $103 = HEAP32[$5>>2]|0;
     $104 = (($102) - ($103))|0;
     $105 = $104 >> 2;
     $106 = ($105>>>0)<(2);
     if (!($106)) {
      label = 47;
      break L11;
     }
    }
    if ((label|0) == 40) {
     $107 = ___cxa_find_matching_catch_2()|0;
     $108 = tempRet0;
     $$1 = $107;$$1109 = $108;
    }
    else if ((label|0) == 41) {
     $109 = ___cxa_find_matching_catch_2()|0;
     $110 = tempRet0;
     __ZdlPv($77);
     $$1 = $109;$$1109 = $110;
    }
    else if ((label|0) == 42) {
     $111 = ___cxa_find_matching_catch_2()|0;
     $112 = tempRet0;
     $113 = HEAP32[$7>>2]|0;
     $114 = ($113|0)==(0|0);
     if (!($114)) {
      $115 = ((($113)) + 8|0);
      $116 = HEAP32[$115>>2]|0;HEAP32[$115>>2] = (($116-1)|0);
      $117 = ($116|0)==(1);
      if ($117) {
       __THREW__ = 0;
       invoke_viii(3262,($113|0),1,1);
       $118 = __THREW__; __THREW__ = 0;
       $119 = $118&1;
       if ($119) {
        $2128 = ___cxa_find_matching_catch_3(0|0)|0;
        $2129 = tempRet0;
        ___clang_call_terminate($2128);
        // unreachable;
       }
      }
     }
     HEAP32[$7>>2] = 0;
     $$1 = $111;$$1109 = $112;
    }
    $$108 = $$1;$$108216 = $$1109;
   } else {
    label = 47;
   }
  }
 } while(0);
 L69: do {
  if ((label|0) == 47) {
   $120 = ((($2)) + 32|0);
   $121 = +HEAPF32[$120>>2];
   $122 = $121;
   $123 = ((($2)) + 28|0);
   $124 = +HEAPF32[$123>>2];
   $125 = $124;
   $126 = ((($2)) + 36|0);
   $127 = +HEAPF32[$126>>2];
   $128 = $127;
   $129 = $122 * 0.5;
   $130 = (+Math_atan2((+$129),(+$128)));
   $131 = $130 * 2.0;
   $132 = $131 * 180.0;
   $133 = $132 / 3.1415926535897931;
   $134 = $125 / $122;
   __THREW__ = 0;
   invoke_vidddd(3346,($1|0),(+$133),(+$134),1.0,1.0E+4);
   $135 = __THREW__; __THREW__ = 0;
   $136 = $135&1;
   if ($136) {
    $155 = ___cxa_find_matching_catch_2()|0;
    $156 = tempRet0;
    $$108 = $155;$$108216 = $156;
    break;
   }
   $137 = HEAP32[$12>>2]|0;
   $138 = ($137|0)==(0|0);
   $139 = ((($137)) + 8|0);
   $140 = HEAP32[$139>>2]|0;HEAP32[$139>>2] = (($140+1)|0);
   $$pre1192 = HEAP32[$12>>2]|0;
   $141 = ((($$pre1192)) + 44|0);
   $142 = HEAP32[$141>>2]|0;
   $143 = ($142|0)==(0|0);
   if (!($143)) {
    $144 = ((($142)) + 8|0);
    $145 = HEAP32[$144>>2]|0;HEAP32[$144>>2] = (($145+1)|0);
   }
   $146 = HEAP8[$15>>0]|0;
   $147 = ($146<<24>>24)==(0);
   L77: do {
    if ($147) {
     $148 = ((($2)) + 184|0);
     $149 = HEAP32[$148>>2]|0;
     $150 = ((($2)) + 188|0);
     $151 = HEAP32[$150>>2]|0;
     $152 = ($149|0)==($151|0);
     if ($152) {
      label = 58;
     } else {
      $153 = HEAP32[$149>>2]|0;
      $154 = ($153|0)==(0|0);
      if ($154) {
       label = 58;
      } else {
       $161 = (___dynamic_cast($153,26112,4080,0)|0);
       $162 = ($161|0)==(0|0);
       if ($162) {
        label = 58;
       } else {
        $163 = ((($161)) + 8|0);
        $164 = HEAP32[$163>>2]|0;HEAP32[$163>>2] = (($164+1)|0);
        $$sroa$0988$4 = $161;
        label = 62;
       }
      }
     }
     do {
      if ((label|0) == 58) {
       __THREW__ = 0;
       $165 = (invoke_ii(3276,120)|0);
       $166 = __THREW__; __THREW__ = 0;
       $167 = $166&1;
       if ($167) {
        $$sroa$0988$0 = 0;
        label = 55;
       } else {
        __THREW__ = 0;
        invoke_vi(3349,($165|0));
        $168 = __THREW__; __THREW__ = 0;
        $169 = $168&1;
        if ($169) {
         $172 = ___cxa_find_matching_catch_2()|0;
         $173 = tempRet0;
         __ZdlPv($165);
         $$104 = $172;$$104212 = $173;
         label = 806;
         break L77;
        } else {
         $170 = ((($165)) + 8|0);
         $171 = HEAP32[$170>>2]|0;HEAP32[$170>>2] = (($171+1)|0);
         $$sroa$0988$4 = $165;
         label = 62;
         break;
        }
       }
      }
     } while(0);
     L89: do {
      if ((label|0) == 62) {
       $174 = ((($142)) + 40|0);
       $175 = HEAP32[$174>>2]|0;
       $176 = ((($142)) + 44|0);
       $177 = HEAP32[$176>>2]|0;
       __THREW__ = 0;
       $178 = (invoke_iiii(3350,0,($175|0),($177|0))|0);
       $179 = __THREW__; __THREW__ = 0;
       $180 = $179&1;
       if ($180) {
        $$sroa$0988$0 = $$sroa$0988$4;
        label = 55;
       } else {
        $181 = ($178|0)==(0|0);
        if (!($181)) {
         $182 = ((($178)) + 8|0);
         $183 = HEAP32[$182>>2]|0;HEAP32[$182>>2] = (($183+1)|0);
        }
        $184 = HEAP32[$174>>2]|0;
        $185 = HEAP32[$176>>2]|0;
        __THREW__ = 0;
        (invoke_iiiiii(3351,($0|0),($137|0),($184|0),($185|0),($178|0))|0);
        $186 = __THREW__; __THREW__ = 0;
        $187 = $186&1;
        L95: do {
         if ($187) {
          label = 79;
         } else {
          $188 = HEAP32[$174>>2]|0;
          $189 = HEAP32[$176>>2]|0;
          $190 = ((($142)) + 110|0);
          $191 = HEAP8[$190>>0]|0;
          $192 = ($191<<24>>24)!=(0);
          $193 = $192 ? 1029 : 1028;
          __THREW__ = 0;
          $194 = (invoke_iiiiiiiiiii(3352,($0|0),($2|0),($137|0),0,0,($188|0),($189|0),($193|0),($178|0),($$sroa$0988$4|0))|0);
          $195 = __THREW__; __THREW__ = 0;
          $196 = $195&1;
          if ($196) {
           label = 79;
          } else {
           $197 = ($194|0)==(0|0);
           if (!($197)) {
            $198 = ((($194)) + 8|0);
            $199 = HEAP32[$198>>2]|0;HEAP32[$198>>2] = (($199+1)|0);
           }
           __THREW__ = 0;
           $200 = (invoke_ii(3276,152)|0);
           $201 = __THREW__; __THREW__ = 0;
           $202 = $201&1;
           do {
            if ($202) {
             label = 80;
            } else {
             __THREW__ = 0;
             invoke_vii(3353,($200|0),($$sroa$0988$4|0));
             $203 = __THREW__; __THREW__ = 0;
             $204 = $203&1;
             if ($204) {
              $234 = ___cxa_find_matching_catch_2()|0;
              $235 = tempRet0;
              __ZdlPv($200);
              $$2 = $234;$$2110 = $235;
              break;
             }
             $205 = HEAP32[$200>>2]|0;
             $206 = ((($205)) + -12|0);
             $207 = HEAP32[$206>>2]|0;
             $208 = (($200) + ($207)|0);
             $209 = ((($194)) + 92|0);
             $210 = HEAP32[$209>>2]|0;
             $211 = ($210|0)==(0|0);
             if ($211) {
              __THREW__ = 0;
              invoke_vii(3354,($194|0),($208|0));
              $221 = __THREW__; __THREW__ = 0;
              $222 = $221&1;
              if ($222) {
               label = 80;
               break;
              }
             } else {
              $$tr$i$i310 = $210;
              while(1) {
               $212 = ((($$tr$i$i310)) + 4|0);
               $213 = HEAP32[$212>>2]|0;
               $214 = ($213|0)==(0|0);
               if ($214) {
                break;
               } else {
                $$tr$i$i310 = $213;
               }
              }
              HEAP32[$212>>2] = $208;
              $215 = HEAP32[$208>>2]|0;
              $216 = ((($215)) + -12|0);
              $217 = HEAP32[$216>>2]|0;
              $218 = (($208) + ($217)|0);
              $219 = ((($218)) + 8|0);
              $220 = HEAP32[$219>>2]|0;HEAP32[$219>>2] = (($220+1)|0);
             }
             __THREW__ = 0;
             invoke_vii(3338,($1|0),(0|0));
             $223 = __THREW__; __THREW__ = 0;
             $224 = $223&1;
             if ($224) {
              label = 80;
              break;
             }
             do {
              if (!($197)) {
               $225 = ((($194)) + 8|0);
               $226 = HEAP32[$225>>2]|0;HEAP32[$225>>2] = (($226-1)|0);
               $227 = ($226|0)==(1);
               if (!($227)) {
                break;
               }
               __THREW__ = 0;
               invoke_viii(3262,($194|0),1,1);
               $228 = __THREW__; __THREW__ = 0;
               $229 = $228&1;
               if (!($229)) {
                break;
               }
               $241 = ___cxa_find_matching_catch_2()|0;
               $242 = tempRet0;
               $$4 = $241;$$4112 = $242;
               break L95;
              }
             } while(0);
             do {
              if (!($181)) {
               $236 = ((($178)) + 8|0);
               $237 = HEAP32[$236>>2]|0;HEAP32[$236>>2] = (($237-1)|0);
               $238 = ($237|0)==(1);
               if (!($238)) {
                break;
               }
               __THREW__ = 0;
               invoke_viii(3262,($178|0),1,1);
               $239 = __THREW__; __THREW__ = 0;
               $240 = $239&1;
               if (!($240)) {
                break;
               }
               $254 = ___cxa_find_matching_catch_2()|0;
               $255 = tempRet0;
               $$6 = $254;$$6114 = $255;$$sroa$0988$5 = $$sroa$0988$4;
               break L89;
              }
             } while(0);
             $248 = ($$sroa$0988$4|0)==(0|0);
             if ($248) {
              label = 788;
              break L77;
             }
             $249 = ((($$sroa$0988$4)) + 8|0);
             $250 = HEAP32[$249>>2]|0;HEAP32[$249>>2] = (($250-1)|0);
             $251 = ($250|0)==(1);
             if (!($251)) {
              label = 788;
              break L77;
             }
             __THREW__ = 0;
             invoke_viii(3262,($$sroa$0988$4|0),1,1);
             $252 = __THREW__; __THREW__ = 0;
             $253 = $252&1;
             if (!($253)) {
              label = 788;
              break L77;
             }
             $261 = ___cxa_find_matching_catch_2()|0;
             $262 = tempRet0;
             $$104 = $261;$$104212 = $262;
             label = 806;
             break L77;
            }
           } while(0);
           if ((label|0) == 80) {
            $232 = ___cxa_find_matching_catch_2()|0;
            $233 = tempRet0;
            $$2 = $232;$$2110 = $233;
           }
           if ($197) {
            $$4 = $$2;$$4112 = $$2110;
           } else {
            $243 = ((($194)) + 8|0);
            $244 = HEAP32[$243>>2]|0;HEAP32[$243>>2] = (($244-1)|0);
            $245 = ($244|0)==(1);
            if ($245) {
             __THREW__ = 0;
             invoke_viii(3262,($194|0),1,1);
             $246 = __THREW__; __THREW__ = 0;
             $247 = $246&1;
             if (!($247)) {
              $$4 = $$2;$$4112 = $$2110;
              break;
             }
             $2128 = ___cxa_find_matching_catch_3(0|0)|0;
             $2129 = tempRet0;
             ___clang_call_terminate($2128);
             // unreachable;
            } else {
             $$4 = $$2;$$4112 = $$2110;
            }
           }
          }
         }
        } while(0);
        if ((label|0) == 79) {
         $230 = ___cxa_find_matching_catch_2()|0;
         $231 = tempRet0;
         $$4 = $230;$$4112 = $231;
        }
        if ($181) {
         $$6 = $$4;$$6114 = $$4112;$$sroa$0988$5 = $$sroa$0988$4;
        } else {
         $256 = ((($178)) + 8|0);
         $257 = HEAP32[$256>>2]|0;HEAP32[$256>>2] = (($257-1)|0);
         $258 = ($257|0)==(1);
         if ($258) {
          __THREW__ = 0;
          invoke_viii(3262,($178|0),1,1);
          $259 = __THREW__; __THREW__ = 0;
          $260 = $259&1;
          if ($260) {
           $2128 = ___cxa_find_matching_catch_3(0|0)|0;
           $2129 = tempRet0;
           ___clang_call_terminate($2128);
           // unreachable;
          } else {
           $$6 = $$4;$$6114 = $$4112;$$sroa$0988$5 = $$sroa$0988$4;
          }
         } else {
          $$6 = $$4;$$6114 = $$4112;$$sroa$0988$5 = $$sroa$0988$4;
         }
        }
       }
      }
     } while(0);
     if ((label|0) == 55) {
      $159 = ___cxa_find_matching_catch_2()|0;
      $160 = tempRet0;
      $$6 = $159;$$6114 = $160;$$sroa$0988$5 = $$sroa$0988$0;
     }
     $263 = ($$sroa$0988$5|0)==(0|0);
     if ($263) {
      $$104 = $$6;$$104212 = $$6114;
      label = 806;
     } else {
      $264 = ((($$sroa$0988$5)) + 8|0);
      $265 = HEAP32[$264>>2]|0;HEAP32[$264>>2] = (($265-1)|0);
      $266 = ($265|0)==(1);
      if ($266) {
       __THREW__ = 0;
       invoke_viii(3262,($$sroa$0988$5|0),1,1);
       $267 = __THREW__; __THREW__ = 0;
       $268 = $267&1;
       if ($268) {
        $2128 = ___cxa_find_matching_catch_3(0|0)|0;
        $2129 = tempRet0;
        ___clang_call_terminate($2128);
        // unreachable;
       } else {
        $$104 = $$6;$$104212 = $$6114;
        label = 806;
       }
      } else {
       $$104 = $$6;$$104212 = $$6114;
       label = 806;
      }
     }
    } else {
     $269 = ((($2)) + 20|0);
     $270 = HEAP32[$269>>2]|0;
     L145: do {
      switch ($270|0) {
      case 0:  {
       __THREW__ = 0;
       invoke_vii(3338,($1|0),(0|0));
       $271 = __THREW__; __THREW__ = 0;
       $272 = $271&1;
       if (!($272)) {
        $273 = ((($142)) + 40|0);
        $274 = HEAP32[$273>>2]|0;
        $275 = ((($142)) + 44|0);
        $276 = HEAP32[$275>>2]|0;
        $277 = ((($142)) + 110|0);
        $278 = HEAP8[$277>>0]|0;
        $279 = ($278<<24>>24)!=(0);
        $280 = $279 ? 1026 : 1024;
        __THREW__ = 0;
        $281 = (invoke_iiiiiiiiid(3355,($0|0),($2|0),($137|0),0,0,($274|0),($276|0),($280|0),-1.0)|0);
        $282 = __THREW__; __THREW__ = 0;
        $283 = $282&1;
        if (!($283)) {
         $284 = ($281|0)==(0|0);
         if (!($284)) {
          $285 = ((($281)) + 8|0);
          $286 = HEAP32[$285>>2]|0;HEAP32[$285>>2] = (($286+1)|0);
         }
         $287 = ((($281)) + 236|0);
         HEAP32[$287>>2] = 16640;
         $288 = ((($281)) + 152|0);
         $289 = HEAP32[$288>>2]|0;
         $290 = ($289|0)==(0);
         $291 = ((($281)) + 148|0);
         if ($290) {
          $292 = HEAP32[$291>>2]|0;
          $293 = $292 & -16385;
          HEAP32[$291>>2] = $293;
         }
         $294 = ((($281)) + 560|0);
         HEAP32[$294>>2] = 1;
         $295 = ((($281)) + 564|0);
         HEAP32[$295>>2] = 0;
         $296 = HEAP32[$273>>2]|0;
         $297 = HEAP32[$275>>2]|0;
         $298 = HEAP8[$277>>0]|0;
         $299 = ($298<<24>>24)!=(0);
         $300 = $299 ? 1027 : 1025;
         __THREW__ = 0;
         $301 = (invoke_iiiiiiiiid(3355,($0|0),($2|0),($137|0),0,0,($296|0),($297|0),($300|0),1.0)|0);
         $302 = __THREW__; __THREW__ = 0;
         $303 = $302&1;
         L155: do {
          if ($303) {
           $447 = ___cxa_find_matching_catch_2()|0;
           $448 = tempRet0;
           $$18 = $447;$$18126 = $448;
          } else {
           $304 = ($301|0)==(0|0);
           if (!($304)) {
            $305 = ((($301)) + 8|0);
            $306 = HEAP32[$305>>2]|0;HEAP32[$305>>2] = (($306+1)|0);
           }
           $307 = ((($301)) + 236|0);
           HEAP32[$307>>2] = 16640;
           $308 = ((($301)) + 152|0);
           $309 = HEAP32[$308>>2]|0;
           $310 = ($309|0)==(0);
           $311 = ((($301)) + 148|0);
           if ($310) {
            $312 = HEAP32[$311>>2]|0;
            $313 = $312 & -16385;
            HEAP32[$311>>2] = $313;
           }
           $314 = ((($301)) + 560|0);
           HEAP32[$314>>2] = 1;
           $315 = ((($301)) + 564|0);
           HEAP32[$315>>2] = 1;
           $316 = HEAP32[$5>>2]|0;
           $317 = HEAP32[$22>>2]|0;
           $318 = ($316|0)==($317|0);
           L164: do {
            if (!($318)) {
             $319 = HEAP32[$316>>2]|0;
             $320 = ($319|0)==(0|0);
             if (!($320)) {
              $321 = ((($319)) + 8|0);
              $322 = HEAP32[$321>>2]|0;HEAP32[$321>>2] = (($322+1)|0);
             }
             $323 = HEAP32[$273>>2]|0;
             $324 = HEAP32[$275>>2]|0;
             __THREW__ = 0;
             $325 = (invoke_iiii(3350,0,($323|0),($324|0))|0);
             $326 = __THREW__; __THREW__ = 0;
             $327 = $326&1;
             L169: do {
              if ($327) {
               $449 = ___cxa_find_matching_catch_2()|0;
               $450 = tempRet0;
               $$14 = $449;$$14122 = $450;
               label = 179;
              } else {
               $328 = ($325|0)==(0|0);
               if (!($328)) {
                $329 = ((($325)) + 8|0);
                $330 = HEAP32[$329>>2]|0;HEAP32[$329>>2] = (($330+1)|0);
               }
               $331 = HEAP32[$273>>2]|0;
               $332 = HEAP32[$275>>2]|0;
               __THREW__ = 0;
               invoke_viiiii(3356,($281|0),0,0,($331|0),($332|0));
               $333 = __THREW__; __THREW__ = 0;
               $334 = $333&1;
               L175: do {
                if ($334) {
                 label = 161;
                } else {
                 $335 = ((($281)) + 568|0);
                 HEAP32[$335>>2] = 1028;
                 $336 = HEAP32[$288>>2]|0;
                 $337 = ($336|0)==(0);
                 if ($337) {
                  $339 = HEAP32[$291>>2]|0;
                  $340 = $339 & -131073;
                  HEAP32[$291>>2] = $340;
                  $341 = ((($281)) + 572|0);
                  HEAP32[$341>>2] = 1028;
                  $342 = $339 & -393217;
                  HEAP32[$291>>2] = $342;
                 } else {
                  $338 = ((($281)) + 572|0);
                  HEAP32[$338>>2] = 1028;
                 }
                 $343 = ((($281)) + 228|0);
                 HEAP8[$343>>0] = 1;
                 __THREW__ = 0;
                 invoke_vii(3341,($281|0),0);
                 $344 = __THREW__; __THREW__ = 0;
                 $345 = $344&1;
                 if ($345) {
                  label = 161;
                  break;
                 }
                 __THREW__ = 0;
                 invoke_viiiiiiii(3342,($281|0),3,($325|0),0,0,0,0,0);
                 $346 = __THREW__; __THREW__ = 0;
                 $347 = $346&1;
                 if ($347) {
                  label = 161;
                  break;
                 }
                 $348 = HEAP32[$273>>2]|0;
                 $349 = HEAP32[$275>>2]|0;
                 __THREW__ = 0;
                 $350 = (invoke_iiii(3350,0,($348|0),($349|0))|0);
                 $351 = __THREW__; __THREW__ = 0;
                 $352 = $351&1;
                 if ($352) {
                  label = 161;
                  break;
                 }
                 $353 = ($350|0)==(0|0);
                 if (!($353)) {
                  $354 = ((($350)) + 8|0);
                  $355 = HEAP32[$354>>2]|0;HEAP32[$354>>2] = (($355+1)|0);
                 }
                 $356 = HEAP32[$273>>2]|0;
                 $357 = HEAP32[$275>>2]|0;
                 __THREW__ = 0;
                 invoke_viiiii(3356,($301|0),0,0,($356|0),($357|0));
                 $358 = __THREW__; __THREW__ = 0;
                 $359 = $358&1;
                 L187: do {
                  if ($359) {
                   label = 162;
                  } else {
                   $360 = ((($301)) + 568|0);
                   HEAP32[$360>>2] = 1028;
                   $361 = HEAP32[$308>>2]|0;
                   $362 = ($361|0)==(0);
                   if ($362) {
                    $364 = HEAP32[$311>>2]|0;
                    $365 = $364 & -131073;
                    HEAP32[$311>>2] = $365;
                    $366 = ((($301)) + 572|0);
                    HEAP32[$366>>2] = 1028;
                    $367 = $364 & -393217;
                    HEAP32[$311>>2] = $367;
                   } else {
                    $363 = ((($301)) + 572|0);
                    HEAP32[$363>>2] = 1028;
                   }
                   $368 = ((($301)) + 228|0);
                   HEAP8[$368>>0] = 1;
                   __THREW__ = 0;
                   invoke_vii(3341,($301|0),0);
                   $369 = __THREW__; __THREW__ = 0;
                   $370 = $369&1;
                   if ($370) {
                    label = 162;
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viiiiiiii(3342,($301|0),3,($350|0),0,0,0,0,0);
                   $371 = __THREW__; __THREW__ = 0;
                   $372 = $371&1;
                   if ($372) {
                    label = 162;
                    break;
                   }
                   $$sroa$0922$0$$sroa_idx = ((($319)) + 36|0);
                   HEAPF32[$$sroa$0922$0$$sroa_idx>>2] = 1.0;
                   $$sroa$4924$0$$sroa_idx926 = ((($319)) + 40|0);
                   HEAPF32[$$sroa$4924$0$$sroa_idx926>>2] = 0.0;
                   $$sroa$5927$0$$sroa_idx929 = ((($319)) + 44|0);
                   HEAPF32[$$sroa$5927$0$$sroa_idx929>>2] = 0.0;
                   $$sroa$6930$0$$sroa_idx932 = ((($319)) + 48|0);
                   HEAPF32[$$sroa$6930$0$$sroa_idx932>>2] = 1.0;
                   $373 = HEAP32[$273>>2]|0;
                   $374 = HEAP32[$275>>2]|0;
                   $375 = HEAP8[$277>>0]|0;
                   $376 = ($375<<24>>24)!=(0);
                   $377 = $376 ? 1026 : 1024;
                   __THREW__ = 0;
                   $378 = (invoke_iiiiiiiiiii(3352,($0|0),($2|0),($137|0),0,0,($373|0),($374|0),($377|0),($325|0),($319|0))|0);
                   $379 = __THREW__; __THREW__ = 0;
                   $380 = $379&1;
                   if ($380) {
                    label = 162;
                    break;
                   }
                   $381 = ($378|0)==(0|0);
                   if (!($381)) {
                    $382 = ((($378)) + 8|0);
                    $383 = HEAP32[$382>>2]|0;HEAP32[$382>>2] = (($383+1)|0);
                   }
                   $384 = ((($378)) + 560|0);
                   HEAP32[$384>>2] = 1;
                   $385 = ((($378)) + 564|0);
                   HEAP32[$385>>2] = 2;
                   __THREW__ = 0;
                   $386 = (invoke_ii(3276,152)|0);
                   $387 = __THREW__; __THREW__ = 0;
                   $388 = $387&1;
                   L199: do {
                    if ($388) {
                     label = 163;
                    } else {
                     __THREW__ = 0;
                     invoke_vii(3353,($386|0),($319|0));
                     $389 = __THREW__; __THREW__ = 0;
                     $390 = $389&1;
                     if ($390) {
                      $457 = ___cxa_find_matching_catch_2()|0;
                      $458 = tempRet0;
                      __ZdlPv($386);
                      $$8 = $457;$$8116 = $458;
                      break;
                     }
                     $391 = HEAP32[$386>>2]|0;
                     $392 = ((($391)) + -12|0);
                     $393 = HEAP32[$392>>2]|0;
                     $394 = (($386) + ($393)|0);
                     $395 = ((($378)) + 92|0);
                     $396 = HEAP32[$395>>2]|0;
                     $397 = ($396|0)==(0|0);
                     if ($397) {
                      __THREW__ = 0;
                      invoke_vii(3354,($378|0),($394|0));
                      $407 = __THREW__; __THREW__ = 0;
                      $408 = $407&1;
                      if ($408) {
                       label = 163;
                       break;
                      }
                     } else {
                      $$tr$i$i486 = $396;
                      while(1) {
                       $398 = ((($$tr$i$i486)) + 4|0);
                       $399 = HEAP32[$398>>2]|0;
                       $400 = ($399|0)==(0|0);
                       if ($400) {
                        break;
                       } else {
                        $$tr$i$i486 = $399;
                       }
                      }
                      HEAP32[$398>>2] = $394;
                      $401 = HEAP32[$394>>2]|0;
                      $402 = ((($401)) + -12|0);
                      $403 = HEAP32[$402>>2]|0;
                      $404 = (($394) + ($403)|0);
                      $405 = ((($404)) + 8|0);
                      $406 = HEAP32[$405>>2]|0;HEAP32[$405>>2] = (($406+1)|0);
                     }
                     $409 = HEAP32[$273>>2]|0;
                     $410 = HEAP32[$275>>2]|0;
                     $411 = HEAP8[$277>>0]|0;
                     $412 = ($411<<24>>24)!=(0);
                     $413 = $412 ? 1027 : 1025;
                     __THREW__ = 0;
                     $414 = (invoke_iiiiiiiiiii(3352,($0|0),($2|0),($137|0),0,0,($409|0),($410|0),($413|0),($350|0),($319|0))|0);
                     $415 = __THREW__; __THREW__ = 0;
                     $416 = $415&1;
                     if ($416) {
                      label = 163;
                      break;
                     }
                     $417 = ($414|0)==(0|0);
                     do {
                      if ($417) {
                       HEAP32[(560)>>2] = 1;
                       HEAP32[(564)>>2] = 3;
                       HEAP8[(228)>>0] = 0;
                      } else {
                       $418 = ((($414)) + 8|0);
                       $419 = HEAP32[$418>>2]|0;HEAP32[$418>>2] = (($419+1)|0);
                       $420 = ((($414)) + 560|0);
                       HEAP32[$420>>2] = 1;
                       $421 = ((($414)) + 564|0);
                       HEAP32[$421>>2] = 3;
                       $422 = ((($414)) + 228|0);
                       HEAP8[$422>>0] = 0;
                       $423 = HEAP32[$418>>2]|0;HEAP32[$418>>2] = (($423-1)|0);
                       $424 = ($423|0)==(1);
                       if (!($424)) {
                        break;
                       }
                       __THREW__ = 0;
                       invoke_viii(3262,($414|0),1,1);
                       $425 = __THREW__; __THREW__ = 0;
                       $426 = $425&1;
                       if (!($426)) {
                        break;
                       }
                       $459 = ___cxa_find_matching_catch_2()|0;
                       $460 = tempRet0;
                       $$8 = $459;$$8116 = $460;
                       break L199;
                      }
                     } while(0);
                     do {
                      if (!($381)) {
                       $427 = ((($378)) + 8|0);
                       $428 = HEAP32[$427>>2]|0;HEAP32[$427>>2] = (($428-1)|0);
                       $429 = ($428|0)==(1);
                       if (!($429)) {
                        break;
                       }
                       __THREW__ = 0;
                       invoke_viii(3262,($378|0),1,1);
                       $430 = __THREW__; __THREW__ = 0;
                       $431 = $430&1;
                       if (!($431)) {
                        break;
                       }
                       $461 = ___cxa_find_matching_catch_2()|0;
                       $462 = tempRet0;
                       $$10 = $461;$$10118 = $462;
                       break L187;
                      }
                     } while(0);
                     do {
                      if (!($353)) {
                       $432 = ((($350)) + 8|0);
                       $433 = HEAP32[$432>>2]|0;HEAP32[$432>>2] = (($433-1)|0);
                       $434 = ($433|0)==(1);
                       if (!($434)) {
                        break;
                       }
                       __THREW__ = 0;
                       invoke_viii(3262,($350|0),1,1);
                       $435 = __THREW__; __THREW__ = 0;
                       $436 = $435&1;
                       if (!($436)) {
                        break;
                       }
                       $468 = ___cxa_find_matching_catch_2()|0;
                       $469 = tempRet0;
                       $$12 = $468;$$12120 = $469;
                       break L175;
                      }
                     } while(0);
                     do {
                      if (!($328)) {
                       $437 = ((($325)) + 8|0);
                       $438 = HEAP32[$437>>2]|0;HEAP32[$437>>2] = (($438-1)|0);
                       $439 = ($438|0)==(1);
                       if (!($439)) {
                        break;
                       }
                       __THREW__ = 0;
                       invoke_viii(3262,($325|0),1,1);
                       $440 = __THREW__; __THREW__ = 0;
                       $441 = $440&1;
                       if (!($441)) {
                        break;
                       }
                       $475 = ___cxa_find_matching_catch_2()|0;
                       $476 = tempRet0;
                       $$14 = $475;$$14122 = $476;
                       label = 179;
                       break L169;
                      }
                     } while(0);
                     if ($320) {
                      break L164;
                     }
                     $442 = ((($319)) + 8|0);
                     $443 = HEAP32[$442>>2]|0;HEAP32[$442>>2] = (($443-1)|0);
                     $444 = ($443|0)==(1);
                     if (!($444)) {
                      break L164;
                     }
                     __THREW__ = 0;
                     invoke_viii(3262,($319|0),1,1);
                     $445 = __THREW__; __THREW__ = 0;
                     $446 = $445&1;
                     if (!($446)) {
                      break L164;
                     }
                     $482 = ___cxa_find_matching_catch_2()|0;
                     $483 = tempRet0;
                     $$15 = $482;$$15123 = $483;
                     break L169;
                    }
                   } while(0);
                   if ((label|0) == 163) {
                    $455 = ___cxa_find_matching_catch_2()|0;
                    $456 = tempRet0;
                    $$8 = $455;$$8116 = $456;
                   }
                   if ($381) {
                    $$10 = $$8;$$10118 = $$8116;
                    break;
                   }
                   $463 = ((($378)) + 8|0);
                   $464 = HEAP32[$463>>2]|0;HEAP32[$463>>2] = (($464-1)|0);
                   $465 = ($464|0)==(1);
                   if (!($465)) {
                    $$10 = $$8;$$10118 = $$8116;
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(3262,($378|0),1,1);
                   $466 = __THREW__; __THREW__ = 0;
                   $467 = $466&1;
                   if (!($467)) {
                    $$10 = $$8;$$10118 = $$8116;
                    break;
                   }
                   $2128 = ___cxa_find_matching_catch_3(0|0)|0;
                   $2129 = tempRet0;
                   ___clang_call_terminate($2128);
                   // unreachable;
                  }
                 } while(0);
                 if ((label|0) == 162) {
                  $453 = ___cxa_find_matching_catch_2()|0;
                  $454 = tempRet0;
                  $$10 = $453;$$10118 = $454;
                 }
                 if ($353) {
                  $$12 = $$10;$$12120 = $$10118;
                  break;
                 }
                 $470 = ((($350)) + 8|0);
                 $471 = HEAP32[$470>>2]|0;HEAP32[$470>>2] = (($471-1)|0);
                 $472 = ($471|0)==(1);
                 if (!($472)) {
                  $$12 = $$10;$$12120 = $$10118;
                  break;
                 }
                 __THREW__ = 0;
                 invoke_viii(3262,($350|0),1,1);
                 $473 = __THREW__; __THREW__ = 0;
                 $474 = $473&1;
                 if (!($474)) {
                  $$12 = $$10;$$12120 = $$10118;
                  break;
                 }
                 $2128 = ___cxa_find_matching_catch_3(0|0)|0;
                 $2129 = tempRet0;
                 ___clang_call_terminate($2128);
                 // unreachable;
                }
               } while(0);
               if ((label|0) == 161) {
                $451 = ___cxa_find_matching_catch_2()|0;
                $452 = tempRet0;
                $$12 = $451;$$12120 = $452;
               }
               if ($328) {
                $$14 = $$12;$$14122 = $$12120;
                label = 179;
                break;
               }
               $477 = ((($325)) + 8|0);
               $478 = HEAP32[$477>>2]|0;HEAP32[$477>>2] = (($478-1)|0);
               $479 = ($478|0)==(1);
               if (!($479)) {
                $$14 = $$12;$$14122 = $$12120;
                label = 179;
                break;
               }
               __THREW__ = 0;
               invoke_viii(3262,($325|0),1,1);
               $480 = __THREW__; __THREW__ = 0;
               $481 = $480&1;
               if (!($481)) {
                $$14 = $$12;$$14122 = $$12120;
                label = 179;
                break;
               }
               $2128 = ___cxa_find_matching_catch_3(0|0)|0;
               $2129 = tempRet0;
               ___clang_call_terminate($2128);
               // unreachable;
              }
             } while(0);
             do {
              if ((label|0) == 179) {
               if ($320) {
                $$15 = $$14;$$15123 = $$14122;
                break;
               }
               $484 = ((($319)) + 8|0);
               $485 = HEAP32[$484>>2]|0;HEAP32[$484>>2] = (($485-1)|0);
               $486 = ($485|0)==(1);
               if (!($486)) {
                $$15 = $$14;$$15123 = $$14122;
                break;
               }
               __THREW__ = 0;
               invoke_viii(3262,($319|0),1,1);
               $487 = __THREW__; __THREW__ = 0;
               $488 = $487&1;
               if (!($488)) {
                $$15 = $$14;$$15123 = $$14122;
                break;
               }
               $2128 = ___cxa_find_matching_catch_3(0|0)|0;
               $2129 = tempRet0;
               ___clang_call_terminate($2128);
               // unreachable;
              }
             } while(0);
             if ($304) {
              $$18 = $$15;$$18126 = $$15123;
              break L155;
             }
             $501 = ((($301)) + 8|0);
             $502 = HEAP32[$501>>2]|0;HEAP32[$501>>2] = (($502-1)|0);
             $503 = ($502|0)==(1);
             if (!($503)) {
              $$18 = $$15;$$18126 = $$15123;
              break L155;
             }
             __THREW__ = 0;
             invoke_viii(3262,($301|0),1,1);
             $504 = __THREW__; __THREW__ = 0;
             $505 = $504&1;
             if (!($505)) {
              $$18 = $$15;$$18126 = $$15123;
              break L155;
             }
             $2128 = ___cxa_find_matching_catch_3(0|0)|0;
             $2129 = tempRet0;
             ___clang_call_terminate($2128);
             // unreachable;
            }
           } while(0);
           do {
            if (!($304)) {
             $489 = ((($301)) + 8|0);
             $490 = HEAP32[$489>>2]|0;HEAP32[$489>>2] = (($490-1)|0);
             $491 = ($490|0)==(1);
             if (!($491)) {
              break;
             }
             __THREW__ = 0;
             invoke_viii(3262,($301|0),1,1);
             $492 = __THREW__; __THREW__ = 0;
             $493 = $492&1;
             if (!($493)) {
              break;
             }
             $499 = ___cxa_find_matching_catch_2()|0;
             $500 = tempRet0;
             $$18 = $499;$$18126 = $500;
             break L155;
            }
           } while(0);
           if ($284) {
            label = 788;
            break L77;
           }
           $494 = ((($281)) + 8|0);
           $495 = HEAP32[$494>>2]|0;HEAP32[$494>>2] = (($495-1)|0);
           $496 = ($495|0)==(1);
           if (!($496)) {
            label = 788;
            break L77;
           }
           __THREW__ = 0;
           invoke_viii(3262,($281|0),1,1);
           $497 = __THREW__; __THREW__ = 0;
           $498 = $497&1;
           if (!($498)) {
            label = 788;
            break L77;
           }
           $506 = ___cxa_find_matching_catch_2()|0;
           $507 = tempRet0;
           $$104 = $506;$$104212 = $507;
           label = 806;
           break L77;
          }
         } while(0);
         if ($284) {
          $$104 = $$18;$$104212 = $$18126;
          label = 806;
          break L77;
         }
         $508 = ((($281)) + 8|0);
         $509 = HEAP32[$508>>2]|0;HEAP32[$508>>2] = (($509-1)|0);
         $510 = ($509|0)==(1);
         if (!($510)) {
          $$104 = $$18;$$104212 = $$18126;
          label = 806;
          break L77;
         }
         __THREW__ = 0;
         invoke_viii(3262,($281|0),1,1);
         $511 = __THREW__; __THREW__ = 0;
         $512 = $511&1;
         if (!($512)) {
          $$104 = $$18;$$104212 = $$18126;
          label = 806;
          break L77;
         }
         $2128 = ___cxa_find_matching_catch_3(0|0)|0;
         $2129 = tempRet0;
         ___clang_call_terminate($2128);
         // unreachable;
        }
       }
       break;
      }
      case 1:  {
       __THREW__ = 0;
       invoke_vii(3338,($1|0),(0|0));
       $513 = __THREW__; __THREW__ = 0;
       $514 = $513&1;
       if (!($514)) {
        $515 = ((($142)) + 40|0);
        $516 = HEAP32[$515>>2]|0;
        $517 = ((($142)) + 44|0);
        $518 = HEAP32[$517>>2]|0;
        $519 = ((($142)) + 110|0);
        $520 = HEAP8[$519>>0]|0;
        $521 = ($520<<24>>24)!=(0);
        $522 = $521 ? 1029 : 1028;
        __THREW__ = 0;
        $523 = (invoke_iiiiiiiiid(3355,($0|0),($2|0),($137|0),0,0,($516|0),($518|0),($522|0),-1.0)|0);
        $524 = __THREW__; __THREW__ = 0;
        $525 = $524&1;
        if (!($525)) {
         $526 = ($523|0)==(0|0);
         if (!($526)) {
          $527 = ((($523)) + 8|0);
          $528 = HEAP32[$527>>2]|0;HEAP32[$527>>2] = (($528+1)|0);
         }
         $529 = ((($523)) + 236|0);
         HEAP32[$529>>2] = 16640;
         $530 = ((($523)) + 152|0);
         $531 = HEAP32[$530>>2]|0;
         $532 = ($531|0)==(0);
         $533 = ((($523)) + 148|0);
         if ($532) {
          $534 = HEAP32[$533>>2]|0;
          $535 = $534 & -16385;
          HEAP32[$533>>2] = $535;
         }
         __THREW__ = 0;
         $536 = (invoke_ii(3281,($523|0))|0);
         $537 = __THREW__; __THREW__ = 0;
         $538 = $537&1;
         L284: do {
          if ($538) {
           label = 281;
          } else {
           __THREW__ = 0;
           $539 = (invoke_ii(3276,60)|0);
           $540 = __THREW__; __THREW__ = 0;
           $541 = $540&1;
           if ($541) {
            label = 281;
           } else {
            __THREW__ = 0;
            invoke_vi(3339,($539|0));
            $542 = __THREW__; __THREW__ = 0;
            $543 = $542&1;
            if ($543) {
             $772 = ___cxa_find_matching_catch_2()|0;
             $773 = tempRet0;
             __ZdlPv($539);
             $$36 = $772;$$36144 = $773;
             break;
            }
            HEAP32[$539>>2] = (57196);
            $544 = ((($539)) + 56|0);
            HEAP8[$544>>0] = 1;
            $545 = ((($539)) + 57|0);
            HEAP8[$545>>0] = 0;
            $546 = ((($539)) + 58|0);
            HEAP8[$546>>0] = 0;
            $547 = ((($539)) + 59|0);
            HEAP8[$547>>0] = 1;
            __THREW__ = 0;
            invoke_viii(3357,($536|0),($539|0),0);
            $548 = __THREW__; __THREW__ = 0;
            $549 = $548&1;
            if ($549) {
             label = 281;
            } else {
             $550 = ((($523)) + 560|0);
             HEAP32[$550>>2] = 1;
             $551 = ((($523)) + 564|0);
             HEAP32[$551>>2] = 0;
             $552 = HEAP32[$515>>2]|0;
             $553 = HEAP32[$517>>2]|0;
             $554 = HEAP8[$519>>0]|0;
             $555 = ($554<<24>>24)!=(0);
             $556 = $555 ? 1029 : 1028;
             __THREW__ = 0;
             $557 = (invoke_iiiiiiiiid(3355,($0|0),($2|0),($137|0),0,0,($552|0),($553|0),($556|0),1.0)|0);
             $558 = __THREW__; __THREW__ = 0;
             $559 = $558&1;
             if ($559) {
              label = 281;
             } else {
              $560 = ($557|0)==(0|0);
              if (!($560)) {
               $561 = ((($557)) + 8|0);
               $562 = HEAP32[$561>>2]|0;HEAP32[$561>>2] = (($562+1)|0);
              }
              $563 = ((($557)) + 236|0);
              HEAP32[$563>>2] = 256;
              $564 = ((($557)) + 152|0);
              $565 = HEAP32[$564>>2]|0;
              $566 = ($565|0)==(0);
              $567 = ((($557)) + 148|0);
              if ($566) {
               $568 = HEAP32[$567>>2]|0;
               $569 = $568 & -16385;
               HEAP32[$567>>2] = $569;
              }
              __THREW__ = 0;
              $570 = (invoke_ii(3281,($557|0))|0);
              $571 = __THREW__; __THREW__ = 0;
              $572 = $571&1;
              L298: do {
               if ($572) {
                label = 283;
               } else {
                __THREW__ = 0;
                $573 = (invoke_ii(3276,60)|0);
                $574 = __THREW__; __THREW__ = 0;
                $575 = $574&1;
                if ($575) {
                 label = 283;
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3339,($573|0));
                $576 = __THREW__; __THREW__ = 0;
                $577 = $576&1;
                if ($577) {
                 $776 = ___cxa_find_matching_catch_2()|0;
                 $777 = tempRet0;
                 __ZdlPv($573);
                 $$34 = $776;$$34142 = $777;
                 break;
                }
                HEAP32[$573>>2] = (57196);
                $578 = ((($573)) + 56|0);
                HEAP8[$578>>0] = 0;
                $579 = ((($573)) + 57|0);
                HEAP8[$579>>0] = 1;
                $580 = ((($573)) + 58|0);
                HEAP8[$580>>0] = 1;
                $581 = ((($573)) + 59|0);
                HEAP8[$581>>0] = 1;
                __THREW__ = 0;
                invoke_viii(3357,($570|0),($573|0),0);
                $582 = __THREW__; __THREW__ = 0;
                $583 = $582&1;
                if ($583) {
                 label = 283;
                 break;
                }
                $584 = ((($557)) + 560|0);
                HEAP32[$584>>2] = 1;
                $585 = ((($557)) + 564|0);
                HEAP32[$585>>2] = 1;
                $586 = HEAP32[$5>>2]|0;
                $587 = HEAP32[$22>>2]|0;
                $588 = ($586|0)==($587|0);
                L305: do {
                 if (!($588)) {
                  $589 = HEAP32[$586>>2]|0;
                  $590 = ($589|0)==(0|0);
                  if (!($590)) {
                   $591 = ((($589)) + 8|0);
                   $592 = HEAP32[$591>>2]|0;HEAP32[$591>>2] = (($592+1)|0);
                  }
                  $593 = HEAP32[$515>>2]|0;
                  $594 = HEAP32[$517>>2]|0;
                  __THREW__ = 0;
                  $595 = (invoke_iiii(3350,0,($593|0),($594|0))|0);
                  $596 = __THREW__; __THREW__ = 0;
                  $597 = $596&1;
                  L310: do {
                   if ($597) {
                    $778 = ___cxa_find_matching_catch_2()|0;
                    $779 = tempRet0;
                    $$32 = $778;$$32140 = $779;
                   } else {
                    $598 = ($595|0)==(0|0);
                    if (!($598)) {
                     $599 = ((($595)) + 8|0);
                     $600 = HEAP32[$599>>2]|0;HEAP32[$599>>2] = (($600+1)|0);
                    }
                    $601 = ((($523)) + 568|0);
                    HEAP32[$601>>2] = 1028;
                    $602 = HEAP32[$530>>2]|0;
                    $603 = ($602|0)==(0);
                    if ($603) {
                     $605 = HEAP32[$533>>2]|0;
                     $606 = $605 & -131073;
                     HEAP32[$533>>2] = $606;
                     $607 = ((($523)) + 572|0);
                     HEAP32[$607>>2] = 1028;
                     $608 = $605 & -393217;
                     HEAP32[$533>>2] = $608;
                    } else {
                     $604 = ((($523)) + 572|0);
                     HEAP32[$604>>2] = 1028;
                    }
                    $609 = ((($523)) + 228|0);
                    HEAP8[$609>>0] = 0;
                    HEAP32[$550>>2] = 1;
                    HEAP32[$551>>2] = 0;
                    __THREW__ = 0;
                    invoke_vii(3341,($523|0),0);
                    $610 = __THREW__; __THREW__ = 0;
                    $611 = $610&1;
                    L320: do {
                     if ($611) {
                      label = 286;
                     } else {
                      __THREW__ = 0;
                      $612 = (invoke_ii(3281,($523|0))|0);
                      $613 = __THREW__; __THREW__ = 0;
                      $614 = $613&1;
                      if ($614) {
                       label = 286;
                       break;
                      }
                      __THREW__ = 0;
                      invoke_viii(3358,($612|0),25,0);
                      $615 = __THREW__; __THREW__ = 0;
                      $616 = $615&1;
                      if ($616) {
                       label = 286;
                       break;
                      }
                      HEAP32[$529>>2] = 16640;
                      $617 = HEAP32[$530>>2]|0;
                      $618 = ($617|0)==(0);
                      if ($618) {
                       $619 = HEAP32[$533>>2]|0;
                       $620 = $619 & -16385;
                       HEAP32[$533>>2] = $620;
                      }
                      __THREW__ = 0;
                      invoke_viiiiiiii(3342,($523|0),3,($595|0),0,0,0,0,0);
                      $621 = __THREW__; __THREW__ = 0;
                      $622 = $621&1;
                      if ($622) {
                       label = 286;
                       break;
                      }
                      $623 = HEAP32[$515>>2]|0;
                      $624 = HEAP32[$517>>2]|0;
                      __THREW__ = 0;
                      $625 = (invoke_iiii(3350,0,($623|0),($624|0))|0);
                      $626 = __THREW__; __THREW__ = 0;
                      $627 = $626&1;
                      if ($627) {
                       label = 286;
                       break;
                      }
                      $628 = ($625|0)==(0|0);
                      if (!($628)) {
                       $629 = ((($625)) + 8|0);
                       $630 = HEAP32[$629>>2]|0;HEAP32[$629>>2] = (($630+1)|0);
                      }
                      $631 = ((($557)) + 568|0);
                      HEAP32[$631>>2] = 1028;
                      $632 = HEAP32[$564>>2]|0;
                      $633 = ($632|0)==(0);
                      if ($633) {
                       $635 = HEAP32[$567>>2]|0;
                       $636 = $635 & -131073;
                       HEAP32[$567>>2] = $636;
                       $637 = ((($557)) + 572|0);
                       HEAP32[$637>>2] = 1028;
                       $638 = $635 & -393217;
                       HEAP32[$567>>2] = $638;
                      } else {
                       $634 = ((($557)) + 572|0);
                       HEAP32[$634>>2] = 1028;
                      }
                      $639 = ((($557)) + 228|0);
                      HEAP8[$639>>0] = 0;
                      HEAP32[$584>>2] = 1;
                      HEAP32[$585>>2] = 1;
                      __THREW__ = 0;
                      invoke_vii(3341,($557|0),0);
                      $640 = __THREW__; __THREW__ = 0;
                      $641 = $640&1;
                      L336: do {
                       if ($641) {
                        label = 287;
                       } else {
                        __THREW__ = 0;
                        $642 = (invoke_ii(3281,($557|0))|0);
                        $643 = __THREW__; __THREW__ = 0;
                        $644 = $643&1;
                        if ($644) {
                         label = 287;
                         break;
                        }
                        __THREW__ = 0;
                        invoke_viii(3358,($642|0),25,0);
                        $645 = __THREW__; __THREW__ = 0;
                        $646 = $645&1;
                        if ($646) {
                         label = 287;
                         break;
                        }
                        HEAP32[$563>>2] = 16640;
                        $647 = HEAP32[$564>>2]|0;
                        $648 = ($647|0)==(0);
                        if ($648) {
                         $649 = HEAP32[$567>>2]|0;
                         $650 = $649 & -16385;
                         HEAP32[$567>>2] = $650;
                        }
                        __THREW__ = 0;
                        invoke_viiiiiiii(3342,($557|0),3,($625|0),0,0,0,0,0);
                        $651 = __THREW__; __THREW__ = 0;
                        $652 = $651&1;
                        if ($652) {
                         label = 287;
                         break;
                        }
                        $653 = HEAP32[$515>>2]|0;
                        $654 = HEAP32[$517>>2]|0;
                        $655 = HEAP8[$519>>0]|0;
                        $656 = ($655<<24>>24)!=(0);
                        $657 = $656 ? 1029 : 1028;
                        __THREW__ = 0;
                        $658 = (invoke_iiiiiiiiiii(3352,($0|0),($2|0),($137|0),0,0,($653|0),($654|0),($657|0),($595|0),($589|0))|0);
                        $659 = __THREW__; __THREW__ = 0;
                        $660 = $659&1;
                        if ($660) {
                         label = 287;
                         break;
                        }
                        $661 = ($658|0)==(0|0);
                        if (!($661)) {
                         $662 = ((($658)) + 8|0);
                         $663 = HEAP32[$662>>2]|0;HEAP32[$662>>2] = (($663+1)|0);
                        }
                        $664 = ((($658)) + 560|0);
                        HEAP32[$664>>2] = 1;
                        $665 = ((($658)) + 564|0);
                        HEAP32[$665>>2] = 2;
                        $666 = ((($658)) + 236|0);
                        HEAP32[$666>>2] = 16640;
                        $667 = ((($658)) + 152|0);
                        $668 = HEAP32[$667>>2]|0;
                        $669 = ($668|0)==(0);
                        $670 = ((($658)) + 148|0);
                        if ($669) {
                         $671 = HEAP32[$670>>2]|0;
                         $672 = $671 & -16385;
                         HEAP32[$670>>2] = $672;
                        }
                        __THREW__ = 0;
                        $673 = (invoke_ii(3281,($658|0))|0);
                        $674 = __THREW__; __THREW__ = 0;
                        $675 = $674&1;
                        L351: do {
                         if ($675) {
                          label = 288;
                         } else {
                          __THREW__ = 0;
                          $676 = (invoke_ii(3276,60)|0);
                          $677 = __THREW__; __THREW__ = 0;
                          $678 = $677&1;
                          if ($678) {
                           label = 288;
                           break;
                          }
                          __THREW__ = 0;
                          invoke_vi(3339,($676|0));
                          $679 = __THREW__; __THREW__ = 0;
                          $680 = $679&1;
                          if ($680) {
                           $786 = ___cxa_find_matching_catch_2()|0;
                           $787 = tempRet0;
                           __ZdlPv($676);
                           $$22 = $786;$$22130 = $787;
                           break;
                          }
                          HEAP32[$676>>2] = (57196);
                          $681 = ((($676)) + 56|0);
                          HEAP8[$681>>0] = 1;
                          $682 = ((($676)) + 57|0);
                          HEAP8[$682>>0] = 0;
                          $683 = ((($676)) + 58|0);
                          HEAP8[$683>>0] = 0;
                          $684 = ((($676)) + 59|0);
                          HEAP8[$684>>0] = 1;
                          __THREW__ = 0;
                          invoke_viii(3357,($673|0),($676|0),0);
                          $685 = __THREW__; __THREW__ = 0;
                          $686 = $685&1;
                          if ($686) {
                           label = 288;
                           break;
                          }
                          $687 = HEAP32[$515>>2]|0;
                          $688 = HEAP32[$517>>2]|0;
                          $689 = HEAP8[$519>>0]|0;
                          $690 = ($689<<24>>24)!=(0);
                          $691 = $690 ? 1029 : 1028;
                          __THREW__ = 0;
                          $692 = (invoke_iiiiiiiiiii(3352,($0|0),($2|0),($137|0),0,0,($687|0),($688|0),($691|0),($625|0),($589|0))|0);
                          $693 = __THREW__; __THREW__ = 0;
                          $694 = $693&1;
                          if ($694) {
                           label = 288;
                           break;
                          }
                          $695 = ($692|0)==(0|0);
                          if (!($695)) {
                           $696 = ((($692)) + 8|0);
                           $697 = HEAP32[$696>>2]|0;HEAP32[$696>>2] = (($697+1)|0);
                          }
                          $698 = ((($692)) + 560|0);
                          HEAP32[$698>>2] = 1;
                          $699 = ((($692)) + 564|0);
                          HEAP32[$699>>2] = 3;
                          $700 = ((($692)) + 236|0);
                          HEAP32[$700>>2] = 256;
                          $701 = ((($692)) + 152|0);
                          $702 = HEAP32[$701>>2]|0;
                          $703 = ($702|0)==(0);
                          $704 = ((($692)) + 148|0);
                          if ($703) {
                           $705 = HEAP32[$704>>2]|0;
                           $706 = $705 & -16385;
                           HEAP32[$704>>2] = $706;
                          }
                          __THREW__ = 0;
                          $707 = (invoke_ii(3281,($692|0))|0);
                          $708 = __THREW__; __THREW__ = 0;
                          $709 = $708&1;
                          do {
                           if ($709) {
                            label = 290;
                           } else {
                            __THREW__ = 0;
                            $710 = (invoke_ii(3276,60)|0);
                            $711 = __THREW__; __THREW__ = 0;
                            $712 = $711&1;
                            if ($712) {
                             label = 290;
                             break;
                            }
                            __THREW__ = 0;
                            invoke_vi(3339,($710|0));
                            $713 = __THREW__; __THREW__ = 0;
                            $714 = $713&1;
                            if ($714) {
                             $790 = ___cxa_find_matching_catch_2()|0;
                             $791 = tempRet0;
                             __ZdlPv($710);
                             $$20 = $790;$$20128 = $791;
                             break;
                            }
                            HEAP32[$710>>2] = (57196);
                            $715 = ((($710)) + 56|0);
                            HEAP8[$715>>0] = 0;
                            $716 = ((($710)) + 57|0);
                            HEAP8[$716>>0] = 1;
                            $717 = ((($710)) + 58|0);
                            HEAP8[$717>>0] = 1;
                            $718 = ((($710)) + 59|0);
                            HEAP8[$718>>0] = 1;
                            __THREW__ = 0;
                            invoke_viii(3357,($707|0),($710|0),0);
                            $719 = __THREW__; __THREW__ = 0;
                            $720 = $719&1;
                            if ($720) {
                             label = 290;
                             break;
                            }
                            __THREW__ = 0;
                            $721 = (invoke_ii(3276,152)|0);
                            $722 = __THREW__; __THREW__ = 0;
                            $723 = $722&1;
                            if ($723) {
                             label = 290;
                             break;
                            }
                            __THREW__ = 0;
                            invoke_vii(3353,($721|0),($589|0));
                            $724 = __THREW__; __THREW__ = 0;
                            $725 = $724&1;
                            if ($725) {
                             $792 = ___cxa_find_matching_catch_2()|0;
                             $793 = tempRet0;
                             __ZdlPv($721);
                             $$20 = $792;$$20128 = $793;
                             break;
                            }
                            $726 = HEAP32[$721>>2]|0;
                            $727 = ((($726)) + -12|0);
                            $728 = HEAP32[$727>>2]|0;
                            $729 = (($721) + ($728)|0);
                            $730 = ((($658)) + 92|0);
                            $731 = HEAP32[$730>>2]|0;
                            $732 = ($731|0)==(0|0);
                            if ($732) {
                             __THREW__ = 0;
                             invoke_vii(3354,($658|0),($729|0));
                             $742 = __THREW__; __THREW__ = 0;
                             $743 = $742&1;
                             if ($743) {
                              label = 290;
                              break;
                             }
                            } else {
                             $$tr$i$i501 = $731;
                             while(1) {
                              $733 = ((($$tr$i$i501)) + 4|0);
                              $734 = HEAP32[$733>>2]|0;
                              $735 = ($734|0)==(0|0);
                              if ($735) {
                               break;
                              } else {
                               $$tr$i$i501 = $734;
                              }
                             }
                             HEAP32[$733>>2] = $729;
                             $736 = HEAP32[$729>>2]|0;
                             $737 = ((($736)) + -12|0);
                             $738 = HEAP32[$737>>2]|0;
                             $739 = (($729) + ($738)|0);
                             $740 = ((($739)) + 8|0);
                             $741 = HEAP32[$740>>2]|0;HEAP32[$740>>2] = (($741+1)|0);
                            }
                            $744 = ((($1)) + 228|0);
                            HEAP8[$744>>0] = 0;
                            do {
                             if (!($695)) {
                              $745 = ((($692)) + 8|0);
                              $746 = HEAP32[$745>>2]|0;HEAP32[$745>>2] = (($746-1)|0);
                              $747 = ($746|0)==(1);
                              if (!($747)) {
                               break;
                              }
                              __THREW__ = 0;
                              invoke_viii(3262,($692|0),1,1);
                              $748 = __THREW__; __THREW__ = 0;
                              $749 = $748&1;
                              if (!($749)) {
                               break;
                              }
                              $794 = ___cxa_find_matching_catch_2()|0;
                              $795 = tempRet0;
                              $$22 = $794;$$22130 = $795;
                              break L351;
                             }
                            } while(0);
                            do {
                             if (!($661)) {
                              $750 = ((($658)) + 8|0);
                              $751 = HEAP32[$750>>2]|0;HEAP32[$750>>2] = (($751-1)|0);
                              $752 = ($751|0)==(1);
                              if (!($752)) {
                               break;
                              }
                              __THREW__ = 0;
                              invoke_viii(3262,($658|0),1,1);
                              $753 = __THREW__; __THREW__ = 0;
                              $754 = $753&1;
                              if (!($754)) {
                               break;
                              }
                              $801 = ___cxa_find_matching_catch_2()|0;
                              $802 = tempRet0;
                              $$24 = $801;$$24132 = $802;
                              break L336;
                             }
                            } while(0);
                            do {
                             if (!($628)) {
                              $755 = ((($625)) + 8|0);
                              $756 = HEAP32[$755>>2]|0;HEAP32[$755>>2] = (($756-1)|0);
                              $757 = ($756|0)==(1);
                              if (!($757)) {
                               break;
                              }
                              __THREW__ = 0;
                              invoke_viii(3262,($625|0),1,1);
                              $758 = __THREW__; __THREW__ = 0;
                              $759 = $758&1;
                              if (!($759)) {
                               break;
                              }
                              $808 = ___cxa_find_matching_catch_2()|0;
                              $809 = tempRet0;
                              $$26 = $808;$$26134 = $809;
                              break L320;
                             }
                            } while(0);
                            do {
                             if (!($598)) {
                              $760 = ((($595)) + 8|0);
                              $761 = HEAP32[$760>>2]|0;HEAP32[$760>>2] = (($761-1)|0);
                              $762 = ($761|0)==(1);
                              if (!($762)) {
                               break;
                              }
                              __THREW__ = 0;
                              invoke_viii(3262,($595|0),1,1);
                              $763 = __THREW__; __THREW__ = 0;
                              $764 = $763&1;
                              if (!($764)) {
                               break;
                              }
                              $815 = ___cxa_find_matching_catch_2()|0;
                              $816 = tempRet0;
                              $$32 = $815;$$32140 = $816;
                              break L310;
                             }
                            } while(0);
                            if ($590) {
                             break L305;
                            }
                            $765 = ((($589)) + 8|0);
                            $766 = HEAP32[$765>>2]|0;HEAP32[$765>>2] = (($766-1)|0);
                            $767 = ($766|0)==(1);
                            if (!($767)) {
                             break L305;
                            }
                            __THREW__ = 0;
                            invoke_viii(3262,($589|0),1,1);
                            $768 = __THREW__; __THREW__ = 0;
                            $769 = $768&1;
                            if (!($769)) {
                             break L305;
                            }
                            $827 = ___cxa_find_matching_catch_2()|0;
                            $828 = tempRet0;
                            $$34 = $827;$$34142 = $828;
                            break L298;
                           }
                          } while(0);
                          if ((label|0) == 290) {
                           $788 = ___cxa_find_matching_catch_2()|0;
                           $789 = tempRet0;
                           $$20 = $788;$$20128 = $789;
                          }
                          $796 = ((($692)) + 8|0);
                          $797 = HEAP32[$796>>2]|0;HEAP32[$796>>2] = (($797-1)|0);
                          $798 = ($797|0)==(1);
                          if (!($798)) {
                           $$22 = $$20;$$22130 = $$20128;
                           break;
                          }
                          __THREW__ = 0;
                          invoke_viii(3262,($692|0),1,1);
                          $799 = __THREW__; __THREW__ = 0;
                          $800 = $799&1;
                          if (!($800)) {
                           $$22 = $$20;$$22130 = $$20128;
                           break;
                          }
                          $2128 = ___cxa_find_matching_catch_3(0|0)|0;
                          $2129 = tempRet0;
                          ___clang_call_terminate($2128);
                          // unreachable;
                         }
                        } while(0);
                        if ((label|0) == 288) {
                         $784 = ___cxa_find_matching_catch_2()|0;
                         $785 = tempRet0;
                         $$22 = $784;$$22130 = $785;
                        }
                        if ($661) {
                         $$24 = $$22;$$24132 = $$22130;
                         break;
                        }
                        $803 = ((($658)) + 8|0);
                        $804 = HEAP32[$803>>2]|0;HEAP32[$803>>2] = (($804-1)|0);
                        $805 = ($804|0)==(1);
                        if (!($805)) {
                         $$24 = $$22;$$24132 = $$22130;
                         break;
                        }
                        __THREW__ = 0;
                        invoke_viii(3262,($658|0),1,1);
                        $806 = __THREW__; __THREW__ = 0;
                        $807 = $806&1;
                        if (!($807)) {
                         $$24 = $$22;$$24132 = $$22130;
                         break;
                        }
                        $2128 = ___cxa_find_matching_catch_3(0|0)|0;
                        $2129 = tempRet0;
                        ___clang_call_terminate($2128);
                        // unreachable;
                       }
                      } while(0);
                      if ((label|0) == 287) {
                       $782 = ___cxa_find_matching_catch_2()|0;
                       $783 = tempRet0;
                       $$24 = $782;$$24132 = $783;
                      }
                      if ($628) {
                       $$26 = $$24;$$26134 = $$24132;
                       break;
                      }
                      $810 = ((($625)) + 8|0);
                      $811 = HEAP32[$810>>2]|0;HEAP32[$810>>2] = (($811-1)|0);
                      $812 = ($811|0)==(1);
                      if (!($812)) {
                       $$26 = $$24;$$26134 = $$24132;
                       break;
                      }
                      __THREW__ = 0;
                      invoke_viii(3262,($625|0),1,1);
                      $813 = __THREW__; __THREW__ = 0;
                      $814 = $813&1;
                      if (!($814)) {
                       $$26 = $$24;$$26134 = $$24132;
                       break;
                      }
                      $2128 = ___cxa_find_matching_catch_3(0|0)|0;
                      $2129 = tempRet0;
                      ___clang_call_terminate($2128);
                      // unreachable;
                     }
                    } while(0);
                    if ((label|0) == 286) {
                     $780 = ___cxa_find_matching_catch_2()|0;
                     $781 = tempRet0;
                     $$26 = $780;$$26134 = $781;
                    }
                    if ($598) {
                     $$32 = $$26;$$32140 = $$26134;
                     break;
                    }
                    $817 = ((($595)) + 8|0);
                    $818 = HEAP32[$817>>2]|0;HEAP32[$817>>2] = (($818-1)|0);
                    $819 = ($818|0)==(1);
                    if (!($819)) {
                     $$32 = $$26;$$32140 = $$26134;
                     break;
                    }
                    __THREW__ = 0;
                    invoke_viii(3262,($595|0),1,1);
                    $820 = __THREW__; __THREW__ = 0;
                    $821 = $820&1;
                    if (!($821)) {
                     $$32 = $$26;$$32140 = $$26134;
                     break;
                    }
                    $2128 = ___cxa_find_matching_catch_3(0|0)|0;
                    $2129 = tempRet0;
                    ___clang_call_terminate($2128);
                    // unreachable;
                   }
                  } while(0);
                  if ($590) {
                   $$34 = $$32;$$34142 = $$32140;
                   break L298;
                  }
                  $822 = ((($589)) + 8|0);
                  $823 = HEAP32[$822>>2]|0;HEAP32[$822>>2] = (($823-1)|0);
                  $824 = ($823|0)==(1);
                  if (!($824)) {
                   $$34 = $$32;$$34142 = $$32140;
                   break L298;
                  }
                  __THREW__ = 0;
                  invoke_viii(3262,($589|0),1,1);
                  $825 = __THREW__; __THREW__ = 0;
                  $826 = $825&1;
                  if (!($826)) {
                   $$34 = $$32;$$34142 = $$32140;
                   break L298;
                  }
                  $2128 = ___cxa_find_matching_catch_3(0|0)|0;
                  $2129 = tempRet0;
                  ___clang_call_terminate($2128);
                  // unreachable;
                 }
                } while(0);
                do {
                 if (!($560)) {
                  $829 = ((($557)) + 8|0);
                  $830 = HEAP32[$829>>2]|0;HEAP32[$829>>2] = (($830-1)|0);
                  $831 = ($830|0)==(1);
                  if (!($831)) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_viii(3262,($557|0),1,1);
                  $832 = __THREW__; __THREW__ = 0;
                  $833 = $832&1;
                  if (!($833)) {
                   break;
                  }
                  $839 = ___cxa_find_matching_catch_2()|0;
                  $840 = tempRet0;
                  $$36 = $839;$$36144 = $840;
                  break L284;
                 }
                } while(0);
                if ($526) {
                 label = 788;
                 break L77;
                }
                $834 = ((($523)) + 8|0);
                $835 = HEAP32[$834>>2]|0;HEAP32[$834>>2] = (($835-1)|0);
                $836 = ($835|0)==(1);
                if (!($836)) {
                 label = 788;
                 break L77;
                }
                __THREW__ = 0;
                invoke_viii(3262,($523|0),1,1);
                $837 = __THREW__; __THREW__ = 0;
                $838 = $837&1;
                if (!($838)) {
                 label = 788;
                 break L77;
                }
                $846 = ___cxa_find_matching_catch_2()|0;
                $847 = tempRet0;
                $$104 = $846;$$104212 = $847;
                label = 806;
                break L77;
               }
              } while(0);
              if ((label|0) == 283) {
               $774 = ___cxa_find_matching_catch_2()|0;
               $775 = tempRet0;
               $$34 = $774;$$34142 = $775;
              }
              if ($560) {
               $$36 = $$34;$$36144 = $$34142;
               break;
              }
              $841 = ((($557)) + 8|0);
              $842 = HEAP32[$841>>2]|0;HEAP32[$841>>2] = (($842-1)|0);
              $843 = ($842|0)==(1);
              if (!($843)) {
               $$36 = $$34;$$36144 = $$34142;
               break;
              }
              __THREW__ = 0;
              invoke_viii(3262,($557|0),1,1);
              $844 = __THREW__; __THREW__ = 0;
              $845 = $844&1;
              if (!($845)) {
               $$36 = $$34;$$36144 = $$34142;
               break;
              }
              $2128 = ___cxa_find_matching_catch_3(0|0)|0;
              $2129 = tempRet0;
              ___clang_call_terminate($2128);
              // unreachable;
             }
            }
           }
          }
         } while(0);
         if ((label|0) == 281) {
          $770 = ___cxa_find_matching_catch_2()|0;
          $771 = tempRet0;
          $$36 = $770;$$36144 = $771;
         }
         if ($526) {
          $$104 = $$36;$$104212 = $$36144;
          label = 806;
          break L77;
         }
         $848 = ((($523)) + 8|0);
         $849 = HEAP32[$848>>2]|0;HEAP32[$848>>2] = (($849-1)|0);
         $850 = ($849|0)==(1);
         if (!($850)) {
          $$104 = $$36;$$104212 = $$36144;
          label = 806;
          break L77;
         }
         __THREW__ = 0;
         invoke_viii(3262,($523|0),1,1);
         $851 = __THREW__; __THREW__ = 0;
         $852 = $851&1;
         if (!($852)) {
          $$104 = $$36;$$104212 = $$36144;
          label = 806;
          break L77;
         }
         $2128 = ___cxa_find_matching_catch_3(0|0)|0;
         $2129 = tempRet0;
         ___clang_call_terminate($2128);
         // unreachable;
        }
       }
       break;
      }
      case 2:  {
       __THREW__ = 0;
       invoke_vii(3338,($1|0),(0|0));
       $853 = __THREW__; __THREW__ = 0;
       $854 = $853&1;
       if (!($854)) {
        $855 = ((($2)) + 40|0);
        $856 = HEAP32[$855>>2]|0;
        $857 = ($856|0)==(0);
        $858 = ((($142)) + 40|0);
        $859 = HEAP32[$858>>2]|0;
        $860 = (($859|0) / 2)&-1;
        $$ = $857 ? 0 : $860;
        $$1155 = $857 ? $860 : 0;
        $861 = ((($142)) + 44|0);
        $862 = HEAP32[$861>>2]|0;
        $863 = ((($142)) + 110|0);
        $864 = HEAP8[$863>>0]|0;
        $865 = ($864<<24>>24)!=(0);
        $866 = $865 ? 1029 : 1028;
        __THREW__ = 0;
        $867 = (invoke_iiiiiiiiid(3355,($0|0),($2|0),($137|0),($$|0),0,($860|0),($862|0),($866|0),-1.0)|0);
        $868 = __THREW__; __THREW__ = 0;
        $869 = $868&1;
        if ($869) {
         $1065 = ___cxa_find_matching_catch_2()|0;
         $1066 = tempRet0;
         $$104 = $1065;$$104212 = $1066;
         label = 806;
         break L77;
        }
        $870 = ($867|0)==(0|0);
        if (!($870)) {
         $871 = ((($867)) + 8|0);
         $872 = HEAP32[$871>>2]|0;HEAP32[$871>>2] = (($872+1)|0);
        }
        $873 = HEAP32[$858>>2]|0;
        $874 = (($873|0) / 2)&-1;
        $875 = HEAP32[$861>>2]|0;
        $876 = HEAP8[$863>>0]|0;
        $877 = ($876<<24>>24)!=(0);
        $878 = $877 ? 1029 : 1028;
        __THREW__ = 0;
        $879 = (invoke_iiiiiiiiid(3355,($0|0),($2|0),($137|0),($$1155|0),0,($874|0),($875|0),($878|0),1.0)|0);
        $880 = __THREW__; __THREW__ = 0;
        $881 = $880&1;
        L461: do {
         if ($881) {
          $1067 = ___cxa_find_matching_catch_2()|0;
          $1068 = tempRet0;
          $$52 = $1067;$$52160 = $1068;
         } else {
          $882 = ($879|0)==(0|0);
          if (!($882)) {
           $883 = ((($879)) + 8|0);
           $884 = HEAP32[$883>>2]|0;HEAP32[$883>>2] = (($884+1)|0);
          }
          $885 = HEAP32[$5>>2]|0;
          $886 = HEAP32[$22>>2]|0;
          $887 = ($885|0)==($886|0);
          L467: do {
           if (!($887)) {
            $888 = HEAP32[$885>>2]|0;
            $889 = ($888|0)==(0|0);
            if ($889) {
             $893 = $885;
            } else {
             $890 = ((($888)) + 8|0);
             $891 = HEAP32[$890>>2]|0;HEAP32[$890>>2] = (($891+1)|0);
             $$pre1194 = HEAP32[$5>>2]|0;
             $893 = $$pre1194;
            }
            $892 = ((($893)) + 4|0);
            $894 = HEAP32[$892>>2]|0;
            $895 = ($894|0)==(0|0);
            if (!($895)) {
             $896 = ((($894)) + 8|0);
             $897 = HEAP32[$896>>2]|0;HEAP32[$896>>2] = (($897+1)|0);
            }
            $898 = HEAP32[$858>>2]|0;
            $899 = (($898|0) / 2)&-1;
            $900 = HEAP32[$861>>2]|0;
            __THREW__ = 0;
            $901 = (invoke_iiii(3350,0,($899|0),($900|0))|0);
            $902 = __THREW__; __THREW__ = 0;
            $903 = $902&1;
            L475: do {
             if ($903) {
              $1069 = ___cxa_find_matching_catch_2()|0;
              $1070 = tempRet0;
              $$46 = $1069;$$46154 = $1070;
              label = 417;
             } else {
              $904 = ($901|0)==(0|0);
              if (!($904)) {
               $905 = ((($901)) + 8|0);
               $906 = HEAP32[$905>>2]|0;HEAP32[$905>>2] = (($906+1)|0);
              }
              $907 = HEAP32[$858>>2]|0;
              $908 = (($907|0) / 2)&-1;
              $909 = HEAP32[$861>>2]|0;
              __THREW__ = 0;
              invoke_viiiii(3356,($867|0),0,0,($908|0),($909|0));
              $910 = __THREW__; __THREW__ = 0;
              $911 = $910&1;
              L481: do {
               if ($911) {
                label = 395;
               } else {
                $912 = ((($867)) + 568|0);
                HEAP32[$912>>2] = 1028;
                $913 = ((($867)) + 152|0);
                $914 = HEAP32[$913>>2]|0;
                $915 = ($914|0)==(0);
                $916 = ((($867)) + 148|0);
                if ($915) {
                 $918 = HEAP32[$916>>2]|0;
                 $919 = $918 & -131073;
                 HEAP32[$916>>2] = $919;
                 $920 = ((($867)) + 572|0);
                 HEAP32[$920>>2] = 1028;
                 $921 = $918 & -393217;
                 HEAP32[$916>>2] = $921;
                } else {
                 $917 = ((($867)) + 572|0);
                 HEAP32[$917>>2] = 1028;
                }
                $922 = ((($867)) + 228|0);
                HEAP8[$922>>0] = 1;
                $923 = ((($867)) + 560|0);
                HEAP32[$923>>2] = 1;
                $924 = ((($867)) + 564|0);
                HEAP32[$924>>2] = 0;
                __THREW__ = 0;
                invoke_vii(3341,($867|0),0);
                $925 = __THREW__; __THREW__ = 0;
                $926 = $925&1;
                if ($926) {
                 label = 395;
                 break;
                }
                __THREW__ = 0;
                invoke_viiiiiiii(3342,($867|0),3,($901|0),0,0,0,0,0);
                $927 = __THREW__; __THREW__ = 0;
                $928 = $927&1;
                if ($928) {
                 label = 395;
                 break;
                }
                $929 = HEAP32[$858>>2]|0;
                $930 = (($929|0) / 2)&-1;
                $931 = HEAP32[$861>>2]|0;
                __THREW__ = 0;
                $932 = (invoke_iiii(3350,0,($930|0),($931|0))|0);
                $933 = __THREW__; __THREW__ = 0;
                $934 = $933&1;
                if ($934) {
                 label = 395;
                 break;
                }
                $935 = ($932|0)==(0|0);
                if (!($935)) {
                 $936 = ((($932)) + 8|0);
                 $937 = HEAP32[$936>>2]|0;HEAP32[$936>>2] = (($937+1)|0);
                }
                $938 = HEAP32[$858>>2]|0;
                $939 = (($938|0) / 2)&-1;
                $940 = HEAP32[$861>>2]|0;
                __THREW__ = 0;
                invoke_viiiii(3356,($879|0),0,0,($939|0),($940|0));
                $941 = __THREW__; __THREW__ = 0;
                $942 = $941&1;
                L493: do {
                 if ($942) {
                  label = 396;
                 } else {
                  $943 = ((($879)) + 568|0);
                  HEAP32[$943>>2] = 1028;
                  $944 = ((($879)) + 152|0);
                  $945 = HEAP32[$944>>2]|0;
                  $946 = ($945|0)==(0);
                  $947 = ((($879)) + 148|0);
                  if ($946) {
                   $949 = HEAP32[$947>>2]|0;
                   $950 = $949 & -131073;
                   HEAP32[$947>>2] = $950;
                   $951 = ((($879)) + 572|0);
                   HEAP32[$951>>2] = 1028;
                   $952 = $949 & -393217;
                   HEAP32[$947>>2] = $952;
                  } else {
                   $948 = ((($879)) + 572|0);
                   HEAP32[$948>>2] = 1028;
                  }
                  $953 = ((($879)) + 228|0);
                  HEAP8[$953>>0] = 1;
                  $954 = ((($879)) + 560|0);
                  HEAP32[$954>>2] = 1;
                  $955 = ((($879)) + 564|0);
                  HEAP32[$955>>2] = 1;
                  __THREW__ = 0;
                  invoke_vii(3341,($879|0),0);
                  $956 = __THREW__; __THREW__ = 0;
                  $957 = $956&1;
                  if ($957) {
                   label = 396;
                   break;
                  }
                  __THREW__ = 0;
                  invoke_viiiiiiii(3342,($879|0),3,($932|0),0,0,0,0,0);
                  $958 = __THREW__; __THREW__ = 0;
                  $959 = $958&1;
                  if ($959) {
                   label = 396;
                   break;
                  }
                  $$sroa$0788$0$$sroa_idx = ((($888)) + 36|0);
                  HEAPF32[$$sroa$0788$0$$sroa_idx>>2] = 1.0;
                  $$sroa$4790$0$$sroa_idx792 = ((($888)) + 40|0);
                  HEAPF32[$$sroa$4790$0$$sroa_idx792>>2] = 0.0;
                  $$sroa$5793$0$$sroa_idx795 = ((($888)) + 44|0);
                  HEAPF32[$$sroa$5793$0$$sroa_idx795>>2] = 0.0;
                  $$sroa$6796$0$$sroa_idx798 = ((($888)) + 48|0);
                  HEAPF32[$$sroa$6796$0$$sroa_idx798>>2] = 1.0;
                  $960 = HEAP32[$858>>2]|0;
                  $961 = (($960|0) / 2)&-1;
                  $962 = HEAP32[$861>>2]|0;
                  $963 = HEAP8[$863>>0]|0;
                  $964 = ($963<<24>>24)!=(0);
                  $965 = $964 ? 1029 : 1028;
                  __THREW__ = 0;
                  $966 = (invoke_iiiiiiiiiii(3352,($0|0),($2|0),($137|0),($$|0),0,($961|0),($962|0),($965|0),($901|0),($888|0))|0);
                  $967 = __THREW__; __THREW__ = 0;
                  $968 = $967&1;
                  if ($968) {
                   label = 396;
                   break;
                  }
                  $969 = ($966|0)==(0|0);
                  if (!($969)) {
                   $970 = ((($966)) + 8|0);
                   $971 = HEAP32[$970>>2]|0;HEAP32[$970>>2] = (($971+1)|0);
                  }
                  $972 = ((($966)) + 560|0);
                  HEAP32[$972>>2] = 1;
                  $973 = ((($966)) + 564|0);
                  HEAP32[$973>>2] = 2;
                  __THREW__ = 0;
                  $974 = (invoke_ii(3276,152)|0);
                  $975 = __THREW__; __THREW__ = 0;
                  $976 = $975&1;
                  L505: do {
                   if ($976) {
                    label = 397;
                   } else {
                    __THREW__ = 0;
                    invoke_vii(3353,($974|0),($888|0));
                    $977 = __THREW__; __THREW__ = 0;
                    $978 = $977&1;
                    if ($978) {
                     $1077 = ___cxa_find_matching_catch_2()|0;
                     $1078 = tempRet0;
                     __ZdlPv($974);
                     $$40 = $1077;$$40148 = $1078;
                     break;
                    }
                    $979 = HEAP32[$974>>2]|0;
                    $980 = ((($979)) + -12|0);
                    $981 = HEAP32[$980>>2]|0;
                    $982 = (($974) + ($981)|0);
                    $983 = ((($966)) + 92|0);
                    $984 = HEAP32[$983>>2]|0;
                    $985 = ($984|0)==(0|0);
                    if ($985) {
                     __THREW__ = 0;
                     invoke_vii(3354,($966|0),($982|0));
                     $995 = __THREW__; __THREW__ = 0;
                     $996 = $995&1;
                     if ($996) {
                      label = 397;
                      break;
                     }
                    } else {
                     $$tr$i$i451 = $984;
                     while(1) {
                      $986 = ((($$tr$i$i451)) + 4|0);
                      $987 = HEAP32[$986>>2]|0;
                      $988 = ($987|0)==(0|0);
                      if ($988) {
                       break;
                      } else {
                       $$tr$i$i451 = $987;
                      }
                     }
                     HEAP32[$986>>2] = $982;
                     $989 = HEAP32[$982>>2]|0;
                     $990 = ((($989)) + -12|0);
                     $991 = HEAP32[$990>>2]|0;
                     $992 = (($982) + ($991)|0);
                     $993 = ((($992)) + 8|0);
                     $994 = HEAP32[$993>>2]|0;HEAP32[$993>>2] = (($994+1)|0);
                    }
                    $$sroa$0771$0$$sroa_idx = ((($894)) + 36|0);
                    HEAPF32[$$sroa$0771$0$$sroa_idx>>2] = 0.0;
                    $$sroa$4773$0$$sroa_idx775 = ((($894)) + 40|0);
                    HEAPF32[$$sroa$4773$0$$sroa_idx775>>2] = 1.0;
                    $$sroa$5776$0$$sroa_idx778 = ((($894)) + 44|0);
                    HEAPF32[$$sroa$5776$0$$sroa_idx778>>2] = 0.0;
                    $$sroa$6779$0$$sroa_idx781 = ((($894)) + 48|0);
                    HEAPF32[$$sroa$6779$0$$sroa_idx781>>2] = 1.0;
                    $997 = HEAP32[$858>>2]|0;
                    $998 = (($997|0) / 2)&-1;
                    $999 = HEAP32[$861>>2]|0;
                    $1000 = HEAP8[$863>>0]|0;
                    $1001 = ($1000<<24>>24)!=(0);
                    $1002 = $1001 ? 1029 : 1028;
                    __THREW__ = 0;
                    $1003 = (invoke_iiiiiiiiiii(3352,($0|0),($2|0),($137|0),($$1155|0),0,($998|0),($999|0),($1002|0),($932|0),($894|0))|0);
                    $1004 = __THREW__; __THREW__ = 0;
                    $1005 = $1004&1;
                    if ($1005) {
                     label = 397;
                     break;
                    }
                    $1006 = ($1003|0)==(0|0);
                    if (!($1006)) {
                     $1007 = ((($1003)) + 8|0);
                     $1008 = HEAP32[$1007>>2]|0;HEAP32[$1007>>2] = (($1008+1)|0);
                    }
                    $1009 = ((($1003)) + 560|0);
                    HEAP32[$1009>>2] = 1;
                    $1010 = ((($1003)) + 564|0);
                    HEAP32[$1010>>2] = 3;
                    __THREW__ = 0;
                    $1011 = (invoke_ii(3276,152)|0);
                    $1012 = __THREW__; __THREW__ = 0;
                    $1013 = $1012&1;
                    do {
                     if ($1013) {
                      label = 399;
                     } else {
                      __THREW__ = 0;
                      invoke_vii(3353,($1011|0),($894|0));
                      $1014 = __THREW__; __THREW__ = 0;
                      $1015 = $1014&1;
                      if ($1015) {
                       $1081 = ___cxa_find_matching_catch_2()|0;
                       $1082 = tempRet0;
                       __ZdlPv($1011);
                       $$38 = $1081;$$38146 = $1082;
                       break;
                      }
                      $1016 = HEAP32[$1011>>2]|0;
                      $1017 = ((($1016)) + -12|0);
                      $1018 = HEAP32[$1017>>2]|0;
                      $1019 = (($1011) + ($1018)|0);
                      $1020 = ((($1003)) + 92|0);
                      $1021 = HEAP32[$1020>>2]|0;
                      $1022 = ($1021|0)==(0|0);
                      if ($1022) {
                       __THREW__ = 0;
                       invoke_vii(3354,($1003|0),($1019|0));
                       $1032 = __THREW__; __THREW__ = 0;
                       $1033 = $1032&1;
                       if ($1033) {
                        label = 399;
                        break;
                       }
                      } else {
                       $$tr$i$i445 = $1021;
                       while(1) {
                        $1023 = ((($$tr$i$i445)) + 4|0);
                        $1024 = HEAP32[$1023>>2]|0;
                        $1025 = ($1024|0)==(0|0);
                        if ($1025) {
                         break;
                        } else {
                         $$tr$i$i445 = $1024;
                        }
                       }
                       HEAP32[$1023>>2] = $1019;
                       $1026 = HEAP32[$1019>>2]|0;
                       $1027 = ((($1026)) + -12|0);
                       $1028 = HEAP32[$1027>>2]|0;
                       $1029 = (($1019) + ($1028)|0);
                       $1030 = ((($1029)) + 8|0);
                       $1031 = HEAP32[$1030>>2]|0;HEAP32[$1030>>2] = (($1031+1)|0);
                      }
                      $1034 = ((($1)) + 228|0);
                      HEAP8[$1034>>0] = 0;
                      do {
                       if (!($1006)) {
                        $1035 = ((($1003)) + 8|0);
                        $1036 = HEAP32[$1035>>2]|0;HEAP32[$1035>>2] = (($1036-1)|0);
                        $1037 = ($1036|0)==(1);
                        if (!($1037)) {
                         break;
                        }
                        __THREW__ = 0;
                        invoke_viii(3262,($1003|0),1,1);
                        $1038 = __THREW__; __THREW__ = 0;
                        $1039 = $1038&1;
                        if (!($1039)) {
                         break;
                        }
                        $1083 = ___cxa_find_matching_catch_2()|0;
                        $1084 = tempRet0;
                        $$40 = $1083;$$40148 = $1084;
                        break L505;
                       }
                      } while(0);
                      do {
                       if (!($969)) {
                        $1040 = ((($966)) + 8|0);
                        $1041 = HEAP32[$1040>>2]|0;HEAP32[$1040>>2] = (($1041-1)|0);
                        $1042 = ($1041|0)==(1);
                        if (!($1042)) {
                         break;
                        }
                        __THREW__ = 0;
                        invoke_viii(3262,($966|0),1,1);
                        $1043 = __THREW__; __THREW__ = 0;
                        $1044 = $1043&1;
                        if (!($1044)) {
                         break;
                        }
                        $1090 = ___cxa_find_matching_catch_2()|0;
                        $1091 = tempRet0;
                        $$42 = $1090;$$42150 = $1091;
                        break L493;
                       }
                      } while(0);
                      do {
                       if (!($935)) {
                        $1045 = ((($932)) + 8|0);
                        $1046 = HEAP32[$1045>>2]|0;HEAP32[$1045>>2] = (($1046-1)|0);
                        $1047 = ($1046|0)==(1);
                        if (!($1047)) {
                         break;
                        }
                        __THREW__ = 0;
                        invoke_viii(3262,($932|0),1,1);
                        $1048 = __THREW__; __THREW__ = 0;
                        $1049 = $1048&1;
                        if (!($1049)) {
                         break;
                        }
                        $1097 = ___cxa_find_matching_catch_2()|0;
                        $1098 = tempRet0;
                        $$44 = $1097;$$44152 = $1098;
                        break L481;
                       }
                      } while(0);
                      do {
                       if (!($904)) {
                        $1050 = ((($901)) + 8|0);
                        $1051 = HEAP32[$1050>>2]|0;HEAP32[$1050>>2] = (($1051-1)|0);
                        $1052 = ($1051|0)==(1);
                        if (!($1052)) {
                         break;
                        }
                        __THREW__ = 0;
                        invoke_viii(3262,($901|0),1,1);
                        $1053 = __THREW__; __THREW__ = 0;
                        $1054 = $1053&1;
                        if (!($1054)) {
                         break;
                        }
                        $1104 = ___cxa_find_matching_catch_2()|0;
                        $1105 = tempRet0;
                        $$46 = $1104;$$46154 = $1105;
                        label = 417;
                        break L475;
                       }
                      } while(0);
                      do {
                       if (!($895)) {
                        $1055 = ((($894)) + 8|0);
                        $1056 = HEAP32[$1055>>2]|0;HEAP32[$1055>>2] = (($1056-1)|0);
                        $1057 = ($1056|0)==(1);
                        if (!($1057)) {
                         break;
                        }
                        __THREW__ = 0;
                        invoke_viii(3262,($894|0),1,1);
                        $1058 = __THREW__; __THREW__ = 0;
                        $1059 = $1058&1;
                        if (!($1059)) {
                         break;
                        }
                        $1111 = ___cxa_find_matching_catch_2()|0;
                        $1112 = tempRet0;
                        $$47 = $1111;$$47155 = $1112;
                        label = 421;
                        break L475;
                       }
                      } while(0);
                      if ($889) {
                       break L467;
                      }
                      $1060 = ((($888)) + 8|0);
                      $1061 = HEAP32[$1060>>2]|0;HEAP32[$1060>>2] = (($1061-1)|0);
                      $1062 = ($1061|0)==(1);
                      if (!($1062)) {
                       break L467;
                      }
                      __THREW__ = 0;
                      invoke_viii(3262,($888|0),1,1);
                      $1063 = __THREW__; __THREW__ = 0;
                      $1064 = $1063&1;
                      if (!($1064)) {
                       break L467;
                      }
                      $1118 = ___cxa_find_matching_catch_2()|0;
                      $1119 = tempRet0;
                      $$49 = $1118;$$49157 = $1119;
                      break L475;
                     }
                    } while(0);
                    if ((label|0) == 399) {
                     $1079 = ___cxa_find_matching_catch_2()|0;
                     $1080 = tempRet0;
                     $$38 = $1079;$$38146 = $1080;
                    }
                    $1085 = ((($1003)) + 8|0);
                    $1086 = HEAP32[$1085>>2]|0;HEAP32[$1085>>2] = (($1086-1)|0);
                    $1087 = ($1086|0)==(1);
                    if (!($1087)) {
                     $$40 = $$38;$$40148 = $$38146;
                     break;
                    }
                    __THREW__ = 0;
                    invoke_viii(3262,($1003|0),1,1);
                    $1088 = __THREW__; __THREW__ = 0;
                    $1089 = $1088&1;
                    if (!($1089)) {
                     $$40 = $$38;$$40148 = $$38146;
                     break;
                    }
                    $2128 = ___cxa_find_matching_catch_3(0|0)|0;
                    $2129 = tempRet0;
                    ___clang_call_terminate($2128);
                    // unreachable;
                   }
                  } while(0);
                  if ((label|0) == 397) {
                   $1075 = ___cxa_find_matching_catch_2()|0;
                   $1076 = tempRet0;
                   $$40 = $1075;$$40148 = $1076;
                  }
                  if ($969) {
                   $$42 = $$40;$$42150 = $$40148;
                   break;
                  }
                  $1092 = ((($966)) + 8|0);
                  $1093 = HEAP32[$1092>>2]|0;HEAP32[$1092>>2] = (($1093-1)|0);
                  $1094 = ($1093|0)==(1);
                  if (!($1094)) {
                   $$42 = $$40;$$42150 = $$40148;
                   break;
                  }
                  __THREW__ = 0;
                  invoke_viii(3262,($966|0),1,1);
                  $1095 = __THREW__; __THREW__ = 0;
                  $1096 = $1095&1;
                  if (!($1096)) {
                   $$42 = $$40;$$42150 = $$40148;
                   break;
                  }
                  $2128 = ___cxa_find_matching_catch_3(0|0)|0;
                  $2129 = tempRet0;
                  ___clang_call_terminate($2128);
                  // unreachable;
                 }
                } while(0);
                if ((label|0) == 396) {
                 $1073 = ___cxa_find_matching_catch_2()|0;
                 $1074 = tempRet0;
                 $$42 = $1073;$$42150 = $1074;
                }
                if ($935) {
                 $$44 = $$42;$$44152 = $$42150;
                 break;
                }
                $1099 = ((($932)) + 8|0);
                $1100 = HEAP32[$1099>>2]|0;HEAP32[$1099>>2] = (($1100-1)|0);
                $1101 = ($1100|0)==(1);
                if (!($1101)) {
                 $$44 = $$42;$$44152 = $$42150;
                 break;
                }
                __THREW__ = 0;
                invoke_viii(3262,($932|0),1,1);
                $1102 = __THREW__; __THREW__ = 0;
                $1103 = $1102&1;
                if (!($1103)) {
                 $$44 = $$42;$$44152 = $$42150;
                 break;
                }
                $2128 = ___cxa_find_matching_catch_3(0|0)|0;
                $2129 = tempRet0;
                ___clang_call_terminate($2128);
                // unreachable;
               }
              } while(0);
              if ((label|0) == 395) {
               $1071 = ___cxa_find_matching_catch_2()|0;
               $1072 = tempRet0;
               $$44 = $1071;$$44152 = $1072;
              }
              if ($904) {
               $$46 = $$44;$$46154 = $$44152;
               label = 417;
               break;
              }
              $1106 = ((($901)) + 8|0);
              $1107 = HEAP32[$1106>>2]|0;HEAP32[$1106>>2] = (($1107-1)|0);
              $1108 = ($1107|0)==(1);
              if (!($1108)) {
               $$46 = $$44;$$46154 = $$44152;
               label = 417;
               break;
              }
              __THREW__ = 0;
              invoke_viii(3262,($901|0),1,1);
              $1109 = __THREW__; __THREW__ = 0;
              $1110 = $1109&1;
              if (!($1110)) {
               $$46 = $$44;$$46154 = $$44152;
               label = 417;
               break;
              }
              $2128 = ___cxa_find_matching_catch_3(0|0)|0;
              $2129 = tempRet0;
              ___clang_call_terminate($2128);
              // unreachable;
             }
            } while(0);
            do {
             if ((label|0) == 417) {
              if ($895) {
               $$47 = $$46;$$47155 = $$46154;
               label = 421;
               break;
              }
              $1113 = ((($894)) + 8|0);
              $1114 = HEAP32[$1113>>2]|0;HEAP32[$1113>>2] = (($1114-1)|0);
              $1115 = ($1114|0)==(1);
              if (!($1115)) {
               $$47 = $$46;$$47155 = $$46154;
               label = 421;
               break;
              }
              __THREW__ = 0;
              invoke_viii(3262,($894|0),1,1);
              $1116 = __THREW__; __THREW__ = 0;
              $1117 = $1116&1;
              if (!($1117)) {
               $$47 = $$46;$$47155 = $$46154;
               label = 421;
               break;
              }
              $2128 = ___cxa_find_matching_catch_3(0|0)|0;
              $2129 = tempRet0;
              ___clang_call_terminate($2128);
              // unreachable;
             }
            } while(0);
            do {
             if ((label|0) == 421) {
              if ($889) {
               $$49 = $$47;$$49157 = $$47155;
               break;
              }
              $1120 = ((($888)) + 8|0);
              $1121 = HEAP32[$1120>>2]|0;HEAP32[$1120>>2] = (($1121-1)|0);
              $1122 = ($1121|0)==(1);
              if (!($1122)) {
               $$49 = $$47;$$49157 = $$47155;
               break;
              }
              __THREW__ = 0;
              invoke_viii(3262,($888|0),1,1);
              $1123 = __THREW__; __THREW__ = 0;
              $1124 = $1123&1;
              if (!($1124)) {
               $$49 = $$47;$$49157 = $$47155;
               break;
              }
              $2128 = ___cxa_find_matching_catch_3(0|0)|0;
              $2129 = tempRet0;
              ___clang_call_terminate($2128);
              // unreachable;
             }
            } while(0);
            if ($882) {
             $$52 = $$49;$$52160 = $$49157;
             break L461;
            }
            $1137 = ((($879)) + 8|0);
            $1138 = HEAP32[$1137>>2]|0;HEAP32[$1137>>2] = (($1138-1)|0);
            $1139 = ($1138|0)==(1);
            if (!($1139)) {
             $$52 = $$49;$$52160 = $$49157;
             break L461;
            }
            __THREW__ = 0;
            invoke_viii(3262,($879|0),1,1);
            $1140 = __THREW__; __THREW__ = 0;
            $1141 = $1140&1;
            if (!($1141)) {
             $$52 = $$49;$$52160 = $$49157;
             break L461;
            }
            $2128 = ___cxa_find_matching_catch_3(0|0)|0;
            $2129 = tempRet0;
            ___clang_call_terminate($2128);
            // unreachable;
           }
          } while(0);
          do {
           if (!($882)) {
            $1125 = ((($879)) + 8|0);
            $1126 = HEAP32[$1125>>2]|0;HEAP32[$1125>>2] = (($1126-1)|0);
            $1127 = ($1126|0)==(1);
            if ($1127) {
             __THREW__ = 0;
             invoke_viii(3262,($879|0),1,1);
             $1128 = __THREW__; __THREW__ = 0;
             $1129 = $1128&1;
             if (!($1129)) {
              break;
             }
             $1135 = ___cxa_find_matching_catch_2()|0;
             $1136 = tempRet0;
             $$52 = $1135;$$52160 = $1136;
             break L461;
            }
           }
          } while(0);
          if ($870) {
           label = 788;
           break L77;
          }
          $1130 = ((($867)) + 8|0);
          $1131 = HEAP32[$1130>>2]|0;HEAP32[$1130>>2] = (($1131-1)|0);
          $1132 = ($1131|0)==(1);
          if (!($1132)) {
           label = 788;
           break L77;
          }
          __THREW__ = 0;
          invoke_viii(3262,($867|0),1,1);
          $1133 = __THREW__; __THREW__ = 0;
          $1134 = $1133&1;
          if (!($1134)) {
           label = 788;
           break L77;
          }
          $1142 = ___cxa_find_matching_catch_2()|0;
          $1143 = tempRet0;
          $$104 = $1142;$$104212 = $1143;
          label = 806;
          break L77;
         }
        } while(0);
        if ($870) {
         $$104 = $$52;$$104212 = $$52160;
         label = 806;
         break L77;
        }
        $1144 = ((($867)) + 8|0);
        $1145 = HEAP32[$1144>>2]|0;HEAP32[$1144>>2] = (($1145-1)|0);
        $1146 = ($1145|0)==(1);
        if (!($1146)) {
         $$104 = $$52;$$104212 = $$52160;
         label = 806;
         break L77;
        }
        __THREW__ = 0;
        invoke_viii(3262,($867|0),1,1);
        $1147 = __THREW__; __THREW__ = 0;
        $1148 = $1147&1;
        if (!($1148)) {
         $$104 = $$52;$$104212 = $$52160;
         label = 806;
         break L77;
        }
        $2128 = ___cxa_find_matching_catch_3(0|0)|0;
        $2129 = tempRet0;
        ___clang_call_terminate($2128);
        // unreachable;
       }
       break;
      }
      case 3:  {
       __THREW__ = 0;
       invoke_vii(3338,($1|0),(0|0));
       $1149 = __THREW__; __THREW__ = 0;
       $1150 = $1149&1;
       if (!($1150)) {
        $1151 = ((($2)) + 48|0);
        $1152 = HEAP32[$1151>>2]|0;
        $1153 = ($1152|0)==(1);
        $1154 = ((($142)) + 44|0);
        $1155 = HEAP32[$1154>>2]|0;
        $1156 = (($1155|0) / 2)&-1;
        $$1156 = $1153 ? 0 : $1156;
        $$1157 = $1153 ? $1156 : 0;
        $1157 = ((($142)) + 40|0);
        $1158 = HEAP32[$1157>>2]|0;
        $1159 = ((($142)) + 110|0);
        $1160 = HEAP8[$1159>>0]|0;
        $1161 = ($1160<<24>>24)!=(0);
        $1162 = $1161 ? 1029 : 1028;
        __THREW__ = 0;
        $1163 = (invoke_iiiiiiiiid(3355,($0|0),($2|0),($137|0),0,($$1156|0),($1158|0),($1156|0),($1162|0),-1.0)|0);
        $1164 = __THREW__; __THREW__ = 0;
        $1165 = $1164&1;
        if ($1165) {
         $1361 = ___cxa_find_matching_catch_2()|0;
         $1362 = tempRet0;
         $$104 = $1361;$$104212 = $1362;
         label = 806;
         break L77;
        }
        $1166 = ($1163|0)==(0|0);
        if (!($1166)) {
         $1167 = ((($1163)) + 8|0);
         $1168 = HEAP32[$1167>>2]|0;HEAP32[$1167>>2] = (($1168+1)|0);
        }
        $1169 = HEAP32[$1157>>2]|0;
        $1170 = HEAP32[$1154>>2]|0;
        $1171 = (($1170|0) / 2)&-1;
        $1172 = HEAP8[$1159>>0]|0;
        $1173 = ($1172<<24>>24)!=(0);
        $1174 = $1173 ? 1029 : 1028;
        __THREW__ = 0;
        $1175 = (invoke_iiiiiiiiid(3355,($0|0),($2|0),($137|0),0,($$1157|0),($1169|0),($1171|0),($1174|0),1.0)|0);
        $1176 = __THREW__; __THREW__ = 0;
        $1177 = $1176&1;
        L617: do {
         if ($1177) {
          $1363 = ___cxa_find_matching_catch_2()|0;
          $1364 = tempRet0;
          $$69 = $1363;$$69177 = $1364;
         } else {
          $1178 = ($1175|0)==(0|0);
          if (!($1178)) {
           $1179 = ((($1175)) + 8|0);
           $1180 = HEAP32[$1179>>2]|0;HEAP32[$1179>>2] = (($1180+1)|0);
          }
          $1181 = HEAP32[$5>>2]|0;
          $1182 = HEAP32[$22>>2]|0;
          $1183 = ($1181|0)==($1182|0);
          L623: do {
           if (!($1183)) {
            $1184 = HEAP32[$1181>>2]|0;
            $1185 = ($1184|0)==(0|0);
            if ($1185) {
             $1189 = $1181;
            } else {
             $1186 = ((($1184)) + 8|0);
             $1187 = HEAP32[$1186>>2]|0;HEAP32[$1186>>2] = (($1187+1)|0);
             $$pre1193 = HEAP32[$5>>2]|0;
             $1189 = $$pre1193;
            }
            $1188 = ((($1189)) + 4|0);
            $1190 = HEAP32[$1188>>2]|0;
            $1191 = ($1190|0)==(0|0);
            if (!($1191)) {
             $1192 = ((($1190)) + 8|0);
             $1193 = HEAP32[$1192>>2]|0;HEAP32[$1192>>2] = (($1193+1)|0);
            }
            $1194 = HEAP32[$1157>>2]|0;
            $1195 = HEAP32[$1154>>2]|0;
            $1196 = (($1195|0) / 2)&-1;
            __THREW__ = 0;
            $1197 = (invoke_iiii(3350,0,($1194|0),($1196|0))|0);
            $1198 = __THREW__; __THREW__ = 0;
            $1199 = $1198&1;
            L631: do {
             if ($1199) {
              $1365 = ___cxa_find_matching_catch_2()|0;
              $1366 = tempRet0;
              $$63 = $1365;$$63171 = $1366;
              label = 529;
             } else {
              $1200 = ($1197|0)==(0|0);
              if (!($1200)) {
               $1201 = ((($1197)) + 8|0);
               $1202 = HEAP32[$1201>>2]|0;HEAP32[$1201>>2] = (($1202+1)|0);
              }
              $1203 = HEAP32[$1157>>2]|0;
              $1204 = HEAP32[$1154>>2]|0;
              $1205 = (($1204|0) / 2)&-1;
              __THREW__ = 0;
              invoke_viiiii(3356,($1163|0),0,0,($1203|0),($1205|0));
              $1206 = __THREW__; __THREW__ = 0;
              $1207 = $1206&1;
              L637: do {
               if ($1207) {
                label = 507;
               } else {
                $1208 = ((($1163)) + 568|0);
                HEAP32[$1208>>2] = 1028;
                $1209 = ((($1163)) + 152|0);
                $1210 = HEAP32[$1209>>2]|0;
                $1211 = ($1210|0)==(0);
                $1212 = ((($1163)) + 148|0);
                if ($1211) {
                 $1214 = HEAP32[$1212>>2]|0;
                 $1215 = $1214 & -131073;
                 HEAP32[$1212>>2] = $1215;
                 $1216 = ((($1163)) + 572|0);
                 HEAP32[$1216>>2] = 1028;
                 $1217 = $1214 & -393217;
                 HEAP32[$1212>>2] = $1217;
                } else {
                 $1213 = ((($1163)) + 572|0);
                 HEAP32[$1213>>2] = 1028;
                }
                $1218 = ((($1163)) + 228|0);
                HEAP8[$1218>>0] = 1;
                $1219 = ((($1163)) + 560|0);
                HEAP32[$1219>>2] = 1;
                $1220 = ((($1163)) + 564|0);
                HEAP32[$1220>>2] = 0;
                __THREW__ = 0;
                invoke_vii(3341,($1163|0),0);
                $1221 = __THREW__; __THREW__ = 0;
                $1222 = $1221&1;
                if ($1222) {
                 label = 507;
                 break;
                }
                __THREW__ = 0;
                invoke_viiiiiiii(3342,($1163|0),3,($1197|0),0,0,0,0,0);
                $1223 = __THREW__; __THREW__ = 0;
                $1224 = $1223&1;
                if ($1224) {
                 label = 507;
                 break;
                }
                $1225 = HEAP32[$1157>>2]|0;
                $1226 = HEAP32[$1154>>2]|0;
                $1227 = (($1226|0) / 2)&-1;
                __THREW__ = 0;
                $1228 = (invoke_iiii(3350,0,($1225|0),($1227|0))|0);
                $1229 = __THREW__; __THREW__ = 0;
                $1230 = $1229&1;
                if ($1230) {
                 label = 507;
                 break;
                }
                $1231 = ($1228|0)==(0|0);
                if (!($1231)) {
                 $1232 = ((($1228)) + 8|0);
                 $1233 = HEAP32[$1232>>2]|0;HEAP32[$1232>>2] = (($1233+1)|0);
                }
                $1234 = HEAP32[$1157>>2]|0;
                $1235 = HEAP32[$1154>>2]|0;
                $1236 = (($1235|0) / 2)&-1;
                __THREW__ = 0;
                invoke_viiiii(3356,($1175|0),0,0,($1234|0),($1236|0));
                $1237 = __THREW__; __THREW__ = 0;
                $1238 = $1237&1;
                L649: do {
                 if ($1238) {
                  label = 508;
                 } else {
                  $1239 = ((($1175)) + 568|0);
                  HEAP32[$1239>>2] = 1028;
                  $1240 = ((($1175)) + 152|0);
                  $1241 = HEAP32[$1240>>2]|0;
                  $1242 = ($1241|0)==(0);
                  $1243 = ((($1175)) + 148|0);
                  if ($1242) {
                   $1245 = HEAP32[$1243>>2]|0;
                   $1246 = $1245 & -131073;
                   HEAP32[$1243>>2] = $1246;
                   $1247 = ((($1175)) + 572|0);
                   HEAP32[$1247>>2] = 1028;
                   $1248 = $1245 & -393217;
                   HEAP32[$1243>>2] = $1248;
                  } else {
                   $1244 = ((($1175)) + 572|0);
                   HEAP32[$1244>>2] = 1028;
                  }
                  $1249 = ((($1175)) + 228|0);
                  HEAP8[$1249>>0] = 1;
                  $1250 = ((($1175)) + 560|0);
                  HEAP32[$1250>>2] = 1;
                  $1251 = ((($1175)) + 564|0);
                  HEAP32[$1251>>2] = 1;
                  __THREW__ = 0;
                  invoke_vii(3341,($1175|0),0);
                  $1252 = __THREW__; __THREW__ = 0;
                  $1253 = $1252&1;
                  if ($1253) {
                   label = 508;
                   break;
                  }
                  __THREW__ = 0;
                  invoke_viiiiiiii(3342,($1175|0),3,($1228|0),0,0,0,0,0);
                  $1254 = __THREW__; __THREW__ = 0;
                  $1255 = $1254&1;
                  if ($1255) {
                   label = 508;
                   break;
                  }
                  $$sroa$0706$0$$sroa_idx = ((($1184)) + 36|0);
                  HEAPF32[$$sroa$0706$0$$sroa_idx>>2] = 1.0;
                  $$sroa$4708$0$$sroa_idx710 = ((($1184)) + 40|0);
                  HEAPF32[$$sroa$4708$0$$sroa_idx710>>2] = 0.0;
                  $$sroa$5711$0$$sroa_idx713 = ((($1184)) + 44|0);
                  HEAPF32[$$sroa$5711$0$$sroa_idx713>>2] = 0.0;
                  $$sroa$6714$0$$sroa_idx716 = ((($1184)) + 48|0);
                  HEAPF32[$$sroa$6714$0$$sroa_idx716>>2] = 1.0;
                  $1256 = HEAP32[$1157>>2]|0;
                  $1257 = HEAP32[$1154>>2]|0;
                  $1258 = (($1257|0) / 2)&-1;
                  $1259 = HEAP8[$1159>>0]|0;
                  $1260 = ($1259<<24>>24)!=(0);
                  $1261 = $1260 ? 1029 : 1028;
                  __THREW__ = 0;
                  $1262 = (invoke_iiiiiiiiiii(3352,($0|0),($2|0),($137|0),0,($$1156|0),($1256|0),($1258|0),($1261|0),($1197|0),($1184|0))|0);
                  $1263 = __THREW__; __THREW__ = 0;
                  $1264 = $1263&1;
                  if ($1264) {
                   label = 508;
                   break;
                  }
                  $1265 = ($1262|0)==(0|0);
                  if (!($1265)) {
                   $1266 = ((($1262)) + 8|0);
                   $1267 = HEAP32[$1266>>2]|0;HEAP32[$1266>>2] = (($1267+1)|0);
                  }
                  $1268 = ((($1262)) + 560|0);
                  HEAP32[$1268>>2] = 1;
                  $1269 = ((($1262)) + 564|0);
                  HEAP32[$1269>>2] = 2;
                  __THREW__ = 0;
                  $1270 = (invoke_ii(3276,152)|0);
                  $1271 = __THREW__; __THREW__ = 0;
                  $1272 = $1271&1;
                  L661: do {
                   if ($1272) {
                    label = 509;
                   } else {
                    __THREW__ = 0;
                    invoke_vii(3353,($1270|0),($1184|0));
                    $1273 = __THREW__; __THREW__ = 0;
                    $1274 = $1273&1;
                    if ($1274) {
                     $1373 = ___cxa_find_matching_catch_2()|0;
                     $1374 = tempRet0;
                     __ZdlPv($1270);
                     $$57 = $1373;$$57165 = $1374;
                     break;
                    }
                    $1275 = HEAP32[$1270>>2]|0;
                    $1276 = ((($1275)) + -12|0);
                    $1277 = HEAP32[$1276>>2]|0;
                    $1278 = (($1270) + ($1277)|0);
                    $1279 = ((($1262)) + 92|0);
                    $1280 = HEAP32[$1279>>2]|0;
                    $1281 = ($1280|0)==(0|0);
                    if ($1281) {
                     __THREW__ = 0;
                     invoke_vii(3354,($1262|0),($1278|0));
                     $1291 = __THREW__; __THREW__ = 0;
                     $1292 = $1291&1;
                     if ($1292) {
                      label = 509;
                      break;
                     }
                    } else {
                     $$tr$i$i392 = $1280;
                     while(1) {
                      $1282 = ((($$tr$i$i392)) + 4|0);
                      $1283 = HEAP32[$1282>>2]|0;
                      $1284 = ($1283|0)==(0|0);
                      if ($1284) {
                       break;
                      } else {
                       $$tr$i$i392 = $1283;
                      }
                     }
                     HEAP32[$1282>>2] = $1278;
                     $1285 = HEAP32[$1278>>2]|0;
                     $1286 = ((($1285)) + -12|0);
                     $1287 = HEAP32[$1286>>2]|0;
                     $1288 = (($1278) + ($1287)|0);
                     $1289 = ((($1288)) + 8|0);
                     $1290 = HEAP32[$1289>>2]|0;HEAP32[$1289>>2] = (($1290+1)|0);
                    }
                    $$sroa$0692$0$$sroa_idx = ((($1190)) + 36|0);
                    HEAPF32[$$sroa$0692$0$$sroa_idx>>2] = 0.0;
                    $$sroa$4$0$$sroa_idx695 = ((($1190)) + 40|0);
                    HEAPF32[$$sroa$4$0$$sroa_idx695>>2] = 1.0;
                    $$sroa$5$0$$sroa_idx697 = ((($1190)) + 44|0);
                    HEAPF32[$$sroa$5$0$$sroa_idx697>>2] = 0.0;
                    $$sroa$6$0$$sroa_idx699 = ((($1190)) + 48|0);
                    HEAPF32[$$sroa$6$0$$sroa_idx699>>2] = 1.0;
                    $1293 = HEAP32[$1157>>2]|0;
                    $1294 = HEAP32[$1154>>2]|0;
                    $1295 = (($1294|0) / 2)&-1;
                    $1296 = HEAP8[$1159>>0]|0;
                    $1297 = ($1296<<24>>24)!=(0);
                    $1298 = $1297 ? 1029 : 1028;
                    __THREW__ = 0;
                    $1299 = (invoke_iiiiiiiiiii(3352,($0|0),($2|0),($137|0),0,($$1157|0),($1293|0),($1295|0),($1298|0),($1228|0),($1190|0))|0);
                    $1300 = __THREW__; __THREW__ = 0;
                    $1301 = $1300&1;
                    if ($1301) {
                     label = 509;
                     break;
                    }
                    $1302 = ($1299|0)==(0|0);
                    if (!($1302)) {
                     $1303 = ((($1299)) + 8|0);
                     $1304 = HEAP32[$1303>>2]|0;HEAP32[$1303>>2] = (($1304+1)|0);
                    }
                    $1305 = ((($1299)) + 560|0);
                    HEAP32[$1305>>2] = 1;
                    $1306 = ((($1299)) + 564|0);
                    HEAP32[$1306>>2] = 3;
                    __THREW__ = 0;
                    $1307 = (invoke_ii(3276,152)|0);
                    $1308 = __THREW__; __THREW__ = 0;
                    $1309 = $1308&1;
                    do {
                     if ($1309) {
                      label = 511;
                     } else {
                      __THREW__ = 0;
                      invoke_vii(3353,($1307|0),($1190|0));
                      $1310 = __THREW__; __THREW__ = 0;
                      $1311 = $1310&1;
                      if ($1311) {
                       $1377 = ___cxa_find_matching_catch_2()|0;
                       $1378 = tempRet0;
                       __ZdlPv($1307);
                       $$55 = $1377;$$55163 = $1378;
                       break;
                      }
                      $1312 = HEAP32[$1307>>2]|0;
                      $1313 = ((($1312)) + -12|0);
                      $1314 = HEAP32[$1313>>2]|0;
                      $1315 = (($1307) + ($1314)|0);
                      $1316 = ((($1299)) + 92|0);
                      $1317 = HEAP32[$1316>>2]|0;
                      $1318 = ($1317|0)==(0|0);
                      if ($1318) {
                       __THREW__ = 0;
                       invoke_vii(3354,($1299|0),($1315|0));
                       $1328 = __THREW__; __THREW__ = 0;
                       $1329 = $1328&1;
                       if ($1329) {
                        label = 511;
                        break;
                       }
                      } else {
                       $$tr$i$i386 = $1317;
                       while(1) {
                        $1319 = ((($$tr$i$i386)) + 4|0);
                        $1320 = HEAP32[$1319>>2]|0;
                        $1321 = ($1320|0)==(0|0);
                        if ($1321) {
                         break;
                        } else {
                         $$tr$i$i386 = $1320;
                        }
                       }
                       HEAP32[$1319>>2] = $1315;
                       $1322 = HEAP32[$1315>>2]|0;
                       $1323 = ((($1322)) + -12|0);
                       $1324 = HEAP32[$1323>>2]|0;
                       $1325 = (($1315) + ($1324)|0);
                       $1326 = ((($1325)) + 8|0);
                       $1327 = HEAP32[$1326>>2]|0;HEAP32[$1326>>2] = (($1327+1)|0);
                      }
                      $1330 = ((($1)) + 228|0);
                      HEAP8[$1330>>0] = 0;
                      do {
                       if (!($1302)) {
                        $1331 = ((($1299)) + 8|0);
                        $1332 = HEAP32[$1331>>2]|0;HEAP32[$1331>>2] = (($1332-1)|0);
                        $1333 = ($1332|0)==(1);
                        if (!($1333)) {
                         break;
                        }
                        __THREW__ = 0;
                        invoke_viii(3262,($1299|0),1,1);
                        $1334 = __THREW__; __THREW__ = 0;
                        $1335 = $1334&1;
                        if (!($1335)) {
                         break;
                        }
                        $1379 = ___cxa_find_matching_catch_2()|0;
                        $1380 = tempRet0;
                        $$57 = $1379;$$57165 = $1380;
                        break L661;
                       }
                      } while(0);
                      do {
                       if (!($1265)) {
                        $1336 = ((($1262)) + 8|0);
                        $1337 = HEAP32[$1336>>2]|0;HEAP32[$1336>>2] = (($1337-1)|0);
                        $1338 = ($1337|0)==(1);
                        if (!($1338)) {
                         break;
                        }
                        __THREW__ = 0;
                        invoke_viii(3262,($1262|0),1,1);
                        $1339 = __THREW__; __THREW__ = 0;
                        $1340 = $1339&1;
                        if (!($1340)) {
                         break;
                        }
                        $1386 = ___cxa_find_matching_catch_2()|0;
                        $1387 = tempRet0;
                        $$59 = $1386;$$59167 = $1387;
                        break L649;
                       }
                      } while(0);
                      do {
                       if (!($1231)) {
                        $1341 = ((($1228)) + 8|0);
                        $1342 = HEAP32[$1341>>2]|0;HEAP32[$1341>>2] = (($1342-1)|0);
                        $1343 = ($1342|0)==(1);
                        if (!($1343)) {
                         break;
                        }
                        __THREW__ = 0;
                        invoke_viii(3262,($1228|0),1,1);
                        $1344 = __THREW__; __THREW__ = 0;
                        $1345 = $1344&1;
                        if (!($1345)) {
                         break;
                        }
                        $1393 = ___cxa_find_matching_catch_2()|0;
                        $1394 = tempRet0;
                        $$61 = $1393;$$61169 = $1394;
                        break L637;
                       }
                      } while(0);
                      do {
                       if (!($1200)) {
                        $1346 = ((($1197)) + 8|0);
                        $1347 = HEAP32[$1346>>2]|0;HEAP32[$1346>>2] = (($1347-1)|0);
                        $1348 = ($1347|0)==(1);
                        if (!($1348)) {
                         break;
                        }
                        __THREW__ = 0;
                        invoke_viii(3262,($1197|0),1,1);
                        $1349 = __THREW__; __THREW__ = 0;
                        $1350 = $1349&1;
                        if (!($1350)) {
                         break;
                        }
                        $1400 = ___cxa_find_matching_catch_2()|0;
                        $1401 = tempRet0;
                        $$63 = $1400;$$63171 = $1401;
                        label = 529;
                        break L631;
                       }
                      } while(0);
                      do {
                       if (!($1191)) {
                        $1351 = ((($1190)) + 8|0);
                        $1352 = HEAP32[$1351>>2]|0;HEAP32[$1351>>2] = (($1352-1)|0);
                        $1353 = ($1352|0)==(1);
                        if (!($1353)) {
                         break;
                        }
                        __THREW__ = 0;
                        invoke_viii(3262,($1190|0),1,1);
                        $1354 = __THREW__; __THREW__ = 0;
                        $1355 = $1354&1;
                        if (!($1355)) {
                         break;
                        }
                        $1407 = ___cxa_find_matching_catch_2()|0;
                        $1408 = tempRet0;
                        $$64 = $1407;$$64172 = $1408;
                        label = 533;
                        break L631;
                       }
                      } while(0);
                      if ($1185) {
                       break L623;
                      }
                      $1356 = ((($1184)) + 8|0);
                      $1357 = HEAP32[$1356>>2]|0;HEAP32[$1356>>2] = (($1357-1)|0);
                      $1358 = ($1357|0)==(1);
                      if (!($1358)) {
                       break L623;
                      }
                      __THREW__ = 0;
                      invoke_viii(3262,($1184|0),1,1);
                      $1359 = __THREW__; __THREW__ = 0;
                      $1360 = $1359&1;
                      if (!($1360)) {
                       break L623;
                      }
                      $1414 = ___cxa_find_matching_catch_2()|0;
                      $1415 = tempRet0;
                      $$66 = $1414;$$66174 = $1415;
                      break L631;
                     }
                    } while(0);
                    if ((label|0) == 511) {
                     $1375 = ___cxa_find_matching_catch_2()|0;
                     $1376 = tempRet0;
                     $$55 = $1375;$$55163 = $1376;
                    }
                    $1381 = ((($1299)) + 8|0);
                    $1382 = HEAP32[$1381>>2]|0;HEAP32[$1381>>2] = (($1382-1)|0);
                    $1383 = ($1382|0)==(1);
                    if (!($1383)) {
                     $$57 = $$55;$$57165 = $$55163;
                     break;
                    }
                    __THREW__ = 0;
                    invoke_viii(3262,($1299|0),1,1);
                    $1384 = __THREW__; __THREW__ = 0;
                    $1385 = $1384&1;
                    if (!($1385)) {
                     $$57 = $$55;$$57165 = $$55163;
                     break;
                    }
                    $2128 = ___cxa_find_matching_catch_3(0|0)|0;
                    $2129 = tempRet0;
                    ___clang_call_terminate($2128);
                    // unreachable;
                   }
                  } while(0);
                  if ((label|0) == 509) {
                   $1371 = ___cxa_find_matching_catch_2()|0;
                   $1372 = tempRet0;
                   $$57 = $1371;$$57165 = $1372;
                  }
                  if ($1265) {
                   $$59 = $$57;$$59167 = $$57165;
                   break;
                  }
                  $1388 = ((($1262)) + 8|0);
                  $1389 = HEAP32[$1388>>2]|0;HEAP32[$1388>>2] = (($1389-1)|0);
                  $1390 = ($1389|0)==(1);
                  if (!($1390)) {
                   $$59 = $$57;$$59167 = $$57165;
                   break;
                  }
                  __THREW__ = 0;
                  invoke_viii(3262,($1262|0),1,1);
                  $1391 = __THREW__; __THREW__ = 0;
                  $1392 = $1391&1;
                  if (!($1392)) {
                   $$59 = $$57;$$59167 = $$57165;
                   break;
                  }
                  $2128 = ___cxa_find_matching_catch_3(0|0)|0;
                  $2129 = tempRet0;
                  ___clang_call_terminate($2128);
                  // unreachable;
                 }
                } while(0);
                if ((label|0) == 508) {
                 $1369 = ___cxa_find_matching_catch_2()|0;
                 $1370 = tempRet0;
                 $$59 = $1369;$$59167 = $1370;
                }
                if ($1231) {
                 $$61 = $$59;$$61169 = $$59167;
                 break;
                }
                $1395 = ((($1228)) + 8|0);
                $1396 = HEAP32[$1395>>2]|0;HEAP32[$1395>>2] = (($1396-1)|0);
                $1397 = ($1396|0)==(1);
                if (!($1397)) {
                 $$61 = $$59;$$61169 = $$59167;
                 break;
                }
                __THREW__ = 0;
                invoke_viii(3262,($1228|0),1,1);
                $1398 = __THREW__; __THREW__ = 0;
                $1399 = $1398&1;
                if (!($1399)) {
                 $$61 = $$59;$$61169 = $$59167;
                 break;
                }
                $2128 = ___cxa_find_matching_catch_3(0|0)|0;
                $2129 = tempRet0;
                ___clang_call_terminate($2128);
                // unreachable;
               }
              } while(0);
              if ((label|0) == 507) {
               $1367 = ___cxa_find_matching_catch_2()|0;
               $1368 = tempRet0;
               $$61 = $1367;$$61169 = $1368;
              }
              if ($1200) {
               $$63 = $$61;$$63171 = $$61169;
               label = 529;
               break;
              }
              $1402 = ((($1197)) + 8|0);
              $1403 = HEAP32[$1402>>2]|0;HEAP32[$1402>>2] = (($1403-1)|0);
              $1404 = ($1403|0)==(1);
              if (!($1404)) {
               $$63 = $$61;$$63171 = $$61169;
               label = 529;
               break;
              }
              __THREW__ = 0;
              invoke_viii(3262,($1197|0),1,1);
              $1405 = __THREW__; __THREW__ = 0;
              $1406 = $1405&1;
              if (!($1406)) {
               $$63 = $$61;$$63171 = $$61169;
               label = 529;
               break;
              }
              $2128 = ___cxa_find_matching_catch_3(0|0)|0;
              $2129 = tempRet0;
              ___clang_call_terminate($2128);
              // unreachable;
             }
            } while(0);
            do {
             if ((label|0) == 529) {
              if ($1191) {
               $$64 = $$63;$$64172 = $$63171;
               label = 533;
               break;
              }
              $1409 = ((($1190)) + 8|0);
              $1410 = HEAP32[$1409>>2]|0;HEAP32[$1409>>2] = (($1410-1)|0);
              $1411 = ($1410|0)==(1);
              if (!($1411)) {
               $$64 = $$63;$$64172 = $$63171;
               label = 533;
               break;
              }
              __THREW__ = 0;
              invoke_viii(3262,($1190|0),1,1);
              $1412 = __THREW__; __THREW__ = 0;
              $1413 = $1412&1;
              if (!($1413)) {
               $$64 = $$63;$$64172 = $$63171;
               label = 533;
               break;
              }
              $2128 = ___cxa_find_matching_catch_3(0|0)|0;
              $2129 = tempRet0;
              ___clang_call_terminate($2128);
              // unreachable;
             }
            } while(0);
            do {
             if ((label|0) == 533) {
              if ($1185) {
               $$66 = $$64;$$66174 = $$64172;
               break;
              }
              $1416 = ((($1184)) + 8|0);
              $1417 = HEAP32[$1416>>2]|0;HEAP32[$1416>>2] = (($1417-1)|0);
              $1418 = ($1417|0)==(1);
              if (!($1418)) {
               $$66 = $$64;$$66174 = $$64172;
               break;
              }
              __THREW__ = 0;
              invoke_viii(3262,($1184|0),1,1);
              $1419 = __THREW__; __THREW__ = 0;
              $1420 = $1419&1;
              if (!($1420)) {
               $$66 = $$64;$$66174 = $$64172;
               break;
              }
              $2128 = ___cxa_find_matching_catch_3(0|0)|0;
              $2129 = tempRet0;
              ___clang_call_terminate($2128);
              // unreachable;
             }
            } while(0);
            if ($1178) {
             $$69 = $$66;$$69177 = $$66174;
             break L617;
            }
            $1433 = ((($1175)) + 8|0);
            $1434 = HEAP32[$1433>>2]|0;HEAP32[$1433>>2] = (($1434-1)|0);
            $1435 = ($1434|0)==(1);
            if (!($1435)) {
             $$69 = $$66;$$69177 = $$66174;
             break L617;
            }
            __THREW__ = 0;
            invoke_viii(3262,($1175|0),1,1);
            $1436 = __THREW__; __THREW__ = 0;
            $1437 = $1436&1;
            if (!($1437)) {
             $$69 = $$66;$$69177 = $$66174;
             break L617;
            }
            $2128 = ___cxa_find_matching_catch_3(0|0)|0;
            $2129 = tempRet0;
            ___clang_call_terminate($2128);
            // unreachable;
           }
          } while(0);
          do {
           if (!($1178)) {
            $1421 = ((($1175)) + 8|0);
            $1422 = HEAP32[$1421>>2]|0;HEAP32[$1421>>2] = (($1422-1)|0);
            $1423 = ($1422|0)==(1);
            if ($1423) {
             __THREW__ = 0;
             invoke_viii(3262,($1175|0),1,1);
             $1424 = __THREW__; __THREW__ = 0;
             $1425 = $1424&1;
             if (!($1425)) {
              break;
             }
             $1431 = ___cxa_find_matching_catch_2()|0;
             $1432 = tempRet0;
             $$69 = $1431;$$69177 = $1432;
             break L617;
            }
           }
          } while(0);
          if ($1166) {
           label = 788;
           break L77;
          }
          $1426 = ((($1163)) + 8|0);
          $1427 = HEAP32[$1426>>2]|0;HEAP32[$1426>>2] = (($1427-1)|0);
          $1428 = ($1427|0)==(1);
          if (!($1428)) {
           label = 788;
           break L77;
          }
          __THREW__ = 0;
          invoke_viii(3262,($1163|0),1,1);
          $1429 = __THREW__; __THREW__ = 0;
          $1430 = $1429&1;
          if (!($1430)) {
           label = 788;
           break L77;
          }
          $1438 = ___cxa_find_matching_catch_2()|0;
          $1439 = tempRet0;
          $$104 = $1438;$$104212 = $1439;
          label = 806;
          break L77;
         }
        } while(0);
        if ($1166) {
         $$104 = $$69;$$104212 = $$69177;
         label = 806;
         break L77;
        }
        $1440 = ((($1163)) + 8|0);
        $1441 = HEAP32[$1440>>2]|0;HEAP32[$1440>>2] = (($1441-1)|0);
        $1442 = ($1441|0)==(1);
        if (!($1442)) {
         $$104 = $$69;$$104212 = $$69177;
         label = 806;
         break L77;
        }
        __THREW__ = 0;
        invoke_viii(3262,($1163|0),1,1);
        $1443 = __THREW__; __THREW__ = 0;
        $1444 = $1443&1;
        if (!($1444)) {
         $$104 = $$69;$$104212 = $$69177;
         label = 806;
         break L77;
        }
        $2128 = ___cxa_find_matching_catch_3(0|0)|0;
        $2129 = tempRet0;
        ___clang_call_terminate($2128);
        // unreachable;
       }
       break;
      }
      case 4:  {
       __THREW__ = 0;
       invoke_vii(3338,($1|0),(0|0));
       $1445 = __THREW__; __THREW__ = 0;
       $1446 = $1445&1;
       if (!($1446)) {
        $1447 = ((($142)) + 40|0);
        $1448 = HEAP32[$1447>>2]|0;
        $1449 = ((($142)) + 44|0);
        $1450 = HEAP32[$1449>>2]|0;
        $1451 = ((($142)) + 110|0);
        $1452 = HEAP8[$1451>>0]|0;
        $1453 = ($1452<<24>>24)!=(0);
        $1454 = $1453 ? 1029 : 1028;
        __THREW__ = 0;
        $1455 = (invoke_iiiiiiiiid(3355,($0|0),($2|0),($137|0),0,0,($1448|0),($1450|0),($1454|0),-1.0)|0);
        $1456 = __THREW__; __THREW__ = 0;
        $1457 = $1456&1;
        if (!($1457)) {
         $1458 = ($1455|0)==(0|0);
         if (!($1458)) {
          $1459 = ((($1455)) + 8|0);
          $1460 = HEAP32[$1459>>2]|0;HEAP32[$1459>>2] = (($1460+1)|0);
         }
         $1461 = HEAP32[$5>>2]|0;
         $1462 = HEAP32[$22>>2]|0;
         $1463 = ($1461|0)==($1462|0);
         L771: do {
          if (!($1463)) {
           $1464 = HEAP32[$1461>>2]|0;
           $1465 = ($1464|0)==(0|0);
           if (!($1465)) {
            $1466 = ((($1464)) + 8|0);
            $1467 = HEAP32[$1466>>2]|0;HEAP32[$1466>>2] = (($1467+1)|0);
           }
           $1468 = HEAP32[$1447>>2]|0;
           $1469 = HEAP32[$1449>>2]|0;
           __THREW__ = 0;
           $1470 = (invoke_iiii(3350,0,($1468|0),($1469|0))|0);
           $1471 = __THREW__; __THREW__ = 0;
           $1472 = $1471&1;
           L776: do {
            if ($1472) {
             $1544 = ___cxa_find_matching_catch_2()|0;
             $1545 = tempRet0;
             $$76 = $1544;$$76184 = $1545;
             label = 595;
            } else {
             $1473 = ($1470|0)==(0|0);
             if (!($1473)) {
              $1474 = ((($1470)) + 8|0);
              $1475 = HEAP32[$1474>>2]|0;HEAP32[$1474>>2] = (($1475+1)|0);
             }
             $1476 = ((($1455)) + 568|0);
             HEAP32[$1476>>2] = 1028;
             $1477 = ((($1455)) + 152|0);
             $1478 = HEAP32[$1477>>2]|0;
             $1479 = ($1478|0)==(0);
             $1480 = ((($1455)) + 148|0);
             if ($1479) {
              $1482 = HEAP32[$1480>>2]|0;
              $1483 = $1482 & -131073;
              HEAP32[$1480>>2] = $1483;
              $1484 = ((($1455)) + 572|0);
              HEAP32[$1484>>2] = 1028;
              $1485 = $1482 & -393217;
              HEAP32[$1480>>2] = $1485;
             } else {
              $1481 = ((($1455)) + 572|0);
              HEAP32[$1481>>2] = 1028;
             }
             $1486 = ((($1455)) + 228|0);
             HEAP8[$1486>>0] = 0;
             $1487 = ((($1455)) + 560|0);
             HEAP32[$1487>>2] = 1;
             $1488 = ((($1455)) + 564|0);
             HEAP32[$1488>>2] = 0;
             __THREW__ = 0;
             invoke_vii(3341,($1455|0),0);
             $1489 = __THREW__; __THREW__ = 0;
             $1490 = $1489&1;
             L786: do {
              if ($1490) {
               label = 584;
              } else {
               __THREW__ = 0;
               invoke_viiiiiiii(3342,($1455|0),3,($1470|0),0,0,0,0,0);
               $1491 = __THREW__; __THREW__ = 0;
               $1492 = $1491&1;
               if ($1492) {
                label = 584;
                break;
               }
               $1493 = HEAP32[$1447>>2]|0;
               $1494 = HEAP32[$1449>>2]|0;
               $1495 = HEAP8[$1451>>0]|0;
               $1496 = ($1495<<24>>24)!=(0);
               $1497 = $1496 ? 1029 : 1028;
               __THREW__ = 0;
               $1498 = (invoke_iiiiiiiiiii(3352,($0|0),($2|0),($137|0),0,0,($1493|0),($1494|0),($1497|0),($1470|0),($1464|0))|0);
               $1499 = __THREW__; __THREW__ = 0;
               $1500 = $1499&1;
               if ($1500) {
                label = 584;
                break;
               }
               $1501 = ($1498|0)==(0|0);
               if (!($1501)) {
                $1502 = ((($1498)) + 8|0);
                $1503 = HEAP32[$1502>>2]|0;HEAP32[$1502>>2] = (($1503+1)|0);
               }
               $1504 = ((($1498)) + 560|0);
               HEAP32[$1504>>2] = 1;
               $1505 = ((($1498)) + 564|0);
               HEAP32[$1505>>2] = 2;
               __THREW__ = 0;
               $1506 = (invoke_ii(3276,152)|0);
               $1507 = __THREW__; __THREW__ = 0;
               $1508 = $1507&1;
               do {
                if ($1508) {
                 label = 585;
                } else {
                 __THREW__ = 0;
                 invoke_vii(3353,($1506|0),($1464|0));
                 $1509 = __THREW__; __THREW__ = 0;
                 $1510 = $1509&1;
                 if ($1510) {
                  $1550 = ___cxa_find_matching_catch_2()|0;
                  $1551 = tempRet0;
                  __ZdlPv($1506);
                  $$72 = $1550;$$72180 = $1551;
                  break;
                 }
                 $1511 = HEAP32[$1506>>2]|0;
                 $1512 = ((($1511)) + -12|0);
                 $1513 = HEAP32[$1512>>2]|0;
                 $1514 = (($1506) + ($1513)|0);
                 $1515 = ((($1498)) + 92|0);
                 $1516 = HEAP32[$1515>>2]|0;
                 $1517 = ($1516|0)==(0|0);
                 if ($1517) {
                  __THREW__ = 0;
                  invoke_vii(3354,($1498|0),($1514|0));
                  $1527 = __THREW__; __THREW__ = 0;
                  $1528 = $1527&1;
                  if ($1528) {
                   label = 585;
                   break;
                  }
                 } else {
                  $$tr$i$i338 = $1516;
                  while(1) {
                   $1518 = ((($$tr$i$i338)) + 4|0);
                   $1519 = HEAP32[$1518>>2]|0;
                   $1520 = ($1519|0)==(0|0);
                   if ($1520) {
                    break;
                   } else {
                    $$tr$i$i338 = $1519;
                   }
                  }
                  HEAP32[$1518>>2] = $1514;
                  $1521 = HEAP32[$1514>>2]|0;
                  $1522 = ((($1521)) + -12|0);
                  $1523 = HEAP32[$1522>>2]|0;
                  $1524 = (($1514) + ($1523)|0);
                  $1525 = ((($1524)) + 8|0);
                  $1526 = HEAP32[$1525>>2]|0;HEAP32[$1525>>2] = (($1526+1)|0);
                 }
                 do {
                  if (!($1501)) {
                   $1529 = ((($1498)) + 8|0);
                   $1530 = HEAP32[$1529>>2]|0;HEAP32[$1529>>2] = (($1530-1)|0);
                   $1531 = ($1530|0)==(1);
                   if (!($1531)) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(3262,($1498|0),1,1);
                   $1532 = __THREW__; __THREW__ = 0;
                   $1533 = $1532&1;
                   if (!($1533)) {
                    break;
                   }
                   $1552 = ___cxa_find_matching_catch_2()|0;
                   $1553 = tempRet0;
                   $$74 = $1552;$$74182 = $1553;
                   break L786;
                  }
                 } while(0);
                 do {
                  if (!($1473)) {
                   $1534 = ((($1470)) + 8|0);
                   $1535 = HEAP32[$1534>>2]|0;HEAP32[$1534>>2] = (($1535-1)|0);
                   $1536 = ($1535|0)==(1);
                   if (!($1536)) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(3262,($1470|0),1,1);
                   $1537 = __THREW__; __THREW__ = 0;
                   $1538 = $1537&1;
                   if (!($1538)) {
                    break;
                   }
                   $1559 = ___cxa_find_matching_catch_2()|0;
                   $1560 = tempRet0;
                   $$76 = $1559;$$76184 = $1560;
                   label = 595;
                   break L776;
                  }
                 } while(0);
                 if ($1465) {
                  break L771;
                 }
                 $1539 = ((($1464)) + 8|0);
                 $1540 = HEAP32[$1539>>2]|0;HEAP32[$1539>>2] = (($1540-1)|0);
                 $1541 = ($1540|0)==(1);
                 if (!($1541)) {
                  break L771;
                 }
                 __THREW__ = 0;
                 invoke_viii(3262,($1464|0),1,1);
                 $1542 = __THREW__; __THREW__ = 0;
                 $1543 = $1542&1;
                 if (!($1543)) {
                  break L771;
                 }
                 $1566 = ___cxa_find_matching_catch_2()|0;
                 $1567 = tempRet0;
                 $$77 = $1566;$$77185 = $1567;
                 break L776;
                }
               } while(0);
               if ((label|0) == 585) {
                $1548 = ___cxa_find_matching_catch_2()|0;
                $1549 = tempRet0;
                $$72 = $1548;$$72180 = $1549;
               }
               $1554 = ((($1498)) + 8|0);
               $1555 = HEAP32[$1554>>2]|0;HEAP32[$1554>>2] = (($1555-1)|0);
               $1556 = ($1555|0)==(1);
               if (!($1556)) {
                $$74 = $$72;$$74182 = $$72180;
                break;
               }
               __THREW__ = 0;
               invoke_viii(3262,($1498|0),1,1);
               $1557 = __THREW__; __THREW__ = 0;
               $1558 = $1557&1;
               if (!($1558)) {
                $$74 = $$72;$$74182 = $$72180;
                break;
               }
               $2128 = ___cxa_find_matching_catch_3(0|0)|0;
               $2129 = tempRet0;
               ___clang_call_terminate($2128);
               // unreachable;
              }
             } while(0);
             if ((label|0) == 584) {
              $1546 = ___cxa_find_matching_catch_2()|0;
              $1547 = tempRet0;
              $$74 = $1546;$$74182 = $1547;
             }
             if ($1473) {
              $$76 = $$74;$$76184 = $$74182;
              label = 595;
              break;
             }
             $1561 = ((($1470)) + 8|0);
             $1562 = HEAP32[$1561>>2]|0;HEAP32[$1561>>2] = (($1562-1)|0);
             $1563 = ($1562|0)==(1);
             if (!($1563)) {
              $$76 = $$74;$$76184 = $$74182;
              label = 595;
              break;
             }
             __THREW__ = 0;
             invoke_viii(3262,($1470|0),1,1);
             $1564 = __THREW__; __THREW__ = 0;
             $1565 = $1564&1;
             if (!($1565)) {
              $$76 = $$74;$$76184 = $$74182;
              label = 595;
              break;
             }
             $2128 = ___cxa_find_matching_catch_3(0|0)|0;
             $2129 = tempRet0;
             ___clang_call_terminate($2128);
             // unreachable;
            }
           } while(0);
           do {
            if ((label|0) == 595) {
             if ($1465) {
              $$77 = $$76;$$77185 = $$76184;
             } else {
              $1568 = ((($1464)) + 8|0);
              $1569 = HEAP32[$1568>>2]|0;HEAP32[$1568>>2] = (($1569-1)|0);
              $1570 = ($1569|0)==(1);
              if ($1570) {
               __THREW__ = 0;
               invoke_viii(3262,($1464|0),1,1);
               $1571 = __THREW__; __THREW__ = 0;
               $1572 = $1571&1;
               if (!($1572)) {
                $$77 = $$76;$$77185 = $$76184;
                break;
               }
               $2128 = ___cxa_find_matching_catch_3(0|0)|0;
               $2129 = tempRet0;
               ___clang_call_terminate($2128);
               // unreachable;
              } else {
               $$77 = $$76;$$77185 = $$76184;
              }
             }
            }
           } while(0);
           if ($1458) {
            $$104 = $$77;$$104212 = $$77185;
            label = 806;
            break L77;
           }
           $1580 = ((($1455)) + 8|0);
           $1581 = HEAP32[$1580>>2]|0;HEAP32[$1580>>2] = (($1581-1)|0);
           $1582 = ($1581|0)==(1);
           if (!($1582)) {
            $$104 = $$77;$$104212 = $$77185;
            label = 806;
            break L77;
           }
           __THREW__ = 0;
           invoke_viii(3262,($1455|0),1,1);
           $1583 = __THREW__; __THREW__ = 0;
           $1584 = $1583&1;
           if (!($1584)) {
            $$104 = $$77;$$104212 = $$77185;
            label = 806;
            break L77;
           }
           $2128 = ___cxa_find_matching_catch_3(0|0)|0;
           $2129 = tempRet0;
           ___clang_call_terminate($2128);
           // unreachable;
          }
         } while(0);
         if ($1458) {
          label = 788;
          break L77;
         }
         $1573 = ((($1455)) + 8|0);
         $1574 = HEAP32[$1573>>2]|0;HEAP32[$1573>>2] = (($1574-1)|0);
         $1575 = ($1574|0)==(1);
         if (!($1575)) {
          label = 788;
          break L77;
         }
         __THREW__ = 0;
         invoke_viii(3262,($1455|0),1,1);
         $1576 = __THREW__; __THREW__ = 0;
         $1577 = $1576&1;
         if (!($1577)) {
          label = 788;
          break L77;
         }
         $1578 = ___cxa_find_matching_catch_2()|0;
         $1579 = tempRet0;
         $$104 = $1578;$$104212 = $1579;
         label = 806;
         break L77;
        }
       }
       break;
      }
      case 5:  {
       __THREW__ = 0;
       invoke_vii(3338,($1|0),(0|0));
       $1585 = __THREW__; __THREW__ = 0;
       $1586 = $1585&1;
       if (!($1586)) {
        $1587 = ((($142)) + 40|0);
        $1588 = HEAP32[$1587>>2]|0;
        $1589 = ((($142)) + 44|0);
        $1590 = HEAP32[$1589>>2]|0;
        $1591 = ((($142)) + 110|0);
        $1592 = HEAP8[$1591>>0]|0;
        $1593 = ($1592<<24>>24)!=(0);
        $1594 = $1593 ? 1029 : 1028;
        __THREW__ = 0;
        $1595 = (invoke_iiiiiiiiid(3355,($0|0),($2|0),($137|0),0,0,($1588|0),($1590|0),($1594|0),1.0)|0);
        $1596 = __THREW__; __THREW__ = 0;
        $1597 = $1596&1;
        if (!($1597)) {
         $1598 = ($1595|0)==(0|0);
         if (!($1598)) {
          $1599 = ((($1595)) + 8|0);
          $1600 = HEAP32[$1599>>2]|0;HEAP32[$1599>>2] = (($1600+1)|0);
         }
         $1601 = HEAP32[$5>>2]|0;
         $1602 = HEAP32[$22>>2]|0;
         $1603 = ($1601|0)==($1602|0);
         L847: do {
          if (!($1603)) {
           $1604 = HEAP32[$1601>>2]|0;
           $1605 = ($1604|0)==(0|0);
           if (!($1605)) {
            $1606 = ((($1604)) + 8|0);
            $1607 = HEAP32[$1606>>2]|0;HEAP32[$1606>>2] = (($1607+1)|0);
           }
           $1608 = HEAP32[$1587>>2]|0;
           $1609 = HEAP32[$1589>>2]|0;
           __THREW__ = 0;
           $1610 = (invoke_iiii(3350,0,($1608|0),($1609|0))|0);
           $1611 = __THREW__; __THREW__ = 0;
           $1612 = $1611&1;
           L852: do {
            if ($1612) {
             $1684 = ___cxa_find_matching_catch_2()|0;
             $1685 = tempRet0;
             $$84 = $1684;$$84192 = $1685;
             label = 650;
            } else {
             $1613 = ($1610|0)==(0|0);
             if (!($1613)) {
              $1614 = ((($1610)) + 8|0);
              $1615 = HEAP32[$1614>>2]|0;HEAP32[$1614>>2] = (($1615+1)|0);
             }
             $1616 = ((($1595)) + 568|0);
             HEAP32[$1616>>2] = 1028;
             $1617 = ((($1595)) + 152|0);
             $1618 = HEAP32[$1617>>2]|0;
             $1619 = ($1618|0)==(0);
             $1620 = ((($1595)) + 148|0);
             if ($1619) {
              $1622 = HEAP32[$1620>>2]|0;
              $1623 = $1622 & -131073;
              HEAP32[$1620>>2] = $1623;
              $1624 = ((($1595)) + 572|0);
              HEAP32[$1624>>2] = 1028;
              $1625 = $1622 & -393217;
              HEAP32[$1620>>2] = $1625;
             } else {
              $1621 = ((($1595)) + 572|0);
              HEAP32[$1621>>2] = 1028;
             }
             $1626 = ((($1595)) + 228|0);
             HEAP8[$1626>>0] = 0;
             $1627 = ((($1595)) + 560|0);
             HEAP32[$1627>>2] = 1;
             $1628 = ((($1595)) + 564|0);
             HEAP32[$1628>>2] = 0;
             __THREW__ = 0;
             invoke_vii(3341,($1595|0),0);
             $1629 = __THREW__; __THREW__ = 0;
             $1630 = $1629&1;
             L862: do {
              if ($1630) {
               label = 639;
              } else {
               __THREW__ = 0;
               invoke_viiiiiiii(3342,($1595|0),3,($1610|0),0,0,0,0,0);
               $1631 = __THREW__; __THREW__ = 0;
               $1632 = $1631&1;
               if ($1632) {
                label = 639;
                break;
               }
               $1633 = HEAP32[$1587>>2]|0;
               $1634 = HEAP32[$1589>>2]|0;
               $1635 = HEAP8[$1591>>0]|0;
               $1636 = ($1635<<24>>24)!=(0);
               $1637 = $1636 ? 1029 : 1028;
               __THREW__ = 0;
               $1638 = (invoke_iiiiiiiiiii(3352,($0|0),($2|0),($137|0),0,0,($1633|0),($1634|0),($1637|0),($1610|0),($1604|0))|0);
               $1639 = __THREW__; __THREW__ = 0;
               $1640 = $1639&1;
               if ($1640) {
                label = 639;
                break;
               }
               $1641 = ($1638|0)==(0|0);
               if (!($1641)) {
                $1642 = ((($1638)) + 8|0);
                $1643 = HEAP32[$1642>>2]|0;HEAP32[$1642>>2] = (($1643+1)|0);
               }
               $1644 = ((($1638)) + 560|0);
               HEAP32[$1644>>2] = 1;
               $1645 = ((($1638)) + 564|0);
               HEAP32[$1645>>2] = 1;
               __THREW__ = 0;
               $1646 = (invoke_ii(3276,152)|0);
               $1647 = __THREW__; __THREW__ = 0;
               $1648 = $1647&1;
               do {
                if ($1648) {
                 label = 640;
                } else {
                 __THREW__ = 0;
                 invoke_vii(3353,($1646|0),($1604|0));
                 $1649 = __THREW__; __THREW__ = 0;
                 $1650 = $1649&1;
                 if ($1650) {
                  $1690 = ___cxa_find_matching_catch_2()|0;
                  $1691 = tempRet0;
                  __ZdlPv($1646);
                  $$80 = $1690;$$80188 = $1691;
                  break;
                 }
                 $1651 = HEAP32[$1646>>2]|0;
                 $1652 = ((($1651)) + -12|0);
                 $1653 = HEAP32[$1652>>2]|0;
                 $1654 = (($1646) + ($1653)|0);
                 $1655 = ((($1638)) + 92|0);
                 $1656 = HEAP32[$1655>>2]|0;
                 $1657 = ($1656|0)==(0|0);
                 if ($1657) {
                  __THREW__ = 0;
                  invoke_vii(3354,($1638|0),($1654|0));
                  $1667 = __THREW__; __THREW__ = 0;
                  $1668 = $1667&1;
                  if ($1668) {
                   label = 640;
                   break;
                  }
                 } else {
                  $$tr$i$i = $1656;
                  while(1) {
                   $1658 = ((($$tr$i$i)) + 4|0);
                   $1659 = HEAP32[$1658>>2]|0;
                   $1660 = ($1659|0)==(0|0);
                   if ($1660) {
                    break;
                   } else {
                    $$tr$i$i = $1659;
                   }
                  }
                  HEAP32[$1658>>2] = $1654;
                  $1661 = HEAP32[$1654>>2]|0;
                  $1662 = ((($1661)) + -12|0);
                  $1663 = HEAP32[$1662>>2]|0;
                  $1664 = (($1654) + ($1663)|0);
                  $1665 = ((($1664)) + 8|0);
                  $1666 = HEAP32[$1665>>2]|0;HEAP32[$1665>>2] = (($1666+1)|0);
                 }
                 do {
                  if (!($1641)) {
                   $1669 = ((($1638)) + 8|0);
                   $1670 = HEAP32[$1669>>2]|0;HEAP32[$1669>>2] = (($1670-1)|0);
                   $1671 = ($1670|0)==(1);
                   if (!($1671)) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(3262,($1638|0),1,1);
                   $1672 = __THREW__; __THREW__ = 0;
                   $1673 = $1672&1;
                   if (!($1673)) {
                    break;
                   }
                   $1692 = ___cxa_find_matching_catch_2()|0;
                   $1693 = tempRet0;
                   $$82 = $1692;$$82190 = $1693;
                   break L862;
                  }
                 } while(0);
                 do {
                  if (!($1613)) {
                   $1674 = ((($1610)) + 8|0);
                   $1675 = HEAP32[$1674>>2]|0;HEAP32[$1674>>2] = (($1675-1)|0);
                   $1676 = ($1675|0)==(1);
                   if (!($1676)) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(3262,($1610|0),1,1);
                   $1677 = __THREW__; __THREW__ = 0;
                   $1678 = $1677&1;
                   if (!($1678)) {
                    break;
                   }
                   $1699 = ___cxa_find_matching_catch_2()|0;
                   $1700 = tempRet0;
                   $$84 = $1699;$$84192 = $1700;
                   label = 650;
                   break L852;
                  }
                 } while(0);
                 if ($1605) {
                  break L847;
                 }
                 $1679 = ((($1604)) + 8|0);
                 $1680 = HEAP32[$1679>>2]|0;HEAP32[$1679>>2] = (($1680-1)|0);
                 $1681 = ($1680|0)==(1);
                 if (!($1681)) {
                  break L847;
                 }
                 __THREW__ = 0;
                 invoke_viii(3262,($1604|0),1,1);
                 $1682 = __THREW__; __THREW__ = 0;
                 $1683 = $1682&1;
                 if (!($1683)) {
                  break L847;
                 }
                 $1706 = ___cxa_find_matching_catch_2()|0;
                 $1707 = tempRet0;
                 $$85 = $1706;$$85193 = $1707;
                 break L852;
                }
               } while(0);
               if ((label|0) == 640) {
                $1688 = ___cxa_find_matching_catch_2()|0;
                $1689 = tempRet0;
                $$80 = $1688;$$80188 = $1689;
               }
               $1694 = ((($1638)) + 8|0);
               $1695 = HEAP32[$1694>>2]|0;HEAP32[$1694>>2] = (($1695-1)|0);
               $1696 = ($1695|0)==(1);
               if (!($1696)) {
                $$82 = $$80;$$82190 = $$80188;
                break;
               }
               __THREW__ = 0;
               invoke_viii(3262,($1638|0),1,1);
               $1697 = __THREW__; __THREW__ = 0;
               $1698 = $1697&1;
               if (!($1698)) {
                $$82 = $$80;$$82190 = $$80188;
                break;
               }
               $2128 = ___cxa_find_matching_catch_3(0|0)|0;
               $2129 = tempRet0;
               ___clang_call_terminate($2128);
               // unreachable;
              }
             } while(0);
             if ((label|0) == 639) {
              $1686 = ___cxa_find_matching_catch_2()|0;
              $1687 = tempRet0;
              $$82 = $1686;$$82190 = $1687;
             }
             if ($1613) {
              $$84 = $$82;$$84192 = $$82190;
              label = 650;
              break;
             }
             $1701 = ((($1610)) + 8|0);
             $1702 = HEAP32[$1701>>2]|0;HEAP32[$1701>>2] = (($1702-1)|0);
             $1703 = ($1702|0)==(1);
             if (!($1703)) {
              $$84 = $$82;$$84192 = $$82190;
              label = 650;
              break;
             }
             __THREW__ = 0;
             invoke_viii(3262,($1610|0),1,1);
             $1704 = __THREW__; __THREW__ = 0;
             $1705 = $1704&1;
             if (!($1705)) {
              $$84 = $$82;$$84192 = $$82190;
              label = 650;
              break;
             }
             $2128 = ___cxa_find_matching_catch_3(0|0)|0;
             $2129 = tempRet0;
             ___clang_call_terminate($2128);
             // unreachable;
            }
           } while(0);
           do {
            if ((label|0) == 650) {
             if ($1605) {
              $$85 = $$84;$$85193 = $$84192;
             } else {
              $1708 = ((($1604)) + 8|0);
              $1709 = HEAP32[$1708>>2]|0;HEAP32[$1708>>2] = (($1709-1)|0);
              $1710 = ($1709|0)==(1);
              if ($1710) {
               __THREW__ = 0;
               invoke_viii(3262,($1604|0),1,1);
               $1711 = __THREW__; __THREW__ = 0;
               $1712 = $1711&1;
               if (!($1712)) {
                $$85 = $$84;$$85193 = $$84192;
                break;
               }
               $2128 = ___cxa_find_matching_catch_3(0|0)|0;
               $2129 = tempRet0;
               ___clang_call_terminate($2128);
               // unreachable;
              } else {
               $$85 = $$84;$$85193 = $$84192;
              }
             }
            }
           } while(0);
           if ($1598) {
            $$104 = $$85;$$104212 = $$85193;
            label = 806;
            break L77;
           }
           $1720 = ((($1595)) + 8|0);
           $1721 = HEAP32[$1720>>2]|0;HEAP32[$1720>>2] = (($1721-1)|0);
           $1722 = ($1721|0)==(1);
           if (!($1722)) {
            $$104 = $$85;$$104212 = $$85193;
            label = 806;
            break L77;
           }
           __THREW__ = 0;
           invoke_viii(3262,($1595|0),1,1);
           $1723 = __THREW__; __THREW__ = 0;
           $1724 = $1723&1;
           if (!($1724)) {
            $$104 = $$85;$$104212 = $$85193;
            label = 806;
            break L77;
           }
           $2128 = ___cxa_find_matching_catch_3(0|0)|0;
           $2129 = tempRet0;
           ___clang_call_terminate($2128);
           // unreachable;
          }
         } while(0);
         if ($1598) {
          label = 788;
          break L77;
         }
         $1713 = ((($1595)) + 8|0);
         $1714 = HEAP32[$1713>>2]|0;HEAP32[$1713>>2] = (($1714-1)|0);
         $1715 = ($1714|0)==(1);
         if (!($1715)) {
          label = 788;
          break L77;
         }
         __THREW__ = 0;
         invoke_viii(3262,($1595|0),1,1);
         $1716 = __THREW__; __THREW__ = 0;
         $1717 = $1716&1;
         if (!($1717)) {
          label = 788;
          break L77;
         }
         $1718 = ___cxa_find_matching_catch_2()|0;
         $1719 = tempRet0;
         $$104 = $1718;$$104212 = $1719;
         label = 806;
         break L77;
        }
       }
       break;
      }
      case 8: case 7: case 6:  {
       __THREW__ = 0;
       invoke_vii(3338,($1|0),(0|0));
       $1725 = __THREW__; __THREW__ = 0;
       $1726 = $1725&1;
       if (!($1726)) {
        __THREW__ = 0;
        $1727 = (invoke_ii(3276,656)|0);
        $1728 = __THREW__; __THREW__ = 0;
        $1729 = $1728&1;
        if (!($1729)) {
         __THREW__ = 0;
         invoke_vi(3336,($1727|0));
         $1730 = __THREW__; __THREW__ = 0;
         $1731 = $1730&1;
         if ($1731) {
          $1839 = ___cxa_find_matching_catch_2()|0;
          $1840 = tempRet0;
          __ZdlPv($1727);
          $$104 = $1839;$$104212 = $1840;
          label = 806;
          break L77;
         }
         $1732 = ((($1727)) + 8|0);
         $1733 = HEAP32[$1732>>2]|0;HEAP32[$1732>>2] = (($1733+1)|0);
         __THREW__ = 0;
         invoke_vii(3338,($1727|0),($137|0));
         $1734 = __THREW__; __THREW__ = 0;
         $1735 = $1734&1;
         L923: do {
          if ($1735) {
           label = 696;
          } else {
           $1736 = ((($142)) + 40|0);
           $1737 = HEAP32[$1736>>2]|0;
           $1738 = ((($142)) + 44|0);
           $1739 = HEAP32[$1738>>2]|0;
           __THREW__ = 0;
           invoke_viiiii(3356,($1727|0),0,0,($1737|0),($1739|0));
           $1740 = __THREW__; __THREW__ = 0;
           $1741 = $1740&1;
           if ($1741) {
            label = 696;
           } else {
            $1742 = ((($142)) + 110|0);
            $1743 = HEAP8[$1742>>0]|0;
            $1744 = ($1743<<24>>24)!=(0);
            $1745 = $1744 ? 1029 : 1028;
            $1746 = ((($1727)) + 568|0);
            HEAP32[$1746>>2] = $1745;
            $1747 = ((($1727)) + 152|0);
            $1748 = HEAP32[$1747>>2]|0;
            $1749 = ($1748|0)==(0);
            $1750 = ((($1727)) + 148|0);
            if ($1749) {
             $1752 = HEAP32[$1750>>2]|0;
             $1753 = $1752 & -131073;
             HEAP32[$1750>>2] = $1753;
             $1754 = ((($1727)) + 572|0);
             HEAP32[$1754>>2] = $1745;
             $1755 = $1752 & -393217;
             HEAP32[$1750>>2] = $1755;
            } else {
             $1751 = ((($1727)) + 572|0);
             HEAP32[$1751>>2] = $1745;
            }
            __THREW__ = 0;
            invoke_vii(3345,($1727|0),1);
            $1756 = __THREW__; __THREW__ = 0;
            $1757 = $1756&1;
            if ($1757) {
             label = 696;
            } else {
             $1758 = ((($1727)) + 236|0);
             HEAP32[$1758>>2] = 17664;
             $1759 = HEAP32[$1747>>2]|0;
             $1760 = ($1759|0)==(0);
             if ($1760) {
              $1761 = HEAP32[$1750>>2]|0;
              $1762 = $1761 & -16385;
              HEAP32[$1750>>2] = $1762;
             }
             $1763 = ((($1727)) + 280|0);
             HEAP32[$1763>>2] = 0;
             $1764 = ((($1727)) + 560|0);
             HEAP32[$1764>>2] = 1;
             $1765 = ((($1727)) + 564|0);
             HEAP32[$1765>>2] = 0;
             __THREW__ = 0;
             invoke_vi(3299,($3|0));
             $1766 = __THREW__; __THREW__ = 0;
             $1767 = $1766&1;
             if ($1767) {
              label = 696;
             } else {
              __THREW__ = 0;
              invoke_vi(3299,($3|0));
              $1768 = __THREW__; __THREW__ = 0;
              $1769 = $1768&1;
              if ($1769) {
               label = 696;
               break;
              }
              __THREW__ = 0;
              invoke_vi(3299,($4|0));
              $1770 = __THREW__; __THREW__ = 0;
              $1771 = $1770&1;
              do {
               if (!($1771)) {
                __THREW__ = 0;
                invoke_vi(3299,($4|0));
                $1772 = __THREW__; __THREW__ = 0;
                $1773 = $1772&1;
                if ($1773) {
                 break;
                }
                __THREW__ = 0;
                (invoke_iiiiii(3343,($0|0),($1727|0),($3|0),($4|0),0)|0);
                $1774 = __THREW__; __THREW__ = 0;
                $1775 = $1774&1;
                if ($1775) {
                 break;
                }
                HEAPF32[$8>>2] = -1.0;
                $1778 = ((($8)) + 4|0);
                HEAPF32[$1778>>2] = -1.0;
                $1779 = ((($8)) + 8|0);
                HEAPF32[$1779>>2] = 0.0;
                HEAPF32[$9>>2] = 2.0;
                $1780 = ((($9)) + 4|0);
                HEAPF32[$1780>>2] = 0.0;
                $1781 = ((($9)) + 8|0);
                HEAPF32[$1781>>2] = 0.0;
                HEAPF32[$10>>2] = 0.0;
                $1782 = ((($10)) + 4|0);
                HEAPF32[$1782>>2] = 2.0;
                $1783 = ((($10)) + 8|0);
                HEAPF32[$1783>>2] = 0.0;
                __THREW__ = 0;
                $1784 = (invoke_iiiidddd(3359,($8|0),($9|0),($10|0),0.0,0.0,1.0,1.0)|0);
                $1785 = __THREW__; __THREW__ = 0;
                $1786 = $1785&1;
                if ($1786) {
                 $1843 = ___cxa_find_matching_catch_2()|0;
                 $1844 = tempRet0;
                 $$96 = $1843;$$96204 = $1844;
                 break L923;
                }
                $1787 = ($1784|0)==(0|0);
                if (!($1787)) {
                 $1788 = ((($1784)) + 8|0);
                 $1789 = HEAP32[$1788>>2]|0;HEAP32[$1788>>2] = (($1789+1)|0);
                }
                __THREW__ = 0;
                $1790 = (invoke_ii(3276,160)|0);
                $1791 = __THREW__; __THREW__ = 0;
                $1792 = $1791&1;
                L946: do {
                 if ($1792) {
                  $1845 = ___cxa_find_matching_catch_2()|0;
                  $1846 = tempRet0;
                  $$94 = $1845;$$94202 = $1846;
                 } else {
                  __THREW__ = 0;
                  invoke_vi(3360,($1790|0));
                  $1793 = __THREW__; __THREW__ = 0;
                  $1794 = $1793&1;
                  if ($1794) {
                   $1847 = ___cxa_find_matching_catch_2()|0;
                   $1848 = tempRet0;
                   __ZdlPv($1790);
                   $$94 = $1847;$$94202 = $1848;
                   break;
                  }
                  $1795 = ((($1790)) + 8|0);
                  $1796 = HEAP32[$1795>>2]|0;HEAP32[$1795>>2] = (($1796+1)|0);
                  $1797 = HEAP32[$1790>>2]|0;
                  $1798 = ((($1797)) + 240|0);
                  $1799 = HEAP32[$1798>>2]|0;
                  __THREW__ = 0;
                  (invoke_iii($1799|0,($1790|0),($1784|0))|0);
                  $1800 = __THREW__; __THREW__ = 0;
                  $1801 = $1800&1;
                  L952: do {
                   if ($1801) {
                    label = 701;
                   } else {
                    $1802 = HEAP32[$1727>>2]|0;
                    $1803 = ((($1802)) + 204|0);
                    $1804 = HEAP32[$1803>>2]|0;
                    __THREW__ = 0;
                    (invoke_iii($1804|0,($1727|0),($1790|0))|0);
                    $1805 = __THREW__; __THREW__ = 0;
                    $1806 = $1805&1;
                    if ($1806) {
                     label = 701;
                     break;
                    }
                    __THREW__ = 0;
                    invoke_vii(3361,($1790|0),0);
                    $1807 = __THREW__; __THREW__ = 0;
                    $1808 = $1807&1;
                    if ($1808) {
                     label = 701;
                     break;
                    }
                    __THREW__ = 0;
                    $1809 = (invoke_ii(3281,($1790|0))|0);
                    $1810 = __THREW__; __THREW__ = 0;
                    $1811 = $1810&1;
                    if ($1811) {
                     label = 701;
                     break;
                    }
                    $1812 = ($1809|0)==(0|0);
                    if (!($1812)) {
                     $1813 = ((($1809)) + 8|0);
                     $1814 = HEAP32[$1813>>2]|0;HEAP32[$1813>>2] = (($1814+1)|0);
                    }
                    __THREW__ = 0;
                    $1815 = (invoke_ii(3276,84)|0);
                    $1816 = __THREW__; __THREW__ = 0;
                    $1817 = $1816&1;
                    L960: do {
                     if ($1817) {
                      $1851 = ___cxa_find_matching_catch_2()|0;
                      $1852 = tempRet0;
                      $$90 = $1851;$$90198 = $1852;
                     } else {
                      __THREW__ = 0;
                      invoke_vi(3362,($1815|0));
                      $1818 = __THREW__; __THREW__ = 0;
                      $1819 = $1818&1;
                      if ($1819) {
                       $1853 = ___cxa_find_matching_catch_2()|0;
                       $1854 = tempRet0;
                       __ZdlPv($1815);
                       $$90 = $1853;$$90198 = $1854;
                       break;
                      }
                      $1820 = ((($1815)) + 8|0);
                      $1821 = HEAP32[$1820>>2]|0;HEAP32[$1820>>2] = (($1821+1)|0);
                      $1822 = ((($1815)) + 56|0);
                      HEAP32[$1822>>2] = 519;
                      $1823 = ((($1815)) + 60|0);
                      HEAP32[$1823>>2] = 1;
                      $1824 = ((($1815)) + 64|0);
                      HEAP32[$1824>>2] = -1;
                      $1825 = ((($1815)) + 68|0);
                      HEAP32[$1825>>2] = 7681;
                      $1826 = ((($1815)) + 72|0);
                      HEAP32[$1826>>2] = 7681;
                      $1827 = ((($1815)) + 76|0);
                      HEAP32[$1827>>2] = 7681;
                      $1828 = ((($1815)) + 80|0);
                      HEAP32[$1828>>2] = -1;
                      __THREW__ = 0;
                      invoke_viii(3363,($1809|0),($1815|0),1);
                      $1829 = __THREW__; __THREW__ = 0;
                      $1830 = $1829&1;
                      L966: do {
                       if ($1830) {
                        label = 704;
                       } else {
                        $1831 = HEAP32[$269>>2]|0;
                        L968: do {
                         switch ($1831|0) {
                         case 7:  {
                          __THREW__ = 0;
                          $1832 = (invoke_ii(3276,184)|0);
                          $1833 = __THREW__; __THREW__ = 0;
                          $1834 = $1833&1;
                          if ($1834) {
                           label = 704;
                           break L966;
                          }
                          __THREW__ = 0;
                          invoke_vii(3364,($1832|0),(103501|0));
                          $1835 = __THREW__; __THREW__ = 0;
                          $1836 = $1835&1;
                          if ($1836) {
                           $1857 = ___cxa_find_matching_catch_2()|0;
                           $1858 = tempRet0;
                           __ZdlPv($1832);
                           $$88 = $1857;$$88196 = $1858;
                           break L966;
                          } else {
                           __THREW__ = 0;
                           invoke_viii(3363,($1809|0),($1832|0),1);
                           $1837 = __THREW__; __THREW__ = 0;
                           $1838 = $1837&1;
                           if ($1838) {
                            label = 704;
                            break L966;
                           } else {
                            break L968;
                           }
                          }
                          break;
                         }
                         case 6:  {
                          __THREW__ = 0;
                          $1859 = (invoke_ii(3276,184)|0);
                          $1860 = __THREW__; __THREW__ = 0;
                          $1861 = $1860&1;
                          if ($1861) {
                           label = 704;
                           break L966;
                          }
                          __THREW__ = 0;
                          invoke_vii(3364,($1859|0),(103629|0));
                          $1862 = __THREW__; __THREW__ = 0;
                          $1863 = $1862&1;
                          if ($1863) {
                           $1866 = ___cxa_find_matching_catch_2()|0;
                           $1867 = tempRet0;
                           __ZdlPv($1859);
                           $$88 = $1866;$$88196 = $1867;
                           break L966;
                          } else {
                           __THREW__ = 0;
                           invoke_viii(3363,($1809|0),($1859|0),1);
                           $1864 = __THREW__; __THREW__ = 0;
                           $1865 = $1864&1;
                           if ($1865) {
                            label = 704;
                            break L966;
                           } else {
                            break L968;
                           }
                          }
                          break;
                         }
                         default: {
                          __THREW__ = 0;
                          $1868 = (invoke_ii(3276,184)|0);
                          $1869 = __THREW__; __THREW__ = 0;
                          $1870 = $1869&1;
                          if ($1870) {
                           label = 704;
                           break L966;
                          }
                          __THREW__ = 0;
                          invoke_vii(3364,($1868|0),(103757|0));
                          $1871 = __THREW__; __THREW__ = 0;
                          $1872 = $1871&1;
                          if ($1872) {
                           $1875 = ___cxa_find_matching_catch_2()|0;
                           $1876 = tempRet0;
                           __ZdlPv($1868);
                           $$88 = $1875;$$88196 = $1876;
                           break L966;
                          } else {
                           __THREW__ = 0;
                           invoke_viii(3363,($1809|0),($1868|0),1);
                           $1873 = __THREW__; __THREW__ = 0;
                           $1874 = $1873&1;
                           if ($1874) {
                            label = 704;
                            break L966;
                           } else {
                            break L968;
                           }
                          }
                         }
                         }
                        } while(0);
                        __THREW__ = 0;
                        invoke_viii(3365,($1809|0),2896,0);
                        $1877 = __THREW__; __THREW__ = 0;
                        $1878 = $1877&1;
                        if ($1878) {
                         label = 704;
                         break;
                        }
                        __THREW__ = 0;
                        invoke_viii(3365,($1809|0),2929,0);
                        $1879 = __THREW__; __THREW__ = 0;
                        $1880 = $1879&1;
                        if ($1880) {
                         label = 704;
                         break;
                        }
                        $1881 = HEAP32[$1820>>2]|0;HEAP32[$1820>>2] = (($1881-1)|0);
                        $1882 = ($1881|0)==(1);
                        do {
                         if ($1882) {
                          __THREW__ = 0;
                          invoke_viii(3262,($1815|0),1,1);
                          $1883 = __THREW__; __THREW__ = 0;
                          $1884 = $1883&1;
                          if (!($1884)) {
                           break;
                          }
                          $1998 = ___cxa_find_matching_catch_2()|0;
                          $1999 = tempRet0;
                          $$90 = $1998;$$90198 = $1999;
                          break L960;
                         }
                        } while(0);
                        do {
                         if (!($1812)) {
                          $1885 = ((($1809)) + 8|0);
                          $1886 = HEAP32[$1885>>2]|0;HEAP32[$1885>>2] = (($1886-1)|0);
                          $1887 = ($1886|0)==(1);
                          if (!($1887)) {
                           break;
                          }
                          __THREW__ = 0;
                          invoke_viii(3262,($1809|0),1,1);
                          $1888 = __THREW__; __THREW__ = 0;
                          $1889 = $1888&1;
                          if (!($1889)) {
                           break;
                          }
                          $2004 = ___cxa_find_matching_catch_2()|0;
                          $2005 = tempRet0;
                          $$92 = $2004;$$92200 = $2005;
                          break L952;
                         }
                        } while(0);
                        $1890 = HEAP32[$1795>>2]|0;HEAP32[$1795>>2] = (($1890-1)|0);
                        $1891 = ($1890|0)==(1);
                        do {
                         if ($1891) {
                          __THREW__ = 0;
                          invoke_viii(3262,($1790|0),1,1);
                          $1892 = __THREW__; __THREW__ = 0;
                          $1893 = $1892&1;
                          if (!($1893)) {
                           break;
                          }
                          $2011 = ___cxa_find_matching_catch_2()|0;
                          $2012 = tempRet0;
                          $$94 = $2011;$$94202 = $2012;
                          break L946;
                         }
                        } while(0);
                        do {
                         if (!($1787)) {
                          $1894 = ((($1784)) + 8|0);
                          $1895 = HEAP32[$1894>>2]|0;HEAP32[$1894>>2] = (($1895-1)|0);
                          $1896 = ($1895|0)==(1);
                          if (!($1896)) {
                           break;
                          }
                          __THREW__ = 0;
                          invoke_viii(3262,($1784|0),1,1);
                          $1897 = __THREW__; __THREW__ = 0;
                          $1898 = $1897&1;
                          if (!($1898)) {
                           break;
                          }
                          $2017 = ___cxa_find_matching_catch_2()|0;
                          $2018 = tempRet0;
                          $$96 = $2017;$$96204 = $2018;
                          break L923;
                         }
                        } while(0);
                        $1899 = HEAP32[$1732>>2]|0;HEAP32[$1732>>2] = (($1899-1)|0);
                        $1900 = ($1899|0)==(1);
                        do {
                         if ($1900) {
                          __THREW__ = 0;
                          invoke_viii(3262,($1727|0),1,1);
                          $1901 = __THREW__; __THREW__ = 0;
                          $1902 = $1901&1;
                          if (!($1902)) {
                           break;
                          }
                          $2024 = ___cxa_find_matching_catch_2()|0;
                          $2025 = tempRet0;
                          $$104 = $2024;$$104212 = $2025;
                          label = 806;
                          break L77;
                         }
                        } while(0);
                        $1903 = HEAP32[$1736>>2]|0;
                        $1904 = HEAP32[$1738>>2]|0;
                        $1905 = HEAP8[$1742>>0]|0;
                        $1906 = ($1905<<24>>24)!=(0);
                        $1907 = $1906 ? 1029 : 1028;
                        __THREW__ = 0;
                        $1908 = (invoke_iiiiiiiiid(3355,($0|0),($2|0),($137|0),0,0,($1903|0),($1904|0),($1907|0),-1.0)|0);
                        $1909 = __THREW__; __THREW__ = 0;
                        $1910 = $1909&1;
                        if ($1910) {
                         break L145;
                        }
                        $1911 = ($1908|0)==(0|0);
                        if (!($1911)) {
                         $1912 = ((($1908)) + 8|0);
                         $1913 = HEAP32[$1912>>2]|0;HEAP32[$1912>>2] = (($1913+1)|0);
                        }
                        $1914 = ((($1908)) + 236|0);
                        HEAP32[$1914>>2] = 0;
                        $1915 = ((($1908)) + 152|0);
                        $1916 = HEAP32[$1915>>2]|0;
                        $1917 = ($1916|0)==(0);
                        $1918 = ((($1908)) + 148|0);
                        if ($1917) {
                         $1919 = HEAP32[$1918>>2]|0;
                         $1920 = $1919 & -16385;
                         HEAP32[$1918>>2] = $1920;
                         HEAP32[$1914>>2] = 16640;
                         $1921 = $1919 & -16385;
                         HEAP32[$1918>>2] = $1921;
                        } else {
                         HEAP32[$1914>>2] = 16640;
                        }
                        $1922 = ((($1908)) + 560|0);
                        HEAP32[$1922>>2] = 1;
                        $1923 = ((($1908)) + 564|0);
                        HEAP32[$1923>>2] = 1;
                        __THREW__ = 0;
                        $1924 = (invoke_ii(3276,84)|0);
                        $1925 = __THREW__; __THREW__ = 0;
                        $1926 = $1925&1;
                        L1017: do {
                         if ($1926) {
                          $2030 = ___cxa_find_matching_catch_2()|0;
                          $2031 = tempRet0;
                          $$99 = $2030;$$99207 = $2031;
                         } else {
                          __THREW__ = 0;
                          invoke_vi(3362,($1924|0));
                          $1927 = __THREW__; __THREW__ = 0;
                          $1928 = $1927&1;
                          if ($1928) {
                           $2032 = ___cxa_find_matching_catch_2()|0;
                           $2033 = tempRet0;
                           __ZdlPv($1924);
                           $$99 = $2032;$$99207 = $2033;
                           break;
                          }
                          $1929 = ((($1924)) + 8|0);
                          $1930 = HEAP32[$1929>>2]|0;HEAP32[$1929>>2] = (($1930+1)|0);
                          $1931 = ((($1924)) + 56|0);
                          HEAP32[$1931>>2] = 514;
                          $1932 = ((($1924)) + 60|0);
                          HEAP32[$1932>>2] = 0;
                          $1933 = ((($1924)) + 64|0);
                          HEAP32[$1933>>2] = -1;
                          $1934 = ((($1924)) + 68|0);
                          HEAP32[$1934>>2] = 7680;
                          $1935 = ((($1924)) + 72|0);
                          HEAP32[$1935>>2] = 7680;
                          $1936 = ((($1924)) + 76|0);
                          HEAP32[$1936>>2] = 7680;
                          __THREW__ = 0;
                          $1937 = (invoke_ii(3281,($1908|0))|0);
                          $1938 = __THREW__; __THREW__ = 0;
                          $1939 = $1938&1;
                          do {
                           if (!($1939)) {
                            __THREW__ = 0;
                            invoke_viii(3363,($1937|0),($1924|0),1);
                            $1940 = __THREW__; __THREW__ = 0;
                            $1941 = $1940&1;
                            if ($1941) {
                             break;
                            }
                            $1942 = HEAP32[$1929>>2]|0;HEAP32[$1929>>2] = (($1942-1)|0);
                            $1943 = ($1942|0)==(1);
                            do {
                             if ($1943) {
                              __THREW__ = 0;
                              invoke_viii(3262,($1924|0),1,1);
                              $1944 = __THREW__; __THREW__ = 0;
                              $1945 = $1944&1;
                              if (!($1945)) {
                               break;
                              }
                              $2040 = ___cxa_find_matching_catch_2()|0;
                              $2041 = tempRet0;
                              $$99 = $2040;$$99207 = $2041;
                              break L1017;
                             }
                            } while(0);
                            $1946 = ((($1908)) + 8|0);
                            $1947 = HEAP32[$1946>>2]|0;HEAP32[$1946>>2] = (($1947-1)|0);
                            $1948 = ($1947|0)==(1);
                            do {
                             if ($1948) {
                              __THREW__ = 0;
                              invoke_viii(3262,($1908|0),1,1);
                              $1949 = __THREW__; __THREW__ = 0;
                              $1950 = $1949&1;
                              if (!($1950)) {
                               break;
                              }
                              $2042 = ___cxa_find_matching_catch_2()|0;
                              $2043 = tempRet0;
                              $$104 = $2042;$$104212 = $2043;
                              label = 806;
                              break L77;
                             }
                            } while(0);
                            $1951 = HEAP32[$1736>>2]|0;
                            $1952 = HEAP32[$1738>>2]|0;
                            $1953 = HEAP8[$1742>>0]|0;
                            $1954 = ($1953<<24>>24)!=(0);
                            $1955 = $1954 ? 1029 : 1028;
                            __THREW__ = 0;
                            $1956 = (invoke_iiiiiiiiid(3355,($0|0),($2|0),($137|0),0,0,($1951|0),($1952|0),($1955|0),1.0)|0);
                            $1957 = __THREW__; __THREW__ = 0;
                            $1958 = $1957&1;
                            if ($1958) {
                             break L145;
                            }
                            $1959 = ($1956|0)==(0|0);
                            if (!($1959)) {
                             $1960 = ((($1956)) + 8|0);
                             $1961 = HEAP32[$1960>>2]|0;HEAP32[$1960>>2] = (($1961+1)|0);
                            }
                            $1962 = ((($1956)) + 236|0);
                            HEAP32[$1962>>2] = 256;
                            $1963 = ((($1956)) + 152|0);
                            $1964 = HEAP32[$1963>>2]|0;
                            $1965 = ($1964|0)==(0);
                            $1966 = ((($1956)) + 148|0);
                            if ($1965) {
                             $1967 = HEAP32[$1966>>2]|0;
                             $1968 = $1967 & -16385;
                             HEAP32[$1966>>2] = $1968;
                            }
                            $1969 = ((($1956)) + 560|0);
                            HEAP32[$1969>>2] = 1;
                            $1970 = ((($1956)) + 564|0);
                            HEAP32[$1970>>2] = 2;
                            __THREW__ = 0;
                            $1971 = (invoke_ii(3276,84)|0);
                            $1972 = __THREW__; __THREW__ = 0;
                            $1973 = $1972&1;
                            L1041: do {
                             if ($1973) {
                              $2049 = ___cxa_find_matching_catch_2()|0;
                              $2050 = tempRet0;
                              $$102 = $2049;$$102210 = $2050;
                             } else {
                              __THREW__ = 0;
                              invoke_vi(3362,($1971|0));
                              $1974 = __THREW__; __THREW__ = 0;
                              $1975 = $1974&1;
                              if ($1975) {
                               $2051 = ___cxa_find_matching_catch_2()|0;
                               $2052 = tempRet0;
                               __ZdlPv($1971);
                               $$102 = $2051;$$102210 = $2052;
                               break;
                              }
                              $1976 = ((($1971)) + 8|0);
                              $1977 = HEAP32[$1976>>2]|0;HEAP32[$1976>>2] = (($1977+1)|0);
                              $1978 = ((($1971)) + 56|0);
                              HEAP32[$1978>>2] = 517;
                              $1979 = ((($1971)) + 60|0);
                              HEAP32[$1979>>2] = 0;
                              $1980 = ((($1971)) + 64|0);
                              HEAP32[$1980>>2] = -1;
                              $1981 = ((($1971)) + 68|0);
                              HEAP32[$1981>>2] = 7680;
                              $1982 = ((($1971)) + 72|0);
                              HEAP32[$1982>>2] = 7680;
                              $1983 = ((($1971)) + 76|0);
                              HEAP32[$1983>>2] = 7680;
                              __THREW__ = 0;
                              $1984 = (invoke_ii(3281,($1956|0))|0);
                              $1985 = __THREW__; __THREW__ = 0;
                              $1986 = $1985&1;
                              do {
                               if (!($1986)) {
                                __THREW__ = 0;
                                invoke_viii(3363,($1984|0),($1971|0),1);
                                $1987 = __THREW__; __THREW__ = 0;
                                $1988 = $1987&1;
                                if ($1988) {
                                 break;
                                }
                                $1989 = HEAP32[$1976>>2]|0;HEAP32[$1976>>2] = (($1989-1)|0);
                                $1990 = ($1989|0)==(1);
                                do {
                                 if ($1990) {
                                  __THREW__ = 0;
                                  invoke_viii(3262,($1971|0),1,1);
                                  $1991 = __THREW__; __THREW__ = 0;
                                  $1992 = $1991&1;
                                  if (!($1992)) {
                                   break;
                                  }
                                  $2059 = ___cxa_find_matching_catch_2()|0;
                                  $2060 = tempRet0;
                                  $$102 = $2059;$$102210 = $2060;
                                  break L1041;
                                 }
                                } while(0);
                                $1993 = ((($1956)) + 8|0);
                                $1994 = HEAP32[$1993>>2]|0;HEAP32[$1993>>2] = (($1994-1)|0);
                                $1995 = ($1994|0)==(1);
                                if (!($1995)) {
                                 label = 788;
                                 break L77;
                                }
                                __THREW__ = 0;
                                invoke_viii(3262,($1956|0),1,1);
                                $1996 = __THREW__; __THREW__ = 0;
                                $1997 = $1996&1;
                                if (!($1997)) {
                                 label = 788;
                                 break L77;
                                }
                                $2061 = ___cxa_find_matching_catch_2()|0;
                                $2062 = tempRet0;
                                $$104 = $2061;$$104212 = $2062;
                                label = 806;
                                break L77;
                               }
                              } while(0);
                              $2053 = ___cxa_find_matching_catch_2()|0;
                              $2054 = tempRet0;
                              $2055 = HEAP32[$1976>>2]|0;HEAP32[$1976>>2] = (($2055-1)|0);
                              $2056 = ($2055|0)==(1);
                              if (!($2056)) {
                               $$102 = $2053;$$102210 = $2054;
                               break;
                              }
                              __THREW__ = 0;
                              invoke_viii(3262,($1971|0),1,1);
                              $2057 = __THREW__; __THREW__ = 0;
                              $2058 = $2057&1;
                              if (!($2058)) {
                               $$102 = $2053;$$102210 = $2054;
                               break;
                              }
                              $2128 = ___cxa_find_matching_catch_3(0|0)|0;
                              $2129 = tempRet0;
                              ___clang_call_terminate($2128);
                              // unreachable;
                             }
                            } while(0);
                            $2063 = ((($1956)) + 8|0);
                            $2064 = HEAP32[$2063>>2]|0;HEAP32[$2063>>2] = (($2064-1)|0);
                            $2065 = ($2064|0)==(1);
                            if (!($2065)) {
                             $$104 = $$102;$$104212 = $$102210;
                             label = 806;
                             break L77;
                            }
                            __THREW__ = 0;
                            invoke_viii(3262,($1956|0),1,1);
                            $2066 = __THREW__; __THREW__ = 0;
                            $2067 = $2066&1;
                            if (!($2067)) {
                             $$104 = $$102;$$104212 = $$102210;
                             label = 806;
                             break L77;
                            }
                            $2128 = ___cxa_find_matching_catch_3(0|0)|0;
                            $2129 = tempRet0;
                            ___clang_call_terminate($2128);
                            // unreachable;
                           }
                          } while(0);
                          $2034 = ___cxa_find_matching_catch_2()|0;
                          $2035 = tempRet0;
                          $2036 = HEAP32[$1929>>2]|0;HEAP32[$1929>>2] = (($2036-1)|0);
                          $2037 = ($2036|0)==(1);
                          if (!($2037)) {
                           $$99 = $2034;$$99207 = $2035;
                           break;
                          }
                          __THREW__ = 0;
                          invoke_viii(3262,($1924|0),1,1);
                          $2038 = __THREW__; __THREW__ = 0;
                          $2039 = $2038&1;
                          if (!($2039)) {
                           $$99 = $2034;$$99207 = $2035;
                           break;
                          }
                          $2128 = ___cxa_find_matching_catch_3(0|0)|0;
                          $2129 = tempRet0;
                          ___clang_call_terminate($2128);
                          // unreachable;
                         }
                        } while(0);
                        $2044 = ((($1908)) + 8|0);
                        $2045 = HEAP32[$2044>>2]|0;HEAP32[$2044>>2] = (($2045-1)|0);
                        $2046 = ($2045|0)==(1);
                        if (!($2046)) {
                         $$104 = $$99;$$104212 = $$99207;
                         label = 806;
                         break L77;
                        }
                        __THREW__ = 0;
                        invoke_viii(3262,($1908|0),1,1);
                        $2047 = __THREW__; __THREW__ = 0;
                        $2048 = $2047&1;
                        if (!($2048)) {
                         $$104 = $$99;$$104212 = $$99207;
                         label = 806;
                         break L77;
                        }
                        $2128 = ___cxa_find_matching_catch_3(0|0)|0;
                        $2129 = tempRet0;
                        ___clang_call_terminate($2128);
                        // unreachable;
                       }
                      } while(0);
                      if ((label|0) == 704) {
                       $1855 = ___cxa_find_matching_catch_2()|0;
                       $1856 = tempRet0;
                       $$88 = $1855;$$88196 = $1856;
                      }
                      $2000 = HEAP32[$1820>>2]|0;HEAP32[$1820>>2] = (($2000-1)|0);
                      $2001 = ($2000|0)==(1);
                      if (!($2001)) {
                       $$90 = $$88;$$90198 = $$88196;
                       break;
                      }
                      __THREW__ = 0;
                      invoke_viii(3262,($1815|0),1,1);
                      $2002 = __THREW__; __THREW__ = 0;
                      $2003 = $2002&1;
                      if (!($2003)) {
                       $$90 = $$88;$$90198 = $$88196;
                       break;
                      }
                      $2128 = ___cxa_find_matching_catch_3(0|0)|0;
                      $2129 = tempRet0;
                      ___clang_call_terminate($2128);
                      // unreachable;
                     }
                    } while(0);
                    if ($1812) {
                     $$92 = $$90;$$92200 = $$90198;
                     break;
                    }
                    $2006 = ((($1809)) + 8|0);
                    $2007 = HEAP32[$2006>>2]|0;HEAP32[$2006>>2] = (($2007-1)|0);
                    $2008 = ($2007|0)==(1);
                    if (!($2008)) {
                     $$92 = $$90;$$92200 = $$90198;
                     break;
                    }
                    __THREW__ = 0;
                    invoke_viii(3262,($1809|0),1,1);
                    $2009 = __THREW__; __THREW__ = 0;
                    $2010 = $2009&1;
                    if (!($2010)) {
                     $$92 = $$90;$$92200 = $$90198;
                     break;
                    }
                    $2128 = ___cxa_find_matching_catch_3(0|0)|0;
                    $2129 = tempRet0;
                    ___clang_call_terminate($2128);
                    // unreachable;
                   }
                  } while(0);
                  if ((label|0) == 701) {
                   $1849 = ___cxa_find_matching_catch_2()|0;
                   $1850 = tempRet0;
                   $$92 = $1849;$$92200 = $1850;
                  }
                  $2013 = HEAP32[$1795>>2]|0;HEAP32[$1795>>2] = (($2013-1)|0);
                  $2014 = ($2013|0)==(1);
                  if (!($2014)) {
                   $$94 = $$92;$$94202 = $$92200;
                   break;
                  }
                  __THREW__ = 0;
                  invoke_viii(3262,($1790|0),1,1);
                  $2015 = __THREW__; __THREW__ = 0;
                  $2016 = $2015&1;
                  if (!($2016)) {
                   $$94 = $$92;$$94202 = $$92200;
                   break;
                  }
                  $2128 = ___cxa_find_matching_catch_3(0|0)|0;
                  $2129 = tempRet0;
                  ___clang_call_terminate($2128);
                  // unreachable;
                 }
                } while(0);
                if ($1787) {
                 $$96 = $$94;$$96204 = $$94202;
                 break L923;
                }
                $2019 = ((($1784)) + 8|0);
                $2020 = HEAP32[$2019>>2]|0;HEAP32[$2019>>2] = (($2020-1)|0);
                $2021 = ($2020|0)==(1);
                if (!($2021)) {
                 $$96 = $$94;$$96204 = $$94202;
                 break L923;
                }
                __THREW__ = 0;
                invoke_viii(3262,($1784|0),1,1);
                $2022 = __THREW__; __THREW__ = 0;
                $2023 = $2022&1;
                if (!($2023)) {
                 $$96 = $$94;$$96204 = $$94202;
                 break L923;
                }
                $2128 = ___cxa_find_matching_catch_3(0|0)|0;
                $2129 = tempRet0;
                ___clang_call_terminate($2128);
                // unreachable;
               }
              } while(0);
              $1776 = ___cxa_find_matching_catch_2()|0;
              $1777 = tempRet0;
              $eh$lpad$body$index4Z2D = $1777;$eh$lpad$body$indexZ2D = $1776;
              label = 697;
             }
            }
           }
          }
         } while(0);
         if ((label|0) == 696) {
          $1841 = ___cxa_find_matching_catch_2()|0;
          $1842 = tempRet0;
          $eh$lpad$body$index4Z2D = $1842;$eh$lpad$body$indexZ2D = $1841;
          label = 697;
         }
         if ((label|0) == 697) {
          $$96 = $eh$lpad$body$indexZ2D;$$96204 = $eh$lpad$body$index4Z2D;
         }
         $2026 = HEAP32[$1732>>2]|0;HEAP32[$1732>>2] = (($2026-1)|0);
         $2027 = ($2026|0)==(1);
         if (!($2027)) {
          $$104 = $$96;$$104212 = $$96204;
          label = 806;
          break L77;
         }
         __THREW__ = 0;
         invoke_viii(3262,($1727|0),1,1);
         $2028 = __THREW__; __THREW__ = 0;
         $2029 = $2028&1;
         if (!($2029)) {
          $$104 = $$96;$$104212 = $$96204;
          label = 806;
          break L77;
         }
         $2128 = ___cxa_find_matching_catch_3(0|0)|0;
         $2129 = tempRet0;
         ___clang_call_terminate($2128);
         // unreachable;
        }
       }
       break;
      }
      default: {
       label = 788;
       break L77;
      }
      }
     } while(0);
     $157 = ___cxa_find_matching_catch_2()|0;
     $158 = tempRet0;
     $$104 = $157;$$104212 = $158;
     label = 806;
    }
   } while(0);
   do {
    if ((label|0) == 788) {
     if (!($143)) {
      $2068 = ((($142)) + 8|0);
      $2069 = HEAP32[$2068>>2]|0;HEAP32[$2068>>2] = (($2069-1)|0);
      $2070 = ($2069|0)==(1);
      if ($2070) {
       __THREW__ = 0;
       invoke_viii(3262,($142|0),1,1);
       $2071 = __THREW__; __THREW__ = 0;
       $2072 = $2071&1;
       if ($2072) {
        $2096 = ___cxa_find_matching_catch_2()|0;
        $2097 = tempRet0;
        $$105 = $2096;$$105213 = $2097;
        break;
       }
      }
     }
     if (!($138)) {
      $2073 = ((($137)) + 8|0);
      $2074 = HEAP32[$2073>>2]|0;HEAP32[$2073>>2] = (($2074-1)|0);
      $2075 = ($2074|0)==(1);
      if ($2075) {
       __THREW__ = 0;
       invoke_viii(3262,($137|0),1,1);
       $2076 = __THREW__; __THREW__ = 0;
       $2077 = $2076&1;
       if ($2077) {
        $2103 = ___cxa_find_matching_catch_2()|0;
        $2104 = tempRet0;
        $$108 = $2103;$$108216 = $2104;
        break L69;
       }
      }
     }
     $2078 = HEAP32[$5>>2]|0;
     $2079 = ($2078|0)==(0|0);
     if (!($2079)) {
      $2080 = HEAP32[$22>>2]|0;
      $2081 = ($2080|0)==($2078|0);
      do {
       if ($2081) {
        $2095 = $2078;
       } else {
        $2083 = $2080;
        while(1) {
         $2082 = ((($2083)) + -4|0);
         HEAP32[$22>>2] = $2082;
         $2084 = HEAP32[$2082>>2]|0;
         $2085 = ($2084|0)==(0|0);
         if (!($2085)) {
          $2086 = ((($2084)) + 8|0);
          $2087 = HEAP32[$2086>>2]|0;HEAP32[$2086>>2] = (($2087-1)|0);
          $2088 = ($2087|0)==(1);
          if ($2088) {
           __THREW__ = 0;
           invoke_viii(3262,($2084|0),1,1);
           $2089 = __THREW__; __THREW__ = 0;
           $2090 = $2089&1;
           if ($2090) {
            label = 800;
            break;
           }
          }
         }
         HEAP32[$2082>>2] = 0;
         $2091 = HEAP32[$22>>2]|0;
         $2092 = ($2091|0)==($2078|0);
         if ($2092) {
          label = 801;
          break;
         } else {
          $2083 = $2091;
         }
        }
        if ((label|0) == 800) {
         $2093 = ___cxa_find_matching_catch_2()|0;
         $2094 = tempRet0;
         ___cxa_call_unexpected(($2093|0));
         // unreachable;
        }
        else if ((label|0) == 801) {
         $$pre$i221 = HEAP32[$5>>2]|0;
         $2095 = $$pre$i221;
         break;
        }
       }
      } while(0);
      __ZdlPv($2095);
     }
     STACKTOP = sp;return;
    }
    else if ((label|0) == 806) {
     if ($143) {
      $$105 = $$104;$$105213 = $$104212;
     } else {
      $2098 = ((($142)) + 8|0);
      $2099 = HEAP32[$2098>>2]|0;HEAP32[$2098>>2] = (($2099-1)|0);
      $2100 = ($2099|0)==(1);
      if ($2100) {
       __THREW__ = 0;
       invoke_viii(3262,($142|0),1,1);
       $2101 = __THREW__; __THREW__ = 0;
       $2102 = $2101&1;
       if ($2102) {
        $2128 = ___cxa_find_matching_catch_3(0|0)|0;
        $2129 = tempRet0;
        ___clang_call_terminate($2128);
        // unreachable;
       } else {
        $$105 = $$104;$$105213 = $$104212;
       }
      } else {
       $$105 = $$104;$$105213 = $$104212;
      }
     }
    }
   } while(0);
   if ($138) {
    $$108 = $$105;$$108216 = $$105213;
   } else {
    $2105 = ((($137)) + 8|0);
    $2106 = HEAP32[$2105>>2]|0;HEAP32[$2105>>2] = (($2106-1)|0);
    $2107 = ($2106|0)==(1);
    if ($2107) {
     __THREW__ = 0;
     invoke_viii(3262,($137|0),1,1);
     $2108 = __THREW__; __THREW__ = 0;
     $2109 = $2108&1;
     if ($2109) {
      $2128 = ___cxa_find_matching_catch_3(0|0)|0;
      $2129 = tempRet0;
      ___clang_call_terminate($2128);
      // unreachable;
     } else {
      $$108 = $$105;$$108216 = $$105213;
     }
    } else {
     $$108 = $$105;$$108216 = $$105213;
    }
   }
  }
 } while(0);
 $2110 = HEAP32[$5>>2]|0;
 $2111 = ($2110|0)==(0|0);
 if ($2111) {
  ___resumeException($$108|0);
  // unreachable;
 }
 $2112 = HEAP32[$22>>2]|0;
 $2113 = ($2112|0)==($2110|0);
 do {
  if ($2113) {
   $2127 = $2110;
  } else {
   $2115 = $2112;
   while(1) {
    $2114 = ((($2115)) + -4|0);
    HEAP32[$22>>2] = $2114;
    $2116 = HEAP32[$2114>>2]|0;
    $2117 = ($2116|0)==(0|0);
    if (!($2117)) {
     $2118 = ((($2116)) + 8|0);
     $2119 = HEAP32[$2118>>2]|0;HEAP32[$2118>>2] = (($2119-1)|0);
     $2120 = ($2119|0)==(1);
     if ($2120) {
      __THREW__ = 0;
      invoke_viii(3262,($2116|0),1,1);
      $2121 = __THREW__; __THREW__ = 0;
      $2122 = $2121&1;
      if ($2122) {
       label = 819;
       break;
      }
     }
    }
    HEAP32[$2114>>2] = 0;
    $2123 = HEAP32[$22>>2]|0;
    $2124 = ($2123|0)==($2110|0);
    if ($2124) {
     label = 820;
     break;
    } else {
     $2115 = $2123;
    }
   }
   if ((label|0) == 819) {
    $2125 = ___cxa_find_matching_catch_2()|0;
    $2126 = tempRet0;
    ___cxa_call_unexpected(($2125|0));
    // unreachable;
   }
   else if ((label|0) == 820) {
    $$pre$i = HEAP32[$5>>2]|0;
    $2127 = $$pre$i;
    break;
   }
  }
 } while(0);
 __ZdlPv($2127);
 ___resumeException($$108|0);
 // unreachable;
}
function __ZNSt3__26vectorIN3osg7ref_ptrIN9osgViewer8KeystoneEEENS_9allocatorIS5_EEE21__push_back_slow_pathIKS5_EEvRT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$06$i$i = 0, $$pre = 0, $$pre$i = 0, $$pre38 = 0, $$pre39 = 0, $$sroa$7$0 = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(1073741823);
 $9 = $4;
 $10 = $3;
 if ($8) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $11 = ((($0)) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) - ($4))|0;
 $14 = $13 >> 2;
 $15 = ($14>>>0)<(536870911);
 $16 = $13 >> 1;
 $17 = ($16>>>0)<($7>>>0);
 $$sroa$speculated$i = $17 ? $7 : $16;
 $$sroa$speculated$$i = $15 ? $$sroa$speculated$i : 1073741823;
 $18 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($18) {
   $28 = 0;
  } else {
   $19 = ($$sroa$speculated$$i>>>0)>(1073741823);
   if (!($19)) {
    $25 = $$sroa$speculated$$i << 2;
    $26 = (__Znwj($25)|0);
    $28 = $26;
    break;
   }
   $20 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($20|0),(204840|0));
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if ($22) {
    $23 = ___cxa_find_matching_catch_2()|0;
    $24 = tempRet0;
    ___cxa_free_exception(($20|0));
    ___resumeException($23|0);
    // unreachable;
   } else {
    HEAP32[$20>>2] = (99824);
    ___cxa_throw(($20|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $27 = (($28) + ($6<<2)|0);
 $29 = $27;
 $30 = (($28) + ($$sroa$speculated$$i<<2)|0);
 $31 = $30;
 $32 = HEAP32[$1>>2]|0;
 HEAP32[$27>>2] = $32;
 $33 = ($32|0)==(0|0);
 if ($33) {
  $38 = $10;$40 = $9;
 } else {
  $34 = ((($32)) + 8|0);
  $35 = HEAP32[$34>>2]|0;HEAP32[$34>>2] = (($35+1)|0);
  $$pre = HEAP32[$0>>2]|0;
  $$pre38 = HEAP32[$2>>2]|0;
  $38 = $$pre38;$40 = $$pre;
 }
 $36 = ((($27)) + 4|0);
 $37 = $36;
 $39 = ($38|0)==($40|0);
 if ($39) {
  $41 = $38;
  $53 = $29;$54 = $41;$56 = $38;
 } else {
  $$06$i$i = $38;$$sroa$7$0 = $29;$44 = $27;
  while(1) {
   $42 = ((($$06$i$i)) + -4|0);
   $43 = ((($44)) + -4|0);
   $45 = HEAP32[$42>>2]|0;
   HEAP32[$43>>2] = $45;
   $46 = ($45|0)==(0|0);
   if (!($46)) {
    $47 = ((($45)) + 8|0);
    $48 = HEAP32[$47>>2]|0;HEAP32[$47>>2] = (($48+1)|0);
   }
   $49 = $$sroa$7$0;
   $50 = ((($49)) + -4|0);
   $51 = $50;
   $52 = ($42|0)==($40|0);
   if ($52) {
    break;
   } else {
    $$06$i$i = $42;$$sroa$7$0 = $51;$44 = $50;
   }
  }
  $$pre$i = HEAP32[$0>>2]|0;
  $$pre39 = HEAP32[$2>>2]|0;
  $53 = $51;$54 = $$pre$i;$56 = $$pre39;
 }
 HEAP32[$0>>2] = $53;
 HEAP32[$2>>2] = $37;
 HEAP32[$11>>2] = $31;
 $55 = $54;
 $57 = ($56|0)==($55|0);
 L25: do {
  if (!($57)) {
   $59 = $56;
   while(1) {
    $58 = ((($59)) + -4|0);
    $60 = HEAP32[$58>>2]|0;
    $61 = ($60|0)==(0|0);
    if (!($61)) {
     $62 = ((($60)) + 8|0);
     $63 = HEAP32[$62>>2]|0;HEAP32[$62>>2] = (($63-1)|0);
     $64 = ($63|0)==(1);
     if ($64) {
      __THREW__ = 0;
      invoke_viii(3262,($60|0),1,1);
      $65 = __THREW__; __THREW__ = 0;
      $66 = $65&1;
      if ($66) {
       break;
      }
     }
    }
    HEAP32[$58>>2] = 0;
    $67 = ($58|0)==($55|0);
    if ($67) {
     break L25;
    } else {
     $59 = $58;
    }
   }
   $68 = ___cxa_find_matching_catch_2()|0;
   $69 = tempRet0;
   ___cxa_call_unexpected(($68|0));
   // unreachable;
  }
 } while(0);
 $70 = ($54|0)==(0);
 if ($70) {
  return;
 }
 $71 = $54;
 __ZdlPv($71);
 return;
}
function __ZN9osgViewer6Viewer14setViewerStatsEPN3osg5StatsE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 108|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==($1|0);
 if ($4) {
  return;
 }
 HEAP32[$2>>2] = $1;
 $5 = ($1|0)==(0|0);
 if (!($5)) {
  $6 = ((($1)) + 8|0);
  $7 = HEAP32[$6>>2]|0;HEAP32[$6>>2] = (($7+1)|0);
 }
 $8 = ($3|0)==(0|0);
 if ($8) {
  return;
 }
 $9 = ((($3)) + 8|0);
 $10 = HEAP32[$9>>2]|0;HEAP32[$9>>2] = (($10-1)|0);
 $11 = ($10|0)==(1);
 if (!($11)) {
  return;
 }
 __ZNK3osg10Referenced24signalObserversAndDeleteEbb($3,1,1);
 return;
}
function __ZN9osgViewer6Viewer14getViewerStatsEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 108|0);
 $2 = HEAP32[$1>>2]|0;
 return ($2|0);
}
function __ZNK9osgViewer6Viewer14getViewerStatsEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 108|0);
 $2 = HEAP32[$1>>2]|0;
 return ($2|0);
}
function __ZN9osgViewer6Viewer17readConfigurationERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$3$ph = 0, $$366 = 0, $$pr = 0, $$sink25$sink26$index = 0, $$sink25$sink26$index6 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0;
 var $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0;
 var $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0;
 var $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $2 = sp + 16|0;
 $3 = sp + 12|0;
 $4 = sp + 8|0;
 $5 = sp + 4|0;
 $6 = sp;
 $7 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
 do {
  if ($7) {
   $8 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
   $9 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($8,104653,26)|0);
   $10 = ((($1)) + 11|0);
   $11 = HEAP8[$10>>0]|0;
   $12 = ($11<<24>>24)<(0);
   $13 = HEAP32[$1>>2]|0;
   $14 = $12 ? $13 : $1;
   $15 = ((($1)) + 4|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = $11&255;
   $18 = $12 ? $16 : $17;
   $19 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($9,$14,$18)|0);
   $20 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($19,174996,1)|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = ((($21)) + -12|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = (($20) + ($23)|0);
   __ZNKSt3__28ios_base6getlocEv($5,$24);
   __THREW__ = 0;
   $25 = (invoke_iii(3255,($5|0),(215188|0))|0);
   $26 = __THREW__; __THREW__ = 0;
   $27 = $26&1;
   if (!($27)) {
    $28 = HEAP32[$25>>2]|0;
    $29 = ((($28)) + 28|0);
    $30 = HEAP32[$29>>2]|0;
    __THREW__ = 0;
    $31 = (invoke_iii($30|0,($25|0),10)|0);
    $32 = __THREW__; __THREW__ = 0;
    $33 = $32&1;
    if (!($33)) {
     __ZNSt3__26localeD2Ev($5);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($20,$31)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($20)|0);
     break;
    }
   }
   $34 = ___cxa_find_matching_catch_2()|0;
   $35 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($5|0));
   $36 = __THREW__; __THREW__ = 0;
   $37 = $36&1;
   if ($37) {
    $38 = ___cxa_find_matching_catch_3(0|0)|0;
    $39 = tempRet0;
    ___clang_call_terminate($38);
    // unreachable;
   } else {
    ___resumeException($34|0);
    // unreachable;
   }
  }
 } while(0);
 $40 = (__ZN5osgDB8Registry8instanceEb(0)|0);
 $41 = ((($40)) + 160|0);
 $42 = HEAP32[$41>>2]|0;
 __ZN5osgDB17readRefObjectFileERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEPKNS_7OptionsE($6,$1,$42);
 $43 = HEAP32[$6>>2]|0;
 $44 = ($43|0)==(0|0);
 if ($44) {
  $$366 = 0;
  STACKTOP = sp;return ($$366|0);
 }
 $45 = (___dynamic_cast($43,26112,3976,0)|0);
 $46 = ($45|0)==(0|0);
 L14: do {
  if ($46) {
   $101 = (___dynamic_cast($43,26112,5584,-1)|0);
   $102 = ($101|0)==(0|0);
   if (!($102)) {
    __THREW__ = 0;
    $103 = (invoke_ii(3265,3)|0);
    $104 = __THREW__; __THREW__ = 0;
    $105 = $104&1;
    do {
     if (!($105)) {
      if (!($103)) {
       $$3$ph = 0;
       label = 65;
       break L14;
      }
      __THREW__ = 0;
      $106 = (invoke_ii(3266,3)|0);
      $107 = __THREW__; __THREW__ = 0;
      $108 = $107&1;
      if (!($108)) {
       __THREW__ = 0;
       $109 = (invoke_iiii(3267,($106|0),(104707|0),20)|0);
       $110 = __THREW__; __THREW__ = 0;
       $111 = $110&1;
       if (!($111)) {
        $112 = ((($1)) + 11|0);
        $113 = HEAP8[$112>>0]|0;
        $114 = ($113<<24>>24)<(0);
        $115 = HEAP32[$1>>2]|0;
        $116 = $114 ? $115 : $1;
        $117 = ((($1)) + 4|0);
        $118 = HEAP32[$117>>2]|0;
        $119 = $113&255;
        $120 = $114 ? $118 : $119;
        __THREW__ = 0;
        $121 = (invoke_iiii(3267,($109|0),($116|0),($120|0))|0);
        $122 = __THREW__; __THREW__ = 0;
        $123 = $122&1;
        if (!($123)) {
         __THREW__ = 0;
         $124 = (invoke_iiii(3267,($121|0),(104728|0),56)|0);
         $125 = __THREW__; __THREW__ = 0;
         $126 = $125&1;
         if (!($126)) {
          $127 = HEAP32[$124>>2]|0;
          $128 = ((($127)) + -12|0);
          $129 = HEAP32[$128>>2]|0;
          $130 = (($124) + ($129)|0);
          __THREW__ = 0;
          invoke_vii(3257,($3|0),($130|0));
          $131 = __THREW__; __THREW__ = 0;
          $132 = $131&1;
          if (!($132)) {
           __THREW__ = 0;
           $133 = (invoke_iii(3255,($3|0),(215188|0))|0);
           $134 = __THREW__; __THREW__ = 0;
           $135 = $134&1;
           if (!($135)) {
            $136 = HEAP32[$133>>2]|0;
            $137 = ((($136)) + 28|0);
            $138 = HEAP32[$137>>2]|0;
            __THREW__ = 0;
            $139 = (invoke_iii($138|0,($133|0),10)|0);
            $140 = __THREW__; __THREW__ = 0;
            $141 = $140&1;
            if (!($141)) {
             __THREW__ = 0;
             invoke_vi(3263,($3|0));
             $148 = __THREW__; __THREW__ = 0;
             $149 = $148&1;
             if ($149) {
              break;
             }
             __THREW__ = 0;
             (invoke_iii(3268,($124|0),($139|0))|0);
             $150 = __THREW__; __THREW__ = 0;
             $151 = $150&1;
             if ($151) {
              break;
             }
             __THREW__ = 0;
             (invoke_ii(3269,($124|0))|0);
             $152 = __THREW__; __THREW__ = 0;
             $153 = $152&1;
             if ($153) {
              break;
             } else {
              $$3$ph = 0;
              label = 65;
              break L14;
             }
            }
           }
           $142 = ___cxa_find_matching_catch_2()|0;
           $143 = tempRet0;
           __THREW__ = 0;
           invoke_vi(3263,($3|0));
           $144 = __THREW__; __THREW__ = 0;
           $145 = $144&1;
           if ($145) {
            $146 = ___cxa_find_matching_catch_3(0|0)|0;
            $147 = tempRet0;
            ___clang_call_terminate($146);
            // unreachable;
           } else {
            $$sink25$sink26$index = $142;$$sink25$sink26$index6 = $143;
            break L14;
           }
          }
         }
        }
       }
      }
     }
    } while(0);
    $154 = ___cxa_find_matching_catch_2()|0;
    $155 = tempRet0;
    $$sink25$sink26$index = $154;$$sink25$sink26$index6 = $155;
    break;
   }
   $156 = (___dynamic_cast($43,26112,3928,-1)|0);
   $157 = ($156|0)==(0|0);
   do {
    if ($157) {
     __THREW__ = 0;
     $165 = (invoke_ii(3265,3)|0);
     $166 = __THREW__; __THREW__ = 0;
     $167 = $166&1;
     if (!($167)) {
      if (!($165)) {
       $$3$ph = 0;
       label = 65;
       break L14;
      }
      __THREW__ = 0;
      $168 = (invoke_ii(3266,3)|0);
      $169 = __THREW__; __THREW__ = 0;
      $170 = $169&1;
      if (!($170)) {
       __THREW__ = 0;
       $171 = (invoke_iiii(3267,($168|0),(104707|0),20)|0);
       $172 = __THREW__; __THREW__ = 0;
       $173 = $172&1;
       if (!($173)) {
        $174 = ((($1)) + 11|0);
        $175 = HEAP8[$174>>0]|0;
        $176 = ($175<<24>>24)<(0);
        $177 = HEAP32[$1>>2]|0;
        $178 = $176 ? $177 : $1;
        $179 = ((($1)) + 4|0);
        $180 = HEAP32[$179>>2]|0;
        $181 = $175&255;
        $182 = $176 ? $180 : $181;
        __THREW__ = 0;
        $183 = (invoke_iiii(3267,($171|0),($178|0),($182|0))|0);
        $184 = __THREW__; __THREW__ = 0;
        $185 = $184&1;
        if (!($185)) {
         __THREW__ = 0;
         $186 = (invoke_iiii(3267,($183|0),(104785|0),48)|0);
         $187 = __THREW__; __THREW__ = 0;
         $188 = $187&1;
         if (!($188)) {
          $189 = HEAP32[$186>>2]|0;
          $190 = ((($189)) + -12|0);
          $191 = HEAP32[$190>>2]|0;
          $192 = (($186) + ($191)|0);
          __THREW__ = 0;
          invoke_vii(3257,($2|0),($192|0));
          $193 = __THREW__; __THREW__ = 0;
          $194 = $193&1;
          if (!($194)) {
           __THREW__ = 0;
           $195 = (invoke_iii(3255,($2|0),(215188|0))|0);
           $196 = __THREW__; __THREW__ = 0;
           $197 = $196&1;
           if (!($197)) {
            $198 = HEAP32[$195>>2]|0;
            $199 = ((($198)) + 28|0);
            $200 = HEAP32[$199>>2]|0;
            __THREW__ = 0;
            $201 = (invoke_iii($200|0,($195|0),10)|0);
            $202 = __THREW__; __THREW__ = 0;
            $203 = $202&1;
            if (!($203)) {
             __THREW__ = 0;
             invoke_vi(3263,($2|0));
             $210 = __THREW__; __THREW__ = 0;
             $211 = $210&1;
             if ($211) {
              break;
             }
             __THREW__ = 0;
             (invoke_iii(3268,($186|0),($201|0))|0);
             $212 = __THREW__; __THREW__ = 0;
             $213 = $212&1;
             if ($213) {
              break;
             }
             __THREW__ = 0;
             (invoke_ii(3269,($186|0))|0);
             $214 = __THREW__; __THREW__ = 0;
             $215 = $214&1;
             if ($215) {
              break;
             } else {
              $$3$ph = 0;
              label = 65;
              break L14;
             }
            }
           }
           $204 = ___cxa_find_matching_catch_2()|0;
           $205 = tempRet0;
           __THREW__ = 0;
           invoke_vi(3263,($2|0));
           $206 = __THREW__; __THREW__ = 0;
           $207 = $206&1;
           if ($207) {
            $208 = ___cxa_find_matching_catch_3(0|0)|0;
            $209 = tempRet0;
            ___clang_call_terminate($208);
            // unreachable;
           } else {
            $$sink25$sink26$index = $204;$$sink25$sink26$index6 = $205;
            break L14;
           }
          }
         }
        }
       }
      }
     }
    } else {
     $158 = HEAP32[$0>>2]|0;
     $159 = ((($158)) + 156|0);
     $160 = HEAP32[$159>>2]|0;
     __THREW__ = 0;
     invoke_vii($160|0,($0|0),($156|0));
     $161 = __THREW__; __THREW__ = 0;
     $162 = $161&1;
     if (!($162)) {
      $$3$ph = 1;
      label = 65;
      break L14;
     }
    }
   } while(0);
   $163 = ___cxa_find_matching_catch_2()|0;
   $164 = tempRet0;
   $$sink25$sink26$index = $163;$$sink25$sink26$index6 = $164;
  } else {
   __THREW__ = 0;
   $47 = (invoke_ii(3265,4)|0);
   $48 = __THREW__; __THREW__ = 0;
   $49 = $48&1;
   L58: do {
    if (!($49)) {
     do {
      if ($47) {
       __THREW__ = 0;
       $50 = (invoke_ii(3266,4)|0);
       $51 = __THREW__; __THREW__ = 0;
       $52 = $51&1;
       if ($52) {
        break L58;
       }
       __THREW__ = 0;
       $53 = (invoke_iiii(3267,($50|0),(104680|0),26)|0);
       $54 = __THREW__; __THREW__ = 0;
       $55 = $54&1;
       if ($55) {
        break L58;
       }
       $56 = HEAP32[$45>>2]|0;
       $57 = ((($56)) + 28|0);
       $58 = HEAP32[$57>>2]|0;
       __THREW__ = 0;
       $59 = (invoke_ii($58|0,($45|0))|0);
       $60 = __THREW__; __THREW__ = 0;
       $61 = $60&1;
       if ($61) {
        break L58;
       }
       $62 = (_strlen($59)|0);
       __THREW__ = 0;
       $63 = (invoke_iiii(3267,($53|0),($59|0),($62|0))|0);
       $64 = __THREW__; __THREW__ = 0;
       $65 = $64&1;
       if ($65) {
        break L58;
       }
       $66 = HEAP32[$63>>2]|0;
       $67 = ((($66)) + -12|0);
       $68 = HEAP32[$67>>2]|0;
       $69 = (($63) + ($68)|0);
       __THREW__ = 0;
       invoke_vii(3257,($4|0),($69|0));
       $70 = __THREW__; __THREW__ = 0;
       $71 = $70&1;
       if ($71) {
        break L58;
       }
       __THREW__ = 0;
       $72 = (invoke_iii(3255,($4|0),(215188|0))|0);
       $73 = __THREW__; __THREW__ = 0;
       $74 = $73&1;
       if (!($74)) {
        $75 = HEAP32[$72>>2]|0;
        $76 = ((($75)) + 28|0);
        $77 = HEAP32[$76>>2]|0;
        __THREW__ = 0;
        $78 = (invoke_iii($77|0,($72|0),10)|0);
        $79 = __THREW__; __THREW__ = 0;
        $80 = $79&1;
        if (!($80)) {
         __THREW__ = 0;
         invoke_vi(3263,($4|0));
         $87 = __THREW__; __THREW__ = 0;
         $88 = $87&1;
         if ($88) {
          break L58;
         }
         __THREW__ = 0;
         (invoke_iii(3268,($63|0),($78|0))|0);
         $89 = __THREW__; __THREW__ = 0;
         $90 = $89&1;
         if ($90) {
          break L58;
         }
         __THREW__ = 0;
         (invoke_ii(3269,($63|0))|0);
         $91 = __THREW__; __THREW__ = 0;
         $92 = $91&1;
         if ($92) {
          break L58;
         } else {
          break;
         }
        }
       }
       $81 = ___cxa_find_matching_catch_2()|0;
       $82 = tempRet0;
       __THREW__ = 0;
       invoke_vi(3263,($4|0));
       $83 = __THREW__; __THREW__ = 0;
       $84 = $83&1;
       if ($84) {
        $85 = ___cxa_find_matching_catch_3(0|0)|0;
        $86 = tempRet0;
        ___clang_call_terminate($85);
        // unreachable;
       } else {
        $$sink25$sink26$index = $81;$$sink25$sink26$index6 = $82;
        break L14;
       }
      }
     } while(0);
     $95 = HEAP32[$45>>2]|0;
     $96 = ((($95)) + 140|0);
     $97 = HEAP32[$96>>2]|0;
     $98 = ((($0)) + 104|0);
     __THREW__ = 0;
     invoke_vii($97|0,($45|0),($98|0));
     $99 = __THREW__; __THREW__ = 0;
     $100 = $99&1;
     if (!($100)) {
      $$3$ph = 1;
      label = 65;
      break L14;
     }
    }
   } while(0);
   $93 = ___cxa_find_matching_catch_2()|0;
   $94 = tempRet0;
   $$sink25$sink26$index = $93;$$sink25$sink26$index6 = $94;
  }
 } while(0);
 if ((label|0) == 65) {
  $$pr = HEAP32[$6>>2]|0;
  $223 = ($$pr|0)==(0|0);
  if ($223) {
   $$366 = $$3$ph;
   STACKTOP = sp;return ($$366|0);
  }
  $224 = ((($$pr)) + 8|0);
  $225 = HEAP32[$224>>2]|0;HEAP32[$224>>2] = (($225-1)|0);
  $226 = ($225|0)==(1);
  if (!($226)) {
   $$366 = $$3$ph;
   STACKTOP = sp;return ($$366|0);
  }
  __ZNK3osg10Referenced24signalObserversAndDeleteEbb($$pr,1,1);
  $$366 = $$3$ph;
  STACKTOP = sp;return ($$366|0);
 }
 $216 = HEAP32[$6>>2]|0;
 $217 = ($216|0)==(0|0);
 if ($217) {
  ___resumeException($$sink25$sink26$index|0);
  // unreachable;
 }
 $218 = ((($216)) + 8|0);
 $219 = HEAP32[$218>>2]|0;HEAP32[$218>>2] = (($219-1)|0);
 $220 = ($219|0)==(1);
 if (!($220)) {
  ___resumeException($$sink25$sink26$index|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(3262,($216|0),1,1);
 $221 = __THREW__; __THREW__ = 0;
 $222 = $221&1;
 if ($222) {
  $227 = ___cxa_find_matching_catch_3(0|0)|0;
  $228 = tempRet0;
  ___clang_call_terminate($227);
  // unreachable;
 } else {
  ___resumeException($$sink25$sink26$index|0);
  // unreachable;
 }
 return (0)|0;
}
function __ZNK9osgViewer6Viewer10isRealizedEv($0) {
 $0 = $0|0;
 var $$$0 = 0, $$0$lcssa = 0, $$022 = 0, $$pre = 0, $$sroa$014$021 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i8 = 0, $scevgep5$i$i$i = 0, $scevgep5$i$i$i9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 HEAP32[$1>>2] = 0;
 $2 = ((($1)) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = ((($1)) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = HEAP32[$0>>2]|0;
 $5 = ((($4)) + 88|0);
 $6 = HEAP32[$5>>2]|0;
 __THREW__ = 0;
 invoke_viii($6|0,($0|0),($1|0),1);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 L1: do {
  if (!($8)) {
   $9 = HEAP32[$1>>2]|0;
   $10 = HEAP32[$2>>2]|0;
   $11 = ($9|0)==($10|0);
   if ($11) {
    $$0$lcssa = 0;$12 = $9;$14 = $9;
   } else {
    $$022 = 0;$$sroa$014$021 = $9;
    while(1) {
     $21 = HEAP32[$$sroa$014$021>>2]|0;
     $22 = HEAP32[$21>>2]|0;
     $23 = ((($22)) + 156|0);
     $24 = HEAP32[$23>>2]|0;
     __THREW__ = 0;
     $25 = (invoke_ii($24|0,($21|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break L1;
     }
     $28 = $25&1;
     $$$0 = (($28) + ($$022))|0;
     $29 = ((($$sroa$014$021)) + 4|0);
     $30 = HEAP32[$2>>2]|0;
     $31 = ($29|0)==($30|0);
     if ($31) {
      break;
     } else {
      $$022 = $$$0;$$sroa$014$021 = $29;
     }
    }
    $$pre = HEAP32[$1>>2]|0;
    $phitmp = ($$$0|0)!=(0);
    $$0$lcssa = $phitmp;$12 = $$pre;$14 = $29;
   }
   $13 = ($12|0)==(0|0);
   if ($13) {
    STACKTOP = sp;return ($$0$lcssa|0);
   }
   $15 = ($14|0)==($12|0);
   if (!($15)) {
    $scevgep$i$i$i8 = ((($14)) + -4|0);
    $16 = $scevgep$i$i$i8;
    $17 = $12;
    $18 = (($16) - ($17))|0;
    $19 = $18 >>> 2;
    $20 = $19 ^ -1;
    $scevgep5$i$i$i9 = (($14) + ($20<<2)|0);
    HEAP32[$2>>2] = $scevgep5$i$i$i9;
   }
   __ZdlPv($12);
   STACKTOP = sp;return ($$0$lcssa|0);
  }
 } while(0);
 $32 = ___cxa_find_matching_catch_2()|0;
 $33 = tempRet0;
 $34 = HEAP32[$1>>2]|0;
 $35 = ($34|0)==(0|0);
 if ($35) {
  ___resumeException($32|0);
  // unreachable;
 }
 $36 = HEAP32[$2>>2]|0;
 $37 = ($36|0)==($34|0);
 if (!($37)) {
  $scevgep$i$i$i = ((($36)) + -4|0);
  $38 = $scevgep$i$i$i;
  $39 = $34;
  $40 = (($38) - ($39))|0;
  $41 = $40 >>> 2;
  $42 = $41 ^ -1;
  $scevgep5$i$i$i = (($36) + ($42<<2)|0);
  HEAP32[$2>>2] = $scevgep5$i$i$i;
 }
 __ZdlPv($34);
 ___resumeException($32|0);
 // unreachable;
 return (0)|0;
}
function __ZN9osgViewer6Viewer7realizeEv($0) {
 $0 = $0|0;
 var $$0 = 0, $$0$i = 0, $$016$i$i = 0, $$016$i$i90 = 0, $$017$i$i = 0, $$017$i$i91 = 0, $$04$i = 0, $$065 = 0, $$066 = 0, $$080 = 0, $$1 = 0, $$13 = 0, $$1379 = 0, $$167 = 0, $$2 = 0, $$268 = 0, $$3 = 0, $$369 = 0, $$pre = 0, $$pre144 = 0;
 var $$pre146 = 0, $$pre147 = 0, $$pre149 = 0, $$pre151 = 0, $$pre152 = 0, $$sroa$0127$0139 = 0, $$sroa$0134$0140 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0;
 var $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0;
 var $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0;
 var $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0;
 var $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0;
 var $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0;
 var $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0;
 var $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0;
 var $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0;
 var $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0;
 var $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0;
 var $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0;
 var $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0;
 var $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0;
 var $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0;
 var $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0;
 var $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$i$index11Z2D = 0, $eh$lpad$body$i$indexZ2D = 0, $eh$lpad$body$index5Z2D = 0, $eh$lpad$body$indexZ2D = 0, $or$cond = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i121 = 0, $scevgep5$i$i$i = 0;
 var $scevgep5$i$i$i122 = 0, $strlenfirst = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(224|0);
 $1 = sp + 208|0;
 $2 = sp + 204|0;
 $3 = sp + 192|0;
 $4 = sp + 180|0;
 $5 = sp + 176|0;
 $6 = sp + 172|0;
 $7 = sp + 168|0;
 $8 = sp + 164|0;
 $9 = sp + 24|0;
 $10 = sp + 12|0;
 $11 = sp;
 HEAP32[$3>>2] = 0;
 $12 = ((($3)) + 4|0);
 HEAP32[$12>>2] = 0;
 $13 = ((($3)) + 8|0);
 HEAP32[$13>>2] = 0;
 $14 = HEAP32[$0>>2]|0;
 $15 = ((($14)) + 88|0);
 $16 = HEAP32[$15>>2]|0;
 __THREW__ = 0;
 invoke_viii($16|0,($0|0),($3|0),1);
 $17 = __THREW__; __THREW__ = 0;
 $18 = $17&1;
 L1: do {
  if ($18) {
   label = 16;
  } else {
   $19 = HEAP32[$3>>2]|0;
   $20 = HEAP32[$12>>2]|0;
   $21 = ($19|0)==($20|0);
   do {
    if ($21) {
     __THREW__ = 0;
     $22 = (invoke_ii(3265,4)|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      label = 16;
      break L1;
     }
     do {
      if ($22) {
       __THREW__ = 0;
       $25 = (invoke_ii(3266,4)|0);
       $26 = __THREW__; __THREW__ = 0;
       $27 = $26&1;
       if ($27) {
        label = 16;
        break L1;
       }
       __THREW__ = 0;
       $28 = (invoke_iiii(3267,($25|0),(104349|0),80)|0);
       $29 = __THREW__; __THREW__ = 0;
       $30 = $29&1;
       if ($30) {
        label = 16;
        break L1;
       }
       $31 = HEAP32[$28>>2]|0;
       $32 = ((($31)) + -12|0);
       $33 = HEAP32[$32>>2]|0;
       $34 = (($28) + ($33)|0);
       __THREW__ = 0;
       invoke_vii(3257,($2|0),($34|0));
       $35 = __THREW__; __THREW__ = 0;
       $36 = $35&1;
       if ($36) {
        label = 16;
        break L1;
       }
       __THREW__ = 0;
       $37 = (invoke_iii(3255,($2|0),(215188|0))|0);
       $38 = __THREW__; __THREW__ = 0;
       $39 = $38&1;
       if (!($39)) {
        $40 = HEAP32[$37>>2]|0;
        $41 = ((($40)) + 28|0);
        $42 = HEAP32[$41>>2]|0;
        __THREW__ = 0;
        $43 = (invoke_iii($42|0,($37|0),10)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         __THREW__ = 0;
         invoke_vi(3263,($2|0));
         $52 = __THREW__; __THREW__ = 0;
         $53 = $52&1;
         if ($53) {
          label = 16;
          break L1;
         }
         __THREW__ = 0;
         (invoke_iii(3268,($28|0),($43|0))|0);
         $54 = __THREW__; __THREW__ = 0;
         $55 = $54&1;
         if ($55) {
          label = 16;
          break L1;
         }
         __THREW__ = 0;
         (invoke_ii(3269,($28|0))|0);
         $56 = __THREW__; __THREW__ = 0;
         $57 = $56&1;
         if ($57) {
          label = 16;
          break L1;
         } else {
          break;
         }
        }
       }
       $46 = ___cxa_find_matching_catch_2()|0;
       $47 = tempRet0;
       __THREW__ = 0;
       invoke_vi(3263,($2|0));
       $48 = __THREW__; __THREW__ = 0;
       $49 = $48&1;
       if ($49) {
        $50 = ___cxa_find_matching_catch_3(0|0)|0;
        $51 = tempRet0;
        ___clang_call_terminate($50);
        // unreachable;
       } else {
        $eh$lpad$body$index5Z2D = $47;$eh$lpad$body$indexZ2D = $46;
        label = 17;
        break L1;
       }
      }
     } while(0);
     $60 = (_getenv((104430|0))|0);
     $61 = ($60|0)==(0|0);
     L21: do {
      if ($61) {
       $97 = (_getenv((104446|0))|0);
       $98 = ($97|0)==(0|0);
       if ($98) {
        $$080 = -1;
       } else {
        $strlenfirst = HEAP8[$97>>0]|0;
        $99 = ($strlenfirst<<24>>24)==(0);
        if ($99) {
         $$080 = -1;
        } else {
         $100 = (_atoi($97)|0);
         $$080 = $100;
        }
       }
       HEAP32[$5>>2] = -1;
       HEAP32[$6>>2] = -1;
       HEAP32[$7>>2] = -1;
       HEAP32[$8>>2] = -1;
       $101 = (_getenv((104457|0))|0);
       $102 = ($101|0)==(0|0);
       L27: do {
        if ($102) {
         $103 = ($$080|0)>(-1);
         $104 = ((($0)) + 104|0);
         if ($103) {
          $196 = $104;
          label = 79;
         } else {
          $199 = $104;
          label = 80;
         }
        } else {
         ;HEAP32[$10>>2]=0|0;HEAP32[$10+4>>2]=0|0;HEAP32[$10+8>>2]=0|0;
         $105 = (_strlen($101)|0);
         $106 = ($105>>>0)>(4294967279);
         do {
          if ($106) {
           __THREW__ = 0;
           invoke_vi(3367,($10|0));
           $107 = __THREW__; __THREW__ = 0;
           label = 67;
          } else {
           $108 = ($105>>>0)<(11);
           if ($108) {
            $117 = $105&255;
            $118 = ((($10)) + 11|0);
            HEAP8[$118>>0] = $117;
            $119 = ($105|0)==(0);
            if ($119) {
             $$017$i$i91 = $10;
            } else {
             $$016$i$i90 = $10;
             label = 46;
            }
           } else {
            $109 = (($105) + 16)|0;
            $110 = $109 & -16;
            __THREW__ = 0;
            $111 = (invoke_ii(3276,($110|0))|0);
            $112 = __THREW__; __THREW__ = 0;
            $113 = $112&1;
            if ($113) {
             label = 67;
             break;
            }
            HEAP32[$10>>2] = $111;
            $114 = $110 | -2147483648;
            $115 = ((($10)) + 8|0);
            HEAP32[$115>>2] = $114;
            $116 = ((($10)) + 4|0);
            HEAP32[$116>>2] = $105;
            $$016$i$i90 = $111;
            label = 46;
           }
           if ((label|0) == 46) {
            _memcpy(($$016$i$i90|0),($101|0),($105|0))|0;
            $$017$i$i91 = $$016$i$i90;
           }
           $120 = (($$017$i$i91) + ($105)|0);
           HEAP8[$120>>0] = 0;
           $121 = ((($9)) + 60|0);
           $122 = ((($9)) + 8|0);
           HEAP32[$9>>2] = ((5316));
           HEAP32[$121>>2] = ((5336));
           $123 = ((($9)) + 4|0);
           HEAP32[$123>>2] = 0;
           $124 = ((($9)) + 60|0);
           __THREW__ = 0;
           invoke_vii(3368,($124|0),($122|0));
           $125 = __THREW__; __THREW__ = 0;
           $126 = $125&1;
           if ($126) {
            $145 = ___cxa_find_matching_catch_2()|0;
            $146 = tempRet0;
            $$0$i = $146;$$04$i = $145;
           } else {
            $127 = ((($9)) + 132|0);
            HEAP32[$127>>2] = 0;
            $128 = ((($9)) + 136|0);
            HEAP32[$128>>2] = -1;
            HEAP32[$9>>2] = (37096);
            HEAP32[$121>>2] = (37116);
            __THREW__ = 0;
            invoke_vi(3369,($122|0));
            $129 = __THREW__; __THREW__ = 0;
            $130 = $129&1;
            do {
             if ($130) {
              $147 = ___cxa_find_matching_catch_2()|0;
              $148 = tempRet0;
              $eh$lpad$body$i$index11Z2D = $148;$eh$lpad$body$i$indexZ2D = $147;
             } else {
              HEAP32[$122>>2] = (37132);
              $131 = ((($9)) + 40|0);
              $132 = ((($9)) + 56|0);
              ;HEAP32[$131>>2]=0|0;HEAP32[$131+4>>2]=0|0;HEAP32[$131+8>>2]=0|0;HEAP32[$131+12>>2]=0|0;
              HEAP32[$132>>2] = 8;
              __THREW__ = 0;
              invoke_vii(3370,($122|0),($10|0));
              $133 = __THREW__; __THREW__ = 0;
              $134 = $133&1;
              if ($134) {
               $135 = ___cxa_find_matching_catch_2()|0;
               $136 = tempRet0;
               $137 = ((($131)) + 11|0);
               $138 = HEAP8[$137>>0]|0;
               $139 = ($138<<24>>24)<(0);
               if ($139) {
                $140 = HEAP32[$131>>2]|0;
                __ZdlPv($140);
               }
               __THREW__ = 0;
               invoke_vi(2911,($122|0));
               $141 = __THREW__; __THREW__ = 0;
               $142 = $141&1;
               if (!($142)) {
                $eh$lpad$body$i$index11Z2D = $136;$eh$lpad$body$i$indexZ2D = $135;
                break;
               }
               $143 = ___cxa_find_matching_catch_3(0|0)|0;
               $144 = tempRet0;
               ___clang_call_terminate($143);
               // unreachable;
              }
              $155 = ((($10)) + 11|0);
              $156 = HEAP8[$155>>0]|0;
              $157 = ($156<<24>>24)<(0);
              if ($157) {
               $158 = HEAP32[$10>>2]|0;
               __ZdlPv($158);
              }
              __THREW__ = 0;
              $159 = (invoke_iii(3372,($9|0),($5|0))|0);
              $160 = __THREW__; __THREW__ = 0;
              $161 = $160&1;
              do {
               if ($161) {
                label = 71;
               } else {
                __THREW__ = 0;
                $162 = (invoke_iii(3372,($159|0),($6|0))|0);
                $163 = __THREW__; __THREW__ = 0;
                $164 = $163&1;
                if ($164) {
                 label = 71;
                 break;
                }
                __THREW__ = 0;
                $165 = (invoke_iii(3372,($162|0),($7|0))|0);
                $166 = __THREW__; __THREW__ = 0;
                $167 = $166&1;
                if ($167) {
                 label = 71;
                 break;
                }
                __THREW__ = 0;
                (invoke_iii(3372,($165|0),($8|0))|0);
                $168 = __THREW__; __THREW__ = 0;
                $169 = $168&1;
                if ($169) {
                 label = 71;
                 break;
                }
                __THREW__ = 0;
                invoke_vi(289,($9|0));
                $170 = __THREW__; __THREW__ = 0;
                $171 = $170&1;
                if ($171) {
                 $184 = ___cxa_find_matching_catch_2()|0;
                 $185 = tempRet0;
                 $$2 = $184;$$268 = $185;
                 break;
                }
                $$pre = HEAP32[$7>>2]|0;
                $$pre144 = HEAP32[$8>>2]|0;
                $186 = ($$pre|0)>(0);
                $187 = ($$pre144|0)>(0);
                $or$cond = $186 & $187;
                $188 = ($$080|0)>(-1);
                $189 = ((($0)) + 104|0);
                if (!($or$cond)) {
                 if ($188) {
                  $196 = $189;
                  label = 79;
                  break L27;
                 } else {
                  $199 = $189;
                  label = 80;
                  break L27;
                 }
                }
                $190 = HEAP32[$5>>2]|0;
                $191 = HEAP32[$6>>2]|0;
                if ($188) {
                 __THREW__ = 0;
                 invoke_viiiiii(3373,($189|0),($190|0),($191|0),($$pre|0),($$pre144|0),($$080|0));
                 $192 = __THREW__; __THREW__ = 0;
                 $193 = $192&1;
                 if ($193) {
                  label = 66;
                  break L27;
                 } else {
                  label = 81;
                  break L27;
                 }
                } else {
                 __THREW__ = 0;
                 invoke_viiiiii(3373,($189|0),($190|0),($191|0),($$pre|0),($$pre144|0),0);
                 $194 = __THREW__; __THREW__ = 0;
                 $195 = $194&1;
                 if ($195) {
                  label = 66;
                  break L27;
                 } else {
                  label = 81;
                  break L27;
                 }
                }
               }
              } while(0);
              do {
               if ((label|0) == 71) {
                $180 = ___cxa_find_matching_catch_2()|0;
                $181 = tempRet0;
                __THREW__ = 0;
                invoke_vi(289,($9|0));
                $182 = __THREW__; __THREW__ = 0;
                $183 = $182&1;
                if (!($183)) {
                 $$2 = $180;$$268 = $181;
                 break;
                }
                $442 = ___cxa_find_matching_catch_3(0|0)|0;
                $443 = tempRet0;
                ___clang_call_terminate($442);
                // unreachable;
               }
              } while(0);
              $$3 = $$2;$$369 = $$268;
              break L27;
             }
            } while(0);
            __THREW__ = 0;
            invoke_vii(3371,($9|0),((37192)|0));
            $149 = __THREW__; __THREW__ = 0;
            $150 = $149&1;
            if ($150) {
             $153 = ___cxa_find_matching_catch_3(0|0)|0;
             $154 = tempRet0;
             ___clang_call_terminate($153);
             // unreachable;
            } else {
             $$0$i = $eh$lpad$body$i$index11Z2D;$$04$i = $eh$lpad$body$i$indexZ2D;
            }
           }
           __THREW__ = 0;
           invoke_vi(2907,($121|0));
           $151 = __THREW__; __THREW__ = 0;
           $152 = $151&1;
           if ($152) {
            $153 = ___cxa_find_matching_catch_3(0|0)|0;
            $154 = tempRet0;
            ___clang_call_terminate($153);
            // unreachable;
           }
           $176 = ((($10)) + 11|0);
           $177 = HEAP8[$176>>0]|0;
           $178 = ($177<<24>>24)<(0);
           if ($178) {
            $179 = HEAP32[$10>>2]|0;
            __ZdlPv($179);
            $$1 = $$04$i;$$167 = $$0$i;
           } else {
            $$1 = $$04$i;$$167 = $$0$i;
           }
          }
         } while(0);
         if ((label|0) == 67) {
          $174 = ___cxa_find_matching_catch_2()|0;
          $175 = tempRet0;
          $$1 = $174;$$167 = $175;
         }
         $$3 = $$1;$$369 = $$167;
        }
       } while(0);
       if ((label|0) == 79) {
        __THREW__ = 0;
        invoke_vii(3374,($196|0),($$080|0));
        $197 = __THREW__; __THREW__ = 0;
        $198 = $197&1;
        if ($198) {
         label = 66;
        } else {
         label = 81;
        }
       }
       else if ((label|0) == 80) {
        __THREW__ = 0;
        invoke_vi(3375,($199|0));
        $200 = __THREW__; __THREW__ = 0;
        $201 = $200&1;
        if ($201) {
         label = 66;
        } else {
         label = 81;
        }
       }
       if ((label|0) == 66) {
        $172 = ___cxa_find_matching_catch_2()|0;
        $173 = tempRet0;
        $$3 = $172;$$369 = $173;
       }
       else if ((label|0) == 81) {
        break;
       }
       $$13 = $$3;$$1379 = $$369;
       break L1;
      } else {
       $62 = HEAP32[$0>>2]|0;
       $63 = ((($62)) + 12|0);
       $64 = HEAP32[$63>>2]|0;
       ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;
       $65 = (_strlen($60)|0);
       $66 = ($65>>>0)>(4294967279);
       do {
        if ($66) {
         __THREW__ = 0;
         invoke_vi(3367,($4|0));
         $67 = __THREW__; __THREW__ = 0;
         label = 31;
        } else {
         $68 = ($65>>>0)<(11);
         if ($68) {
          $77 = $65&255;
          $78 = ((($4)) + 11|0);
          HEAP8[$78>>0] = $77;
          $79 = ($65|0)==(0);
          if ($79) {
           $$017$i$i = $4;
          } else {
           $$016$i$i = $4;
           label = 25;
          }
         } else {
          $69 = (($65) + 16)|0;
          $70 = $69 & -16;
          __THREW__ = 0;
          $71 = (invoke_ii(3276,($70|0))|0);
          $72 = __THREW__; __THREW__ = 0;
          $73 = $72&1;
          if ($73) {
           label = 31;
           break;
          }
          HEAP32[$4>>2] = $71;
          $74 = $70 | -2147483648;
          $75 = ((($4)) + 8|0);
          HEAP32[$75>>2] = $74;
          $76 = ((($4)) + 4|0);
          HEAP32[$76>>2] = $65;
          $$016$i$i = $71;
          label = 25;
         }
         if ((label|0) == 25) {
          _memcpy(($$016$i$i|0),($60|0),($65|0))|0;
          $$017$i$i = $$016$i$i;
         }
         $80 = (($$017$i$i) + ($65)|0);
         HEAP8[$80>>0] = 0;
         __THREW__ = 0;
         (invoke_iii($64|0,($0|0),($4|0))|0);
         $81 = __THREW__; __THREW__ = 0;
         $82 = $81&1;
         if ($82) {
          $91 = ___cxa_find_matching_catch_2()|0;
          $92 = tempRet0;
          $93 = ((($4)) + 11|0);
          $94 = HEAP8[$93>>0]|0;
          $95 = ($94<<24>>24)<(0);
          if (!($95)) {
           $$0 = $91;$$066 = $92;
           break;
          }
          $96 = HEAP32[$4>>2]|0;
          __ZdlPv($96);
          $$0 = $91;$$066 = $92;
          break;
         }
         $83 = ((($4)) + 11|0);
         $84 = HEAP8[$83>>0]|0;
         $85 = ($84<<24>>24)<(0);
         if ($85) {
          $86 = HEAP32[$4>>2]|0;
          __ZdlPv($86);
         }
         break L21;
        }
       } while(0);
       if ((label|0) == 31) {
        $89 = ___cxa_find_matching_catch_2()|0;
        $90 = tempRet0;
        $$0 = $89;$$066 = $90;
       }
       $$13 = $$0;$$1379 = $$066;
       break L1;
      }
     } while(0);
     $202 = HEAP32[$0>>2]|0;
     $203 = ((($202)) + 88|0);
     $204 = HEAP32[$203>>2]|0;
     __THREW__ = 0;
     invoke_viii($204|0,($0|0),($3|0),1);
     $205 = __THREW__; __THREW__ = 0;
     $206 = $205&1;
     if ($206) {
      $87 = ___cxa_find_matching_catch_2()|0;
      $88 = tempRet0;
      $$13 = $87;$$1379 = $88;
      break L1;
     } else {
      $$pre146 = HEAP32[$3>>2]|0;
      $$pre147 = HEAP32[$12>>2]|0;
      $207 = $$pre146;$209 = $$pre147;
      break;
     }
    } else {
     $207 = $19;$209 = $20;
    }
   } while(0);
   $208 = ($207|0)==($209|0);
   L117: do {
    if ($208) {
     __THREW__ = 0;
     $210 = (invoke_ii(3265,3)|0);
     $211 = __THREW__; __THREW__ = 0;
     $212 = $211&1;
     if ($212) {
      label = 16;
      break L1;
     }
     do {
      if ($210) {
       __THREW__ = 0;
       $213 = (invoke_ii(3266,3)|0);
       $214 = __THREW__; __THREW__ = 0;
       $215 = $214&1;
       if ($215) {
        label = 16;
        break L1;
       }
       __THREW__ = 0;
       $216 = (invoke_iiii(3267,($213|0),(104468|0),48)|0);
       $217 = __THREW__; __THREW__ = 0;
       $218 = $217&1;
       if ($218) {
        label = 16;
        break L1;
       }
       $219 = HEAP32[$216>>2]|0;
       $220 = ((($219)) + -12|0);
       $221 = HEAP32[$220>>2]|0;
       $222 = (($216) + ($221)|0);
       __THREW__ = 0;
       invoke_vii(3257,($1|0),($222|0));
       $223 = __THREW__; __THREW__ = 0;
       $224 = $223&1;
       if ($224) {
        label = 16;
        break L1;
       }
       __THREW__ = 0;
       $225 = (invoke_iii(3255,($1|0),(215188|0))|0);
       $226 = __THREW__; __THREW__ = 0;
       $227 = $226&1;
       if (!($227)) {
        $228 = HEAP32[$225>>2]|0;
        $229 = ((($228)) + 28|0);
        $230 = HEAP32[$229>>2]|0;
        __THREW__ = 0;
        $231 = (invoke_iii($230|0,($225|0),10)|0);
        $232 = __THREW__; __THREW__ = 0;
        $233 = $232&1;
        if (!($233)) {
         __THREW__ = 0;
         invoke_vi(3263,($1|0));
         $240 = __THREW__; __THREW__ = 0;
         $241 = $240&1;
         if ($241) {
          label = 16;
          break L1;
         }
         __THREW__ = 0;
         (invoke_iii(3268,($216|0),($231|0))|0);
         $242 = __THREW__; __THREW__ = 0;
         $243 = $242&1;
         if ($243) {
          label = 16;
          break L1;
         }
         __THREW__ = 0;
         (invoke_ii(3269,($216|0))|0);
         $244 = __THREW__; __THREW__ = 0;
         $245 = $244&1;
         if ($245) {
          label = 16;
          break L1;
         } else {
          break;
         }
        }
       }
       $234 = ___cxa_find_matching_catch_2()|0;
       $235 = tempRet0;
       __THREW__ = 0;
       invoke_vi(3263,($1|0));
       $236 = __THREW__; __THREW__ = 0;
       $237 = $236&1;
       if ($237) {
        $238 = ___cxa_find_matching_catch_3(0|0)|0;
        $239 = tempRet0;
        ___clang_call_terminate($238);
        // unreachable;
       } else {
        $eh$lpad$body$index5Z2D = $235;$eh$lpad$body$indexZ2D = $234;
        label = 17;
        break L1;
       }
      }
     } while(0);
     $246 = ((($0)) + 5|0);
     HEAP8[$246>>0] = 1;
    } else {
     $247 = ((($0)) + 220|0);
     $248 = HEAP32[$247>>2]|0;
     $249 = ($248|0)==(0|0);
     if ($249) {
      __THREW__ = 0;
      $250 = (invoke_i(3285)|0);
      $251 = __THREW__; __THREW__ = 0;
      $252 = $251&1;
      if ($252) {
       label = 16;
       break L1;
      }
      $$pre149 = HEAP32[$250>>2]|0;
      $271 = $$pre149;
     } else {
      $271 = $248;
     }
     $253 = ((($11)) + 11|0);
     ;HEAP32[$11>>2]=0|0;HEAP32[$11+4>>2]=0|0;HEAP32[$11+8>>2]=0|0;
     __THREW__ = 0;
     $254 = (invoke_ii(3376,($11|0))|0);
     $255 = __THREW__; __THREW__ = 0;
     $256 = $255&1;
     if ($256) {
      $274 = ___cxa_find_matching_catch_2()|0;
      $275 = tempRet0;
      $276 = HEAP8[$253>>0]|0;
      $277 = ($276<<24>>24)<(0);
      if ($277) {
       $278 = HEAP32[$11>>2]|0;
       __ZdlPv($278);
      }
      $$13 = $274;$$1379 = $275;
      break L1;
     }
     $257 = HEAP8[$253>>0]|0;
     $258 = ($257<<24>>24)<(0);
     if ($258) {
      $259 = HEAP32[$11>>2]|0;
      __ZdlPv($259);
     }
     $260 = ($254|0)==(0|0);
     do {
      if (!($260)) {
       $261 = HEAP32[$254>>2]|0;
       $262 = ((($261)) + 32|0);
       $263 = HEAP32[$262>>2]|0;
       __THREW__ = 0;
       $264 = (invoke_ii($263|0,($254|0))|0);
       $265 = __THREW__; __THREW__ = 0;
       $266 = $265&1;
       if (!($266)) {
        $267 = ($264|0)==(0|0);
        if (!($267)) {
         break;
        }
        $268 = HEAP32[$254>>2]|0;
        $269 = ((($268)) + 28|0);
        $270 = HEAP32[$269>>2]|0;
        __THREW__ = 0;
        invoke_vii($270|0,($254|0),($271|0));
        $272 = __THREW__; __THREW__ = 0;
        $273 = $272&1;
        if (!($273)) {
         break;
        }
       }
       $279 = ___cxa_find_matching_catch_2()|0;
       $280 = tempRet0;
       $$13 = $279;$$1379 = $280;
       break L1;
      }
     } while(0);
     $281 = ((($271)) + 116|0);
     $282 = HEAP32[$281>>2]|0;
     $283 = ((($271)) + 120|0);
     $284 = HEAP32[$283>>2]|0;
     $285 = HEAP32[$3>>2]|0;
     $286 = HEAP32[$12>>2]|0;
     $287 = ($285|0)==($286|0);
     L156: do {
      if ($287) {
       $444 = $285;
      } else {
       $288 = ((($271)) + 156|0);
       $289 = ((($0)) + 80|0);
       $$sroa$0134$0140 = $285;
       while(1) {
        $293 = HEAP32[$$sroa$0134$0140>>2]|0;
        $294 = HEAP32[$288>>2]|0;
        $295 = ($294|0)==(0);
        if (!($295)) {
         __THREW__ = 0;
         $296 = (invoke_ii(3276,16)|0);
         $297 = __THREW__; __THREW__ = 0;
         $298 = $297&1;
         if ($298) {
          label = 124;
          break;
         }
         __THREW__ = 0;
         invoke_vi(3377,($296|0));
         $299 = __THREW__; __THREW__ = 0;
         $300 = $299&1;
         if ($300) {
          label = 125;
          break;
         }
         $301 = ((($293)) + 116|0);
         $302 = HEAP32[$301>>2]|0;
         $303 = ($302|0)==($296|0);
         if (!($303)) {
          HEAP32[$301>>2] = $296;
          $304 = ((($296)) + 8|0);
          $305 = HEAP32[$304>>2]|0;HEAP32[$304>>2] = (($305+1)|0);
          $306 = ($302|0)==(0|0);
          if (!($306)) {
           $307 = ((($302)) + 8|0);
           $308 = HEAP32[$307>>2]|0;HEAP32[$307>>2] = (($308-1)|0);
           $309 = ($308|0)==(1);
           if ($309) {
            __THREW__ = 0;
            invoke_viii(3262,($302|0),1,1);
            $310 = __THREW__; __THREW__ = 0;
            $311 = $310&1;
            if ($311) {
             label = 124;
             break;
            }
           }
          }
         }
        }
        $316 = ((($293)) + 48|0);
        $317 = HEAP32[$316>>2]|0;
        __THREW__ = 0;
        invoke_vii(3378,($317|0),($282|0));
        $318 = __THREW__; __THREW__ = 0;
        $319 = $318&1;
        if ($319) {
         label = 124;
         break;
        }
        $320 = HEAP32[$316>>2]|0;
        __THREW__ = 0;
        invoke_vii(3379,($320|0),($284|0));
        $321 = __THREW__; __THREW__ = 0;
        $322 = $321&1;
        if ($322) {
         label = 124;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(3380,($293|0))|0);
        $323 = __THREW__; __THREW__ = 0;
        $324 = $323&1;
        if ($324) {
         label = 124;
         break;
        }
        $325 = HEAP32[$289>>2]|0;
        $326 = ($325|0)==(0|0);
        if (!($326)) {
         $327 = HEAP32[$293>>2]|0;
         $328 = ((($327)) + 144|0);
         $329 = HEAP32[$328>>2]|0;
         __THREW__ = 0;
         $330 = (invoke_ii($329|0,($293|0))|0);
         $331 = __THREW__; __THREW__ = 0;
         $332 = $331&1;
         if ($332) {
          label = 124;
          break;
         }
         if ($330) {
          __THREW__ = 0;
          (invoke_ii(3381,($293|0))|0);
          $333 = __THREW__; __THREW__ = 0;
          $334 = $333&1;
          if ($334) {
           label = 124;
           break;
          }
          $335 = HEAP32[$289>>2]|0;
          $336 = HEAP32[$335>>2]|0;
          $337 = ((($336)) + 4|0);
          $338 = HEAP32[$337>>2]|0;
          __THREW__ = 0;
          invoke_vii($338|0,($335|0),($293|0));
          $339 = __THREW__; __THREW__ = 0;
          $340 = $339&1;
          if ($340) {
           label = 124;
           break;
          }
          __THREW__ = 0;
          (invoke_ii(3382,($293|0))|0);
          $341 = __THREW__; __THREW__ = 0;
          $342 = $341&1;
          if ($342) {
           label = 124;
           break;
          }
         }
        }
        $343 = ((($$sroa$0134$0140)) + 4|0);
        $344 = HEAP32[$12>>2]|0;
        $345 = ($343|0)==($344|0);
        if ($345) {
         $444 = $343;
         break L156;
        } else {
         $$sroa$0134$0140 = $343;
        }
       }
       if ((label|0) == 124) {
        $312 = ___cxa_find_matching_catch_2()|0;
        $313 = tempRet0;
        $$13 = $312;$$1379 = $313;
        break L1;
       }
       else if ((label|0) == 125) {
        $314 = ___cxa_find_matching_catch_2()|0;
        $315 = tempRet0;
        __ZdlPv($296);
        $$13 = $314;$$1379 = $315;
        break L1;
       }
      }
     } while(0);
     $290 = ((($0)) + 88|0);
     $291 = HEAP32[$290>>2]|0;
     $292 = ($291|0)==(0|0);
     do {
      if ($292) {
       $352 = $444;
      } else {
       __THREW__ = 0;
       invoke_vii(3383,($291|0),($3|0));
       $346 = __THREW__; __THREW__ = 0;
       $347 = $346&1;
       if ($347) {
        $348 = ___cxa_find_matching_catch_2()|0;
        $349 = tempRet0;
        $$13 = $348;$$1379 = $349;
        break L1;
       } else {
        $$pre151 = HEAP32[$12>>2]|0;
        $352 = $$pre151;
        break;
       }
      }
     } while(0);
     $350 = HEAP32[$3>>2]|0;
     $351 = ($350|0)==($352|0);
     L188: do {
      if (!($351)) {
       $$sroa$0127$0139 = $350;$445 = $352;
       while(1) {
        $356 = HEAP32[$$sroa$0127$0139>>2]|0;
        $357 = ($356|0)==(0|0);
        if ($357) {
         $369 = $445;
        } else {
         $358 = (___dynamic_cast($356,24816,3888,0)|0);
         $359 = ($358|0)==(0|0);
         if ($359) {
          $369 = $445;
         } else {
          $360 = HEAP32[$358>>2]|0;
          $361 = ((($360)) + 212|0);
          $362 = HEAP32[$361>>2]|0;
          __THREW__ = 0;
          invoke_vi($362|0,($358|0));
          $363 = __THREW__; __THREW__ = 0;
          $364 = $363&1;
          if ($364) {
           break;
          }
          $$pre152 = HEAP32[$12>>2]|0;
          $369 = $$pre152;
         }
        }
        $367 = ((($$sroa$0127$0139)) + 4|0);
        $368 = ($367|0)==($369|0);
        if ($368) {
         break L188;
        } else {
         $$sroa$0127$0139 = $367;$445 = $369;
        }
       }
       $365 = ___cxa_find_matching_catch_2()|0;
       $366 = tempRet0;
       $$13 = $365;$$1379 = $366;
       break L1;
      }
     } while(0);
     __THREW__ = 0;
     $353 = (invoke_i(3384)|0);
     $354 = __THREW__; __THREW__ = 0;
     $355 = $354&1;
     if (!($355)) {
      __THREW__ = 0;
      $370 = (invoke_ii(3385,($353|0))|0);
      $371 = tempRet0;
      $372 = __THREW__; __THREW__ = 0;
      $373 = $372&1;
      if (!($373)) {
       $374 = $353;
       $375 = $374;
       HEAP32[$375>>2] = $370;
       $376 = (($374) + 4)|0;
       $377 = $376;
       HEAP32[$377>>2] = $371;
       $378 = HEAP32[$0>>2]|0;
       $379 = ((($378)) + 160|0);
       $380 = HEAP32[$379>>2]|0;
       __THREW__ = 0;
       $381 = (invoke_i(3384)|0);
       $382 = __THREW__; __THREW__ = 0;
       $383 = $382&1;
       if (!($383)) {
        $384 = $381;
        $385 = $384;
        $386 = HEAP32[$385>>2]|0;
        $387 = (($384) + 4)|0;
        $388 = $387;
        $389 = HEAP32[$388>>2]|0;
        __THREW__ = 0;
        invoke_viii($380|0,($0|0),($386|0),($389|0));
        $390 = __THREW__; __THREW__ = 0;
        $391 = $390&1;
        if (!($391)) {
         $392 = HEAP32[$0>>2]|0;
         $393 = ((($392)) + 40|0);
         $394 = HEAP32[$393>>2]|0;
         __THREW__ = 0;
         invoke_vi($394|0,($0|0));
         $395 = __THREW__; __THREW__ = 0;
         $396 = $395&1;
         if (!($396)) {
          __THREW__ = 0;
          $397 = (invoke_i(3285)|0);
          $398 = __THREW__; __THREW__ = 0;
          $399 = $398&1;
          if (!($399)) {
           $400 = HEAP32[$397>>2]|0;
           $401 = ((($400)) + 92|0);
           $402 = HEAP8[$401>>0]|0;
           $403 = ($402<<24>>24)==(0);
           if ($403) {
            break;
           } else {
            $$065 = 0;
           }
           while(1) {
            __THREW__ = 0;
            $404 = (invoke_i(3386)|0);
            $405 = __THREW__; __THREW__ = 0;
            $406 = $405&1;
            if ($406) {
             break;
            }
            $407 = ($$065>>>0)>($404>>>0);
            if ($407) {
             break L117;
            }
            __THREW__ = 0;
            $410 = (invoke_ii(3387,($$065|0))|0);
            $411 = __THREW__; __THREW__ = 0;
            $412 = $411&1;
            if ($412) {
             break;
            }
            $413 = ($410|0)==(0|0);
            if (!($413)) {
             __THREW__ = 0;
             invoke_vi(3388,($410|0));
             $414 = __THREW__; __THREW__ = 0;
             $415 = $414&1;
             if ($415) {
              break;
             }
             $416 = ((($410)) + 108|0);
             $417 = HEAP32[$416>>2]|0;
             $418 = ((($417)) + 12|0);
             __THREW__ = 0;
             (invoke_ii(3389,($418|0))|0);
             $419 = __THREW__; __THREW__ = 0;
             $420 = $419&1;
             if ($420) {
              break;
             }
            }
            $421 = (($$065) + 1)|0;
            $$065 = $421;
           }
           $422 = ___cxa_find_matching_catch_2()|0;
           $423 = tempRet0;
           $$13 = $422;$$1379 = $423;
           break L1;
          }
         }
        }
       }
      }
     }
     $408 = ___cxa_find_matching_catch_2()|0;
     $409 = tempRet0;
     $$13 = $408;$$1379 = $409;
     break L1;
    }
   } while(0);
   $424 = HEAP32[$3>>2]|0;
   $425 = ($424|0)==(0|0);
   if ($425) {
    STACKTOP = sp;return;
   }
   $426 = HEAP32[$12>>2]|0;
   $427 = ($426|0)==($424|0);
   if (!($427)) {
    $scevgep$i$i$i121 = ((($426)) + -4|0);
    $428 = $scevgep$i$i$i121;
    $429 = $424;
    $430 = (($428) - ($429))|0;
    $431 = $430 >>> 2;
    $432 = $431 ^ -1;
    $scevgep5$i$i$i122 = (($426) + ($432<<2)|0);
    HEAP32[$12>>2] = $scevgep5$i$i$i122;
   }
   __ZdlPv($424);
   STACKTOP = sp;return;
  }
 } while(0);
 if ((label|0) == 16) {
  $58 = ___cxa_find_matching_catch_2()|0;
  $59 = tempRet0;
  $eh$lpad$body$index5Z2D = $59;$eh$lpad$body$indexZ2D = $58;
  label = 17;
 }
 if ((label|0) == 17) {
  $$13 = $eh$lpad$body$indexZ2D;$$1379 = $eh$lpad$body$index5Z2D;
 }
 $433 = HEAP32[$3>>2]|0;
 $434 = ($433|0)==(0|0);
 if ($434) {
  ___resumeException($$13|0);
  // unreachable;
 }
 $435 = HEAP32[$12>>2]|0;
 $436 = ($435|0)==($433|0);
 if (!($436)) {
  $scevgep$i$i$i = ((($435)) + -4|0);
  $437 = $scevgep$i$i$i;
  $438 = $433;
  $439 = (($437) - ($438))|0;
  $440 = $439 >>> 2;
  $441 = $440 ^ -1;
  $scevgep5$i$i$i = (($435) + ($441<<2)|0);
  HEAP32[$12>>2] = $scevgep5$i$i$i;
 }
 __ZdlPv($433);
 ___resumeException($$13|0);
 // unreachable;
}
function __ZN9osgViewer10ViewerBase20setProcessorAffinityERKN11OpenThreads8AffinityE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy1 = sp + 12|0;
 $$byval_copy = sp + 8|0;
 $2 = sp + 4|0;
 $3 = sp;
 $4 = ((($0)) + 16|0);
 $5 = ($4|0)==($1|0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $6 = HEAP32[$1>>2]|0;
 HEAP32[$2>>2] = $6;
 $7 = ((($1)) + 4|0);
 HEAP32[$3>>2] = $7;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$2>>2]|0;
 ;HEAP32[$$byval_copy1>>2]=HEAP32[$3>>2]|0;
 __ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEE14__assign_multiINS_21__tree_const_iteratorIjPNS_11__tree_nodeIjPvEEiEEEEvT_SD_($4,$$byval_copy,$$byval_copy1);
 STACKTOP = sp;return;
}
function __ZN9osgViewer6Viewer3runEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 104|0);
 $2 = ((($0)) + 180|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 do {
  if ($4) {
   $5 = ((($0)) + 120|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ((($6)) + 228|0);
   $8 = HEAP8[$7>>0]|0;
   $9 = ($8<<24>>24)==(0);
   if (!($9)) {
    $10 = (__Znwj(288)|0);
    __THREW__ = 0;
    invoke_vii(3390,($10|0),5);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     $13 = ___cxa_find_matching_catch_2()|0;
     $14 = tempRet0;
     __ZdlPv($10);
     ___resumeException($13|0);
     // unreachable;
    } else {
     __ZN9osgViewer4View20setCameraManipulatorEPN5osgGA17CameraManipulatorEb($1,$10,1);
     break;
    }
   }
  }
 } while(0);
 $15 = ((($0)) + 13|0);
 HEAP8[$15>>0] = 0;
 $16 = (__ZN9osgViewer10ViewerBase3runEv($0)|0);
 return ($16|0);
}
function __ZN9osgViewer6Viewer18checkNeedToDoFrameEv($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $not$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 33|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if (!($3)) {
  $$0 = 1;
  return ($$0|0);
 }
 $4 = ((($0)) + 34|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)==(0);
 if (!($6)) {
  $$0 = 1;
  return ($$0|0);
 }
 $7 = ((($0)) + 104|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($8)) + 68|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (FUNCTION_TABLE_ii[$10 & 8191]($7)|0);
 if ($11) {
  $$0 = 1;
  return ($$0|0);
 }
 $12 = HEAP32[$7>>2]|0;
 $13 = ((($12)) + 72|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (FUNCTION_TABLE_ii[$14 & 8191]($7)|0);
 if ($15) {
  $$0 = 1;
  return ($$0|0);
 }
 $16 = HEAP32[$0>>2]|0;
 $17 = ((($16)) + 60|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (FUNCTION_TABLE_ii[$18 & 8191]($0)|0);
 if ($19) {
  $$0 = 1;
  return ($$0|0);
 }
 $20 = HEAP8[$1>>0]|0;
 $21 = ($20<<24>>24)==(0);
 if (!($21)) {
  $$0 = 1;
  return ($$0|0);
 }
 $22 = HEAP8[$4>>0]|0;
 $not$ = ($22<<24>>24)!=(0);
 $$0 = $not$;
 return ($$0|0);
}
function __ZN9osgViewer6Viewer11checkEventsEv($0) {
 $0 = $0|0;
 var $$5 = 0, $$ph = 0, $$pre = 0, $$pre43 = 0, $$sroa$021$035 = 0, $$sroa$028$038 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i15 = 0, $scevgep5$i$i$i = 0, $scevgep5$i$i$i16 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $2 = ((($0)) + 160|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 164|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 L1: do {
  if (!($6)) {
   $$sroa$028$038 = $3;$59 = $5;
   while(1) {
    $7 = HEAP32[$$sroa$028$038>>2]|0;
    $8 = ((($7)) + 36|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = $9 & 1;
    $11 = ($10|0)==(0);
    if ($11) {
     $18 = $59;
    } else {
     $12 = HEAP32[$7>>2]|0;
     $13 = ((($12)) + 140|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = (FUNCTION_TABLE_ii[$14 & 8191]($7)|0);
     if ($15) {
      $$5 = 1;
      break;
     }
     $$pre = HEAP32[$4>>2]|0;
     $18 = $$pre;
    }
    $16 = ((($$sroa$028$038)) + 4|0);
    $17 = ($16|0)==($18|0);
    if ($17) {
     break L1;
    } else {
     $$sroa$028$038 = $16;$59 = $18;
    }
   }
   STACKTOP = sp;return ($$5|0);
  }
 } while(0);
 HEAP32[$1>>2] = 0;
 $19 = ((($1)) + 4|0);
 HEAP32[$19>>2] = 0;
 $20 = ((($1)) + 8|0);
 HEAP32[$20>>2] = 0;
 $21 = HEAP32[$0>>2]|0;
 $22 = ((($21)) + 92|0);
 $23 = HEAP32[$22>>2]|0;
 __THREW__ = 0;
 invoke_viii($23|0,($0|0),($1|0),1);
 $24 = __THREW__; __THREW__ = 0;
 $25 = $24&1;
 L10: do {
  if (!($25)) {
   $26 = HEAP32[$1>>2]|0;
   $27 = HEAP32[$19>>2]|0;
   $28 = ($26|0)==($27|0);
   if ($28) {
    $39 = $26;$60 = 0;
   } else {
    $$sroa$021$035 = $26;
    while(1) {
     $32 = HEAP32[$$sroa$021$035>>2]|0;
     $33 = HEAP32[$32>>2]|0;
     $34 = ((($33)) + 188|0);
     $35 = HEAP32[$34>>2]|0;
     __THREW__ = 0;
     $36 = (invoke_ii($35|0,($32|0))|0);
     $37 = __THREW__; __THREW__ = 0;
     $38 = $37&1;
     if ($38) {
      break L10;
     }
     $30 = ((($$sroa$021$035)) + 4|0);
     if ($36) {
      $$ph = 1;
      break;
     }
     $29 = HEAP32[$19>>2]|0;
     $31 = ($30|0)==($29|0);
     if ($31) {
      $$ph = 0;
      break;
     } else {
      $$sroa$021$035 = $30;
     }
    }
    $$pre43 = HEAP32[$1>>2]|0;
    $39 = $$pre43;$60 = $$ph;
   }
   $40 = ($39|0)==(0|0);
   if (!($40)) {
    $41 = HEAP32[$19>>2]|0;
    $42 = ($41|0)==($39|0);
    if (!($42)) {
     $scevgep$i$i$i15 = ((($41)) + -4|0);
     $43 = $scevgep$i$i$i15;
     $44 = $39;
     $45 = (($43) - ($44))|0;
     $46 = $45 >>> 2;
     $47 = $46 ^ -1;
     $scevgep5$i$i$i16 = (($41) + ($47<<2)|0);
     HEAP32[$19>>2] = $scevgep5$i$i$i16;
    }
    __ZdlPv($39);
   }
   $$5 = $60;
   STACKTOP = sp;return ($$5|0);
  }
 } while(0);
 $48 = ___cxa_find_matching_catch_2()|0;
 $49 = tempRet0;
 $50 = HEAP32[$1>>2]|0;
 $51 = ($50|0)==(0|0);
 if ($51) {
  ___resumeException($48|0);
  // unreachable;
 }
 $52 = HEAP32[$19>>2]|0;
 $53 = ($52|0)==($50|0);
 if (!($53)) {
  $scevgep$i$i$i = ((($52)) + -4|0);
  $54 = $scevgep$i$i$i;
  $55 = $50;
  $56 = (($54) - ($55))|0;
  $57 = $56 >>> 2;
  $58 = $57 ^ -1;
  $scevgep5$i$i$i = (($52) + ($58<<2)|0);
  HEAP32[$19>>2] = $scevgep5$i$i$i;
 }
 __ZdlPv($50);
 ___resumeException($48|0);
 // unreachable;
 return (0)|0;
}
function __ZN9osgViewer6Viewer7advanceEd($0,$1) {
 $0 = $0|0;
 $1 = +$1;
 var $$1 = 0, $$123 = 0, $$sink = 0.0, $$sink$i = 0.0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0.0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0.0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0.0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0.0, $35 = 0, $36 = 0, $37 = 0.0, $38 = 0.0, $39 = 0, $4 = 0, $40 = 0.0, $41 = 0.0, $42 = 0, $43 = 0, $44 = 0, $45 = 0.0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0.0, $93 = 0.0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, dest = 0, label = 0, sp = 0;
 var src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $2 = sp + 36|0;
 $3 = sp + 24|0;
 $4 = sp + 12|0;
 $5 = sp;
 $6 = ((($0)) + 5|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = ($7<<24>>24)==(0);
 if (!($8)) {
  STACKTOP = sp;return;
 }
 $9 = ((($0)) + 136|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ((($10)) + 16|0);
 $12 = +HEAPF64[$11>>3];
 $13 = ((($10)) + 12|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($14) + 1)|0;
 HEAP32[$13>>2] = $15;
 $16 = (__ZN3osg5Timer8instanceEv()|0);
 $17 = ((($0)) + 152|0);
 $18 = $17;
 $19 = $18;
 $20 = HEAP32[$19>>2]|0;
 $21 = (($18) + 4)|0;
 $22 = $21;
 $23 = HEAP32[$22>>2]|0;
 $24 = (__ZN3osg5Timer8instanceEv()|0);
 $25 = (__ZNK3osg5Timer4tickEv($24)|0);
 $26 = tempRet0;
 $27 = ($26>>>0)>($23>>>0);
 $28 = ($25>>>0)>($20>>>0);
 $29 = ($26|0)==($23|0);
 $30 = $29 & $28;
 $31 = $27 | $30;
 if ($31) {
  $32 = (_i64Subtract(($25|0),($26|0),($20|0),($23|0))|0);
  $33 = tempRet0;
  $34 = (+($32>>>0)) + (4294967296.0*(+($33>>>0)));
  $$sink$i = $34;
 } else {
  $35 = (_i64Subtract(($20|0),($23|0),($25|0),($26|0))|0);
  $36 = tempRet0;
  $37 = (+($35>>>0)) + (4294967296.0*(+($36>>>0)));
  $38 = -$37;
  $$sink$i = $38;
 }
 $39 = ((($16)) + 8|0);
 $40 = +HEAPF64[$39>>3];
 $41 = $$sink$i * $40;
 HEAPF64[$11>>3] = $41;
 $42 = $1 == 1.7976931348623157E+308;
 $43 = HEAP32[$9>>2]|0;
 if ($42) {
  $44 = ((($43)) + 16|0);
  $45 = +HEAPF64[$44>>3];
  $$sink = $45;
 } else {
  $$sink = $1;
 }
 $46 = ((($43)) + 24|0);
 HEAPF64[$46>>3] = $$sink;
 $47 = HEAP32[$0>>2]|0;
 $48 = ((($47)) + 4|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = (FUNCTION_TABLE_ii[$49 & 8191]($0)|0);
 $51 = ($50|0)==(0|0);
 L11: do {
  if (!($51)) {
   $52 = HEAP32[$0>>2]|0;
   $53 = ((($52)) + 4|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = (FUNCTION_TABLE_ii[$54 & 8191]($0)|0);
   $56 = ((($2)) + 11|0);
   HEAP8[$56>>0] = 10;
   dest=$2; src=104297; stop=dest+10|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
   $57 = ((($2)) + 10|0);
   HEAP8[$57>>0] = 0;
   $58 = ((($55)) + 24|0);
   $59 = HEAP32[$58>>2]|0;
   $60 = ((($59)) + 8|0);
   $61 = HEAP32[$60>>2]|0;
   __THREW__ = 0;
   (invoke_ii($61|0,($58|0))|0);
   $62 = __THREW__; __THREW__ = 0;
   $63 = $62&1;
   do {
    if ($63) {
     label = 28;
    } else {
     $64 = ((($55)) + 68|0);
     __THREW__ = 0;
     $65 = (invoke_iii(3391,($64|0),($2|0))|0);
     $66 = __THREW__; __THREW__ = 0;
     $67 = $66&1;
     if ($67) {
      $78 = ___cxa_find_matching_catch_2()|0;
      $79 = tempRet0;
      $80 = HEAP32[$58>>2]|0;
      $81 = ((($80)) + 12|0);
      $82 = HEAP32[$81>>2]|0;
      __THREW__ = 0;
      (invoke_ii($82|0,($58|0))|0);
      $83 = __THREW__; __THREW__ = 0;
      $84 = $83&1;
      if (!($84)) {
       $eh$lpad$body$index2Z2D = $79;$eh$lpad$body$indexZ2D = $78;
       break;
      }
      $85 = ___cxa_find_matching_catch_3(0|0)|0;
      $86 = tempRet0;
      ___clang_call_terminate($85);
      // unreachable;
     }
     $68 = ((($55)) + 72|0);
     $69 = ($65|0)==($68|0);
     if ($69) {
      $172 = 0;
     } else {
      $70 = ((($65)) + 28|0);
      $71 = HEAP8[$70>>0]|0;
      $72 = ($71<<24>>24)!=(0);
      $172 = $72;
     }
     $73 = HEAP32[$58>>2]|0;
     $74 = ((($73)) + 12|0);
     $75 = HEAP32[$74>>2]|0;
     __THREW__ = 0;
     (invoke_ii($75|0,($58|0))|0);
     $76 = __THREW__; __THREW__ = 0;
     $77 = $76&1;
     if ($77) {
      label = 28;
     } else {
      $87 = HEAP8[$56>>0]|0;
      $88 = ($87<<24>>24)<(0);
      if ($88) {
       $89 = HEAP32[$2>>2]|0;
       __ZdlPv($89);
      }
      if (!($172)) {
       break L11;
      }
      $90 = HEAP32[$9>>2]|0;
      $91 = ((($90)) + 16|0);
      $92 = +HEAPF64[$91>>3];
      $93 = $92 - $12;
      $94 = HEAP32[$0>>2]|0;
      $95 = ((($94)) + 4|0);
      $96 = HEAP32[$95>>2]|0;
      $97 = (FUNCTION_TABLE_ii[$96 & 8191]($0)|0);
      $98 = (__Znwj(16)|0);
      HEAP32[$3>>2] = $98;
      $99 = ((($3)) + 8|0);
      HEAP32[$99>>2] = -2147483632;
      $100 = ((($3)) + 4|0);
      HEAP32[$100>>2] = 14;
      dest=$98; src=104308; stop=dest+14|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
      $101 = ((($98)) + 14|0);
      HEAP8[$101>>0] = 0;
      __THREW__ = 0;
      (invoke_iiiid(3392,($97|0),($14|0),($3|0),(+$93))|0);
      $102 = __THREW__; __THREW__ = 0;
      $103 = $102&1;
      if ($103) {
       $144 = ___cxa_find_matching_catch_2()|0;
       $145 = tempRet0;
       $146 = ((($3)) + 11|0);
       $147 = HEAP8[$146>>0]|0;
       $148 = ($147<<24>>24)<(0);
       if ($148) {
        $149 = HEAP32[$3>>2]|0;
        __ZdlPv($149);
       }
       $$1 = $145;$$123 = $144;
       ___resumeException($$123|0);
       // unreachable;
      }
      $104 = ((($3)) + 11|0);
      $105 = HEAP8[$104>>0]|0;
      $106 = ($105<<24>>24)<(0);
      if ($106) {
       $107 = HEAP32[$3>>2]|0;
       __ZdlPv($107);
      }
      $108 = HEAP32[$0>>2]|0;
      $109 = ((($108)) + 4|0);
      $110 = HEAP32[$109>>2]|0;
      $111 = (FUNCTION_TABLE_ii[$110 & 8191]($0)|0);
      $112 = ((($4)) + 11|0);
      HEAP8[$112>>0] = 10;
      dest=$4; src=104323; stop=dest+10|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
      $113 = ((($4)) + 10|0);
      HEAP8[$113>>0] = 0;
      $114 = 1.0 / $93;
      __THREW__ = 0;
      (invoke_iiiid(3392,($111|0),($14|0),($4|0),(+$114))|0);
      $115 = __THREW__; __THREW__ = 0;
      $116 = $115&1;
      if ($116) {
       $150 = ___cxa_find_matching_catch_2()|0;
       $151 = tempRet0;
       $152 = HEAP8[$112>>0]|0;
       $153 = ($152<<24>>24)<(0);
       if ($153) {
        $154 = HEAP32[$4>>2]|0;
        __ZdlPv($154);
       }
       $$1 = $151;$$123 = $150;
       ___resumeException($$123|0);
       // unreachable;
      }
      $117 = HEAP8[$112>>0]|0;
      $118 = ($117<<24>>24)<(0);
      if ($118) {
       $119 = HEAP32[$4>>2]|0;
       __ZdlPv($119);
      }
      $120 = HEAP32[$0>>2]|0;
      $121 = ((($120)) + 4|0);
      $122 = HEAP32[$121>>2]|0;
      $123 = (FUNCTION_TABLE_ii[$122 & 8191]($0)|0);
      $124 = HEAP32[$9>>2]|0;
      $125 = ((($124)) + 12|0);
      $126 = HEAP32[$125>>2]|0;
      $127 = (__Znwj(16)|0);
      HEAP32[$5>>2] = $127;
      $128 = ((($5)) + 8|0);
      HEAP32[$128>>2] = -2147483632;
      $129 = ((($5)) + 4|0);
      HEAP32[$129>>2] = 14;
      dest=$127; src=104334; stop=dest+14|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
      $130 = ((($127)) + 14|0);
      HEAP8[$130>>0] = 0;
      $131 = ((($124)) + 16|0);
      $132 = +HEAPF64[$131>>3];
      __THREW__ = 0;
      (invoke_iiiid(3392,($123|0),($126|0),($5|0),(+$132))|0);
      $133 = __THREW__; __THREW__ = 0;
      $134 = $133&1;
      if (!($134)) {
       $135 = ((($5)) + 11|0);
       $136 = HEAP8[$135>>0]|0;
       $137 = ($136<<24>>24)<(0);
       if ($137) {
        $138 = HEAP32[$5>>2]|0;
        __ZdlPv($138);
       }
       break L11;
      }
      $155 = ___cxa_find_matching_catch_2()|0;
      $156 = tempRet0;
      $157 = ((($5)) + 11|0);
      $158 = HEAP8[$157>>0]|0;
      $159 = ($158<<24>>24)<(0);
      if ($159) {
       $160 = HEAP32[$5>>2]|0;
       __ZdlPv($160);
      }
      $$1 = $156;$$123 = $155;
      ___resumeException($$123|0);
      // unreachable;
     }
    }
   } while(0);
   if ((label|0) == 28) {
    $139 = ___cxa_find_matching_catch_2()|0;
    $140 = tempRet0;
    $eh$lpad$body$index2Z2D = $140;$eh$lpad$body$indexZ2D = $139;
   }
   $141 = HEAP8[$56>>0]|0;
   $142 = ($141<<24>>24)<(0);
   if ($142) {
    $143 = HEAP32[$2>>2]|0;
    __ZdlPv($143);
   }
   $$1 = $eh$lpad$body$index2Z2D;$$123 = $eh$lpad$body$indexZ2D;
   ___resumeException($$123|0);
   // unreachable;
  }
 } while(0);
 $161 = (__ZN3osg10Referenced16getDeleteHandlerEv()|0);
 $162 = ($161|0)==(0|0);
 if ($162) {
  STACKTOP = sp;return;
 }
 $163 = (__ZN3osg10Referenced16getDeleteHandlerEv()|0);
 $164 = HEAP32[$163>>2]|0;
 $165 = ((($164)) + 8|0);
 $166 = HEAP32[$165>>2]|0;
 FUNCTION_TABLE_vi[$166 & 8191]($163);
 $167 = (__ZN3osg10Referenced16getDeleteHandlerEv()|0);
 $168 = HEAP32[$9>>2]|0;
 $169 = ((($168)) + 12|0);
 $170 = HEAP32[$169>>2]|0;
 $171 = ((($167)) + 8|0);
 HEAP32[$171>>2] = $170;
 STACKTOP = sp;return;
}
function __ZN9osgViewer6Viewer14eventTraversalEv($0) {
 $0 = $0|0;
 var $$$i$i = 0, $$0166346 = 0, $$0167350 = 0, $$023$i$i = 0, $$023$i$i173 = 0, $$023$i$i219 = 0, $$023$i$i222 = 0, $$18 = 0, $$18154 = 0, $$19 = 0, $$19155 = 0, $$20 = 0, $$20156 = 0, $$23 = 0, $$23159 = 0, $$4 = 0, $$4140 = 0, $$pr$i$i = 0, $$pre = 0, $$pre386 = 0;
 var $$pre387 = 0, $$pre388 = 0, $$pre389 = 0, $$pre391 = 0, $$pre392 = 0, $$sink$i = 0.0, $$sink$i200 = 0.0, $$sroa$0234$0 = 0, $$sroa$0234$0334 = 0, $$sroa$0234$0334$pre = 0, $$sroa$0234$0335 = 0, $$sroa$0242$0 = 0, $$sroa$0242$0337 = 0, $$sroa$0242$0338 = 0, $$sroa$0250$0 = 0, $$sroa$0250$0343 = 0, $$sroa$0250$0344 = 0, $$sroa$0258$0 = 0, $$sroa$0258$0354 = 0, $$sroa$0258$0355 = 0;
 var $$sroa$0266$0 = 0, $$sroa$0266$0359 = 0, $$sroa$0266$0360 = 0, $$sroa$0288$0 = 0, $$sroa$0288$0363 = 0, $$sroa$0288$0364 = 0, $$sroa$0288$1 = 0, $$sroa$0288$1367 = 0, $$sroa$0288$1367$pre = 0, $$sroa$0288$1368 = 0, $$sroa$0298$0371 = 0, $$sroa$0305$0375 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0.0, $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0;
 var $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0;
 var $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0;
 var $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0;
 var $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0;
 var $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0;
 var $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0;
 var $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0;
 var $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0;
 var $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0.0, $321 = 0;
 var $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0.0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0;
 var $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0;
 var $359 = 0, $36 = 0.0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0.0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0;
 var $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0.0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0;
 var $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0.0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0;
 var $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0;
 var $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0;
 var $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0;
 var $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0;
 var $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0;
 var $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0;
 var $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0;
 var $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0;
 var $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0;
 var $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0;
 var $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0;
 var $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0;
 var $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0;
 var $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0;
 var $665 = 0.0, $666 = 0, $667 = 0, $668 = 0.0, $669 = 0.0, $67 = 0, $670 = 0, $671 = 0.0, $672 = 0.0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0;
 var $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0;
 var $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0;
 var $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0.0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0;
 var $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0;
 var $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0;
 var $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0;
 var $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0;
 var $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0;
 var $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = 0, $834 = 0, $835 = 0, $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0;
 var $845 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $cond = 0, $eh$lpad$body$index8Z2D = 0, $eh$lpad$body$indexZ2D = 0;
 var $scevgep$i$i$i = 0, $scevgep$i$i$i176 = 0, $scevgep5$i$i$i = 0, $scevgep5$i$i$i177 = 0, $switch$split2D = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(96|0);
 $1 = sp + 72|0;
 $2 = sp + 60|0;
 $3 = sp + 48|0;
 $4 = sp + 36|0;
 $5 = sp + 24|0;
 $6 = sp + 12|0;
 $7 = sp;
 $8 = ((($0)) + 5|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = ($9<<24>>24)==(0);
 if (!($10)) {
  STACKTOP = sp;return;
 }
 $11 = ((($0)) + 136|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ((($12)) + 16|0);
 $14 = +HEAPF64[$13>>3];
 $15 = (__ZN3osg5Timer8instanceEv()|0);
 $16 = ((($0)) + 152|0);
 $17 = $16;
 $18 = $17;
 $19 = HEAP32[$18>>2]|0;
 $20 = (($17) + 4)|0;
 $21 = $20;
 $22 = HEAP32[$21>>2]|0;
 $23 = (__ZN3osg5Timer8instanceEv()|0);
 $24 = (__ZNK3osg5Timer4tickEv($23)|0);
 $25 = tempRet0;
 $26 = ($25>>>0)>($22>>>0);
 $27 = ($24>>>0)>($19>>>0);
 $28 = ($25|0)==($22|0);
 $29 = $28 & $27;
 $30 = $26 | $29;
 if ($30) {
  $31 = (_i64Subtract(($24|0),($25|0),($19|0),($22|0))|0);
  $32 = tempRet0;
  $33 = (+($31>>>0)) + (4294967296.0*(+($32>>>0)));
  $$sink$i = $33;
 } else {
  $34 = (_i64Subtract(($19|0),($22|0),($24|0),($25|0))|0);
  $35 = tempRet0;
  $36 = (+($34>>>0)) + (4294967296.0*(+($35>>>0)));
  $37 = -$36;
  $$sink$i = $37;
 }
 $38 = ((($15)) + 8|0);
 $39 = +HEAPF64[$38>>3];
 $40 = $$sink$i * $39;
 HEAP32[$1>>2] = $1;
 $41 = ((($1)) + 4|0);
 HEAP32[$41>>2] = $1;
 $42 = ((($1)) + 8|0);
 HEAP32[$42>>2] = 0;
 HEAP32[$2>>2] = 0;
 $43 = ((($2)) + 4|0);
 HEAP32[$43>>2] = 0;
 $44 = ((($2)) + 8|0);
 HEAP32[$44>>2] = 0;
 $45 = HEAP32[$0>>2]|0;
 $46 = ((($45)) + 88|0);
 $47 = HEAP32[$46>>2]|0;
 __THREW__ = 0;
 invoke_viii($47|0,($0|0),($2|0),1);
 $48 = __THREW__; __THREW__ = 0;
 $49 = $48&1;
 L8: do {
  if ($49) {
   label = 8;
  } else {
   __THREW__ = 0;
   invoke_vii(3393,($0|0),($2|0));
   $50 = __THREW__; __THREW__ = 0;
   $51 = $50&1;
   if ($51) {
    label = 8;
   } else {
    $52 = HEAP8[$8>>0]|0;
    $53 = ($52<<24>>24)==(0);
    L11: do {
     if ($53) {
      $56 = ((($0)) + 176|0);
      $57 = HEAP32[$56>>2]|0;
      $58 = ((($57)) + 12|0);
      $59 = HEAP32[$58>>2]|0;
      $60 = ((($0)) + 160|0);
      $61 = HEAP32[$60>>2]|0;
      $62 = ((($0)) + 164|0);
      $63 = HEAP32[$62>>2]|0;
      $64 = ($61|0)==($63|0);
      L13: do {
       if (!($64)) {
        $$sroa$0305$0375 = $61;
        while(1) {
         $77 = HEAP32[$$sroa$0305$0375>>2]|0;
         $78 = ((($77)) + 36|0);
         $79 = HEAP32[$78>>2]|0;
         $80 = $79 & 1;
         $81 = ($80|0)==(0);
         if (!($81)) {
          $82 = HEAP32[$77>>2]|0;
          $83 = ((($82)) + 140|0);
          $84 = HEAP32[$83>>2]|0;
          __THREW__ = 0;
          (invoke_ii($84|0,($77|0))|0);
          $85 = __THREW__; __THREW__ = 0;
          $86 = $85&1;
          if ($86) {
           break;
          }
         }
         $89 = ((($77)) + 32|0);
         $90 = HEAP32[$89>>2]|0;
         __THREW__ = 0;
         (invoke_iiid(3394,($90|0),($1|0),(+$14))|0);
         $91 = __THREW__; __THREW__ = 0;
         $92 = $91&1;
         if ($92) {
          break;
         }
         $93 = ((($$sroa$0305$0375)) + 4|0);
         $94 = HEAP32[$62>>2]|0;
         $95 = ($93|0)==($94|0);
         if ($95) {
          break L13;
         } else {
          $$sroa$0305$0375 = $93;
         }
        }
        $87 = ___cxa_find_matching_catch_2()|0;
        $88 = tempRet0;
        $$23 = $87;$$23159 = $88;
        break L8;
       }
      } while(0);
      $65 = HEAP32[$2>>2]|0;
      $66 = HEAP32[$43>>2]|0;
      $67 = ($65|0)==($66|0);
      L22: do {
       if (!($67)) {
        $68 = ((($3)) + 4|0);
        $69 = ((($3)) + 8|0);
        $70 = ((($0)) + 32|0);
        $71 = ((($0)) + 92|0);
        $72 = ((($0)) + 96|0);
        $73 = ((($59)) + 52|0);
        $74 = ((($59)) + 160|0);
        $75 = ((($59)) + 164|0);
        $76 = ((($59)) + 56|0);
        $$sroa$0298$0371 = $65;$834 = $66;
        L24: while(1) {
         $96 = HEAP32[$$sroa$0298$0371>>2]|0;
         $97 = ($96|0)==(0|0);
         if ($97) {
          $316 = $834;
         } else {
          $98 = (___dynamic_cast($96,24816,3888,0)|0);
          $99 = ($98|0)==(0|0);
          if ($99) {
           $316 = $834;
          } else {
           $100 = HEAP32[$98>>2]|0;
           $101 = ((($100)) + 188|0);
           $102 = HEAP32[$101>>2]|0;
           __THREW__ = 0;
           (invoke_ii($102|0,($98|0))|0);
           $103 = __THREW__; __THREW__ = 0;
           $104 = $103&1;
           if ($104) {
            label = 28;
            break;
           }
           HEAP32[$3>>2] = $3;
           HEAP32[$68>>2] = $3;
           HEAP32[$69>>2] = 0;
           $105 = ((($98)) + 136|0);
           $106 = HEAP32[$105>>2]|0;
           __THREW__ = 0;
           (invoke_iiid(3394,($106|0),($3|0),(+$14))|0);
           $107 = __THREW__; __THREW__ = 0;
           $108 = $107&1;
           if ($108) {
            label = 29;
            break;
           }
           $$sroa$0288$0363 = HEAP32[$68>>2]|0;
           $109 = $$sroa$0288$0363;
           $110 = ($109|0)==($3|0);
           if ($110) {
            $$sroa$0288$1367 = $$sroa$0288$0363;
           } else {
            $$sroa$0288$0364 = $$sroa$0288$0363;$213 = $109;
            while(1) {
             $113 = $$sroa$0288$0364;
             $114 = ((($113)) + 8|0);
             $115 = HEAP32[$114>>2]|0;
             $116 = HEAP32[$115>>2]|0;
             $117 = ((($116)) + 140|0);
             $118 = HEAP32[$117>>2]|0;
             __THREW__ = 0;
             $119 = (invoke_ii($118|0,($115|0))|0);
             $120 = __THREW__; __THREW__ = 0;
             $121 = $120&1;
             if ($121) {
              label = 30;
              break L24;
             }
             $122 = ($119|0)==(0|0);
             do {
              if (!($122)) {
               __THREW__ = 0;
               $129 = (invoke_ii(3325,($98|0))|0);
               $130 = __THREW__; __THREW__ = 0;
               $131 = $130&1;
               if ($131) {
                label = 43;
                break L24;
               }
               $132 = ((($119)) + 52|0);
               $133 = HEAP32[$132>>2]|0;
               $134 = ($133|0)==($129|0);
               if ($134) {
                $144 = $129;
               } else {
                HEAP32[$132>>2] = $129;
                $135 = ($129|0)==(0|0);
                if (!($135)) {
                 $136 = ((($129)) + 8|0);
                 $137 = HEAP32[$136>>2]|0;HEAP32[$136>>2] = (($137+1)|0);
                }
                $138 = ($133|0)==(0|0);
                do {
                 if (!($138)) {
                  $139 = ((($133)) + 8|0);
                  $140 = HEAP32[$139>>2]|0;HEAP32[$139>>2] = (($140-1)|0);
                  $141 = ($140|0)==(1);
                  if (!($141)) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_viii(3262,($133|0),1,1);
                  $142 = __THREW__; __THREW__ = 0;
                  $143 = $142&1;
                  if ($143) {
                   label = 43;
                   break L24;
                  }
                 }
                } while(0);
                $$pr$i$i = HEAP32[$132>>2]|0;
                $144 = $$pr$i$i;
               }
               $145 = ($144|0)==(0|0);
               if ($145) {
                $150 = 0;
               } else {
                $146 = ((($144)) + 24|0);
                $147 = HEAP32[$146>>2]|0;
                $148 = ($147|0)!=(0|0);
                $$$i$i = $148 ? $98 : 0;
                $150 = $$$i$i;
               }
               $149 = ((($119)) + 56|0);
               HEAP32[$149>>2] = $150;
               $151 = HEAP32[$119>>2]|0;
               $152 = ((($151)) + 148|0);
               $153 = HEAP32[$152>>2]|0;
               __THREW__ = 0;
               $154 = (invoke_ii($153|0,($119|0))|0);
               $155 = __THREW__; __THREW__ = 0;
               $156 = $155&1;
               if ($156) {
                label = 43;
                break L24;
               }
               switch ($154|0) {
               case 8: case 16: case 4: case 2: case 1:  {
                $159 = HEAP32[$119>>2]|0;
                $160 = ((($159)) + 148|0);
                $161 = HEAP32[$160>>2]|0;
                __THREW__ = 0;
                $162 = (invoke_ii($161|0,($119|0))|0);
                $163 = __THREW__; __THREW__ = 0;
                $164 = $163&1;
                if ($164) {
                 label = 43;
                 break L24;
                }
                $165 = ($162|0)==(8);
                do {
                 if ($165) {
                  $166 = HEAP32[$73>>2]|0;
                  $167 = ($166|0)==(0|0);
                  do {
                   if ($167) {
                    $178 = 0;
                   } else {
                    $168 = ((($166)) + 24|0);
                    $169 = HEAP32[$168>>2]|0;
                    $170 = ($169|0)==(0|0);
                    if ($170) {
                     $178 = 0;
                     break;
                    }
                    $171 = HEAP32[$76>>2]|0;
                    $178 = $171;
                   }
                  } while(0);
                  $172 = HEAP32[$132>>2]|0;
                  $173 = ($172|0)==(0|0);
                  do {
                   if ($173) {
                    $180 = 0;
                   } else {
                    $174 = ((($172)) + 24|0);
                    $175 = HEAP32[$174>>2]|0;
                    $176 = ($175|0)==(0|0);
                    if ($176) {
                     $180 = 0;
                     break;
                    }
                    $177 = HEAP32[$149>>2]|0;
                    $180 = $177;
                   }
                  } while(0);
                  $179 = ($178|0)==($180|0);
                  if (!($179)) {
                   label = 54;
                   break;
                  }
                  $181 = HEAP32[$75>>2]|0;
                  $182 = HEAP32[$74>>2]|0;
                  $183 = (($181) - ($182))|0;
                  $184 = $183 >> 2;
                  $185 = ($184>>>0)<(2);
                  if ($185) {
                   label = 54;
                   break;
                  }
                  __THREW__ = 0;
                  invoke_viii(3396,($0|0),($59|0),($119|0));
                  $188 = __THREW__; __THREW__ = 0;
                  $189 = $188&1;
                  if ($189) {
                   label = 43;
                   break L24;
                  }
                 } else {
                  label = 54;
                 }
                } while(0);
                if ((label|0) == 54) {
                 label = 0;
                 __THREW__ = 0;
                 invoke_vii(3395,($0|0),($119|0));
                 $186 = __THREW__; __THREW__ = 0;
                 $187 = $186&1;
                 if ($187) {
                  label = 43;
                  break L24;
                 }
                }
                __THREW__ = 0;
                invoke_vii(3397,($59|0),($119|0));
                $190 = __THREW__; __THREW__ = 0;
                $191 = $190&1;
                if ($191) {
                 label = 43;
                 break L24;
                }
                break;
               }
               default: {
                __THREW__ = 0;
                invoke_vii(3397,($119|0),($59|0));
                $192 = __THREW__; __THREW__ = 0;
                $193 = $192&1;
                if ($193) {
                 label = 43;
                 break L24;
                }
               }
               }
               $194 = ((($119)) + 8|0);
               $195 = HEAP32[$194>>2]|0;HEAP32[$194>>2] = (($195+1)|0);
               __THREW__ = 0;
               $196 = (invoke_ii(3276,12)|0);
               $197 = __THREW__; __THREW__ = 0;
               $198 = $197&1;
               if ($198) {
                label = 63;
                break L24;
               }
               $199 = ((($196)) + 8|0);
               HEAP32[$199>>2] = $119;
               $200 = ((($119)) + 8|0);
               $201 = HEAP32[$200>>2]|0;HEAP32[$200>>2] = (($201+1)|0);
               $202 = ((($196)) + 4|0);
               HEAP32[$202>>2] = $1;
               $203 = HEAP32[$1>>2]|0;
               HEAP32[$196>>2] = $203;
               $204 = ((($203)) + 4|0);
               HEAP32[$204>>2] = $196;
               HEAP32[$1>>2] = $196;
               $205 = HEAP32[$42>>2]|0;
               $206 = (($205) + 1)|0;
               HEAP32[$42>>2] = $206;
               $207 = ((($119)) + 8|0);
               $208 = HEAP32[$207>>2]|0;HEAP32[$207>>2] = (($208-1)|0);
               $209 = ($208|0)==(1);
               if (!($209)) {
                break;
               }
               __THREW__ = 0;
               invoke_viii(3262,($119|0),1,1);
               $210 = __THREW__; __THREW__ = 0;
               $211 = $210&1;
               if ($211) {
                label = 62;
                break L24;
               }
              }
             } while(0);
             $212 = ((($213)) + 4|0);
             $$sroa$0288$0 = HEAP32[$212>>2]|0;
             $214 = $$sroa$0288$0;
             $215 = ($214|0)==($3|0);
             if ($215) {
              break;
             } else {
              $$sroa$0288$0364 = $$sroa$0288$0;$213 = $214;
             }
            }
            $$sroa$0288$1367$pre = HEAP32[$68>>2]|0;
            $$sroa$0288$1367 = $$sroa$0288$1367$pre;
           }
           $111 = $$sroa$0288$1367;
           $112 = ($111|0)==($3|0);
           if (!($112)) {
            $$sroa$0288$1368 = $$sroa$0288$1367;$263 = $111;
            while(1) {
             $225 = $$sroa$0288$1368;
             $226 = ((($225)) + 8|0);
             $227 = HEAP32[$226>>2]|0;
             $228 = HEAP32[$227>>2]|0;
             $229 = ((($228)) + 140|0);
             $230 = HEAP32[$229>>2]|0;
             __THREW__ = 0;
             $231 = (invoke_ii($230|0,($227|0))|0);
             $232 = __THREW__; __THREW__ = 0;
             $233 = $232&1;
             if ($233) {
              label = 30;
              break L24;
             }
             $234 = ($231|0)==(0|0);
             do {
              if (!($234)) {
               $235 = HEAP32[$231>>2]|0;
               $236 = ((($235)) + 148|0);
               $237 = HEAP32[$236>>2]|0;
               __THREW__ = 0;
               $238 = (invoke_ii($237|0,($231|0))|0);
               $239 = __THREW__; __THREW__ = 0;
               $240 = $239&1;
               if ($240) {
                label = 78;
                break L24;
               }
               $cond = ($238|0)==(16384);
               if (!($cond)) {
                break;
               }
               $241 = HEAP8[$70>>0]|0;
               $242 = ($241<<24>>24)!=(0);
               if ($242) {
                $243 = HEAP32[$0>>2]|0;
                $244 = ((($243)) + 44|0);
                $245 = HEAP32[$244>>2]|0;
                __THREW__ = 0;
                invoke_vi($245|0,($0|0));
                $246 = __THREW__; __THREW__ = 0;
                $247 = $246&1;
                if ($247) {
                 label = 78;
                 break L24;
                }
               }
               __THREW__ = 0;
               invoke_vii(3398,($98|0),1);
               $248 = __THREW__; __THREW__ = 0;
               $249 = $248&1;
               if ($249) {
                label = 78;
                break L24;
               }
               $250 = HEAP32[$71>>2]|0;
               $251 = ($250|0)==(0|0);
               do {
                if (!($251)) {
                 HEAP32[$71>>2] = 0;
                 $252 = ((($250)) + 8|0);
                 $253 = HEAP32[$252>>2]|0;HEAP32[$252>>2] = (($253-1)|0);
                 $254 = ($253|0)==(1);
                 if (!($254)) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_viii(3262,($250|0),1,1);
                 $255 = __THREW__; __THREW__ = 0;
                 $256 = $255&1;
                 if ($256) {
                  label = 78;
                  break L24;
                 }
                }
               } while(0);
               HEAP32[$72>>2] = 0;
               if (!($242)) {
                break;
               }
               $257 = HEAP32[$0>>2]|0;
               $258 = ((($257)) + 48|0);
               $259 = HEAP32[$258>>2]|0;
               __THREW__ = 0;
               invoke_vi($259|0,($0|0));
               $260 = __THREW__; __THREW__ = 0;
               $261 = $260&1;
               if ($261) {
                label = 78;
                break L24;
               }
              }
             } while(0);
             $262 = ((($263)) + 4|0);
             $$sroa$0288$1 = HEAP32[$262>>2]|0;
             $264 = $$sroa$0288$1;
             $265 = ($264|0)==($3|0);
             if ($265) {
              break;
             } else {
              $$sroa$0288$1368 = $$sroa$0288$1;$263 = $264;
             }
            }
           }
           $268 = HEAP32[$69>>2]|0;
           $269 = ($268|0)==(0);
           do {
            if (!($269)) {
             $270 = HEAP32[$68>>2]|0;
             $271 = HEAP32[$3>>2]|0;
             $272 = ((($271)) + 4|0);
             $273 = HEAP32[$272>>2]|0;
             $274 = HEAP32[$270>>2]|0;
             $275 = ((($274)) + 4|0);
             HEAP32[$275>>2] = $273;
             $276 = HEAP32[$272>>2]|0;
             HEAP32[$276>>2] = $274;
             HEAP32[$69>>2] = 0;
             $277 = ($270|0)==($3|0);
             if ($277) {
              break;
             } else {
              $$023$i$i219 = $270;
             }
             while(1) {
              $278 = ((($$023$i$i219)) + 4|0);
              $279 = HEAP32[$278>>2]|0;
              $280 = ((($$023$i$i219)) + 8|0);
              $281 = HEAP32[$280>>2]|0;
              $282 = ($281|0)==(0|0);
              do {
               if (!($282)) {
                $283 = ((($281)) + 8|0);
                $284 = HEAP32[$283>>2]|0;HEAP32[$283>>2] = (($284-1)|0);
                $285 = ($284|0)==(1);
                if (!($285)) {
                 break;
                }
                __THREW__ = 0;
                invoke_viii(3262,($281|0),1,1);
                $286 = __THREW__; __THREW__ = 0;
                $287 = $286&1;
                if ($287) {
                 label = 85;
                 break L24;
                }
               }
              } while(0);
              __ZdlPv($$023$i$i219);
              $288 = ($279|0)==($3|0);
              if ($288) {
               break;
              } else {
               $$023$i$i219 = $279;
              }
             }
            }
           } while(0);
           $$pre = HEAP32[$43>>2]|0;
           $316 = $$pre;
          }
         }
         $314 = ((($$sroa$0298$0371)) + 4|0);
         $315 = ($314|0)==($316|0);
         if ($315) {
          break L22;
         } else {
          $$sroa$0298$0371 = $314;$834 = $316;
         }
        }
        if ((label|0) == 28) {
         $123 = ___cxa_find_matching_catch_2()|0;
         $124 = tempRet0;
         $$23 = $123;$$23159 = $124;
         break L8;
        }
        else if ((label|0) == 29) {
         $125 = ___cxa_find_matching_catch_2()|0;
         $126 = tempRet0;
         $$4 = $125;$$4140 = $126;
        }
        else if ((label|0) == 30) {
         $127 = ___cxa_find_matching_catch_2()|0;
         $128 = tempRet0;
         $$4 = $127;$$4140 = $128;
        }
        else if ((label|0) == 43) {
         $157 = ___cxa_find_matching_catch_2()|0;
         $158 = tempRet0;
         $$4 = $157;$$4140 = $158;
        }
        else if ((label|0) == 62) {
         $216 = ___cxa_find_matching_catch_2()|0;
         $217 = tempRet0;
         $$4 = $216;$$4140 = $217;
        }
        else if ((label|0) == 63) {
         $218 = ___cxa_find_matching_catch_2()|0;
         $219 = tempRet0;
         $220 = ((($119)) + 8|0);
         $221 = HEAP32[$220>>2]|0;HEAP32[$220>>2] = (($221-1)|0);
         $222 = ($221|0)==(1);
         if ($222) {
          __THREW__ = 0;
          invoke_viii(3262,($119|0),1,1);
          $223 = __THREW__; __THREW__ = 0;
          $224 = $223&1;
          if ($224) {
           $832 = ___cxa_find_matching_catch_3(0|0)|0;
           $833 = tempRet0;
           ___clang_call_terminate($832);
           // unreachable;
          } else {
           $$4 = $218;$$4140 = $219;
          }
         } else {
          $$4 = $218;$$4140 = $219;
         }
        }
        else if ((label|0) == 78) {
         $266 = ___cxa_find_matching_catch_2()|0;
         $267 = tempRet0;
         $$4 = $266;$$4140 = $267;
        }
        else if ((label|0) == 85) {
         $289 = ___cxa_find_matching_catch_2()|0;
         $290 = tempRet0;
         ___cxa_call_unexpected(($289|0));
         // unreachable;
        }
        $291 = HEAP32[$69>>2]|0;
        $292 = ($291|0)==(0);
        L120: do {
         if (!($292)) {
          $293 = HEAP32[$68>>2]|0;
          $294 = HEAP32[$3>>2]|0;
          $295 = ((($294)) + 4|0);
          $296 = HEAP32[$295>>2]|0;
          $297 = HEAP32[$293>>2]|0;
          $298 = ((($297)) + 4|0);
          HEAP32[$298>>2] = $296;
          $299 = HEAP32[$295>>2]|0;
          HEAP32[$299>>2] = $297;
          HEAP32[$69>>2] = 0;
          $300 = ($293|0)==($3|0);
          if (!($300)) {
           $$023$i$i222 = $293;
           while(1) {
            $301 = ((($$023$i$i222)) + 4|0);
            $302 = HEAP32[$301>>2]|0;
            $303 = ((($$023$i$i222)) + 8|0);
            $304 = HEAP32[$303>>2]|0;
            $305 = ($304|0)==(0|0);
            if (!($305)) {
             $306 = ((($304)) + 8|0);
             $307 = HEAP32[$306>>2]|0;HEAP32[$306>>2] = (($307-1)|0);
             $308 = ($307|0)==(1);
             if ($308) {
              __THREW__ = 0;
              invoke_viii(3262,($304|0),1,1);
              $309 = __THREW__; __THREW__ = 0;
              $310 = $309&1;
              if ($310) {
               break;
              }
             }
            }
            __ZdlPv($$023$i$i222);
            $311 = ($302|0)==($3|0);
            if ($311) {
             break L120;
            } else {
             $$023$i$i222 = $302;
            }
           }
           $312 = ___cxa_find_matching_catch_2()|0;
           $313 = tempRet0;
           ___cxa_call_unexpected(($312|0));
           // unreachable;
          }
         }
        } while(0);
        $$23 = $$4;$$23159 = $$4140;
        break L8;
       }
      } while(0);
      $317 = HEAP32[$56>>2]|0;
      $318 = HEAP32[$11>>2]|0;
      $319 = ((($318)) + 16|0);
      $320 = +HEAPF64[$319>>3];
      __THREW__ = 0;
      $321 = (invoke_iid(3399,($317|0),(+$320))|0);
      $322 = __THREW__; __THREW__ = 0;
      $323 = $322&1;
      L131: do {
       if (!($323)) {
        $324 = ($321|0)==(0|0);
        if (!($324)) {
         $325 = ((($321)) + 8|0);
         $326 = HEAP32[$325>>2]|0;HEAP32[$325>>2] = (($326+1)|0);
        }
        $327 = ($59|0)==(0|0);
        if ($327) {
         label = 101;
        } else {
         $328 = ((($59)) + 160|0);
         $329 = ((($59)) + 164|0);
         $330 = HEAP32[$329>>2]|0;
         $331 = HEAP32[$328>>2]|0;
         $332 = (($330) - ($331))|0;
         $333 = $332 >> 2;
         $334 = ($333>>>0)<(2);
         if ($334) {
          label = 101;
         } else {
          __THREW__ = 0;
          invoke_viii(3396,($0|0),($59|0),($321|0));
          $346 = __THREW__; __THREW__ = 0;
          $347 = $346&1;
          if ($347) {
           label = 103;
          }
         }
        }
        if ((label|0) == 101) {
         __THREW__ = 0;
         invoke_vii(3395,($0|0),($321|0));
         $335 = __THREW__; __THREW__ = 0;
         $336 = $335&1;
         if ($336) {
          label = 103;
         }
        }
        if ((label|0) == 103) {
         $339 = ___cxa_find_matching_catch_2()|0;
         $340 = tempRet0;
         if ($324) {
          $$23 = $339;$$23159 = $340;
          break L8;
         }
         $341 = ((($321)) + 8|0);
         $342 = HEAP32[$341>>2]|0;HEAP32[$341>>2] = (($342-1)|0);
         $343 = ($342|0)==(1);
         if (!($343)) {
          $$23 = $339;$$23159 = $340;
          break L8;
         }
         __THREW__ = 0;
         invoke_viii(3262,($321|0),1,1);
         $344 = __THREW__; __THREW__ = 0;
         $345 = $344&1;
         if (!($345)) {
          $$23 = $339;$$23159 = $340;
          break L8;
         }
         $832 = ___cxa_find_matching_catch_3(0|0)|0;
         $833 = tempRet0;
         ___clang_call_terminate($832);
         // unreachable;
        }
        if (!($324)) {
         $348 = ((($321)) + 8|0);
         $349 = HEAP32[$348>>2]|0;HEAP32[$348>>2] = (($349-1)|0);
         $350 = ($349|0)==(1);
         if ($350) {
          __THREW__ = 0;
          invoke_viii(3262,($321|0),1,1);
          $351 = __THREW__; __THREW__ = 0;
          $352 = $351&1;
          if ($352) {
           $365 = ___cxa_find_matching_catch_2()|0;
           $366 = tempRet0;
           $$23 = $365;$$23159 = $366;
           break L8;
          }
         }
        }
        $353 = HEAP32[$56>>2]|0;
        __THREW__ = 0;
        (invoke_iiid(3394,($353|0),($1|0),(+$14))|0);
        $354 = __THREW__; __THREW__ = 0;
        $355 = $354&1;
        if (!($355)) {
         $356 = ((($0)) + 8|0);
         $357 = HEAP32[$356>>2]|0;
         $358 = ($357|0)==(0);
         if ($358) {
          $359 = ((($0)) + 12|0);
          $360 = HEAP8[$359>>0]|0;
          $361 = ($360<<24>>24)==(0);
          if (!($361)) {
           label = 113;
          }
         } else {
          label = 113;
         }
         L155: do {
          if ((label|0) == 113) {
           $$sroa$0266$0359 = HEAP32[$41>>2]|0;
           $362 = $$sroa$0266$0359;
           $363 = ($362|0)==($1|0);
           if (!($363)) {
            $364 = ((($0)) + 12|0);
            $$sroa$0266$0360 = $$sroa$0266$0359;$403 = $362;
            L158: while(1) {
             $367 = $$sroa$0266$0360;
             $368 = ((($367)) + 8|0);
             $369 = HEAP32[$368>>2]|0;
             $370 = HEAP32[$369>>2]|0;
             $371 = ((($370)) + 140|0);
             $372 = HEAP32[$371>>2]|0;
             __THREW__ = 0;
             $373 = (invoke_ii($372|0,($369|0))|0);
             $374 = __THREW__; __THREW__ = 0;
             $375 = $374&1;
             if ($375) {
              label = 118;
              break;
             }
             $376 = ($373|0)==(0|0);
             L161: do {
              if (!($376)) {
               $379 = ((($373)) + 32|0);
               $380 = HEAP8[$379>>0]|0;
               $381 = ($380<<24>>24)==(0);
               if (!($381)) {
                break;
               }
               $384 = HEAP32[$373>>2]|0;
               $385 = ((($384)) + 148|0);
               $386 = HEAP32[$385>>2]|0;
               __THREW__ = 0;
               $387 = (invoke_ii($386|0,($373|0))|0);
               $388 = __THREW__; __THREW__ = 0;
               $389 = $388&1;
               if ($389) {
                label = 120;
                break L158;
               }
               $switch$split2D = ($387|0)<(32768);
               if (!($switch$split2D)) {
                switch ($387|0) {
                case 32768:  {
                 break;
                }
                default: {
                 break L161;
                }
                }
                $400 = HEAP8[$364>>0]|0;
                $401 = ($400<<24>>24)==(0);
                if ($401) {
                 break;
                }
                HEAP8[$8>>0] = 1;
                break;
               }
               switch ($387|0) {
               case 64:  {
                break;
               }
               default: {
                break L161;
               }
               }
               $390 = HEAP32[$356>>2]|0;
               $391 = ($390|0)==(0);
               if ($391) {
                break;
               }
               $392 = HEAP32[$373>>2]|0;
               $393 = ((($392)) + 152|0);
               $394 = HEAP32[$393>>2]|0;
               __THREW__ = 0;
               $395 = (invoke_ii($394|0,($373|0))|0);
               $396 = __THREW__; __THREW__ = 0;
               $397 = $396&1;
               if ($397) {
                label = 120;
                break L158;
               }
               $398 = HEAP32[$356>>2]|0;
               $399 = ($395|0)==($398|0);
               if (!($399)) {
                break;
               }
               HEAP8[$8>>0] = 1;
              }
             } while(0);
             $402 = ((($403)) + 4|0);
             $$sroa$0266$0 = HEAP32[$402>>2]|0;
             $404 = $$sroa$0266$0;
             $405 = ($404|0)==($1|0);
             if ($405) {
              break L155;
             } else {
              $$sroa$0266$0360 = $$sroa$0266$0;$403 = $404;
             }
            }
            if ((label|0) == 118) {
             $377 = ___cxa_find_matching_catch_2()|0;
             $378 = tempRet0;
             $$23 = $377;$$23159 = $378;
             break L8;
            }
            else if ((label|0) == 120) {
             $382 = ___cxa_find_matching_catch_2()|0;
             $383 = tempRet0;
             $$23 = $382;$$23159 = $383;
             break L8;
            }
           }
          }
         } while(0);
         $406 = HEAP8[$8>>0]|0;
         $407 = ($406<<24>>24)==(0);
         if (!($407)) {
          break L11;
         }
         $408 = ((($0)) + 68|0);
         $409 = HEAP32[$408>>2]|0;
         $410 = ($409|0)==(0|0);
         L180: do {
          if (!($410)) {
           $411 = ((($0)) + 172|0);
           $412 = HEAP32[$411>>2]|0;
           $413 = ($412|0)==(0|0);
           if (!($413)) {
            __THREW__ = 0;
            $414 = (invoke_ii(3279,($412|0))|0);
            $415 = __THREW__; __THREW__ = 0;
            $416 = $415&1;
            if ($416) {
             break L131;
            }
            $417 = ($414|0)==(0|0);
            if ($417) {
             break;
            }
            $422 = HEAP32[$408>>2]|0;
            $423 = HEAP32[$11>>2]|0;
            $424 = ((($422)) + 12|0);
            $425 = HEAP32[$424>>2]|0;
            $426 = ($425|0)==($423|0);
            do {
             if (!($426)) {
              HEAP32[$424>>2] = $423;
              $427 = ($423|0)==(0|0);
              if (!($427)) {
               $428 = ((($423)) + 8|0);
               $429 = HEAP32[$428>>2]|0;HEAP32[$428>>2] = (($429+1)|0);
              }
              $430 = ($425|0)==(0|0);
              if ($430) {
               break;
              }
              $431 = ((($425)) + 8|0);
              $432 = HEAP32[$431>>2]|0;HEAP32[$431>>2] = (($432-1)|0);
              $433 = ($432|0)==(1);
              if (!($433)) {
               break;
              }
              __THREW__ = 0;
              invoke_viii(3262,($425|0),1,1);
              $434 = __THREW__; __THREW__ = 0;
              $435 = $434&1;
              if ($435) {
               break L131;
              }
             }
            } while(0);
            $436 = HEAP32[$408>>2]|0;
            $437 = HEAP32[$11>>2]|0;
            $438 = ((($437)) + 12|0);
            $439 = HEAP32[$438>>2]|0;
            $440 = ((($436)) + 8|0);
            HEAP32[$440>>2] = $439;
            $$sroa$0258$0354 = HEAP32[$41>>2]|0;
            $441 = $$sroa$0258$0354;
            $442 = ($441|0)==($1|0);
            if ($442) {
             break;
            }
            $443 = ((($0)) + 124|0);
            $444 = ((($0)) + 128|0);
            $445 = ((($0)) + 120|0);
            $$sroa$0258$0355 = $$sroa$0258$0354;$545 = $441;
            L194: while(1) {
             $446 = $$sroa$0258$0355;
             $447 = ((($446)) + 8|0);
             $448 = HEAP32[$447>>2]|0;
             $449 = HEAP32[$448>>2]|0;
             $450 = ((($449)) + 140|0);
             $451 = HEAP32[$450>>2]|0;
             __THREW__ = 0;
             $452 = (invoke_ii($451|0,($448|0))|0);
             $453 = __THREW__; __THREW__ = 0;
             $454 = $453&1;
             if ($454) {
              label = 147;
              break;
             }
             $455 = ($452|0)==(0|0);
             if (!($455)) {
              $458 = HEAP32[$408>>2]|0;
              $459 = HEAP32[$458>>2]|0;
              $460 = ((($459)) + 76|0);
              $461 = HEAP32[$460>>2]|0;
              __THREW__ = 0;
              invoke_vi($461|0,($458|0));
              $462 = __THREW__; __THREW__ = 0;
              $463 = $462&1;
              if ($463) {
               label = 171;
               break;
              }
              $464 = HEAP32[$408>>2]|0;
              __THREW__ = 0;
              invoke_vii(3400,($464|0),($452|0));
              $465 = __THREW__; __THREW__ = 0;
              $466 = $465&1;
              if ($466) {
               label = 171;
               break;
              }
              $467 = HEAP32[$411>>2]|0;
              __THREW__ = 0;
              $468 = (invoke_ii(3279,($467|0))|0);
              $469 = __THREW__; __THREW__ = 0;
              $470 = $469&1;
              if ($470) {
               label = 171;
               break;
              }
              $471 = HEAP32[$468>>2]|0;
              $472 = ((($471)) + 188|0);
              $473 = HEAP32[$472>>2]|0;
              $474 = HEAP32[$408>>2]|0;
              __THREW__ = 0;
              invoke_vii($473|0,($468|0),($474|0));
              $475 = __THREW__; __THREW__ = 0;
              $476 = $475&1;
              if ($476) {
               label = 171;
               break;
              }
              $477 = HEAP32[$444>>2]|0;
              $478 = HEAP32[$443>>2]|0;
              $479 = ($477|0)==($478|0);
              $480 = $478;
              if ($479) {
               $835 = $480;$836 = $477;$837 = $477;
              } else {
               $$0166346 = 0;$490 = $480;$838 = $480;$839 = $478;$840 = $477;
               while(1) {
                $489 = (((($490) + (($$0166346*272)|0)|0)) + 4|0);
                $491 = HEAP32[$489>>2]|0;
                $492 = ($491|0)==(0|0);
                do {
                 if ($492) {
                  $505 = $839;$506 = $840;$844 = $838;
                 } else {
                  $493 = (((($490) + (($$0166346*272)|0)|0)) + 264|0);
                  $494 = HEAP8[$493>>0]|0;
                  $495 = ($494<<24>>24)==(0);
                  if (!($495)) {
                   $505 = $839;$506 = $840;$844 = $838;
                   break;
                  }
                  $496 = HEAP32[$491>>2]|0;
                  $497 = ((($496)) + 188|0);
                  $498 = HEAP32[$497>>2]|0;
                  $499 = HEAP32[$408>>2]|0;
                  __THREW__ = 0;
                  invoke_vii($498|0,($491|0),($499|0));
                  $500 = __THREW__; __THREW__ = 0;
                  $501 = $500&1;
                  if ($501) {
                   label = 171;
                   break L194;
                  }
                  $$pre386 = HEAP32[$444>>2]|0;
                  $$pre387 = HEAP32[$443>>2]|0;
                  $502 = $$pre387;
                  $505 = $$pre387;$506 = $$pre386;$844 = $502;
                 }
                } while(0);
                $503 = (($$0166346) + 1)|0;
                $504 = (($506) - ($505))|0;
                $507 = (($504|0) / 272)&-1;
                $508 = ($503>>>0)<($507>>>0);
                $509 = $505;
                if ($508) {
                 $$0166346 = $503;$490 = $509;$838 = $844;$839 = $505;$840 = $506;
                } else {
                 $835 = $844;$836 = $505;$837 = $506;
                 break;
                }
               }
              }
              $481 = HEAP32[$408>>2]|0;
              $482 = ((($481)) + 16|0);
              $483 = HEAP32[$482>>2]|0;
              HEAP32[$482>>2] = 0;
              $484 = HEAP32[$445>>2]|0;
              $485 = ($484|0)==(0|0);
              do {
               if ($485) {
                $486 = $837;$488 = $836;$841 = $835;
               } else {
                $510 = ((($484)) + 92|0);
                $511 = HEAP32[$510>>2]|0;
                $512 = ($511|0)==(0|0);
                if ($512) {
                 $486 = $837;$488 = $836;$841 = $835;
                 break;
                }
                $513 = HEAP32[$484>>2]|0;
                $514 = ((($513)) + 188|0);
                $515 = HEAP32[$514>>2]|0;
                __THREW__ = 0;
                invoke_vii($515|0,($484|0),($481|0));
                $516 = __THREW__; __THREW__ = 0;
                $517 = $516&1;
                if ($517) {
                 label = 171;
                 break L194;
                }
                $$pre388 = HEAP32[$444>>2]|0;
                $$pre389 = HEAP32[$443>>2]|0;
                $518 = $$pre389;
                $486 = $$pre388;$488 = $$pre389;$841 = $518;
               }
              } while(0);
              $487 = ($486|0)==($488|0);
              if (!($487)) {
               $$0167350 = 0;$522 = $841;$842 = $488;$843 = $486;
               while(1) {
                $521 = (((($522) + (($$0167350*272)|0)|0)) + 4|0);
                $523 = HEAP32[$521>>2]|0;
                $524 = ($523|0)==(0|0);
                do {
                 if ($524) {
                  $539 = $842;$540 = $843;
                 } else {
                  $525 = (((($522) + (($$0167350*272)|0)|0)) + 264|0);
                  $526 = HEAP8[$525>>0]|0;
                  $527 = ($526<<24>>24)==(0);
                  if ($527) {
                   $539 = $842;$540 = $843;
                   break;
                  }
                  $528 = ((($523)) + 92|0);
                  $529 = HEAP32[$528>>2]|0;
                  $530 = ($529|0)==(0|0);
                  if ($530) {
                   $539 = $842;$540 = $843;
                   break;
                  }
                  $531 = HEAP32[$523>>2]|0;
                  $532 = ((($531)) + 188|0);
                  $533 = HEAP32[$532>>2]|0;
                  $534 = HEAP32[$408>>2]|0;
                  __THREW__ = 0;
                  invoke_vii($533|0,($523|0),($534|0));
                  $535 = __THREW__; __THREW__ = 0;
                  $536 = $535&1;
                  if ($536) {
                   label = 171;
                   break L194;
                  }
                  $$pre391 = HEAP32[$444>>2]|0;
                  $$pre392 = HEAP32[$443>>2]|0;
                  $539 = $$pre392;$540 = $$pre391;
                 }
                } while(0);
                $537 = (($$0167350) + 1)|0;
                $538 = (($540) - ($539))|0;
                $541 = (($538|0) / 272)&-1;
                $542 = ($537>>>0)<($541>>>0);
                $543 = $539;
                if ($542) {
                 $$0167350 = $537;$522 = $543;$842 = $539;$843 = $540;
                } else {
                 break;
                }
               }
              }
              $519 = HEAP32[$408>>2]|0;
              $520 = ((($519)) + 16|0);
              HEAP32[$520>>2] = $483;
             }
             $544 = ((($545)) + 4|0);
             $$sroa$0258$0 = HEAP32[$544>>2]|0;
             $546 = $$sroa$0258$0;
             $547 = ($546|0)==($1|0);
             if ($547) {
              break L180;
             } else {
              $$sroa$0258$0355 = $$sroa$0258$0;$545 = $546;
             }
            }
            if ((label|0) == 147) {
             $456 = ___cxa_find_matching_catch_2()|0;
             $457 = tempRet0;
             $$23 = $456;$$23159 = $457;
             break L8;
            }
            else if ((label|0) == 171) {
             $548 = ___cxa_find_matching_catch_2()|0;
             $549 = tempRet0;
             $$23 = $548;$$23159 = $549;
             break L8;
            }
           }
          }
         } while(0);
         $$sroa$0250$0343 = HEAP32[$41>>2]|0;
         $418 = $$sroa$0250$0343;
         $419 = ($418|0)==($1|0);
         do {
          if ($419) {
           $$sroa$0234$0334 = $$sroa$0250$0343;
          } else {
           $420 = ((($0)) + 188|0);
           $421 = ((($0)) + 184|0);
           $$sroa$0250$0344 = $$sroa$0250$0343;$559 = $418;
           L234: while(1) {
            $553 = $$sroa$0250$0344;
            $554 = ((($553)) + 8|0);
            $555 = HEAP32[$554>>2]|0;
            $$sroa$0242$0337 = HEAP32[$420>>2]|0;
            $556 = $$sroa$0242$0337;
            $557 = ($556|0)==($421|0);
            if (!($557)) {
             $$sroa$0242$0338 = $$sroa$0242$0337;$572 = $556;
             while(1) {
              $562 = $$sroa$0242$0338;
              $563 = ((($562)) + 8|0);
              $564 = HEAP32[$563>>2]|0;
              $565 = HEAP32[$564>>2]|0;
              $566 = ((($565)) + 64|0);
              $567 = HEAP32[$566>>2]|0;
              $568 = HEAP32[$408>>2]|0;
              __THREW__ = 0;
              (invoke_iiiii($567|0,($564|0),($555|0),(0|0),($568|0))|0);
              $569 = __THREW__; __THREW__ = 0;
              $570 = $569&1;
              if ($570) {
               label = 179;
               break L234;
              }
              $571 = ((($572)) + 4|0);
              $$sroa$0242$0 = HEAP32[$571>>2]|0;
              $573 = $$sroa$0242$0;
              $574 = ($573|0)==($421|0);
              if ($574) {
               break;
              } else {
               $$sroa$0242$0338 = $$sroa$0242$0;$572 = $573;
              }
             }
            }
            $558 = ((($559)) + 4|0);
            $$sroa$0250$0 = HEAP32[$558>>2]|0;
            $560 = $$sroa$0250$0;
            $561 = ($560|0)==($1|0);
            if ($561) {
             label = 172;
             break;
            } else {
             $$sroa$0250$0344 = $$sroa$0250$0;$559 = $560;
            }
           }
           if ((label|0) == 172) {
            $$sroa$0234$0334$pre = HEAP32[$41>>2]|0;
            $$sroa$0234$0334 = $$sroa$0234$0334$pre;
            break;
           }
           else if ((label|0) == 179) {
            $575 = ___cxa_find_matching_catch_2()|0;
            $576 = tempRet0;
            $$23 = $575;$$23159 = $576;
            break L8;
           }
          }
         } while(0);
         $550 = $$sroa$0234$0334;
         $551 = ($550|0)==($1|0);
         L245: do {
          if (!($551)) {
           $552 = ((($0)) + 180|0);
           $$sroa$0234$0335 = $$sroa$0234$0334;$596 = $550;
           L247: while(1) {
            $583 = $$sroa$0234$0335;
            $584 = ((($583)) + 8|0);
            $585 = HEAP32[$584>>2]|0;
            $586 = ($585|0)==(0|0);
            do {
             if (!($586)) {
              $587 = HEAP32[$552>>2]|0;
              $588 = ($587|0)==(0|0);
              if ($588) {
               break;
              }
              $589 = HEAP32[$587>>2]|0;
              $590 = ((($589)) + 64|0);
              $591 = HEAP32[$590>>2]|0;
              $592 = HEAP32[$408>>2]|0;
              __THREW__ = 0;
              (invoke_iiiii($591|0,($587|0),($585|0),(0|0),($592|0))|0);
              $593 = __THREW__; __THREW__ = 0;
              $594 = $593&1;
              if ($594) {
               break L247;
              }
             }
            } while(0);
            $595 = ((($596)) + 4|0);
            $$sroa$0234$0 = HEAP32[$595>>2]|0;
            $597 = $$sroa$0234$0;
            $598 = ($597|0)==($1|0);
            if ($598) {
             break L245;
            } else {
             $$sroa$0234$0335 = $$sroa$0234$0;$596 = $597;
            }
           }
           $599 = ___cxa_find_matching_catch_2()|0;
           $600 = tempRet0;
           $$23 = $599;$$23159 = $600;
           break L8;
          }
         } while(0);
         $577 = HEAP32[$0>>2]|0;
         $578 = ((($577)) + 4|0);
         $579 = HEAP32[$578>>2]|0;
         __THREW__ = 0;
         $580 = (invoke_ii($579|0,($0|0))|0);
         $581 = __THREW__; __THREW__ = 0;
         $582 = $581&1;
         if ($582) {
          break;
         }
         $601 = ($580|0)==(0|0);
         if ($601) {
          break L11;
         }
         $602 = HEAP32[$0>>2]|0;
         $603 = ((($602)) + 4|0);
         $604 = HEAP32[$603>>2]|0;
         __THREW__ = 0;
         $605 = (invoke_ii($604|0,($0|0))|0);
         $606 = __THREW__; __THREW__ = 0;
         $607 = $606&1;
         if ($607) {
          break;
         }
         ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;
         $608 = ((($4)) + 11|0);
         HEAP8[$608>>0] = 5;
         ;HEAP8[$4>>0]=HEAP8[104154>>0]|0;HEAP8[$4+1>>0]=HEAP8[104154+1>>0]|0;HEAP8[$4+2>>0]=HEAP8[104154+2>>0]|0;HEAP8[$4+3>>0]=HEAP8[104154+3>>0]|0;HEAP8[$4+4>>0]=HEAP8[104154+4>>0]|0;
         $609 = ((($4)) + 5|0);
         HEAP8[$609>>0] = 0;
         $610 = ((($605)) + 24|0);
         $611 = HEAP32[$610>>2]|0;
         $612 = ((($611)) + 8|0);
         $613 = HEAP32[$612>>2]|0;
         __THREW__ = 0;
         (invoke_ii($613|0,($610|0))|0);
         $614 = __THREW__; __THREW__ = 0;
         $615 = $614&1;
         do {
          if ($615) {
           label = 220;
          } else {
           $616 = ((($605)) + 68|0);
           __THREW__ = 0;
           $617 = (invoke_iii(3391,($616|0),($4|0))|0);
           $618 = __THREW__; __THREW__ = 0;
           $619 = $618&1;
           if ($619) {
            $630 = ___cxa_find_matching_catch_2()|0;
            $631 = tempRet0;
            $632 = HEAP32[$610>>2]|0;
            $633 = ((($632)) + 12|0);
            $634 = HEAP32[$633>>2]|0;
            __THREW__ = 0;
            (invoke_ii($634|0,($610|0))|0);
            $635 = __THREW__; __THREW__ = 0;
            $636 = $635&1;
            if (!($636)) {
             $eh$lpad$body$index8Z2D = $631;$eh$lpad$body$indexZ2D = $630;
             break;
            }
            $637 = ___cxa_find_matching_catch_3(0|0)|0;
            $638 = tempRet0;
            ___clang_call_terminate($637);
            // unreachable;
           }
           $620 = ((($605)) + 72|0);
           $621 = ($617|0)==($620|0);
           if ($621) {
            $845 = 0;
           } else {
            $622 = ((($617)) + 28|0);
            $623 = HEAP8[$622>>0]|0;
            $624 = ($623<<24>>24)!=(0);
            $845 = $624;
           }
           $625 = HEAP32[$610>>2]|0;
           $626 = ((($625)) + 12|0);
           $627 = HEAP32[$626>>2]|0;
           __THREW__ = 0;
           (invoke_ii($627|0,($610|0))|0);
           $628 = __THREW__; __THREW__ = 0;
           $629 = $628&1;
           if ($629) {
            label = 220;
            break;
           }
           $639 = HEAP8[$608>>0]|0;
           $640 = ($639<<24>>24)<(0);
           if ($640) {
            $641 = HEAP32[$4>>2]|0;
            __ZdlPv($641);
           }
           if (!($845)) {
            break L11;
           }
           __THREW__ = 0;
           $642 = (invoke_i(3384)|0);
           $643 = __THREW__; __THREW__ = 0;
           $644 = $643&1;
           if ($644) {
            break L131;
           }
           $645 = $16;
           $646 = $645;
           $647 = HEAP32[$646>>2]|0;
           $648 = (($645) + 4)|0;
           $649 = $648;
           $650 = HEAP32[$649>>2]|0;
           __THREW__ = 0;
           $651 = (invoke_i(3384)|0);
           $652 = __THREW__; __THREW__ = 0;
           $653 = $652&1;
           if ($653) {
            break L131;
           }
           __THREW__ = 0;
           $654 = (invoke_ii(3385,($651|0))|0);
           $655 = tempRet0;
           $656 = __THREW__; __THREW__ = 0;
           $657 = $656&1;
           if ($657) {
            break L131;
           }
           $658 = ($655>>>0)>($650>>>0);
           $659 = ($654>>>0)>($647>>>0);
           $660 = ($655|0)==($650|0);
           $661 = $660 & $659;
           $662 = $658 | $661;
           if ($662) {
            $663 = (_i64Subtract(($654|0),($655|0),($647|0),($650|0))|0);
            $664 = tempRet0;
            $665 = (+($663>>>0)) + (4294967296.0*(+($664>>>0)));
            $$sink$i200 = $665;
           } else {
            $666 = (_i64Subtract(($647|0),($650|0),($654|0),($655|0))|0);
            $667 = tempRet0;
            $668 = (+($666>>>0)) + (4294967296.0*(+($667>>>0)));
            $669 = -$668;
            $$sink$i200 = $669;
           }
           $670 = ((($642)) + 8|0);
           $671 = +HEAPF64[$670>>3];
           $672 = $$sink$i200 * $671;
           $673 = HEAP32[$0>>2]|0;
           $674 = ((($673)) + 4|0);
           $675 = HEAP32[$674>>2]|0;
           __THREW__ = 0;
           $676 = (invoke_ii($675|0,($0|0))|0);
           $677 = __THREW__; __THREW__ = 0;
           $678 = $677&1;
           L279: do {
            if (!($678)) {
             $679 = HEAP32[$11>>2]|0;
             $680 = ((($679)) + 12|0);
             $681 = HEAP32[$680>>2]|0;
             ;HEAP32[$5>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;
             __THREW__ = 0;
             $682 = (invoke_ii(3276,32)|0);
             $683 = __THREW__; __THREW__ = 0;
             $684 = $683&1;
             do {
              if ($684) {
               $744 = ___cxa_find_matching_catch_2()|0;
               $745 = tempRet0;
               $$18 = $744;$$18154 = $745;
              } else {
               HEAP32[$5>>2] = $682;
               $685 = ((($5)) + 8|0);
               HEAP32[$685>>2] = -2147483616;
               $686 = ((($5)) + 4|0);
               HEAP32[$686>>2] = 26;
               dest=$682; src=104160; stop=dest+26|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
               $687 = ((($682)) + 26|0);
               HEAP8[$687>>0] = 0;
               __THREW__ = 0;
               (invoke_iiiid(3392,($676|0),($681|0),($5|0),(+$40))|0);
               $688 = __THREW__; __THREW__ = 0;
               $689 = $688&1;
               if ($689) {
                $746 = ___cxa_find_matching_catch_2()|0;
                $747 = tempRet0;
                $748 = ((($5)) + 11|0);
                $749 = HEAP8[$748>>0]|0;
                $750 = ($749<<24>>24)<(0);
                if (!($750)) {
                 $$18 = $746;$$18154 = $747;
                 break;
                }
                $751 = HEAP32[$5>>2]|0;
                __ZdlPv($751);
                $$18 = $746;$$18154 = $747;
                break;
               }
               $690 = ((($5)) + 11|0);
               $691 = HEAP8[$690>>0]|0;
               $692 = ($691<<24>>24)<(0);
               if ($692) {
                $693 = HEAP32[$5>>2]|0;
                __ZdlPv($693);
               }
               $694 = HEAP32[$0>>2]|0;
               $695 = ((($694)) + 4|0);
               $696 = HEAP32[$695>>2]|0;
               __THREW__ = 0;
               $697 = (invoke_ii($696|0,($0|0))|0);
               $698 = __THREW__; __THREW__ = 0;
               $699 = $698&1;
               if ($699) {
                break L279;
               }
               $700 = HEAP32[$11>>2]|0;
               $701 = ((($700)) + 12|0);
               $702 = HEAP32[$701>>2]|0;
               ;HEAP32[$6>>2]=0|0;HEAP32[$6+4>>2]=0|0;HEAP32[$6+8>>2]=0|0;
               __THREW__ = 0;
               $703 = (invoke_ii(3276,32)|0);
               $704 = __THREW__; __THREW__ = 0;
               $705 = $704&1;
               do {
                if ($705) {
                 $752 = ___cxa_find_matching_catch_2()|0;
                 $753 = tempRet0;
                 $$19 = $752;$$19155 = $753;
                } else {
                 HEAP32[$6>>2] = $703;
                 $706 = ((($6)) + 8|0);
                 HEAP32[$706>>2] = -2147483616;
                 $707 = ((($6)) + 4|0);
                 HEAP32[$707>>2] = 24;
                 dest=$703; src=104187; stop=dest+24|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                 $708 = ((($703)) + 24|0);
                 HEAP8[$708>>0] = 0;
                 __THREW__ = 0;
                 (invoke_iiiid(3392,($697|0),($702|0),($6|0),(+$672))|0);
                 $709 = __THREW__; __THREW__ = 0;
                 $710 = $709&1;
                 if ($710) {
                  $754 = ___cxa_find_matching_catch_2()|0;
                  $755 = tempRet0;
                  $756 = ((($6)) + 11|0);
                  $757 = HEAP8[$756>>0]|0;
                  $758 = ($757<<24>>24)<(0);
                  if (!($758)) {
                   $$19 = $754;$$19155 = $755;
                   break;
                  }
                  $759 = HEAP32[$6>>2]|0;
                  __ZdlPv($759);
                  $$19 = $754;$$19155 = $755;
                  break;
                 }
                 $711 = ((($6)) + 11|0);
                 $712 = HEAP8[$711>>0]|0;
                 $713 = ($712<<24>>24)<(0);
                 if ($713) {
                  $714 = HEAP32[$6>>2]|0;
                  __ZdlPv($714);
                 }
                 $715 = HEAP32[$0>>2]|0;
                 $716 = ((($715)) + 4|0);
                 $717 = HEAP32[$716>>2]|0;
                 __THREW__ = 0;
                 $718 = (invoke_ii($717|0,($0|0))|0);
                 $719 = __THREW__; __THREW__ = 0;
                 $720 = $719&1;
                 if ($720) {
                  break L279;
                 }
                 $721 = HEAP32[$11>>2]|0;
                 $722 = ((($721)) + 12|0);
                 $723 = HEAP32[$722>>2]|0;
                 ;HEAP32[$7>>2]=0|0;HEAP32[$7+4>>2]=0|0;HEAP32[$7+8>>2]=0|0;
                 __THREW__ = 0;
                 $724 = (invoke_ii(3276,32)|0);
                 $725 = __THREW__; __THREW__ = 0;
                 $726 = $725&1;
                 do {
                  if ($726) {
                   $760 = ___cxa_find_matching_catch_2()|0;
                   $761 = tempRet0;
                   $$20 = $760;$$20156 = $761;
                  } else {
                   HEAP32[$7>>2] = $724;
                   $727 = ((($7)) + 8|0);
                   HEAP32[$727>>2] = -2147483616;
                   $728 = ((($7)) + 4|0);
                   HEAP32[$728>>2] = 26;
                   dest=$724; src=104212; stop=dest+26|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                   $729 = ((($724)) + 26|0);
                   HEAP8[$729>>0] = 0;
                   $730 = $672 - $40;
                   __THREW__ = 0;
                   (invoke_iiiid(3392,($718|0),($723|0),($7|0),(+$730))|0);
                   $731 = __THREW__; __THREW__ = 0;
                   $732 = $731&1;
                   if ($732) {
                    $762 = ___cxa_find_matching_catch_2()|0;
                    $763 = tempRet0;
                    $764 = ((($7)) + 11|0);
                    $765 = HEAP8[$764>>0]|0;
                    $766 = ($765<<24>>24)<(0);
                    if (!($766)) {
                     $$20 = $762;$$20156 = $763;
                     break;
                    }
                    $767 = HEAP32[$7>>2]|0;
                    __ZdlPv($767);
                    $$20 = $762;$$20156 = $763;
                    break;
                   }
                   $733 = ((($7)) + 11|0);
                   $734 = HEAP8[$733>>0]|0;
                   $735 = ($734<<24>>24)<(0);
                   if ($735) {
                    $736 = HEAP32[$7>>2]|0;
                    __ZdlPv($736);
                   }
                   break L11;
                  }
                 } while(0);
                 $$23 = $$20;$$23159 = $$20156;
                 break L8;
                }
               } while(0);
               $$23 = $$19;$$23159 = $$19155;
               break L8;
              }
             } while(0);
             $$23 = $$18;$$23159 = $$18154;
             break L8;
            }
           } while(0);
           $742 = ___cxa_find_matching_catch_2()|0;
           $743 = tempRet0;
           $$23 = $742;$$23159 = $743;
           break L8;
          }
         } while(0);
         if ((label|0) == 220) {
          $737 = ___cxa_find_matching_catch_2()|0;
          $738 = tempRet0;
          $eh$lpad$body$index8Z2D = $738;$eh$lpad$body$indexZ2D = $737;
         }
         $739 = HEAP8[$608>>0]|0;
         $740 = ($739<<24>>24)<(0);
         if ($740) {
          $741 = HEAP32[$4>>2]|0;
          __ZdlPv($741);
         }
         $$23 = $eh$lpad$body$indexZ2D;$$23159 = $eh$lpad$body$index8Z2D;
         break L8;
        }
       }
      } while(0);
      $337 = ___cxa_find_matching_catch_2()|0;
      $338 = tempRet0;
      $$23 = $337;$$23159 = $338;
      break L8;
     }
    } while(0);
    $768 = HEAP32[$2>>2]|0;
    $769 = ($768|0)==(0|0);
    if (!($769)) {
     $770 = HEAP32[$43>>2]|0;
     $771 = ($770|0)==($768|0);
     if (!($771)) {
      $scevgep$i$i$i176 = ((($770)) + -4|0);
      $772 = $scevgep$i$i$i176;
      $773 = $768;
      $774 = (($772) - ($773))|0;
      $775 = $774 >>> 2;
      $776 = $775 ^ -1;
      $scevgep5$i$i$i177 = (($770) + ($776<<2)|0);
      HEAP32[$43>>2] = $scevgep5$i$i$i177;
     }
     __ZdlPv($768);
    }
    $777 = HEAP32[$42>>2]|0;
    $778 = ($777|0)==(0);
    L331: do {
     if (!($778)) {
      $779 = HEAP32[$41>>2]|0;
      $780 = HEAP32[$1>>2]|0;
      $781 = ((($780)) + 4|0);
      $782 = HEAP32[$781>>2]|0;
      $783 = HEAP32[$779>>2]|0;
      $784 = ((($783)) + 4|0);
      HEAP32[$784>>2] = $782;
      $785 = HEAP32[$781>>2]|0;
      HEAP32[$785>>2] = $783;
      HEAP32[$42>>2] = 0;
      $786 = ($779|0)==($1|0);
      if (!($786)) {
       $$023$i$i173 = $779;
       while(1) {
        $787 = ((($$023$i$i173)) + 4|0);
        $788 = HEAP32[$787>>2]|0;
        $789 = ((($$023$i$i173)) + 8|0);
        $790 = HEAP32[$789>>2]|0;
        $791 = ($790|0)==(0|0);
        if (!($791)) {
         $792 = ((($790)) + 8|0);
         $793 = HEAP32[$792>>2]|0;HEAP32[$792>>2] = (($793-1)|0);
         $794 = ($793|0)==(1);
         if ($794) {
          __THREW__ = 0;
          invoke_viii(3262,($790|0),1,1);
          $795 = __THREW__; __THREW__ = 0;
          $796 = $795&1;
          if ($796) {
           break;
          }
         }
        }
        __ZdlPv($$023$i$i173);
        $797 = ($788|0)==($1|0);
        if ($797) {
         break L331;
        } else {
         $$023$i$i173 = $788;
        }
       }
       $798 = ___cxa_find_matching_catch_2()|0;
       $799 = tempRet0;
       ___cxa_call_unexpected(($798|0));
       // unreachable;
      }
     }
    } while(0);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 8) {
  $54 = ___cxa_find_matching_catch_2()|0;
  $55 = tempRet0;
  $$23 = $54;$$23159 = $55;
 }
 $800 = HEAP32[$2>>2]|0;
 $801 = ($800|0)==(0|0);
 if (!($801)) {
  $802 = HEAP32[$43>>2]|0;
  $803 = ($802|0)==($800|0);
  if (!($803)) {
   $scevgep$i$i$i = ((($802)) + -4|0);
   $804 = $scevgep$i$i$i;
   $805 = $800;
   $806 = (($804) - ($805))|0;
   $807 = $806 >>> 2;
   $808 = $807 ^ -1;
   $scevgep5$i$i$i = (($802) + ($808<<2)|0);
   HEAP32[$43>>2] = $scevgep5$i$i$i;
  }
  __ZdlPv($800);
 }
 $809 = HEAP32[$42>>2]|0;
 $810 = ($809|0)==(0);
 if ($810) {
  ___resumeException($$23|0);
  // unreachable;
 }
 $811 = HEAP32[$41>>2]|0;
 $812 = HEAP32[$1>>2]|0;
 $813 = ((($812)) + 4|0);
 $814 = HEAP32[$813>>2]|0;
 $815 = HEAP32[$811>>2]|0;
 $816 = ((($815)) + 4|0);
 HEAP32[$816>>2] = $814;
 $817 = HEAP32[$813>>2]|0;
 HEAP32[$817>>2] = $815;
 HEAP32[$42>>2] = 0;
 $818 = ($811|0)==($1|0);
 if ($818) {
  ___resumeException($$23|0);
  // unreachable;
 } else {
  $$023$i$i = $811;
 }
 while(1) {
  $819 = ((($$023$i$i)) + 4|0);
  $820 = HEAP32[$819>>2]|0;
  $821 = ((($$023$i$i)) + 8|0);
  $822 = HEAP32[$821>>2]|0;
  $823 = ($822|0)==(0|0);
  if (!($823)) {
   $824 = ((($822)) + 8|0);
   $825 = HEAP32[$824>>2]|0;HEAP32[$824>>2] = (($825-1)|0);
   $826 = ($825|0)==(1);
   if ($826) {
    __THREW__ = 0;
    invoke_viii(3262,($822|0),1,1);
    $827 = __THREW__; __THREW__ = 0;
    $828 = $827&1;
    if ($828) {
     label = 260;
     break;
    }
   }
  }
  __ZdlPv($$023$i$i);
  $829 = ($820|0)==($1|0);
  if ($829) {
   label = 261;
   break;
  } else {
   $$023$i$i = $820;
  }
 }
 if ((label|0) == 260) {
  $830 = ___cxa_find_matching_catch_2()|0;
  $831 = tempRet0;
  ___cxa_call_unexpected(($830|0));
  // unreachable;
 }
 else if ((label|0) == 261) {
  ___resumeException($$23|0);
  // unreachable;
 }
}
function __ZN9osgViewer6Viewer15updateTraversalEv($0) {
 $0 = $0|0;
 var $$05075 = 0, $$076 = 0, $$1 = 0, $$147 = 0, $$pre = 0, $$pre80 = 0, $$pre81 = 0, $$pre82 = 0, $$pre83 = 0, $$pre84 = 0, $$sink$i = 0.0, $$sink$i65 = 0.0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0;
 var $160 = 0.0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0;
 var $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0;
 var $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0;
 var $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0.0, $229 = 0, $23 = 0, $230 = 0, $231 = 0.0;
 var $232 = 0.0, $233 = 0, $234 = 0.0, $235 = 0.0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0;
 var $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0;
 var $269 = 0, $27 = 0.0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0.0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0;
 var $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0.0, $300 = 0, $301 = 0, $302 = 0, $303 = 0;
 var $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0.0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0;
 var $33 = 0.0, $34 = 0.0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $1 = sp + 36|0;
 $2 = sp + 24|0;
 $3 = sp + 12|0;
 $4 = sp;
 $5 = ((($0)) + 5|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = ($6<<24>>24)==(0);
 if (!($7)) {
  STACKTOP = sp;return;
 }
 $8 = (__ZN3osg5Timer8instanceEv()|0);
 $9 = ((($0)) + 104|0);
 $10 = ((($0)) + 152|0);
 $11 = $10;
 $12 = $11;
 $13 = HEAP32[$12>>2]|0;
 $14 = (($11) + 4)|0;
 $15 = $14;
 $16 = HEAP32[$15>>2]|0;
 $17 = (__ZN3osg5Timer8instanceEv()|0);
 $18 = (__ZNK3osg5Timer4tickEv($17)|0);
 $19 = tempRet0;
 $20 = ($19>>>0)>($16>>>0);
 $21 = ($18>>>0)>($13>>>0);
 $22 = ($19|0)==($16|0);
 $23 = $22 & $21;
 $24 = $20 | $23;
 if ($24) {
  $25 = (_i64Subtract(($18|0),($19|0),($13|0),($16|0))|0);
  $26 = tempRet0;
  $27 = (+($25>>>0)) + (4294967296.0*(+($26>>>0)));
  $$sink$i = $27;
 } else {
  $28 = (_i64Subtract(($13|0),($16|0),($18|0),($19|0))|0);
  $29 = tempRet0;
  $30 = (+($28>>>0)) + (4294967296.0*(+($29>>>0)));
  $31 = -$30;
  $$sink$i = $31;
 }
 $32 = ((($8)) + 8|0);
 $33 = +HEAPF64[$32>>3];
 $34 = $$sink$i * $33;
 $35 = ((($0)) + 76|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = HEAP32[$36>>2]|0;
 $38 = ((($37)) + 76|0);
 $39 = HEAP32[$38>>2]|0;
 FUNCTION_TABLE_vi[$39 & 8191]($36);
 $40 = HEAP32[$35>>2]|0;
 $41 = ((($0)) + 136|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ((($40)) + 12|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = ($44|0)==($42|0);
 if (!($45)) {
  HEAP32[$43>>2] = $42;
  $46 = ($42|0)==(0|0);
  if (!($46)) {
   $47 = ((($42)) + 8|0);
   $48 = HEAP32[$47>>2]|0;HEAP32[$47>>2] = (($48+1)|0);
  }
  $49 = ($44|0)==(0|0);
  if (!($49)) {
   $50 = ((($44)) + 8|0);
   $51 = HEAP32[$50>>2]|0;HEAP32[$50>>2] = (($51-1)|0);
   $52 = ($51|0)==(1);
   if ($52) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($44,1,1);
   }
  }
 }
 $53 = HEAP32[$35>>2]|0;
 $54 = HEAP32[$41>>2]|0;
 $55 = ((($54)) + 12|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = ((($53)) + 8|0);
 HEAP32[$57>>2] = $56;
 $58 = ((($0)) + 172|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = HEAP32[$59>>2]|0;
 $61 = ((($60)) + 20|0);
 $62 = HEAP32[$61>>2]|0;
 FUNCTION_TABLE_vii[$62 & 8191]($59,$53);
 $63 = (__ZN5osgDB8Registry8instanceEb(0)|0);
 $64 = ((($63)) + 236|0);
 $65 = HEAP32[$64>>2]|0;
 $66 = ($65|0)==(0|0);
 if (!($66)) {
  $67 = (__ZN5osgDB8Registry8instanceEb(0)|0);
  $68 = ((($67)) + 236|0);
  $69 = HEAP32[$68>>2]|0;
  __ZN5osgDB18SharedStateManager5pruneEv($69);
 }
 $70 = (__ZN5osgDB8Registry8instanceEb(0)|0);
 $71 = HEAP32[$41>>2]|0;
 __ZN5osgDB8Registry53updateTimeStampOfObjectsInCacheWithExternalReferencesERKN3osg10FrameStampE($70,$71);
 $72 = (__ZN5osgDB8Registry8instanceEb(0)|0);
 $73 = HEAP32[$41>>2]|0;
 __ZN5osgDB8Registry27removeExpiredObjectsInCacheERKN3osg10FrameStampE($72,$73);
 $74 = ((($0)) + 72|0);
 $75 = HEAP32[$74>>2]|0;
 $76 = ($75|0)==(0|0);
 if (!($76)) {
  $77 = HEAP32[$0>>2]|0;
  $78 = ((($77)) + -12|0);
  $79 = HEAP32[$78>>2]|0;
  $80 = (($0) + ($79)|0);
  __ZN3osg14OperationQueue13runOperationsEPNS_6ObjectE($75,$80);
 }
 $81 = ((($0)) + 88|0);
 $82 = HEAP32[$81>>2]|0;
 $83 = ($82|0)==(0|0);
 if (!($83)) {
  $84 = HEAP32[$41>>2]|0;
  __ZN7osgUtil27IncrementalCompileOperation22mergeCompiledSubgraphsEPKN3osg10FrameStampE($82,$84);
 }
 $85 = ((($0)) + 124|0);
 $86 = ((($0)) + 128|0);
 $87 = HEAP32[$86>>2]|0;
 $88 = HEAP32[$85>>2]|0;
 $89 = ($87|0)==($88|0);
 $90 = $88;
 if ($89) {
  $311 = $90;$312 = $87;$313 = $87;
 } else {
  $$076 = 0;$314 = $90;$315 = $88;$316 = $87;$98 = $90;
  while(1) {
   $97 = (((($98) + (($$076*272)|0)|0)) + 4|0);
   $99 = HEAP32[$97>>2]|0;
   $100 = ($99|0)==(0|0);
   if ($100) {
    $111 = $315;$112 = $316;$318 = $314;
   } else {
    $101 = (((($98) + (($$076*272)|0)|0)) + 264|0);
    $102 = HEAP8[$101>>0]|0;
    $103 = ($102<<24>>24)==(0);
    if ($103) {
     $104 = HEAP32[$99>>2]|0;
     $105 = ((($104)) + 188|0);
     $106 = HEAP32[$105>>2]|0;
     $107 = HEAP32[$35>>2]|0;
     FUNCTION_TABLE_vii[$106 & 8191]($99,$107);
     $$pre = HEAP32[$86>>2]|0;
     $$pre80 = HEAP32[$85>>2]|0;
     $108 = $$pre80;
     $111 = $$pre80;$112 = $$pre;$318 = $108;
    } else {
     $111 = $315;$112 = $316;$318 = $314;
    }
   }
   $109 = (($$076) + 1)|0;
   $110 = (($112) - ($111))|0;
   $113 = (($110|0) / 272)&-1;
   $114 = ($109>>>0)<($113>>>0);
   $115 = $111;
   if ($114) {
    $$076 = $109;$314 = $318;$315 = $111;$316 = $112;$98 = $115;
   } else {
    $311 = $318;$312 = $111;$313 = $112;
    break;
   }
  }
 }
 $91 = HEAP32[$35>>2]|0;
 $92 = ((($91)) + 16|0);
 $93 = HEAP32[$92>>2]|0;
 HEAP32[$92>>2] = 0;
 $94 = ((($0)) + 120|0);
 $95 = HEAP32[$94>>2]|0;
 $96 = ($95|0)==(0|0);
 if ($96) {
  $123 = $313;$125 = $312;$317 = $311;
 } else {
  $116 = ((($95)) + 84|0);
  $117 = HEAP32[$116>>2]|0;
  $118 = ($117|0)==(0|0);
  if ($118) {
   $123 = $313;$125 = $312;$317 = $311;
  } else {
   $119 = HEAP32[$95>>2]|0;
   $120 = ((($119)) + 188|0);
   $121 = HEAP32[$120>>2]|0;
   FUNCTION_TABLE_vii[$121 & 8191]($95,$91);
   $$pre81 = HEAP32[$86>>2]|0;
   $$pre82 = HEAP32[$85>>2]|0;
   $122 = $$pre82;
   $123 = $$pre81;$125 = $$pre82;$317 = $122;
  }
 }
 $124 = ($123|0)==($125|0);
 if (!($124)) {
  $$05075 = 0;$132 = $317;$319 = $125;$320 = $123;
  while(1) {
   $131 = (((($132) + (($$05075*272)|0)|0)) + 4|0);
   $133 = HEAP32[$131>>2]|0;
   $134 = ($133|0)==(0|0);
   if ($134) {
    $147 = $319;$148 = $320;
   } else {
    $135 = (((($132) + (($$05075*272)|0)|0)) + 264|0);
    $136 = HEAP8[$135>>0]|0;
    $137 = ($136<<24>>24)==(0);
    if ($137) {
     $147 = $319;$148 = $320;
    } else {
     $138 = ((($133)) + 84|0);
     $139 = HEAP32[$138>>2]|0;
     $140 = ($139|0)==(0|0);
     if ($140) {
      $147 = $319;$148 = $320;
     } else {
      $141 = HEAP32[$133>>2]|0;
      $142 = ((($141)) + 188|0);
      $143 = HEAP32[$142>>2]|0;
      $144 = HEAP32[$35>>2]|0;
      FUNCTION_TABLE_vii[$143 & 8191]($133,$144);
      $$pre83 = HEAP32[$86>>2]|0;
      $$pre84 = HEAP32[$85>>2]|0;
      $147 = $$pre84;$148 = $$pre83;
     }
    }
   }
   $145 = (($$05075) + 1)|0;
   $146 = (($148) - ($147))|0;
   $149 = (($146|0) / 272)&-1;
   $150 = ($145>>>0)<($149>>>0);
   $151 = $147;
   if ($150) {
    $$05075 = $145;$132 = $151;$319 = $147;$320 = $148;
   } else {
    break;
   }
  }
 }
 $126 = HEAP32[$35>>2]|0;
 $127 = ((($126)) + 16|0);
 HEAP32[$127>>2] = $93;
 $128 = ((($0)) + 180|0);
 $129 = HEAP32[$128>>2]|0;
 $130 = ($129|0)==(0|0);
 if (!($130)) {
  $152 = HEAP32[$129>>2]|0;
  $153 = ((($152)) + 104|0);
  $154 = HEAP32[$153>>2]|0;
  $155 = (FUNCTION_TABLE_ii[$154 & 8191]($129)|0);
  $156 = HEAP32[$128>>2]|0;
  $157 = HEAP32[$156>>2]|0;
  $158 = ((($157)) + 108|0);
  $159 = HEAP32[$158>>2]|0;
  $160 = (+FUNCTION_TABLE_di[$159 & 8191]($156));
  $161 = ((($0)) + 224|0);
  HEAP32[$161>>2] = $155;
  $162 = ((($0)) + 228|0);
  HEAPF32[$162>>2] = $160;
  $163 = HEAP32[$128>>2]|0;
  $164 = HEAP32[$163>>2]|0;
  $165 = ((($164)) + 100|0);
  $166 = HEAP32[$165>>2]|0;
  $167 = HEAP32[$94>>2]|0;
  FUNCTION_TABLE_vii[$166 & 8191]($163,$167);
 }
 __ZN3osg4View12updateSlavesEv($9);
 $168 = HEAP32[$0>>2]|0;
 $169 = ((($168)) + 4|0);
 $170 = HEAP32[$169>>2]|0;
 $171 = (FUNCTION_TABLE_ii[$170 & 8191]($0)|0);
 $172 = ($171|0)==(0|0);
 if ($172) {
  STACKTOP = sp;return;
 }
 $173 = HEAP32[$0>>2]|0;
 $174 = ((($173)) + 4|0);
 $175 = HEAP32[$174>>2]|0;
 $176 = (FUNCTION_TABLE_ii[$175 & 8191]($0)|0);
 ;HEAP32[$1>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;
 $177 = ((($1)) + 11|0);
 HEAP8[$177>>0] = 6;
 ;HEAP8[$1>>0]=HEAP8[105415>>0]|0;HEAP8[$1+1>>0]=HEAP8[105415+1>>0]|0;HEAP8[$1+2>>0]=HEAP8[105415+2>>0]|0;HEAP8[$1+3>>0]=HEAP8[105415+3>>0]|0;HEAP8[$1+4>>0]=HEAP8[105415+4>>0]|0;HEAP8[$1+5>>0]=HEAP8[105415+5>>0]|0;
 $178 = ((($1)) + 6|0);
 HEAP8[$178>>0] = 0;
 $179 = ((($176)) + 24|0);
 $180 = HEAP32[$179>>2]|0;
 $181 = ((($180)) + 8|0);
 $182 = HEAP32[$181>>2]|0;
 __THREW__ = 0;
 (invoke_ii($182|0,($179|0))|0);
 $183 = __THREW__; __THREW__ = 0;
 $184 = $183&1;
 do {
  if ($184) {
   label = 57;
  } else {
   $185 = ((($176)) + 68|0);
   __THREW__ = 0;
   $186 = (invoke_iii(3391,($185|0),($1|0))|0);
   $187 = __THREW__; __THREW__ = 0;
   $188 = $187&1;
   if ($188) {
    $199 = ___cxa_find_matching_catch_2()|0;
    $200 = tempRet0;
    $201 = HEAP32[$179>>2]|0;
    $202 = ((($201)) + 12|0);
    $203 = HEAP32[$202>>2]|0;
    __THREW__ = 0;
    (invoke_ii($203|0,($179|0))|0);
    $204 = __THREW__; __THREW__ = 0;
    $205 = $204&1;
    if (!($205)) {
     $eh$lpad$body$index2Z2D = $200;$eh$lpad$body$indexZ2D = $199;
     break;
    }
    $206 = ___cxa_find_matching_catch_3(0|0)|0;
    $207 = tempRet0;
    ___clang_call_terminate($206);
    // unreachable;
   }
   $189 = ((($176)) + 72|0);
   $190 = ($186|0)==($189|0);
   if ($190) {
    $321 = 0;
   } else {
    $191 = ((($186)) + 28|0);
    $192 = HEAP8[$191>>0]|0;
    $193 = ($192<<24>>24)!=(0);
    $321 = $193;
   }
   $194 = HEAP32[$179>>2]|0;
   $195 = ((($194)) + 12|0);
   $196 = HEAP32[$195>>2]|0;
   __THREW__ = 0;
   (invoke_ii($196|0,($179|0))|0);
   $197 = __THREW__; __THREW__ = 0;
   $198 = $197&1;
   if ($198) {
    label = 57;
   } else {
    $208 = HEAP8[$177>>0]|0;
    $209 = ($208<<24>>24)<(0);
    if ($209) {
     $210 = HEAP32[$1>>2]|0;
     __ZdlPv($210);
    }
    if (!($321)) {
     STACKTOP = sp;return;
    }
    $211 = (__ZN3osg5Timer8instanceEv()|0);
    $212 = $10;
    $213 = $212;
    $214 = HEAP32[$213>>2]|0;
    $215 = (($212) + 4)|0;
    $216 = $215;
    $217 = HEAP32[$216>>2]|0;
    $218 = (__ZN3osg5Timer8instanceEv()|0);
    $219 = (__ZNK3osg5Timer4tickEv($218)|0);
    $220 = tempRet0;
    $221 = ($220>>>0)>($217>>>0);
    $222 = ($219>>>0)>($214>>>0);
    $223 = ($220|0)==($217|0);
    $224 = $223 & $222;
    $225 = $221 | $224;
    if ($225) {
     $226 = (_i64Subtract(($219|0),($220|0),($214|0),($217|0))|0);
     $227 = tempRet0;
     $228 = (+($226>>>0)) + (4294967296.0*(+($227>>>0)));
     $$sink$i65 = $228;
    } else {
     $229 = (_i64Subtract(($214|0),($217|0),($219|0),($220|0))|0);
     $230 = tempRet0;
     $231 = (+($229>>>0)) + (4294967296.0*(+($230>>>0)));
     $232 = -$231;
     $$sink$i65 = $232;
    }
    $233 = ((($211)) + 8|0);
    $234 = +HEAPF64[$233>>3];
    $235 = $$sink$i65 * $234;
    $236 = HEAP32[$0>>2]|0;
    $237 = ((($236)) + 4|0);
    $238 = HEAP32[$237>>2]|0;
    $239 = (FUNCTION_TABLE_ii[$238 & 8191]($0)|0);
    $240 = HEAP32[$41>>2]|0;
    $241 = ((($240)) + 12|0);
    $242 = HEAP32[$241>>2]|0;
    $243 = (__Znwj(32)|0);
    HEAP32[$2>>2] = $243;
    $244 = ((($2)) + 8|0);
    HEAP32[$244>>2] = -2147483616;
    $245 = ((($2)) + 4|0);
    HEAP32[$245>>2] = 27;
    dest=$243; src=104072; stop=dest+27|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
    $246 = ((($243)) + 27|0);
    HEAP8[$246>>0] = 0;
    __THREW__ = 0;
    (invoke_iiiid(3392,($239|0),($242|0),($2|0),(+$34))|0);
    $247 = __THREW__; __THREW__ = 0;
    $248 = $247&1;
    if ($248) {
     $293 = ___cxa_find_matching_catch_2()|0;
     $294 = tempRet0;
     $295 = ((($2)) + 11|0);
     $296 = HEAP8[$295>>0]|0;
     $297 = ($296<<24>>24)<(0);
     if ($297) {
      $298 = HEAP32[$2>>2]|0;
      __ZdlPv($298);
     }
     $$1 = $294;$$147 = $293;
     ___resumeException($$147|0);
     // unreachable;
    }
    $249 = ((($2)) + 11|0);
    $250 = HEAP8[$249>>0]|0;
    $251 = ($250<<24>>24)<(0);
    if ($251) {
     $252 = HEAP32[$2>>2]|0;
     __ZdlPv($252);
    }
    $253 = HEAP32[$0>>2]|0;
    $254 = ((($253)) + 4|0);
    $255 = HEAP32[$254>>2]|0;
    $256 = (FUNCTION_TABLE_ii[$255 & 8191]($0)|0);
    $257 = HEAP32[$41>>2]|0;
    $258 = ((($257)) + 12|0);
    $259 = HEAP32[$258>>2]|0;
    $260 = (__Znwj(32)|0);
    HEAP32[$3>>2] = $260;
    $261 = ((($3)) + 8|0);
    HEAP32[$261>>2] = -2147483616;
    $262 = ((($3)) + 4|0);
    HEAP32[$262>>2] = 25;
    dest=$260; src=104100; stop=dest+25|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
    $263 = ((($260)) + 25|0);
    HEAP8[$263>>0] = 0;
    __THREW__ = 0;
    (invoke_iiiid(3392,($256|0),($259|0),($3|0),(+$235))|0);
    $264 = __THREW__; __THREW__ = 0;
    $265 = $264&1;
    if ($265) {
     $299 = ___cxa_find_matching_catch_2()|0;
     $300 = tempRet0;
     $301 = ((($3)) + 11|0);
     $302 = HEAP8[$301>>0]|0;
     $303 = ($302<<24>>24)<(0);
     if ($303) {
      $304 = HEAP32[$3>>2]|0;
      __ZdlPv($304);
     }
     $$1 = $300;$$147 = $299;
     ___resumeException($$147|0);
     // unreachable;
    }
    $266 = ((($3)) + 11|0);
    $267 = HEAP8[$266>>0]|0;
    $268 = ($267<<24>>24)<(0);
    if ($268) {
     $269 = HEAP32[$3>>2]|0;
     __ZdlPv($269);
    }
    $270 = HEAP32[$0>>2]|0;
    $271 = ((($270)) + 4|0);
    $272 = HEAP32[$271>>2]|0;
    $273 = (FUNCTION_TABLE_ii[$272 & 8191]($0)|0);
    $274 = HEAP32[$41>>2]|0;
    $275 = ((($274)) + 12|0);
    $276 = HEAP32[$275>>2]|0;
    $277 = (__Znwj(32)|0);
    HEAP32[$4>>2] = $277;
    $278 = ((($4)) + 8|0);
    HEAP32[$278>>2] = -2147483616;
    $279 = ((($4)) + 4|0);
    HEAP32[$279>>2] = 27;
    dest=$277; src=104126; stop=dest+27|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
    $280 = ((($277)) + 27|0);
    HEAP8[$280>>0] = 0;
    $281 = $235 - $34;
    __THREW__ = 0;
    (invoke_iiiid(3392,($273|0),($276|0),($4|0),(+$281))|0);
    $282 = __THREW__; __THREW__ = 0;
    $283 = $282&1;
    if ($283) {
     $305 = ___cxa_find_matching_catch_2()|0;
     $306 = tempRet0;
     $307 = ((($4)) + 11|0);
     $308 = HEAP8[$307>>0]|0;
     $309 = ($308<<24>>24)<(0);
     if ($309) {
      $310 = HEAP32[$4>>2]|0;
      __ZdlPv($310);
     }
     $$1 = $306;$$147 = $305;
     ___resumeException($$147|0);
     // unreachable;
    } else {
     $284 = ((($4)) + 11|0);
     $285 = HEAP8[$284>>0]|0;
     $286 = ($285<<24>>24)<(0);
     if ($286) {
      $287 = HEAP32[$4>>2]|0;
      __ZdlPv($287);
     }
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 if ((label|0) == 57) {
  $288 = ___cxa_find_matching_catch_2()|0;
  $289 = tempRet0;
  $eh$lpad$body$index2Z2D = $289;$eh$lpad$body$indexZ2D = $288;
 }
 $290 = HEAP8[$177>>0]|0;
 $291 = ($290<<24>>24)<(0);
 if ($291) {
  $292 = HEAP32[$1>>2]|0;
  __ZdlPv($292);
 }
 $$1 = $eh$lpad$body$index2Z2D;$$147 = $eh$lpad$body$indexZ2D;
 ___resumeException($$147|0);
 // unreachable;
}
function __ZN9osgViewer6Viewer10getCamerasERNSt3__26vectorIPN3osg6CameraENS1_9allocatorIS5_EEEEb($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$pre = 0, $$pre17 = 0, $$pre18 = 0, $$sroa$07$014 = 0, $$sroa$07$014$us = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i = 0, $scevgep5$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp + 4|0;
 $4 = sp;
 $5 = HEAP32[$1>>2]|0;
 $6 = ((($1)) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==($5|0);
 if ($8) {
  $69 = $5;
 } else {
  $scevgep$i$i$i = ((($7)) + -4|0);
  $9 = $scevgep$i$i$i;
  $10 = $5;
  $11 = (($9) - ($10))|0;
  $12 = $11 >>> 2;
  $13 = $12 ^ -1;
  $scevgep5$i$i$i = (($7) + ($13<<2)|0);
  HEAP32[$6>>2] = $scevgep5$i$i$i;
  $69 = $scevgep5$i$i$i;
 }
 $14 = ((($0)) + 120|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0|0);
 do {
  if (!($16)) {
   $17 = $15;
   if ($2) {
    $18 = ((($15)) + 624|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = ($19|0)==(0|0);
    if ($20) {
     break;
    }
    $21 = HEAP32[$19>>2]|0;
    $22 = ((($21)) + 144|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = (FUNCTION_TABLE_ii[$23 & 8191]($19)|0);
    if (!($24)) {
     break;
    }
    $$pre = HEAP32[$14>>2]|0;
    $$pre17 = HEAP32[$6>>2]|0;
    $25 = $$pre;$28 = $$pre17;
   } else {
    $25 = $17;$28 = $69;
   }
   HEAP32[$3>>2] = $25;
   $26 = ((($1)) + 8|0);
   $27 = HEAP32[$26>>2]|0;
   $29 = ($28|0)==($27|0);
   if ($29) {
    __ZNSt3__26vectorIPN3osg6CameraENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_($1,$3);
   } else {
    HEAP32[$28>>2] = $25;
    $30 = HEAP32[$6>>2]|0;
    $31 = ((($30)) + 4|0);
    HEAP32[$6>>2] = $31;
   }
  }
 } while(0);
 $32 = ((($0)) + 124|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ((($0)) + 128|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = ($33|0)==($35|0);
 if ($36) {
  STACKTOP = sp;return;
 }
 $37 = ((($1)) + 8|0);
 if ($2) {
  $$sroa$07$014$us = $33;
 } else {
  $$sroa$07$014 = $33;$70 = $35;
  while(1) {
   $57 = ((($$sroa$07$014)) + 4|0);
   $58 = HEAP32[$57>>2]|0;
   $59 = ($58|0)==(0|0);
   $60 = $58;
   if ($59) {
    $68 = $70;
   } else {
    HEAP32[$4>>2] = $60;
    $61 = HEAP32[$6>>2]|0;
    $62 = HEAP32[$37>>2]|0;
    $63 = ($61|0)==($62|0);
    if ($63) {
     __ZNSt3__26vectorIPN3osg6CameraENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_($1,$4);
    } else {
     HEAP32[$61>>2] = $60;
     $64 = HEAP32[$6>>2]|0;
     $65 = ((($64)) + 4|0);
     HEAP32[$6>>2] = $65;
    }
    $$pre18 = HEAP32[$34>>2]|0;
    $68 = $$pre18;
   }
   $66 = ((($$sroa$07$014)) + 272|0);
   $67 = ($66|0)==($68|0);
   if ($67) {
    break;
   } else {
    $$sroa$07$014 = $66;$70 = $68;
   }
  }
  STACKTOP = sp;return;
 }
 while(1) {
  $38 = ((($$sroa$07$014$us)) + 4|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = ($39|0)==(0|0);
  if (!($40)) {
   $41 = ((($39)) + 624|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = ($42|0)==(0|0);
   if (!($43)) {
    $44 = HEAP32[$42>>2]|0;
    $45 = ((($44)) + 144|0);
    $46 = HEAP32[$45>>2]|0;
    $47 = (FUNCTION_TABLE_ii[$46 & 8191]($42)|0);
    if ($47) {
     $48 = HEAP32[$38>>2]|0;
     HEAP32[$4>>2] = $48;
     $49 = HEAP32[$6>>2]|0;
     $50 = HEAP32[$37>>2]|0;
     $51 = ($49|0)==($50|0);
     if ($51) {
      __ZNSt3__26vectorIPN3osg6CameraENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_($1,$4);
     } else {
      HEAP32[$49>>2] = $48;
      $52 = HEAP32[$6>>2]|0;
      $53 = ((($52)) + 4|0);
      HEAP32[$6>>2] = $53;
     }
    }
   }
  }
  $54 = ((($$sroa$07$014$us)) + 272|0);
  $55 = HEAP32[$34>>2]|0;
  $56 = ($54|0)==($55|0);
  if ($56) {
   break;
  } else {
   $$sroa$07$014$us = $54;
  }
 }
 STACKTOP = sp;return;
}
function __ZN9osgViewer6Viewer11getContextsERNSt3__26vectorIPN3osg15GraphicsContextENS1_9allocatorIS5_EEEEb($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$i$i$i$i = 0, $$0$i$i$i$i31 = 0, $$0$ph$i$i$i$i = 0, $$0$ph$i$i$i$i28 = 0, $$01765 = 0, $$024$i$i$i$i = 0, $$024$i$i$i$i30 = 0, $$025$i$i$i$i = 0, $$025$i$i$i$i33 = 0, $$036$i$i$i = 0, $$036$i$i$i32 = 0, $$2 = 0, $$220 = 0, $$in = 0, $$in$i$i$i$i = 0, $$in$i$i$i$i27 = 0, $$not = 0, $$not21 = 0, $$pre = 0, $$pre$i$i$i$i = 0;
 var $$pre$i$i$i$i36 = 0, $$pre$phi79Z2D = 0, $$pre$phiZ2D = 0, $$sink$be$i$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $brmerge = 0, $brmerge22 = 0, $scevgep$i$i$i = 0, $scevgep5$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $3 = sp + 8|0;
 $4 = sp + 4|0;
 $5 = sp;
 $6 = ((($3)) + 4|0);
 HEAP32[$6>>2] = 0;
 $7 = ((($3)) + 8|0);
 HEAP32[$7>>2] = 0;
 $8 = ((($3)) + 4|0);
 HEAP32[$3>>2] = $8;
 $9 = HEAP32[$1>>2]|0;
 $10 = ((($1)) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==($9|0);
 if (!($12)) {
  $scevgep$i$i$i = ((($11)) + -4|0);
  $13 = $scevgep$i$i$i;
  $14 = $9;
  $15 = (($13) - ($14))|0;
  $16 = $15 >>> 2;
  $17 = $16 ^ -1;
  $scevgep5$i$i$i = (($11) + ($17<<2)|0);
  HEAP32[$10>>2] = $scevgep5$i$i$i;
 }
 $18 = ((($0)) + 120|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)==(0|0);
 if (!($20)) {
  $27 = ((($19)) + 624|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = ($28|0)==(0|0);
  if (!($29)) {
   $30 = HEAP32[$28>>2]|0;
   $31 = ((($30)) + 144|0);
   $32 = HEAP32[$31>>2]|0;
   __THREW__ = 0;
   $33 = (invoke_ii($32|0,($28|0))|0);
   $34 = __THREW__; __THREW__ = 0;
   $35 = $34&1;
   if ($35) {
    $78 = ___cxa_find_matching_catch_2()|0;
    $79 = tempRet0;
    $$2 = $78;$$220 = $79;$$pre$phiZ2D = $8;
    $151 = HEAP32[$$pre$phiZ2D>>2]|0;
    __ZNSt3__26__treeIPN3osg15GraphicsContextENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($3,$151);
    ___resumeException($$2|0);
    // unreachable;
   }
   $$not = $2 ^ 1;
   $brmerge = $33 | $$not;
   if ($brmerge) {
    $36 = HEAP32[$18>>2]|0;
    $37 = ((($36)) + 624|0);
    $38 = HEAP32[$37>>2]|0;
    $39 = $38;
    $40 = HEAP32[$8>>2]|0;
    $41 = ($40|0)==(0|0);
    do {
     if ($41) {
      $$025$i$i$i$i33 = $8;$$036$i$i$i32 = $8;
     } else {
      $$0$i$i$i$i31 = $6;$$024$i$i$i$i30 = $40;
      while(1) {
       $42 = ((($$024$i$i$i$i30)) + 16|0);
       $43 = HEAP32[$42>>2]|0;
       $44 = ($38>>>0)<($43>>>0);
       if ($44) {
        $45 = HEAP32[$$024$i$i$i$i30>>2]|0;
        $46 = ($45|0)==(0|0);
        if ($46) {
         label = 14;
         break;
        } else {
         $$0$ph$i$i$i$i28 = $$024$i$i$i$i30;$$in$i$i$i$i27 = $45;
        }
       } else {
        $47 = ($43>>>0)<($38>>>0);
        if (!($47)) {
         label = 18;
         break;
        }
        $48 = ((($$024$i$i$i$i30)) + 4|0);
        $49 = HEAP32[$48>>2]|0;
        $50 = ($49|0)==(0|0);
        if ($50) {
         label = 17;
         break;
        } else {
         $$0$ph$i$i$i$i28 = $48;$$in$i$i$i$i27 = $49;
        }
       }
       $$0$i$i$i$i31 = $$0$ph$i$i$i$i28;$$024$i$i$i$i30 = $$in$i$i$i$i27;
      }
      if ((label|0) == 14) {
       $$025$i$i$i$i33 = $$024$i$i$i$i30;$$036$i$i$i32 = $$024$i$i$i$i30;
       break;
      }
      else if ((label|0) == 17) {
       $$025$i$i$i$i33 = $48;$$036$i$i$i32 = $$024$i$i$i$i30;
       break;
      }
      else if ((label|0) == 18) {
       $$025$i$i$i$i33 = $$0$i$i$i$i31;$$036$i$i$i32 = $$024$i$i$i$i30;
       break;
      }
     }
    } while(0);
    $51 = HEAP32[$$025$i$i$i$i33>>2]|0;
    $52 = ($51|0)==(0|0);
    if ($52) {
     __THREW__ = 0;
     $53 = (invoke_ii(3276,20)|0);
     $54 = __THREW__; __THREW__ = 0;
     $55 = $54&1;
     if ($55) {
      $80 = ___cxa_find_matching_catch_2()|0;
      $81 = tempRet0;
      $$2 = $80;$$220 = $81;$$pre$phiZ2D = $8;
      $151 = HEAP32[$$pre$phiZ2D>>2]|0;
      __ZNSt3__26__treeIPN3osg15GraphicsContextENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($3,$151);
      ___resumeException($$2|0);
      // unreachable;
     }
     $56 = ((($53)) + 16|0);
     HEAP32[$56>>2] = $39;
     HEAP32[$53>>2] = 0;
     $57 = ((($53)) + 4|0);
     HEAP32[$57>>2] = 0;
     $58 = ((($53)) + 8|0);
     HEAP32[$58>>2] = $$036$i$i$i32;
     HEAP32[$$025$i$i$i$i33>>2] = $53;
     $59 = HEAP32[$3>>2]|0;
     $60 = HEAP32[$59>>2]|0;
     $61 = ($60|0)==(0|0);
     if ($61) {
      $64 = $53;
     } else {
      $62 = $60;
      HEAP32[$3>>2] = $62;
      $$pre$i$i$i$i36 = HEAP32[$$025$i$i$i$i33>>2]|0;
      $64 = $$pre$i$i$i$i36;
     }
     $63 = HEAP32[$6>>2]|0;
     __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($63,$64);
     $65 = HEAP32[$7>>2]|0;
     $66 = (($65) + 1)|0;
     HEAP32[$7>>2] = $66;
     $$pre = HEAP32[$18>>2]|0;
     $68 = $$pre;
    } else {
     $68 = $36;
    }
    $67 = ((($68)) + 624|0);
    $69 = HEAP32[$67>>2]|0;
    HEAP32[$4>>2] = $69;
    $70 = HEAP32[$10>>2]|0;
    $71 = ((($1)) + 8|0);
    $72 = HEAP32[$71>>2]|0;
    $73 = ($70|0)==($72|0);
    if ($73) {
     __THREW__ = 0;
     invoke_vii(3401,($1|0),($4|0));
     $76 = __THREW__; __THREW__ = 0;
     $77 = $76&1;
     if ($77) {
      $82 = ___cxa_find_matching_catch_2()|0;
      $83 = tempRet0;
      $$2 = $82;$$220 = $83;$$pre$phiZ2D = $8;
      $151 = HEAP32[$$pre$phiZ2D>>2]|0;
      __ZNSt3__26__treeIPN3osg15GraphicsContextENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($3,$151);
      ___resumeException($$2|0);
      // unreachable;
     }
    } else {
     HEAP32[$70>>2] = $69;
     $74 = HEAP32[$10>>2]|0;
     $75 = ((($74)) + 4|0);
     HEAP32[$10>>2] = $75;
    }
   }
  }
 }
 $21 = ((($0)) + 124|0);
 $22 = ((($0)) + 128|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = HEAP32[$21>>2]|0;
 $25 = ($23|0)==($24|0);
 if ($25) {
  $$pre$phi79Z2D = $8;
  $84 = HEAP32[$$pre$phi79Z2D>>2]|0;
  __ZNSt3__26__treeIPN3osg15GraphicsContextENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($3,$84);
  STACKTOP = sp;return;
 }
 $$not21 = $2 ^ 1;
 $26 = ((($1)) + 8|0);
 $$01765 = 0;$$in = $24;
 L47: while(1) {
  $85 = $$in;
  $86 = (((($85) + (($$01765*272)|0)|0)) + 4|0);
  $87 = HEAP32[$86>>2]|0;
  $88 = ($87|0)==(0|0);
  L49: do {
   if ($88) {
    HEAP32[$5>>2] = 0;
   } else {
    $89 = ((($87)) + 624|0);
    $90 = HEAP32[$89>>2]|0;
    HEAP32[$5>>2] = $90;
    $91 = ($90|0)==(0|0);
    if (!($91)) {
     $92 = HEAP32[$90>>2]|0;
     $93 = ((($92)) + 144|0);
     $94 = HEAP32[$93>>2]|0;
     __THREW__ = 0;
     $95 = (invoke_ii($94|0,($90|0))|0);
     $96 = __THREW__; __THREW__ = 0;
     $97 = $96&1;
     if ($97) {
      break L47;
     }
     $brmerge22 = $95 | $$not21;
     if ($brmerge22) {
      $98 = HEAP32[$8>>2]|0;
      $99 = ($98|0)==(0|0);
      do {
       if ($99) {
        $$025$i$i$i$i = $8;$$036$i$i$i = $8;
       } else {
        $100 = HEAP32[$5>>2]|0;
        $102 = $98;
        while(1) {
         $101 = ((($102)) + 16|0);
         $103 = HEAP32[$101>>2]|0;
         $104 = ($100>>>0)<($103>>>0);
         if ($104) {
          $$sink$be$i$i = $102;
         } else {
          $105 = ($103>>>0)<($100>>>0);
          if (!($105)) {
           break L49;
          }
          $106 = ((($102)) + 4|0);
          $$sink$be$i$i = $106;
         }
         $107 = HEAP32[$$sink$be$i$i>>2]|0;
         $108 = ($107|0)==(0|0);
         if ($108) {
          $$0$i$i$i$i = $6;$$024$i$i$i$i = $98;
          break;
         } else {
          $102 = $107;
         }
        }
        while(1) {
         $109 = ((($$024$i$i$i$i)) + 16|0);
         $110 = HEAP32[$109>>2]|0;
         $111 = ($100>>>0)<($110>>>0);
         if ($111) {
          $112 = HEAP32[$$024$i$i$i$i>>2]|0;
          $113 = ($112|0)==(0|0);
          if ($113) {
           label = 48;
           break;
          } else {
           $$0$ph$i$i$i$i = $$024$i$i$i$i;$$in$i$i$i$i = $112;
          }
         } else {
          $114 = ($110>>>0)<($100>>>0);
          if (!($114)) {
           label = 52;
           break;
          }
          $115 = ((($$024$i$i$i$i)) + 4|0);
          $116 = HEAP32[$115>>2]|0;
          $117 = ($116|0)==(0|0);
          if ($117) {
           label = 51;
           break;
          } else {
           $$0$ph$i$i$i$i = $115;$$in$i$i$i$i = $116;
          }
         }
         $$0$i$i$i$i = $$0$ph$i$i$i$i;$$024$i$i$i$i = $$in$i$i$i$i;
        }
        if ((label|0) == 48) {
         label = 0;
         $$025$i$i$i$i = $$024$i$i$i$i;$$036$i$i$i = $$024$i$i$i$i;
         break;
        }
        else if ((label|0) == 51) {
         label = 0;
         $$025$i$i$i$i = $115;$$036$i$i$i = $$024$i$i$i$i;
         break;
        }
        else if ((label|0) == 52) {
         label = 0;
         $$025$i$i$i$i = $$0$i$i$i$i;$$036$i$i$i = $$024$i$i$i$i;
         break;
        }
       }
      } while(0);
      $118 = HEAP32[$$025$i$i$i$i>>2]|0;
      $119 = ($118|0)==(0|0);
      if ($119) {
       __THREW__ = 0;
       $120 = (invoke_ii(3276,20)|0);
       $121 = __THREW__; __THREW__ = 0;
       $122 = $121&1;
       if ($122) {
        break L47;
       }
       $123 = ((($120)) + 16|0);
       $124 = HEAP32[$5>>2]|0;
       HEAP32[$123>>2] = $124;
       HEAP32[$120>>2] = 0;
       $125 = ((($120)) + 4|0);
       HEAP32[$125>>2] = 0;
       $126 = ((($120)) + 8|0);
       HEAP32[$126>>2] = $$036$i$i$i;
       HEAP32[$$025$i$i$i$i>>2] = $120;
       $127 = HEAP32[$3>>2]|0;
       $128 = HEAP32[$127>>2]|0;
       $129 = ($128|0)==(0|0);
       if ($129) {
        $132 = $120;
       } else {
        $130 = $128;
        HEAP32[$3>>2] = $130;
        $$pre$i$i$i$i = HEAP32[$$025$i$i$i$i>>2]|0;
        $132 = $$pre$i$i$i$i;
       }
       $131 = HEAP32[$6>>2]|0;
       __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($131,$132);
       $133 = HEAP32[$7>>2]|0;
       $134 = (($133) + 1)|0;
       HEAP32[$7>>2] = $134;
      }
      $135 = HEAP32[$10>>2]|0;
      $136 = HEAP32[$26>>2]|0;
      $137 = ($135|0)==($136|0);
      if ($137) {
       __THREW__ = 0;
       invoke_vii(3401,($1|0),($5|0));
       $141 = __THREW__; __THREW__ = 0;
       $142 = $141&1;
       if ($142) {
        break L47;
       } else {
        break;
       }
      } else {
       $138 = HEAP32[$5>>2]|0;
       HEAP32[$135>>2] = $138;
       $139 = HEAP32[$10>>2]|0;
       $140 = ((($139)) + 4|0);
       HEAP32[$10>>2] = $140;
       break;
      }
     }
    }
   }
  } while(0);
  $145 = (($$01765) + 1)|0;
  $146 = HEAP32[$22>>2]|0;
  $147 = HEAP32[$21>>2]|0;
  $148 = (($146) - ($147))|0;
  $149 = (($148|0) / 272)&-1;
  $150 = ($145>>>0)<($149>>>0);
  if ($150) {
   $$01765 = $145;$$in = $147;
  } else {
   $$pre$phi79Z2D = $8;
   label = 32;
   break;
  }
 }
 if ((label|0) == 32) {
  $84 = HEAP32[$$pre$phi79Z2D>>2]|0;
  __ZNSt3__26__treeIPN3osg15GraphicsContextENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($3,$84);
  STACKTOP = sp;return;
 }
 $143 = ___cxa_find_matching_catch_2()|0;
 $144 = tempRet0;
 $$2 = $143;$$220 = $144;$$pre$phiZ2D = $8;
 $151 = HEAP32[$$pre$phiZ2D>>2]|0;
 __ZNSt3__26__treeIPN3osg15GraphicsContextENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($3,$151);
 ___resumeException($$2|0);
 // unreachable;
}
function __ZN9osgViewer6Viewer13getAllThreadsERNSt3__26vectorIPN11OpenThreads6ThreadENS1_9allocatorIS5_EEEEb($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$02243 = 0, $$02243$us = 0, $$2 = 0, $$225 = 0, $$sroa$037$046 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i26 = 0, $scevgep$i$i$i29 = 0, $scevgep5$i$i$i = 0, $scevgep5$i$i$i27 = 0, $scevgep5$i$i$i30 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $3 = sp + 8|0;
 $4 = sp + 4|0;
 $5 = sp;
 $6 = HEAP32[$1>>2]|0;
 $7 = ((($1)) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==($6|0);
 if (!($9)) {
  $scevgep$i$i$i = ((($8)) + -4|0);
  $10 = $scevgep$i$i$i;
  $11 = $6;
  $12 = (($10) - ($11))|0;
  $13 = $12 >>> 2;
  $14 = $13 ^ -1;
  $scevgep5$i$i$i = (($8) + ($14<<2)|0);
  HEAP32[$7>>2] = $scevgep5$i$i$i;
 }
 HEAP32[$3>>2] = 0;
 $15 = ((($3)) + 4|0);
 HEAP32[$15>>2] = 0;
 $16 = ((($3)) + 8|0);
 HEAP32[$16>>2] = 0;
 $17 = HEAP32[$0>>2]|0;
 $18 = ((($17)) + 100|0);
 $19 = HEAP32[$18>>2]|0;
 __THREW__ = 0;
 invoke_viii($19|0,($0|0),($3|0),1);
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 L4: do {
  if ($21) {
   $29 = ___cxa_find_matching_catch_2()|0;
   $30 = tempRet0;
   $$2 = $29;$$225 = $30;
  } else {
   $22 = HEAP32[$3>>2]|0;
   $23 = HEAP32[$15>>2]|0;
   $24 = ($22|0)==($23|0);
   L7: do {
    if (!($24)) {
     $25 = ((($1)) + 8|0);
     $$sroa$037$046 = $22;
     while(1) {
      $31 = HEAP32[$$sroa$037$046>>2]|0;
      $32 = ($31|0)==(0|0);
      $33 = ((($31)) + 12|0);
      $34 = $32 ? 0 : $33;
      HEAP32[$4>>2] = $34;
      $35 = HEAP32[$7>>2]|0;
      $36 = HEAP32[$25>>2]|0;
      $37 = ($35|0)==($36|0);
      if ($37) {
       __THREW__ = 0;
       invoke_vii(3402,($1|0),($4|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if ($42) {
        break;
       }
      } else {
       $38 = $34;
       HEAP32[$35>>2] = $38;
       $39 = HEAP32[$7>>2]|0;
       $40 = ((($39)) + 4|0);
       HEAP32[$7>>2] = $40;
      }
      $43 = ((($$sroa$037$046)) + 4|0);
      $44 = HEAP32[$15>>2]|0;
      $45 = ($43|0)==($44|0);
      if ($45) {
       break L7;
      } else {
       $$sroa$037$046 = $43;
      }
     }
     $46 = ___cxa_find_matching_catch_2()|0;
     $47 = tempRet0;
     $$2 = $46;$$225 = $47;
     break L4;
    }
   } while(0);
   $26 = ((($0)) + 172|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = ($27|0)==(0|0);
   L17: do {
    if (!($28)) {
     $48 = ((($27)) + 16|0);
     $49 = HEAP32[$48>>2]|0;
     $50 = ($49|0)==(0|0);
     if (!($50)) {
      $51 = ((($49)) + 56|0);
      $52 = ((($49)) + 60|0);
      $53 = HEAP32[$52>>2]|0;
      $54 = HEAP32[$51>>2]|0;
      $55 = ($53|0)==($54|0);
      $56 = $54;
      if (!($55)) {
       $57 = ((($1)) + 8|0);
       L21: do {
        if ($2) {
         $$02243$us = 0;$59 = $56;
         while(1) {
          $58 = (($59) + ($$02243$us<<2)|0);
          $60 = HEAP32[$58>>2]|0;
          $61 = ((($60)) + 12|0);
          __THREW__ = 0;
          $62 = (invoke_ii(3403,($61|0))|0);
          $63 = __THREW__; __THREW__ = 0;
          $64 = $63&1;
          if ($64) {
           break;
          }
          if ($62) {
           $65 = ($60|0)==(0|0);
           $66 = $65 ? 0 : $61;
           HEAP32[$5>>2] = $66;
           $67 = HEAP32[$7>>2]|0;
           $68 = HEAP32[$57>>2]|0;
           $69 = ($67|0)==($68|0);
           if ($69) {
            __THREW__ = 0;
            invoke_vii(3402,($1|0),($5|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break L21;
            }
           } else {
            $70 = $66;
            HEAP32[$67>>2] = $70;
            $71 = HEAP32[$7>>2]|0;
            $72 = ((($71)) + 4|0);
            HEAP32[$7>>2] = $72;
           }
          }
          $75 = (($$02243$us) + 1)|0;
          $76 = HEAP32[$52>>2]|0;
          $77 = HEAP32[$51>>2]|0;
          $78 = (($76) - ($77))|0;
          $79 = $78 >> 2;
          $80 = ($75>>>0)<($79>>>0);
          $81 = $77;
          if ($80) {
           $$02243$us = $75;$59 = $81;
          } else {
           break L17;
          }
         }
         $82 = ___cxa_find_matching_catch_2()|0;
         $83 = tempRet0;
         $$2 = $82;$$225 = $83;
         break L4;
        } else {
         $$02243 = 0;$85 = $56;
         while(1) {
          $84 = (($85) + ($$02243<<2)|0);
          $86 = HEAP32[$84>>2]|0;
          $87 = ($86|0)==(0|0);
          $88 = ((($86)) + 12|0);
          $89 = $87 ? 0 : $88;
          HEAP32[$5>>2] = $89;
          $90 = HEAP32[$7>>2]|0;
          $91 = HEAP32[$57>>2]|0;
          $92 = ($90|0)==($91|0);
          if ($92) {
           __THREW__ = 0;
           invoke_vii(3402,($1|0),($5|0));
           $96 = __THREW__; __THREW__ = 0;
           $97 = $96&1;
           if ($97) {
            break L21;
           }
          } else {
           $93 = $89;
           HEAP32[$90>>2] = $93;
           $94 = HEAP32[$7>>2]|0;
           $95 = ((($94)) + 4|0);
           HEAP32[$7>>2] = $95;
          }
          $98 = (($$02243) + 1)|0;
          $99 = HEAP32[$52>>2]|0;
          $100 = HEAP32[$51>>2]|0;
          $101 = (($99) - ($100))|0;
          $102 = $101 >> 2;
          $103 = ($98>>>0)<($102>>>0);
          $104 = $100;
          if ($103) {
           $$02243 = $98;$85 = $104;
          } else {
           break L17;
          }
         }
        }
       } while(0);
       $105 = ___cxa_find_matching_catch_2()|0;
       $106 = tempRet0;
       $$2 = $105;$$225 = $106;
       break L4;
      }
     }
    }
   } while(0);
   $107 = HEAP32[$3>>2]|0;
   $108 = ($107|0)==(0|0);
   if ($108) {
    STACKTOP = sp;return;
   }
   $109 = HEAP32[$15>>2]|0;
   $110 = ($109|0)==($107|0);
   if (!($110)) {
    $scevgep$i$i$i29 = ((($109)) + -4|0);
    $111 = $scevgep$i$i$i29;
    $112 = $107;
    $113 = (($111) - ($112))|0;
    $114 = $113 >>> 2;
    $115 = $114 ^ -1;
    $scevgep5$i$i$i30 = (($109) + ($115<<2)|0);
    HEAP32[$15>>2] = $scevgep5$i$i$i30;
   }
   __ZdlPv($107);
   STACKTOP = sp;return;
  }
 } while(0);
 $116 = HEAP32[$3>>2]|0;
 $117 = ($116|0)==(0|0);
 if ($117) {
  ___resumeException($$2|0);
  // unreachable;
 }
 $118 = HEAP32[$15>>2]|0;
 $119 = ($118|0)==($116|0);
 if (!($119)) {
  $scevgep$i$i$i26 = ((($118)) + -4|0);
  $120 = $scevgep$i$i$i26;
  $121 = $116;
  $122 = (($120) - ($121))|0;
  $123 = $122 >>> 2;
  $124 = $123 ^ -1;
  $scevgep5$i$i$i27 = (($118) + ($124<<2)|0);
  HEAP32[$15>>2] = $scevgep5$i$i$i27;
 }
 __ZdlPv($116);
 ___resumeException($$2|0);
 // unreachable;
}
function __ZN9osgViewer6Viewer19getOperationThreadsERNSt3__26vectorIPN3osg15OperationThreadENS1_9allocatorIS5_EEEEb($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$2 = 0, $$220 = 0, $$4 = 0, $$422 = 0, $$ph = 0, $$pr = 0, $$pre = 0, $$pre68 = 0, $$sroa$042$055 = 0, $$sroa$042$055$us = 0, $$sroa$049$058 = 0, $$sroa$049$058$us = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0;
 var $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i23 = 0, $scevgep$i$i$i26 = 0, $scevgep$i$i$i29 = 0, $scevgep$i$i$i34 = 0, $scevgep5$i$i$i = 0, $scevgep5$i$i$i24 = 0, $scevgep5$i$i$i27 = 0, $scevgep5$i$i$i30 = 0, $scevgep5$i$i$i35 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $3 = sp + 20|0;
 $4 = sp + 16|0;
 $5 = sp + 4|0;
 $6 = sp;
 $7 = HEAP32[$1>>2]|0;
 $8 = ((($1)) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==($7|0);
 if (!($10)) {
  $scevgep$i$i$i = ((($9)) + -4|0);
  $11 = $scevgep$i$i$i;
  $12 = $7;
  $13 = (($11) - ($12))|0;
  $14 = $13 >>> 2;
  $15 = $14 ^ -1;
  $scevgep5$i$i$i = (($9) + ($15<<2)|0);
  HEAP32[$8>>2] = $scevgep5$i$i$i;
 }
 HEAP32[$3>>2] = 0;
 $16 = ((($3)) + 4|0);
 HEAP32[$16>>2] = 0;
 $17 = ((($3)) + 8|0);
 HEAP32[$17>>2] = 0;
 $18 = HEAP32[$0>>2]|0;
 $19 = ((($18)) + 88|0);
 $20 = HEAP32[$19>>2]|0;
 __THREW__ = 0;
 invoke_viii($20|0,($0|0),($3|0),1);
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 L4: do {
  if ($22) {
   $49 = ___cxa_find_matching_catch_2()|0;
   $50 = tempRet0;
   $$4 = $49;$$422 = $50;
  } else {
   $23 = HEAP32[$3>>2]|0;
   $24 = HEAP32[$16>>2]|0;
   $25 = ($23|0)==($24|0);
   L7: do {
    if (!($25)) {
     $26 = ((($1)) + 8|0);
     L9: do {
      if ($2) {
       $$sroa$049$058$us = $23;
       while(1) {
        $27 = HEAP32[$$sroa$049$058$us>>2]|0;
        $28 = ((($27)) + 108|0);
        $29 = HEAP32[$28>>2]|0;
        $30 = ($29|0)==(0|0);
        if (!($30)) {
         $31 = ((($29)) + 12|0);
         __THREW__ = 0;
         $32 = (invoke_ii(3403,($31|0))|0);
         $33 = __THREW__; __THREW__ = 0;
         $34 = $33&1;
         if ($34) {
          break;
         }
         if ($32) {
          $35 = HEAP32[$28>>2]|0;
          HEAP32[$4>>2] = $35;
          $36 = HEAP32[$8>>2]|0;
          $37 = HEAP32[$26>>2]|0;
          $38 = ($36|0)==($37|0);
          if ($38) {
           __THREW__ = 0;
           invoke_vii(3404,($1|0),($4|0));
           $42 = __THREW__; __THREW__ = 0;
           $43 = $42&1;
           if ($43) {
            break L9;
           }
          } else {
           $39 = $35;
           HEAP32[$36>>2] = $39;
           $40 = HEAP32[$8>>2]|0;
           $41 = ((($40)) + 4|0);
           HEAP32[$8>>2] = $41;
          }
         }
        }
        $44 = ((($$sroa$049$058$us)) + 4|0);
        $45 = HEAP32[$16>>2]|0;
        $46 = ($44|0)==($45|0);
        if ($46) {
         break L7;
        } else {
         $$sroa$049$058$us = $44;
        }
       }
       $47 = ___cxa_find_matching_catch_2()|0;
       $48 = tempRet0;
       $$4 = $47;$$422 = $48;
       break L4;
      } else {
       $$sroa$049$058 = $23;$155 = $24;
       while(1) {
        $51 = HEAP32[$$sroa$049$058>>2]|0;
        $52 = ((($51)) + 108|0);
        $53 = HEAP32[$52>>2]|0;
        $54 = ($53|0)==(0|0);
        if ($54) {
         $67 = $155;
        } else {
         HEAP32[$4>>2] = $53;
         $55 = HEAP32[$8>>2]|0;
         $56 = HEAP32[$26>>2]|0;
         $57 = ($55|0)==($56|0);
         if ($57) {
          __THREW__ = 0;
          invoke_vii(3404,($1|0),($4|0));
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if ($62) {
           break L9;
          }
         } else {
          $58 = $53;
          HEAP32[$55>>2] = $58;
          $59 = HEAP32[$8>>2]|0;
          $60 = ((($59)) + 4|0);
          HEAP32[$8>>2] = $60;
         }
         $$pre = HEAP32[$16>>2]|0;
         $67 = $$pre;
        }
        $65 = ((($$sroa$049$058)) + 4|0);
        $66 = ($65|0)==($67|0);
        if ($66) {
         break L7;
        } else {
         $$sroa$049$058 = $65;$155 = $67;
        }
       }
      }
     } while(0);
     $63 = ___cxa_find_matching_catch_2()|0;
     $64 = tempRet0;
     $$4 = $63;$$422 = $64;
     break L4;
    }
   } while(0);
   HEAP32[$5>>2] = 0;
   $68 = ((($5)) + 4|0);
   HEAP32[$68>>2] = 0;
   $69 = ((($5)) + 8|0);
   HEAP32[$69>>2] = 0;
   $70 = HEAP32[$0>>2]|0;
   $71 = ((($70)) + 84|0);
   $72 = HEAP32[$71>>2]|0;
   __THREW__ = 0;
   invoke_viii($72|0,($0|0),($5|0),1);
   $73 = __THREW__; __THREW__ = 0;
   $74 = $73&1;
   L33: do {
    if ($74) {
     $109 = ___cxa_find_matching_catch_2()|0;
     $110 = tempRet0;
     $$2 = $109;$$220 = $110;
    } else {
     $75 = HEAP32[$5>>2]|0;
     $76 = HEAP32[$68>>2]|0;
     $77 = ($75|0)==($76|0);
     do {
      if ($77) {
       $100 = $75;$102 = $75;
      } else {
       $78 = ((($1)) + 8|0);
       L38: do {
        if ($2) {
         $$sroa$042$055$us = $75;
         while(1) {
          $79 = HEAP32[$$sroa$042$055$us>>2]|0;
          $80 = ((($79)) + 620|0);
          $81 = HEAP32[$80>>2]|0;
          $82 = ($81|0)==(0|0);
          if (!($82)) {
           $83 = ((($81)) + 12|0);
           __THREW__ = 0;
           $84 = (invoke_ii(3403,($83|0))|0);
           $85 = __THREW__; __THREW__ = 0;
           $86 = $85&1;
           if ($86) {
            break;
           }
           if ($84) {
            $87 = HEAP32[$80>>2]|0;
            HEAP32[$6>>2] = $87;
            $88 = HEAP32[$8>>2]|0;
            $89 = HEAP32[$78>>2]|0;
            $90 = ($88|0)==($89|0);
            if ($90) {
             __THREW__ = 0;
             invoke_vii(3404,($1|0),($6|0));
             $93 = __THREW__; __THREW__ = 0;
             $94 = $93&1;
             if ($94) {
              label = 46;
              break L38;
             }
            } else {
             HEAP32[$88>>2] = $87;
             $91 = HEAP32[$8>>2]|0;
             $92 = ((($91)) + 4|0);
             HEAP32[$8>>2] = $92;
            }
           }
          }
          $95 = ((($$sroa$042$055$us)) + 4|0);
          $96 = HEAP32[$68>>2]|0;
          $97 = ($95|0)==($96|0);
          if ($97) {
           $$ph = $95;
           label = 35;
           break L38;
          } else {
           $$sroa$042$055$us = $95;
          }
         }
         $98 = ___cxa_find_matching_catch_2()|0;
         $99 = tempRet0;
         $$2 = $98;$$220 = $99;
         break L33;
        } else {
         $$sroa$042$055 = $75;$156 = $76;
         while(1) {
          $111 = HEAP32[$$sroa$042$055>>2]|0;
          $112 = ((($111)) + 620|0);
          $113 = HEAP32[$112>>2]|0;
          $114 = ($113|0)==(0|0);
          $115 = $113;
          if ($114) {
           $127 = $156;
          } else {
           HEAP32[$6>>2] = $115;
           $116 = HEAP32[$8>>2]|0;
           $117 = HEAP32[$78>>2]|0;
           $118 = ($116|0)==($117|0);
           if ($118) {
            __THREW__ = 0;
            invoke_vii(3404,($1|0),($6|0));
            $121 = __THREW__; __THREW__ = 0;
            $122 = $121&1;
            if ($122) {
             label = 46;
             break L38;
            }
           } else {
            HEAP32[$116>>2] = $115;
            $119 = HEAP32[$8>>2]|0;
            $120 = ((($119)) + 4|0);
            HEAP32[$8>>2] = $120;
           }
           $$pre68 = HEAP32[$68>>2]|0;
           $127 = $$pre68;
          }
          $125 = ((($$sroa$042$055)) + 4|0);
          $126 = ($125|0)==($127|0);
          if ($126) {
           $$ph = $127;
           label = 35;
           break;
          } else {
           $$sroa$042$055 = $125;$156 = $127;
          }
         }
        }
       } while(0);
       if ((label|0) == 35) {
        $$pr = HEAP32[$5>>2]|0;
        $100 = $$pr;$102 = $$ph;
        break;
       }
       else if ((label|0) == 46) {
        $123 = ___cxa_find_matching_catch_2()|0;
        $124 = tempRet0;
        $$2 = $123;$$220 = $124;
        break L33;
       }
      }
     } while(0);
     $101 = ($100|0)==(0|0);
     if (!($101)) {
      $103 = ($102|0)==($100|0);
      if (!($103)) {
       $scevgep$i$i$i34 = ((($102)) + -4|0);
       $104 = $scevgep$i$i$i34;
       $105 = $100;
       $106 = (($104) - ($105))|0;
       $107 = $106 >>> 2;
       $108 = $107 ^ -1;
       $scevgep5$i$i$i35 = (($102) + ($108<<2)|0);
       HEAP32[$68>>2] = $scevgep5$i$i$i35;
      }
      __ZdlPv($100);
     }
     $128 = HEAP32[$3>>2]|0;
     $129 = ($128|0)==(0|0);
     if ($129) {
      STACKTOP = sp;return;
     }
     $130 = HEAP32[$16>>2]|0;
     $131 = ($130|0)==($128|0);
     if (!($131)) {
      $scevgep$i$i$i29 = ((($130)) + -4|0);
      $132 = $scevgep$i$i$i29;
      $133 = $128;
      $134 = (($132) - ($133))|0;
      $135 = $134 >>> 2;
      $136 = $135 ^ -1;
      $scevgep5$i$i$i30 = (($130) + ($136<<2)|0);
      HEAP32[$16>>2] = $scevgep5$i$i$i30;
     }
     __ZdlPv($128);
     STACKTOP = sp;return;
    }
   } while(0);
   $137 = HEAP32[$5>>2]|0;
   $138 = ($137|0)==(0|0);
   if (!($138)) {
    $139 = HEAP32[$68>>2]|0;
    $140 = ($139|0)==($137|0);
    if (!($140)) {
     $scevgep$i$i$i26 = ((($139)) + -4|0);
     $141 = $scevgep$i$i$i26;
     $142 = $137;
     $143 = (($141) - ($142))|0;
     $144 = $143 >>> 2;
     $145 = $144 ^ -1;
     $scevgep5$i$i$i27 = (($139) + ($145<<2)|0);
     HEAP32[$68>>2] = $scevgep5$i$i$i27;
    }
    __ZdlPv($137);
   }
   $$4 = $$2;$$422 = $$220;
  }
 } while(0);
 $146 = HEAP32[$3>>2]|0;
 $147 = ($146|0)==(0|0);
 if ($147) {
  ___resumeException($$4|0);
  // unreachable;
 }
 $148 = HEAP32[$16>>2]|0;
 $149 = ($148|0)==($146|0);
 if (!($149)) {
  $scevgep$i$i$i23 = ((($148)) + -4|0);
  $150 = $scevgep$i$i$i23;
  $151 = $146;
  $152 = (($150) - ($151))|0;
  $153 = $152 >>> 2;
  $154 = $153 ^ -1;
  $scevgep5$i$i$i24 = (($148) + ($154<<2)|0);
  HEAP32[$16>>2] = $scevgep5$i$i$i24;
 }
 __ZdlPv($146);
 ___resumeException($$4|0);
 // unreachable;
}
function __ZN9osgViewer6Viewer9getScenesERNSt3__26vectorIPNS_5SceneENS1_9allocatorIS4_EEEEb($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i = 0, $scevgep5$i$i$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = HEAP32[$1>>2]|0;
 $5 = ((($1)) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==($4|0);
 if ($7) {
  $17 = $4;
 } else {
  $scevgep$i$i$i = ((($6)) + -4|0);
  $8 = $scevgep$i$i$i;
  $9 = $4;
  $10 = (($8) - ($9))|0;
  $11 = $10 >>> 2;
  $12 = $11 ^ -1;
  $scevgep5$i$i$i = (($6) + ($12<<2)|0);
  HEAP32[$5>>2] = $scevgep5$i$i$i;
  $17 = $scevgep5$i$i$i;
 }
 $13 = ((($0)) + 172|0);
 $14 = HEAP32[$13>>2]|0;
 HEAP32[$3>>2] = $14;
 $15 = ((($1)) + 8|0);
 $16 = HEAP32[$15>>2]|0;
 $18 = ($17|0)==($16|0);
 if ($18) {
  __ZNSt3__26vectorIPN9osgViewer5SceneENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_($1,$3);
  STACKTOP = sp;return;
 } else {
  HEAP32[$17>>2] = $14;
  $19 = HEAP32[$5>>2]|0;
  $20 = ((($19)) + 4|0);
  HEAP32[$5>>2] = $20;
  STACKTOP = sp;return;
 }
}
function __ZN9osgViewer6Viewer8getViewsERNSt3__26vectorIPNS_4ViewENS1_9allocatorIS4_EEEEb($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i = 0, $scevgep5$i$i$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = HEAP32[$1>>2]|0;
 $5 = ((($1)) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==($4|0);
 if ($7) {
  $16 = $4;
 } else {
  $scevgep$i$i$i = ((($6)) + -4|0);
  $8 = $scevgep$i$i$i;
  $9 = $4;
  $10 = (($8) - ($9))|0;
  $11 = $10 >>> 2;
  $12 = $11 ^ -1;
  $scevgep5$i$i$i = (($6) + ($12<<2)|0);
  HEAP32[$5>>2] = $scevgep5$i$i$i;
  $16 = $scevgep5$i$i$i;
 }
 $13 = ((($0)) + 104|0);
 HEAP32[$3>>2] = $13;
 $14 = ((($1)) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $17 = ($16|0)==($15|0);
 if ($17) {
  __ZNSt3__26vectorIPN9osgViewer4ViewENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_($1,$3);
  STACKTOP = sp;return;
 } else {
  $18 = $13;
  HEAP32[$16>>2] = $18;
  $19 = HEAP32[$5>>2]|0;
  $20 = ((($19)) + 4|0);
  HEAP32[$5>>2] = $20;
  STACKTOP = sp;return;
 }
}
function __ZN9osgViewer6Viewer11elapsedTimeEv($0) {
 $0 = $0|0;
 var $$sink$i = 0.0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0.0, $2 = 0, $20 = 0, $21 = 0, $22 = 0.0, $23 = 0.0, $24 = 0, $25 = 0.0, $26 = 0.0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__ZN3osg5Timer8instanceEv()|0);
 $2 = ((($0)) + 152|0);
 $3 = $2;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 4)|0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = (__ZN3osg5Timer8instanceEv()|0);
 $10 = (__ZNK3osg5Timer4tickEv($9)|0);
 $11 = tempRet0;
 $12 = ($11>>>0)>($8>>>0);
 $13 = ($10>>>0)>($5>>>0);
 $14 = ($11|0)==($8|0);
 $15 = $14 & $13;
 $16 = $12 | $15;
 if ($16) {
  $17 = (_i64Subtract(($10|0),($11|0),($5|0),($8|0))|0);
  $18 = tempRet0;
  $19 = (+($17>>>0)) + (4294967296.0*(+($18>>>0)));
  $$sink$i = $19;
  $24 = ((($1)) + 8|0);
  $25 = +HEAPF64[$24>>3];
  $26 = $$sink$i * $25;
  return (+$26);
 } else {
  $20 = (_i64Subtract(($5|0),($8|0),($10|0),($11|0))|0);
  $21 = tempRet0;
  $22 = (+($20>>>0)) + (4294967296.0*(+($21>>>0)));
  $23 = -$22;
  $$sink$i = $23;
  $24 = ((($1)) + 8|0);
  $25 = +HEAPF64[$24>>3];
  $26 = $$sink$i * $25;
  return (+$26);
 }
 return +(0.0);
}
function __ZN9osgViewer6Viewer19getViewerFrameStampEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 136|0);
 $2 = HEAP32[$1>>2]|0;
 return ($2|0);
}
function __ZNK9osgViewer6Viewer8getUsageERN3osg16ApplicationUsageE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$sroa$04$0 = 0, $$sroa$04$010 = 0, $$sroa$04$09 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 180|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = HEAP32[$3>>2]|0;
  $6 = ((($5)) + 68|0);
  $7 = HEAP32[$6>>2]|0;
  FUNCTION_TABLE_vii[$7 & 8191]($3,$1);
 }
 $8 = ((($0)) + 188|0);
 $$sroa$04$09 = HEAP32[$8>>2]|0;
 $9 = ((($0)) + 184|0);
 $10 = $$sroa$04$09;
 $11 = ($10|0)==($9|0);
 if ($11) {
  return;
 } else {
  $$sroa$04$010 = $$sroa$04$09;$19 = $10;
 }
 while(1) {
  $12 = $$sroa$04$010;
  $13 = ((($12)) + 8|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = HEAP32[$14>>2]|0;
  $16 = ((($15)) + 68|0);
  $17 = HEAP32[$16>>2]|0;
  FUNCTION_TABLE_vii[$17 & 8191]($14,$1);
  $18 = ((($19)) + 4|0);
  $$sroa$04$0 = HEAP32[$18>>2]|0;
  $20 = $$sroa$04$0;
  $21 = ($20|0)==($9|0);
  if ($21) {
   break;
  } else {
   $$sroa$04$010 = $$sroa$04$0;$19 = $20;
  }
 }
 return;
}
function __ZN9osgViewer6Viewer10viewerInitEv($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 104|0);
 __ZN9osgViewer4View4initEv($1);
 return;
}
function __ZN9osgViewer6ViewerD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vii(3405,($0|0),(36724|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  $3 = ((($0)) + 236|0);
  __ZN3osg6ObjectD2Ev($3);
  return;
 }
 $4 = ___cxa_find_matching_catch_2()|0;
 $5 = tempRet0;
 $6 = ((($0)) + 236|0);
 __THREW__ = 0;
 invoke_vi(388,($6|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch_3(0|0)|0;
  $10 = tempRet0;
  ___clang_call_terminate($9);
  // unreachable;
 } else {
  ___resumeException($4|0);
  // unreachable;
 }
}
function __ZN9osgViewer6ViewerD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vii(3405,($0|0),(36724|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $6 = ___cxa_find_matching_catch_2()|0;
  $7 = tempRet0;
  $8 = ((($0)) + 236|0);
  __THREW__ = 0;
  invoke_vi(388,($8|0));
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if ($10) {
   $11 = ___cxa_find_matching_catch_3(0|0)|0;
   $12 = tempRet0;
   ___clang_call_terminate($11);
   // unreachable;
  } else {
   $eh$lpad$body$index2Z2D = $7;$eh$lpad$body$indexZ2D = $6;
   __ZdlPv($0);
   ___resumeException($eh$lpad$body$indexZ2D|0);
   // unreachable;
  }
 }
 $3 = ((($0)) + 236|0);
 __THREW__ = 0;
 invoke_vi(388,($3|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  __ZdlPv($0);
  return;
 }
 $13 = ___cxa_find_matching_catch_2()|0;
 $14 = tempRet0;
 $eh$lpad$body$index2Z2D = $14;$eh$lpad$body$indexZ2D = $13;
 __ZdlPv($0);
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
}
function __ZNK9osgViewer6Viewer9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(272)|0);
 __THREW__ = 0;
 invoke_vi(3248,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $8 = ___cxa_find_matching_catch_2()|0;
  $9 = tempRet0;
  __ZdlPv($1);
  ___resumeException($8|0);
  // unreachable;
 } else {
  $4 = HEAP32[$1>>2]|0;
  $5 = ((($4)) + -12|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($1) + ($6)|0);
  return ($7|0);
 }
 return (0)|0;
}
function __ZNK9osgViewer6Viewer5cloneERKN3osg6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(272)|0);
 __THREW__ = 0;
 invoke_viii(3406,($2|0),($0|0),($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $9 = ___cxa_find_matching_catch_2()|0;
  $10 = tempRet0;
  __ZdlPv($2);
  ___resumeException($9|0);
  // unreachable;
 } else {
  $5 = HEAP32[$2>>2]|0;
  $6 = ((($5)) + -12|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($2) + ($7)|0);
  return ($8|0);
 }
 return (0)|0;
}
function __ZNK9osgViewer6Viewer12isSameKindAsEPKN3osg6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,4096,-1)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK9osgViewer6Viewer11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (107921|0);
}
function __ZNK9osgViewer6Viewer9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (103907|0);
}
function __ZN9osgViewer6Viewer4takeERN3osg4ViewE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0;
 var $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0;
 var $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0;
 var $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0;
 var $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0;
 var $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0;
 var $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0;
 var $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0;
 var $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 104|0);
 __ZN9osgViewer4View4takeERN3osg4ViewE($2,$1);
 $3 = (___dynamic_cast($1,27072,4096,104)|0);
 $4 = ($3|0)==(0|0);
 if ($4) {
  return;
 }
 $5 = ((($3)) + 5|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = ((($0)) + 5|0);
 HEAP8[$7>>0] = $6;
 $8 = ((($3)) + 8|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($0)) + 8|0);
 HEAP32[$10>>2] = $9;
 $11 = ((($3)) + 12|0);
 $12 = HEAP8[$11>>0]|0;
 $13 = ((($0)) + 12|0);
 HEAP8[$13>>0] = $12;
 $14 = ((($3)) + 28|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ((($0)) + 28|0);
 HEAP32[$16>>2] = $15;
 $17 = ((($3)) + 32|0);
 $18 = HEAP8[$17>>0]|0;
 $19 = ((($0)) + 32|0);
 HEAP8[$19>>0] = $18;
 $20 = ((($3)) + 48|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ((($0)) + 48|0);
 HEAP32[$22>>2] = $21;
 $23 = ((($3)) + 56|0);
 $24 = ((($0)) + 56|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = HEAP32[$23>>2]|0;
 $27 = ($25|0)==($26|0);
 if (!($27)) {
  HEAP32[$24>>2] = $26;
  $28 = ($26|0)==(0|0);
  if (!($28)) {
   $29 = HEAP32[$26>>2]|0;
   $30 = ((($29)) + -12|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = (($26) + ($31)|0);
   $33 = ((($32)) + 8|0);
   $34 = HEAP32[$33>>2]|0;HEAP32[$33>>2] = (($34+1)|0);
  }
  $35 = ($25|0)==(0|0);
  if (!($35)) {
   $36 = HEAP32[$25>>2]|0;
   $37 = ((($36)) + -12|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = (($25) + ($38)|0);
   $40 = ((($39)) + 8|0);
   $41 = HEAP32[$40>>2]|0;HEAP32[$40>>2] = (($41-1)|0);
   $42 = ($41|0)==(1);
   if ($42) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($39,1,1);
   }
  }
 }
 $43 = ((($3)) + 60|0);
 $44 = ((($0)) + 60|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = HEAP32[$43>>2]|0;
 $47 = ($45|0)==($46|0);
 if (!($47)) {
  HEAP32[$44>>2] = $46;
  $48 = ($46|0)==(0|0);
  if (!($48)) {
   $49 = HEAP32[$46>>2]|0;
   $50 = ((($49)) + -12|0);
   $51 = HEAP32[$50>>2]|0;
   $52 = (($46) + ($51)|0);
   $53 = ((($52)) + 8|0);
   $54 = HEAP32[$53>>2]|0;HEAP32[$53>>2] = (($54+1)|0);
  }
  $55 = ($45|0)==(0|0);
  if (!($55)) {
   $56 = HEAP32[$45>>2]|0;
   $57 = ((($56)) + -12|0);
   $58 = HEAP32[$57>>2]|0;
   $59 = (($45) + ($58)|0);
   $60 = ((($59)) + 8|0);
   $61 = HEAP32[$60>>2]|0;HEAP32[$60>>2] = (($61-1)|0);
   $62 = ($61|0)==(1);
   if ($62) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($59,1,1);
   }
  }
 }
 $63 = ((($3)) + 64|0);
 $64 = ((($0)) + 64|0);
 $65 = HEAP32[$64>>2]|0;
 $66 = HEAP32[$63>>2]|0;
 $67 = ($65|0)==($66|0);
 if (!($67)) {
  HEAP32[$64>>2] = $66;
  $68 = ($66|0)==(0|0);
  if (!($68)) {
   $69 = ((($66)) + 8|0);
   $70 = HEAP32[$69>>2]|0;HEAP32[$69>>2] = (($70+1)|0);
  }
  $71 = ($65|0)==(0|0);
  if (!($71)) {
   $72 = ((($65)) + 8|0);
   $73 = HEAP32[$72>>2]|0;HEAP32[$72>>2] = (($73-1)|0);
   $74 = ($73|0)==(1);
   if ($74) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($65,1,1);
   }
  }
 }
 $75 = ((($3)) + 68|0);
 $76 = ((($0)) + 68|0);
 $77 = HEAP32[$76>>2]|0;
 $78 = HEAP32[$75>>2]|0;
 $79 = ($77|0)==($78|0);
 if (!($79)) {
  HEAP32[$76>>2] = $78;
  $80 = ($78|0)==(0|0);
  if (!($80)) {
   $81 = HEAP32[$78>>2]|0;
   $82 = ((($81)) + -12|0);
   $83 = HEAP32[$82>>2]|0;
   $84 = (($78) + ($83)|0);
   $85 = ((($84)) + 8|0);
   $86 = HEAP32[$85>>2]|0;HEAP32[$85>>2] = (($86+1)|0);
  }
  $87 = ($77|0)==(0|0);
  if (!($87)) {
   $88 = HEAP32[$77>>2]|0;
   $89 = ((($88)) + -12|0);
   $90 = HEAP32[$89>>2]|0;
   $91 = (($77) + ($90)|0);
   $92 = ((($91)) + 8|0);
   $93 = HEAP32[$92>>2]|0;HEAP32[$92>>2] = (($93-1)|0);
   $94 = ($93|0)==(1);
   if ($94) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($91,1,1);
   }
  }
 }
 $95 = HEAP32[$76>>2]|0;
 $96 = ((($0)) + 140|0);
 $97 = ((($95)) + 56|0);
 HEAP32[$97>>2] = $96;
 $98 = ((($0)) + 136|0);
 $99 = HEAP32[$98>>2]|0;
 $100 = ((($95)) + 12|0);
 $101 = HEAP32[$100>>2]|0;
 $102 = ($101|0)==($99|0);
 if (!($102)) {
  HEAP32[$100>>2] = $99;
  $103 = ($99|0)==(0|0);
  if (!($103)) {
   $104 = ((($99)) + 8|0);
   $105 = HEAP32[$104>>2]|0;HEAP32[$104>>2] = (($105+1)|0);
  }
  $106 = ($101|0)==(0|0);
  if (!($106)) {
   $107 = ((($101)) + 8|0);
   $108 = HEAP32[$107>>2]|0;HEAP32[$107>>2] = (($108-1)|0);
   $109 = ($108|0)==(1);
   if ($109) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($101,1,1);
   }
  }
 }
 $110 = ((($3)) + 72|0);
 $111 = ((($0)) + 72|0);
 $112 = HEAP32[$111>>2]|0;
 $113 = HEAP32[$110>>2]|0;
 $114 = ($112|0)==($113|0);
 if (!($114)) {
  HEAP32[$111>>2] = $113;
  $115 = ($113|0)==(0|0);
  if (!($115)) {
   $116 = ((($113)) + 8|0);
   $117 = HEAP32[$116>>2]|0;HEAP32[$116>>2] = (($117+1)|0);
  }
  $118 = ($112|0)==(0|0);
  if (!($118)) {
   $119 = ((($112)) + 8|0);
   $120 = HEAP32[$119>>2]|0;HEAP32[$119>>2] = (($120-1)|0);
   $121 = ($120|0)==(1);
   if ($121) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($112,1,1);
   }
  }
 }
 $122 = ((($3)) + 76|0);
 $123 = ((($0)) + 76|0);
 $124 = HEAP32[$123>>2]|0;
 $125 = HEAP32[$122>>2]|0;
 $126 = ($124|0)==($125|0);
 if (!($126)) {
  HEAP32[$123>>2] = $125;
  $127 = ($125|0)==(0|0);
  if (!($127)) {
   $128 = HEAP32[$125>>2]|0;
   $129 = ((($128)) + -12|0);
   $130 = HEAP32[$129>>2]|0;
   $131 = (($125) + ($130)|0);
   $132 = ((($131)) + 8|0);
   $133 = HEAP32[$132>>2]|0;HEAP32[$132>>2] = (($133+1)|0);
  }
  $134 = ($124|0)==(0|0);
  if (!($134)) {
   $135 = HEAP32[$124>>2]|0;
   $136 = ((($135)) + -12|0);
   $137 = HEAP32[$136>>2]|0;
   $138 = (($124) + ($137)|0);
   $139 = ((($138)) + 8|0);
   $140 = HEAP32[$139>>2]|0;HEAP32[$139>>2] = (($140-1)|0);
   $141 = ($140|0)==(1);
   if ($141) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($138,1,1);
   }
  }
 }
 $142 = ((($3)) + 80|0);
 $143 = ((($0)) + 80|0);
 $144 = HEAP32[$143>>2]|0;
 $145 = HEAP32[$142>>2]|0;
 $146 = ($144|0)==($145|0);
 if (!($146)) {
  HEAP32[$143>>2] = $145;
  $147 = ($145|0)==(0|0);
  if (!($147)) {
   $148 = HEAP32[$145>>2]|0;
   $149 = ((($148)) + -12|0);
   $150 = HEAP32[$149>>2]|0;
   $151 = (($145) + ($150)|0);
   $152 = ((($151)) + 8|0);
   $153 = HEAP32[$152>>2]|0;HEAP32[$152>>2] = (($153+1)|0);
  }
  $154 = ($144|0)==(0|0);
  if (!($154)) {
   $155 = HEAP32[$144>>2]|0;
   $156 = ((($155)) + -12|0);
   $157 = HEAP32[$156>>2]|0;
   $158 = (($144) + ($157)|0);
   $159 = ((($158)) + 8|0);
   $160 = HEAP32[$159>>2]|0;HEAP32[$159>>2] = (($160-1)|0);
   $161 = ($160|0)==(1);
   if ($161) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($158,1,1);
   }
  }
 }
 $162 = ((($3)) + 84|0);
 $163 = ((($0)) + 84|0);
 $164 = HEAP32[$163>>2]|0;
 $165 = HEAP32[$162>>2]|0;
 $166 = ($164|0)==($165|0);
 if (!($166)) {
  HEAP32[$163>>2] = $165;
  $167 = ($165|0)==(0|0);
  if (!($167)) {
   $168 = HEAP32[$165>>2]|0;
   $169 = ((($168)) + -12|0);
   $170 = HEAP32[$169>>2]|0;
   $171 = (($165) + ($170)|0);
   $172 = ((($171)) + 8|0);
   $173 = HEAP32[$172>>2]|0;HEAP32[$172>>2] = (($173+1)|0);
  }
  $174 = ($164|0)==(0|0);
  if (!($174)) {
   $175 = HEAP32[$164>>2]|0;
   $176 = ((($175)) + -12|0);
   $177 = HEAP32[$176>>2]|0;
   $178 = (($164) + ($177)|0);
   $179 = ((($178)) + 8|0);
   $180 = HEAP32[$179>>2]|0;HEAP32[$179>>2] = (($180-1)|0);
   $181 = ($180|0)==(1);
   if ($181) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($178,1,1);
   }
  }
 }
 $182 = ((($3)) + 92|0);
 $183 = ((($0)) + 92|0);
 $184 = ($182|0)==($183|0);
 if (!($184)) {
  $185 = HEAP32[$183>>2]|0;
  $186 = HEAP32[$182>>2]|0;
  $187 = ($185|0)==($186|0);
  if (!($187)) {
   HEAP32[$183>>2] = $186;
   $188 = ($186|0)==(0|0);
   if (!($188)) {
    $189 = ((($186)) + 8|0);
    $190 = HEAP32[$189>>2]|0;HEAP32[$189>>2] = (($190+1)|0);
   }
   $191 = ($185|0)==(0|0);
   if (!($191)) {
    $192 = ((($185)) + 8|0);
    $193 = HEAP32[$192>>2]|0;HEAP32[$192>>2] = (($193-1)|0);
    $194 = ($193|0)==(1);
    if ($194) {
     __ZNK3osg10Referenced24signalObserversAndDeleteEbb($185,1,1);
    }
   }
  }
  $195 = ((($3)) + 96|0);
  $196 = HEAP32[$195>>2]|0;
  $197 = ((($0)) + 96|0);
  HEAP32[$197>>2] = $196;
 }
 HEAP8[$5>>0] = 1;
 $198 = HEAP32[$23>>2]|0;
 $199 = ($198|0)==(0|0);
 if (!($199)) {
  HEAP32[$23>>2] = 0;
  $200 = HEAP32[$198>>2]|0;
  $201 = ((($200)) + -12|0);
  $202 = HEAP32[$201>>2]|0;
  $203 = (($198) + ($202)|0);
  $204 = ((($203)) + 8|0);
  $205 = HEAP32[$204>>2]|0;HEAP32[$204>>2] = (($205-1)|0);
  $206 = ($205|0)==(1);
  if ($206) {
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($203,1,1);
  }
 }
 $207 = HEAP32[$43>>2]|0;
 $208 = ($207|0)==(0|0);
 if (!($208)) {
  HEAP32[$43>>2] = 0;
  $209 = HEAP32[$207>>2]|0;
  $210 = ((($209)) + -12|0);
  $211 = HEAP32[$210>>2]|0;
  $212 = (($207) + ($211)|0);
  $213 = ((($212)) + 8|0);
  $214 = HEAP32[$213>>2]|0;HEAP32[$213>>2] = (($214-1)|0);
  $215 = ($214|0)==(1);
  if ($215) {
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($212,1,1);
  }
 }
 $216 = HEAP32[$63>>2]|0;
 $217 = ($216|0)==(0|0);
 if (!($217)) {
  HEAP32[$63>>2] = 0;
  $218 = ((($216)) + 8|0);
  $219 = HEAP32[$218>>2]|0;HEAP32[$218>>2] = (($219-1)|0);
  $220 = ($219|0)==(1);
  if ($220) {
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($216,1,1);
  }
 }
 $221 = HEAP32[$75>>2]|0;
 $222 = ($221|0)==(0|0);
 if (!($222)) {
  HEAP32[$75>>2] = 0;
  $223 = HEAP32[$221>>2]|0;
  $224 = ((($223)) + -12|0);
  $225 = HEAP32[$224>>2]|0;
  $226 = (($221) + ($225)|0);
  $227 = ((($226)) + 8|0);
  $228 = HEAP32[$227>>2]|0;HEAP32[$227>>2] = (($228-1)|0);
  $229 = ($228|0)==(1);
  if ($229) {
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($226,1,1);
  }
 }
 $230 = HEAP32[$110>>2]|0;
 $231 = ($230|0)==(0|0);
 if (!($231)) {
  HEAP32[$110>>2] = 0;
  $232 = ((($230)) + 8|0);
  $233 = HEAP32[$232>>2]|0;HEAP32[$232>>2] = (($233-1)|0);
  $234 = ($233|0)==(1);
  if ($234) {
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($230,1,1);
  }
 }
 $235 = HEAP32[$122>>2]|0;
 $236 = ($235|0)==(0|0);
 if (!($236)) {
  HEAP32[$122>>2] = 0;
  $237 = HEAP32[$235>>2]|0;
  $238 = ((($237)) + -12|0);
  $239 = HEAP32[$238>>2]|0;
  $240 = (($235) + ($239)|0);
  $241 = ((($240)) + 8|0);
  $242 = HEAP32[$241>>2]|0;HEAP32[$241>>2] = (($242-1)|0);
  $243 = ($242|0)==(1);
  if ($243) {
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($240,1,1);
  }
 }
 $244 = HEAP32[$142>>2]|0;
 $245 = ($244|0)==(0|0);
 if (!($245)) {
  HEAP32[$142>>2] = 0;
  $246 = HEAP32[$244>>2]|0;
  $247 = ((($246)) + -12|0);
  $248 = HEAP32[$247>>2]|0;
  $249 = (($244) + ($248)|0);
  $250 = ((($249)) + 8|0);
  $251 = HEAP32[$250>>2]|0;HEAP32[$250>>2] = (($251-1)|0);
  $252 = ($251|0)==(1);
  if ($252) {
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($249,1,1);
  }
 }
 $253 = HEAP32[$162>>2]|0;
 $254 = ($253|0)==(0|0);
 do {
  if (!($254)) {
   HEAP32[$162>>2] = 0;
   $255 = HEAP32[$253>>2]|0;
   $256 = ((($255)) + -12|0);
   $257 = HEAP32[$256>>2]|0;
   $258 = (($253) + ($257)|0);
   $259 = ((($258)) + 8|0);
   $260 = HEAP32[$259>>2]|0;HEAP32[$259>>2] = (($260-1)|0);
   $261 = ($260|0)==(1);
   if (!($261)) {
    break;
   }
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($258,1,1);
  }
 } while(0);
 $262 = HEAP32[$182>>2]|0;
 $263 = ($262|0)==(0|0);
 do {
  if (!($263)) {
   HEAP32[$182>>2] = 0;
   $264 = ((($262)) + 8|0);
   $265 = HEAP32[$264>>2]|0;HEAP32[$264>>2] = (($265-1)|0);
   $266 = ($265|0)==(1);
   if (!($266)) {
    break;
   }
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($262,1,1);
  }
 } while(0);
 $267 = ((($3)) + 96|0);
 HEAP32[$267>>2] = 0;
 return;
}
function __ZN9osgViewer6Viewer12setStartTickEy($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$pre = 0, $$pre22 = 0, $$sroa$015$021 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i9 = 0, $scevgep5$i$i$i = 0, $scevgep5$i$i$i10 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = ((($0)) + 104|0);
 __ZN9osgViewer4View12setStartTickEy($4,$1,$2);
 HEAP32[$3>>2] = 0;
 $5 = ((($3)) + 4|0);
 HEAP32[$5>>2] = 0;
 $6 = ((($3)) + 8|0);
 HEAP32[$6>>2] = 0;
 $7 = HEAP32[$0>>2]|0;
 $8 = ((($7)) + 88|0);
 $9 = HEAP32[$8>>2]|0;
 __THREW__ = 0;
 invoke_viii($9|0,($0|0),($3|0),0);
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 L1: do {
  if (!($11)) {
   $12 = ((($0)) + 176|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = ((($0)) + 152|0);
   $15 = $14;
   $16 = $15;
   $17 = HEAP32[$16>>2]|0;
   $18 = (($15) + 4)|0;
   $19 = $18;
   $20 = HEAP32[$19>>2]|0;
   $21 = ((($13)) + 24|0);
   $22 = $21;
   $23 = $22;
   HEAP32[$23>>2] = $17;
   $24 = (($22) + 4)|0;
   $25 = $24;
   HEAP32[$25>>2] = $20;
   __THREW__ = 0;
   invoke_vi(3407,($13|0));
   $26 = __THREW__; __THREW__ = 0;
   $27 = $26&1;
   if (!($27)) {
    $28 = HEAP32[$3>>2]|0;
    $29 = HEAP32[$5>>2]|0;
    $30 = ($28|0)==($29|0);
    if ($30) {
     $31 = $28;$33 = $28;
    } else {
     $$sroa$015$021 = $28;$73 = $29;
     while(1) {
      $40 = HEAP32[$$sroa$015$021>>2]|0;
      $41 = ($40|0)==(0|0);
      if ($41) {
       $61 = $73;
      } else {
       $42 = (___dynamic_cast($40,24816,3888,0)|0);
       $43 = ($42|0)==(0|0);
       if ($43) {
        $61 = $73;
       } else {
        $44 = ((($42)) + 136|0);
        $45 = HEAP32[$44>>2]|0;
        $46 = $14;
        $47 = $46;
        $48 = HEAP32[$47>>2]|0;
        $49 = (($46) + 4)|0;
        $50 = $49;
        $51 = HEAP32[$50>>2]|0;
        $52 = ((($45)) + 24|0);
        $53 = $52;
        $54 = $53;
        HEAP32[$54>>2] = $48;
        $55 = (($53) + 4)|0;
        $56 = $55;
        HEAP32[$56>>2] = $51;
        __THREW__ = 0;
        invoke_vi(3407,($45|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         break L1;
        }
        $$pre = HEAP32[$5>>2]|0;
        $61 = $$pre;
       }
      }
      $59 = ((($$sroa$015$021)) + 4|0);
      $60 = ($59|0)==($61|0);
      if ($60) {
       break;
      } else {
       $$sroa$015$021 = $59;$73 = $61;
      }
     }
     $$pre22 = HEAP32[$3>>2]|0;
     $31 = $$pre22;$33 = $61;
    }
    $32 = ($31|0)==(0|0);
    if ($32) {
     STACKTOP = sp;return;
    }
    $34 = ($33|0)==($31|0);
    if (!($34)) {
     $scevgep$i$i$i9 = ((($33)) + -4|0);
     $35 = $scevgep$i$i$i9;
     $36 = $31;
     $37 = (($35) - ($36))|0;
     $38 = $37 >>> 2;
     $39 = $38 ^ -1;
     $scevgep5$i$i$i10 = (($33) + ($39<<2)|0);
     HEAP32[$5>>2] = $scevgep5$i$i$i10;
    }
    __ZdlPv($31);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $62 = ___cxa_find_matching_catch_2()|0;
 $63 = tempRet0;
 $64 = HEAP32[$3>>2]|0;
 $65 = ($64|0)==(0|0);
 if ($65) {
  ___resumeException($62|0);
  // unreachable;
 }
 $66 = HEAP32[$5>>2]|0;
 $67 = ($66|0)==($64|0);
 if (!($67)) {
  $scevgep$i$i$i = ((($66)) + -4|0);
  $68 = $scevgep$i$i$i;
  $69 = $64;
  $70 = (($68) - ($69))|0;
  $71 = $70 >>> 2;
  $72 = $71 ^ -1;
  $scevgep5$i$i$i = (($66) + ($72<<2)|0);
  HEAP32[$5>>2] = $scevgep5$i$i$i;
 }
 __ZdlPv($64);
 ___resumeException($62|0);
 // unreachable;
}
function __ZN9osgViewer6Viewer12setSceneDataEPN3osg4NodeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$sink$i$i = 0.0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0.0, $21 = 0, $22 = 0, $23 = 0.0, $24 = 0.0, $25 = 0, $26 = 0.0, $27 = 0.0;
 var $28 = 0.0, $29 = 0, $3 = 0, $30 = 0, $31 = 0.0, $32 = 0.0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0.0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__ZN3osg5Timer8instanceEv()|0);
 $3 = (__ZNK3osg5Timer4tickEv($2)|0);
 $4 = tempRet0;
 $5 = (__ZN3osg5Timer8instanceEv()|0);
 $6 = ((($0)) + 152|0);
 $7 = $6;
 $8 = $7;
 $9 = HEAP32[$8>>2]|0;
 $10 = (($7) + 4)|0;
 $11 = $10;
 $12 = HEAP32[$11>>2]|0;
 $13 = ($4>>>0)>($12>>>0);
 $14 = ($3>>>0)>($9>>>0);
 $15 = ($4|0)==($12|0);
 $16 = $15 & $14;
 $17 = $13 | $16;
 if ($17) {
  $18 = (_i64Subtract(($3|0),($4|0),($9|0),($12|0))|0);
  $19 = tempRet0;
  $20 = (+($18>>>0)) + (4294967296.0*(+($19>>>0)));
  $$sink$i$i = $20;
 } else {
  $21 = (_i64Subtract(($9|0),($12|0),($3|0),($4|0))|0);
  $22 = tempRet0;
  $23 = (+($21>>>0)) + (4294967296.0*(+($22>>>0)));
  $24 = -$23;
  $$sink$i$i = $24;
 }
 $25 = ((($5)) + 8|0);
 $26 = +HEAPF64[$25>>3];
 $27 = $$sink$i$i * $26;
 $28 = 0.0 - $27;
 $29 = (__ZN3osg5Timer8instanceEv()|0);
 $30 = ((($29)) + 8|0);
 $31 = +HEAPF64[$30>>3];
 $32 = $28 / $31;
 $33 = !($32 >= 0.0);
 if ($33) {
  $38 = -$32;
  $39 = (~~$38)>>>0;
  $40 = +Math_abs($38) >= 1.0 ? $38 > 0.0 ? (~~+Math_min(+Math_floor($38 / 4294967296.0), 4294967295.0)) >>> 0 : ~~+Math_ceil(($38 - +(~~$38 >>> 0)) / 4294967296.0) >>> 0 : 0;
  $41 = (_i64Subtract(($3|0),($4|0),($39|0),($40|0))|0);
  $42 = tempRet0;
  $46 = $41;$47 = $42;
  $43 = HEAP32[$0>>2]|0;
  $44 = ((($43)) + 160|0);
  $45 = HEAP32[$44>>2]|0;
  FUNCTION_TABLE_viii[$45 & 8191]($0,$46,$47);
  $48 = ((($0)) + 104|0);
  __ZN9osgViewer4View12setSceneDataEPN3osg4NodeE($48,$1);
  return;
 } else {
  $34 = (~~$32)>>>0;
  $35 = +Math_abs($32) >= 1.0 ? $32 > 0.0 ? (~~+Math_min(+Math_floor($32 / 4294967296.0), 4294967295.0)) >>> 0 : ~~+Math_ceil(($32 - +(~~$32 >>> 0)) / 4294967296.0) >>> 0 : 0;
  $36 = (_i64Add(($34|0),($35|0),($3|0),($4|0))|0);
  $37 = tempRet0;
  $46 = $36;$47 = $37;
  $43 = HEAP32[$0>>2]|0;
  $44 = ((($43)) + 160|0);
  $45 = HEAP32[$44>>2]|0;
  FUNCTION_TABLE_viii[$45 & 8191]($0,$46,$47);
  $48 = ((($0)) + 104|0);
  __ZN9osgViewer4View12setSceneDataEPN3osg4NodeE($48,$1);
  return;
 }
}
function __ZN9osgViewer6Viewer29setUpViewerAsEmbeddedInWindowEiiii($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0 = 0, $$014 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0.0, $15 = 0.0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0.0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = HEAP32[$0>>2]|0;
 $6 = ((($5)) + 32|0);
 $7 = HEAP32[$6>>2]|0;
 FUNCTION_TABLE_vii[$7 & 8191]($0,0);
 $8 = (__Znwj(144)|0);
 __THREW__ = 0;
 invoke_viiiii(3408,($8|0),($1|0),($2|0),($3|0),($4|0));
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if ($10) {
  $24 = ___cxa_find_matching_catch_2()|0;
  $25 = tempRet0;
  __ZdlPv($8);
  $$0 = $25;$$014 = $24;
  ___resumeException($$014|0);
  // unreachable;
 }
 $11 = ((($0)) + 120|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (__Znwj(88)|0);
 $14 = (+($3|0));
 $15 = (+($4|0));
 __THREW__ = 0;
 invoke_vi(3339,($13|0));
 $16 = __THREW__; __THREW__ = 0;
 $17 = $16&1;
 if (!($17)) {
  HEAP32[$13>>2] = (70172);
  $18 = ((($13)) + 56|0);
  $19 = ((($13)) + 72|0);
  ;HEAP32[$18>>2]=0|0;HEAP32[$18+4>>2]=0|0;HEAP32[$18+8>>2]=0|0;HEAP32[$18+12>>2]=0|0;
  HEAPF64[$19>>3] = $14;
  $20 = ((($13)) + 80|0);
  HEAPF64[$20>>3] = $15;
  __ZN3osg6Camera11setViewportEPNS_8ViewportE($12,$13);
  $21 = HEAP32[$11>>2]|0;
  $22 = $14 / $15;
  __ZN3osg6Camera32setProjectionMatrixAsPerspectiveEdddd($21,30.0,$22,1.0,1.0E+4);
  $23 = HEAP32[$11>>2]|0;
  __ZN3osg6Camera18setGraphicsContextEPNS_15GraphicsContextE($23,$8);
  return ($8|0);
 }
 $26 = ___cxa_find_matching_catch_2()|0;
 $27 = tempRet0;
 __ZdlPv($13);
 $$0 = $27;$$014 = $26;
 ___resumeException($$014|0);
 // unreachable;
 return (0)|0;
}
function __ZThn104_NK9osgViewer6Viewer9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(272)|0);
 __THREW__ = 0;
 invoke_vi(3248,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch_2()|0;
  $5 = tempRet0;
  __ZdlPv($1);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $6 = HEAP32[$1>>2]|0;
  $7 = ((($6)) + -12|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($1) + ($8)|0);
  return ($9|0);
 }
 return (0)|0;
}
function __ZThn104_NK9osgViewer6Viewer5cloneERKN3osg6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + -104|0);
 $3 = (__Znwj(272)|0);
 __THREW__ = 0;
 invoke_viii(3406,($3|0),($2|0),($1|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch_2()|0;
  $7 = tempRet0;
  __ZdlPv($3);
  ___resumeException($6|0);
  // unreachable;
 } else {
  $8 = HEAP32[$3>>2]|0;
  $9 = ((($8)) + -12|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($3) + ($10)|0);
  return ($11|0);
 }
 return (0)|0;
}
function __ZThn104_NK9osgViewer6Viewer12isSameKindAsEPKN3osg6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,4096,-1)|0);
 $phitmp$i = ($3|0)!=(0|0);
 $4 = $phitmp$i;
 return ($4|0);
}
function __ZThn104_NK9osgViewer6Viewer11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (107921|0);
}
function __ZThn104_NK9osgViewer6Viewer9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (103907|0);
}
function __ZThn104_N9osgViewer6Viewer4takeERN3osg4ViewE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + -104|0);
 __ZN9osgViewer6Viewer4takeERN3osg4ViewE($2,$1);
 return;
}
function __ZThn104_N9osgViewer6ViewerD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -104|0);
 __THREW__ = 0;
 invoke_vii(3405,($1|0),(36724|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  $11 = ((($1)) + 236|0);
  __ZN3osg6ObjectD2Ev($11);
  return;
 }
 $4 = ___cxa_find_matching_catch_2()|0;
 $5 = tempRet0;
 $6 = ((($1)) + 236|0);
 __THREW__ = 0;
 invoke_vi(388,($6|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch_3(0|0)|0;
  $10 = tempRet0;
  ___clang_call_terminate($9);
  // unreachable;
 } else {
  ___resumeException($4|0);
  // unreachable;
 }
}
function __ZThn104_N9osgViewer6ViewerD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$i$index2Z2D = 0, $eh$lpad$body$i$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -104|0);
 __THREW__ = 0;
 invoke_vii(3405,($1|0),(36724|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $7 = ___cxa_find_matching_catch_2()|0;
  $8 = tempRet0;
  $9 = ((($1)) + 236|0);
  __THREW__ = 0;
  invoke_vi(388,($9|0));
  $10 = __THREW__; __THREW__ = 0;
  $11 = $10&1;
  if ($11) {
   $12 = ___cxa_find_matching_catch_3(0|0)|0;
   $13 = tempRet0;
   ___clang_call_terminate($12);
   // unreachable;
  } else {
   $eh$lpad$body$i$index2Z2D = $8;$eh$lpad$body$i$indexZ2D = $7;
   __ZdlPv($1);
   ___resumeException($eh$lpad$body$i$indexZ2D|0);
   // unreachable;
  }
 }
 $4 = ((($1)) + 236|0);
 __THREW__ = 0;
 invoke_vi(388,($4|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if (!($6)) {
  __ZdlPv($1);
  return;
 }
 $14 = ___cxa_find_matching_catch_2()|0;
 $15 = tempRet0;
 $eh$lpad$body$i$index2Z2D = $15;$eh$lpad$body$i$indexZ2D = $14;
 __ZdlPv($1);
 ___resumeException($eh$lpad$body$i$indexZ2D|0);
 // unreachable;
}
function __ZThn104_N9osgViewer6Viewer12setStartTickEy($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + -104|0);
 __ZN9osgViewer6Viewer12setStartTickEy($3,$1,$2);
 return;
}
function __ZThn104_N9osgViewer6Viewer12setSceneDataEPN3osg4NodeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + -104|0);
 __ZN9osgViewer6Viewer12setSceneDataEPN3osg4NodeE($2,$1);
 return;
}
function __ZThn140_N9osgViewer6ViewerD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -140|0);
 __THREW__ = 0;
 invoke_vii(3405,($1|0),(36724|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  $11 = ((($1)) + 236|0);
  __ZN3osg6ObjectD2Ev($11);
  return;
 }
 $4 = ___cxa_find_matching_catch_2()|0;
 $5 = tempRet0;
 $6 = ((($1)) + 236|0);
 __THREW__ = 0;
 invoke_vi(388,($6|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch_3(0|0)|0;
  $10 = tempRet0;
  ___clang_call_terminate($9);
  // unreachable;
 } else {
  ___resumeException($4|0);
  // unreachable;
 }
}
function __ZThn140_N9osgViewer6ViewerD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$i$index2Z2D = 0, $eh$lpad$body$i$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -140|0);
 __THREW__ = 0;
 invoke_vii(3405,($1|0),(36724|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $7 = ___cxa_find_matching_catch_2()|0;
  $8 = tempRet0;
  $9 = ((($1)) + 236|0);
  __THREW__ = 0;
  invoke_vi(388,($9|0));
  $10 = __THREW__; __THREW__ = 0;
  $11 = $10&1;
  if ($11) {
   $12 = ___cxa_find_matching_catch_3(0|0)|0;
   $13 = tempRet0;
   ___clang_call_terminate($12);
   // unreachable;
  } else {
   $eh$lpad$body$i$index2Z2D = $8;$eh$lpad$body$i$indexZ2D = $7;
   __ZdlPv($1);
   ___resumeException($eh$lpad$body$i$indexZ2D|0);
   // unreachable;
  }
 }
 $4 = ((($1)) + 236|0);
 __THREW__ = 0;
 invoke_vi(388,($4|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if (!($6)) {
  __ZdlPv($1);
  return;
 }
 $14 = ___cxa_find_matching_catch_2()|0;
 $15 = tempRet0;
 $eh$lpad$body$i$index2Z2D = $15;$eh$lpad$body$i$indexZ2D = $14;
 __ZdlPv($1);
 ___resumeException($eh$lpad$body$i$indexZ2D|0);
 // unreachable;
}
function __ZTv0_n16_N9osgViewer6ViewerD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __THREW__ = 0;
 invoke_vii(3405,($4|0),(36724|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if (!($6)) {
  $14 = ((($4)) + 236|0);
  __ZN3osg6ObjectD2Ev($14);
  return;
 }
 $7 = ___cxa_find_matching_catch_2()|0;
 $8 = tempRet0;
 $9 = ((($4)) + 236|0);
 __THREW__ = 0;
 invoke_vi(388,($9|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if ($11) {
  $12 = ___cxa_find_matching_catch_3(0|0)|0;
  $13 = tempRet0;
  ___clang_call_terminate($12);
  // unreachable;
 } else {
  ___resumeException($7|0);
  // unreachable;
 }
}
function __ZTv0_n16_N9osgViewer6ViewerD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$i$index2Z2D = 0, $eh$lpad$body$i$indexZ2D = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __THREW__ = 0;
 invoke_vii(3405,($4|0),(36724|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $10 = ___cxa_find_matching_catch_2()|0;
  $11 = tempRet0;
  $12 = ((($4)) + 236|0);
  __THREW__ = 0;
  invoke_vi(388,($12|0));
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if ($14) {
   $15 = ___cxa_find_matching_catch_3(0|0)|0;
   $16 = tempRet0;
   ___clang_call_terminate($15);
   // unreachable;
  } else {
   $eh$lpad$body$i$index2Z2D = $11;$eh$lpad$body$i$indexZ2D = $10;
   __ZdlPv($4);
   ___resumeException($eh$lpad$body$i$indexZ2D|0);
   // unreachable;
  }
 }
 $7 = ((($4)) + 236|0);
 __THREW__ = 0;
 invoke_vi(388,($7|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if (!($9)) {
  __ZdlPv($4);
  return;
 }
 $17 = ___cxa_find_matching_catch_2()|0;
 $18 = tempRet0;
 $eh$lpad$body$i$index2Z2D = $18;$eh$lpad$body$i$indexZ2D = $17;
 __ZdlPv($4);
 ___resumeException($eh$lpad$body$i$indexZ2D|0);
 // unreachable;
}
function __ZTv0_n20_NK9osgViewer6Viewer9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(272)|0);
 __THREW__ = 0;
 invoke_vi(3248,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch_2()|0;
  $5 = tempRet0;
  __ZdlPv($1);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $6 = HEAP32[$1>>2]|0;
  $7 = ((($6)) + -12|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($1) + ($8)|0);
  return ($9|0);
 }
 return (0)|0;
}
function __ZTv0_n24_NK9osgViewer6Viewer5cloneERKN3osg6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $3 = ((($2)) + -24|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($0) + ($4)|0);
 $6 = (__Znwj(272)|0);
 __THREW__ = 0;
 invoke_viii(3406,($6|0),($5|0),($1|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch_2()|0;
  $10 = tempRet0;
  __ZdlPv($6);
  ___resumeException($9|0);
  // unreachable;
 } else {
  $11 = HEAP32[$6>>2]|0;
  $12 = ((($11)) + -12|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($6) + ($13)|0);
  return ($14|0);
 }
 return (0)|0;
}
function __ZTv0_n28_NK9osgViewer6Viewer12isSameKindAsEPKN3osg6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,4096,-1)|0);
 $phitmp$i = ($3|0)!=(0|0);
 $4 = $phitmp$i;
 return ($4|0);
}
function __ZTv0_n32_NK9osgViewer6Viewer11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (107921|0);
}
function __ZTv0_n36_NK9osgViewer6Viewer9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (103907|0);
}
function __ZN9osgViewer6ViewerC1ERKS0_RKN3osg6CopyOpE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$$i = 0, $$0 = 0, $$07 = 0, $$1 = 0, $$18 = 0, $$pr$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 236|0);
 $4 = HEAP32[$1>>2]|0;
 $5 = ((($4)) + -12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($1) + ($6)|0);
 __ZN3osg6ObjectC2ERKS0_RKNS_6CopyOpE($3,$7,$2);
 __THREW__ = 0;
 invoke_viii(3409,($0|0),((36728)|0),($1|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $40 = ___cxa_find_matching_catch_2()|0;
  $41 = tempRet0;
  $$1 = $41;$$18 = $40;
 } else {
  $10 = ((($0)) + 104|0);
  $11 = ((($1)) + 104|0);
  __THREW__ = 0;
  invoke_viiii(3410,($10|0),((36736)|0),($11|0),($2|0));
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if ($13) {
   $42 = ___cxa_find_matching_catch_2()|0;
   $43 = tempRet0;
   $$0 = $43;$$07 = $42;
  } else {
   HEAP32[$0>>2] = (36140);
   HEAP32[$3>>2] = (36584);
   HEAP32[$10>>2] = (36324);
   $14 = ((($0)) + 140|0);
   HEAP32[$14>>2] = (36408);
   $15 = ($0|0)==(0|0);
   if ($15) {
    $23 = 0;
    label = 5;
   } else {
    $16 = ((($0)) + 236|0);
    __THREW__ = 0;
    $17 = (invoke_ii(3325,($16|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     $23 = $17;
     label = 5;
    }
   }
   do {
    if ((label|0) == 5) {
     $20 = ((($0)) + 144|0);
     $21 = HEAP32[$20>>2]|0;
     $22 = ($21|0)==($23|0);
     if ($22) {
      $33 = $23;
     } else {
      HEAP32[$20>>2] = $23;
      $24 = ($23|0)==(0|0);
      if (!($24)) {
       $25 = ((($23)) + 8|0);
       $26 = HEAP32[$25>>2]|0;HEAP32[$25>>2] = (($26+1)|0);
      }
      $27 = ($21|0)==(0|0);
      if (!($27)) {
       $28 = ((($21)) + 8|0);
       $29 = HEAP32[$28>>2]|0;HEAP32[$28>>2] = (($29-1)|0);
       $30 = ($29|0)==(1);
       if ($30) {
        __THREW__ = 0;
        invoke_viii(3262,($21|0),1,1);
        $31 = __THREW__; __THREW__ = 0;
        $32 = $31&1;
        if ($32) {
         break;
        }
       }
      }
      $$pr$i = HEAP32[$20>>2]|0;
      $33 = $$pr$i;
     }
     $34 = ($33|0)==(0|0);
     if ($34) {
      $39 = 0;
      $38 = ((($0)) + 148|0);
      HEAP32[$38>>2] = $39;
      return;
     }
     $35 = ((($33)) + 24|0);
     $36 = HEAP32[$35>>2]|0;
     $37 = ($36|0)!=(0|0);
     $$$i = $37 ? $0 : 0;
     $39 = $$$i;
     $38 = ((($0)) + 148|0);
     HEAP32[$38>>2] = $39;
     return;
    }
   } while(0);
   $44 = ___cxa_find_matching_catch_2()|0;
   $45 = tempRet0;
   __THREW__ = 0;
   invoke_vii(3272,($10|0),((36736)|0));
   $46 = __THREW__; __THREW__ = 0;
   $47 = $46&1;
   if ($47) {
    $52 = ___cxa_find_matching_catch_3(0|0)|0;
    $53 = tempRet0;
    ___clang_call_terminate($52);
    // unreachable;
   } else {
    $$0 = $45;$$07 = $44;
   }
  }
  __THREW__ = 0;
  invoke_vii(3411,($0|0),((36728)|0));
  $48 = __THREW__; __THREW__ = 0;
  $49 = $48&1;
  if ($49) {
   $52 = ___cxa_find_matching_catch_3(0|0)|0;
   $53 = tempRet0;
   ___clang_call_terminate($52);
   // unreachable;
  } else {
   $$1 = $$0;$$18 = $$07;
  }
 }
 __THREW__ = 0;
 invoke_vi(388,($3|0));
 $50 = __THREW__; __THREW__ = 0;
 $51 = $50&1;
 if ($51) {
  $52 = ___cxa_find_matching_catch_3(0|0)|0;
  $53 = tempRet0;
  ___clang_call_terminate($52);
  // unreachable;
 } else {
  ___resumeException($$18|0);
  // unreachable;
 }
}
function __ZN9osgViewer10ViewerBaseD2Ev($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$03 = 0, $$1 = 0, $$14 = 0, $$2 = 0, $$25 = 0, $$3 = 0, $$36 = 0, $$4 = 0, $$47 = 0, $$5 = 0, $$58 = 0, $$6 = 0, $$69 = 0, $$7 = 0, $$710 = 0, $$8 = 0, $$811 = 0, $$cast = 0, $10 = 0;
 var $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0;
 var $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0;
 var $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0;
 var $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0;
 var $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0;
 var $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0;
 var $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0;
 var $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $2;
 $3 = ((($1)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $$cast = $2;
 $5 = ((($$cast)) + -12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($0) + ($6)|0);
 HEAP32[$7>>2] = $4;
 $8 = ((($0)) + 92|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if ($10) {
  label = 4;
 } else {
  $11 = ((($9)) + 8|0);
  $12 = HEAP32[$11>>2]|0;HEAP32[$11>>2] = (($12-1)|0);
  $13 = ($12|0)==(1);
  if ($13) {
   __THREW__ = 0;
   invoke_viii(3262,($9|0),1,1);
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if ($15) {
    $119 = ___cxa_find_matching_catch_2()|0;
    $120 = tempRet0;
    $121 = ((($0)) + 88|0);
    $122 = HEAP32[$121>>2]|0;
    $123 = ($122|0)==(0|0);
    if (!($123)) {
     $124 = HEAP32[$122>>2]|0;
     $125 = ((($124)) + -12|0);
     $126 = HEAP32[$125>>2]|0;
     $127 = (($122) + ($126)|0);
     $128 = ((($127)) + 8|0);
     $129 = HEAP32[$128>>2]|0;HEAP32[$128>>2] = (($129-1)|0);
     $130 = ($129|0)==(1);
     if ($130) {
      __THREW__ = 0;
      invoke_viii(3262,($127|0),1,1);
      $131 = __THREW__; __THREW__ = 0;
      $132 = $131&1;
      if ($132) {
       $242 = ___cxa_find_matching_catch_3(0|0)|0;
       $243 = tempRet0;
       ___clang_call_terminate($242);
       // unreachable;
      }
     }
    }
    HEAP32[$121>>2] = 0;
    $$0 = $120;$$03 = $119;
    label = 38;
   } else {
    label = 4;
   }
  } else {
   label = 4;
  }
 }
 do {
  if ((label|0) == 4) {
   HEAP32[$8>>2] = 0;
   $16 = ((($0)) + 88|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = ($17|0)==(0|0);
   if (!($18)) {
    $19 = HEAP32[$17>>2]|0;
    $20 = ((($19)) + -12|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($17) + ($21)|0);
    $23 = ((($22)) + 8|0);
    $24 = HEAP32[$23>>2]|0;HEAP32[$23>>2] = (($24-1)|0);
    $25 = ($24|0)==(1);
    if ($25) {
     __THREW__ = 0;
     invoke_viii(3262,($22|0),1,1);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      $133 = ___cxa_find_matching_catch_2()|0;
      $134 = tempRet0;
      $$0 = $134;$$03 = $133;
      label = 38;
      break;
     }
    }
   }
   HEAP32[$16>>2] = 0;
   $28 = ((($0)) + 84|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = ($29|0)==(0|0);
   if (!($30)) {
    $31 = HEAP32[$29>>2]|0;
    $32 = ((($31)) + -12|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = (($29) + ($33)|0);
    $35 = ((($34)) + 8|0);
    $36 = HEAP32[$35>>2]|0;HEAP32[$35>>2] = (($36-1)|0);
    $37 = ($36|0)==(1);
    if ($37) {
     __THREW__ = 0;
     invoke_viii(3262,($34|0),1,1);
     $38 = __THREW__; __THREW__ = 0;
     $39 = $38&1;
     if ($39) {
      $135 = ___cxa_find_matching_catch_2()|0;
      $136 = tempRet0;
      $$1 = $136;$$14 = $135;
      label = 43;
      break;
     }
    }
   }
   HEAP32[$28>>2] = 0;
   $40 = ((($0)) + 80|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = ($41|0)==(0|0);
   if (!($42)) {
    $43 = HEAP32[$41>>2]|0;
    $44 = ((($43)) + -12|0);
    $45 = HEAP32[$44>>2]|0;
    $46 = (($41) + ($45)|0);
    $47 = ((($46)) + 8|0);
    $48 = HEAP32[$47>>2]|0;HEAP32[$47>>2] = (($48-1)|0);
    $49 = ($48|0)==(1);
    if ($49) {
     __THREW__ = 0;
     invoke_viii(3262,($46|0),1,1);
     $50 = __THREW__; __THREW__ = 0;
     $51 = $50&1;
     if ($51) {
      $149 = ___cxa_find_matching_catch_2()|0;
      $150 = tempRet0;
      $$2 = $150;$$25 = $149;
      label = 48;
      break;
     }
    }
   }
   HEAP32[$40>>2] = 0;
   $52 = ((($0)) + 76|0);
   $53 = HEAP32[$52>>2]|0;
   $54 = ($53|0)==(0|0);
   if (!($54)) {
    $55 = HEAP32[$53>>2]|0;
    $56 = ((($55)) + -12|0);
    $57 = HEAP32[$56>>2]|0;
    $58 = (($53) + ($57)|0);
    $59 = ((($58)) + 8|0);
    $60 = HEAP32[$59>>2]|0;HEAP32[$59>>2] = (($60-1)|0);
    $61 = ($60|0)==(1);
    if ($61) {
     __THREW__ = 0;
     invoke_viii(3262,($58|0),1,1);
     $62 = __THREW__; __THREW__ = 0;
     $63 = $62&1;
     if ($63) {
      $163 = ___cxa_find_matching_catch_2()|0;
      $164 = tempRet0;
      $$3 = $164;$$36 = $163;
      label = 53;
      break;
     }
    }
   }
   HEAP32[$52>>2] = 0;
   $64 = ((($0)) + 72|0);
   $65 = HEAP32[$64>>2]|0;
   $66 = ($65|0)==(0|0);
   if (!($66)) {
    $67 = ((($65)) + 8|0);
    $68 = HEAP32[$67>>2]|0;HEAP32[$67>>2] = (($68-1)|0);
    $69 = ($68|0)==(1);
    if ($69) {
     __THREW__ = 0;
     invoke_viii(3262,($65|0),1,1);
     $70 = __THREW__; __THREW__ = 0;
     $71 = $70&1;
     if ($71) {
      $177 = ___cxa_find_matching_catch_2()|0;
      $178 = tempRet0;
      $$4 = $178;$$47 = $177;
      label = 58;
      break;
     }
    }
   }
   HEAP32[$64>>2] = 0;
   $72 = ((($0)) + 68|0);
   $73 = HEAP32[$72>>2]|0;
   $74 = ($73|0)==(0|0);
   if (!($74)) {
    $75 = HEAP32[$73>>2]|0;
    $76 = ((($75)) + -12|0);
    $77 = HEAP32[$76>>2]|0;
    $78 = (($73) + ($77)|0);
    $79 = ((($78)) + 8|0);
    $80 = HEAP32[$79>>2]|0;HEAP32[$79>>2] = (($80-1)|0);
    $81 = ($80|0)==(1);
    if ($81) {
     __THREW__ = 0;
     invoke_viii(3262,($78|0),1,1);
     $82 = __THREW__; __THREW__ = 0;
     $83 = $82&1;
     if ($83) {
      $187 = ___cxa_find_matching_catch_2()|0;
      $188 = tempRet0;
      $$5 = $188;$$58 = $187;
      label = 63;
      break;
     }
    }
   }
   HEAP32[$72>>2] = 0;
   $84 = ((($0)) + 64|0);
   $85 = HEAP32[$84>>2]|0;
   $86 = ($85|0)==(0|0);
   if (!($86)) {
    $87 = ((($85)) + 8|0);
    $88 = HEAP32[$87>>2]|0;HEAP32[$87>>2] = (($88-1)|0);
    $89 = ($88|0)==(1);
    if ($89) {
     __THREW__ = 0;
     invoke_viii(3262,($85|0),1,1);
     $90 = __THREW__; __THREW__ = 0;
     $91 = $90&1;
     if ($91) {
      $201 = ___cxa_find_matching_catch_2()|0;
      $202 = tempRet0;
      $$6 = $202;$$69 = $201;
      label = 68;
      break;
     }
    }
   }
   HEAP32[$84>>2] = 0;
   $92 = ((($0)) + 60|0);
   $93 = HEAP32[$92>>2]|0;
   $94 = ($93|0)==(0|0);
   if (!($94)) {
    $95 = HEAP32[$93>>2]|0;
    $96 = ((($95)) + -12|0);
    $97 = HEAP32[$96>>2]|0;
    $98 = (($93) + ($97)|0);
    $99 = ((($98)) + 8|0);
    $100 = HEAP32[$99>>2]|0;HEAP32[$99>>2] = (($100-1)|0);
    $101 = ($100|0)==(1);
    if ($101) {
     __THREW__ = 0;
     invoke_viii(3262,($98|0),1,1);
     $102 = __THREW__; __THREW__ = 0;
     $103 = $102&1;
     if ($103) {
      $211 = ___cxa_find_matching_catch_2()|0;
      $212 = tempRet0;
      $$7 = $212;$$710 = $211;
      break;
     }
    }
   }
   HEAP32[$92>>2] = 0;
   $104 = ((($0)) + 56|0);
   $105 = HEAP32[$104>>2]|0;
   $106 = ($105|0)==(0|0);
   if ($106) {
    HEAP32[$104>>2] = 0;
    $116 = ((($0)) + 16|0);
    $117 = ((($0)) + 20|0);
    $118 = HEAP32[$117>>2]|0;
    __ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEE7destroyEPNS_11__tree_nodeIjPvEE($116,$118);
    return;
   }
   $107 = HEAP32[$105>>2]|0;
   $108 = ((($107)) + -12|0);
   $109 = HEAP32[$108>>2]|0;
   $110 = (($105) + ($109)|0);
   $111 = ((($110)) + 8|0);
   $112 = HEAP32[$111>>2]|0;HEAP32[$111>>2] = (($112-1)|0);
   $113 = ($112|0)==(1);
   if (!($113)) {
    HEAP32[$104>>2] = 0;
    $116 = ((($0)) + 16|0);
    $117 = ((($0)) + 20|0);
    $118 = HEAP32[$117>>2]|0;
    __ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEE7destroyEPNS_11__tree_nodeIjPvEE($116,$118);
    return;
   }
   __THREW__ = 0;
   invoke_viii(3262,($110|0),1,1);
   $114 = __THREW__; __THREW__ = 0;
   $115 = $114&1;
   if (!($115)) {
    HEAP32[$104>>2] = 0;
    $116 = ((($0)) + 16|0);
    $117 = ((($0)) + 20|0);
    $118 = HEAP32[$117>>2]|0;
    __ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEE7destroyEPNS_11__tree_nodeIjPvEE($116,$118);
    return;
   }
   $225 = ___cxa_find_matching_catch_2()|0;
   $226 = tempRet0;
   $$8 = $226;$$811 = $225;
   $239 = ((($0)) + 16|0);
   $240 = ((($0)) + 20|0);
   $241 = HEAP32[$240>>2]|0;
   __ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEE7destroyEPNS_11__tree_nodeIjPvEE($239,$241);
   ___resumeException($$811|0);
   // unreachable;
  }
 } while(0);
 if ((label|0) == 38) {
  $137 = ((($0)) + 84|0);
  $138 = HEAP32[$137>>2]|0;
  $139 = ($138|0)==(0|0);
  if (!($139)) {
   $140 = HEAP32[$138>>2]|0;
   $141 = ((($140)) + -12|0);
   $142 = HEAP32[$141>>2]|0;
   $143 = (($138) + ($142)|0);
   $144 = ((($143)) + 8|0);
   $145 = HEAP32[$144>>2]|0;HEAP32[$144>>2] = (($145-1)|0);
   $146 = ($145|0)==(1);
   if ($146) {
    __THREW__ = 0;
    invoke_viii(3262,($143|0),1,1);
    $147 = __THREW__; __THREW__ = 0;
    $148 = $147&1;
    if ($148) {
     $242 = ___cxa_find_matching_catch_3(0|0)|0;
     $243 = tempRet0;
     ___clang_call_terminate($242);
     // unreachable;
    }
   }
  }
  HEAP32[$137>>2] = 0;
  $$1 = $$0;$$14 = $$03;
  label = 43;
 }
 if ((label|0) == 43) {
  $151 = ((($0)) + 80|0);
  $152 = HEAP32[$151>>2]|0;
  $153 = ($152|0)==(0|0);
  if (!($153)) {
   $154 = HEAP32[$152>>2]|0;
   $155 = ((($154)) + -12|0);
   $156 = HEAP32[$155>>2]|0;
   $157 = (($152) + ($156)|0);
   $158 = ((($157)) + 8|0);
   $159 = HEAP32[$158>>2]|0;HEAP32[$158>>2] = (($159-1)|0);
   $160 = ($159|0)==(1);
   if ($160) {
    __THREW__ = 0;
    invoke_viii(3262,($157|0),1,1);
    $161 = __THREW__; __THREW__ = 0;
    $162 = $161&1;
    if ($162) {
     $242 = ___cxa_find_matching_catch_3(0|0)|0;
     $243 = tempRet0;
     ___clang_call_terminate($242);
     // unreachable;
    }
   }
  }
  HEAP32[$151>>2] = 0;
  $$2 = $$1;$$25 = $$14;
  label = 48;
 }
 if ((label|0) == 48) {
  $165 = ((($0)) + 76|0);
  $166 = HEAP32[$165>>2]|0;
  $167 = ($166|0)==(0|0);
  if (!($167)) {
   $168 = HEAP32[$166>>2]|0;
   $169 = ((($168)) + -12|0);
   $170 = HEAP32[$169>>2]|0;
   $171 = (($166) + ($170)|0);
   $172 = ((($171)) + 8|0);
   $173 = HEAP32[$172>>2]|0;HEAP32[$172>>2] = (($173-1)|0);
   $174 = ($173|0)==(1);
   if ($174) {
    __THREW__ = 0;
    invoke_viii(3262,($171|0),1,1);
    $175 = __THREW__; __THREW__ = 0;
    $176 = $175&1;
    if ($176) {
     $242 = ___cxa_find_matching_catch_3(0|0)|0;
     $243 = tempRet0;
     ___clang_call_terminate($242);
     // unreachable;
    }
   }
  }
  HEAP32[$165>>2] = 0;
  $$3 = $$2;$$36 = $$25;
  label = 53;
 }
 if ((label|0) == 53) {
  $179 = ((($0)) + 72|0);
  $180 = HEAP32[$179>>2]|0;
  $181 = ($180|0)==(0|0);
  if (!($181)) {
   $182 = ((($180)) + 8|0);
   $183 = HEAP32[$182>>2]|0;HEAP32[$182>>2] = (($183-1)|0);
   $184 = ($183|0)==(1);
   if ($184) {
    __THREW__ = 0;
    invoke_viii(3262,($180|0),1,1);
    $185 = __THREW__; __THREW__ = 0;
    $186 = $185&1;
    if ($186) {
     $242 = ___cxa_find_matching_catch_3(0|0)|0;
     $243 = tempRet0;
     ___clang_call_terminate($242);
     // unreachable;
    }
   }
  }
  HEAP32[$179>>2] = 0;
  $$4 = $$3;$$47 = $$36;
  label = 58;
 }
 if ((label|0) == 58) {
  $189 = ((($0)) + 68|0);
  $190 = HEAP32[$189>>2]|0;
  $191 = ($190|0)==(0|0);
  if (!($191)) {
   $192 = HEAP32[$190>>2]|0;
   $193 = ((($192)) + -12|0);
   $194 = HEAP32[$193>>2]|0;
   $195 = (($190) + ($194)|0);
   $196 = ((($195)) + 8|0);
   $197 = HEAP32[$196>>2]|0;HEAP32[$196>>2] = (($197-1)|0);
   $198 = ($197|0)==(1);
   if ($198) {
    __THREW__ = 0;
    invoke_viii(3262,($195|0),1,1);
    $199 = __THREW__; __THREW__ = 0;
    $200 = $199&1;
    if ($200) {
     $242 = ___cxa_find_matching_catch_3(0|0)|0;
     $243 = tempRet0;
     ___clang_call_terminate($242);
     // unreachable;
    }
   }
  }
  HEAP32[$189>>2] = 0;
  $$5 = $$4;$$58 = $$47;
  label = 63;
 }
 if ((label|0) == 63) {
  $203 = ((($0)) + 64|0);
  $204 = HEAP32[$203>>2]|0;
  $205 = ($204|0)==(0|0);
  if (!($205)) {
   $206 = ((($204)) + 8|0);
   $207 = HEAP32[$206>>2]|0;HEAP32[$206>>2] = (($207-1)|0);
   $208 = ($207|0)==(1);
   if ($208) {
    __THREW__ = 0;
    invoke_viii(3262,($204|0),1,1);
    $209 = __THREW__; __THREW__ = 0;
    $210 = $209&1;
    if ($210) {
     $242 = ___cxa_find_matching_catch_3(0|0)|0;
     $243 = tempRet0;
     ___clang_call_terminate($242);
     // unreachable;
    }
   }
  }
  HEAP32[$203>>2] = 0;
  $$6 = $$5;$$69 = $$58;
  label = 68;
 }
 if ((label|0) == 68) {
  $213 = ((($0)) + 60|0);
  $214 = HEAP32[$213>>2]|0;
  $215 = ($214|0)==(0|0);
  if (!($215)) {
   $216 = HEAP32[$214>>2]|0;
   $217 = ((($216)) + -12|0);
   $218 = HEAP32[$217>>2]|0;
   $219 = (($214) + ($218)|0);
   $220 = ((($219)) + 8|0);
   $221 = HEAP32[$220>>2]|0;HEAP32[$220>>2] = (($221-1)|0);
   $222 = ($221|0)==(1);
   if ($222) {
    __THREW__ = 0;
    invoke_viii(3262,($219|0),1,1);
    $223 = __THREW__; __THREW__ = 0;
    $224 = $223&1;
    if ($224) {
     $242 = ___cxa_find_matching_catch_3(0|0)|0;
     $243 = tempRet0;
     ___clang_call_terminate($242);
     // unreachable;
    }
   }
  }
  HEAP32[$213>>2] = 0;
  $$7 = $$6;$$710 = $$69;
 }
 $227 = ((($0)) + 56|0);
 $228 = HEAP32[$227>>2]|0;
 $229 = ($228|0)==(0|0);
 if (!($229)) {
  $230 = HEAP32[$228>>2]|0;
  $231 = ((($230)) + -12|0);
  $232 = HEAP32[$231>>2]|0;
  $233 = (($228) + ($232)|0);
  $234 = ((($233)) + 8|0);
  $235 = HEAP32[$234>>2]|0;HEAP32[$234>>2] = (($235-1)|0);
  $236 = ($235|0)==(1);
  if ($236) {
   __THREW__ = 0;
   invoke_viii(3262,($233|0),1,1);
   $237 = __THREW__; __THREW__ = 0;
   $238 = $237&1;
   if ($238) {
    $242 = ___cxa_find_matching_catch_3(0|0)|0;
    $243 = tempRet0;
    ___clang_call_terminate($242);
    // unreachable;
   }
  }
 }
 HEAP32[$227>>2] = 0;
 $$8 = $$7;$$811 = $$710;
 $239 = ((($0)) + 16|0);
 $240 = ((($0)) + 20|0);
 $241 = HEAP32[$240>>2]|0;
 __ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEE7destroyEPNS_11__tree_nodeIjPvEE($239,$241);
 ___resumeException($$811|0);
 // unreachable;
}
function __ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEE7destroyEPNS_11__tree_nodeIjPvEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 } else {
  $3 = HEAP32[$1>>2]|0;
  __ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEE7destroyEPNS_11__tree_nodeIjPvEE($0,$3);
  $4 = ((($1)) + 4|0);
  $5 = HEAP32[$4>>2]|0;
  __ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEE7destroyEPNS_11__tree_nodeIjPvEE($0,$5);
  __ZdlPv($1);
  return;
 }
}
function __ZN9osgViewer10ViewerBaseD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vii(3411,($0|0),(37784|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  $3 = ((($0)) + 100|0);
  __ZN3osg6ObjectD2Ev($3);
  return;
 }
 $4 = ___cxa_find_matching_catch_2()|0;
 $5 = tempRet0;
 $6 = ((($0)) + 100|0);
 __THREW__ = 0;
 invoke_vi(388,($6|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch_3(0|0)|0;
  $10 = tempRet0;
  ___clang_call_terminate($9);
  // unreachable;
 } else {
  ___resumeException($4|0);
  // unreachable;
 }
}
function __ZN9osgViewer10ViewerBaseD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vii(3411,($0|0),(37784|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $6 = ___cxa_find_matching_catch_2()|0;
  $7 = tempRet0;
  $8 = ((($0)) + 100|0);
  __THREW__ = 0;
  invoke_vi(388,($8|0));
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if ($10) {
   $11 = ___cxa_find_matching_catch_3(0|0)|0;
   $12 = tempRet0;
   ___clang_call_terminate($11);
   // unreachable;
  } else {
   $eh$lpad$body$index2Z2D = $7;$eh$lpad$body$indexZ2D = $6;
   __ZdlPv($0);
   ___resumeException($eh$lpad$body$indexZ2D|0);
   // unreachable;
  }
 }
 $3 = ((($0)) + 100|0);
 __THREW__ = 0;
 invoke_vi(388,($3|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  __ZdlPv($0);
  return;
 }
 $13 = ___cxa_find_matching_catch_2()|0;
 $14 = tempRet0;
 $eh$lpad$body$index2Z2D = $14;$eh$lpad$body$indexZ2D = $13;
 __ZdlPv($0);
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
}
function __ZTv0_n16_N9osgViewer10ViewerBaseD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __THREW__ = 0;
 invoke_vii(3411,($4|0),(37784|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if (!($6)) {
  $14 = ((($4)) + 100|0);
  __ZN3osg6ObjectD2Ev($14);
  return;
 }
 $7 = ___cxa_find_matching_catch_2()|0;
 $8 = tempRet0;
 $9 = ((($4)) + 100|0);
 __THREW__ = 0;
 invoke_vi(388,($9|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if ($11) {
  $12 = ___cxa_find_matching_catch_3(0|0)|0;
  $13 = tempRet0;
  ___clang_call_terminate($12);
  // unreachable;
 } else {
  ___resumeException($7|0);
  // unreachable;
 }
}
function __ZTv0_n16_N9osgViewer10ViewerBaseD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$i$index2Z2D = 0, $eh$lpad$body$i$indexZ2D = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __THREW__ = 0;
 invoke_vii(3411,($4|0),(37784|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $10 = ___cxa_find_matching_catch_2()|0;
  $11 = tempRet0;
  $12 = ((($4)) + 100|0);
  __THREW__ = 0;
  invoke_vi(388,($12|0));
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if ($14) {
   $15 = ___cxa_find_matching_catch_3(0|0)|0;
   $16 = tempRet0;
   ___clang_call_terminate($15);
   // unreachable;
  } else {
   $eh$lpad$body$i$index2Z2D = $11;$eh$lpad$body$i$indexZ2D = $10;
   __ZdlPv($4);
   ___resumeException($eh$lpad$body$i$indexZ2D|0);
   // unreachable;
  }
 }
 $7 = ((($4)) + 100|0);
 __THREW__ = 0;
 invoke_vi(388,($7|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if (!($9)) {
  __ZdlPv($4);
  return;
 }
 $17 = ___cxa_find_matching_catch_2()|0;
 $18 = tempRet0;
 $eh$lpad$body$i$index2Z2D = $18;$eh$lpad$body$i$indexZ2D = $17;
 __ZdlPv($4);
 ___resumeException($eh$lpad$body$i$indexZ2D|0);
 // unreachable;
}
function __ZNK3osg6Object12isSameKindAsEPKS0_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 1;
}
function __ZN9osgViewer6ViewerC1Ev($0) {
 $0 = $0|0;
 var $$$i = 0, $$0 = 0, $$02 = 0, $$1 = 0, $$13 = 0, $$pr$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 236|0);
 __ZN3osg10ReferencedC2Ev($1);
 HEAP32[$1>>2] = (63412);
 $2 = ((($0)) + 248|0);
 ;HEAP32[$2>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;
 $3 = ((($0)) + 260|0);
 HEAP32[$3>>2] = 2;
 $4 = ((($0)) + 264|0);
 HEAP32[$4>>2] = 0;
 __THREW__ = 0;
 invoke_vii(3412,($0|0),((36728)|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $36 = ___cxa_find_matching_catch_2()|0;
  $37 = tempRet0;
  $$1 = $37;$$13 = $36;
 } else {
  $7 = ((($0)) + 104|0);
  __THREW__ = 0;
  invoke_vii(3413,($7|0),((36736)|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if ($9) {
   $38 = ___cxa_find_matching_catch_2()|0;
   $39 = tempRet0;
   $$0 = $39;$$02 = $38;
  } else {
   HEAP32[$0>>2] = (36140);
   HEAP32[$1>>2] = (36584);
   HEAP32[$7>>2] = (36324);
   $10 = ((($0)) + 140|0);
   HEAP32[$10>>2] = (36408);
   $11 = ((($0)) + 236|0);
   __THREW__ = 0;
   $12 = (invoke_ii(3325,($11|0))|0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   do {
    if (!($14)) {
     $15 = ((($0)) + 144|0);
     $16 = HEAP32[$15>>2]|0;
     $17 = ($16|0)==($12|0);
     if ($17) {
      $27 = $12;
     } else {
      HEAP32[$15>>2] = $12;
      $18 = ($12|0)==(0|0);
      if (!($18)) {
       $19 = ((($12)) + 8|0);
       $20 = HEAP32[$19>>2]|0;HEAP32[$19>>2] = (($20+1)|0);
      }
      $21 = ($16|0)==(0|0);
      if (!($21)) {
       $22 = ((($16)) + 8|0);
       $23 = HEAP32[$22>>2]|0;HEAP32[$22>>2] = (($23-1)|0);
       $24 = ($23|0)==(1);
       if ($24) {
        __THREW__ = 0;
        invoke_viii(3262,($16|0),1,1);
        $25 = __THREW__; __THREW__ = 0;
        $26 = $25&1;
        if ($26) {
         break;
        }
       }
      }
      $$pr$i = HEAP32[$15>>2]|0;
      $27 = $$pr$i;
     }
     $28 = ($27|0)==(0|0);
     if ($28) {
      $33 = 0;
     } else {
      $29 = ((($27)) + 24|0);
      $30 = HEAP32[$29>>2]|0;
      $31 = ($30|0)!=(0|0);
      $$$i = $31 ? $0 : 0;
      $33 = $$$i;
     }
     $32 = ((($0)) + 148|0);
     HEAP32[$32>>2] = $33;
     __THREW__ = 0;
     invoke_vi(3414,($0|0));
     $34 = __THREW__; __THREW__ = 0;
     $35 = $34&1;
     if (!($35)) {
      return;
     }
    }
   } while(0);
   $40 = ___cxa_find_matching_catch_2()|0;
   $41 = tempRet0;
   __THREW__ = 0;
   invoke_vii(3272,($7|0),((36736)|0));
   $42 = __THREW__; __THREW__ = 0;
   $43 = $42&1;
   if ($43) {
    $48 = ___cxa_find_matching_catch_3(0|0)|0;
    $49 = tempRet0;
    ___clang_call_terminate($48);
    // unreachable;
   } else {
    $$0 = $41;$$02 = $40;
   }
  }
  __THREW__ = 0;
  invoke_vii(3411,($0|0),((36728)|0));
  $44 = __THREW__; __THREW__ = 0;
  $45 = $44&1;
  if ($45) {
   $48 = ___cxa_find_matching_catch_3(0|0)|0;
   $49 = tempRet0;
   ___clang_call_terminate($48);
   // unreachable;
  } else {
   $$1 = $$0;$$13 = $$02;
  }
 }
 __THREW__ = 0;
 invoke_vi(388,($1|0));
 $46 = __THREW__; __THREW__ = 0;
 $47 = $46&1;
 if ($47) {
  $48 = ___cxa_find_matching_catch_3(0|0)|0;
  $49 = tempRet0;
  ___clang_call_terminate($48);
  // unreachable;
 } else {
  ___resumeException($$13|0);
  // unreachable;
 }
}
function __ZN9osgViewer6Viewer15constructorInitEv($0) {
 $0 = $0|0;
 var $$0 = 0, $$14 = 0, $$16 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $2 = (__Znwj(112)|0);
 __THREW__ = 0;
 invoke_vi(3415,($2|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $81 = ___cxa_find_matching_catch_2()|0;
  $82 = tempRet0;
  __ZdlPv($2);
  $$14 = $82;$$16 = $81;
  ___resumeException($$16|0);
  // unreachable;
 }
 $5 = ((($0)) + 68|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==($2|0);
 if (!($7)) {
  HEAP32[$5>>2] = $2;
  $8 = HEAP32[$2>>2]|0;
  $9 = ((($8)) + -12|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($2) + ($10)|0);
  $12 = ((($11)) + 8|0);
  $13 = HEAP32[$12>>2]|0;HEAP32[$12>>2] = (($13+1)|0);
  $14 = ($6|0)==(0|0);
  if (!($14)) {
   $15 = HEAP32[$6>>2]|0;
   $16 = ((($15)) + -12|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (($6) + ($17)|0);
   $19 = ((($18)) + 8|0);
   $20 = HEAP32[$19>>2]|0;HEAP32[$19>>2] = (($20-1)|0);
   $21 = ($20|0)==(1);
   if ($21) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($18,1,1);
   }
  }
 }
 $22 = HEAP32[$5>>2]|0;
 $23 = ((($0)) + 140|0);
 $24 = ((($22)) + 56|0);
 HEAP32[$24>>2] = $23;
 $25 = ((($0)) + 136|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ((($22)) + 12|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = ($28|0)==($26|0);
 if (!($29)) {
  HEAP32[$27>>2] = $26;
  $30 = ($26|0)==(0|0);
  if (!($30)) {
   $31 = ((($26)) + 8|0);
   $32 = HEAP32[$31>>2]|0;HEAP32[$31>>2] = (($32+1)|0);
  }
  $33 = ($28|0)==(0|0);
  if (!($33)) {
   $34 = ((($28)) + 8|0);
   $35 = HEAP32[$34>>2]|0;HEAP32[$34>>2] = (($35-1)|0);
   $36 = ($35|0)==(1);
   if ($36) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($28,1,1);
   }
  }
 }
 $37 = (__Znwj(88)|0);
 __THREW__ = 0;
 invoke_vi(3416,($37|0));
 $38 = __THREW__; __THREW__ = 0;
 $39 = $38&1;
 if ($39) {
  $83 = ___cxa_find_matching_catch_2()|0;
  $84 = tempRet0;
  __ZdlPv($37);
  $$14 = $84;$$16 = $83;
  ___resumeException($$16|0);
  // unreachable;
 }
 $40 = ((($0)) + 76|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = ($41|0)==($37|0);
 if (!($42)) {
  HEAP32[$40>>2] = $37;
  $43 = HEAP32[$37>>2]|0;
  $44 = ((($43)) + -12|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = (($37) + ($45)|0);
  $47 = ((($46)) + 8|0);
  $48 = HEAP32[$47>>2]|0;HEAP32[$47>>2] = (($48+1)|0);
  $49 = ($41|0)==(0|0);
  if (!($49)) {
   $50 = HEAP32[$41>>2]|0;
   $51 = ((($50)) + -12|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = (($41) + ($52)|0);
   $54 = ((($53)) + 8|0);
   $55 = HEAP32[$54>>2]|0;HEAP32[$54>>2] = (($55-1)|0);
   $56 = ($55|0)==(1);
   if ($56) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($53,1,1);
   }
  }
 }
 $57 = HEAP32[$40>>2]|0;
 $58 = HEAP32[$25>>2]|0;
 $59 = ((($57)) + 12|0);
 $60 = HEAP32[$59>>2]|0;
 $61 = ($60|0)==($58|0);
 if (!($61)) {
  HEAP32[$59>>2] = $58;
  $62 = ($58|0)==(0|0);
  if (!($62)) {
   $63 = ((($58)) + 8|0);
   $64 = HEAP32[$63>>2]|0;HEAP32[$63>>2] = (($64+1)|0);
  }
  $65 = ($60|0)==(0|0);
  if (!($65)) {
   $66 = ((($60)) + 8|0);
   $67 = HEAP32[$66>>2]|0;HEAP32[$66>>2] = (($67-1)|0);
   $68 = ($67|0)==(1);
   if ($68) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($60,1,1);
   }
  }
 }
 $69 = HEAP32[$0>>2]|0;
 $70 = HEAP32[$69>>2]|0;
 $71 = (__Znwj(80)|0);
 ;HEAP32[$1>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;
 $72 = ((($1)) + 11|0);
 HEAP8[$72>>0] = 6;
 ;HEAP8[$1>>0]=HEAP8[103907>>0]|0;HEAP8[$1+1>>0]=HEAP8[103907+1>>0]|0;HEAP8[$1+2>>0]=HEAP8[103907+2>>0]|0;HEAP8[$1+3>>0]=HEAP8[103907+3>>0]|0;HEAP8[$1+4>>0]=HEAP8[103907+4>>0]|0;HEAP8[$1+5>>0]=HEAP8[103907+5>>0]|0;
 $73 = ((($1)) + 6|0);
 HEAP8[$73>>0] = 0;
 __THREW__ = 0;
 invoke_vii(3274,($71|0),($1|0));
 $74 = __THREW__; __THREW__ = 0;
 $75 = $74&1;
 if ($75) {
  $$0 = 1;
 } else {
  __THREW__ = 0;
  invoke_vii($70|0,($0|0),($71|0));
  $76 = __THREW__; __THREW__ = 0;
  $77 = $76&1;
  if ($77) {
   $$0 = 0;
  } else {
   $78 = HEAP8[$72>>0]|0;
   $79 = ($78<<24>>24)<(0);
   if (!($79)) {
    STACKTOP = sp;return;
   }
   $80 = HEAP32[$1>>2]|0;
   __ZdlPv($80);
   STACKTOP = sp;return;
  }
 }
 $85 = ___cxa_find_matching_catch_2()|0;
 $86 = tempRet0;
 $87 = HEAP8[$72>>0]|0;
 $88 = ($87<<24>>24)<(0);
 if ($88) {
  $89 = HEAP32[$1>>2]|0;
  __ZdlPv($89);
  if (!($$0)) {
   $$14 = $86;$$16 = $85;
   ___resumeException($$16|0);
   // unreachable;
  }
 } else {
  if (!($$0)) {
   $$14 = $86;$$16 = $85;
   ___resumeException($$16|0);
   // unreachable;
  }
 }
 __ZdlPv($71);
 $$14 = $86;$$16 = $85;
 ___resumeException($$16|0);
 // unreachable;
}
function __ZN9osgViewer6ViewerD2Ev($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$2 = 0, $$212 = 0, $$5 = 0, $$515 = 0, $$cast = 0, $$pre$phiZ2D = 0, $$sink50$index = 0, $$sink50$index8 = 0, $$sroa$045$051 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0;
 var $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0;
 var $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0;
 var $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0;
 var $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i19 = 0, $scevgep$i$i$i22 = 0, $scevgep$i$i$i27 = 0, $scevgep5$i$i$i = 0, $scevgep5$i$i$i20 = 0, $scevgep5$i$i$i23 = 0;
 var $scevgep5$i$i$i28 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $2 = sp + 28|0;
 $3 = sp + 24|0;
 $4 = sp + 12|0;
 $5 = sp;
 $6 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $6;
 $7 = ((($1)) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $$cast = $6;
 $9 = ((($$cast)) + -12|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($0) + ($10)|0);
 HEAP32[$11>>2] = $8;
 $12 = ((($1)) + 32|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($0)) + 104|0);
 HEAP32[$14>>2] = $13;
 $15 = ((($0)) + 140|0);
 HEAP32[$15>>2] = (36408);
 HEAP32[$4>>2] = 0;
 $16 = ((($4)) + 4|0);
 HEAP32[$16>>2] = 0;
 $17 = ((($4)) + 8|0);
 HEAP32[$17>>2] = 0;
 $18 = HEAP32[$0>>2]|0;
 $19 = ((($18)) + 96|0);
 $20 = HEAP32[$19>>2]|0;
 __THREW__ = 0;
 invoke_viii($20|0,($0|0),($4|0),1);
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 L1: do {
  if ($22) {
   label = 16;
  } else {
   __THREW__ = 0;
   $23 = (invoke_ii(3265,4)|0);
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   if ($25) {
    label = 16;
   } else {
    do {
     if ($23) {
      __THREW__ = 0;
      $26 = (invoke_ii(3266,4)|0);
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       label = 16;
       break L1;
      }
      __THREW__ = 0;
      $29 = (invoke_iiii(3267,($26|0),(103914|0),50)|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 16;
       break L1;
      }
      $32 = HEAP32[$16>>2]|0;
      $33 = HEAP32[$4>>2]|0;
      $34 = (($32) - ($33))|0;
      $35 = $34 >> 2;
      __THREW__ = 0;
      $36 = (invoke_iii(3417,($29|0),($35|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       label = 16;
       break L1;
      }
      $39 = HEAP32[$36>>2]|0;
      $40 = ((($39)) + -12|0);
      $41 = HEAP32[$40>>2]|0;
      $42 = (($36) + ($41)|0);
      __THREW__ = 0;
      invoke_vii(3257,($3|0),($42|0));
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 16;
       break L1;
      }
      __THREW__ = 0;
      $45 = (invoke_iii(3255,($3|0),(215188|0))|0);
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if (!($47)) {
       $48 = HEAP32[$45>>2]|0;
       $49 = ((($48)) + 28|0);
       $50 = HEAP32[$49>>2]|0;
       __THREW__ = 0;
       $51 = (invoke_iii($50|0,($45|0),10)|0);
       $52 = __THREW__; __THREW__ = 0;
       $53 = $52&1;
       if (!($53)) {
        __THREW__ = 0;
        invoke_vi(3263,($3|0));
        $60 = __THREW__; __THREW__ = 0;
        $61 = $60&1;
        if ($61) {
         label = 16;
         break L1;
        }
        __THREW__ = 0;
        (invoke_iii(3268,($36|0),($51|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 16;
         break L1;
        }
        __THREW__ = 0;
        (invoke_ii(3269,($36|0))|0);
        $64 = __THREW__; __THREW__ = 0;
        $65 = $64&1;
        if ($65) {
         label = 16;
         break L1;
        } else {
         break;
        }
       }
      }
      $54 = ___cxa_find_matching_catch_2()|0;
      $55 = tempRet0;
      __THREW__ = 0;
      invoke_vi(3263,($3|0));
      $56 = __THREW__; __THREW__ = 0;
      $57 = $56&1;
      if ($57) {
       $58 = ___cxa_find_matching_catch_3(0|0)|0;
       $59 = tempRet0;
       ___clang_call_terminate($58);
       // unreachable;
      } else {
       $eh$lpad$body$index2Z2D = $55;$eh$lpad$body$indexZ2D = $54;
       label = 17;
       break L1;
      }
     }
    } while(0);
    $68 = HEAP32[$0>>2]|0;
    $69 = ((($68)) + 44|0);
    $70 = HEAP32[$69>>2]|0;
    __THREW__ = 0;
    invoke_vi($70|0,($0|0));
    $71 = __THREW__; __THREW__ = 0;
    $72 = $71&1;
    if ($72) {
     label = 16;
    } else {
     $73 = ((($0)) + 172|0);
     $74 = HEAP32[$73>>2]|0;
     $75 = ($74|0)==(0|0);
     if (!($75)) {
      $76 = ((($74)) + 16|0);
      $77 = HEAP32[$76>>2]|0;
      $78 = ($77|0)==(0|0);
      if (!($78)) {
       $79 = HEAP32[$77>>2]|0;
       $80 = ((($79)) + 24|0);
       $81 = HEAP32[$80>>2]|0;
       __THREW__ = 0;
       (invoke_ii($81|0,($77|0))|0);
       $82 = __THREW__; __THREW__ = 0;
       $83 = $82&1;
       if ($83) {
        label = 16;
        break;
       }
       $84 = HEAP32[$73>>2]|0;
       __THREW__ = 0;
       invoke_vii(3418,($84|0),(0|0));
       $85 = __THREW__; __THREW__ = 0;
       $86 = $85&1;
       if ($86) {
        label = 16;
        break;
       }
      }
     }
     HEAP32[$5>>2] = 0;
     $87 = ((($5)) + 4|0);
     HEAP32[$87>>2] = 0;
     $88 = ((($5)) + 8|0);
     HEAP32[$88>>2] = 0;
     $89 = HEAP32[$0>>2]|0;
     $90 = ((($89)) + 88|0);
     $91 = HEAP32[$90>>2]|0;
     __THREW__ = 0;
     invoke_viii($91|0,($0|0),($5|0),1);
     $92 = __THREW__; __THREW__ = 0;
     $93 = $92&1;
     L26: do {
      if ($93) {
       label = 27;
      } else {
       $94 = HEAP32[$5>>2]|0;
       $95 = HEAP32[$87>>2]|0;
       $96 = ($94|0)==($95|0);
       L28: do {
        if (!($96)) {
         $97 = ((($0)) + 84|0);
         $$sroa$045$051 = $94;
         while(1) {
          $105 = HEAP32[$$sroa$045$051>>2]|0;
          $106 = HEAP32[$97>>2]|0;
          $107 = ($106|0)==(0|0);
          if (!($107)) {
           $108 = HEAP32[$105>>2]|0;
           $109 = ((($108)) + 144|0);
           $110 = HEAP32[$109>>2]|0;
           __THREW__ = 0;
           $111 = (invoke_ii($110|0,($105|0))|0);
           $112 = __THREW__; __THREW__ = 0;
           $113 = $112&1;
           if ($113) {
            break;
           }
           if ($111) {
            __THREW__ = 0;
            (invoke_ii(3381,($105|0))|0);
            $114 = __THREW__; __THREW__ = 0;
            $115 = $114&1;
            if ($115) {
             break;
            }
            $116 = HEAP32[$97>>2]|0;
            $117 = HEAP32[$116>>2]|0;
            $118 = ((($117)) + 4|0);
            $119 = HEAP32[$118>>2]|0;
            __THREW__ = 0;
            invoke_vii($119|0,($116|0),($105|0));
            $120 = __THREW__; __THREW__ = 0;
            $121 = $120&1;
            if ($121) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(3382,($105|0))|0);
            $122 = __THREW__; __THREW__ = 0;
            $123 = $122&1;
            if ($123) {
             break;
            }
           }
          }
          __THREW__ = 0;
          invoke_vii(3398,($105|0),1);
          $126 = __THREW__; __THREW__ = 0;
          $127 = $126&1;
          if ($127) {
           break;
          }
          $128 = ((($$sroa$045$051)) + 4|0);
          $129 = HEAP32[$87>>2]|0;
          $130 = ($128|0)==($129|0);
          if ($130) {
           break L28;
          } else {
           $$sroa$045$051 = $128;
          }
         }
         $124 = ___cxa_find_matching_catch_2()|0;
         $125 = tempRet0;
         $$sink50$index = $124;$$sink50$index8 = $125;
         break L26;
        }
       } while(0);
       $98 = HEAP32[$0>>2]|0;
       $99 = ((($98)) + 96|0);
       $100 = HEAP32[$99>>2]|0;
       __THREW__ = 0;
       invoke_viii($100|0,($0|0),($4|0),1);
       $101 = __THREW__; __THREW__ = 0;
       $102 = $101&1;
       if ($102) {
        label = 27;
       } else {
        __THREW__ = 0;
        $131 = (invoke_ii(3265,4)|0);
        $132 = __THREW__; __THREW__ = 0;
        $133 = $132&1;
        if ($133) {
         label = 27;
        } else {
         do {
          if ($131) {
           __THREW__ = 0;
           $134 = (invoke_ii(3266,4)|0);
           $135 = __THREW__; __THREW__ = 0;
           $136 = $135&1;
           if ($136) {
            label = 27;
            break L26;
           }
           __THREW__ = 0;
           $137 = (invoke_iiii(3267,($134|0),(103965|0),46)|0);
           $138 = __THREW__; __THREW__ = 0;
           $139 = $138&1;
           if ($139) {
            label = 27;
            break L26;
           }
           $140 = HEAP32[$16>>2]|0;
           $141 = HEAP32[$4>>2]|0;
           $142 = (($140) - ($141))|0;
           $143 = $142 >> 2;
           __THREW__ = 0;
           $144 = (invoke_iii(3417,($137|0),($143|0))|0);
           $145 = __THREW__; __THREW__ = 0;
           $146 = $145&1;
           if ($146) {
            label = 27;
            break L26;
           }
           $147 = HEAP32[$144>>2]|0;
           $148 = ((($147)) + -12|0);
           $149 = HEAP32[$148>>2]|0;
           $150 = (($144) + ($149)|0);
           __THREW__ = 0;
           invoke_vii(3257,($2|0),($150|0));
           $151 = __THREW__; __THREW__ = 0;
           $152 = $151&1;
           if ($152) {
            label = 27;
            break L26;
           }
           __THREW__ = 0;
           $153 = (invoke_iii(3255,($2|0),(215188|0))|0);
           $154 = __THREW__; __THREW__ = 0;
           $155 = $154&1;
           if (!($155)) {
            $156 = HEAP32[$153>>2]|0;
            $157 = ((($156)) + 28|0);
            $158 = HEAP32[$157>>2]|0;
            __THREW__ = 0;
            $159 = (invoke_iii($158|0,($153|0),10)|0);
            $160 = __THREW__; __THREW__ = 0;
            $161 = $160&1;
            if (!($161)) {
             __THREW__ = 0;
             invoke_vi(3263,($2|0));
             $168 = __THREW__; __THREW__ = 0;
             $169 = $168&1;
             if ($169) {
              label = 27;
              break L26;
             }
             __THREW__ = 0;
             (invoke_iii(3268,($144|0),($159|0))|0);
             $170 = __THREW__; __THREW__ = 0;
             $171 = $170&1;
             if ($171) {
              label = 27;
              break L26;
             }
             __THREW__ = 0;
             (invoke_ii(3269,($144|0))|0);
             $172 = __THREW__; __THREW__ = 0;
             $173 = $172&1;
             if ($173) {
              label = 27;
              break L26;
             } else {
              break;
             }
            }
           }
           $162 = ___cxa_find_matching_catch_2()|0;
           $163 = tempRet0;
           __THREW__ = 0;
           invoke_vi(3263,($2|0));
           $164 = __THREW__; __THREW__ = 0;
           $165 = $164&1;
           if ($165) {
            $166 = ___cxa_find_matching_catch_3(0|0)|0;
            $167 = tempRet0;
            ___clang_call_terminate($166);
            // unreachable;
           } else {
            $$sink50$index = $162;$$sink50$index8 = $163;
            break L26;
           }
          }
         } while(0);
         $174 = HEAP32[$5>>2]|0;
         $175 = ($174|0)==(0|0);
         if (!($175)) {
          $176 = HEAP32[$87>>2]|0;
          $177 = ($176|0)==($174|0);
          if (!($177)) {
           $scevgep$i$i$i27 = ((($176)) + -4|0);
           $178 = $scevgep$i$i$i27;
           $179 = $174;
           $180 = (($178) - ($179))|0;
           $181 = $180 >>> 2;
           $182 = $181 ^ -1;
           $scevgep5$i$i$i28 = (($176) + ($182<<2)|0);
           HEAP32[$87>>2] = $scevgep5$i$i$i28;
          }
          __ZdlPv($174);
         }
         $183 = HEAP32[$4>>2]|0;
         $184 = ($183|0)==(0|0);
         if (!($184)) {
          $185 = HEAP32[$16>>2]|0;
          $186 = ($185|0)==($183|0);
          if (!($186)) {
           $scevgep$i$i$i22 = ((($185)) + -4|0);
           $187 = $scevgep$i$i$i22;
           $188 = $183;
           $189 = (($187) - ($188))|0;
           $190 = $189 >>> 2;
           $191 = $190 ^ -1;
           $scevgep5$i$i$i23 = (($185) + ($191<<2)|0);
           HEAP32[$16>>2] = $scevgep5$i$i$i23;
          }
          __ZdlPv($183);
         }
         $192 = ((($1)) + 12|0);
         __THREW__ = 0;
         invoke_vii(3272,($14|0),($192|0));
         $193 = __THREW__; __THREW__ = 0;
         $194 = $193&1;
         if ($194) {
          $214 = ___cxa_find_matching_catch_2()|0;
          $215 = tempRet0;
          $$5 = $214;$$515 = $215;$$pre$phiZ2D = $0;
          break L1;
         } else {
          $195 = ((($1)) + 4|0);
          __ZN9osgViewer10ViewerBaseD2Ev($0,$195);
          STACKTOP = sp;return;
         }
        }
       }
      }
     } while(0);
     if ((label|0) == 27) {
      $103 = ___cxa_find_matching_catch_2()|0;
      $104 = tempRet0;
      $$sink50$index = $103;$$sink50$index8 = $104;
     }
     $196 = HEAP32[$5>>2]|0;
     $197 = ($196|0)==(0|0);
     if (!($197)) {
      $198 = HEAP32[$87>>2]|0;
      $199 = ($198|0)==($196|0);
      if (!($199)) {
       $scevgep$i$i$i19 = ((($198)) + -4|0);
       $200 = $scevgep$i$i$i19;
       $201 = $196;
       $202 = (($200) - ($201))|0;
       $203 = $202 >>> 2;
       $204 = $203 ^ -1;
       $scevgep5$i$i$i20 = (($198) + ($204<<2)|0);
       HEAP32[$87>>2] = $scevgep5$i$i$i20;
      }
      __ZdlPv($196);
     }
     $$2 = $$sink50$index;$$212 = $$sink50$index8;
     label = 66;
    }
   }
  }
 } while(0);
 if ((label|0) == 16) {
  $66 = ___cxa_find_matching_catch_2()|0;
  $67 = tempRet0;
  $eh$lpad$body$index2Z2D = $67;$eh$lpad$body$indexZ2D = $66;
  label = 17;
 }
 if ((label|0) == 17) {
  $$2 = $eh$lpad$body$indexZ2D;$$212 = $eh$lpad$body$index2Z2D;
  label = 66;
 }
 do {
  if ((label|0) == 66) {
   $205 = HEAP32[$4>>2]|0;
   $206 = ($205|0)==(0|0);
   if (!($206)) {
    $207 = HEAP32[$16>>2]|0;
    $208 = ($207|0)==($205|0);
    if (!($208)) {
     $scevgep$i$i$i = ((($207)) + -4|0);
     $209 = $scevgep$i$i$i;
     $210 = $205;
     $211 = (($209) - ($210))|0;
     $212 = $211 >>> 2;
     $213 = $212 ^ -1;
     $scevgep5$i$i$i = (($207) + ($213<<2)|0);
     HEAP32[$16>>2] = $scevgep5$i$i$i;
    }
    __ZdlPv($205);
   }
   $216 = ((($1)) + 12|0);
   __THREW__ = 0;
   invoke_vii(3272,($14|0),($216|0));
   $217 = __THREW__; __THREW__ = 0;
   $218 = $217&1;
   if ($218) {
    $222 = ___cxa_find_matching_catch_3(0|0)|0;
    $223 = tempRet0;
    ___clang_call_terminate($222);
    // unreachable;
   } else {
    $$5 = $$2;$$515 = $$212;$$pre$phiZ2D = $0;
    break;
   }
  }
 } while(0);
 $219 = ((($1)) + 4|0);
 __THREW__ = 0;
 invoke_vii(3411,($$pre$phiZ2D|0),($219|0));
 $220 = __THREW__; __THREW__ = 0;
 $221 = $220&1;
 if ($221) {
  $222 = ___cxa_find_matching_catch_3(0|0)|0;
  $223 = tempRet0;
  ___clang_call_terminate($222);
  // unreachable;
 } else {
  ___resumeException($$5|0);
  // unreachable;
 }
}
function __ZN9osgViewer22GraphicsWindowEmbeddedC2Eiiii($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0 = 0, $$06 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN9osgViewer14GraphicsWindowC2Ev($0);
 HEAP32[$0>>2] = (36768);
 $5 = ((($0)) + 132|0);
 HEAP32[$5>>2] = (37032);
 __THREW__ = 0;
 $6 = (invoke_ii(3276,200)|0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 do {
  if ($8) {
   label = 9;
  } else {
   __THREW__ = 0;
   invoke_vii(3419,($6|0),(0|0));
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if ($10) {
    $31 = ___cxa_find_matching_catch_2()|0;
    $32 = tempRet0;
    __ZdlPv($6);
    $$0 = $32;$$06 = $31;
    break;
   }
   $11 = ((($0)) + 44|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = ($12|0)==($6|0);
   if (!($13)) {
    HEAP32[$11>>2] = $6;
    $14 = ((($6)) + 8|0);
    $15 = HEAP32[$14>>2]|0;HEAP32[$14>>2] = (($15+1)|0);
    $16 = ($12|0)==(0|0);
    if (!($16)) {
     $17 = ((($12)) + 8|0);
     $18 = HEAP32[$17>>2]|0;HEAP32[$17>>2] = (($18-1)|0);
     $19 = ($18|0)==(1);
     if ($19) {
      __THREW__ = 0;
      invoke_viii(3262,($12|0),1,1);
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if ($21) {
       label = 9;
       break;
      }
     }
    }
   }
   $22 = HEAP32[$11>>2]|0;
   $23 = ((($22)) + 32|0);
   HEAP32[$23>>2] = $1;
   $24 = ((($22)) + 36|0);
   HEAP32[$24>>2] = $2;
   $25 = ((($22)) + 40|0);
   HEAP32[$25>>2] = $3;
   $26 = ((($22)) + 44|0);
   HEAP32[$26>>2] = $4;
   __THREW__ = 0;
   invoke_vi(3420,($0|0));
   $27 = __THREW__; __THREW__ = 0;
   $28 = $27&1;
   if ($28) {
    label = 9;
   } else {
    return;
   }
  }
 } while(0);
 if ((label|0) == 9) {
  $29 = ___cxa_find_matching_catch_2()|0;
  $30 = tempRet0;
  $$0 = $30;$$06 = $29;
 }
 HEAP32[$0>>2] = (34776);
 HEAP32[$5>>2] = (35040);
 $33 = ((($0)) + 136|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)==(0|0);
 if (!($35)) {
  $36 = ((($34)) + 8|0);
  $37 = HEAP32[$36>>2]|0;HEAP32[$36>>2] = (($37-1)|0);
  $38 = ($37|0)==(1);
  if ($38) {
   __THREW__ = 0;
   invoke_viii(3262,($34|0),1,1);
   $39 = __THREW__; __THREW__ = 0;
   $40 = $39&1;
   if ($40) {
    $43 = ___cxa_find_matching_catch_3(0|0)|0;
    $44 = tempRet0;
    __THREW__ = 0;
    invoke_vi(1871,($0|0));
    $45 = __THREW__; __THREW__ = 0;
    $46 = $45&1;
    if ($46) {
     $47 = ___cxa_find_matching_catch_3(0|0)|0;
     $48 = tempRet0;
     ___clang_call_terminate($47);
     // unreachable;
    } else {
     $eh$lpad$body$indexZ2D = $43;
     ___clang_call_terminate($eh$lpad$body$indexZ2D);
     // unreachable;
    }
   }
  }
 }
 HEAP32[$33>>2] = 0;
 __THREW__ = 0;
 invoke_vi(1871,($0|0));
 $41 = __THREW__; __THREW__ = 0;
 $42 = $41&1;
 if (!($42)) {
  ___resumeException($$06|0);
  // unreachable;
 }
 $49 = ___cxa_find_matching_catch_3(0|0)|0;
 $50 = tempRet0;
 $eh$lpad$body$indexZ2D = $49;
 ___clang_call_terminate($eh$lpad$body$indexZ2D);
 // unreachable;
}
function __ZN9osgViewer14GraphicsWindowC2Ev($0) {
 $0 = $0|0;
 var $$$i$i$i = 0, $$0 = 0, $$02 = 0, $$pr$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg15GraphicsContextC2Ev($0);
 $1 = ((($0)) + 132|0);
 HEAP32[$0>>2] = (34776);
 HEAP32[$1>>2] = (35040);
 $2 = ((($0)) + 136|0);
 HEAP32[$2>>2] = 0;
 __THREW__ = 0;
 $3 = (invoke_ii(3276,64)|0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 do {
  if ($5) {
   label = 18;
  } else {
   __THREW__ = 0;
   invoke_vii(3292,($3|0),1);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if ($7) {
    $45 = ___cxa_find_matching_catch_2()|0;
    $46 = tempRet0;
    __ZdlPv($3);
    $$0 = $46;$$02 = $45;
    break;
   }
   $8 = HEAP32[$2>>2]|0;
   $9 = ($8|0)==($3|0);
   if (!($9)) {
    HEAP32[$2>>2] = $3;
    $10 = ((($3)) + 8|0);
    $11 = HEAP32[$10>>2]|0;HEAP32[$10>>2] = (($11+1)|0);
    $12 = ($8|0)==(0|0);
    if (!($12)) {
     $13 = ((($8)) + 8|0);
     $14 = HEAP32[$13>>2]|0;HEAP32[$13>>2] = (($14-1)|0);
     $15 = ($14|0)==(1);
     if ($15) {
      __THREW__ = 0;
      invoke_viii(3262,($8|0),1,1);
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if ($17) {
       label = 18;
       break;
      }
     }
    }
   }
   $18 = HEAP32[$2>>2]|0;
   $19 = ((($18)) + 12|0);
   $20 = HEAP32[$19>>2]|0;
   __THREW__ = 0;
   $21 = (invoke_ii(3325,($0|0))|0);
   $22 = __THREW__; __THREW__ = 0;
   $23 = $22&1;
   if ($23) {
    label = 18;
   } else {
    $24 = ((($20)) + 52|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = ($25|0)==($21|0);
    if ($26) {
     $36 = $21;
    } else {
     HEAP32[$24>>2] = $21;
     $27 = ($21|0)==(0|0);
     if (!($27)) {
      $28 = ((($21)) + 8|0);
      $29 = HEAP32[$28>>2]|0;HEAP32[$28>>2] = (($29+1)|0);
     }
     $30 = ($25|0)==(0|0);
     if (!($30)) {
      $31 = ((($25)) + 8|0);
      $32 = HEAP32[$31>>2]|0;HEAP32[$31>>2] = (($32-1)|0);
      $33 = ($32|0)==(1);
      if ($33) {
       __THREW__ = 0;
       invoke_viii(3262,($25|0),1,1);
       $34 = __THREW__; __THREW__ = 0;
       $35 = $34&1;
       if ($35) {
        label = 18;
        break;
       }
      }
     }
     $$pr$i$i$i = HEAP32[$24>>2]|0;
     $36 = $$pr$i$i$i;
    }
    $37 = ($36|0)==(0|0);
    if ($37) {
     $42 = 0;
     $41 = ((($20)) + 56|0);
     HEAP32[$41>>2] = $42;
     return;
    }
    $38 = ((($36)) + 24|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = ($39|0)!=(0|0);
    $$$i$i$i = $40 ? $0 : 0;
    $42 = $$$i$i$i;
    $41 = ((($20)) + 56|0);
    HEAP32[$41>>2] = $42;
    return;
   }
  }
 } while(0);
 if ((label|0) == 18) {
  $43 = ___cxa_find_matching_catch_2()|0;
  $44 = tempRet0;
  $$0 = $44;$$02 = $43;
 }
 $47 = HEAP32[$2>>2]|0;
 $48 = ($47|0)==(0|0);
 if (!($48)) {
  $49 = ((($47)) + 8|0);
  $50 = HEAP32[$49>>2]|0;HEAP32[$49>>2] = (($50-1)|0);
  $51 = ($50|0)==(1);
  if ($51) {
   __THREW__ = 0;
   invoke_viii(3262,($47|0),1,1);
   $52 = __THREW__; __THREW__ = 0;
   $53 = $52&1;
   if ($53) {
    $56 = ___cxa_find_matching_catch_3(0|0)|0;
    $57 = tempRet0;
    ___clang_call_terminate($56);
    // unreachable;
   }
  }
 }
 HEAP32[$2>>2] = 0;
 __THREW__ = 0;
 invoke_vi(1871,($0|0));
 $54 = __THREW__; __THREW__ = 0;
 $55 = $54&1;
 if ($55) {
  $56 = ___cxa_find_matching_catch_3(0|0)|0;
  $57 = tempRet0;
  ___clang_call_terminate($56);
  // unreachable;
 } else {
  ___resumeException($$02|0);
  // unreachable;
 }
}
function __ZN9osgViewer22GraphicsWindowEmbedded4initEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + 144|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (FUNCTION_TABLE_ii[$3 & 8191]($0)|0);
 if (!($4)) {
  return;
 }
 $5 = (__Znwj(896)|0);
 __THREW__ = 0;
 invoke_vi(3421,($5|0));
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if ($7) {
  $35 = ___cxa_find_matching_catch_2()|0;
  $36 = tempRet0;
  __ZdlPv($5);
  ___resumeException($35|0);
  // unreachable;
 }
 $8 = ((($0)) + 48|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==($5|0);
 if (!($10)) {
  HEAP32[$8>>2] = $5;
  $11 = ((($5)) + 8|0);
  $12 = HEAP32[$11>>2]|0;HEAP32[$11>>2] = (($12+1)|0);
  $13 = ($9|0)==(0|0);
  if (!($13)) {
   $14 = ((($9)) + 8|0);
   $15 = HEAP32[$14>>2]|0;HEAP32[$14>>2] = (($15-1)|0);
   $16 = ($15|0)==(1);
   if ($16) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($9,1,1);
   }
  }
 }
 $17 = HEAP32[$8>>2]|0;
 $18 = ((($17)) + 120|0);
 HEAP32[$18>>2] = $0;
 $19 = ((($0)) + 44|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)==(0|0);
 if (!($21)) {
  $22 = ((($20)) + 168|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = ($23|0)==(0|0);
  if (!($24)) {
   $25 = ((($23)) + 24|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = ($26|0)==(0|0);
   if (!($27)) {
    $28 = ((($20)) + 172|0);
    $29 = HEAP32[$28>>2]|0;
    $phitmp$i = ($29|0)==(0|0);
    if (!($phitmp$i)) {
     $30 = ((($29)) + 48|0);
     $31 = HEAP32[$30>>2]|0;
     $32 = ((($31)) + 124|0);
     $33 = HEAP32[$32>>2]|0;
     $34 = ((($17)) + 124|0);
     HEAP32[$34>>2] = $33;
     __ZN3osg15GraphicsContext28incrementContextIDUsageCountEj($33);
     return;
    }
   }
  }
 }
 $37 = (__ZN3osg15GraphicsContext18createNewContextIDEv()|0);
 $38 = ((($17)) + 124|0);
 HEAP32[$38>>2] = $37;
 return;
}
function __ZN9osgViewer22GraphicsWindowEmbeddedD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0;
 var $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (34776);
 $1 = ((($0)) + 132|0);
 HEAP32[$1>>2] = (35040);
 $2 = ((($0)) + 136|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = ((($3)) + 8|0);
  $6 = HEAP32[$5>>2]|0;HEAP32[$5>>2] = (($6-1)|0);
  $7 = ($6|0)==(1);
  if ($7) {
   __THREW__ = 0;
   invoke_viii(3262,($3|0),1,1);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if ($9) {
    $12 = ___cxa_find_matching_catch_2()|0;
    $13 = tempRet0;
    __THREW__ = 0;
    invoke_vi(1871,($0|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     $16 = ___cxa_find_matching_catch_3(0|0)|0;
     $17 = tempRet0;
     ___clang_call_terminate($16);
     // unreachable;
    } else {
     $eh$lpad$body$index2Z2D = $13;$eh$lpad$body$indexZ2D = $12;
     __ZdlPv($0);
     ___resumeException($eh$lpad$body$indexZ2D|0);
     // unreachable;
    }
   }
  }
 }
 HEAP32[$2>>2] = 0;
 __THREW__ = 0;
 invoke_vi(1871,($0|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if (!($11)) {
  __ZdlPv($0);
  return;
 }
 $18 = ___cxa_find_matching_catch_2()|0;
 $19 = tempRet0;
 $eh$lpad$body$index2Z2D = $19;$eh$lpad$body$indexZ2D = $18;
 __ZdlPv($0);
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
}
function __ZNK9osgViewer22GraphicsWindowEmbedded12isSameKindAsEPKN3osg6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,5272,0)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK9osgViewer22GraphicsWindowEmbedded11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (107921|0);
}
function __ZNK9osgViewer22GraphicsWindowEmbedded9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (104012|0);
}
function __ZNK9osgViewer22GraphicsWindowEmbedded5validEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 1;
}
function __ZN9osgViewer22GraphicsWindowEmbedded21realizeImplementationEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 1;
}
function __ZNK9osgViewer22GraphicsWindowEmbedded24isRealizedImplementationEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 1;
}
function __ZN9osgViewer22GraphicsWindowEmbedded19closeImplementationEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN9osgViewer22GraphicsWindowEmbedded25makeCurrentImplementationEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 1;
}
function __ZN9osgViewer22GraphicsWindowEmbedded28releaseContextImplementationEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 1;
}
function __ZN9osgViewer22GraphicsWindowEmbedded25swapBuffersImplementationEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN9osgViewer22GraphicsWindowEmbedded9grabFocusEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN9osgViewer22GraphicsWindowEmbedded26grabFocusIfPointerInWindowEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN9osgViewer22GraphicsWindowEmbedded11raiseWindowEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZThn132_N9osgViewer22GraphicsWindowEmbeddedD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -132|0);
 HEAP32[$1>>2] = (34776);
 $2 = ((($1)) + 132|0);
 HEAP32[$2>>2] = (35040);
 $3 = ((($1)) + 136|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  HEAP32[$3>>2] = 0;
  __ZN3osg15GraphicsContextD2Ev($1);
  return;
 }
 $6 = ((($4)) + 8|0);
 $7 = HEAP32[$6>>2]|0;HEAP32[$6>>2] = (($7-1)|0);
 $8 = ($7|0)==(1);
 if (!($8)) {
  HEAP32[$3>>2] = 0;
  __ZN3osg15GraphicsContextD2Ev($1);
  return;
 }
 __THREW__ = 0;
 invoke_viii(3262,($4|0),1,1);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if (!($10)) {
  HEAP32[$3>>2] = 0;
  __ZN3osg15GraphicsContextD2Ev($1);
  return;
 }
 $11 = ___cxa_find_matching_catch_2()|0;
 $12 = tempRet0;
 __THREW__ = 0;
 invoke_vi(1871,($1|0));
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 if ($14) {
  $15 = ___cxa_find_matching_catch_3(0|0)|0;
  $16 = tempRet0;
  ___clang_call_terminate($15);
  // unreachable;
 } else {
  ___resumeException($11|0);
  // unreachable;
 }
}
function __ZThn132_N9osgViewer22GraphicsWindowEmbeddedD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $eh$lpad$body$i$index2Z2D = 0, $eh$lpad$body$i$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -132|0);
 HEAP32[$1>>2] = (34776);
 $2 = ((($1)) + 132|0);
 HEAP32[$2>>2] = (35040);
 $3 = ((($1)) + 136|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if (!($5)) {
  $6 = ((($4)) + 8|0);
  $7 = HEAP32[$6>>2]|0;HEAP32[$6>>2] = (($7-1)|0);
  $8 = ($7|0)==(1);
  if ($8) {
   __THREW__ = 0;
   invoke_viii(3262,($4|0),1,1);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if ($10) {
    $13 = ___cxa_find_matching_catch_2()|0;
    $14 = tempRet0;
    __THREW__ = 0;
    invoke_vi(1871,($1|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     $17 = ___cxa_find_matching_catch_3(0|0)|0;
     $18 = tempRet0;
     ___clang_call_terminate($17);
     // unreachable;
    } else {
     $eh$lpad$body$i$index2Z2D = $14;$eh$lpad$body$i$indexZ2D = $13;
     __ZdlPv($1);
     ___resumeException($eh$lpad$body$i$indexZ2D|0);
     // unreachable;
    }
   }
  }
 }
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vi(1871,($1|0));
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if (!($12)) {
  __ZdlPv($1);
  return;
 }
 $19 = ___cxa_find_matching_catch_2()|0;
 $20 = tempRet0;
 $eh$lpad$body$i$index2Z2D = $20;$eh$lpad$body$i$indexZ2D = $19;
 __ZdlPv($1);
 ___resumeException($eh$lpad$body$i$indexZ2D|0);
 // unreachable;
}
function __ZNSt3__26vectorIPN9osgViewer4ViewENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(1073741823);
 if ($8) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $9 = ((($0)) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) - ($4))|0;
 $12 = $11 >> 2;
 $13 = ($12>>>0)<(536870911);
 $14 = $11 >> 1;
 $15 = ($14>>>0)<($7>>>0);
 $$sroa$speculated$i = $15 ? $7 : $14;
 $$sroa$speculated$$i = $13 ? $$sroa$speculated$i : 1073741823;
 $16 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($16) {
   $26 = 0;
  } else {
   $17 = ($$sroa$speculated$$i>>>0)>(1073741823);
   if (!($17)) {
    $23 = $$sroa$speculated$$i << 2;
    $24 = (__Znwj($23)|0);
    $26 = $24;
    break;
   }
   $18 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($18|0),(204840|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if ($20) {
    $21 = ___cxa_find_matching_catch_2()|0;
    $22 = tempRet0;
    ___cxa_free_exception(($18|0));
    ___resumeException($21|0);
    // unreachable;
   } else {
    HEAP32[$18>>2] = (99824);
    ___cxa_throw(($18|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $25 = (($26) + ($6<<2)|0);
 $27 = (($26) + ($$sroa$speculated$$i<<2)|0);
 $28 = $27;
 $29 = HEAP32[$1>>2]|0;
 HEAP32[$25>>2] = $29;
 $30 = ((($25)) + 4|0);
 $31 = $30;
 $32 = (0 - ($6))|0;
 $33 = (($25) + ($32<<2)|0);
 $34 = $33;
 $35 = ($5|0)>(0);
 if ($35) {
  $36 = $4;
  _memcpy(($33|0),($36|0),($5|0))|0;
 }
 HEAP32[$0>>2] = $34;
 HEAP32[$2>>2] = $31;
 HEAP32[$9>>2] = $28;
 $37 = ($4|0)==(0);
 if ($37) {
  return;
 }
 $38 = $4;
 __ZdlPv($38);
 return;
}
function __ZNSt3__26vectorIPN9osgViewer5SceneENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(1073741823);
 if ($8) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $9 = ((($0)) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) - ($4))|0;
 $12 = $11 >> 2;
 $13 = ($12>>>0)<(536870911);
 $14 = $11 >> 1;
 $15 = ($14>>>0)<($7>>>0);
 $$sroa$speculated$i = $15 ? $7 : $14;
 $$sroa$speculated$$i = $13 ? $$sroa$speculated$i : 1073741823;
 $16 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($16) {
   $26 = 0;
  } else {
   $17 = ($$sroa$speculated$$i>>>0)>(1073741823);
   if (!($17)) {
    $23 = $$sroa$speculated$$i << 2;
    $24 = (__Znwj($23)|0);
    $26 = $24;
    break;
   }
   $18 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($18|0),(204840|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if ($20) {
    $21 = ___cxa_find_matching_catch_2()|0;
    $22 = tempRet0;
    ___cxa_free_exception(($18|0));
    ___resumeException($21|0);
    // unreachable;
   } else {
    HEAP32[$18>>2] = (99824);
    ___cxa_throw(($18|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $25 = (($26) + ($6<<2)|0);
 $27 = (($26) + ($$sroa$speculated$$i<<2)|0);
 $28 = $27;
 $29 = HEAP32[$1>>2]|0;
 HEAP32[$25>>2] = $29;
 $30 = ((($25)) + 4|0);
 $31 = $30;
 $32 = (0 - ($6))|0;
 $33 = (($25) + ($32<<2)|0);
 $34 = $33;
 $35 = ($5|0)>(0);
 if ($35) {
  $36 = $4;
  _memcpy(($33|0),($36|0),($5|0))|0;
 }
 HEAP32[$0>>2] = $34;
 HEAP32[$2>>2] = $31;
 HEAP32[$9>>2] = $28;
 $37 = ($4|0)==(0);
 if ($37) {
  return;
 }
 $38 = $4;
 __ZdlPv($38);
 return;
}
function __ZNSt3__26vectorIPN3osg15OperationThreadENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(1073741823);
 if ($8) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $9 = ((($0)) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) - ($4))|0;
 $12 = $11 >> 2;
 $13 = ($12>>>0)<(536870911);
 $14 = $11 >> 1;
 $15 = ($14>>>0)<($7>>>0);
 $$sroa$speculated$i = $15 ? $7 : $14;
 $$sroa$speculated$$i = $13 ? $$sroa$speculated$i : 1073741823;
 $16 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($16) {
   $26 = 0;
  } else {
   $17 = ($$sroa$speculated$$i>>>0)>(1073741823);
   if (!($17)) {
    $23 = $$sroa$speculated$$i << 2;
    $24 = (__Znwj($23)|0);
    $26 = $24;
    break;
   }
   $18 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($18|0),(204840|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if ($20) {
    $21 = ___cxa_find_matching_catch_2()|0;
    $22 = tempRet0;
    ___cxa_free_exception(($18|0));
    ___resumeException($21|0);
    // unreachable;
   } else {
    HEAP32[$18>>2] = (99824);
    ___cxa_throw(($18|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $25 = (($26) + ($6<<2)|0);
 $27 = (($26) + ($$sroa$speculated$$i<<2)|0);
 $28 = $27;
 $29 = HEAP32[$1>>2]|0;
 HEAP32[$25>>2] = $29;
 $30 = ((($25)) + 4|0);
 $31 = $30;
 $32 = (0 - ($6))|0;
 $33 = (($25) + ($32<<2)|0);
 $34 = $33;
 $35 = ($5|0)>(0);
 if ($35) {
  $36 = $4;
  _memcpy(($33|0),($36|0),($5|0))|0;
 }
 HEAP32[$0>>2] = $34;
 HEAP32[$2>>2] = $31;
 HEAP32[$9>>2] = $28;
 $37 = ($4|0)==(0);
 if ($37) {
  return;
 }
 $38 = $4;
 __ZdlPv($38);
 return;
}
function __ZNSt3__26vectorIPN11OpenThreads6ThreadENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(1073741823);
 if ($8) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $9 = ((($0)) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) - ($4))|0;
 $12 = $11 >> 2;
 $13 = ($12>>>0)<(536870911);
 $14 = $11 >> 1;
 $15 = ($14>>>0)<($7>>>0);
 $$sroa$speculated$i = $15 ? $7 : $14;
 $$sroa$speculated$$i = $13 ? $$sroa$speculated$i : 1073741823;
 $16 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($16) {
   $26 = 0;
  } else {
   $17 = ($$sroa$speculated$$i>>>0)>(1073741823);
   if (!($17)) {
    $23 = $$sroa$speculated$$i << 2;
    $24 = (__Znwj($23)|0);
    $26 = $24;
    break;
   }
   $18 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($18|0),(204840|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if ($20) {
    $21 = ___cxa_find_matching_catch_2()|0;
    $22 = tempRet0;
    ___cxa_free_exception(($18|0));
    ___resumeException($21|0);
    // unreachable;
   } else {
    HEAP32[$18>>2] = (99824);
    ___cxa_throw(($18|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $25 = (($26) + ($6<<2)|0);
 $27 = (($26) + ($$sroa$speculated$$i<<2)|0);
 $28 = $27;
 $29 = HEAP32[$1>>2]|0;
 HEAP32[$25>>2] = $29;
 $30 = ((($25)) + 4|0);
 $31 = $30;
 $32 = (0 - ($6))|0;
 $33 = (($25) + ($32<<2)|0);
 $34 = $33;
 $35 = ($5|0)>(0);
 if ($35) {
  $36 = $4;
  _memcpy(($33|0),($36|0),($5|0))|0;
 }
 HEAP32[$0>>2] = $34;
 HEAP32[$2>>2] = $31;
 HEAP32[$9>>2] = $28;
 $37 = ($4|0)==(0);
 if ($37) {
  return;
 }
 $38 = $4;
 __ZdlPv($38);
 return;
}
function __ZNSt3__26vectorIPN3osg15GraphicsContextENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(1073741823);
 if ($8) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $9 = ((($0)) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) - ($4))|0;
 $12 = $11 >> 2;
 $13 = ($12>>>0)<(536870911);
 $14 = $11 >> 1;
 $15 = ($14>>>0)<($7>>>0);
 $$sroa$speculated$i = $15 ? $7 : $14;
 $$sroa$speculated$$i = $13 ? $$sroa$speculated$i : 1073741823;
 $16 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($16) {
   $26 = 0;
  } else {
   $17 = ($$sroa$speculated$$i>>>0)>(1073741823);
   if (!($17)) {
    $23 = $$sroa$speculated$$i << 2;
    $24 = (__Znwj($23)|0);
    $26 = $24;
    break;
   }
   $18 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($18|0),(204840|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if ($20) {
    $21 = ___cxa_find_matching_catch_2()|0;
    $22 = tempRet0;
    ___cxa_free_exception(($18|0));
    ___resumeException($21|0);
    // unreachable;
   } else {
    HEAP32[$18>>2] = (99824);
    ___cxa_throw(($18|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $25 = (($26) + ($6<<2)|0);
 $27 = (($26) + ($$sroa$speculated$$i<<2)|0);
 $28 = $27;
 $29 = HEAP32[$1>>2]|0;
 HEAP32[$25>>2] = $29;
 $30 = ((($25)) + 4|0);
 $31 = $30;
 $32 = (0 - ($6))|0;
 $33 = (($25) + ($32<<2)|0);
 $34 = $33;
 $35 = ($5|0)>(0);
 if ($35) {
  $36 = $4;
  _memcpy(($33|0),($36|0),($5|0))|0;
 }
 HEAP32[$0>>2] = $34;
 HEAP32[$2>>2] = $31;
 HEAP32[$9>>2] = $28;
 $37 = ($4|0)==(0);
 if ($37) {
  return;
 }
 $38 = $4;
 __ZdlPv($38);
 return;
}
function __ZNSt3__26__treeIPN3osg15GraphicsContextENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 } else {
  $3 = HEAP32[$1>>2]|0;
  __ZNSt3__26__treeIPN3osg15GraphicsContextENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($0,$3);
  $4 = ((($1)) + 4|0);
  $5 = HEAP32[$4>>2]|0;
  __ZNSt3__26__treeIPN3osg15GraphicsContextENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($0,$5);
  __ZdlPv($1);
  return;
 }
}
function __ZNSt3__26vectorIPN3osg6CameraENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(1073741823);
 if ($8) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $9 = ((($0)) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) - ($4))|0;
 $12 = $11 >> 2;
 $13 = ($12>>>0)<(536870911);
 $14 = $11 >> 1;
 $15 = ($14>>>0)<($7>>>0);
 $$sroa$speculated$i = $15 ? $7 : $14;
 $$sroa$speculated$$i = $13 ? $$sroa$speculated$i : 1073741823;
 $16 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($16) {
   $26 = 0;
  } else {
   $17 = ($$sroa$speculated$$i>>>0)>(1073741823);
   if (!($17)) {
    $23 = $$sroa$speculated$$i << 2;
    $24 = (__Znwj($23)|0);
    $26 = $24;
    break;
   }
   $18 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($18|0),(204840|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if ($20) {
    $21 = ___cxa_find_matching_catch_2()|0;
    $22 = tempRet0;
    ___cxa_free_exception(($18|0));
    ___resumeException($21|0);
    // unreachable;
   } else {
    HEAP32[$18>>2] = (99824);
    ___cxa_throw(($18|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $25 = (($26) + ($6<<2)|0);
 $27 = (($26) + ($$sroa$speculated$$i<<2)|0);
 $28 = $27;
 $29 = HEAP32[$1>>2]|0;
 HEAP32[$25>>2] = $29;
 $30 = ((($25)) + 4|0);
 $31 = $30;
 $32 = (0 - ($6))|0;
 $33 = (($25) + ($32<<2)|0);
 $34 = $33;
 $35 = ($5|0)>(0);
 if ($35) {
  $36 = $4;
  _memcpy(($33|0),($36|0),($5|0))|0;
 }
 HEAP32[$0>>2] = $34;
 HEAP32[$2>>2] = $31;
 HEAP32[$9>>2] = $28;
 $37 = ($4|0)==(0);
 if ($37) {
  return;
 }
 $38 = $4;
 __ZdlPv($38);
 return;
}
function __ZNKSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEbEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE4findIS7_EENS_21__tree_const_iteratorIS8_PNS_11__tree_nodeIS8_PvEEiEERKT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$ph$lcssa$i = 0, $$0$ph15$i = 0, $$07$ph14$i = 0, $$0711$i = 0, $$sroa$0$0 = 0, $$sroa$speculated$i$i$i$i$i = 0, $$sroa$speculated$i$i$i$i$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 do {
  if (!($4)) {
   $5 = ((($1)) + 11|0);
   $6 = HEAP8[$5>>0]|0;
   $7 = ($6<<24>>24)<(0);
   $8 = ((($1)) + 4|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = $6&255;
   $11 = $7 ? $9 : $10;
   $12 = HEAP32[$1>>2]|0;
   $13 = $7 ? $12 : $1;
   $$0$ph15$i = $2;$$07$ph14$i = $3;
   L3: while(1) {
    $$0711$i = $$07$ph14$i;
    while(1) {
     $14 = ((($$0711$i)) + 16|0);
     $15 = ((($14)) + 11|0);
     $16 = HEAP8[$15>>0]|0;
     $17 = ($16<<24>>24)<(0);
     $18 = ((($$0711$i)) + 20|0);
     $19 = HEAP32[$18>>2]|0;
     $20 = $16&255;
     $21 = $17 ? $19 : $20;
     $22 = ($11>>>0)<($21>>>0);
     $$sroa$speculated$i$i$i$i$i$i = $22 ? $11 : $21;
     $23 = ($$sroa$speculated$i$i$i$i$i$i|0)==(0);
     if ($23) {
      label = 6;
     } else {
      $24 = HEAP32[$14>>2]|0;
      $25 = $17 ? $24 : $14;
      $26 = (_memcmp($25,$13,$$sroa$speculated$i$i$i$i$i$i)|0);
      $27 = ($26|0)==(0);
      if ($27) {
       label = 6;
      } else {
       $29 = ($26|0)<(0);
       if (!($29)) {
        break;
       }
      }
     }
     if ((label|0) == 6) {
      label = 0;
      $28 = ($21>>>0)<($11>>>0);
      if (!($28)) {
       break;
      }
     }
     $32 = ((($$0711$i)) + 4|0);
     $33 = HEAP32[$32>>2]|0;
     $34 = ($33|0)==(0|0);
     if ($34) {
      $$0$ph$lcssa$i = $$0$ph15$i;
      break L3;
     } else {
      $$0711$i = $33;
     }
    }
    $30 = HEAP32[$$0711$i>>2]|0;
    $31 = ($30|0)==(0|0);
    if ($31) {
     $$0$ph$lcssa$i = $$0711$i;
     break;
    } else {
     $$0$ph15$i = $$0711$i;$$07$ph14$i = $30;
    }
   }
   $35 = ($$0$ph$lcssa$i|0)==($2|0);
   if (!($35)) {
    $36 = ((($$0$ph$lcssa$i)) + 16|0);
    $37 = ((($36)) + 11|0);
    $38 = HEAP8[$37>>0]|0;
    $39 = ($38<<24>>24)<(0);
    $40 = ((($$0$ph$lcssa$i)) + 20|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = $38&255;
    $43 = $39 ? $41 : $42;
    $44 = ($43>>>0)<($11>>>0);
    $$sroa$speculated$i$i$i$i$i = $44 ? $43 : $11;
    $45 = ($$sroa$speculated$i$i$i$i$i|0)==(0);
    if (!($45)) {
     $46 = HEAP32[$36>>2]|0;
     $47 = $39 ? $46 : $36;
     $48 = (_memcmp($13,$47,$$sroa$speculated$i$i$i$i$i)|0);
     $49 = ($48|0)==(0);
     if (!($49)) {
      $51 = ($48|0)<(0);
      if ($51) {
       break;
      } else {
       $$sroa$0$0 = $$0$ph$lcssa$i;
      }
      return ($$sroa$0$0|0);
     }
    }
    $50 = ($11>>>0)<($43>>>0);
    if (!($50)) {
     $$sroa$0$0 = $$0$ph$lcssa$i;
     return ($$sroa$0$0|0);
    }
   }
  }
 } while(0);
 $$sroa$0$0 = $2;
 return ($$sroa$0$0|0);
}
function __ZN9osgViewer6Viewer19generatePointerDataERN5osgGA15GUIEventAdapterE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0.0, $$4 = 0, $$474 = 0, $$5 = 0, $$575 = 0, $$pr = 0, $$pre = 0, $$pre105 = 0, $$sroa$093$0 = 0, $$sroa$093$0103 = 0, $$sroa$093$0104 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0.0;
 var $126 = 0, $127 = 0.0, $128 = 0.0, $129 = 0, $13 = 0, $130 = 0.0, $131 = 0.0, $132 = 0.0, $133 = 0.0, $134 = 0.0, $135 = 0.0, $136 = 0, $137 = 0.0, $138 = 0.0, $139 = 0, $14 = 0, $140 = 0.0, $141 = 0.0, $142 = 0.0, $143 = 0.0;
 var $144 = 0.0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0;
 var $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0.0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0;
 var $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0.0, $190 = 0, $191 = 0, $192 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0.0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0.0, $35 = 0, $36 = 0, $37 = 0.0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0.0, $63 = 0.0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0.0, $89 = 0, $9 = 0, $90 = 0, $91 = 0.0, $92 = 0, $93 = 0, $94 = 0.0, $95 = 0.0, $96 = 0, $97 = 0;
 var $98 = 0.0, $99 = 0.0, $eh$lpad$body$index7Z2D = 0, $eh$lpad$body$indexZ2D = 0, $eh$lpad$body84$index2Z2D = 0, $eh$lpad$body84$indexZ2D = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i77 = 0, $scevgep5$i$i$i = 0, $scevgep5$i$i$i78 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $2 = sp;
 $3 = sp + 8|0;
 $4 = sp + 4|0;
 $5 = ((($1)) + 52|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  STACKTOP = sp;return;
 }
 $8 = ((($6)) + 24|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if ($10) {
  STACKTOP = sp;return;
 }
 $11 = ((($1)) + 56|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0|0);
 if ($13) {
  STACKTOP = sp;return;
 }
 $14 = (___dynamic_cast($12,24816,3888,0)|0);
 $15 = ($14|0)==(0|0);
 if ($15) {
  STACKTOP = sp;return;
 }
 $16 = ((($1)) + 104|0);
 $17 = +HEAPF32[$16>>2];
 $18 = ((($1)) + 108|0);
 $19 = +HEAPF32[$18>>2];
 $20 = ((($1)) + 120|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(1);
 $23 = ((($14)) + 44|0);
 if ($22) {
  $24 = HEAP32[$23>>2]|0;
  $25 = ($24|0)==(0|0);
  if ($25) {
   $$0 = $19;
  } else {
   $26 = ((($24)) + 44|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = (+($27|0));
   $29 = $28 - $19;
   $$0 = $29;
  }
 } else {
  $$0 = $19;
 }
 $30 = (__Znwj(44)|0);
 $31 = HEAP32[$23>>2]|0;
 $32 = ((($31)) + 40|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = (+($33|0));
 $35 = ((($31)) + 44|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = (+($36|0));
 __THREW__ = 0;
 invoke_vi(3282,($30|0));
 $38 = __THREW__; __THREW__ = 0;
 $39 = $38&1;
 do {
  if ($39) {
   $69 = ___cxa_find_matching_catch_2()|0;
   $70 = tempRet0;
   $eh$lpad$body84$index2Z2D = $70;$eh$lpad$body84$indexZ2D = $69;
  } else {
   HEAP32[$30>>2] = (37072);
   $40 = ((($30)) + 12|0);
   __THREW__ = 0;
   invoke_vii(3422,($40|0),($14|0));
   $41 = __THREW__; __THREW__ = 0;
   $42 = $41&1;
   if ($42) {
    $43 = ___cxa_find_matching_catch_2()|0;
    $44 = tempRet0;
    __THREW__ = 0;
    invoke_vi(712,($30|0));
    $45 = __THREW__; __THREW__ = 0;
    $46 = $45&1;
    if (!($46)) {
     $eh$lpad$body84$index2Z2D = $44;$eh$lpad$body84$indexZ2D = $43;
     break;
    }
    $47 = ___cxa_find_matching_catch_3(0|0)|0;
    $48 = tempRet0;
    ___clang_call_terminate($47);
    // unreachable;
   }
   $49 = ((($30)) + 20|0);
   HEAPF32[$49>>2] = $17;
   $50 = ((($30)) + 24|0);
   HEAPF32[$50>>2] = 0.0;
   $51 = ((($30)) + 28|0);
   HEAPF32[$51>>2] = $34;
   $52 = ((($30)) + 32|0);
   HEAPF32[$52>>2] = $$0;
   $53 = ((($30)) + 36|0);
   HEAPF32[$53>>2] = 0.0;
   $54 = ((($30)) + 40|0);
   HEAPF32[$54>>2] = $37;
   __ZN5osgGA15GUIEventAdapter14addPointerDataEPNS_11PointerDataE($1,$30);
   __ZN5osgGA15GUIEventAdapter35setMouseYOrientationAndUpdateCoordsENS0_17MouseYOrientationE($1,0);
   HEAP32[$3>>2] = 0;
   $55 = ((($3)) + 4|0);
   HEAP32[$55>>2] = 0;
   $56 = ((($3)) + 8|0);
   HEAP32[$56>>2] = 0;
   $57 = ((($14)) + 32|0);
   $58 = ((($14)) + 36|0);
   $$sroa$093$0103 = HEAP32[$58>>2]|0;
   $59 = $$sroa$093$0103;
   $60 = ($59|0)==($57|0);
   do {
    if ($60) {
     $65 = 0;$66 = 0;
     label = 15;
    } else {
     $61 = ((($0)) + 104|0);
     $62 = $17;
     $63 = $$0;
     $64 = ((($3)) + 8|0);
     $$sroa$093$0104 = $$sroa$093$0103;$109 = $59;
     L26: while(1) {
      $71 = $$sroa$093$0104;
      $72 = ((($71)) + 8|0);
      $73 = HEAP32[$72>>2]|0;
      HEAP32[$4>>2] = $73;
      $74 = ((($73)) + 220|0);
      $75 = HEAP32[$74>>2]|0;
      $76 = ($75|0)==($61|0);
      $77 = $73;
      do {
       if ($76) {
        $78 = ((($73)) + 228|0);
        $79 = HEAP8[$78>>0]|0;
        $80 = ($79<<24>>24)==(0);
        if (!($80)) {
         $81 = ((($73)) + 576|0);
         $82 = HEAP32[$81>>2]|0;
         $83 = ($82|0)==(3);
         if ($83) {
          $84 = ((($73)) + 288|0);
          $85 = HEAP32[$84>>2]|0;
          $86 = ($85|0)==(0|0);
          if (!($86)) {
           $87 = ((($85)) + 56|0);
           $88 = +HEAPF64[$87>>3];
           $89 = !($62 >= $88);
           if (!($89)) {
            $90 = ((($85)) + 64|0);
            $91 = +HEAPF64[$90>>3];
            $92 = !($63 >= $91);
            if (!($92)) {
             $93 = ((($85)) + 72|0);
             $94 = +HEAPF64[$93>>3];
             $95 = $88 + $94;
             $96 = !($62 <= $95);
             if (!($96)) {
              $97 = ((($85)) + 80|0);
              $98 = +HEAPF64[$97>>3];
              $99 = $91 + $98;
              $100 = !($63 <= $99);
              if (!($100)) {
               $101 = HEAP32[$55>>2]|0;
               $102 = HEAP32[$64>>2]|0;
               $103 = ($101|0)==($102|0);
               if ($103) {
                __THREW__ = 0;
                invoke_vii(3424,($3|0),($4|0));
                $106 = __THREW__; __THREW__ = 0;
                $107 = $106&1;
                if ($107) {
                 label = 30;
                 break L26;
                } else {
                 break;
                }
               } else {
                HEAP32[$101>>2] = $77;
                $104 = HEAP32[$55>>2]|0;
                $105 = ((($104)) + 4|0);
                HEAP32[$55>>2] = $105;
                break;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      } while(0);
      $108 = ((($109)) + 4|0);
      $$sroa$093$0 = HEAP32[$108>>2]|0;
      $110 = $$sroa$093$0;
      $111 = ($110|0)==($57|0);
      if ($111) {
       label = 14;
       break;
      } else {
       $$sroa$093$0104 = $$sroa$093$0;$109 = $110;
      }
     }
     if ((label|0) == 14) {
      $$pre = HEAP32[$3>>2]|0;
      $$pre105 = HEAP32[$55>>2]|0;
      $65 = $$pre;$66 = $$pre105;
      label = 15;
      break;
     }
     else if ((label|0) == 30) {
      $112 = ___cxa_find_matching_catch_2()|0;
      $113 = tempRet0;
      $$4 = $112;$$474 = $113;
      break;
     }
    }
   } while(0);
   L44: do {
    if ((label|0) == 15) {
     __THREW__ = 0;
     invoke_viii(3423,($65|0),($66|0),($2|0));
     $67 = __THREW__; __THREW__ = 0;
     $68 = $67&1;
     if ($68) {
      $169 = ___cxa_find_matching_catch_2()|0;
      $170 = tempRet0;
      $$4 = $169;$$474 = $170;
      break;
     }
     $114 = HEAP32[$3>>2]|0;
     $115 = HEAP32[$55>>2]|0;
     $116 = ($114|0)==($115|0);
     if ($116) {
      $175 = $114;
     } else {
      $117 = ((($115)) + -4|0);
      $118 = HEAP32[$117>>2]|0;
      $119 = ($118|0)==(0|0);
      L51: do {
       if (!($119)) {
        $120 = ((($118)) + 288|0);
        $121 = HEAP32[$120>>2]|0;
        __THREW__ = 0;
        $122 = (invoke_ii(3276,44)|0);
        $123 = __THREW__; __THREW__ = 0;
        $124 = $123&1;
        L53: do {
         if (!($124)) {
          $125 = $17;
          $126 = ((($121)) + 56|0);
          $127 = +HEAPF64[$126>>3];
          $128 = $125 - $127;
          $129 = ((($121)) + 72|0);
          $130 = +HEAPF64[$129>>3];
          $131 = $128 / $130;
          $132 = $131 * 2.0;
          $133 = $132 + -1.0;
          $134 = $133;
          $135 = $$0;
          $136 = ((($121)) + 64|0);
          $137 = +HEAPF64[$136>>3];
          $138 = $135 - $137;
          $139 = ((($121)) + 80|0);
          $140 = +HEAPF64[$139>>3];
          $141 = $138 / $140;
          $142 = $141 * 2.0;
          $143 = $142 + -1.0;
          $144 = $143;
          __THREW__ = 0;
          invoke_vi(3282,($122|0));
          $145 = __THREW__; __THREW__ = 0;
          $146 = $145&1;
          do {
           if ($146) {
            $173 = ___cxa_find_matching_catch_2()|0;
            $174 = tempRet0;
            $eh$lpad$body$index7Z2D = $174;$eh$lpad$body$indexZ2D = $173;
           } else {
            HEAP32[$122>>2] = (37072);
            $147 = ((($122)) + 12|0);
            __THREW__ = 0;
            invoke_vii(3422,($147|0),($118|0));
            $148 = __THREW__; __THREW__ = 0;
            $149 = $148&1;
            if ($149) {
             $150 = ___cxa_find_matching_catch_2()|0;
             $151 = tempRet0;
             __THREW__ = 0;
             invoke_vi(712,($122|0));
             $152 = __THREW__; __THREW__ = 0;
             $153 = $152&1;
             if (!($153)) {
              $eh$lpad$body$index7Z2D = $151;$eh$lpad$body$indexZ2D = $150;
              break;
             }
             $154 = ___cxa_find_matching_catch_3(0|0)|0;
             $155 = tempRet0;
             ___clang_call_terminate($154);
             // unreachable;
            }
            $156 = ((($122)) + 20|0);
            HEAPF32[$156>>2] = $134;
            $157 = ((($122)) + 24|0);
            HEAPF32[$157>>2] = -1.0;
            $158 = ((($122)) + 28|0);
            HEAPF32[$158>>2] = 1.0;
            $159 = ((($122)) + 32|0);
            HEAPF32[$159>>2] = $144;
            $160 = ((($122)) + 36|0);
            HEAPF32[$160>>2] = -1.0;
            $161 = ((($122)) + 40|0);
            HEAPF32[$161>>2] = 1.0;
            __THREW__ = 0;
            invoke_vii(3425,($1|0),($122|0));
            $162 = __THREW__; __THREW__ = 0;
            $163 = $162&1;
            if ($163) {
             break L53;
            }
            $164 = ((($0)) + 120|0);
            $165 = HEAP32[$164>>2]|0;
            $166 = ($118|0)==($165|0);
            if ($166) {
             break L51;
            }
            __THREW__ = 0;
            invoke_viii(3426,($0|0),($118|0),($1|0));
            $167 = __THREW__; __THREW__ = 0;
            $168 = $167&1;
            if ($168) {
             break L53;
            } else {
             break L51;
            }
           }
          } while(0);
          __ZdlPv($122);
          $$4 = $eh$lpad$body$indexZ2D;$$474 = $eh$lpad$body$index7Z2D;
          break L44;
         }
        } while(0);
        $171 = ___cxa_find_matching_catch_2()|0;
        $172 = tempRet0;
        $$4 = $171;$$474 = $172;
        break L44;
       }
      } while(0);
      $$pr = HEAP32[$3>>2]|0;
      $175 = $$pr;
     }
     $176 = ($175|0)==(0|0);
     if (!($176)) {
      $177 = HEAP32[$55>>2]|0;
      $178 = ($177|0)==($175|0);
      if (!($178)) {
       $scevgep$i$i$i77 = ((($177)) + -4|0);
       $179 = $scevgep$i$i$i77;
       $180 = $175;
       $181 = (($179) - ($180))|0;
       $182 = $181 >>> 2;
       $183 = $182 ^ -1;
       $scevgep5$i$i$i78 = (($177) + ($183<<2)|0);
       HEAP32[$55>>2] = $scevgep5$i$i$i78;
      }
      __ZdlPv($175);
     }
     STACKTOP = sp;return;
    }
   } while(0);
   $184 = HEAP32[$3>>2]|0;
   $185 = ($184|0)==(0|0);
   if (!($185)) {
    $186 = HEAP32[$55>>2]|0;
    $187 = ($186|0)==($184|0);
    if (!($187)) {
     $scevgep$i$i$i = ((($186)) + -4|0);
     $188 = $scevgep$i$i$i;
     $189 = $184;
     $190 = (($188) - ($189))|0;
     $191 = $190 >>> 2;
     $192 = $191 ^ -1;
     $scevgep5$i$i$i = (($186) + ($192<<2)|0);
     HEAP32[$55>>2] = $scevgep5$i$i$i;
    }
    __ZdlPv($184);
   }
   $$5 = $$4;$$575 = $$474;
   ___resumeException($$5|0);
   // unreachable;
  }
 } while(0);
 __ZdlPv($30);
 $$5 = $eh$lpad$body84$indexZ2D;$$575 = $eh$lpad$body84$index2Z2D;
 ___resumeException($$5|0);
 // unreachable;
}
function __ZN9osgViewer6Viewer20reprojectPointerDataERN5osgGA15GUIEventAdapterES3_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0.0, $$053 = 0, $$054 = 0, $10 = 0, $100 = 0.0, $101 = 0.0, $102 = 0.0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $13 = 0, $14 = 0, $15 = 0.0, $16 = 0, $17 = 0.0, $18 = 0, $19 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0.0, $27 = 0.0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0.0, $33 = 0, $34 = 0, $35 = 0.0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0.0, $84 = 0, $85 = 0.0, $86 = 0.0, $87 = 0, $88 = 0.0, $89 = 0.0, $9 = 0, $90 = 0.0, $91 = 0.0, $92 = 0.0, $93 = 0.0, $94 = 0;
 var $95 = 0.0, $96 = 0.0, $97 = 0, $98 = 0.0, $99 = 0.0, $eh$lpad$body$index7Z2D = 0, $eh$lpad$body$indexZ2D = 0, $eh$lpad$body57$index2Z2D = 0, $eh$lpad$body57$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($2)) + 52|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  return;
 }
 $6 = ((($4)) + 24|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if ($8) {
  return;
 }
 $9 = ((($2)) + 56|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  return;
 }
 $12 = (___dynamic_cast($10,24816,3888,0)|0);
 $13 = ($12|0)==(0|0);
 if ($13) {
  return;
 }
 $14 = ((($2)) + 104|0);
 $15 = +HEAPF32[$14>>2];
 $16 = ((($2)) + 108|0);
 $17 = +HEAPF32[$16>>2];
 $18 = ((($2)) + 120|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)==(1);
 $21 = ((($12)) + 44|0);
 if ($20) {
  $22 = HEAP32[$21>>2]|0;
  $23 = ($22|0)==(0|0);
  if ($23) {
   $$0 = $17;
  } else {
   $24 = ((($22)) + 44|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = (+($25|0));
   $27 = $26 - $17;
   $$0 = $27;
  }
 } else {
  $$0 = $17;
 }
 $28 = (__Znwj(44)|0);
 $29 = HEAP32[$21>>2]|0;
 $30 = ((($29)) + 40|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (+($31|0));
 $33 = ((($29)) + 44|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = (+($34|0));
 __THREW__ = 0;
 invoke_vi(3282,($28|0));
 $36 = __THREW__; __THREW__ = 0;
 $37 = $36&1;
 do {
  if ($37) {
   $80 = ___cxa_find_matching_catch_2()|0;
   $81 = tempRet0;
   $eh$lpad$body57$index2Z2D = $81;$eh$lpad$body57$indexZ2D = $80;
  } else {
   HEAP32[$28>>2] = (37072);
   $38 = ((($28)) + 12|0);
   __THREW__ = 0;
   invoke_vii(3422,($38|0),($12|0));
   $39 = __THREW__; __THREW__ = 0;
   $40 = $39&1;
   if ($40) {
    $41 = ___cxa_find_matching_catch_2()|0;
    $42 = tempRet0;
    __THREW__ = 0;
    invoke_vi(712,($28|0));
    $43 = __THREW__; __THREW__ = 0;
    $44 = $43&1;
    if (!($44)) {
     $eh$lpad$body57$index2Z2D = $42;$eh$lpad$body57$indexZ2D = $41;
     break;
    }
    $45 = ___cxa_find_matching_catch_3(0|0)|0;
    $46 = tempRet0;
    ___clang_call_terminate($45);
    // unreachable;
   }
   $47 = ((($28)) + 20|0);
   HEAPF32[$47>>2] = $15;
   $48 = ((($28)) + 24|0);
   HEAPF32[$48>>2] = 0.0;
   $49 = ((($28)) + 28|0);
   HEAPF32[$49>>2] = $32;
   $50 = ((($28)) + 32|0);
   HEAPF32[$50>>2] = $$0;
   $51 = ((($28)) + 36|0);
   HEAPF32[$51>>2] = 0.0;
   $52 = ((($28)) + 40|0);
   HEAPF32[$52>>2] = $35;
   __ZN5osgGA15GUIEventAdapter14addPointerDataEPNS_11PointerDataE($2,$28);
   __ZN5osgGA15GUIEventAdapter35setMouseYOrientationAndUpdateCoordsENS0_17MouseYOrientationE($2,0);
   $53 = ((($1)) + 160|0);
   $54 = ((($1)) + 164|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = HEAP32[$53>>2]|0;
   $57 = (($55) - ($56))|0;
   $58 = $57 >> 2;
   $59 = ($58>>>0)>(1);
   if (!($59)) {
    return;
   }
   $60 = $56;
   $61 = ((($60)) + 4|0);
   $62 = HEAP32[$61>>2]|0;
   $63 = ((($62)) + 12|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = ($64|0)==(0|0);
   if ($65) {
    return;
   }
   $66 = ((($64)) + 24|0);
   $67 = HEAP32[$66>>2]|0;
   $68 = ($67|0)==(0|0);
   if ($68) {
    return;
   }
   $69 = ((($62)) + 16|0);
   $70 = HEAP32[$69>>2]|0;
   $71 = ($70|0)==(0|0);
   if ($71) {
    return;
   }
   $72 = HEAP32[$70>>2]|0;
   $73 = ((($72)) + 72|0);
   $74 = HEAP32[$73>>2]|0;
   $75 = (FUNCTION_TABLE_ii[$74 & 8191]($70)|0);
   $76 = ($75|0)==(0|0);
   if ($76) {
    return;
   }
   $77 = ((($75)) + 288|0);
   $78 = HEAP32[$77>>2]|0;
   $79 = ($78|0)==(0|0);
   if ($79) {
    return;
   }
   $82 = (__Znwj(44)|0);
   $83 = $15;
   $84 = ((($78)) + 56|0);
   $85 = +HEAPF64[$84>>3];
   $86 = $83 - $85;
   $87 = ((($78)) + 72|0);
   $88 = +HEAPF64[$87>>3];
   $89 = $86 / $88;
   $90 = $89 * 2.0;
   $91 = $90 + -1.0;
   $92 = $91;
   $93 = $$0;
   $94 = ((($78)) + 64|0);
   $95 = +HEAPF64[$94>>3];
   $96 = $93 - $95;
   $97 = ((($78)) + 80|0);
   $98 = +HEAPF64[$97>>3];
   $99 = $96 / $98;
   $100 = $99 * 2.0;
   $101 = $100 + -1.0;
   $102 = $101;
   __THREW__ = 0;
   invoke_vi(3282,($82|0));
   $103 = __THREW__; __THREW__ = 0;
   $104 = $103&1;
   do {
    if ($104) {
     $123 = ___cxa_find_matching_catch_2()|0;
     $124 = tempRet0;
     $eh$lpad$body$index7Z2D = $124;$eh$lpad$body$indexZ2D = $123;
    } else {
     HEAP32[$82>>2] = (37072);
     $105 = ((($82)) + 12|0);
     __THREW__ = 0;
     invoke_vii(3422,($105|0),($75|0));
     $106 = __THREW__; __THREW__ = 0;
     $107 = $106&1;
     if ($107) {
      $108 = ___cxa_find_matching_catch_2()|0;
      $109 = tempRet0;
      __THREW__ = 0;
      invoke_vi(712,($82|0));
      $110 = __THREW__; __THREW__ = 0;
      $111 = $110&1;
      if (!($111)) {
       $eh$lpad$body$index7Z2D = $109;$eh$lpad$body$indexZ2D = $108;
       break;
      }
      $112 = ___cxa_find_matching_catch_3(0|0)|0;
      $113 = tempRet0;
      ___clang_call_terminate($112);
      // unreachable;
     }
     $114 = ((($82)) + 20|0);
     HEAPF32[$114>>2] = $92;
     $115 = ((($82)) + 24|0);
     HEAPF32[$115>>2] = -1.0;
     $116 = ((($82)) + 28|0);
     HEAPF32[$116>>2] = 1.0;
     $117 = ((($82)) + 32|0);
     HEAPF32[$117>>2] = $102;
     $118 = ((($82)) + 36|0);
     HEAPF32[$118>>2] = -1.0;
     $119 = ((($82)) + 40|0);
     HEAPF32[$119>>2] = 1.0;
     __ZN5osgGA15GUIEventAdapter14addPointerDataEPNS_11PointerDataE($2,$82);
     $120 = ((($0)) + 120|0);
     $121 = HEAP32[$120>>2]|0;
     $122 = ($75|0)==($121|0);
     if ($122) {
      return;
     }
     __ZN9osgViewer6Viewer24generateSlavePointerDataEPN3osg6CameraERN5osgGA15GUIEventAdapterE($0,$75,$2);
     return;
    }
   } while(0);
   __ZdlPv($82);
   $$053 = $eh$lpad$body$indexZ2D;$$054 = $eh$lpad$body$index7Z2D;
   ___resumeException($$053|0);
   // unreachable;
  }
 } while(0);
 __ZdlPv($28);
 $$053 = $eh$lpad$body57$indexZ2D;$$054 = $eh$lpad$body57$index2Z2D;
 ___resumeException($$053|0);
 // unreachable;
}
function __ZN3osg12observer_ptrINS_6ObjectEEC2EPS1_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$ = 0, $$pr = 0, $$pr6 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = 0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   label = 9;
  } else {
   __THREW__ = 0;
   $3 = (invoke_ii(3325,($1|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $$pr = HEAP32[$0>>2]|0;
    $6 = ($$pr|0)==($3|0);
    if ($6) {
     $16 = $3;
     break;
    }
    HEAP32[$0>>2] = $3;
    $7 = ($3|0)==(0|0);
    if (!($7)) {
     $8 = ((($3)) + 8|0);
     $9 = HEAP32[$8>>2]|0;HEAP32[$8>>2] = (($9+1)|0);
    }
    $10 = ($$pr|0)==(0|0);
    if ($10) {
     label = 9;
     break;
    }
    $11 = ((($$pr)) + 8|0);
    $12 = HEAP32[$11>>2]|0;HEAP32[$11>>2] = (($12-1)|0);
    $13 = ($12|0)==(1);
    if (!($13)) {
     label = 9;
     break;
    }
    __THREW__ = 0;
    invoke_viii(3262,($$pr|0),1,1);
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if (!($15)) {
     label = 9;
     break;
    }
   }
   $23 = ___cxa_find_matching_catch_2()|0;
   $24 = tempRet0;
   $25 = HEAP32[$0>>2]|0;
   $26 = ($25|0)==(0|0);
   if ($26) {
    HEAP32[$0>>2] = 0;
    ___resumeException($23|0);
    // unreachable;
   }
   $27 = ((($25)) + 8|0);
   $28 = HEAP32[$27>>2]|0;HEAP32[$27>>2] = (($28-1)|0);
   $29 = ($28|0)==(1);
   if (!($29)) {
    HEAP32[$0>>2] = 0;
    ___resumeException($23|0);
    // unreachable;
   }
   __THREW__ = 0;
   invoke_viii(3262,($25|0),1,1);
   $30 = __THREW__; __THREW__ = 0;
   $31 = $30&1;
   if ($31) {
    $32 = ___cxa_find_matching_catch_3(0|0)|0;
    $33 = tempRet0;
    ___clang_call_terminate($32);
    // unreachable;
   } else {
    HEAP32[$0>>2] = 0;
    ___resumeException($23|0);
    // unreachable;
   }
  }
 } while(0);
 if ((label|0) == 9) {
  $$pr6 = HEAP32[$0>>2]|0;
  $16 = $$pr6;
 }
 $17 = ($16|0)==(0|0);
 if ($17) {
  $22 = 0;
  $21 = ((($0)) + 4|0);
  HEAP32[$21>>2] = $22;
  return;
 }
 $18 = ((($16)) + 24|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)!=(0|0);
 $$ = $20 ? $1 : 0;
 $22 = $$;
 $21 = ((($0)) + 4|0);
 HEAP32[$21>>2] = $22;
 return;
}
function __ZN5osgGA15GUIEventAdapter14addPointerDataEPNS_11PointerDataE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$pre$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = ((($0)) + 160|0);
 HEAP32[$2>>2] = $1;
 $4 = ($1|0)==(0|0);
 if (!($4)) {
  $5 = ((($1)) + 8|0);
  $6 = HEAP32[$5>>2]|0;HEAP32[$5>>2] = (($6+1)|0);
 }
 $7 = ((($0)) + 164|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($0)) + 168|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8|0)==($10|0);
 if ($11) {
  __THREW__ = 0;
  invoke_vii(3427,($3|0),($2|0));
  $18 = __THREW__; __THREW__ = 0;
  $19 = $18&1;
  if ($19) {
   $25 = ___cxa_find_matching_catch_2()|0;
   $26 = tempRet0;
   $27 = HEAP32[$2>>2]|0;
   $28 = ($27|0)==(0|0);
   if ($28) {
    ___resumeException($25|0);
    // unreachable;
   }
   $29 = ((($27)) + 8|0);
   $30 = HEAP32[$29>>2]|0;HEAP32[$29>>2] = (($30-1)|0);
   $31 = ($30|0)==(1);
   if (!($31)) {
    ___resumeException($25|0);
    // unreachable;
   }
   __THREW__ = 0;
   invoke_viii(3262,($27|0),1,1);
   $32 = __THREW__; __THREW__ = 0;
   $33 = $32&1;
   if ($33) {
    $34 = ___cxa_find_matching_catch_3(0|0)|0;
    $35 = tempRet0;
    ___clang_call_terminate($34);
    // unreachable;
   } else {
    ___resumeException($25|0);
    // unreachable;
   }
  }
 } else {
  $12 = HEAP32[$2>>2]|0;
  HEAP32[$8>>2] = $12;
  $13 = ($12|0)==(0|0);
  if ($13) {
   $17 = $8;
  } else {
   $14 = ((($12)) + 8|0);
   $15 = HEAP32[$14>>2]|0;HEAP32[$14>>2] = (($15+1)|0);
   $$pre$i = HEAP32[$7>>2]|0;
   $17 = $$pre$i;
  }
  $16 = ((($17)) + 4|0);
  HEAP32[$7>>2] = $16;
 }
 $20 = HEAP32[$2>>2]|0;
 $21 = ($20|0)==(0|0);
 if ($21) {
  STACKTOP = sp;return;
 }
 $22 = ((($20)) + 8|0);
 $23 = HEAP32[$22>>2]|0;HEAP32[$22>>2] = (($23-1)|0);
 $24 = ($23|0)==(1);
 if (!($24)) {
  STACKTOP = sp;return;
 }
 __ZNK3osg10Referenced24signalObserversAndDeleteEbb($20,1,1);
 STACKTOP = sp;return;
}
function __ZN9osgViewer6Viewer24generateSlavePointerDataEPN3osg6CameraERN5osgGA15GUIEventAdapterE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$$i$i = 0, $$0 = 0.0, $$0$ph$lcssa$i$i$i = 0, $$0$ph13$i$i$i = 0, $$0100223 = 0, $$0101 = 0.0, $$0102 = 0.0, $$0103 = 0.0, $$07$ph12$i$i$i = 0, $$0710$i$i$i = 0, $$099 = 0.0, $$11 = 0, $$11116 = 0, $$12 = 0, $$12117 = 0, $$13 = 0, $$13118 = 0, $$14 = 0, $$14119 = 0, $$17 = 0;
 var $$17122 = 0, $$2 = 0, $$2107 = 0, $$4 = 0, $$4109 = 0, $$in = 0, $$not = 0, $$not126 = 0, $10 = 0, $100 = 0.0, $101 = 0, $102 = 0, $103 = 0.0, $104 = 0, $105 = 0, $106 = 0.0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0.0, $117 = 0.0, $118 = 0, $119 = 0.0, $12 = 0, $120 = 0.0, $121 = 0, $122 = 0.0, $123 = 0.0, $124 = 0.0, $125 = 0, $126 = 0.0, $127 = 0.0, $128 = 0.0;
 var $129 = 0, $13 = 0, $130 = 0.0, $131 = 0.0, $132 = 0.0, $133 = 0.0, $134 = 0, $135 = 0.0, $136 = 0, $137 = 0.0, $138 = 0, $139 = 0.0, $14 = 0, $140 = 0, $141 = 0.0, $142 = 0, $143 = 0.0, $144 = 0, $145 = 0.0, $146 = 0;
 var $147 = 0.0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0.0, $152 = 0.0, $153 = 0.0, $154 = 0.0, $155 = 0.0, $156 = 0.0, $157 = 0.0, $158 = 0.0, $159 = 0.0, $16 = 0, $160 = 0.0, $161 = 0.0, $162 = 0.0, $163 = 0.0, $164 = 0.0;
 var $165 = 0, $166 = 0.0, $167 = 0.0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0;
 var $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0.0, $199 = 0.0, $20 = 0, $200 = 0;
 var $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0;
 var $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0;
 var $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0;
 var $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0;
 var $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0.0, $290 = 0, $291 = 0;
 var $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0.0, $297 = 0.0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0;
 var $31 = 0.0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0;
 var $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0;
 var $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0;
 var $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0;
 var $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0;
 var $40 = 0.0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0.0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0;
 var $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0;
 var $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0.0, $5 = 0, $50 = 0, $51 = 0.0, $52 = 0, $53 = 0.0, $54 = 0.0, $55 = 0, $56 = 0.0, $57 = 0.0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0.0, $98 = 0, $99 = 0, $brmerge = 0, $eh$lpad$body$indexZ2D = 0, $eh$lpad$body132$index26Z2D = 0, $eh$lpad$body132$indexZ2D = 0, $eh$lpad$body136$index21Z2D = 0, $eh$lpad$body136$indexZ2D = 0, $eh$lpad$body140$index11Z2D = 0, $eh$lpad$body140$indexZ2D = 0, $eh$lpad$body160$index16Z2D = 0, $eh$lpad$body160$indexZ2D = 0, $eh$lpad$body164$index6Z2D = 0, $eh$lpad$body164$indexZ2D = 0, $phitmp = 0.0, $phitmp123 = 0.0;
 var $phitmp124 = 0.0, $phitmp125 = 0.0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1088|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(1088|0);
 $3 = sp + 1072|0;
 $4 = sp + 736|0;
 $5 = sp + 608|0;
 $6 = sp + 480|0;
 $7 = sp + 352|0;
 $8 = sp + 224|0;
 $9 = sp + 96|0;
 $10 = sp + 880|0;
 $11 = sp + 864|0;
 $12 = sp;
 $13 = ((($2)) + 52|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(0|0);
 if ($15) {
  STACKTOP = sp;return;
 }
 $16 = ((($14)) + 24|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==(0|0);
 if ($18) {
  STACKTOP = sp;return;
 }
 $19 = ((($2)) + 56|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)==(0|0);
 if ($21) {
  STACKTOP = sp;return;
 }
 $22 = (___dynamic_cast($20,24816,3888,0)|0);
 $23 = ($22|0)==(0|0);
 if ($23) {
  STACKTOP = sp;return;
 }
 $24 = ((($0)) + 104|0);
 $25 = ((($0)) + 120|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($26|0)==($1|0);
 if ($27) {
  STACKTOP = sp;return;
 }
 $28 = ((($2)) + 104|0);
 $29 = +HEAPF32[$28>>2];
 $30 = ((($2)) + 108|0);
 $31 = +HEAPF32[$30>>2];
 $32 = ((($2)) + 120|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ($33|0)==(1);
 if ($34) {
  $35 = ((($22)) + 44|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = ($36|0)==(0|0);
  if ($37) {
   $$0 = $31;
  } else {
   $38 = ((($36)) + 44|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = (+($39|0));
   $41 = $40 - $31;
   $$0 = $41;
  }
 } else {
  $$0 = $31;
 }
 $42 = ((($26)) + 432|0);
 $43 = ((($26)) + 304|0);
 __ZN3osg7Matrixd12makeIdentityEv($4);
 __ZN3osg7Matrixd4multERKS0_S2_($4,$42,$43);
 $44 = HEAP32[$25>>2]|0;
 $45 = ((($44)) + 288|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = ($46|0)==(0|0);
 do {
  if ($47) {
   $$0101 = 1.0;$$0102 = -1.0;$$0103 = 1.0;$$099 = -1.0;
  } else {
   $48 = ((($46)) + 56|0);
   $49 = +HEAPF64[$48>>3];
   $50 = ((($46)) + 64|0);
   $51 = +HEAPF64[$50>>3];
   $52 = ((($46)) + 72|0);
   $53 = +HEAPF64[$52>>3];
   $54 = $49 + $53;
   $55 = ((($46)) + 80|0);
   $56 = +HEAPF64[$55>>3];
   $57 = $51 + $56;
   __THREW__ = 0;
   invoke_vii(3301,($5|0),($46|0));
   $58 = __THREW__; __THREW__ = 0;
   $59 = $58&1;
   if (!($59)) {
    __THREW__ = 0;
    invoke_vii(3302,($4|0),($5|0));
    $60 = __THREW__; __THREW__ = 0;
    $61 = $60&1;
    if (!($61)) {
     $phitmp = $49;
     $phitmp123 = $54;
     $phitmp124 = $51;
     $phitmp125 = $57;
     $$0101 = $phitmp123;$$0102 = $phitmp124;$$0103 = $phitmp125;$$099 = $phitmp;
     break;
    }
   }
   $64 = ___cxa_find_matching_catch_2()|0;
   $65 = tempRet0;
   $$17 = $64;$$17122 = $65;
   ___resumeException($$17|0);
   // unreachable;
  }
 } while(0);
 __THREW__ = 0;
 $66 = (invoke_iii(3428,($24|0),($1|0))|0);
 $67 = __THREW__; __THREW__ = 0;
 $68 = $67&1;
 if ($68) {
  $62 = ___cxa_find_matching_catch_2()|0;
  $63 = tempRet0;
  $$17 = $62;$$17122 = $63;
  ___resumeException($$17|0);
  // unreachable;
 }
 $69 = ($66|0)==(0|0);
 L32: do {
  if (!($69)) {
   $70 = ((($1)) + 136|0);
   $71 = HEAP32[$70>>2]|0;
   $72 = ((($66)) + 264|0);
   $73 = HEAP8[$72>>0]|0;
   $74 = ($73<<24>>24)!=(0);
   $$not = ($71|0)!=(0);
   $$not126 = $74 ^ 1;
   $brmerge = $$not | $$not126;
   if (!($brmerge)) {
    $75 = ((($1)) + 288|0);
    $76 = HEAP32[$75>>2]|0;
    __THREW__ = 0;
    invoke_vi(3299,($6|0));
    $77 = __THREW__; __THREW__ = 0;
    $78 = $77&1;
    if (!($78)) {
     $79 = ((($1)) + 304|0);
     $80 = ((($1)) + 432|0);
     __THREW__ = 0;
     invoke_viii(3300,($6|0),($80|0),($79|0));
     $81 = __THREW__; __THREW__ = 0;
     $82 = $81&1;
     if (!($82)) {
      $83 = ($76|0)==(0|0);
      do {
       if ($83) {
        label = 27;
       } else {
        __THREW__ = 0;
        invoke_vii(3301,($7|0),($76|0));
        $84 = __THREW__; __THREW__ = 0;
        $85 = $84&1;
        if (!($85)) {
         __THREW__ = 0;
         invoke_vii(3302,($6|0),($7|0));
         $86 = __THREW__; __THREW__ = 0;
         $87 = $86&1;
         if (!($87)) {
          label = 27;
          break;
         }
        }
        $92 = ___cxa_find_matching_catch_2()|0;
        $93 = tempRet0;
        $$4 = $92;$$4109 = $93;
       }
      } while(0);
      L45: do {
       if ((label|0) == 27) {
        __THREW__ = 0;
        invoke_vi(3299,($9|0));
        $94 = __THREW__; __THREW__ = 0;
        $95 = $94&1;
        L47: do {
         if (!($95)) {
          $96 = ((($6)) + 24|0);
          $97 = +HEAPF64[$96>>3];
          $98 = $97 == 0.0;
          do {
           if ($98) {
            $99 = ((($6)) + 56|0);
            $100 = +HEAPF64[$99>>3];
            $101 = $100 == 0.0;
            if (!($101)) {
             label = 33;
             break;
            }
            $102 = ((($6)) + 88|0);
            $103 = +HEAPF64[$102>>3];
            $104 = $103 == 0.0;
            if (!($104)) {
             label = 33;
             break;
            }
            $105 = ((($6)) + 120|0);
            $106 = +HEAPF64[$105>>3];
            $107 = $106 == 1.0;
            if (!($107)) {
             label = 33;
             break;
            }
            __THREW__ = 0;
            (invoke_iii(3303,($9|0),($6|0))|0);
            $108 = __THREW__; __THREW__ = 0;
            $109 = $108&1;
            if ($109) {
             break L47;
            }
           } else {
            label = 33;
           }
          } while(0);
          if ((label|0) == 33) {
           __THREW__ = 0;
           (invoke_iii(3304,($9|0),($6|0))|0);
           $110 = __THREW__; __THREW__ = 0;
           $111 = $110&1;
           if ($111) {
            break;
           }
          }
          __THREW__ = 0;
          invoke_vi(3299,($8|0));
          $112 = __THREW__; __THREW__ = 0;
          $113 = $112&1;
          do {
           if (!($113)) {
            __THREW__ = 0;
            invoke_viii(3300,($8|0),($9|0),($4|0));
            $114 = __THREW__; __THREW__ = 0;
            $115 = $114&1;
            if ($115) {
             break;
            }
            $116 = $29;
            $117 = $$0;
            $118 = ((($8)) + 24|0);
            $119 = +HEAPF64[$118>>3];
            $120 = $116 * $119;
            $121 = ((($8)) + 56|0);
            $122 = +HEAPF64[$121>>3];
            $123 = $117 * $122;
            $124 = $120 + $123;
            $125 = ((($8)) + 88|0);
            $126 = +HEAPF64[$125>>3];
            $127 = $126 * 0.0;
            $128 = $124 + $127;
            $129 = ((($8)) + 120|0);
            $130 = +HEAPF64[$129>>3];
            $131 = $130 + $128;
            $132 = 1.0 / $131;
            $133 = +HEAPF64[$8>>3];
            $134 = ((($8)) + 32|0);
            $135 = +HEAPF64[$134>>3];
            $136 = ((($8)) + 64|0);
            $137 = +HEAPF64[$136>>3];
            $138 = ((($8)) + 96|0);
            $139 = +HEAPF64[$138>>3];
            $140 = ((($8)) + 8|0);
            $141 = +HEAPF64[$140>>3];
            $142 = ((($8)) + 40|0);
            $143 = +HEAPF64[$142>>3];
            $144 = ((($8)) + 72|0);
            $145 = +HEAPF64[$144>>3];
            $146 = ((($8)) + 104|0);
            $147 = +HEAPF64[$146>>3];
            __THREW__ = 0;
            $148 = (invoke_ii(3276,44)|0);
            $149 = __THREW__; __THREW__ = 0;
            $150 = $149&1;
            L60: do {
             if ($150) {
              label = 45;
             } else {
              $151 = $116 * $141;
              $152 = $117 * $143;
              $153 = $151 + $152;
              $154 = $145 * 0.0;
              $155 = $153 + $154;
              $156 = $147 + $155;
              $157 = $132 * $156;
              $158 = $116 * $133;
              $159 = $117 * $135;
              $160 = $158 + $159;
              $161 = $137 * 0.0;
              $162 = $160 + $161;
              $163 = $139 + $162;
              $164 = $132 * $163;
              $165 = HEAP32[$25>>2]|0;
              $166 = $164;
              $167 = $157;
              __THREW__ = 0;
              invoke_vi(3282,($148|0));
              $168 = __THREW__; __THREW__ = 0;
              $169 = $168&1;
              do {
               if ($169) {
                $193 = ___cxa_find_matching_catch_2()|0;
                $194 = tempRet0;
                $eh$lpad$body164$index6Z2D = $194;$eh$lpad$body164$indexZ2D = $193;
               } else {
                HEAP32[$148>>2] = (37072);
                $170 = ((($148)) + 12|0);
                __THREW__ = 0;
                invoke_vii(3422,($170|0),($165|0));
                $171 = __THREW__; __THREW__ = 0;
                $172 = $171&1;
                if ($172) {
                 $173 = ___cxa_find_matching_catch_2()|0;
                 $174 = tempRet0;
                 __THREW__ = 0;
                 invoke_vi(712,($148|0));
                 $175 = __THREW__; __THREW__ = 0;
                 $176 = $175&1;
                 if (!($176)) {
                  $eh$lpad$body164$index6Z2D = $174;$eh$lpad$body164$indexZ2D = $173;
                  break;
                 }
                 $177 = ___cxa_find_matching_catch_3(0|0)|0;
                 $178 = tempRet0;
                 ___clang_call_terminate($177);
                 // unreachable;
                } else {
                 $179 = ((($148)) + 20|0);
                 HEAPF32[$179>>2] = $166;
                 $180 = ((($148)) + 24|0);
                 HEAPF32[$180>>2] = $$099;
                 $181 = ((($148)) + 28|0);
                 HEAPF32[$181>>2] = $$0101;
                 $182 = ((($148)) + 32|0);
                 HEAPF32[$182>>2] = $167;
                 $183 = ((($148)) + 36|0);
                 HEAPF32[$183>>2] = $$0102;
                 $184 = ((($148)) + 40|0);
                 HEAPF32[$184>>2] = $$0103;
                 __THREW__ = 0;
                 invoke_vii(3425,($2|0),($148|0));
                 $185 = __THREW__; __THREW__ = 0;
                 $186 = $185&1;
                 if ($186) {
                  label = 45;
                  break L60;
                 }
                 break L32;
                }
               }
              } while(0);
              __ZdlPv($148);
              $$2 = $eh$lpad$body164$indexZ2D;$$2107 = $eh$lpad$body164$index6Z2D;
             }
            } while(0);
            if ((label|0) == 45) {
             $191 = ___cxa_find_matching_catch_2()|0;
             $192 = tempRet0;
             $$2 = $191;$$2107 = $192;
            }
            $$4 = $$2;$$4109 = $$2107;
            break L45;
           }
          } while(0);
          $189 = ___cxa_find_matching_catch_2()|0;
          $190 = tempRet0;
          $$4 = $189;$$4109 = $190;
          break L45;
         }
        } while(0);
        $187 = ___cxa_find_matching_catch_2()|0;
        $188 = tempRet0;
        $$4 = $187;$$4109 = $188;
       }
      } while(0);
      $$17 = $$4;$$17122 = $$4109;
      ___resumeException($$17|0);
      // unreachable;
     }
    }
    $90 = ___cxa_find_matching_catch_2()|0;
    $91 = tempRet0;
    $$17 = $90;$$17122 = $91;
    ___resumeException($$17|0);
    // unreachable;
   }
   if (!($74)) {
    __THREW__ = 0;
    $195 = (invoke_ii(3276,96)|0);
    $196 = __THREW__; __THREW__ = 0;
    $197 = $196&1;
    if ($197) {
     $88 = ___cxa_find_matching_catch_2()|0;
     $89 = tempRet0;
     $$17 = $88;$$17122 = $89;
     ___resumeException($$17|0);
     // unreachable;
    }
    $198 = $29;
    $199 = $$0;
    __THREW__ = 0;
    invoke_viidd(3429,($195|0),0,(+$198),(+$199));
    $200 = __THREW__; __THREW__ = 0;
    $201 = $200&1;
    if ($201) {
     $243 = ___cxa_find_matching_catch_2()|0;
     $244 = tempRet0;
     __ZdlPv($195);
     $$17 = $243;$$17122 = $244;
     ___resumeException($$17|0);
     // unreachable;
    }
    $202 = ((($195)) + 8|0);
    $203 = HEAP32[$202>>2]|0;HEAP32[$202>>2] = (($203+1)|0);
    __THREW__ = 0;
    invoke_viii(3310,($10|0),($195|0),(0|0));
    $204 = __THREW__; __THREW__ = 0;
    $205 = $204&1;
    L90: do {
     if ($205) {
      $245 = ___cxa_find_matching_catch_2()|0;
      $246 = tempRet0;
      $$14 = $245;$$14119 = $246;
      label = 134;
     } else {
      $206 = HEAP32[$1>>2]|0;
      $207 = ((($206)) + 188|0);
      $208 = HEAP32[$207>>2]|0;
      __THREW__ = 0;
      invoke_vii($208|0,($1|0),($10|0));
      $209 = __THREW__; __THREW__ = 0;
      $210 = $209&1;
      L93: do {
       if ($210) {
        label = 67;
       } else {
        $211 = HEAP32[$195>>2]|0;
        $212 = ((($211)) + 32|0);
        $213 = HEAP32[$212>>2]|0;
        __THREW__ = 0;
        $214 = (invoke_ii($213|0,($195|0))|0);
        $215 = __THREW__; __THREW__ = 0;
        $216 = $215&1;
        if ($216) {
         label = 67;
        } else {
         L96: do {
          if ($214) {
           HEAPF32[$11>>2] = 0.0;
           $217 = ((($11)) + 4|0);
           HEAPF32[$217>>2] = 0.0;
           $218 = ((($11)) + 8|0);
           HEAPF32[$218>>2] = 0.0;
           $219 = ((($195)) + 28|0);
           $220 = HEAP32[$219>>2]|0;
           $221 = ($220|0)==(0|0);
           $$$i$i = $221 ? $195 : $220;
           $222 = ((($$$i$i)) + 88|0);
           $223 = HEAP32[$222>>2]|0;
           $224 = ($223|0)==(0);
           if ($224) {
            HEAPF64[$12>>3] = -1.0;
            $225 = ((($12)) + 8|0);
            $226 = ((($12)) + 32|0);
            ;HEAP32[$225>>2]=0|0;HEAP32[$225+4>>2]=0|0;HEAP32[$225+8>>2]=0|0;HEAP32[$225+12>>2]=0|0;HEAP32[$225+16>>2]=0|0;
            dest=$226; stop=dest+64|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
            label = 60;
           } else {
            $227 = ((($$$i$i)) + 80|0);
            $228 = HEAP32[$227>>2]|0;
            $229 = ((($228)) + 16|0);
            __THREW__ = 0;
            invoke_vii(3430,($12|0),($229|0));
            $230 = __THREW__; __THREW__ = 0;
            $231 = $230&1;
            if ($231) {
             label = 68;
            } else {
             label = 60;
            }
           }
           L101: do {
            if ((label|0) == 60) {
             __THREW__ = 0;
             $232 = (invoke_iii(3431,($12|0),($11|0))|0);
             $233 = __THREW__; __THREW__ = 0;
             $234 = $233&1;
             if ($234) {
              $251 = ___cxa_find_matching_catch_2()|0;
              $252 = tempRet0;
              __THREW__ = 0;
              invoke_vi(3432,($12|0));
              $253 = __THREW__; __THREW__ = 0;
              $254 = $253&1;
              if ($254) {
               break L90;
              } else {
               $$11 = $251;$$11116 = $252;
               break;
              }
             }
             __THREW__ = 0;
             invoke_vi(3432,($12|0));
             $235 = __THREW__; __THREW__ = 0;
             $236 = $235&1;
             if ($236) {
              label = 68;
              break;
             }
             $237 = ($232|0)==(0|0);
             L107: do {
              if (!($237)) {
               $238 = ((($0)) + 124|0);
               $239 = ((($0)) + 128|0);
               $240 = HEAP32[$239>>2]|0;
               $241 = HEAP32[$238>>2]|0;
               $242 = ($240|0)==($241|0);
               if ($242) {
                break;
               }
               $$0100223 = 0;$$in = $241;
               L110: while(1) {
                $255 = $$in;
                $256 = (((($255) + (($$0100223*272)|0)|0)) + 4|0);
                $257 = HEAP32[$256>>2]|0;
                $258 = ($257|0)==(0|0);
                do {
                 if (!($258)) {
                  $259 = ((($257)) + 588|0);
                  $260 = HEAP32[$259>>2]|0;
                  $261 = ($260|0)==(0|0);
                  if ($261) {
                   break;
                  } else {
                   $$0$ph13$i$i$i = $259;$$07$ph12$i$i$i = $260;
                  }
                  L114: while(1) {
                   $$0710$i$i$i = $$07$ph12$i$i$i;
                   while(1) {
                    $262 = ((($$0710$i$i$i)) + 16|0);
                    $263 = HEAP32[$262>>2]|0;
                    $264 = ($263|0)<(3);
                    if (!($264)) {
                     break;
                    }
                    $267 = ((($$0710$i$i$i)) + 4|0);
                    $268 = HEAP32[$267>>2]|0;
                    $269 = ($268|0)==(0|0);
                    if ($269) {
                     $$0$ph$lcssa$i$i$i = $$0$ph13$i$i$i;
                     break L114;
                    } else {
                     $$0710$i$i$i = $268;
                    }
                   }
                   $265 = HEAP32[$$0710$i$i$i>>2]|0;
                   $266 = ($265|0)==(0|0);
                   if ($266) {
                    $$0$ph$lcssa$i$i$i = $$0710$i$i$i;
                    break;
                   } else {
                    $$0$ph13$i$i$i = $$0710$i$i$i;$$07$ph12$i$i$i = $265;
                   }
                  }
                  $270 = ($$0$ph$lcssa$i$i$i|0)==($259|0);
                  if ($270) {
                   break;
                  }
                  $271 = ((($$0$ph$lcssa$i$i$i)) + 16|0);
                  $272 = HEAP32[$271>>2]|0;
                  $273 = ($272|0)>(3);
                  if ($273) {
                   break;
                  }
                  $274 = ((($$0$ph$lcssa$i$i$i)) + 28|0);
                  $275 = HEAP32[$274>>2]|0;
                  $276 = ($275|0)==($232|0);
                  if (!($276)) {
                   break;
                  }
                  $277 = (___dynamic_cast($232,26864,26912,0)|0);
                  $278 = ($277|0)==(0|0);
                  if (!($278)) {
                   __THREW__ = 0;
                   $279 = (invoke_ii(3276,44)|0);
                   $280 = __THREW__; __THREW__ = 0;
                   $281 = $280&1;
                   if ($281) {
                    label = 88;
                    break L110;
                   }
                   $282 = HEAP32[$11>>2]|0;
                   $283 = HEAP32[$277>>2]|0;
                   $284 = ((($283)) + 184|0);
                   $285 = HEAP32[$284>>2]|0;
                   __THREW__ = 0;
                   $286 = (invoke_ii($285|0,($277|0))|0);
                   $287 = __THREW__; __THREW__ = 0;
                   $288 = $287&1;
                   if ($288) {
                    label = 90;
                    break L110;
                   }
                   $289 = HEAP32[$217>>2]|0;
                   $290 = HEAP32[$277>>2]|0;
                   $291 = ((($290)) + 188|0);
                   $292 = HEAP32[$291>>2]|0;
                   __THREW__ = 0;
                   $293 = (invoke_ii($292|0,($277|0))|0);
                   $294 = __THREW__; __THREW__ = 0;
                   $295 = $294&1;
                   if ($295) {
                    label = 90;
                    break L110;
                   }
                   $296 = (+($286|0));
                   $297 = (+($293|0));
                   __THREW__ = 0;
                   invoke_vi(3282,($279|0));
                   $298 = __THREW__; __THREW__ = 0;
                   $299 = $298&1;
                   if ($299) {
                    label = 90;
                    break L110;
                   }
                   HEAP32[$279>>2] = (37072);
                   $300 = ((($279)) + 12|0);
                   __THREW__ = 0;
                   invoke_vii(3422,($300|0),($257|0));
                   $301 = __THREW__; __THREW__ = 0;
                   $302 = $301&1;
                   if ($302) {
                    label = 85;
                    break L110;
                   }
                   $309 = ((($279)) + 20|0);
                   HEAP32[$309>>2] = $282;
                   $310 = ((($279)) + 24|0);
                   HEAPF32[$310>>2] = 0.0;
                   $311 = ((($279)) + 28|0);
                   HEAPF32[$311>>2] = $296;
                   $312 = ((($279)) + 32|0);
                   HEAP32[$312>>2] = $289;
                   $313 = ((($279)) + 36|0);
                   HEAPF32[$313>>2] = 0.0;
                   $314 = ((($279)) + 40|0);
                   HEAPF32[$314>>2] = $297;
                   __THREW__ = 0;
                   invoke_vii(3425,($2|0),($279|0));
                   $315 = __THREW__; __THREW__ = 0;
                   $316 = $315&1;
                   if ($316) {
                    label = 88;
                    break L110;
                   } else {
                    break;
                   }
                  }
                  $321 = (___dynamic_cast($232,26864,26896,0)|0);
                  $322 = ($321|0)==(0|0);
                  if ($322) {
                   __THREW__ = 0;
                   $371 = (invoke_ii(3276,44)|0);
                   $372 = __THREW__; __THREW__ = 0;
                   $373 = $372&1;
                   if ($373) {
                    label = 88;
                    break L110;
                   }
                   $374 = HEAP32[$11>>2]|0;
                   $375 = HEAP32[$217>>2]|0;
                   __THREW__ = 0;
                   invoke_vi(3282,($371|0));
                   $376 = __THREW__; __THREW__ = 0;
                   $377 = $376&1;
                   if ($377) {
                    label = 115;
                    break L110;
                   }
                   HEAP32[$371>>2] = (37072);
                   $378 = ((($371)) + 12|0);
                   __THREW__ = 0;
                   invoke_vii(3422,($378|0),($257|0));
                   $379 = __THREW__; __THREW__ = 0;
                   $380 = $379&1;
                   if ($380) {
                    label = 112;
                    break L110;
                   }
                   $387 = ((($371)) + 20|0);
                   HEAP32[$387>>2] = $374;
                   $388 = ((($371)) + 24|0);
                   HEAPF32[$388>>2] = 0.0;
                   $389 = ((($371)) + 28|0);
                   HEAPF32[$389>>2] = 1.0;
                   $390 = ((($371)) + 32|0);
                   HEAP32[$390>>2] = $375;
                   $391 = ((($371)) + 36|0);
                   HEAPF32[$391>>2] = 0.0;
                   $392 = ((($371)) + 40|0);
                   HEAPF32[$392>>2] = 1.0;
                   __THREW__ = 0;
                   invoke_vii(3425,($2|0),($371|0));
                   $393 = __THREW__; __THREW__ = 0;
                   $394 = $393&1;
                   if ($394) {
                    label = 88;
                    break L110;
                   } else {
                    break;
                   }
                  }
                  __THREW__ = 0;
                  $323 = (invoke_ii(3265,4)|0);
                  $324 = __THREW__; __THREW__ = 0;
                  $325 = $324&1;
                  if ($325) {
                   label = 88;
                   break L110;
                  }
                  if (!($323)) {
                   break;
                  }
                  __THREW__ = 0;
                  $326 = (invoke_ii(3266,4)|0);
                  $327 = __THREW__; __THREW__ = 0;
                  $328 = $327&1;
                  if ($328) {
                   label = 88;
                   break L110;
                  }
                  __THREW__ = 0;
                  $329 = (invoke_iiii(3267,($326|0),(104239|0),35)|0);
                  $330 = __THREW__; __THREW__ = 0;
                  $331 = $330&1;
                  if ($331) {
                   label = 88;
                   break L110;
                  }
                  $332 = HEAP32[$274>>2]|0;
                  __THREW__ = 0;
                  $333 = (invoke_iii(3275,($329|0),($332|0))|0);
                  $334 = __THREW__; __THREW__ = 0;
                  $335 = $334&1;
                  if ($335) {
                   label = 88;
                   break L110;
                  }
                  __THREW__ = 0;
                  $336 = (invoke_iiii(3267,($333|0),(146554|0),2)|0);
                  $337 = __THREW__; __THREW__ = 0;
                  $338 = $337&1;
                  if ($338) {
                   label = 88;
                   break L110;
                  }
                  $339 = ((($$0$ph$lcssa$i$i$i)) + 36|0);
                  $340 = HEAP32[$339>>2]|0;
                  __THREW__ = 0;
                  $341 = (invoke_iii(3417,($336|0),($340|0))|0);
                  $342 = __THREW__; __THREW__ = 0;
                  $343 = $342&1;
                  if ($343) {
                   label = 88;
                   break L110;
                  }
                  $344 = HEAP32[$341>>2]|0;
                  $345 = ((($344)) + -12|0);
                  $346 = HEAP32[$345>>2]|0;
                  $347 = (($341) + ($346)|0);
                  __THREW__ = 0;
                  invoke_vii(3257,($3|0),($347|0));
                  $348 = __THREW__; __THREW__ = 0;
                  $349 = $348&1;
                  if ($349) {
                   label = 88;
                   break L110;
                  }
                  __THREW__ = 0;
                  $350 = (invoke_iii(3255,($3|0),(215188|0))|0);
                  $351 = __THREW__; __THREW__ = 0;
                  $352 = $351&1;
                  if ($352) {
                   label = 103;
                   break L110;
                  }
                  $353 = HEAP32[$350>>2]|0;
                  $354 = ((($353)) + 28|0);
                  $355 = HEAP32[$354>>2]|0;
                  __THREW__ = 0;
                  $356 = (invoke_iii($355|0,($350|0),10)|0);
                  $357 = __THREW__; __THREW__ = 0;
                  $358 = $357&1;
                  if ($358) {
                   label = 103;
                   break L110;
                  }
                  __THREW__ = 0;
                  invoke_vi(3263,($3|0));
                  $365 = __THREW__; __THREW__ = 0;
                  $366 = $365&1;
                  if ($366) {
                   label = 88;
                   break L110;
                  }
                  __THREW__ = 0;
                  (invoke_iii(3268,($341|0),($356|0))|0);
                  $367 = __THREW__; __THREW__ = 0;
                  $368 = $367&1;
                  if ($368) {
                   label = 88;
                   break L110;
                  }
                  __THREW__ = 0;
                  (invoke_ii(3269,($341|0))|0);
                  $369 = __THREW__; __THREW__ = 0;
                  $370 = $369&1;
                  if ($370) {
                   label = 88;
                   break L110;
                  }
                 }
                } while(0);
                $397 = (($$0100223) + 1)|0;
                $398 = HEAP32[$239>>2]|0;
                $399 = HEAP32[$238>>2]|0;
                $400 = (($398) - ($399))|0;
                $401 = (($400|0) / 272)&-1;
                $402 = ($397>>>0)<($401>>>0);
                if ($402) {
                 $$0100223 = $397;$$in = $399;
                } else {
                 break L107;
                }
               }
               do {
                if ((label|0) == 85) {
                 $303 = ___cxa_find_matching_catch_2()|0;
                 $304 = tempRet0;
                 __THREW__ = 0;
                 invoke_vi(712,($279|0));
                 $305 = __THREW__; __THREW__ = 0;
                 $306 = $305&1;
                 if (!($306)) {
                  $eh$lpad$body160$index16Z2D = $304;$eh$lpad$body160$indexZ2D = $303;
                  label = 91;
                  break;
                 }
                 $307 = ___cxa_find_matching_catch_3(0|0)|0;
                 $308 = tempRet0;
                 ___clang_call_terminate($307);
                 // unreachable;
                }
                else if ((label|0) == 88) {
                 $317 = ___cxa_find_matching_catch_2()|0;
                 $318 = tempRet0;
                 $eh$lpad$body140$index11Z2D = $318;$eh$lpad$body140$indexZ2D = $317;
                 label = 89;
                }
                else if ((label|0) == 90) {
                 $319 = ___cxa_find_matching_catch_2()|0;
                 $320 = tempRet0;
                 $eh$lpad$body160$index16Z2D = $320;$eh$lpad$body160$indexZ2D = $319;
                 label = 91;
                }
                else if ((label|0) == 103) {
                 $359 = ___cxa_find_matching_catch_2()|0;
                 $360 = tempRet0;
                 __THREW__ = 0;
                 invoke_vi(3263,($3|0));
                 $361 = __THREW__; __THREW__ = 0;
                 $362 = $361&1;
                 if ($362) {
                  $363 = ___cxa_find_matching_catch_3(0|0)|0;
                  $364 = tempRet0;
                  ___clang_call_terminate($363);
                  // unreachable;
                 } else {
                  $eh$lpad$body140$index11Z2D = $360;$eh$lpad$body140$indexZ2D = $359;
                  label = 89;
                  break;
                 }
                }
                else if ((label|0) == 112) {
                 $381 = ___cxa_find_matching_catch_2()|0;
                 $382 = tempRet0;
                 __THREW__ = 0;
                 invoke_vi(712,($371|0));
                 $383 = __THREW__; __THREW__ = 0;
                 $384 = $383&1;
                 if (!($384)) {
                  $eh$lpad$body136$index21Z2D = $382;$eh$lpad$body136$indexZ2D = $381;
                  label = 116;
                  break;
                 }
                 $385 = ___cxa_find_matching_catch_3(0|0)|0;
                 $386 = tempRet0;
                 ___clang_call_terminate($385);
                 // unreachable;
                }
                else if ((label|0) == 115) {
                 $395 = ___cxa_find_matching_catch_2()|0;
                 $396 = tempRet0;
                 $eh$lpad$body136$index21Z2D = $396;$eh$lpad$body136$indexZ2D = $395;
                 label = 116;
                }
               } while(0);
               if ((label|0) == 89) {
                $$11 = $eh$lpad$body140$indexZ2D;$$11116 = $eh$lpad$body140$index11Z2D;
                break L101;
               }
               else if ((label|0) == 91) {
                __ZdlPv($279);
                $$11 = $eh$lpad$body160$indexZ2D;$$11116 = $eh$lpad$body160$index16Z2D;
                break L101;
               }
               else if ((label|0) == 116) {
                __ZdlPv($371);
                $$11 = $eh$lpad$body136$indexZ2D;$$11116 = $eh$lpad$body136$index21Z2D;
                break L101;
               }
              }
             } while(0);
             break L96;
            }
           } while(0);
           if ((label|0) == 68) {
            $249 = ___cxa_find_matching_catch_2()|0;
            $250 = tempRet0;
            $$11 = $249;$$11116 = $250;
           }
           $$12 = $$11;$$12117 = $$11116;
           label = 128;
           break L93;
          }
         } while(0);
         __THREW__ = 0;
         invoke_vii(3312,($10|0),(47564|0));
         $403 = __THREW__; __THREW__ = 0;
         $404 = $403&1;
         do {
          if ($404) {
           $408 = ___cxa_find_matching_catch_2()|0;
           $409 = tempRet0;
           $410 = ((($10)) + 160|0);
           __THREW__ = 0;
           invoke_vi(388,($410|0));
           $411 = __THREW__; __THREW__ = 0;
           $412 = $411&1;
           if (!($412)) {
            $eh$lpad$body132$index26Z2D = $409;$eh$lpad$body132$indexZ2D = $408;
            break;
           }
           $413 = ___cxa_find_matching_catch_3(0|0)|0;
           $414 = tempRet0;
           ___clang_call_terminate($413);
           // unreachable;
          } else {
           $405 = ((($10)) + 160|0);
           __THREW__ = 0;
           invoke_vi(388,($405|0));
           $406 = __THREW__; __THREW__ = 0;
           $407 = $406&1;
           if ($407) {
            $419 = ___cxa_find_matching_catch_2()|0;
            $420 = tempRet0;
            $eh$lpad$body132$index26Z2D = $420;$eh$lpad$body132$indexZ2D = $419;
            break;
           }
           $415 = HEAP32[$202>>2]|0;HEAP32[$202>>2] = (($415-1)|0);
           $416 = ($415|0)==(1);
           if (!($416)) {
            break L32;
           }
           __THREW__ = 0;
           invoke_viii(3262,($195|0),1,1);
           $417 = __THREW__; __THREW__ = 0;
           $418 = $417&1;
           if (!($418)) {
            break L32;
           }
           $433 = ___cxa_find_matching_catch_2()|0;
           $434 = tempRet0;
           $$17 = $433;$$17122 = $434;
           ___resumeException($$17|0);
           // unreachable;
          }
         } while(0);
         $$13 = $eh$lpad$body132$indexZ2D;$$13118 = $eh$lpad$body132$index26Z2D;
        }
       }
      } while(0);
      if ((label|0) == 67) {
       $247 = ___cxa_find_matching_catch_2()|0;
       $248 = tempRet0;
       $$12 = $247;$$12117 = $248;
       label = 128;
      }
      do {
       if ((label|0) == 128) {
        __THREW__ = 0;
        invoke_vii(3312,($10|0),(47564|0));
        $421 = __THREW__; __THREW__ = 0;
        $422 = $421&1;
        if (!($422)) {
         $423 = ((($10)) + 160|0);
         __THREW__ = 0;
         invoke_vi(388,($423|0));
         $424 = __THREW__; __THREW__ = 0;
         $425 = $424&1;
         if ($425) {
          break L90;
         } else {
          $$13 = $$12;$$13118 = $$12117;
          break;
         }
        }
        $426 = ___cxa_find_matching_catch_3(0|0)|0;
        $427 = tempRet0;
        $428 = ((($10)) + 160|0);
        __THREW__ = 0;
        invoke_vi(388,($428|0));
        $429 = __THREW__; __THREW__ = 0;
        $430 = $429&1;
        if ($430) {
         $431 = ___cxa_find_matching_catch_3(0|0)|0;
         $432 = tempRet0;
         ___clang_call_terminate($431);
         // unreachable;
        } else {
         $eh$lpad$body$indexZ2D = $426;
         ___clang_call_terminate($eh$lpad$body$indexZ2D);
         // unreachable;
        }
       }
      } while(0);
      $$14 = $$13;$$14119 = $$13118;
      label = 134;
     }
    } while(0);
    if ((label|0) == 134) {
     $435 = HEAP32[$202>>2]|0;HEAP32[$202>>2] = (($435-1)|0);
     $436 = ($435|0)==(1);
     if (!($436)) {
      $$17 = $$14;$$17122 = $$14119;
      ___resumeException($$17|0);
      // unreachable;
     }
     __THREW__ = 0;
     invoke_viii(3262,($195|0),1,1);
     $437 = __THREW__; __THREW__ = 0;
     $438 = $437&1;
     if (!($438)) {
      $$17 = $$14;$$17122 = $$14119;
      ___resumeException($$17|0);
      // unreachable;
     }
    }
    $439 = ___cxa_find_matching_catch_3(0|0)|0;
    $440 = tempRet0;
    $eh$lpad$body$indexZ2D = $439;
    ___clang_call_terminate($eh$lpad$body$indexZ2D);
    // unreachable;
   }
  }
 } while(0);
 STACKTOP = sp;return;
}
function __ZN7osgUtil14RayIntersector12IntersectionC2ERKS1_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$010 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0.0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i13 = 0, $scevgep5$i$i$i = 0, $scevgep5$i$i$i14 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $2 = +HEAPF64[$1>>3];
 HEAPF64[$0>>3] = $2;
 $3 = ((($0)) + 8|0);
 $4 = ((($1)) + 8|0);
 __ZNSt3__26vectorIPN3osg4NodeENS_9allocatorIS3_EEEC2ERKS6_($3,$4);
 $5 = ((($0)) + 20|0);
 $6 = ((($1)) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 HEAP32[$5>>2] = $7;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = ((($7)) + 8|0);
  $10 = HEAP32[$9>>2]|0;HEAP32[$9>>2] = (($10+1)|0);
 }
 $11 = ((($0)) + 24|0);
 $12 = ((($1)) + 24|0);
 $13 = HEAP32[$12>>2]|0;
 HEAP32[$11>>2] = $13;
 $14 = ($13|0)==(0|0);
 if (!($14)) {
  $15 = ((($13)) + 8|0);
  $16 = HEAP32[$15>>2]|0;HEAP32[$15>>2] = (($16+1)|0);
 }
 $17 = ((($0)) + 32|0);
 $18 = ((($1)) + 32|0);
 dest=$17; src=$18; stop=dest+36|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $19 = ((($0)) + 68|0);
 $20 = ((($1)) + 68|0);
 __THREW__ = 0;
 invoke_vii(3317,($19|0),($20|0));
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if ($22) {
  $30 = ___cxa_find_matching_catch_2()|0;
  $31 = tempRet0;
  $$0 = $31;$$010 = $30;
 } else {
  $23 = ((($0)) + 80|0);
  $24 = ((($1)) + 80|0);
  __THREW__ = 0;
  invoke_vii(3318,($23|0),($24|0));
  $25 = __THREW__; __THREW__ = 0;
  $26 = $25&1;
  if (!($26)) {
   $27 = ((($0)) + 92|0);
   $28 = ((($1)) + 92|0);
   $29 = HEAP32[$28>>2]|0;
   HEAP32[$27>>2] = $29;
   return;
  }
  $32 = ___cxa_find_matching_catch_2()|0;
  $33 = tempRet0;
  $34 = HEAP32[$19>>2]|0;
  $35 = ($34|0)==(0|0);
  if ($35) {
   $$0 = $33;$$010 = $32;
  } else {
   $36 = ((($0)) + 72|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = ($37|0)==($34|0);
   if (!($38)) {
    $scevgep$i$i$i13 = ((($37)) + -4|0);
    $39 = $scevgep$i$i$i13;
    $40 = $34;
    $41 = (($39) - ($40))|0;
    $42 = $41 >>> 2;
    $43 = $42 ^ -1;
    $scevgep5$i$i$i14 = (($37) + ($43<<2)|0);
    HEAP32[$36>>2] = $scevgep5$i$i$i14;
   }
   __ZdlPv($34);
   $$0 = $33;$$010 = $32;
  }
 }
 $44 = HEAP32[$11>>2]|0;
 $45 = ($44|0)==(0|0);
 if (!($45)) {
  $46 = ((($44)) + 8|0);
  $47 = HEAP32[$46>>2]|0;HEAP32[$46>>2] = (($47-1)|0);
  $48 = ($47|0)==(1);
  if ($48) {
   __THREW__ = 0;
   invoke_viii(3262,($44|0),1,1);
   $49 = __THREW__; __THREW__ = 0;
   $50 = $49&1;
   if ($50) {
    $68 = ___cxa_find_matching_catch_3(0|0)|0;
    $69 = tempRet0;
    ___clang_call_terminate($68);
    // unreachable;
   }
  }
 }
 HEAP32[$11>>2] = 0;
 $51 = HEAP32[$5>>2]|0;
 $52 = ($51|0)==(0|0);
 if (!($52)) {
  $53 = ((($51)) + 8|0);
  $54 = HEAP32[$53>>2]|0;HEAP32[$53>>2] = (($54-1)|0);
  $55 = ($54|0)==(1);
  if ($55) {
   __THREW__ = 0;
   invoke_viii(3262,($51|0),1,1);
   $56 = __THREW__; __THREW__ = 0;
   $57 = $56&1;
   if ($57) {
    $68 = ___cxa_find_matching_catch_3(0|0)|0;
    $69 = tempRet0;
    ___clang_call_terminate($68);
    // unreachable;
   }
  }
 }
 HEAP32[$5>>2] = 0;
 $58 = HEAP32[$3>>2]|0;
 $59 = ($58|0)==(0|0);
 if ($59) {
  ___resumeException($$010|0);
  // unreachable;
 }
 $60 = ((($0)) + 12|0);
 $61 = HEAP32[$60>>2]|0;
 $62 = ($61|0)==($58|0);
 if (!($62)) {
  $scevgep$i$i$i = ((($61)) + -4|0);
  $63 = $scevgep$i$i$i;
  $64 = $58;
  $65 = (($63) - ($64))|0;
  $66 = $65 >>> 2;
  $67 = $66 ^ -1;
  $scevgep5$i$i$i = (($61) + ($67<<2)|0);
  HEAP32[$60>>2] = $scevgep5$i$i$i;
 }
 __ZdlPv($58);
 ___resumeException($$010|0);
 // unreachable;
}
function __ZN7osgUtil14RayIntersector12IntersectionD2Ev($0) {
 $0 = $0|0;
 var $$2 = 0, $$24 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i21 = 0, $scevgep$i$i$i5 = 0, $scevgep$i$i$i9 = 0;
 var $scevgep5$i$i$i = 0, $scevgep5$i$i$i10 = 0, $scevgep5$i$i$i22 = 0, $scevgep5$i$i$i6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = ((($0)) + 84|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==($2|0);
  if (!($6)) {
   $scevgep$i$i$i = ((($5)) + -8|0);
   $7 = $scevgep$i$i$i;
   $8 = $2;
   $9 = (($7) - ($8))|0;
   $10 = $9 >>> 3;
   $11 = $10 ^ -1;
   $scevgep5$i$i$i = (($5) + ($11<<3)|0);
   HEAP32[$4>>2] = $scevgep5$i$i$i;
  }
  __ZdlPv($2);
 }
 $12 = ((($0)) + 68|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0|0);
 if (!($14)) {
  $15 = ((($0)) + 72|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($16|0)==($13|0);
  if (!($17)) {
   $scevgep$i$i$i5 = ((($16)) + -4|0);
   $18 = $scevgep$i$i$i5;
   $19 = $13;
   $20 = (($18) - ($19))|0;
   $21 = $20 >>> 2;
   $22 = $21 ^ -1;
   $scevgep5$i$i$i6 = (($16) + ($22<<2)|0);
   HEAP32[$15>>2] = $scevgep5$i$i$i6;
  }
  __ZdlPv($13);
 }
 $23 = ((($0)) + 24|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)==(0|0);
 if ($25) {
  label = 12;
 } else {
  $26 = ((($24)) + 8|0);
  $27 = HEAP32[$26>>2]|0;HEAP32[$26>>2] = (($27-1)|0);
  $28 = ($27|0)==(1);
  if ($28) {
   __THREW__ = 0;
   invoke_viii(3262,($24|0),1,1);
   $29 = __THREW__; __THREW__ = 0;
   $30 = $29&1;
   if ($30) {
    $52 = ___cxa_find_matching_catch_2()|0;
    $53 = tempRet0;
    $54 = ((($0)) + 20|0);
    $55 = HEAP32[$54>>2]|0;
    $56 = ($55|0)==(0|0);
    if (!($56)) {
     $57 = ((($55)) + 8|0);
     $58 = HEAP32[$57>>2]|0;HEAP32[$57>>2] = (($58-1)|0);
     $59 = ($58|0)==(1);
     if ($59) {
      __THREW__ = 0;
      invoke_viii(3262,($55|0),1,1);
      $60 = __THREW__; __THREW__ = 0;
      $61 = $60&1;
      if ($61) {
       $73 = ___cxa_find_matching_catch_3(0|0)|0;
       $74 = tempRet0;
       ___clang_call_terminate($73);
       // unreachable;
      }
     }
    }
    HEAP32[$54>>2] = 0;
    $$2 = $53;$$24 = $52;
   } else {
    label = 12;
   }
  } else {
   label = 12;
  }
 }
 do {
  if ((label|0) == 12) {
   HEAP32[$23>>2] = 0;
   $31 = ((($0)) + 20|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ($32|0)==(0|0);
   if (!($33)) {
    $34 = ((($32)) + 8|0);
    $35 = HEAP32[$34>>2]|0;HEAP32[$34>>2] = (($35-1)|0);
    $36 = ($35|0)==(1);
    if ($36) {
     __THREW__ = 0;
     invoke_viii(3262,($32|0),1,1);
     $37 = __THREW__; __THREW__ = 0;
     $38 = $37&1;
     if ($38) {
      $50 = ___cxa_find_matching_catch_2()|0;
      $51 = tempRet0;
      $$2 = $51;$$24 = $50;
      break;
     }
    }
   }
   HEAP32[$31>>2] = 0;
   $39 = ((($0)) + 8|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = ($40|0)==(0|0);
   if ($41) {
    return;
   }
   $42 = ((($0)) + 12|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = ($43|0)==($40|0);
   if (!($44)) {
    $scevgep$i$i$i9 = ((($43)) + -4|0);
    $45 = $scevgep$i$i$i9;
    $46 = $40;
    $47 = (($45) - ($46))|0;
    $48 = $47 >>> 2;
    $49 = $48 ^ -1;
    $scevgep5$i$i$i10 = (($43) + ($49<<2)|0);
    HEAP32[$42>>2] = $scevgep5$i$i$i10;
   }
   __ZdlPv($40);
   return;
  }
 } while(0);
 $62 = ((($0)) + 8|0);
 $63 = HEAP32[$62>>2]|0;
 $64 = ($63|0)==(0|0);
 if ($64) {
  ___resumeException($$24|0);
  // unreachable;
 }
 $65 = ((($0)) + 12|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = ($66|0)==($63|0);
 if (!($67)) {
  $scevgep$i$i$i21 = ((($66)) + -4|0);
  $68 = $scevgep$i$i$i21;
  $69 = $63;
  $70 = (($68) - ($69))|0;
  $71 = $70 >>> 2;
  $72 = $71 ^ -1;
  $scevgep5$i$i$i22 = (($66) + ($72<<2)|0);
  HEAP32[$65>>2] = $scevgep5$i$i$i22;
 }
 __ZdlPv($63);
 ___resumeException($$24|0);
 // unreachable;
}
function __ZNSt3__26vectorIN3osg7ref_ptrIN5osgGA11PointerDataEEENS_9allocatorIS5_EEE21__push_back_slow_pathIKS5_EEvRT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$06$i$i = 0, $$pre = 0, $$pre$i = 0, $$pre38 = 0, $$pre39 = 0, $$sroa$7$0 = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(1073741823);
 $9 = $4;
 $10 = $3;
 if ($8) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $11 = ((($0)) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) - ($4))|0;
 $14 = $13 >> 2;
 $15 = ($14>>>0)<(536870911);
 $16 = $13 >> 1;
 $17 = ($16>>>0)<($7>>>0);
 $$sroa$speculated$i = $17 ? $7 : $16;
 $$sroa$speculated$$i = $15 ? $$sroa$speculated$i : 1073741823;
 $18 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($18) {
   $28 = 0;
  } else {
   $19 = ($$sroa$speculated$$i>>>0)>(1073741823);
   if (!($19)) {
    $25 = $$sroa$speculated$$i << 2;
    $26 = (__Znwj($25)|0);
    $28 = $26;
    break;
   }
   $20 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($20|0),(204840|0));
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if ($22) {
    $23 = ___cxa_find_matching_catch_2()|0;
    $24 = tempRet0;
    ___cxa_free_exception(($20|0));
    ___resumeException($23|0);
    // unreachable;
   } else {
    HEAP32[$20>>2] = (99824);
    ___cxa_throw(($20|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $27 = (($28) + ($6<<2)|0);
 $29 = $27;
 $30 = (($28) + ($$sroa$speculated$$i<<2)|0);
 $31 = $30;
 $32 = HEAP32[$1>>2]|0;
 HEAP32[$27>>2] = $32;
 $33 = ($32|0)==(0|0);
 if ($33) {
  $38 = $10;$40 = $9;
 } else {
  $34 = ((($32)) + 8|0);
  $35 = HEAP32[$34>>2]|0;HEAP32[$34>>2] = (($35+1)|0);
  $$pre = HEAP32[$0>>2]|0;
  $$pre38 = HEAP32[$2>>2]|0;
  $38 = $$pre38;$40 = $$pre;
 }
 $36 = ((($27)) + 4|0);
 $37 = $36;
 $39 = ($38|0)==($40|0);
 if ($39) {
  $41 = $38;
  $53 = $29;$54 = $41;$56 = $38;
 } else {
  $$06$i$i = $38;$$sroa$7$0 = $29;$44 = $27;
  while(1) {
   $42 = ((($$06$i$i)) + -4|0);
   $43 = ((($44)) + -4|0);
   $45 = HEAP32[$42>>2]|0;
   HEAP32[$43>>2] = $45;
   $46 = ($45|0)==(0|0);
   if (!($46)) {
    $47 = ((($45)) + 8|0);
    $48 = HEAP32[$47>>2]|0;HEAP32[$47>>2] = (($48+1)|0);
   }
   $49 = $$sroa$7$0;
   $50 = ((($49)) + -4|0);
   $51 = $50;
   $52 = ($42|0)==($40|0);
   if ($52) {
    break;
   } else {
    $$06$i$i = $42;$$sroa$7$0 = $51;$44 = $50;
   }
  }
  $$pre$i = HEAP32[$0>>2]|0;
  $$pre39 = HEAP32[$2>>2]|0;
  $53 = $51;$54 = $$pre$i;$56 = $$pre39;
 }
 HEAP32[$0>>2] = $53;
 HEAP32[$2>>2] = $37;
 HEAP32[$11>>2] = $31;
 $55 = $54;
 $57 = ($56|0)==($55|0);
 L25: do {
  if (!($57)) {
   $59 = $56;
   while(1) {
    $58 = ((($59)) + -4|0);
    $60 = HEAP32[$58>>2]|0;
    $61 = ($60|0)==(0|0);
    if (!($61)) {
     $62 = ((($60)) + 8|0);
     $63 = HEAP32[$62>>2]|0;HEAP32[$62>>2] = (($63-1)|0);
     $64 = ($63|0)==(1);
     if ($64) {
      __THREW__ = 0;
      invoke_viii(3262,($60|0),1,1);
      $65 = __THREW__; __THREW__ = 0;
      $66 = $65&1;
      if ($66) {
       break;
      }
     }
    }
    HEAP32[$58>>2] = 0;
    $67 = ($58|0)==($55|0);
    if ($67) {
     break L25;
    } else {
     $59 = $58;
    }
   }
   $68 = ___cxa_find_matching_catch_2()|0;
   $69 = tempRet0;
   ___cxa_call_unexpected(($68|0));
   // unreachable;
  }
 } while(0);
 $70 = ($54|0)==(0);
 if ($70) {
  return;
 }
 $71 = $54;
 __ZdlPv($71);
 return;
}
function __ZN5osgGA11PointerDataD2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (37072);
 $1 = ((($0)) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  HEAP32[$1>>2] = 0;
  __ZN3osg10ReferencedD2Ev($0);
  return;
 }
 $4 = ((($2)) + 8|0);
 $5 = HEAP32[$4>>2]|0;HEAP32[$4>>2] = (($5-1)|0);
 $6 = ($5|0)==(1);
 if (!($6)) {
  HEAP32[$1>>2] = 0;
  __ZN3osg10ReferencedD2Ev($0);
  return;
 }
 __THREW__ = 0;
 invoke_viii(3262,($2|0),1,1);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if (!($8)) {
  HEAP32[$1>>2] = 0;
  __ZN3osg10ReferencedD2Ev($0);
  return;
 }
 $9 = ___cxa_find_matching_catch_2()|0;
 $10 = tempRet0;
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if ($12) {
  $13 = ___cxa_find_matching_catch_3(0|0)|0;
  $14 = tempRet0;
  ___clang_call_terminate($13);
  // unreachable;
 } else {
  ___resumeException($9|0);
  // unreachable;
 }
}
function __ZN5osgGA11PointerDataD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (37072);
 $1 = ((($0)) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = ((($2)) + 8|0);
  $5 = HEAP32[$4>>2]|0;HEAP32[$4>>2] = (($5-1)|0);
  $6 = ($5|0)==(1);
  if ($6) {
   __THREW__ = 0;
   invoke_viii(3262,($2|0),1,1);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch_2()|0;
    $12 = tempRet0;
    __THREW__ = 0;
    invoke_vi(712,($0|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     $15 = ___cxa_find_matching_catch_3(0|0)|0;
     $16 = tempRet0;
     ___clang_call_terminate($15);
     // unreachable;
    } else {
     $eh$lpad$body$index2Z2D = $12;$eh$lpad$body$indexZ2D = $11;
     __ZdlPv($0);
     ___resumeException($eh$lpad$body$indexZ2D|0);
     // unreachable;
    }
   }
  }
 }
 HEAP32[$1>>2] = 0;
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if (!($10)) {
  __ZdlPv($0);
  return;
 }
 $17 = ___cxa_find_matching_catch_2()|0;
 $18 = tempRet0;
 $eh$lpad$body$index2Z2D = $18;$eh$lpad$body$indexZ2D = $17;
 __ZdlPv($0);
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
}
function __ZNSt3__26__sortIRN3osg23CameraRenderOrderSortOpEPPNS1_6CameraEEEvT0_S7_T_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$$0174 = 0, $$0 = 0, $$0$i$i = 0, $$0$i$i188 = 0, $$0$i31$i = 0, $$0$i31$i190 = 0, $$0$ph = 0, $$0160266 = 0, $$0167 = 0, $$0174 = 0, $$0180$ph = 0, $$1 = 0, $$1155 = 0, $$1161 = 0, $$2156 = 0, $$2162 = 0, $$2176 = 0, $$3157 = 0, $$3163$lcssa = 0, $$3163268 = 0;
 var $$3170 = 0, $$4158 = 0, $$4164 = 0, $$4171 = 0, $$5165 = 0, $$5172 = 0, $$6166 = 0, $$6173 = 0, $$lcssa256 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0;
 var $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0;
 var $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0;
 var $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0;
 var $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0;
 var $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0;
 var $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0;
 var $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0;
 var $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$0$ph = $0;$$0180$ph = $1;
 L1: while(1) {
  $3 = $$0180$ph;
  $4 = ((($$0180$ph)) + -4|0);
  $5 = ((($$0180$ph)) + -8|0);
  $$0 = $$0$ph;
  while(1) {
   $$1 = $$0;
   L5: while(1) {
    $6 = $$1;
    $7 = (($3) - ($6))|0;
    $8 = $7 >> 2;
    switch ($8|0) {
    case 2:  {
     label = 5;
     break L1;
     break;
    }
    case 3:  {
     label = 9;
     break L1;
     break;
    }
    case 4:  {
     label = 27;
     break L1;
     break;
    }
    case 5:  {
     label = 28;
     break L1;
     break;
    }
    case 1: case 0:  {
     label = 107;
     break L1;
     break;
    }
    default: {
    }
    }
    $82 = ($7|0)<(124);
    if ($82) {
     label = 30;
     break L1;
    }
    $83 = ($7|0)>(3996);
    $84 = (($8|0) / 2)&-1;
    $85 = (($$1) + ($84<<2)|0);
    do {
     if ($83) {
      $86 = (($8|0) / 4)&-1;
      $87 = (($$1) + ($86<<2)|0);
      $88 = (($85) + ($86<<2)|0);
      $89 = (__ZNSt3__27__sort5IRN3osg23CameraRenderOrderSortOpEPPNS1_6CameraEEEjT0_S7_S7_S7_S7_T_($$1,$87,$85,$88,$4,$2)|0);
      $$0167 = $89;
     } else {
      $90 = HEAP32[$85>>2]|0;
      $91 = HEAP32[$$1>>2]|0;
      $92 = ((($90)) + 560|0);
      $93 = HEAP32[$92>>2]|0;
      $94 = ((($91)) + 560|0);
      $95 = HEAP32[$94>>2]|0;
      $96 = ($93|0)<($95|0);
      $97 = $90;
      $98 = $91;
      if ($96) {
       $$0$i$i188 = 1;
      } else {
       $99 = ($95|0)<($93|0);
       if ($99) {
        $$0$i$i188 = 0;
       } else {
        $100 = ((($90)) + 564|0);
        $101 = HEAP32[$100>>2]|0;
        $102 = ((($91)) + 564|0);
        $103 = HEAP32[$102>>2]|0;
        $104 = ($101|0)<($103|0);
        $$0$i$i188 = $104;
       }
      }
      $105 = HEAP32[$4>>2]|0;
      $106 = ((($105)) + 560|0);
      $107 = HEAP32[$106>>2]|0;
      $108 = ($107|0)<($93|0);
      $109 = $105;
      if ($108) {
       $$0$i31$i190 = 1;
      } else {
       $110 = ($93|0)<($107|0);
       if ($110) {
        $$0$i31$i190 = 0;
       } else {
        $111 = ((($105)) + 564|0);
        $112 = HEAP32[$111>>2]|0;
        $113 = ((($90)) + 564|0);
        $114 = HEAP32[$113>>2]|0;
        $115 = ($112|0)<($114|0);
        $$0$i31$i190 = $115;
       }
      }
      if (!($$0$i$i188)) {
       if (!($$0$i31$i190)) {
        $$0167 = 0;
        break;
       }
       HEAP32[$85>>2] = $109;
       HEAP32[$4>>2] = $97;
       $116 = HEAP32[$85>>2]|0;
       $117 = HEAP32[$$1>>2]|0;
       $118 = ((($116)) + 560|0);
       $119 = HEAP32[$118>>2]|0;
       $120 = ((($117)) + 560|0);
       $121 = HEAP32[$120>>2]|0;
       $122 = ($119|0)<($121|0);
       $123 = $117;
       $124 = $116;
       if (!($122)) {
        $125 = ($121|0)<($119|0);
        if ($125) {
         $$0167 = 1;
         break;
        }
        $126 = ((($116)) + 564|0);
        $127 = HEAP32[$126>>2]|0;
        $128 = ((($117)) + 564|0);
        $129 = HEAP32[$128>>2]|0;
        $130 = ($127|0)<($129|0);
        if (!($130)) {
         $$0167 = 1;
         break;
        }
       }
       HEAP32[$$1>>2] = $124;
       HEAP32[$85>>2] = $123;
       $$0167 = 2;
       break;
      }
      if ($$0$i31$i190) {
       HEAP32[$$1>>2] = $109;
       HEAP32[$4>>2] = $98;
       $$0167 = 1;
       break;
      }
      HEAP32[$$1>>2] = $97;
      HEAP32[$85>>2] = $98;
      $131 = HEAP32[$4>>2]|0;
      $132 = ((($131)) + 560|0);
      $133 = HEAP32[$132>>2]|0;
      $134 = ($133|0)<($95|0);
      $135 = $131;
      if (!($134)) {
       $136 = ($95|0)<($133|0);
       if ($136) {
        $$0167 = 1;
        break;
       }
       $137 = ((($131)) + 564|0);
       $138 = HEAP32[$137>>2]|0;
       $139 = ((($91)) + 564|0);
       $140 = HEAP32[$139>>2]|0;
       $141 = ($138|0)<($140|0);
       if (!($141)) {
        $$0167 = 1;
        break;
       }
      }
      HEAP32[$85>>2] = $135;
      HEAP32[$4>>2] = $98;
      $$0167 = 2;
     }
    } while(0);
    $142 = HEAP32[$$1>>2]|0;
    $143 = HEAP32[$85>>2]|0;
    $144 = ((($142)) + 560|0);
    $145 = HEAP32[$144>>2]|0;
    $146 = ((($143)) + 560|0);
    $147 = HEAP32[$146>>2]|0;
    $148 = ($145|0)<($147|0);
    if ($148) {
     $$3157 = $4;$$3170 = $$0167;
     break;
    }
    $149 = ($147|0)<($145|0);
    if (!($149)) {
     $150 = ((($142)) + 564|0);
     $151 = HEAP32[$150>>2]|0;
     $152 = ((($143)) + 564|0);
     $153 = HEAP32[$152>>2]|0;
     $154 = ($151|0)<($153|0);
     if ($154) {
      $$3157 = $4;$$3170 = $$0167;
      break;
     }
    }
    $155 = ($$1|0)==($5|0);
    if (!($155)) {
     $156 = ((($143)) + 564|0);
     $221 = $5;
     while(1) {
      $220 = HEAP32[$221>>2]|0;
      $222 = ((($220)) + 560|0);
      $223 = HEAP32[$222>>2]|0;
      $224 = ($223|0)<($147|0);
      if ($224) {
       label = 82;
       break L5;
      }
      $225 = ($147|0)<($223|0);
      if (!($225)) {
       $226 = ((($220)) + 564|0);
       $227 = HEAP32[$226>>2]|0;
       $228 = HEAP32[$156>>2]|0;
       $229 = ($227|0)<($228|0);
       if ($229) {
        label = 82;
        break L5;
       }
      }
      $230 = ((($221)) + -4|0);
      $231 = ($$1|0)==($230|0);
      if ($231) {
       break;
      } else {
       $221 = $230;
      }
     }
    }
    $157 = ((($$1)) + 4|0);
    $158 = HEAP32[$4>>2]|0;
    $159 = ((($158)) + 560|0);
    $160 = HEAP32[$159>>2]|0;
    $161 = ($145|0)<($160|0);
    $162 = $158;
    do {
     if ($161) {
      $$1161 = $157;
     } else {
      $163 = ($160|0)<($145|0);
      if (!($163)) {
       $164 = ((($142)) + 564|0);
       $165 = HEAP32[$164>>2]|0;
       $166 = ((($158)) + 564|0);
       $167 = HEAP32[$166>>2]|0;
       $168 = ($165|0)<($167|0);
       if ($168) {
        $$1161 = $157;
        break;
       }
      }
      $169 = ($157|0)==($4|0);
      if ($169) {
       label = 107;
       break L1;
      }
      $170 = ((($142)) + 564|0);
      $$0160266 = $157;
      while(1) {
       $171 = HEAP32[$$0160266>>2]|0;
       $172 = ((($171)) + 560|0);
       $173 = HEAP32[$172>>2]|0;
       $174 = ($145|0)<($173|0);
       if ($174) {
        break;
       }
       $175 = ($173|0)<($145|0);
       if (!($175)) {
        $176 = HEAP32[$170>>2]|0;
        $177 = ((($171)) + 564|0);
        $178 = HEAP32[$177>>2]|0;
        $179 = ($176|0)<($178|0);
        if ($179) {
         break;
        }
       }
       $182 = ((($$0160266)) + 4|0);
       $183 = ($182|0)==($4|0);
       if ($183) {
        label = 107;
        break L1;
       } else {
        $$0160266 = $182;
       }
      }
      $180 = $171;
      HEAP32[$$0160266>>2] = $162;
      HEAP32[$4>>2] = $180;
      $181 = ((($$0160266)) + 4|0);
      $$1161 = $181;
     }
    } while(0);
    $184 = ($$1161|0)==($4|0);
    if ($184) {
     label = 107;
     break L1;
    } else {
     $$1155 = $4;$$2162 = $$1161;
    }
    while(1) {
     $185 = HEAP32[$$1>>2]|0;
     $186 = HEAP32[$$2162>>2]|0;
     $187 = ((($185)) + 560|0);
     $188 = HEAP32[$187>>2]|0;
     $189 = ((($186)) + 560|0);
     $190 = HEAP32[$189>>2]|0;
     $191 = ($188|0)<($190|0);
     L65: do {
      if ($191) {
       $$3163$lcssa = $$2162;
      } else {
       $192 = ((($185)) + 564|0);
       $$3163268 = $$2162;$194 = $190;$198 = $186;
       while(1) {
        $195 = ($194|0)<($188|0);
        if (!($195)) {
         $196 = HEAP32[$192>>2]|0;
         $197 = ((($198)) + 564|0);
         $199 = HEAP32[$197>>2]|0;
         $200 = ($196|0)<($199|0);
         if ($200) {
          $$3163$lcssa = $$3163268;
          break L65;
         }
        }
        $201 = ((($$3163268)) + 4|0);
        $202 = HEAP32[$201>>2]|0;
        $203 = ((($202)) + 560|0);
        $204 = HEAP32[$203>>2]|0;
        $205 = ($188|0)<($204|0);
        if ($205) {
         $$3163$lcssa = $201;
         break;
        } else {
         $$3163268 = $201;$194 = $204;$198 = $202;
        }
       }
      }
     } while(0);
     $193 = ((($185)) + 564|0);
     $$2156 = $$1155;
     while(1) {
      $206 = ((($$2156)) + -4|0);
      $207 = HEAP32[$206>>2]|0;
      $208 = ((($207)) + 560|0);
      $209 = HEAP32[$208>>2]|0;
      $210 = ($188|0)<($209|0);
      if ($210) {
       $$2156 = $206;
       continue;
      }
      $211 = ($209|0)<($188|0);
      if ($211) {
       break;
      }
      $212 = HEAP32[$193>>2]|0;
      $213 = ((($207)) + 564|0);
      $214 = HEAP32[$213>>2]|0;
      $215 = ($212|0)<($214|0);
      if ($215) {
       $$2156 = $206;
      } else {
       break;
      }
     }
     $216 = ($$3163$lcssa>>>0)<($206>>>0);
     if (!($216)) {
      $$1 = $$3163$lcssa;
      continue L5;
     }
     $217 = $207;
     $218 = HEAP32[$$3163$lcssa>>2]|0;
     HEAP32[$$3163$lcssa>>2] = $217;
     HEAP32[$206>>2] = $218;
     $219 = ((($$3163$lcssa)) + 4|0);
     $$1155 = $206;$$2162 = $219;
    }
   }
   if ((label|0) == 82) {
    label = 0;
    $232 = $142;
    $233 = $220;
    HEAP32[$$1>>2] = $233;
    HEAP32[$221>>2] = $232;
    $234 = (($$0167) + 1)|0;
    $$3157 = $221;$$3170 = $234;
   }
   $235 = ((($$1)) + 4|0);
   $236 = ($235>>>0)<($$3157>>>0);
   L82: do {
    if ($236) {
     $$0174 = $85;$$4158 = $$3157;$$4164 = $235;$$4171 = $$3170;
     while(1) {
      $237 = HEAP32[$$0174>>2]|0;
      $238 = ((($237)) + 560|0);
      $239 = HEAP32[$238>>2]|0;
      $240 = ((($237)) + 564|0);
      $$5165 = $$4164;
      while(1) {
       $241 = HEAP32[$$5165>>2]|0;
       $242 = ((($241)) + 560|0);
       $243 = HEAP32[$242>>2]|0;
       $244 = ($243|0)<($239|0);
       if (!($244)) {
        $245 = ($239|0)<($243|0);
        if ($245) {
         break;
        }
        $252 = ((($241)) + 564|0);
        $253 = HEAP32[$252>>2]|0;
        $254 = HEAP32[$240>>2]|0;
        $255 = ($253|0)<($254|0);
        if (!($255)) {
         break;
        }
       }
       $256 = ((($$5165)) + 4|0);
       $$5165 = $256;
      }
      $246 = $241;
      $247 = ((($$4158)) + -4|0);
      $248 = HEAP32[$247>>2]|0;
      $249 = ((($248)) + 560|0);
      $250 = HEAP32[$249>>2]|0;
      $251 = ($250|0)<($239|0);
      L92: do {
       if ($251) {
        $$lcssa256 = $247;
       } else {
        $258 = $250;$260 = $248;$265 = $247;
        while(1) {
         $257 = ($239|0)<($258|0);
         if (!($257)) {
          $259 = ((($260)) + 564|0);
          $261 = HEAP32[$259>>2]|0;
          $262 = HEAP32[$240>>2]|0;
          $263 = ($261|0)<($262|0);
          if ($263) {
           $$lcssa256 = $265;
           break L92;
          }
         }
         $264 = ((($265)) + -4|0);
         $266 = HEAP32[$264>>2]|0;
         $267 = ((($266)) + 560|0);
         $268 = HEAP32[$267>>2]|0;
         $269 = ($268|0)<($239|0);
         if ($269) {
          $$lcssa256 = $264;
          break;
         } else {
          $258 = $268;$260 = $266;$265 = $264;
         }
        }
       }
      } while(0);
      $270 = ($$5165>>>0)>($$lcssa256>>>0);
      if ($270) {
       $$2176 = $$0174;$$5172 = $$4171;$$6166 = $$5165;
       break L82;
      }
      $271 = HEAP32[$$lcssa256>>2]|0;
      HEAP32[$$5165>>2] = $271;
      HEAP32[$$lcssa256>>2] = $246;
      $272 = (($$4171) + 1)|0;
      $273 = ($$0174|0)==($$5165|0);
      $$$0174 = $273 ? $$lcssa256 : $$0174;
      $274 = ((($$5165)) + 4|0);
      $$0174 = $$$0174;$$4158 = $$lcssa256;$$4164 = $274;$$4171 = $272;
     }
    } else {
     $$2176 = $85;$$5172 = $$3170;$$6166 = $235;
    }
   } while(0);
   $275 = ($$6166|0)==($$2176|0);
   do {
    if ($275) {
     $$6173 = $$5172;
    } else {
     $276 = HEAP32[$$2176>>2]|0;
     $277 = HEAP32[$$6166>>2]|0;
     $278 = ((($276)) + 560|0);
     $279 = HEAP32[$278>>2]|0;
     $280 = ((($277)) + 560|0);
     $281 = HEAP32[$280>>2]|0;
     $282 = ($279|0)<($281|0);
     $283 = $277;
     $284 = $276;
     if (!($282)) {
      $285 = ($281|0)<($279|0);
      if ($285) {
       $$6173 = $$5172;
       break;
      }
      $286 = ((($276)) + 564|0);
      $287 = HEAP32[$286>>2]|0;
      $288 = ((($277)) + 564|0);
      $289 = HEAP32[$288>>2]|0;
      $290 = ($287|0)<($289|0);
      if (!($290)) {
       $$6173 = $$5172;
       break;
      }
     }
     $291 = (($$5172) + 1)|0;
     HEAP32[$$6166>>2] = $284;
     HEAP32[$$2176>>2] = $283;
     $$6173 = $291;
    }
   } while(0);
   $292 = ($$6173|0)==(0);
   if ($292) {
    $293 = (__ZNSt3__227__insertion_sort_incompleteIRN3osg23CameraRenderOrderSortOpEPPNS1_6CameraEEEbT0_S7_T_($$1,$$6166,$2)|0);
    $294 = ((($$6166)) + 4|0);
    $295 = (__ZNSt3__227__insertion_sort_incompleteIRN3osg23CameraRenderOrderSortOpEPPNS1_6CameraEEEbT0_S7_T_($294,$$0180$ph,$2)|0);
    if ($295) {
     label = 106;
     break;
    }
    if ($293) {
     $$0 = $294;
     continue;
    }
   }
   $296 = $$6166;
   $297 = (($296) - ($6))|0;
   $298 = (($3) - ($296))|0;
   $299 = ($297|0)<($298|0);
   if (!($299)) {
    label = 105;
    break;
   }
   __ZNSt3__26__sortIRN3osg23CameraRenderOrderSortOpEPPNS1_6CameraEEEvT0_S7_T_($$1,$$6166,$2);
   $300 = ((($$6166)) + 4|0);
   $$0 = $300;
  }
  if ((label|0) == 105) {
   label = 0;
   $301 = ((($$6166)) + 4|0);
   __ZNSt3__26__sortIRN3osg23CameraRenderOrderSortOpEPPNS1_6CameraEEEvT0_S7_T_($301,$$0180$ph,$2);
   $$0$ph = $$1;$$0180$ph = $$6166;
   continue;
  }
  else if ((label|0) == 106) {
   label = 0;
   if ($293) {
    label = 107;
    break;
   } else {
    $$0$ph = $$1;$$0180$ph = $$6166;
    continue;
   }
  }
 }
 if ((label|0) == 5) {
  $9 = HEAP32[$4>>2]|0;
  $10 = HEAP32[$$1>>2]|0;
  $11 = ((($9)) + 560|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ((($10)) + 560|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = ($12|0)<($14|0);
  $16 = $10;
  $17 = $9;
  if (!($15)) {
   $18 = ($14|0)<($12|0);
   if ($18) {
    return;
   }
   $19 = ((($9)) + 564|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = ((($10)) + 564|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = ($20|0)<($22|0);
   if (!($23)) {
    return;
   }
  }
  HEAP32[$$1>>2] = $17;
  HEAP32[$4>>2] = $16;
  return;
 }
 else if ((label|0) == 9) {
  $24 = ((($$1)) + 4|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = HEAP32[$$1>>2]|0;
  $27 = ((($25)) + 560|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = ((($26)) + 560|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = ($28|0)<($30|0);
  $32 = $25;
  $33 = $26;
  if ($31) {
   $$0$i$i = 1;
  } else {
   $34 = ($30|0)<($28|0);
   if ($34) {
    $$0$i$i = 0;
   } else {
    $35 = ((($25)) + 564|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = ((($26)) + 564|0);
    $38 = HEAP32[$37>>2]|0;
    $39 = ($36|0)<($38|0);
    $$0$i$i = $39;
   }
  }
  $40 = HEAP32[$4>>2]|0;
  $41 = ((($40)) + 560|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = ($42|0)<($28|0);
  $44 = $40;
  if ($43) {
   $$0$i31$i = 1;
  } else {
   $45 = ($28|0)<($42|0);
   if ($45) {
    $$0$i31$i = 0;
   } else {
    $46 = ((($40)) + 564|0);
    $47 = HEAP32[$46>>2]|0;
    $48 = ((($25)) + 564|0);
    $49 = HEAP32[$48>>2]|0;
    $50 = ($47|0)<($49|0);
    $$0$i31$i = $50;
   }
  }
  if (!($$0$i$i)) {
   if (!($$0$i31$i)) {
    return;
   }
   HEAP32[$24>>2] = $44;
   HEAP32[$4>>2] = $32;
   $51 = HEAP32[$24>>2]|0;
   $52 = HEAP32[$$1>>2]|0;
   $53 = ((($51)) + 560|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = ((($52)) + 560|0);
   $56 = HEAP32[$55>>2]|0;
   $57 = ($54|0)<($56|0);
   $58 = $52;
   $59 = $51;
   if (!($57)) {
    $60 = ($56|0)<($54|0);
    if ($60) {
     return;
    }
    $61 = ((($51)) + 564|0);
    $62 = HEAP32[$61>>2]|0;
    $63 = ((($52)) + 564|0);
    $64 = HEAP32[$63>>2]|0;
    $65 = ($62|0)<($64|0);
    if (!($65)) {
     return;
    }
   }
   HEAP32[$$1>>2] = $59;
   HEAP32[$24>>2] = $58;
   return;
  }
  if ($$0$i31$i) {
   HEAP32[$$1>>2] = $44;
   HEAP32[$4>>2] = $33;
   return;
  }
  HEAP32[$$1>>2] = $32;
  HEAP32[$24>>2] = $33;
  $66 = HEAP32[$4>>2]|0;
  $67 = ((($66)) + 560|0);
  $68 = HEAP32[$67>>2]|0;
  $69 = ($68|0)<($30|0);
  $70 = $66;
  if (!($69)) {
   $71 = ($30|0)<($68|0);
   if ($71) {
    return;
   }
   $72 = ((($66)) + 564|0);
   $73 = HEAP32[$72>>2]|0;
   $74 = ((($26)) + 564|0);
   $75 = HEAP32[$74>>2]|0;
   $76 = ($73|0)<($75|0);
   if (!($76)) {
    return;
   }
  }
  HEAP32[$24>>2] = $70;
  HEAP32[$4>>2] = $33;
  return;
 }
 else if ((label|0) == 27) {
  $77 = ((($$1)) + 4|0);
  $78 = ((($$1)) + 8|0);
  (__ZNSt3__27__sort4IRN3osg23CameraRenderOrderSortOpEPPNS1_6CameraEEEjT0_S7_S7_S7_T_($$1,$77,$78,$4,$2)|0);
  return;
 }
 else if ((label|0) == 28) {
  $79 = ((($$1)) + 4|0);
  $80 = ((($$1)) + 8|0);
  $81 = ((($$1)) + 12|0);
  (__ZNSt3__27__sort5IRN3osg23CameraRenderOrderSortOpEPPNS1_6CameraEEEjT0_S7_S7_S7_S7_T_($$1,$79,$80,$81,$4,$2)|0);
  return;
 }
 else if ((label|0) == 30) {
  __ZNSt3__218__insertion_sort_3IRN3osg23CameraRenderOrderSortOpEPPNS1_6CameraEEEvT0_S7_T_($$1,$$0180$ph,$2);
  return;
 }
 else if ((label|0) == 107) {
  return;
 }
}
function __ZNSt3__27__sort4IRN3osg23CameraRenderOrderSortOpEPPNS1_6CameraEEEjT0_S7_S7_S7_T_($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0 = 0, $$0$i$i = 0, $$0$i31$i = 0, $$026$i = 0, $$pre = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = HEAP32[$1>>2]|0;
 $6 = HEAP32[$0>>2]|0;
 $7 = ((($5)) + 560|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($6)) + 560|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8|0)<($10|0);
 $12 = $5;
 $13 = $6;
 if ($11) {
  $$0$i$i = 1;
 } else {
  $14 = ($10|0)<($8|0);
  if ($14) {
   $$0$i$i = 0;
  } else {
   $15 = ((($5)) + 564|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ((($6)) + 564|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = ($16|0)<($18|0);
   $$0$i$i = $19;
  }
 }
 $20 = HEAP32[$2>>2]|0;
 $21 = ((($20)) + 560|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)<($8|0);
 $24 = $20;
 if ($23) {
  $$0$i31$i = 1;
 } else {
  $25 = ($8|0)<($22|0);
  if ($25) {
   $$0$i31$i = 0;
  } else {
   $26 = ((($20)) + 564|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = ((($5)) + 564|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = ($27|0)<($29|0);
   $$0$i31$i = $30;
  }
 }
 do {
  if ($$0$i$i) {
   if ($$0$i31$i) {
    HEAP32[$0>>2] = $24;
    HEAP32[$2>>2] = $13;
    $$026$i = 1;$62 = $6;$72 = $13;
    break;
   }
   HEAP32[$0>>2] = $12;
   HEAP32[$1>>2] = $13;
   $47 = HEAP32[$2>>2]|0;
   $48 = ((($47)) + 560|0);
   $49 = HEAP32[$48>>2]|0;
   $50 = ($49|0)<($10|0);
   $51 = $47;
   if (!($50)) {
    $52 = ($10|0)<($49|0);
    if ($52) {
     $$026$i = 1;$62 = $47;$72 = $51;
     break;
    }
    $53 = ((($47)) + 564|0);
    $54 = HEAP32[$53>>2]|0;
    $55 = ((($6)) + 564|0);
    $56 = HEAP32[$55>>2]|0;
    $57 = ($54|0)<($56|0);
    if (!($57)) {
     $$026$i = 1;$62 = $47;$72 = $51;
     break;
    }
   }
   HEAP32[$1>>2] = $51;
   HEAP32[$2>>2] = $13;
   $$026$i = 2;$62 = $6;$72 = $13;
  } else {
   if ($$0$i31$i) {
    HEAP32[$1>>2] = $24;
    HEAP32[$2>>2] = $12;
    $31 = HEAP32[$1>>2]|0;
    $32 = HEAP32[$0>>2]|0;
    $33 = ((($31)) + 560|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = ((($32)) + 560|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = ($34|0)<($36|0);
    $38 = $32;
    $39 = $31;
    if (!($37)) {
     $40 = ($36|0)<($34|0);
     if ($40) {
      $$026$i = 1;$62 = $5;$72 = $12;
      break;
     }
     $41 = ((($31)) + 564|0);
     $42 = HEAP32[$41>>2]|0;
     $43 = ((($32)) + 564|0);
     $44 = HEAP32[$43>>2]|0;
     $45 = ($42|0)<($44|0);
     if (!($45)) {
      $$026$i = 1;$62 = $5;$72 = $12;
      break;
     }
    }
    HEAP32[$0>>2] = $39;
    HEAP32[$1>>2] = $38;
    $$pre = HEAP32[$2>>2]|0;
    $46 = $$pre;
    $$026$i = 2;$62 = $$pre;$72 = $46;
   } else {
    $$026$i = 0;$62 = $20;$72 = $24;
   }
  }
 } while(0);
 $58 = HEAP32[$3>>2]|0;
 $59 = ((($58)) + 560|0);
 $60 = HEAP32[$59>>2]|0;
 $61 = ((($62)) + 560|0);
 $63 = HEAP32[$61>>2]|0;
 $64 = ($60|0)<($63|0);
 $65 = $58;
 if (!($64)) {
  $66 = ($63|0)<($60|0);
  if ($66) {
   $$0 = $$026$i;
   return ($$0|0);
  }
  $67 = ((($58)) + 564|0);
  $68 = HEAP32[$67>>2]|0;
  $69 = ((($62)) + 564|0);
  $70 = HEAP32[$69>>2]|0;
  $71 = ($68|0)<($70|0);
  if (!($71)) {
   $$0 = $$026$i;
   return ($$0|0);
  }
 }
 HEAP32[$2>>2] = $65;
 HEAP32[$3>>2] = $72;
 $73 = (($$026$i) + 1)|0;
 $74 = HEAP32[$2>>2]|0;
 $75 = HEAP32[$1>>2]|0;
 $76 = ((($74)) + 560|0);
 $77 = HEAP32[$76>>2]|0;
 $78 = ((($75)) + 560|0);
 $79 = HEAP32[$78>>2]|0;
 $80 = ($77|0)<($79|0);
 $81 = $75;
 $82 = $74;
 if (!($80)) {
  $83 = ($79|0)<($77|0);
  if ($83) {
   $$0 = $73;
   return ($$0|0);
  }
  $84 = ((($74)) + 564|0);
  $85 = HEAP32[$84>>2]|0;
  $86 = ((($75)) + 564|0);
  $87 = HEAP32[$86>>2]|0;
  $88 = ($85|0)<($87|0);
  if (!($88)) {
   $$0 = $73;
   return ($$0|0);
  }
 }
 HEAP32[$1>>2] = $82;
 HEAP32[$2>>2] = $81;
 $89 = (($$026$i) + 2)|0;
 $90 = HEAP32[$1>>2]|0;
 $91 = HEAP32[$0>>2]|0;
 $92 = ((($90)) + 560|0);
 $93 = HEAP32[$92>>2]|0;
 $94 = ((($91)) + 560|0);
 $95 = HEAP32[$94>>2]|0;
 $96 = ($93|0)<($95|0);
 $97 = $91;
 $98 = $90;
 if (!($96)) {
  $99 = ($95|0)<($93|0);
  if ($99) {
   $$0 = $89;
   return ($$0|0);
  }
  $100 = ((($90)) + 564|0);
  $101 = HEAP32[$100>>2]|0;
  $102 = ((($91)) + 564|0);
  $103 = HEAP32[$102>>2]|0;
  $104 = ($101|0)<($103|0);
  if (!($104)) {
   $$0 = $89;
   return ($$0|0);
  }
 }
 $105 = (($$026$i) + 3)|0;
 HEAP32[$0>>2] = $98;
 HEAP32[$1>>2] = $97;
 $$0 = $105;
 return ($$0|0);
}
function __ZNSt3__27__sort5IRN3osg23CameraRenderOrderSortOpEPPNS1_6CameraEEEjT0_S7_S7_S7_S7_T_($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $6 = (__ZNSt3__27__sort4IRN3osg23CameraRenderOrderSortOpEPPNS1_6CameraEEEjT0_S7_S7_S7_T_($0,$1,$2,$3,$5)|0);
 $7 = HEAP32[$4>>2]|0;
 $8 = HEAP32[$3>>2]|0;
 $9 = ((($7)) + 560|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ((($8)) + 560|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($10|0)<($12|0);
 $14 = $8;
 $15 = $7;
 if (!($13)) {
  $16 = ($12|0)<($10|0);
  if ($16) {
   $$0 = $6;
   return ($$0|0);
  }
  $17 = ((($7)) + 564|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = ((($8)) + 564|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = ($18|0)<($20|0);
  if (!($21)) {
   $$0 = $6;
   return ($$0|0);
  }
 }
 HEAP32[$3>>2] = $15;
 HEAP32[$4>>2] = $14;
 $22 = (($6) + 1)|0;
 $23 = HEAP32[$3>>2]|0;
 $24 = HEAP32[$2>>2]|0;
 $25 = ((($23)) + 560|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ((($24)) + 560|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = ($26|0)<($28|0);
 $30 = $24;
 $31 = $23;
 if (!($29)) {
  $32 = ($28|0)<($26|0);
  if ($32) {
   $$0 = $22;
   return ($$0|0);
  }
  $33 = ((($23)) + 564|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = ((($24)) + 564|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = ($34|0)<($36|0);
  if (!($37)) {
   $$0 = $22;
   return ($$0|0);
  }
 }
 HEAP32[$2>>2] = $31;
 HEAP32[$3>>2] = $30;
 $38 = (($6) + 2)|0;
 $39 = HEAP32[$2>>2]|0;
 $40 = HEAP32[$1>>2]|0;
 $41 = ((($39)) + 560|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ((($40)) + 560|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = ($42|0)<($44|0);
 $46 = $40;
 $47 = $39;
 if (!($45)) {
  $48 = ($44|0)<($42|0);
  if ($48) {
   $$0 = $38;
   return ($$0|0);
  }
  $49 = ((($39)) + 564|0);
  $50 = HEAP32[$49>>2]|0;
  $51 = ((($40)) + 564|0);
  $52 = HEAP32[$51>>2]|0;
  $53 = ($50|0)<($52|0);
  if (!($53)) {
   $$0 = $38;
   return ($$0|0);
  }
 }
 HEAP32[$1>>2] = $47;
 HEAP32[$2>>2] = $46;
 $54 = (($6) + 3)|0;
 $55 = HEAP32[$1>>2]|0;
 $56 = HEAP32[$0>>2]|0;
 $57 = ((($55)) + 560|0);
 $58 = HEAP32[$57>>2]|0;
 $59 = ((($56)) + 560|0);
 $60 = HEAP32[$59>>2]|0;
 $61 = ($58|0)<($60|0);
 $62 = $56;
 $63 = $55;
 if (!($61)) {
  $64 = ($60|0)<($58|0);
  if ($64) {
   $$0 = $54;
   return ($$0|0);
  }
  $65 = ((($55)) + 564|0);
  $66 = HEAP32[$65>>2]|0;
  $67 = ((($56)) + 564|0);
  $68 = HEAP32[$67>>2]|0;
  $69 = ($66|0)<($68|0);
  if (!($69)) {
   $$0 = $54;
   return ($$0|0);
  }
 }
 $70 = (($6) + 4)|0;
 HEAP32[$0>>2] = $63;
 HEAP32[$1>>2] = $62;
 $$0 = $70;
 return ($$0|0);
}
function __ZNSt3__218__insertion_sort_3IRN3osg23CameraRenderOrderSortOpEPPNS1_6CameraEEEvT0_S7_T_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$i$i = 0, $$0$i31$i = 0, $$02940 = 0, $$03039 = 0, $$03039$phi = 0, $$lcssa = 0, $$pre = 0, $$pre$phiZ2D = 0, $$pre42 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 8|0);
 $4 = ((($0)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$0>>2]|0;
 $7 = ((($5)) + 560|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($6)) + 560|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8|0)<($10|0);
 $12 = $5;
 $13 = $6;
 if ($11) {
  $$0$i$i = 1;
 } else {
  $14 = ($10|0)<($8|0);
  if ($14) {
   $$0$i$i = 0;
  } else {
   $15 = ((($5)) + 564|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ((($6)) + 564|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = ($16|0)<($18|0);
   $$0$i$i = $19;
  }
 }
 $20 = HEAP32[$3>>2]|0;
 $21 = ((($20)) + 560|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)<($8|0);
 $24 = $20;
 if ($23) {
  $$0$i31$i = 1;
 } else {
  $25 = ($8|0)<($22|0);
  if ($25) {
   $$0$i31$i = 0;
  } else {
   $26 = ((($20)) + 564|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = ((($5)) + 564|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = ($27|0)<($29|0);
   $$0$i31$i = $30;
  }
 }
 do {
  if ($$0$i$i) {
   if ($$0$i31$i) {
    HEAP32[$0>>2] = $24;
    HEAP32[$3>>2] = $13;
    $80 = $13;$81 = $6;
    break;
   }
   HEAP32[$0>>2] = $12;
   HEAP32[$4>>2] = $13;
   $38 = ($22|0)<($10|0);
   if (!($38)) {
    $39 = ($10|0)<($22|0);
    if ($39) {
     $80 = $24;$81 = $20;
     break;
    }
    $40 = ((($20)) + 564|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = ((($6)) + 564|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = ($41|0)<($43|0);
    if (!($44)) {
     $80 = $24;$81 = $20;
     break;
    }
   }
   HEAP32[$4>>2] = $24;
   HEAP32[$3>>2] = $13;
   $80 = $13;$81 = $6;
  } else {
   if ($$0$i31$i) {
    HEAP32[$4>>2] = $24;
    HEAP32[$3>>2] = $12;
    $31 = ($22|0)<($10|0);
    if (!($31)) {
     $32 = ($10|0)<($22|0);
     if ($32) {
      $80 = $12;$81 = $5;
      break;
     }
     $33 = ((($20)) + 564|0);
     $34 = HEAP32[$33>>2]|0;
     $35 = ((($6)) + 564|0);
     $36 = HEAP32[$35>>2]|0;
     $37 = ($34|0)<($36|0);
     if (!($37)) {
      $80 = $12;$81 = $5;
      break;
     }
    }
    HEAP32[$0>>2] = $24;
    HEAP32[$4>>2] = $13;
    $80 = $12;$81 = $5;
   } else {
    $80 = $24;$81 = $20;
   }
  }
 } while(0);
 $45 = ((($0)) + 12|0);
 $46 = ($45|0)==($1|0);
 if ($46) {
  return;
 } else {
  $$02940 = $45;$$03039 = $3;$51 = $81;$61 = $80;
 }
 while(1) {
  $47 = HEAP32[$$02940>>2]|0;
  $48 = ((($47)) + 560|0);
  $49 = HEAP32[$48>>2]|0;
  $50 = ((($51)) + 560|0);
  $52 = HEAP32[$50>>2]|0;
  $53 = ($49|0)<($52|0);
  $54 = $47;
  if ($53) {
   $$pre42 = ((($47)) + 564|0);
   $$pre$phiZ2D = $$pre42;
   label = 25;
  } else {
   $55 = ($52|0)<($49|0);
   if (!($55)) {
    $56 = ((($47)) + 564|0);
    $57 = HEAP32[$56>>2]|0;
    $58 = ((($51)) + 564|0);
    $59 = HEAP32[$58>>2]|0;
    $60 = ($57|0)<($59|0);
    if ($60) {
     $$pre$phiZ2D = $56;
     label = 25;
    }
   }
  }
  if ((label|0) == 25) {
   label = 0;
   HEAP32[$$02940>>2] = $61;
   $62 = ($$03039|0)==($0|0);
   L35: do {
    if ($62) {
     $$lcssa = $$03039;
    } else {
     $64 = $$03039;$75 = $$03039;
     while(1) {
      $63 = ((($64)) + -4|0);
      $65 = HEAP32[$63>>2]|0;
      $66 = ((($65)) + 560|0);
      $67 = HEAP32[$66>>2]|0;
      $68 = ($49|0)<($67|0);
      $69 = $65;
      if (!($68)) {
       $70 = ($67|0)<($49|0);
       if ($70) {
        $$lcssa = $75;
        break L35;
       }
       $71 = HEAP32[$$pre$phiZ2D>>2]|0;
       $72 = ((($65)) + 564|0);
       $73 = HEAP32[$72>>2]|0;
       $74 = ($71|0)<($73|0);
       if (!($74)) {
        $$lcssa = $75;
        break L35;
       }
      }
      HEAP32[$75>>2] = $69;
      $76 = ($63|0)==($0|0);
      if ($76) {
       $$lcssa = $63;
       break;
      } else {
       $64 = $63;$75 = $63;
      }
     }
    }
   } while(0);
   HEAP32[$$lcssa>>2] = $54;
  }
  $77 = ((($$02940)) + 4|0);
  $78 = ($77|0)==($1|0);
  if ($78) {
   break;
  }
  $$pre = HEAP32[$$02940>>2]|0;
  $79 = $$pre;
  $$03039$phi = $$02940;$$02940 = $77;$51 = $$pre;$61 = $79;$$03039 = $$03039$phi;
 }
 return;
}
function __ZNSt3__227__insertion_sort_incompleteIRN3osg23CameraRenderOrderSortOpEPPNS1_6CameraEEEbT0_S7_T_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$$3 = 0, $$0$i$i = 0, $$0$i$i75 = 0, $$0$i31$i = 0, $$0$i31$i77 = 0, $$06295 = 0, $$06494 = 0, $$06992 = 0, $$06992$phi = 0, $$1 = 0, $$165 = 0, $$3 = 0, $$5 = 0, $$lcssa = 0, $$pre = 0, $$pre$phiZ2D = 0, $$pre101 = 0, $10 = 0, $100 = 0, $101 = 0;
 var $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0;
 var $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0;
 var $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0;
 var $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $3 = $1;
 $4 = $0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 switch ($6|0) {
 case 2:  {
  $7 = ((($1)) + -4|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = HEAP32[$0>>2]|0;
  $10 = ((($8)) + 560|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ((($9)) + 560|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($11|0)<($13|0);
  $15 = $9;
  $16 = $8;
  if (!($14)) {
   $17 = ($13|0)<($11|0);
   if ($17) {
    $$5 = 1;
    return ($$5|0);
   }
   $18 = ((($8)) + 564|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ((($9)) + 564|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = ($19|0)<($21|0);
   if (!($22)) {
    $$5 = 1;
    return ($$5|0);
   }
  }
  HEAP32[$0>>2] = $16;
  HEAP32[$7>>2] = $15;
  $$5 = 1;
  return ($$5|0);
  break;
 }
 case 3:  {
  $23 = ((($0)) + 4|0);
  $24 = ((($1)) + -4|0);
  $25 = HEAP32[$23>>2]|0;
  $26 = HEAP32[$0>>2]|0;
  $27 = ((($25)) + 560|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = ((($26)) + 560|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = ($28|0)<($30|0);
  $32 = $25;
  $33 = $26;
  if ($31) {
   $$0$i$i75 = 1;
  } else {
   $34 = ($30|0)<($28|0);
   if ($34) {
    $$0$i$i75 = 0;
   } else {
    $35 = ((($25)) + 564|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = ((($26)) + 564|0);
    $38 = HEAP32[$37>>2]|0;
    $39 = ($36|0)<($38|0);
    $$0$i$i75 = $39;
   }
  }
  $40 = HEAP32[$24>>2]|0;
  $41 = ((($40)) + 560|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = ($42|0)<($28|0);
  $44 = $40;
  if ($43) {
   $$0$i31$i77 = 1;
  } else {
   $45 = ($28|0)<($42|0);
   if ($45) {
    $$0$i31$i77 = 0;
   } else {
    $46 = ((($40)) + 564|0);
    $47 = HEAP32[$46>>2]|0;
    $48 = ((($25)) + 564|0);
    $49 = HEAP32[$48>>2]|0;
    $50 = ($47|0)<($49|0);
    $$0$i31$i77 = $50;
   }
  }
  if (!($$0$i$i75)) {
   if (!($$0$i31$i77)) {
    $$5 = 1;
    return ($$5|0);
   }
   HEAP32[$23>>2] = $44;
   HEAP32[$24>>2] = $32;
   $51 = HEAP32[$23>>2]|0;
   $52 = HEAP32[$0>>2]|0;
   $53 = ((($51)) + 560|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = ((($52)) + 560|0);
   $56 = HEAP32[$55>>2]|0;
   $57 = ($54|0)<($56|0);
   $58 = $52;
   $59 = $51;
   if (!($57)) {
    $60 = ($56|0)<($54|0);
    if ($60) {
     $$5 = 1;
     return ($$5|0);
    }
    $61 = ((($51)) + 564|0);
    $62 = HEAP32[$61>>2]|0;
    $63 = ((($52)) + 564|0);
    $64 = HEAP32[$63>>2]|0;
    $65 = ($62|0)<($64|0);
    if (!($65)) {
     $$5 = 1;
     return ($$5|0);
    }
   }
   HEAP32[$0>>2] = $59;
   HEAP32[$23>>2] = $58;
   $$5 = 1;
   return ($$5|0);
  }
  if ($$0$i31$i77) {
   HEAP32[$0>>2] = $44;
   HEAP32[$24>>2] = $33;
   $$5 = 1;
   return ($$5|0);
  }
  HEAP32[$0>>2] = $32;
  HEAP32[$23>>2] = $33;
  $66 = HEAP32[$24>>2]|0;
  $67 = ((($66)) + 560|0);
  $68 = HEAP32[$67>>2]|0;
  $69 = ($68|0)<($30|0);
  $70 = $66;
  if (!($69)) {
   $71 = ($30|0)<($68|0);
   if ($71) {
    $$5 = 1;
    return ($$5|0);
   }
   $72 = ((($66)) + 564|0);
   $73 = HEAP32[$72>>2]|0;
   $74 = ((($26)) + 564|0);
   $75 = HEAP32[$74>>2]|0;
   $76 = ($73|0)<($75|0);
   if (!($76)) {
    $$5 = 1;
    return ($$5|0);
   }
  }
  HEAP32[$23>>2] = $70;
  HEAP32[$24>>2] = $33;
  $$5 = 1;
  return ($$5|0);
  break;
 }
 case 4:  {
  $77 = ((($0)) + 4|0);
  $78 = ((($0)) + 8|0);
  $79 = ((($1)) + -4|0);
  (__ZNSt3__27__sort4IRN3osg23CameraRenderOrderSortOpEPPNS1_6CameraEEEjT0_S7_S7_S7_T_($0,$77,$78,$79,$2)|0);
  $$5 = 1;
  return ($$5|0);
  break;
 }
 case 5:  {
  $80 = ((($0)) + 4|0);
  $81 = ((($0)) + 8|0);
  $82 = ((($0)) + 12|0);
  $83 = ((($1)) + -4|0);
  (__ZNSt3__27__sort5IRN3osg23CameraRenderOrderSortOpEPPNS1_6CameraEEEjT0_S7_S7_S7_S7_T_($0,$80,$81,$82,$83,$2)|0);
  $$5 = 1;
  return ($$5|0);
  break;
 }
 case 1: case 0:  {
  $$5 = 1;
  return ($$5|0);
  break;
 }
 default: {
  $84 = ((($0)) + 8|0);
  $85 = ((($0)) + 4|0);
  $86 = HEAP32[$85>>2]|0;
  $87 = HEAP32[$0>>2]|0;
  $88 = ((($86)) + 560|0);
  $89 = HEAP32[$88>>2]|0;
  $90 = ((($87)) + 560|0);
  $91 = HEAP32[$90>>2]|0;
  $92 = ($89|0)<($91|0);
  $93 = $86;
  $94 = $87;
  if ($92) {
   $$0$i$i = 1;
  } else {
   $95 = ($91|0)<($89|0);
   if ($95) {
    $$0$i$i = 0;
   } else {
    $96 = ((($86)) + 564|0);
    $97 = HEAP32[$96>>2]|0;
    $98 = ((($87)) + 564|0);
    $99 = HEAP32[$98>>2]|0;
    $100 = ($97|0)<($99|0);
    $$0$i$i = $100;
   }
  }
  $101 = HEAP32[$84>>2]|0;
  $102 = ((($101)) + 560|0);
  $103 = HEAP32[$102>>2]|0;
  $104 = ($103|0)<($89|0);
  $105 = $101;
  if ($104) {
   $$0$i31$i = 1;
  } else {
   $106 = ($89|0)<($103|0);
   if ($106) {
    $$0$i31$i = 0;
   } else {
    $107 = ((($101)) + 564|0);
    $108 = HEAP32[$107>>2]|0;
    $109 = ((($86)) + 564|0);
    $110 = HEAP32[$109>>2]|0;
    $111 = ($108|0)<($110|0);
    $$0$i31$i = $111;
   }
  }
  do {
   if ($$0$i$i) {
    if ($$0$i31$i) {
     HEAP32[$0>>2] = $105;
     HEAP32[$84>>2] = $94;
     $164 = $87;
     break;
    }
    HEAP32[$0>>2] = $93;
    HEAP32[$85>>2] = $94;
    $119 = ($103|0)<($91|0);
    if (!($119)) {
     $120 = ($91|0)<($103|0);
     if ($120) {
      $164 = $101;
      break;
     }
     $121 = ((($101)) + 564|0);
     $122 = HEAP32[$121>>2]|0;
     $123 = ((($87)) + 564|0);
     $124 = HEAP32[$123>>2]|0;
     $125 = ($122|0)<($124|0);
     if (!($125)) {
      $164 = $101;
      break;
     }
    }
    HEAP32[$85>>2] = $105;
    HEAP32[$84>>2] = $94;
    $164 = $87;
   } else {
    if ($$0$i31$i) {
     HEAP32[$85>>2] = $105;
     HEAP32[$84>>2] = $93;
     $112 = ($103|0)<($91|0);
     if (!($112)) {
      $113 = ($91|0)<($103|0);
      if ($113) {
       $164 = $86;
       break;
      }
      $114 = ((($101)) + 564|0);
      $115 = HEAP32[$114>>2]|0;
      $116 = ((($87)) + 564|0);
      $117 = HEAP32[$116>>2]|0;
      $118 = ($115|0)<($117|0);
      if (!($118)) {
       $164 = $86;
       break;
      }
     }
     HEAP32[$0>>2] = $105;
     HEAP32[$85>>2] = $94;
     $164 = $86;
    } else {
     $164 = $101;
    }
   }
  } while(0);
  $126 = ((($0)) + 12|0);
  $127 = ($126|0)==($1|0);
  L27: do {
   if ($127) {
    $$1 = 1;$$3 = 0;
   } else {
    $$06295 = $126;$$06494 = 0;$$06992 = $84;$132 = $164;
    while(1) {
     $128 = HEAP32[$$06295>>2]|0;
     $129 = ((($128)) + 560|0);
     $130 = HEAP32[$129>>2]|0;
     $131 = ((($132)) + 560|0);
     $133 = HEAP32[$131>>2]|0;
     $134 = ($130|0)<($133|0);
     $135 = $128;
     if ($134) {
      $$pre101 = ((($128)) + 564|0);
      $$pre$phiZ2D = $$pre101;
      label = 49;
     } else {
      $136 = ($133|0)<($130|0);
      if ($136) {
       $$165 = $$06494;
      } else {
       $137 = ((($128)) + 564|0);
       $138 = HEAP32[$137>>2]|0;
       $139 = ((($132)) + 564|0);
       $140 = HEAP32[$139>>2]|0;
       $141 = ($138|0)<($140|0);
       if ($141) {
        $$pre$phiZ2D = $137;
        label = 49;
       } else {
        $$165 = $$06494;
       }
      }
     }
     if ((label|0) == 49) {
      label = 0;
      $142 = HEAP32[$$06992>>2]|0;
      HEAP32[$$06295>>2] = $142;
      $143 = ($$06992|0)==($0|0);
      L36: do {
       if ($143) {
        $$lcssa = $$06992;
       } else {
        $145 = $$06992;$156 = $$06992;
        while(1) {
         $144 = ((($145)) + -4|0);
         $146 = HEAP32[$144>>2]|0;
         $147 = ((($146)) + 560|0);
         $148 = HEAP32[$147>>2]|0;
         $149 = ($130|0)<($148|0);
         $150 = $146;
         if (!($149)) {
          $151 = ($148|0)<($130|0);
          if ($151) {
           $$lcssa = $156;
           break L36;
          }
          $152 = HEAP32[$$pre$phiZ2D>>2]|0;
          $153 = ((($146)) + 564|0);
          $154 = HEAP32[$153>>2]|0;
          $155 = ($152|0)<($154|0);
          if (!($155)) {
           $$lcssa = $156;
           break L36;
          }
         }
         HEAP32[$156>>2] = $150;
         $157 = ($144|0)==($0|0);
         if ($157) {
          $$lcssa = $144;
          break;
         } else {
          $145 = $144;$156 = $144;
         }
        }
       }
      } while(0);
      HEAP32[$$lcssa>>2] = $135;
      $158 = (($$06494) + 1)|0;
      $159 = ($158|0)==(8);
      $160 = ((($$06295)) + 4|0);
      $161 = ($160|0)==($1|0);
      if ($159) {
       $$1 = 0;$$3 = $161;
       break L27;
      } else {
       $$165 = $158;
      }
     }
     $162 = ((($$06295)) + 4|0);
     $163 = ($162|0)==($1|0);
     if ($163) {
      $$1 = 1;$$3 = 0;
      break L27;
     }
     $$pre = HEAP32[$$06295>>2]|0;
     $$06992$phi = $$06295;$$06295 = $162;$$06494 = $$165;$132 = $$pre;$$06992 = $$06992$phi;
    }
   }
  } while(0);
  $$$3 = $$3 | $$1;
  $$5 = $$$3;
  return ($$5|0);
 }
 }
 return (0)|0;
}
function __ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEE14__assign_multiINS_21__tree_const_iteratorIjPNS_11__tree_nodeIjPvEEiEEEEvT_SD_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$$i = 0, $$0$i = 0, $$0$i$i = 0, $$0$i$i$i = 0, $$0$i$i$i23 = 0, $$0$i$i21 = 0, $$0$i$i27 = 0, $$0$i$i32 = 0, $$0$i$i35 = 0, $$0$i11$i = 0, $$0$i36 = 0, $$015$i$i = 0, $$015$i$i33 = 0, $$027$i = 0, $$049 = 0, $$2$lcssa = 0, $$in$i$i = 0, $$in$i$i30 = 0, $$in61 = 0, $$in63 = 0;
 var $$pre = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i$i34 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 L1: do {
  if (!($5)) {
   $6 = HEAP32[$0>>2]|0;
   $7 = ((($0)) + 4|0);
   HEAP32[$0>>2] = $7;
   $8 = HEAP32[$7>>2]|0;
   $9 = ((($8)) + 8|0);
   HEAP32[$9>>2] = 0;
   HEAP32[$7>>2] = 0;
   HEAP32[$3>>2] = 0;
   $10 = ((($6)) + 4|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = ($11|0)==(0|0);
   $$$i = $12 ? $6 : $11;
   $13 = ($$$i|0)==(0|0);
   if (!($13)) {
    $14 = ((($0)) + 4|0);
    $$pre = HEAP32[$1>>2]|0;
    $$049 = $$$i;$$in61 = $$pre;
    while(1) {
     $15 = HEAP32[$2>>2]|0;
     $16 = ($$in61|0)==($15|0);
     if ($16) {
      break;
     }
     $20 = ((($$in61)) + 16|0);
     $21 = HEAP32[$20>>2]|0;
     $22 = ((($$049)) + 16|0);
     HEAP32[$22>>2] = $21;
     $23 = ((($$049)) + 8|0);
     $24 = HEAP32[$23>>2]|0;
     $25 = ($24|0)==(0|0);
     do {
      if ($25) {
       $$0$i36 = 0;
      } else {
       $26 = HEAP32[$24>>2]|0;
       $27 = ($26|0)==($$049|0);
       if ($27) {
        HEAP32[$24>>2] = 0;
        $28 = ((($24)) + 4|0);
        $29 = HEAP32[$28>>2]|0;
        $30 = ($29|0)==(0|0);
        if ($30) {
         $$0$i36 = $24;
         break;
        } else {
         $$0$i11$i = $29;
        }
        while(1) {
         $31 = HEAP32[$$0$i11$i>>2]|0;
         $32 = ($31|0)==(0|0);
         if (!($32)) {
          $$0$i11$i = $31;
          continue;
         }
         $33 = ((($$0$i11$i)) + 4|0);
         $34 = HEAP32[$33>>2]|0;
         $35 = ($34|0)==(0|0);
         if ($35) {
          break;
         } else {
          $$0$i11$i = $34;
         }
        }
        $$0$i36 = $$0$i11$i;
        break;
       } else {
        $36 = ((($24)) + 4|0);
        HEAP32[$36>>2] = 0;
        $37 = ($26|0)==(0|0);
        if ($37) {
         $$0$i36 = $24;
         break;
        } else {
         $$0$i$i35 = $26;
        }
        while(1) {
         $38 = HEAP32[$$0$i$i35>>2]|0;
         $39 = ($38|0)==(0|0);
         if (!($39)) {
          $$0$i$i35 = $38;
          continue;
         }
         $40 = ((($$0$i$i35)) + 4|0);
         $41 = HEAP32[$40>>2]|0;
         $42 = ($41|0)==(0|0);
         if ($42) {
          break;
         } else {
          $$0$i$i35 = $41;
         }
        }
        $$0$i36 = $$0$i$i35;
        break;
       }
      }
     } while(0);
     $43 = HEAP32[$7>>2]|0;
     $44 = ($43|0)==(0|0);
     do {
      if ($44) {
       $$0$i = $7;$$015$i$i33 = $7;
      } else {
       $$0$i$i32 = $43;
       while(1) {
        $45 = ((($$0$i$i32)) + 16|0);
        $46 = HEAP32[$45>>2]|0;
        $47 = ($21>>>0)<($46>>>0);
        if ($47) {
         $48 = HEAP32[$$0$i$i32>>2]|0;
         $49 = ($48|0)==(0|0);
         if ($49) {
          label = 20;
          break;
         } else {
          $$in$i$i30 = $48;
         }
        } else {
         $50 = ((($$0$i$i32)) + 4|0);
         $51 = HEAP32[$50>>2]|0;
         $52 = ($51|0)==(0|0);
         if ($52) {
          label = 22;
          break;
         } else {
          $$in$i$i30 = $51;
         }
        }
        $$0$i$i32 = $$in$i$i30;
       }
       if ((label|0) == 20) {
        label = 0;
        $$0$i = $$0$i$i32;$$015$i$i33 = $$0$i$i32;
        break;
       }
       else if ((label|0) == 22) {
        label = 0;
        $$0$i = $$0$i$i32;$$015$i$i33 = $50;
        break;
       }
      }
     } while(0);
     HEAP32[$$049>>2] = 0;
     $53 = ((($$049)) + 4|0);
     HEAP32[$53>>2] = 0;
     HEAP32[$23>>2] = $$0$i;
     HEAP32[$$015$i$i33>>2] = $$049;
     $54 = HEAP32[$0>>2]|0;
     $55 = HEAP32[$54>>2]|0;
     $56 = ($55|0)==(0|0);
     if ($56) {
      $59 = $$049;
     } else {
      $57 = $55;
      HEAP32[$0>>2] = $57;
      $$pre$i$i34 = HEAP32[$$015$i$i33>>2]|0;
      $59 = $$pre$i$i34;
     }
     $58 = HEAP32[$14>>2]|0;
     __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($58,$59);
     $60 = HEAP32[$3>>2]|0;
     $61 = (($60) + 1)|0;
     HEAP32[$3>>2] = $61;
     $62 = ((($$in61)) + 4|0);
     $63 = HEAP32[$62>>2]|0;
     $64 = ($63|0)==(0|0);
     if ($64) {
      $65 = ((($$in61)) + 8|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = HEAP32[$66>>2]|0;
      $68 = ($67|0)==($$in61|0);
      if ($68) {
       $$0$i$i27 = $66;
      } else {
       $72 = $65;
       while(1) {
        $71 = HEAP32[$72>>2]|0;
        $73 = ((($71)) + 8|0);
        $74 = HEAP32[$73>>2]|0;
        $75 = HEAP32[$74>>2]|0;
        $76 = ($75|0)==($71|0);
        if ($76) {
         $$0$i$i27 = $74;
         break;
        } else {
         $72 = $73;
        }
       }
      }
     } else {
      $$0$i$i$i23 = $63;
      while(1) {
       $69 = HEAP32[$$0$i$i$i23>>2]|0;
       $70 = ($69|0)==(0|0);
       if ($70) {
        break;
       } else {
        $$0$i$i$i23 = $69;
       }
      }
      $$0$i$i27 = $$0$i$i$i23;
     }
     HEAP32[$1>>2] = $$0$i$i27;
     $77 = ($$0$i36|0)==(0|0);
     if ($77) {
      break L1;
     } else {
      $$049 = $$0$i36;$$in61 = $$0$i$i27;
     }
    }
    $17 = ((($$049)) + 8|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = ($18|0)==(0|0);
    if ($19) {
     $$2$lcssa = $$049;
    } else {
     $79 = $17;
     while(1) {
      $78 = HEAP32[$79>>2]|0;
      $80 = ((($78)) + 8|0);
      $81 = HEAP32[$80>>2]|0;
      $82 = ($81|0)==(0|0);
      if ($82) {
       $$2$lcssa = $78;
       break;
      } else {
       $79 = $80;
      }
     }
    }
    __ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEE7destroyEPNS_11__tree_nodeIjPvEE($0,$$2$lcssa);
   }
  }
 } while(0);
 $83 = HEAP32[$1>>2]|0;
 $84 = HEAP32[$2>>2]|0;
 $85 = ($83|0)==($84|0);
 if ($85) {
  return;
 }
 $86 = ((($0)) + 4|0);
 $87 = ((($0)) + 4|0);
 $$in63 = $83;
 while(1) {
  $88 = ((($$in63)) + 16|0);
  $89 = HEAP32[$86>>2]|0;
  $90 = ($89|0)==(0|0);
  $$pre$i = HEAP32[$88>>2]|0;
  do {
   if ($90) {
    $$015$i$i = $86;$$027$i = $86;
   } else {
    $$0$i$i21 = $89;
    while(1) {
     $91 = ((($$0$i$i21)) + 16|0);
     $92 = HEAP32[$91>>2]|0;
     $93 = ($$pre$i>>>0)<($92>>>0);
     if ($93) {
      $94 = HEAP32[$$0$i$i21>>2]|0;
      $95 = ($94|0)==(0|0);
      if ($95) {
       label = 39;
       break;
      } else {
       $$in$i$i = $94;
      }
     } else {
      $96 = ((($$0$i$i21)) + 4|0);
      $97 = HEAP32[$96>>2]|0;
      $98 = ($97|0)==(0|0);
      if ($98) {
       label = 41;
       break;
      } else {
       $$in$i$i = $97;
      }
     }
     $$0$i$i21 = $$in$i$i;
    }
    if ((label|0) == 39) {
     label = 0;
     $$015$i$i = $$0$i$i21;$$027$i = $$0$i$i21;
     break;
    }
    else if ((label|0) == 41) {
     label = 0;
     $$015$i$i = $96;$$027$i = $$0$i$i21;
     break;
    }
   }
  } while(0);
  $99 = (__Znwj(20)|0);
  $100 = ((($99)) + 16|0);
  HEAP32[$100>>2] = $$pre$i;
  HEAP32[$99>>2] = 0;
  $101 = ((($99)) + 4|0);
  HEAP32[$101>>2] = 0;
  $102 = ((($99)) + 8|0);
  HEAP32[$102>>2] = $$027$i;
  HEAP32[$$015$i$i>>2] = $99;
  $103 = HEAP32[$0>>2]|0;
  $104 = HEAP32[$103>>2]|0;
  $105 = ($104|0)==(0|0);
  if ($105) {
   $108 = $99;
  } else {
   $106 = $104;
   HEAP32[$0>>2] = $106;
   $$pre$i$i = HEAP32[$$015$i$i>>2]|0;
   $108 = $$pre$i$i;
  }
  $107 = HEAP32[$87>>2]|0;
  __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($107,$108);
  $109 = HEAP32[$3>>2]|0;
  $110 = (($109) + 1)|0;
  HEAP32[$3>>2] = $110;
  $111 = ((($$in63)) + 4|0);
  $112 = HEAP32[$111>>2]|0;
  $113 = ($112|0)==(0|0);
  if ($113) {
   $114 = ((($$in63)) + 8|0);
   $115 = HEAP32[$114>>2]|0;
   $116 = HEAP32[$115>>2]|0;
   $117 = ($116|0)==($$in63|0);
   if ($117) {
    $$0$i$i = $115;
   } else {
    $121 = $114;
    while(1) {
     $120 = HEAP32[$121>>2]|0;
     $122 = ((($120)) + 8|0);
     $123 = HEAP32[$122>>2]|0;
     $124 = HEAP32[$123>>2]|0;
     $125 = ($124|0)==($120|0);
     if ($125) {
      $$0$i$i = $123;
      break;
     } else {
      $121 = $122;
     }
    }
   }
  } else {
   $$0$i$i$i = $112;
   while(1) {
    $118 = HEAP32[$$0$i$i$i>>2]|0;
    $119 = ($118|0)==(0|0);
    if ($119) {
     break;
    } else {
     $$0$i$i$i = $118;
    }
   }
   $$0$i$i = $$0$i$i$i;
  }
  HEAP32[$1>>2] = $$0$i$i;
  $126 = ($$0$i$i|0)==($84|0);
  if ($126) {
   break;
  } else {
   $$in63 = $$0$i$i;
  }
 }
 return;
}
function __ZNSt3__215basic_stringbufIcNS_11char_traitsIcEENS_9allocatorIcEEE3strERKNS_12basic_stringIcS2_S4_EE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp$i = 0, $storemerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 32|0);
 (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEaSERKS5_($2,$1)|0);
 $3 = ((($0)) + 44|0);
 HEAP32[$3>>2] = 0;
 $4 = ((($0)) + 48|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5 & 8;
 $7 = ($6|0)==(0);
 if (!($7)) {
  $8 = ((($2)) + 11|0);
  $9 = HEAP8[$8>>0]|0;
  $10 = ($9<<24>>24)<(0);
  if ($10) {
   $11 = HEAP32[$2>>2]|0;
   $12 = ((($0)) + 36|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($11) + ($13)|0);
   $19 = $11;$21 = $11;$storemerge = $14;
  } else {
   $15 = $9&255;
   $16 = (($2) + ($15)|0);
   $19 = $2;$21 = $2;$storemerge = $16;
  }
  HEAP32[$3>>2] = $storemerge;
  $17 = $storemerge;
  $18 = ((($0)) + 8|0);
  HEAP32[$18>>2] = $19;
  $20 = ((($0)) + 12|0);
  HEAP32[$20>>2] = $21;
  $22 = ((($0)) + 16|0);
  HEAP32[$22>>2] = $17;
 }
 $23 = $5 & 16;
 $24 = ($23|0)==(0);
 if ($24) {
  return;
 }
 $25 = ((($2)) + 11|0);
 $26 = HEAP8[$25>>0]|0;
 $27 = ($26<<24>>24)<(0);
 if ($27) {
  $30 = ((($0)) + 36|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = HEAP32[$2>>2]|0;
  $33 = (($32) + ($31)|0);
  HEAP32[$3>>2] = $33;
  $34 = ((($0)) + 40|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = $35 & 2147483647;
  $phitmp$i = (($36) + -1)|0;
  $37 = $phitmp$i;$55 = $31;
 } else {
  $28 = $26&255;
  $29 = (($2) + ($28)|0);
  HEAP32[$3>>2] = $29;
  $37 = 10;$55 = $28;
 }
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEjc($2,$37,0);
 $38 = HEAP8[$25>>0]|0;
 $39 = ($38<<24>>24)<(0);
 if ($39) {
  $40 = HEAP32[$2>>2]|0;
  $41 = ((($0)) + 36|0);
  $42 = HEAP32[$41>>2]|0;
  $45 = $40;$46 = $42;$48 = $40;
 } else {
  $43 = $38&255;
  $45 = $2;$46 = $43;$48 = $2;
 }
 $44 = (($45) + ($46)|0);
 $47 = ((($0)) + 24|0);
 HEAP32[$47>>2] = $48;
 $49 = ((($0)) + 20|0);
 HEAP32[$49>>2] = $48;
 $50 = ((($0)) + 28|0);
 HEAP32[$50>>2] = $44;
 $51 = HEAP32[$4>>2]|0;
 $52 = $51 & 3;
 $53 = ($52|0)==(0);
 if ($53) {
  return;
 }
 $54 = (($48) + ($55)|0);
 HEAP32[$47>>2] = $54;
 return;
}
function __ZNSt3__219basic_istringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = ((37096));
 $1 = ((($0)) + 60|0);
 HEAP32[$1>>2] = ((37116));
 $2 = ((($0)) + 8|0);
 HEAP32[$2>>2] = (37132);
 $3 = ((($0)) + 40|0);
 $4 = ((($3)) + 11|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)<(0);
 if ($6) {
  $7 = HEAP32[$3>>2]|0;
  __ZdlPv($7);
 }
 __THREW__ = 0;
 invoke_vi(2911,($2|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 do {
  if ($9) {
   $12 = ___cxa_find_matching_catch_2()|0;
   $13 = tempRet0;
   __THREW__ = 0;
   invoke_vii(3371,($0|0),((37192)|0));
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if ($15) {
    $16 = ___cxa_find_matching_catch_3(0|0)|0;
    $17 = tempRet0;
    ___clang_call_terminate($16);
    // unreachable;
   } else {
    $eh$lpad$body$index2Z2D = $13;$eh$lpad$body$indexZ2D = $12;
   }
  } else {
   __THREW__ = 0;
   invoke_vii(3371,($0|0),((37192)|0));
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if ($11) {
    $18 = ___cxa_find_matching_catch_2()|0;
    $19 = tempRet0;
    $eh$lpad$body$index2Z2D = $19;$eh$lpad$body$indexZ2D = $18;
    break;
   } else {
    __ZNSt3__29basic_iosIcNS_11char_traitsIcEEED2Ev($1);
    return;
   }
  }
 } while(0);
 __THREW__ = 0;
 invoke_vi(2907,($1|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if ($21) {
  $22 = ___cxa_find_matching_catch_3(0|0)|0;
  $23 = tempRet0;
  ___clang_call_terminate($22);
  // unreachable;
 } else {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
}
function __ZNSt3__215basic_stringbufIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (37132);
 $1 = ((($0)) + 32|0);
 $2 = ((($1)) + 11|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)<(0);
 if ($4) {
  $5 = HEAP32[$1>>2]|0;
  __ZdlPv($5);
 }
 __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEED2Ev($0);
 return;
}
function __ZNSt3__215basic_stringbufIcNS_11char_traitsIcEENS_9allocatorIcEEED0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (37132);
 $1 = ((($0)) + 32|0);
 $2 = ((($1)) + 11|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)<(0);
 if ($4) {
  $5 = HEAP32[$1>>2]|0;
  __ZdlPv($5);
 }
 __THREW__ = 0;
 invoke_vi(2911,($0|0));
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if ($7) {
  $8 = ___cxa_find_matching_catch_2()|0;
  $9 = tempRet0;
  __ZdlPv($0);
  ___resumeException($8|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNSt3__215basic_stringbufIcNS_11char_traitsIcEENS_9allocatorIcEEE7seekoffExNS_8ios_base7seekdirEj($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$pre = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $or$cond = 0, $or$cond22 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $6 = ((($1)) + 44|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($1)) + 24|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($7>>>0)<($9>>>0);
 $11 = $7;
 $12 = $9;
 if ($10) {
  HEAP32[$6>>2] = $9;
  $39 = $12;
 } else {
  $39 = $11;
 }
 $13 = $5 & 24;
 $14 = ($13|0)==(0);
 L4: do {
  if ($14) {
   $90 = -1;$93 = -1;
  } else {
   $15 = ($13|0)==(24);
   $16 = ($4|0)==(1);
   $or$cond = $16 & $15;
   if ($or$cond) {
    $90 = -1;$93 = -1;
   } else {
    L7: do {
     switch ($4|0) {
     case 0:  {
      $42 = 0;$43 = 0;
      break;
     }
     case 1:  {
      $17 = $5 & 8;
      $18 = ($17|0)==(0);
      if ($18) {
       $26 = ((($1)) + 20|0);
       $27 = HEAP32[$26>>2]|0;
       $28 = (($12) - ($27))|0;
       $29 = ($28|0)<(0);
       $30 = $29 << 31 >> 31;
       $42 = $28;$43 = $30;
       break L7;
      } else {
       $19 = ((($1)) + 12|0);
       $20 = HEAP32[$19>>2]|0;
       $21 = ((($1)) + 8|0);
       $22 = HEAP32[$21>>2]|0;
       $23 = (($20) - ($22))|0;
       $24 = ($23|0)<(0);
       $25 = $24 << 31 >> 31;
       $42 = $23;$43 = $25;
       break L7;
      }
      break;
     }
     case 2:  {
      $31 = ((($1)) + 32|0);
      $32 = ((($31)) + 11|0);
      $33 = HEAP8[$32>>0]|0;
      $34 = ($33<<24>>24)<(0);
      if ($34) {
       $35 = HEAP32[$31>>2]|0;
       $36 = $35;
      } else {
       $36 = $31;
      }
      $37 = $36;
      $38 = (($39) - ($37))|0;
      $40 = ($38|0)<(0);
      $41 = $40 << 31 >> 31;
      $42 = $38;$43 = $41;
      break;
     }
     default: {
      $90 = -1;$93 = -1;
      break L4;
     }
     }
    } while(0);
    $44 = (_i64Add(($42|0),($43|0),($2|0),($3|0))|0);
    $45 = tempRet0;
    $46 = ($45|0)<(0);
    if ($46) {
     $90 = -1;$93 = -1;
    } else {
     $47 = ((($1)) + 32|0);
     $48 = ((($47)) + 11|0);
     $49 = HEAP8[$48>>0]|0;
     $50 = ($49<<24>>24)<(0);
     if ($50) {
      $51 = HEAP32[$47>>2]|0;
      $52 = $51;
     } else {
      $52 = $47;
     }
     $53 = $52;
     $54 = (($39) - ($53))|0;
     $55 = ($54|0)<(0);
     $56 = $55 << 31 >> 31;
     $57 = ($56|0)<($45|0);
     $58 = ($54>>>0)<($44>>>0);
     $59 = ($56|0)==($45|0);
     $60 = $59 & $58;
     $61 = $57 | $60;
     if ($61) {
      $90 = -1;$93 = -1;
     } else {
      $62 = ($44|0)==(0);
      $63 = ($45|0)==(0);
      $64 = $62 & $63;
      $$pre = $5 & 8;
      if (!($64)) {
       $65 = ($$pre|0)==(0);
       if (!($65)) {
        $66 = ((($1)) + 12|0);
        $67 = HEAP32[$66>>2]|0;
        $68 = ($67|0)==(0|0);
        if ($68) {
         $90 = -1;$93 = -1;
         break;
        }
       }
       $69 = $5 & 16;
       $70 = ($69|0)!=(0);
       $71 = ($9|0)==(0|0);
       $or$cond22 = $70 & $71;
       if ($or$cond22) {
        $90 = -1;$93 = -1;
        break;
       }
      }
      $72 = ($$pre|0)==(0);
      if (!($72)) {
       $73 = ((($1)) + 8|0);
       $74 = HEAP32[$73>>2]|0;
       $75 = (($74) + ($44)|0);
       $76 = ((($1)) + 12|0);
       HEAP32[$76>>2] = $75;
       $77 = ((($1)) + 16|0);
       HEAP32[$77>>2] = $39;
      }
      $78 = $5 & 16;
      $79 = ($78|0)==(0);
      if ($79) {
       $90 = $44;$93 = $45;
      } else {
       $80 = ((($1)) + 20|0);
       $81 = HEAP32[$80>>2]|0;
       $82 = (($81) + ($44)|0);
       HEAP32[$8>>2] = $82;
       $90 = $44;$93 = $45;
      }
     }
    }
   }
  }
 } while(0);
 $83 = $0;
 $84 = $83;
 HEAP32[$84>>2] = 0;
 $85 = (($83) + 4)|0;
 $86 = $85;
 HEAP32[$86>>2] = 0;
 $87 = ((($0)) + 8|0);
 $88 = $87;
 $89 = $88;
 HEAP32[$89>>2] = $90;
 $91 = (($88) + 4)|0;
 $92 = $91;
 HEAP32[$92>>2] = $93;
 return;
}
function __ZNSt3__215basic_stringbufIcNS_11char_traitsIcEENS_9allocatorIcEEE7seekposENS_4fposI11__mbstate_tEEj($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = HEAP32[$1>>2]|0;
 $5 = ((($4)) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($2)) + 8|0);
 $8 = $7;
 $9 = $8;
 $10 = HEAP32[$9>>2]|0;
 $11 = (($8) + 4)|0;
 $12 = $11;
 $13 = HEAP32[$12>>2]|0;
 FUNCTION_TABLE_viiiiii[$6 & 8191]($0,$1,$10,$13,0,$3);
 return;
}
function __ZNSt3__215basic_stringbufIcNS_11char_traitsIcEENS_9allocatorIcEEE9underflowEv($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 44|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 24|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)<($4>>>0);
 if ($5) {
  HEAP32[$1>>2] = $4;
  $13 = $4;
 } else {
  $13 = $2;
 }
 $6 = ((($0)) + 48|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 & 8;
 $9 = ($8|0)==(0);
 if ($9) {
  $$0 = -1;
  return ($$0|0);
 }
 $10 = ((($0)) + 16|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11>>>0)<($13>>>0);
 if ($12) {
  HEAP32[$10>>2] = $13;
  $17 = $13;
 } else {
  $17 = $11;
 }
 $14 = ((($0)) + 12|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15>>>0)<($17>>>0);
 if (!($16)) {
  $$0 = -1;
  return ($$0|0);
 }
 $18 = HEAP8[$15>>0]|0;
 $19 = $18&255;
 $$0 = $19;
 return ($$0|0);
}
function __ZNSt3__215basic_stringbufIcNS_11char_traitsIcEENS_9allocatorIcEEE9pbackfailEi($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$in = 0, $$pre = 0, $$pre$phi7Z2D = 0, $$pre$phiZ2D = 0, $$pre6 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 44|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 24|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)<($5>>>0);
 if ($6) {
  HEAP32[$2>>2] = $5;
  $$in = $5;
 } else {
  $$in = $3;
 }
 $7 = $$in;
 $8 = ((($0)) + 8|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($0)) + 12|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($9>>>0)<($11>>>0);
 if (!($12)) {
  $$0 = -1;
  return ($$0|0);
 }
 $13 = ($1|0)==(-1);
 if ($13) {
  $14 = ((($11)) + -1|0);
  HEAP32[$10>>2] = $14;
  $15 = ((($0)) + 16|0);
  HEAP32[$15>>2] = $7;
  $$0 = 0;
  return ($$0|0);
 }
 $16 = ((($0)) + 48|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = $17 & 16;
 $19 = ($18|0)==(0);
 if ($19) {
  $20 = $1&255;
  $21 = ((($11)) + -1|0);
  $22 = HEAP8[$21>>0]|0;
  $23 = ($20<<24>>24)==($22<<24>>24);
  if ($23) {
   $$pre$phi7Z2D = $20;$$pre$phiZ2D = $21;
  } else {
   $$0 = -1;
   return ($$0|0);
  }
 } else {
  $$pre = ((($11)) + -1|0);
  $$pre6 = $1&255;
  $$pre$phi7Z2D = $$pre6;$$pre$phiZ2D = $$pre;
 }
 HEAP32[$10>>2] = $$pre$phiZ2D;
 $24 = ((($0)) + 16|0);
 HEAP32[$24>>2] = $7;
 HEAP8[$$pre$phiZ2D>>0] = $$pre$phi7Z2D;
 $$0 = $1;
 return ($$0|0);
}
function __ZNSt3__215basic_stringbufIcNS_11char_traitsIcEENS_9allocatorIcEEE8overflowEi($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$1 = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre$phi26Z2D = 0, $$pre$phi28Z2D = 0, $$pre$phiZ2D = 0, $$pre27 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $8 = 0;
 var $9 = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = ($1|0)==(-1);
 if ($3) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $4 = ((($0)) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($0)) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5) - ($7))|0;
 $9 = ((($0)) + 24|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ((($0)) + 28|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($10|0)==($12|0);
 do {
  if ($13) {
   $14 = ((($0)) + 48|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = $15 & 16;
   $17 = ($16|0)==(0);
   if ($17) {
    $$1 = -1;
    STACKTOP = sp;return ($$1|0);
   }
   $18 = ((($0)) + 20|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = $10;
   $21 = (($20) - ($19))|0;
   $22 = ((($0)) + 44|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = (($23) - ($19))|0;
   $25 = ((($0)) + 32|0);
   __THREW__ = 0;
   invoke_vii(3433,($25|0),0);
   $26 = __THREW__; __THREW__ = 0;
   $27 = $26&1;
   if (!($27)) {
    $28 = ((($25)) + 11|0);
    $29 = HEAP8[$28>>0]|0;
    $30 = ($29<<24>>24)<(0);
    if ($30) {
     $31 = ((($0)) + 40|0);
     $32 = HEAP32[$31>>2]|0;
     $33 = $32 & 2147483647;
     $phitmp$i = (($33) + -1)|0;
     $34 = $phitmp$i;
    } else {
     $34 = 10;
    }
    __THREW__ = 0;
    invoke_viii(3434,($25|0),($34|0),0);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if (!($36)) {
     $37 = HEAP8[$28>>0]|0;
     $38 = ($37<<24>>24)<(0);
     if ($38) {
      $39 = HEAP32[$25>>2]|0;
      $40 = ((($0)) + 36|0);
      $41 = HEAP32[$40>>2]|0;
      $44 = $39;$45 = $41;
     } else {
      $42 = $37&255;
      $44 = $25;$45 = $42;
     }
     $43 = (($44) + ($45)|0);
     HEAP32[$18>>2] = $44;
     HEAP32[$11>>2] = $43;
     $46 = (($44) + ($21)|0);
     HEAP32[$9>>2] = $46;
     $47 = (($44) + ($24)|0);
     HEAP32[$22>>2] = $47;
     $$pre$phi26Z2D = $22;$$pre$phi28Z2D = $14;$$pre$phiZ2D = $22;$51 = $46;$53 = $47;$68 = $43;
     break;
    }
   }
   $48 = ___cxa_find_matching_catch_3(0|0)|0;
   $49 = tempRet0;
   (___cxa_begin_catch(($48|0))|0);
   ___cxa_end_catch();
   $$1 = -1;
   STACKTOP = sp;return ($$1|0);
  } else {
   $$phi$trans$insert = ((($0)) + 44|0);
   $$pre = HEAP32[$$phi$trans$insert>>2]|0;
   $$pre27 = ((($0)) + 48|0);
   $$pre$phi26Z2D = $$phi$trans$insert;$$pre$phi28Z2D = $$pre27;$$pre$phiZ2D = $$phi$trans$insert;$51 = $10;$53 = $$pre;$68 = $12;
  }
 } while(0);
 $50 = ((($51)) + 1|0);
 HEAP32[$2>>2] = $50;
 $52 = ($50>>>0)<($53>>>0);
 $54 = $52 ? $$pre$phiZ2D : $2;
 $55 = HEAP32[$54>>2]|0;
 HEAP32[$$pre$phi26Z2D>>2] = $55;
 $56 = HEAP32[$$pre$phi28Z2D>>2]|0;
 $57 = $56 & 8;
 $58 = ($57|0)==(0);
 if (!($58)) {
  $59 = ((($0)) + 32|0);
  $60 = ((($59)) + 11|0);
  $61 = HEAP8[$60>>0]|0;
  $62 = ($61<<24>>24)<(0);
  if ($62) {
   $63 = HEAP32[$59>>2]|0;
   $65 = $63;
  } else {
   $65 = $59;
  }
  $64 = (($65) + ($8)|0);
  HEAP32[$6>>2] = $65;
  HEAP32[$4>>2] = $64;
  $66 = ((($0)) + 16|0);
  HEAP32[$66>>2] = $55;
 }
 $67 = ($51|0)==($68|0);
 if ($67) {
  $69 = HEAP32[$0>>2]|0;
  $70 = ((($69)) + 52|0);
  $71 = HEAP32[$70>>2]|0;
  $72 = $1 & 255;
  $73 = (FUNCTION_TABLE_iii[$71 & 8191]($0,$72)|0);
  $$1 = $73;
  STACKTOP = sp;return ($$1|0);
 } else {
  $74 = $1&255;
  HEAP32[$9>>2] = $50;
  HEAP8[$51>>0] = $74;
  $75 = $1 & 255;
  $$1 = $75;
  STACKTOP = sp;return ($$1|0);
 }
 return (0)|0;
}
function __ZNSt3__219basic_istringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(289,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZTv0_n12_NSt3__219basic_istringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __ZNSt3__219basic_istringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($4);
 return;
}
function __ZTv0_n12_NSt3__219basic_istringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __THREW__ = 0;
 invoke_vi(289,($4|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $7 = ___cxa_find_matching_catch_2()|0;
  $8 = tempRet0;
  __ZdlPv($4);
  ___resumeException($7|0);
  // unreachable;
 } else {
  __ZdlPv($4);
  return;
 }
}
function __ZN5osgDB7OptionsD2Ev($0) {
 $0 = $0|0;
 var $$0 = 0, $$02 = 0, $$08$i = 0, $$08$i37 = 0, $$1 = 0, $$13 = 0, $$2 = 0, $$24 = 0, $$3 = 0, $$35 = 0, $$4 = 0, $$46 = 0, $$5 = 0, $$57 = 0, $$8 = 0, $$810 = 0, $$9 = 0, $$911 = 0, $$pre$i = 0, $$pre$i39 = 0;
 var $$pre9$i = 0, $$pre9$i40 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0;
 var $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0;
 var $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0;
 var $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i42 = 0, $scevgep5$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i43 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (37212);
 $1 = ((($0)) + 140|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  label = 4;
 } else {
  $4 = ((($2)) + 8|0);
  $5 = HEAP32[$4>>2]|0;HEAP32[$4>>2] = (($5-1)|0);
  $6 = ($5|0)==(1);
  if ($6) {
   __THREW__ = 0;
   invoke_viii(3262,($2|0),1,1);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $117 = ___cxa_find_matching_catch_2()|0;
    $118 = tempRet0;
    $119 = ((($0)) + 132|0);
    $120 = HEAP32[$119>>2]|0;
    $121 = ($120|0)==(0|0);
    if (!($121)) {
     $122 = ((($120)) + 8|0);
     $123 = HEAP32[$122>>2]|0;HEAP32[$122>>2] = (($123-1)|0);
     $124 = ($123|0)==(1);
     if ($124) {
      __THREW__ = 0;
      invoke_viii(3262,($120|0),1,1);
      $125 = __THREW__; __THREW__ = 0;
      $126 = $125&1;
      if ($126) {
       $245 = ___cxa_find_matching_catch_3(0|0)|0;
       $246 = tempRet0;
       ___clang_call_terminate($245);
       // unreachable;
      }
     }
    }
    HEAP32[$119>>2] = 0;
    $$0 = $118;$$02 = $117;
    label = 43;
   } else {
    label = 4;
   }
  } else {
   label = 4;
  }
 }
 do {
  if ((label|0) == 4) {
   HEAP32[$1>>2] = 0;
   $9 = ((($0)) + 132|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($10|0)==(0|0);
   if (!($11)) {
    $12 = ((($10)) + 8|0);
    $13 = HEAP32[$12>>2]|0;HEAP32[$12>>2] = (($13-1)|0);
    $14 = ($13|0)==(1);
    if ($14) {
     __THREW__ = 0;
     invoke_viii(3262,($10|0),1,1);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      $127 = ___cxa_find_matching_catch_2()|0;
      $128 = tempRet0;
      $$0 = $128;$$02 = $127;
      label = 43;
      break;
     }
    }
   }
   HEAP32[$9>>2] = 0;
   $17 = ((($0)) + 128|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = ($18|0)==(0|0);
   if (!($19)) {
    $20 = ((($18)) + 8|0);
    $21 = HEAP32[$20>>2]|0;HEAP32[$20>>2] = (($21-1)|0);
    $22 = ($21|0)==(1);
    if ($22) {
     __THREW__ = 0;
     invoke_viii(3262,($18|0),1,1);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      $129 = ___cxa_find_matching_catch_2()|0;
      $130 = tempRet0;
      $$1 = $130;$$13 = $129;
      label = 48;
      break;
     }
    }
   }
   HEAP32[$17>>2] = 0;
   $25 = ((($0)) + 124|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = ($26|0)==(0|0);
   if (!($27)) {
    $28 = HEAP32[$26>>2]|0;
    $29 = ((($28)) + -12|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = (($26) + ($30)|0);
    $32 = ((($31)) + 8|0);
    $33 = HEAP32[$32>>2]|0;HEAP32[$32>>2] = (($33-1)|0);
    $34 = ($33|0)==(1);
    if ($34) {
     __THREW__ = 0;
     invoke_viii(3262,($31|0),1,1);
     $35 = __THREW__; __THREW__ = 0;
     $36 = $35&1;
     if ($36) {
      $139 = ___cxa_find_matching_catch_2()|0;
      $140 = tempRet0;
      $$2 = $140;$$24 = $139;
      label = 53;
      break;
     }
    }
   }
   HEAP32[$25>>2] = 0;
   $37 = ((($0)) + 120|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = ($38|0)==(0|0);
   if (!($39)) {
    $40 = HEAP32[$38>>2]|0;
    $41 = ((($40)) + -12|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = (($38) + ($42)|0);
    $44 = ((($43)) + 8|0);
    $45 = HEAP32[$44>>2]|0;HEAP32[$44>>2] = (($45-1)|0);
    $46 = ($45|0)==(1);
    if ($46) {
     __THREW__ = 0;
     invoke_viii(3262,($43|0),1,1);
     $47 = __THREW__; __THREW__ = 0;
     $48 = $47&1;
     if ($48) {
      $153 = ___cxa_find_matching_catch_2()|0;
      $154 = tempRet0;
      $$3 = $154;$$35 = $153;
      label = 58;
      break;
     }
    }
   }
   HEAP32[$37>>2] = 0;
   $49 = ((($0)) + 116|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = ($50|0)==(0|0);
   if (!($51)) {
    $52 = HEAP32[$50>>2]|0;
    $53 = ((($52)) + -12|0);
    $54 = HEAP32[$53>>2]|0;
    $55 = (($50) + ($54)|0);
    $56 = ((($55)) + 8|0);
    $57 = HEAP32[$56>>2]|0;HEAP32[$56>>2] = (($57-1)|0);
    $58 = ($57|0)==(1);
    if ($58) {
     __THREW__ = 0;
     invoke_viii(3262,($55|0),1,1);
     $59 = __THREW__; __THREW__ = 0;
     $60 = $59&1;
     if ($60) {
      $167 = ___cxa_find_matching_catch_2()|0;
      $168 = tempRet0;
      $$4 = $168;$$46 = $167;
      label = 63;
      break;
     }
    }
   }
   HEAP32[$49>>2] = 0;
   $61 = ((($0)) + 112|0);
   $62 = HEAP32[$61>>2]|0;
   $63 = ($62|0)==(0|0);
   if (!($63)) {
    $64 = HEAP32[$62>>2]|0;
    $65 = ((($64)) + -12|0);
    $66 = HEAP32[$65>>2]|0;
    $67 = (($62) + ($66)|0);
    $68 = ((($67)) + 8|0);
    $69 = HEAP32[$68>>2]|0;HEAP32[$68>>2] = (($69-1)|0);
    $70 = ($69|0)==(1);
    if ($70) {
     __THREW__ = 0;
     invoke_viii(3262,($67|0),1,1);
     $71 = __THREW__; __THREW__ = 0;
     $72 = $71&1;
     if ($72) {
      $181 = ___cxa_find_matching_catch_2()|0;
      $182 = tempRet0;
      $$5 = $182;$$57 = $181;
      label = 68;
      break;
     }
    }
   }
   HEAP32[$61>>2] = 0;
   $73 = ((($0)) + 100|0);
   $74 = ((($0)) + 104|0);
   $75 = HEAP32[$74>>2]|0;
   __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES7_EENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($73,$75);
   $76 = ((($0)) + 88|0);
   $77 = ((($0)) + 92|0);
   $78 = HEAP32[$77>>2]|0;
   __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPvEENS_19__map_value_compareIS7_S9_NS_4lessIS7_EELb1EEENS5_IS9_EEE7destroyEPNS_11__tree_nodeIS9_S8_EE($76,$78);
   $79 = ((($0)) + 84|0);
   $80 = HEAP32[$79>>2]|0;
   $81 = ($80|0)==(0|0);
   if (!($81)) {
    $82 = ((($80)) + 8|0);
    $83 = HEAP32[$82>>2]|0;HEAP32[$82>>2] = (($83-1)|0);
    $84 = ($83|0)==(1);
    if ($84) {
     __THREW__ = 0;
     invoke_viii(3262,($80|0),1,1);
     $85 = __THREW__; __THREW__ = 0;
     $86 = $85&1;
     if ($86) {
      $195 = ___cxa_find_matching_catch_2()|0;
      $196 = tempRet0;
      $$8 = $196;$$810 = $195;
      label = 73;
      break;
     }
    }
   }
   HEAP32[$79>>2] = 0;
   $87 = ((($0)) + 72|0);
   $88 = HEAP32[$87>>2]|0;
   $89 = ($88|0)==(0|0);
   if (!($89)) {
    $90 = ((($88)) + 8|0);
    $91 = HEAP32[$90>>2]|0;HEAP32[$90>>2] = (($91-1)|0);
    $92 = ($91|0)==(1);
    if ($92) {
     __THREW__ = 0;
     invoke_viii(3262,($88|0),1,1);
     $93 = __THREW__; __THREW__ = 0;
     $94 = $93&1;
     if ($94) {
      $211 = ___cxa_find_matching_catch_2()|0;
      $212 = tempRet0;
      $$9 = $212;$$911 = $211;
      break;
     }
    }
   }
   HEAP32[$87>>2] = 0;
   $95 = ((($0)) + 44|0);
   __ZNSt3__212__deque_baseINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS4_IS6_EEE5clearEv($95);
   $96 = ((($0)) + 48|0);
   $97 = HEAP32[$96>>2]|0;
   $98 = ((($0)) + 52|0);
   $99 = HEAP32[$98>>2]|0;
   $100 = ($97|0)==($99|0);
   if (!($100)) {
    $$08$i = $97;
    while(1) {
     $101 = HEAP32[$$08$i>>2]|0;
     __ZdlPv($101);
     $102 = ((($$08$i)) + 4|0);
     $103 = ($102|0)==($99|0);
     if ($103) {
      break;
     } else {
      $$08$i = $102;
     }
    }
    $$pre$i = HEAP32[$96>>2]|0;
    $$pre9$i = HEAP32[$98>>2]|0;
    $104 = ($$pre9$i|0)==($$pre$i|0);
    if (!($104)) {
     $scevgep$i$i$i$i$i = ((($$pre9$i)) + -4|0);
     $105 = $scevgep$i$i$i$i$i;
     $106 = $$pre$i;
     $107 = (($105) - ($106))|0;
     $108 = $107 >>> 2;
     $109 = $108 ^ -1;
     $scevgep5$i$i$i$i$i = (($$pre9$i) + ($109<<2)|0);
     HEAP32[$98>>2] = $scevgep5$i$i$i$i$i;
    }
   }
   $110 = HEAP32[$95>>2]|0;
   $111 = ($110|0)==(0|0);
   if (!($111)) {
    __ZdlPv($110);
   }
   $112 = ((($0)) + 32|0);
   $113 = ((($112)) + 11|0);
   $114 = HEAP8[$113>>0]|0;
   $115 = ($114<<24>>24)<(0);
   if (!($115)) {
    __ZN3osg6ObjectD2Ev($0);
    return;
   }
   $116 = HEAP32[$112>>2]|0;
   __ZdlPv($116);
   __ZN3osg6ObjectD2Ev($0);
   return;
  }
 } while(0);
 if ((label|0) == 43) {
  $131 = ((($0)) + 128|0);
  $132 = HEAP32[$131>>2]|0;
  $133 = ($132|0)==(0|0);
  if (!($133)) {
   $134 = ((($132)) + 8|0);
   $135 = HEAP32[$134>>2]|0;HEAP32[$134>>2] = (($135-1)|0);
   $136 = ($135|0)==(1);
   if ($136) {
    __THREW__ = 0;
    invoke_viii(3262,($132|0),1,1);
    $137 = __THREW__; __THREW__ = 0;
    $138 = $137&1;
    if ($138) {
     $245 = ___cxa_find_matching_catch_3(0|0)|0;
     $246 = tempRet0;
     ___clang_call_terminate($245);
     // unreachable;
    }
   }
  }
  HEAP32[$131>>2] = 0;
  $$1 = $$0;$$13 = $$02;
  label = 48;
 }
 if ((label|0) == 48) {
  $141 = ((($0)) + 124|0);
  $142 = HEAP32[$141>>2]|0;
  $143 = ($142|0)==(0|0);
  if (!($143)) {
   $144 = HEAP32[$142>>2]|0;
   $145 = ((($144)) + -12|0);
   $146 = HEAP32[$145>>2]|0;
   $147 = (($142) + ($146)|0);
   $148 = ((($147)) + 8|0);
   $149 = HEAP32[$148>>2]|0;HEAP32[$148>>2] = (($149-1)|0);
   $150 = ($149|0)==(1);
   if ($150) {
    __THREW__ = 0;
    invoke_viii(3262,($147|0),1,1);
    $151 = __THREW__; __THREW__ = 0;
    $152 = $151&1;
    if ($152) {
     $245 = ___cxa_find_matching_catch_3(0|0)|0;
     $246 = tempRet0;
     ___clang_call_terminate($245);
     // unreachable;
    }
   }
  }
  HEAP32[$141>>2] = 0;
  $$2 = $$1;$$24 = $$13;
  label = 53;
 }
 if ((label|0) == 53) {
  $155 = ((($0)) + 120|0);
  $156 = HEAP32[$155>>2]|0;
  $157 = ($156|0)==(0|0);
  if (!($157)) {
   $158 = HEAP32[$156>>2]|0;
   $159 = ((($158)) + -12|0);
   $160 = HEAP32[$159>>2]|0;
   $161 = (($156) + ($160)|0);
   $162 = ((($161)) + 8|0);
   $163 = HEAP32[$162>>2]|0;HEAP32[$162>>2] = (($163-1)|0);
   $164 = ($163|0)==(1);
   if ($164) {
    __THREW__ = 0;
    invoke_viii(3262,($161|0),1,1);
    $165 = __THREW__; __THREW__ = 0;
    $166 = $165&1;
    if ($166) {
     $245 = ___cxa_find_matching_catch_3(0|0)|0;
     $246 = tempRet0;
     ___clang_call_terminate($245);
     // unreachable;
    }
   }
  }
  HEAP32[$155>>2] = 0;
  $$3 = $$2;$$35 = $$24;
  label = 58;
 }
 if ((label|0) == 58) {
  $169 = ((($0)) + 116|0);
  $170 = HEAP32[$169>>2]|0;
  $171 = ($170|0)==(0|0);
  if (!($171)) {
   $172 = HEAP32[$170>>2]|0;
   $173 = ((($172)) + -12|0);
   $174 = HEAP32[$173>>2]|0;
   $175 = (($170) + ($174)|0);
   $176 = ((($175)) + 8|0);
   $177 = HEAP32[$176>>2]|0;HEAP32[$176>>2] = (($177-1)|0);
   $178 = ($177|0)==(1);
   if ($178) {
    __THREW__ = 0;
    invoke_viii(3262,($175|0),1,1);
    $179 = __THREW__; __THREW__ = 0;
    $180 = $179&1;
    if ($180) {
     $245 = ___cxa_find_matching_catch_3(0|0)|0;
     $246 = tempRet0;
     ___clang_call_terminate($245);
     // unreachable;
    }
   }
  }
  HEAP32[$169>>2] = 0;
  $$4 = $$3;$$46 = $$35;
  label = 63;
 }
 if ((label|0) == 63) {
  $183 = ((($0)) + 112|0);
  $184 = HEAP32[$183>>2]|0;
  $185 = ($184|0)==(0|0);
  if (!($185)) {
   $186 = HEAP32[$184>>2]|0;
   $187 = ((($186)) + -12|0);
   $188 = HEAP32[$187>>2]|0;
   $189 = (($184) + ($188)|0);
   $190 = ((($189)) + 8|0);
   $191 = HEAP32[$190>>2]|0;HEAP32[$190>>2] = (($191-1)|0);
   $192 = ($191|0)==(1);
   if ($192) {
    __THREW__ = 0;
    invoke_viii(3262,($189|0),1,1);
    $193 = __THREW__; __THREW__ = 0;
    $194 = $193&1;
    if ($194) {
     $245 = ___cxa_find_matching_catch_3(0|0)|0;
     $246 = tempRet0;
     ___clang_call_terminate($245);
     // unreachable;
    }
   }
  }
  HEAP32[$183>>2] = 0;
  $$5 = $$4;$$57 = $$46;
  label = 68;
 }
 if ((label|0) == 68) {
  $197 = ((($0)) + 100|0);
  $198 = ((($0)) + 104|0);
  $199 = HEAP32[$198>>2]|0;
  __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES7_EENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($197,$199);
  $200 = ((($0)) + 88|0);
  $201 = ((($0)) + 92|0);
  $202 = HEAP32[$201>>2]|0;
  __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPvEENS_19__map_value_compareIS7_S9_NS_4lessIS7_EELb1EEENS5_IS9_EEE7destroyEPNS_11__tree_nodeIS9_S8_EE($200,$202);
  $203 = ((($0)) + 84|0);
  $204 = HEAP32[$203>>2]|0;
  $205 = ($204|0)==(0|0);
  if (!($205)) {
   $206 = ((($204)) + 8|0);
   $207 = HEAP32[$206>>2]|0;HEAP32[$206>>2] = (($207-1)|0);
   $208 = ($207|0)==(1);
   if ($208) {
    __THREW__ = 0;
    invoke_viii(3262,($204|0),1,1);
    $209 = __THREW__; __THREW__ = 0;
    $210 = $209&1;
    if ($210) {
     $245 = ___cxa_find_matching_catch_3(0|0)|0;
     $246 = tempRet0;
     ___clang_call_terminate($245);
     // unreachable;
    }
   }
  }
  HEAP32[$203>>2] = 0;
  $$8 = $$5;$$810 = $$57;
  label = 73;
 }
 if ((label|0) == 73) {
  $213 = ((($0)) + 72|0);
  $214 = HEAP32[$213>>2]|0;
  $215 = ($214|0)==(0|0);
  if (!($215)) {
   $216 = ((($214)) + 8|0);
   $217 = HEAP32[$216>>2]|0;HEAP32[$216>>2] = (($217-1)|0);
   $218 = ($217|0)==(1);
   if ($218) {
    __THREW__ = 0;
    invoke_viii(3262,($214|0),1,1);
    $219 = __THREW__; __THREW__ = 0;
    $220 = $219&1;
    if ($220) {
     $245 = ___cxa_find_matching_catch_3(0|0)|0;
     $246 = tempRet0;
     ___clang_call_terminate($245);
     // unreachable;
    }
   }
  }
  HEAP32[$213>>2] = 0;
  $$9 = $$8;$$911 = $$810;
 }
 $221 = ((($0)) + 44|0);
 __ZNSt3__212__deque_baseINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS4_IS6_EEE5clearEv($221);
 $222 = ((($0)) + 48|0);
 $223 = HEAP32[$222>>2]|0;
 $224 = ((($0)) + 52|0);
 $225 = HEAP32[$224>>2]|0;
 $226 = ($223|0)==($225|0);
 if (!($226)) {
  $$08$i37 = $223;
  while(1) {
   $227 = HEAP32[$$08$i37>>2]|0;
   __ZdlPv($227);
   $228 = ((($$08$i37)) + 4|0);
   $229 = ($228|0)==($225|0);
   if ($229) {
    break;
   } else {
    $$08$i37 = $228;
   }
  }
  $$pre$i39 = HEAP32[$222>>2]|0;
  $$pre9$i40 = HEAP32[$224>>2]|0;
  $230 = ($$pre9$i40|0)==($$pre$i39|0);
  if (!($230)) {
   $scevgep$i$i$i$i$i42 = ((($$pre9$i40)) + -4|0);
   $231 = $scevgep$i$i$i$i$i42;
   $232 = $$pre$i39;
   $233 = (($231) - ($232))|0;
   $234 = $233 >>> 2;
   $235 = $234 ^ -1;
   $scevgep5$i$i$i$i$i43 = (($$pre9$i40) + ($235<<2)|0);
   HEAP32[$224>>2] = $scevgep5$i$i$i$i$i43;
  }
 }
 $236 = HEAP32[$221>>2]|0;
 $237 = ($236|0)==(0|0);
 if (!($237)) {
  __ZdlPv($236);
 }
 $238 = ((($0)) + 32|0);
 $239 = ((($238)) + 11|0);
 $240 = HEAP8[$239>>0]|0;
 $241 = ($240<<24>>24)<(0);
 if ($241) {
  $242 = HEAP32[$238>>2]|0;
  __ZdlPv($242);
 }
 __THREW__ = 0;
 invoke_vi(388,($0|0));
 $243 = __THREW__; __THREW__ = 0;
 $244 = $243&1;
 if ($244) {
  $245 = ___cxa_find_matching_catch_3(0|0)|0;
  $246 = tempRet0;
  ___clang_call_terminate($245);
  // unreachable;
 } else {
  ___resumeException($$911|0);
  // unreachable;
 }
}
function __ZN5osgDB7OptionsD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(307,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK5osgDB7Options9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0;
 var sp = 0, stop = 0;
 sp = STACKTOP;
 $1 = (__Znwj(148)|0);
 __THREW__ = 0;
 invoke_vii(3435,($1|0),1);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $17 = ___cxa_find_matching_catch_2()|0;
  $18 = tempRet0;
  __ZdlPv($1);
  ___resumeException($17|0);
  // unreachable;
 } else {
  $4 = ((($1)) + 12|0);
  ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;
  $5 = ((($1)) + 24|0);
  HEAP32[$5>>2] = 2;
  $6 = ((($1)) + 28|0);
  HEAP32[$6>>2] = 0;
  HEAP32[$1>>2] = (37212);
  $7 = ((($1)) + 32|0);
  $8 = ((($1)) + 68|0);
  dest=$7; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
  HEAP32[$8>>2] = 8;
  $9 = ((($1)) + 72|0);
  $10 = ((($1)) + 92|0);
  HEAP32[$10>>2] = 0;
  $11 = ((($1)) + 96|0);
  HEAP32[$11>>2] = 0;
  $12 = ((($1)) + 88|0);
  ;HEAP32[$9>>2]=0|0;HEAP32[$9+4>>2]=0|0;HEAP32[$9+8>>2]=0|0;HEAP32[$9+12>>2]=0|0;
  HEAP32[$12>>2] = $10;
  $13 = ((($1)) + 104|0);
  HEAP32[$13>>2] = 0;
  $14 = ((($1)) + 108|0);
  HEAP32[$14>>2] = 0;
  $15 = ((($1)) + 100|0);
  HEAP32[$15>>2] = $13;
  $16 = ((($1)) + 112|0);
  dest=$16; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
  return ($1|0);
 }
 return (0)|0;
}
function __ZNK5osgDB7Options5cloneERKN3osg6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(148)|0);
 __THREW__ = 0;
 invoke_viii(3436,($2|0),($0|0),($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch_2()|0;
  $6 = tempRet0;
  __ZdlPv($2);
  ___resumeException($5|0);
  // unreachable;
 } else {
  return ($2|0);
 }
 return (0)|0;
}
function __ZNK5osgDB7Options12isSameKindAsEPKN3osg6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,5376,0)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK5osgDB7Options11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (104862|0);
}
function __ZNK5osgDB7Options9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (104854|0);
}
function __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES7_EENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 }
 $3 = HEAP32[$1>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES7_EENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($0,$3);
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES7_EENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($0,$5);
 $6 = ((($1)) + 16|0);
 $7 = ((($1)) + 28|0);
 $8 = ((($7)) + 11|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = ($9<<24>>24)<(0);
 if ($10) {
  $11 = HEAP32[$7>>2]|0;
  __ZdlPv($11);
 }
 $12 = ((($6)) + 11|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = ($13<<24>>24)<(0);
 if ($14) {
  $15 = HEAP32[$6>>2]|0;
  __ZdlPv($15);
 }
 __ZdlPv($1);
 return;
}
function __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPvEENS_19__map_value_compareIS7_S9_NS_4lessIS7_EELb1EEENS5_IS9_EEE7destroyEPNS_11__tree_nodeIS9_S8_EE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 }
 $3 = HEAP32[$1>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPvEENS_19__map_value_compareIS7_S9_NS_4lessIS7_EELb1EEENS5_IS9_EEE7destroyEPNS_11__tree_nodeIS9_S8_EE($0,$3);
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPvEENS_19__map_value_compareIS7_S9_NS_4lessIS7_EELb1EEENS5_IS9_EEE7destroyEPNS_11__tree_nodeIS9_S8_EE($0,$5);
 $6 = ((($1)) + 16|0);
 $7 = ((($6)) + 11|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = ($8<<24>>24)<(0);
 if ($9) {
  $10 = HEAP32[$6>>2]|0;
  __ZdlPv($10);
 }
 __ZdlPv($1);
 return;
}
function __ZNSt3__212__deque_baseINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS4_IS6_EEE5clearEv($0) {
 $0 = $0|0;
 var $$cast = 0, $$in = 0, $$lcssa = 0, $$sink = 0, $$sroa$011$0$ph = 0, $$sroa$6$0 = 0, $$sroa$6$0$ph = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4>>>0) / 341)&-1;
 $6 = (($2) + ($5<<2)|0);
 $7 = ((($0)) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==($2|0);
 if ($9) {
  $10 = ((($0)) + 20|0);
  $24 = 0;$25 = $10;$51 = 0;
 } else {
  $11 = HEAP32[$6>>2]|0;
  $12 = (($4>>>0) % 341)&-1;
  $13 = (($11) + (($12*12)|0)|0);
  $phitmp = $13;
  $14 = ((($0)) + 20|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (($4) + ($15))|0;
  $17 = (($16>>>0) / 341)&-1;
  $18 = (($2) + ($17<<2)|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = (($16>>>0) % 341)&-1;
  $21 = (($19) + (($20*12)|0)|0);
  $24 = $21;$25 = $14;$51 = $phitmp;
 }
 $$sroa$011$0$ph = $6;$$sroa$6$0$ph = $51;
 L5: while(1) {
  $$sroa$6$0 = $$sroa$6$0$ph;
  while(1) {
   $22 = $$sroa$6$0;
   $23 = ($22|0)==($24|0);
   if ($23) {
    break L5;
   }
   $31 = $$sroa$6$0;
   $32 = ((($31)) + 11|0);
   $33 = HEAP8[$32>>0]|0;
   $34 = ($33<<24>>24)<(0);
   if ($34) {
    $35 = HEAP32[$22>>2]|0;
    __ZdlPv($35);
   }
   $36 = ((($22)) + 12|0);
   $37 = $36;
   $38 = HEAP32[$$sroa$011$0$ph>>2]|0;
   $39 = (($37) - ($38))|0;
   $40 = ($39|0)==(4092);
   if ($40) {
    break;
   } else {
    $$sroa$6$0 = $37;
   }
  }
  $41 = ((($$sroa$011$0$ph)) + 4|0);
  $42 = HEAP32[$41>>2]|0;
  $$sroa$011$0$ph = $41;$$sroa$6$0$ph = $42;
 }
 HEAP32[$25>>2] = 0;
 $26 = HEAP32[$7>>2]|0;
 $27 = HEAP32[$1>>2]|0;
 $28 = (($26) - ($27))|0;
 $29 = $28 >> 2;
 $30 = ($29>>>0)>(2);
 if ($30) {
  $$in = $27;
  while(1) {
   $43 = $$in;
   $44 = HEAP32[$43>>2]|0;
   __ZdlPv($44);
   $45 = HEAP32[$1>>2]|0;
   $46 = ((($45)) + 4|0);
   HEAP32[$1>>2] = $46;
   $47 = HEAP32[$7>>2]|0;
   $$cast = $46;
   $48 = (($47) - ($$cast))|0;
   $49 = $48 >> 2;
   $50 = ($49>>>0)>(2);
   if ($50) {
    $$in = $$cast;
   } else {
    $$lcssa = $49;
    break;
   }
  }
 } else {
  $$lcssa = $29;
 }
 switch ($$lcssa|0) {
 case 1:  {
  $$sink = 170;
  break;
 }
 case 2:  {
  $$sink = 341;
  break;
 }
 default: {
  return;
 }
 }
 HEAP32[$3>>2] = $$sink;
 return;
}
function __ZN9osgViewer10ViewerBase17configureAffinityEv($0) {
 $0 = $0|0;
 var $$023$i$i = 0, $$023$i$i87 = 0, $$029 = 0, $$035 = 0, $$1$lcssa = 0, $$1179 = 0, $$12 = 0, $$1247 = 0, $$130 = 0, $$136 = 0, $$14 = 0, $$1449 = 0, $$17 = 0, $$1752 = 0, $$2150 = 0, $$231 = 0, $$237 = 0, $$3$lcssa = 0, $$3174 = 0, $$4 = 0;
 var $$433 = 0, $$439 = 0, $$5 = 0, $$6 = 0, $$641 = 0, $$9 = 0, $$944 = 0, $$byval_copy = 0, $$byval_copy6 = 0, $$byval_copy7 = 0, $$byval_copy8 = 0, $$cast = 0, $$cast151 = 0, $$cast152 = 0, $$pre = 0, $$pre194 = 0, $$pre195 = 0, $$pre196 = 0, $$pre197 = 0, $$pre198 = 0;
 var $$pre199 = 0, $$pre200 = 0, $$sroa$0117$0 = 0, $$sroa$0117$0167 = 0, $$sroa$0117$0168 = 0, $$sroa$0127$0169 = 0, $$sroa$0135$0173 = 0, $$sroa$0143$0178 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0;
 var $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0;
 var $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0;
 var $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0;
 var $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0;
 var $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0;
 var $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0;
 var $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0;
 var $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0;
 var $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0;
 var $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0;
 var $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0;
 var $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0;
 var $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0;
 var $399 = 0, $4 = 0, $40 = 0, $400 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body111$index2Z2D = 0, $eh$lpad$body111$indexZ2D = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i63 = 0, $scevgep$i$i$i66 = 0, $scevgep$i$i$i71 = 0, $scevgep$i$i$i76 = 0, $scevgep$i$i$i79 = 0, $scevgep$i$i$i84 = 0, $scevgep$i$i$i99 = 0, $scevgep5$i$i$i = 0, $scevgep5$i$i$i100 = 0;
 var $scevgep5$i$i$i64 = 0, $scevgep5$i$i$i67 = 0, $scevgep5$i$i$i72 = 0, $scevgep5$i$i$i77 = 0, $scevgep5$i$i$i80 = 0, $scevgep5$i$i$i85 = 0, $storemerge188 = 0, $storemerge53184 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(176|0);
 $$byval_copy8 = sp + 164|0;
 $$byval_copy7 = sp + 160|0;
 $$byval_copy6 = sp + 156|0;
 $$byval_copy = sp + 152|0;
 $1 = sp + 148|0;
 $2 = sp + 144|0;
 $3 = sp + 140|0;
 $4 = sp + 136|0;
 $5 = sp + 132|0;
 $6 = sp + 128|0;
 $7 = sp + 116|0;
 $8 = sp + 112|0;
 $9 = sp + 108|0;
 $10 = sp + 96|0;
 $11 = sp + 84|0;
 $12 = sp + 72|0;
 $13 = sp + 60|0;
 $14 = sp + 48|0;
 $15 = sp + 36|0;
 $16 = sp + 24|0;
 $17 = sp + 12|0;
 $18 = sp;
 $19 = (__ZN11OpenThreads21GetNumberOfProcessorsEv()|0);
 $20 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
 do {
  if ($20) {
   $21 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
   $22 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($21,106069,46)|0);
   $23 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($22,$19)|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = ((($24)) + -12|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = (($23) + ($26)|0);
   __ZNKSt3__28ios_base6getlocEv($6,$27);
   __THREW__ = 0;
   $28 = (invoke_iii(3255,($6|0),(215188|0))|0);
   $29 = __THREW__; __THREW__ = 0;
   $30 = $29&1;
   if (!($30)) {
    $31 = HEAP32[$28>>2]|0;
    $32 = ((($31)) + 28|0);
    $33 = HEAP32[$32>>2]|0;
    __THREW__ = 0;
    $34 = (invoke_iii($33|0,($28|0),10)|0);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if (!($36)) {
     __ZNSt3__26localeD2Ev($6);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($23,$34)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($23)|0);
     break;
    }
   }
   $37 = ___cxa_find_matching_catch_2()|0;
   $38 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($6|0));
   $39 = __THREW__; __THREW__ = 0;
   $40 = $39&1;
   if ($40) {
    $41 = ___cxa_find_matching_catch_3(0|0)|0;
    $42 = tempRet0;
    ___clang_call_terminate($41);
    // unreachable;
   } else {
    ___resumeException($37|0);
    // unreachable;
   }
  }
 } while(0);
 $43 = ($19|0)==(1);
 if ($43) {
  STACKTOP = sp;return;
 }
 HEAP32[$7>>2] = 0;
 $44 = ((($7)) + 4|0);
 HEAP32[$44>>2] = 0;
 $45 = ((($7)) + 8|0);
 HEAP32[$45>>2] = 0;
 HEAP32[$8>>2] = 0;
 $46 = ($19|0)==(0);
 L14: do {
  if ($46) {
   HEAP32[$9>>2] = 1;
   $397 = $9;
   label = 20;
  } else {
   $47 = ((($7)) + 8|0);
   $50 = 0;$52 = 0;$storemerge188 = 0;
   while(1) {
    $51 = ($50|0)==($52|0);
    if ($51) {
     __THREW__ = 0;
     invoke_vii(3437,($7|0),($8|0));
     $54 = __THREW__; __THREW__ = 0;
     $55 = $54&1;
     if ($55) {
      label = 19;
      break;
     }
    } else {
     HEAP32[$50>>2] = $storemerge188;
     $53 = ((($50)) + 4|0);
     HEAP32[$44>>2] = $53;
    }
    $56 = HEAP32[$8>>2]|0;
    $57 = (($56) + 2)|0;
    HEAP32[$8>>2] = $57;
    $58 = ($57>>>0)<($19>>>0);
    if (!($58)) {
     break;
    }
    $$pre = HEAP32[$44>>2]|0;
    $$pre194 = HEAP32[$47>>2]|0;
    $50 = $$pre;$52 = $$pre194;$storemerge188 = $57;
   }
   if ((label|0) == 19) {
    $59 = ___cxa_find_matching_catch_2()|0;
    $60 = tempRet0;
    $$17 = $60;$$1752 = $59;
    break;
   }
   HEAP32[$9>>2] = 1;
   $48 = ($19>>>0)>(1);
   if ($48) {
    $49 = ((($7)) + 8|0);
    $storemerge53184 = 1;
    while(1) {
     $69 = HEAP32[$44>>2]|0;
     $70 = HEAP32[$49>>2]|0;
     $71 = ($69|0)==($70|0);
     if ($71) {
      __THREW__ = 0;
      invoke_vii(3437,($7|0),($9|0));
      $73 = __THREW__; __THREW__ = 0;
      $74 = $73&1;
      if ($74) {
       break;
      }
     } else {
      HEAP32[$69>>2] = $storemerge53184;
      $72 = ((($69)) + 4|0);
      HEAP32[$44>>2] = $72;
     }
     $75 = HEAP32[$9>>2]|0;
     $76 = (($75) + 2)|0;
     HEAP32[$9>>2] = $76;
     $77 = ($76>>>0)<($19>>>0);
     if ($77) {
      $storemerge53184 = $76;
     } else {
      $397 = $9;
      label = 20;
      break L14;
     }
    }
    $78 = ___cxa_find_matching_catch_2()|0;
    $79 = tempRet0;
    $$17 = $79;$$1752 = $78;
   } else {
    $397 = $9;
    label = 20;
   }
  }
 } while(0);
 L35: do {
  if ((label|0) == 20) {
   $61 = HEAP32[$7>>2]|0;
   $62 = HEAP32[$61>>2]|0;
   $63 = ((($10)) + 4|0);
   HEAP32[$63>>2] = 0;
   $64 = ((($10)) + 8|0);
   HEAP32[$64>>2] = 0;
   $65 = ((($10)) + 4|0);
   HEAP32[$10>>2] = $65;
   __THREW__ = 0;
   $66 = (invoke_ii(3276,20)|0);
   $67 = __THREW__; __THREW__ = 0;
   $68 = $67&1;
   L37: do {
    if ($68) {
     $92 = ___cxa_find_matching_catch_2()|0;
     $93 = tempRet0;
     $$029 = $93;$$035 = $92;
    } else {
     $80 = ((($66)) + 16|0);
     HEAP32[$80>>2] = $62;
     HEAP32[$66>>2] = 0;
     $81 = ((($66)) + 4|0);
     HEAP32[$81>>2] = 0;
     $82 = ((($66)) + 8|0);
     HEAP32[$82>>2] = $65;
     HEAP32[$65>>2] = $66;
     $83 = $66;
     HEAP32[$10>>2] = $83;
     $84 = ((($66)) + 12|0);
     HEAP8[$84>>0] = 1;
     HEAP32[$64>>2] = 1;
     $85 = ((($0)) + 16|0);
     $86 = ($10|0)==($85|0);
     do {
      if ($86) {
       $89 = $66;
      } else {
       HEAP32[$4>>2] = $83;
       HEAP32[$5>>2] = $65;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy>>2]=HEAP32[$4>>2]|0;
       ;HEAP32[$$byval_copy6>>2]=HEAP32[$5>>2]|0;
       invoke_viii(3438,($85|0),($$byval_copy|0),($$byval_copy6|0));
       $87 = __THREW__; __THREW__ = 0;
       $88 = $87&1;
       if ($88) {
        $94 = ___cxa_find_matching_catch_2()|0;
        $95 = tempRet0;
        $96 = HEAP32[$65>>2]|0;
        __ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEE7destroyEPNS_11__tree_nodeIjPvEE($10,$96);
        $$029 = $95;$$035 = $94;
        break L37;
       } else {
        $$pre195 = HEAP32[$65>>2]|0;
        $89 = $$pre195;
        break;
       }
      }
     } while(0);
     __ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEE7destroyEPNS_11__tree_nodeIjPvEE($10,$89);
     $90 = ((($0)) + 28|0);
     $91 = HEAP32[$90>>2]|0;
     L46: do {
      switch ($91|0) {
      case 1:  {
       $$2150 = 0;
       label = 55;
       break;
      }
      case 2:  {
       $$2150 = 1;
       label = 55;
       break;
      }
      case 3:  {
       HEAP32[$11>>2] = 0;
       $97 = ((($11)) + 4|0);
       HEAP32[$97>>2] = 0;
       $98 = ((($11)) + 8|0);
       HEAP32[$98>>2] = 0;
       $99 = HEAP32[$0>>2]|0;
       $100 = ((($99)) + 84|0);
       $101 = HEAP32[$100>>2]|0;
       __THREW__ = 0;
       invoke_viii($101|0,($0|0),($11|0),1);
       $102 = __THREW__; __THREW__ = 0;
       $103 = $102&1;
       L49: do {
        if ($103) {
         $119 = ___cxa_find_matching_catch_2()|0;
         $120 = tempRet0;
         $$231 = $120;$$237 = $119;
        } else {
         $104 = HEAP32[$11>>2]|0;
         $105 = HEAP32[$97>>2]|0;
         $106 = ($104|0)==($105|0);
         do {
          if ($106) {
           $$1$lcssa = 0;$110 = $104;$112 = $104;
          } else {
           $107 = ((($12)) + 4|0);
           $108 = ((($12)) + 8|0);
           $109 = ((($12)) + 4|0);
           $$1179 = 0;$$sroa$0143$0178 = $104;
           while(1) {
            $121 = HEAP32[$$sroa$0143$0178>>2]|0;
            $122 = (($$1179) + 1)|0;
            $123 = HEAP32[$44>>2]|0;
            $124 = HEAP32[$7>>2]|0;
            $125 = (($123) - ($124))|0;
            $126 = $125 >> 2;
            $127 = (($$1179>>>0) % ($126>>>0))&-1;
            $$cast152 = $124;
            $128 = (($$cast152) + ($127<<2)|0);
            $129 = HEAP32[$128>>2]|0;
            HEAP32[$107>>2] = 0;
            HEAP32[$108>>2] = 0;
            HEAP32[$12>>2] = $109;
            __THREW__ = 0;
            $130 = (invoke_ii(3276,20)|0);
            $131 = __THREW__; __THREW__ = 0;
            $132 = $131&1;
            if ($132) {
             label = 46;
             break;
            }
            $133 = ((($130)) + 16|0);
            HEAP32[$133>>2] = $129;
            HEAP32[$130>>2] = 0;
            $134 = ((($130)) + 4|0);
            HEAP32[$134>>2] = 0;
            $135 = ((($130)) + 8|0);
            HEAP32[$135>>2] = $109;
            HEAP32[$109>>2] = $130;
            $136 = $130;
            HEAP32[$12>>2] = $136;
            $137 = ((($130)) + 12|0);
            HEAP8[$137>>0] = 1;
            HEAP32[$108>>2] = 1;
            __THREW__ = 0;
            invoke_vii(3439,($121|0),($12|0));
            $138 = __THREW__; __THREW__ = 0;
            $139 = $138&1;
            if ($139) {
             label = 47;
             break;
            }
            $140 = HEAP32[$109>>2]|0;
            __ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEE7destroyEPNS_11__tree_nodeIjPvEE($12,$140);
            $141 = ((($$sroa$0143$0178)) + 4|0);
            $142 = HEAP32[$97>>2]|0;
            $143 = ($141|0)==($142|0);
            if ($143) {
             label = 37;
             break;
            } else {
             $$1179 = $122;$$sroa$0143$0178 = $141;
            }
           }
           if ((label|0) == 37) {
            $$pre196 = HEAP32[$11>>2]|0;
            $$1$lcssa = $122;$110 = $$pre196;$112 = $141;
            break;
           }
           else if ((label|0) == 46) {
            $144 = ___cxa_find_matching_catch_2()|0;
            $145 = tempRet0;
            $$130 = $145;$$136 = $144;
           }
           else if ((label|0) == 47) {
            $146 = ___cxa_find_matching_catch_2()|0;
            $147 = tempRet0;
            $148 = HEAP32[$109>>2]|0;
            __ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEE7destroyEPNS_11__tree_nodeIjPvEE($12,$148);
            $$130 = $147;$$136 = $146;
           }
           $$231 = $$130;$$237 = $$136;
           break L49;
          }
         } while(0);
         $111 = ($110|0)==(0|0);
         if (!($111)) {
          $113 = ($112|0)==($110|0);
          if (!($113)) {
           $scevgep$i$i$i = ((($112)) + -4|0);
           $114 = $scevgep$i$i$i;
           $115 = $110;
           $116 = (($114) - ($115))|0;
           $117 = $116 >>> 2;
           $118 = $117 ^ -1;
           $scevgep5$i$i$i = (($112) + ($118<<2)|0);
           HEAP32[$97>>2] = $scevgep5$i$i$i;
          }
          __ZdlPv($110);
         }
         $$2150 = $$1$lcssa;
         label = 55;
         break L46;
        }
       } while(0);
       $149 = HEAP32[$11>>2]|0;
       $150 = ($149|0)==(0|0);
       if (!($150)) {
        $151 = HEAP32[$97>>2]|0;
        $152 = ($151|0)==($149|0);
        if (!($152)) {
         $scevgep$i$i$i66 = ((($151)) + -4|0);
         $153 = $scevgep$i$i$i66;
         $154 = $149;
         $155 = (($153) - ($154))|0;
         $156 = $155 >>> 2;
         $157 = $156 ^ -1;
         $scevgep5$i$i$i67 = (($151) + ($157<<2)|0);
         HEAP32[$97>>2] = $scevgep5$i$i$i67;
        }
        __ZdlPv($149);
       }
       $$17 = $$231;$$1752 = $$237;
       break L35;
       break;
      }
      default: {
       $$5 = 0;
      }
      }
     } while(0);
     L77: do {
      if ((label|0) == 55) {
       HEAP32[$13>>2] = 0;
       $158 = ((($13)) + 4|0);
       HEAP32[$158>>2] = 0;
       $159 = ((($13)) + 8|0);
       HEAP32[$159>>2] = 0;
       $160 = HEAP32[$0>>2]|0;
       $161 = ((($160)) + 88|0);
       $162 = HEAP32[$161>>2]|0;
       __THREW__ = 0;
       invoke_viii($162|0,($0|0),($13|0),1);
       $163 = __THREW__; __THREW__ = 0;
       $164 = $163&1;
       L79: do {
        if ($164) {
         $180 = ___cxa_find_matching_catch_2()|0;
         $181 = tempRet0;
         $$6 = $181;$$641 = $180;
        } else {
         $165 = HEAP32[$13>>2]|0;
         $166 = HEAP32[$158>>2]|0;
         $167 = ($165|0)==($166|0);
         do {
          if ($167) {
           $$3$lcssa = $$2150;$171 = $165;$173 = $165;
          } else {
           $168 = ((($14)) + 4|0);
           $169 = ((($14)) + 8|0);
           $170 = ((($14)) + 4|0);
           $$3174 = $$2150;$$sroa$0135$0173 = $165;$398 = $166;
           while(1) {
            $182 = HEAP32[$$sroa$0135$0173>>2]|0;
            $183 = ((($182)) + 44|0);
            $184 = HEAP32[$183>>2]|0;
            $185 = ($184|0)==(0|0);
            if ($185) {
             $$4 = $$3174;$214 = $398;
            } else {
             $186 = (($$3174) + 1)|0;
             $187 = HEAP32[$44>>2]|0;
             $188 = HEAP32[$7>>2]|0;
             $189 = (($187) - ($188))|0;
             $190 = $189 >> 2;
             $191 = (($$3174>>>0) % ($190>>>0))&-1;
             $$cast151 = $188;
             $192 = (($$cast151) + ($191<<2)|0);
             $193 = HEAP32[$192>>2]|0;
             HEAP32[$168>>2] = 0;
             HEAP32[$169>>2] = 0;
             HEAP32[$14>>2] = $170;
             __THREW__ = 0;
             $194 = (invoke_ii(3276,20)|0);
             $195 = __THREW__; __THREW__ = 0;
             $196 = $195&1;
             if ($196) {
              label = 70;
              break;
             }
             $197 = ((($194)) + 16|0);
             HEAP32[$197>>2] = $193;
             HEAP32[$194>>2] = 0;
             $198 = ((($194)) + 4|0);
             HEAP32[$198>>2] = 0;
             $199 = ((($194)) + 8|0);
             HEAP32[$199>>2] = $170;
             HEAP32[$170>>2] = $194;
             $200 = $194;
             HEAP32[$14>>2] = $200;
             $201 = ((($194)) + 12|0);
             HEAP8[$201>>0] = 1;
             HEAP32[$169>>2] = 1;
             $202 = ((($184)) + 188|0);
             $203 = ($14|0)==($202|0);
             if ($203) {
              $206 = $194;
             } else {
              HEAP32[$2>>2] = $200;
              HEAP32[$3>>2] = $170;
              __THREW__ = 0;
              ;HEAP32[$$byval_copy7>>2]=HEAP32[$2>>2]|0;
              ;HEAP32[$$byval_copy8>>2]=HEAP32[$3>>2]|0;
              invoke_viii(3438,($202|0),($$byval_copy7|0),($$byval_copy8|0));
              $204 = __THREW__; __THREW__ = 0;
              $205 = $204&1;
              if ($205) {
               label = 71;
               break;
              }
              $$pre197 = HEAP32[$170>>2]|0;
              $206 = $$pre197;
             }
             __ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEE7destroyEPNS_11__tree_nodeIjPvEE($14,$206);
             $$pre198 = HEAP32[$158>>2]|0;
             $$4 = $186;$214 = $$pre198;
            }
            $212 = ((($$sroa$0135$0173)) + 4|0);
            $213 = ($212|0)==($214|0);
            if ($213) {
             label = 58;
             break;
            } else {
             $$3174 = $$4;$$sroa$0135$0173 = $212;$398 = $214;
            }
           }
           if ((label|0) == 58) {
            $$pre199 = HEAP32[$13>>2]|0;
            $$3$lcssa = $$4;$171 = $$pre199;$173 = $214;
            break;
           }
           else if ((label|0) == 70) {
            $207 = ___cxa_find_matching_catch_2()|0;
            $208 = tempRet0;
            $$433 = $208;$$439 = $207;
           }
           else if ((label|0) == 71) {
            $209 = ___cxa_find_matching_catch_2()|0;
            $210 = tempRet0;
            $211 = HEAP32[$170>>2]|0;
            __ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEE7destroyEPNS_11__tree_nodeIjPvEE($14,$211);
            $$433 = $210;$$439 = $209;
           }
           $$6 = $$433;$$641 = $$439;
           break L79;
          }
         } while(0);
         $172 = ($171|0)==(0|0);
         if (!($172)) {
          $174 = ($173|0)==($171|0);
          if (!($174)) {
           $scevgep$i$i$i84 = ((($173)) + -4|0);
           $175 = $scevgep$i$i$i84;
           $176 = $171;
           $177 = (($175) - ($176))|0;
           $178 = $177 >>> 2;
           $179 = $178 ^ -1;
           $scevgep5$i$i$i85 = (($173) + ($179<<2)|0);
           HEAP32[$158>>2] = $scevgep5$i$i$i85;
          }
          __ZdlPv($171);
         }
         $$5 = $$3$lcssa;
         break L77;
        }
       } while(0);
       $215 = HEAP32[$13>>2]|0;
       $216 = ($215|0)==(0|0);
       if (!($216)) {
        $217 = HEAP32[$158>>2]|0;
        $218 = ($217|0)==($215|0);
        if (!($218)) {
         $scevgep$i$i$i99 = ((($217)) + -4|0);
         $219 = $scevgep$i$i$i99;
         $220 = $215;
         $221 = (($219) - ($220))|0;
         $222 = $221 >>> 2;
         $223 = $222 ^ -1;
         $scevgep5$i$i$i100 = (($217) + ($223<<2)|0);
         HEAP32[$158>>2] = $scevgep5$i$i$i100;
        }
        __ZdlPv($215);
       }
       $$17 = $$6;$$1752 = $$641;
       break L35;
      }
     } while(0);
     $224 = ($$5>>>0)<($19>>>0);
     L114: do {
      if ($224) {
       HEAP32[$15>>2] = 0;
       $225 = ((($15)) + 4|0);
       HEAP32[$225>>2] = 0;
       $226 = ((($15)) + 8|0);
       HEAP32[$226>>2] = 0;
       $227 = HEAP32[$0>>2]|0;
       $228 = ((($227)) + 104|0);
       $229 = HEAP32[$228>>2]|0;
       __THREW__ = 0;
       invoke_viii($229|0,($0|0),($15|0),1);
       $230 = __THREW__; __THREW__ = 0;
       $231 = $230&1;
       if ($231) {
        $240 = ___cxa_find_matching_catch_2()|0;
        $241 = tempRet0;
        $$14 = $241;$$1449 = $240;
       } else {
        HEAP32[$16>>2] = $16;
        $232 = ((($16)) + 4|0);
        HEAP32[$232>>2] = $16;
        $233 = ((($16)) + 8|0);
        HEAP32[$233>>2] = 0;
        $234 = HEAP32[$15>>2]|0;
        $235 = HEAP32[$225>>2]|0;
        $236 = ($234|0)==($235|0);
        L119: do {
         if ($236) {
          label = 84;
         } else {
          $$sroa$0127$0169 = $234;$252 = $16;$255 = 0;
          while(1) {
           $242 = HEAP32[$$sroa$0127$0169>>2]|0;
           $243 = ((($242)) + 16|0);
           $244 = HEAP32[$243>>2]|0;
           $245 = ($244|0)==(0|0);
           if ($245) {
            $399 = $255;$400 = $252;
           } else {
            __THREW__ = 0;
            $246 = (invoke_ii(3276,12)|0);
            $247 = __THREW__; __THREW__ = 0;
            $248 = $247&1;
            if ($248) {
             break;
            }
            $249 = $244;
            $250 = ((($246)) + 8|0);
            HEAP32[$250>>2] = $249;
            $251 = ((($246)) + 4|0);
            HEAP32[$251>>2] = $16;
            HEAP32[$246>>2] = $252;
            $253 = ((($252)) + 4|0);
            HEAP32[$253>>2] = $246;
            HEAP32[$16>>2] = $246;
            $254 = (($255) + 1)|0;
            HEAP32[$233>>2] = $254;
            $399 = $254;$400 = $246;
           }
           $256 = ((($$sroa$0127$0169)) + 4|0);
           $257 = ($256|0)==($235|0);
           if ($257) {
            label = 84;
            break L119;
           } else {
            $$sroa$0127$0169 = $256;$252 = $400;$255 = $399;
           }
          }
          $258 = ___cxa_find_matching_catch_2()|0;
          $259 = tempRet0;
          $$12 = $259;$$1247 = $258;
         }
        } while(0);
        L128: do {
         if ((label|0) == 84) {
          __THREW__ = 0;
          $237 = (invoke_ii(3265,3)|0);
          $238 = __THREW__; __THREW__ = 0;
          $239 = $238&1;
          L130: do {
           if ($239) {
            label = 104;
           } else {
            L132: do {
             if ($237) {
              __THREW__ = 0;
              $260 = (invoke_ii(3266,3)|0);
              $261 = __THREW__; __THREW__ = 0;
              $262 = $261&1;
              if ($262) {
               label = 104;
               break L130;
              }
              __THREW__ = 0;
              $263 = (invoke_iiii(3267,($260|0),(106116|0),19)|0);
              $264 = __THREW__; __THREW__ = 0;
              $265 = $264&1;
              if ($265) {
               label = 104;
               break L130;
              }
              $266 = HEAP32[$233>>2]|0;
              __THREW__ = 0;
              $267 = (invoke_iii(3417,($263|0),($266|0))|0);
              $268 = __THREW__; __THREW__ = 0;
              $269 = $268&1;
              if ($269) {
               label = 104;
               break L130;
              }
              $270 = HEAP32[$267>>2]|0;
              $271 = ((($270)) + -12|0);
              $272 = HEAP32[$271>>2]|0;
              $273 = (($267) + ($272)|0);
              __THREW__ = 0;
              invoke_vii(3257,($1|0),($273|0));
              $274 = __THREW__; __THREW__ = 0;
              $275 = $274&1;
              if ($275) {
               label = 104;
               break L130;
              }
              __THREW__ = 0;
              $276 = (invoke_iii(3255,($1|0),(215188|0))|0);
              $277 = __THREW__; __THREW__ = 0;
              $278 = $277&1;
              do {
               if (!($278)) {
                $279 = HEAP32[$276>>2]|0;
                $280 = ((($279)) + 28|0);
                $281 = HEAP32[$280>>2]|0;
                __THREW__ = 0;
                $282 = (invoke_iii($281|0,($276|0),10)|0);
                $283 = __THREW__; __THREW__ = 0;
                $284 = $283&1;
                if ($284) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3263,($1|0));
                $285 = __THREW__; __THREW__ = 0;
                $286 = $285&1;
                if ($286) {
                 label = 104;
                 break L130;
                }
                __THREW__ = 0;
                (invoke_iii(3268,($267|0),($282|0))|0);
                $293 = __THREW__; __THREW__ = 0;
                $294 = $293&1;
                if ($294) {
                 label = 104;
                 break L130;
                }
                __THREW__ = 0;
                (invoke_ii(3269,($267|0))|0);
                $295 = __THREW__; __THREW__ = 0;
                $296 = $295&1;
                if ($296) {
                 label = 104;
                 break L130;
                } else {
                 break L132;
                }
               }
              } while(0);
              $287 = ___cxa_find_matching_catch_2()|0;
              $288 = tempRet0;
              __THREW__ = 0;
              invoke_vi(3263,($1|0));
              $289 = __THREW__; __THREW__ = 0;
              $290 = $289&1;
              if ($290) {
               $291 = ___cxa_find_matching_catch_3(0|0)|0;
               $292 = tempRet0;
               ___clang_call_terminate($291);
               // unreachable;
              } else {
               $eh$lpad$body111$index2Z2D = $288;$eh$lpad$body111$indexZ2D = $287;
               break L130;
              }
             }
            } while(0);
            $299 = HEAP32[$44>>2]|0;
            $300 = HEAP32[$7>>2]|0;
            $301 = (($299) - ($300))|0;
            $302 = $301 >> 2;
            $303 = (($$5>>>0) % ($302>>>0))&-1;
            $$cast = $300;
            $304 = (($$cast) + ($303<<2)|0);
            $305 = HEAP32[$304>>2]|0;
            $306 = ((($17)) + 4|0);
            HEAP32[$306>>2] = 0;
            $307 = ((($17)) + 8|0);
            HEAP32[$307>>2] = 0;
            $308 = ((($17)) + 4|0);
            HEAP32[$17>>2] = $308;
            $$sroa$0117$0167 = HEAP32[$232>>2]|0;
            $309 = $$sroa$0117$0167;
            $310 = ($309|0)==($16|0);
            do {
             if ($310) {
              $333 = 0;
             } else {
              $311 = (($19) - ($305))|0;
              $312 = ((($18)) + 4|0);
              $$sroa$0117$0168 = $$sroa$0117$0167;$325 = $309;
              while(1) {
               $313 = $$sroa$0117$0168;
               $314 = ((($313)) + 8|0);
               $315 = HEAP32[$314>>2]|0;
               $316 = HEAP32[$315>>2]|0;
               $317 = ((($316)) + 36|0);
               $318 = HEAP32[$317>>2]|0;
               __THREW__ = 0;
               invoke_viii(3440,($18|0),($305|0),($311|0));
               $319 = __THREW__; __THREW__ = 0;
               $320 = $319&1;
               if ($320) {
                label = 111;
                break;
               }
               __THREW__ = 0;
               invoke_vii($318|0,($315|0),($18|0));
               $321 = __THREW__; __THREW__ = 0;
               $322 = $321&1;
               if ($322) {
                label = 112;
                break;
               }
               $323 = HEAP32[$312>>2]|0;
               __ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEE7destroyEPNS_11__tree_nodeIjPvEE($18,$323);
               $324 = ((($325)) + 4|0);
               $$sroa$0117$0 = HEAP32[$324>>2]|0;
               $326 = $$sroa$0117$0;
               $327 = ($326|0)==($16|0);
               if ($327) {
                label = 113;
                break;
               } else {
                $$sroa$0117$0168 = $$sroa$0117$0;$325 = $326;
               }
              }
              if ((label|0) == 111) {
               $328 = ___cxa_find_matching_catch_2()|0;
               $329 = tempRet0;
               $$9 = $329;$$944 = $328;
              }
              else if ((label|0) == 112) {
               $330 = ___cxa_find_matching_catch_2()|0;
               $331 = tempRet0;
               $332 = HEAP32[$312>>2]|0;
               __ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEE7destroyEPNS_11__tree_nodeIjPvEE($18,$332);
               $$9 = $331;$$944 = $330;
              }
              else if ((label|0) == 113) {
               $$pre200 = HEAP32[$308>>2]|0;
               $333 = $$pre200;
               break;
              }
              $356 = HEAP32[$308>>2]|0;
              __ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEE7destroyEPNS_11__tree_nodeIjPvEE($17,$356);
              $$12 = $$9;$$1247 = $$944;
              break L128;
             }
            } while(0);
            __ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEE7destroyEPNS_11__tree_nodeIjPvEE($17,$333);
            $334 = HEAP32[$233>>2]|0;
            $335 = ($334|0)==(0);
            if (!($335)) {
             $336 = HEAP32[$232>>2]|0;
             $337 = HEAP32[$16>>2]|0;
             $338 = ((($337)) + 4|0);
             $339 = HEAP32[$338>>2]|0;
             $340 = HEAP32[$336>>2]|0;
             $341 = ((($340)) + 4|0);
             HEAP32[$341>>2] = $339;
             $342 = HEAP32[$338>>2]|0;
             HEAP32[$342>>2] = $340;
             HEAP32[$233>>2] = 0;
             $343 = ($336|0)==($16|0);
             if (!($343)) {
              $$023$i$i87 = $336;
              while(1) {
               $344 = ((($$023$i$i87)) + 4|0);
               $345 = HEAP32[$344>>2]|0;
               __ZdlPv($$023$i$i87);
               $346 = ($345|0)==($16|0);
               if ($346) {
                break;
               } else {
                $$023$i$i87 = $345;
               }
              }
             }
            }
            $347 = HEAP32[$15>>2]|0;
            $348 = ($347|0)==(0|0);
            if (!($348)) {
             $349 = HEAP32[$225>>2]|0;
             $350 = ($349|0)==($347|0);
             if (!($350)) {
              $scevgep$i$i$i79 = ((($349)) + -4|0);
              $351 = $scevgep$i$i$i79;
              $352 = $347;
              $353 = (($351) - ($352))|0;
              $354 = $353 >>> 2;
              $355 = $354 ^ -1;
              $scevgep5$i$i$i80 = (($349) + ($355<<2)|0);
              HEAP32[$225>>2] = $scevgep5$i$i$i80;
             }
             __ZdlPv($347);
            }
            break L114;
           }
          } while(0);
          if ((label|0) == 104) {
           $297 = ___cxa_find_matching_catch_2()|0;
           $298 = tempRet0;
           $eh$lpad$body111$index2Z2D = $298;$eh$lpad$body111$indexZ2D = $297;
          }
          $$12 = $eh$lpad$body111$index2Z2D;$$1247 = $eh$lpad$body111$indexZ2D;
         }
        } while(0);
        $357 = HEAP32[$233>>2]|0;
        $358 = ($357|0)==(0);
        if (!($358)) {
         $359 = HEAP32[$232>>2]|0;
         $360 = HEAP32[$16>>2]|0;
         $361 = ((($360)) + 4|0);
         $362 = HEAP32[$361>>2]|0;
         $363 = HEAP32[$359>>2]|0;
         $364 = ((($363)) + 4|0);
         HEAP32[$364>>2] = $362;
         $365 = HEAP32[$361>>2]|0;
         HEAP32[$365>>2] = $363;
         HEAP32[$233>>2] = 0;
         $366 = ($359|0)==($16|0);
         if (!($366)) {
          $$023$i$i = $359;
          while(1) {
           $367 = ((($$023$i$i)) + 4|0);
           $368 = HEAP32[$367>>2]|0;
           __ZdlPv($$023$i$i);
           $369 = ($368|0)==($16|0);
           if ($369) {
            break;
           } else {
            $$023$i$i = $368;
           }
          }
         }
        }
        $$14 = $$12;$$1449 = $$1247;
       }
       $370 = HEAP32[$15>>2]|0;
       $371 = ($370|0)==(0|0);
       if (!($371)) {
        $372 = HEAP32[$225>>2]|0;
        $373 = ($372|0)==($370|0);
        if (!($373)) {
         $scevgep$i$i$i76 = ((($372)) + -4|0);
         $374 = $scevgep$i$i$i76;
         $375 = $370;
         $376 = (($374) - ($375))|0;
         $377 = $376 >>> 2;
         $378 = $377 ^ -1;
         $scevgep5$i$i$i77 = (($372) + ($378<<2)|0);
         HEAP32[$225>>2] = $scevgep5$i$i$i77;
        }
        __ZdlPv($370);
       }
       $$17 = $$14;$$1752 = $$1449;
       break L35;
      }
     } while(0);
     $379 = HEAP32[$7>>2]|0;
     $380 = ($379|0)==(0|0);
     if (!($380)) {
      $381 = HEAP32[$44>>2]|0;
      $382 = ($381|0)==($379|0);
      if (!($382)) {
       $scevgep$i$i$i71 = ((($381)) + -4|0);
       $383 = $scevgep$i$i$i71;
       $384 = $379;
       $385 = (($383) - ($384))|0;
       $386 = $385 >>> 2;
       $387 = $386 ^ -1;
       $scevgep5$i$i$i72 = (($381) + ($387<<2)|0);
       HEAP32[$44>>2] = $scevgep5$i$i$i72;
      }
      __ZdlPv($379);
     }
     STACKTOP = sp;return;
    }
   } while(0);
   $$17 = $$029;$$1752 = $$035;
  }
 } while(0);
 $388 = HEAP32[$7>>2]|0;
 $389 = ($388|0)==(0|0);
 if ($389) {
  ___resumeException($$1752|0);
  // unreachable;
 }
 $390 = HEAP32[$44>>2]|0;
 $391 = ($390|0)==($388|0);
 if (!($391)) {
  $scevgep$i$i$i63 = ((($390)) + -4|0);
  $392 = $scevgep$i$i$i63;
  $393 = $388;
  $394 = (($392) - ($393))|0;
  $395 = $394 >>> 2;
  $396 = $395 ^ -1;
  $scevgep5$i$i$i64 = (($390) + ($396<<2)|0);
  HEAP32[$44>>2] = $scevgep5$i$i$i64;
 }
 __ZdlPv($388);
 ___resumeException($$1752|0);
 // unreachable;
}
function __ZN9osgViewer10ViewerBase17setThreadingModelENS0_14ThreadingModelE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==($1|0);
 if ($4) {
  return;
 }
 $5 = ((($0)) + 32|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = ($6<<24>>24)==(0);
 if (!($7)) {
  $8 = HEAP32[$0>>2]|0;
  $9 = ((($8)) + 44|0);
  $10 = HEAP32[$9>>2]|0;
  FUNCTION_TABLE_vi[$10 & 8191]($0);
 }
 HEAP32[$2>>2] = $1;
 $11 = HEAP32[$0>>2]|0;
 $12 = ((($11)) + 40|0);
 $13 = HEAP32[$12>>2]|0;
 FUNCTION_TABLE_vi[$13 & 8191]($0);
 return;
}
function __ZN9osgViewer10ViewerBase25suggestBestThreadingModelEv($0) {
 $0 = $0|0;
 var $$ = 0, $$1 = 0, $$114 = 0, $$116 = 0, $$17 = 0, $$2 = 0, $$3 = 0, $$pre = 0, $$pre31 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $9 = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i18 = 0, $scevgep$i$i$i23 = 0;
 var $scevgep$i$i$i26 = 0, $scevgep5$i$i$i = 0, $scevgep5$i$i$i19 = 0, $scevgep5$i$i$i24 = 0, $scevgep5$i$i$i27 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $1 = sp + 12|0;
 $2 = sp;
 $3 = (_getenv((105954|0))|0);
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = (_strcmp($3,105968)|0);
  $6 = ($5|0)==(0);
  if ($6) {
   $$3 = 0;
   STACKTOP = sp;return ($$3|0);
  }
  $7 = (_strcmp($3,105983)|0);
  $8 = ($7|0)==(0);
  if ($8) {
   $$3 = 1;
   STACKTOP = sp;return ($$3|0);
  }
  $9 = (_strcmp($3,106008)|0);
  $10 = ($9|0)==(0);
  if ($10) {
   $$3 = 2;
   STACKTOP = sp;return ($$3|0);
  }
  $11 = (_strcmp($3,106029)|0);
  $12 = ($11|0)==(0);
  if ($12) {
   $$3 = 3;
   STACKTOP = sp;return ($$3|0);
  }
 }
 HEAP32[$1>>2] = 0;
 $13 = ((($1)) + 4|0);
 HEAP32[$13>>2] = 0;
 $14 = ((($1)) + 8|0);
 HEAP32[$14>>2] = 0;
 $15 = HEAP32[$0>>2]|0;
 $16 = ((($15)) + 88|0);
 $17 = HEAP32[$16>>2]|0;
 __THREW__ = 0;
 invoke_viii($17|0,($0|0),($1|0),1);
 $18 = __THREW__; __THREW__ = 0;
 $19 = $18&1;
 L14: do {
  if ($19) {
   $23 = ___cxa_find_matching_catch_2()|0;
   $24 = tempRet0;
   $$114 = $24;$$116 = $23;
  } else {
   $20 = HEAP32[$1>>2]|0;
   $21 = HEAP32[$13>>2]|0;
   $22 = ($20|0)==($21|0);
   L17: do {
    if ($22) {
     $$2 = 0;$71 = $20;
    } else {
     HEAP32[$2>>2] = 0;
     $25 = ((($2)) + 4|0);
     HEAP32[$25>>2] = 0;
     $26 = ((($2)) + 8|0);
     HEAP32[$26>>2] = 0;
     $27 = HEAP32[$0>>2]|0;
     $28 = ((($27)) + 84|0);
     $29 = HEAP32[$28>>2]|0;
     __THREW__ = 0;
     invoke_viii($29|0,($0|0),($2|0),1);
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     L19: do {
      if (!($31)) {
       $32 = HEAP32[$2>>2]|0;
       $33 = HEAP32[$25>>2]|0;
       $34 = ($32|0)==($33|0);
       do {
        if ($34) {
         $$1 = 0;$62 = $32;
        } else {
         __THREW__ = 0;
         $46 = (invoke_i(3441)|0);
         $47 = __THREW__; __THREW__ = 0;
         $48 = $47&1;
         if ($48) {
          break L19;
         }
         $49 = HEAP32[$13>>2]|0;
         $50 = HEAP32[$1>>2]|0;
         $51 = (($49) - ($50))|0;
         $52 = $51 >> 2;
         $53 = ($52|0)==(1);
         if ($53) {
          $54 = ($46|0)==(1);
          $$ = $54 ? 0 : 2;
          $$pre = HEAP32[$2>>2]|0;
          $$1 = $$;$62 = $$pre;
          break;
         } else {
          $55 = HEAP32[$25>>2]|0;
          $56 = HEAP32[$2>>2]|0;
          $57 = (($55) - ($56))|0;
          $58 = $57 >> 2;
          $59 = (($58) + ($52))|0;
          $60 = ($46|0)<($59|0);
          $$17 = $60 ? 2 : 3;
          $61 = $56;
          $$1 = $$17;$62 = $61;
          break;
         }
        }
       } while(0);
       $63 = ($62|0)==(0|0);
       if (!($63)) {
        $64 = HEAP32[$25>>2]|0;
        $65 = ($64|0)==($62|0);
        if (!($65)) {
         $scevgep$i$i$i23 = ((($64)) + -4|0);
         $66 = $scevgep$i$i$i23;
         $67 = $62;
         $68 = (($66) - ($67))|0;
         $69 = $68 >>> 2;
         $70 = $69 ^ -1;
         $scevgep5$i$i$i24 = (($64) + ($70<<2)|0);
         HEAP32[$25>>2] = $scevgep5$i$i$i24;
        }
        __ZdlPv($62);
       }
       $$pre31 = HEAP32[$1>>2]|0;
       $$2 = $$1;$71 = $$pre31;
       break L17;
      }
     } while(0);
     $35 = ___cxa_find_matching_catch_2()|0;
     $36 = tempRet0;
     $37 = HEAP32[$2>>2]|0;
     $38 = ($37|0)==(0|0);
     if (!($38)) {
      $39 = HEAP32[$25>>2]|0;
      $40 = ($39|0)==($37|0);
      if (!($40)) {
       $scevgep$i$i$i26 = ((($39)) + -4|0);
       $41 = $scevgep$i$i$i26;
       $42 = $37;
       $43 = (($41) - ($42))|0;
       $44 = $43 >>> 2;
       $45 = $44 ^ -1;
       $scevgep5$i$i$i27 = (($39) + ($45<<2)|0);
       HEAP32[$25>>2] = $scevgep5$i$i$i27;
      }
      __ZdlPv($37);
     }
     $$114 = $36;$$116 = $35;
     break L14;
    }
   } while(0);
   $72 = ($71|0)==(0|0);
   if (!($72)) {
    $73 = HEAP32[$13>>2]|0;
    $74 = ($73|0)==($71|0);
    if (!($74)) {
     $scevgep$i$i$i18 = ((($73)) + -4|0);
     $75 = $scevgep$i$i$i18;
     $76 = $71;
     $77 = (($75) - ($76))|0;
     $78 = $77 >>> 2;
     $79 = $78 ^ -1;
     $scevgep5$i$i$i19 = (($73) + ($79<<2)|0);
     HEAP32[$13>>2] = $scevgep5$i$i$i19;
    }
    __ZdlPv($71);
   }
   $$3 = $$2;
   STACKTOP = sp;return ($$3|0);
  }
 } while(0);
 $80 = HEAP32[$1>>2]|0;
 $81 = ($80|0)==(0|0);
 if ($81) {
  ___resumeException($$116|0);
  // unreachable;
 }
 $82 = HEAP32[$13>>2]|0;
 $83 = ($82|0)==($80|0);
 if (!($83)) {
  $scevgep$i$i$i = ((($82)) + -4|0);
  $84 = $scevgep$i$i$i;
  $85 = $80;
  $86 = (($84) - ($85))|0;
  $87 = $86 >>> 2;
  $88 = $87 ^ -1;
  $scevgep5$i$i$i = (($82) + ($88<<2)|0);
  HEAP32[$13>>2] = $scevgep5$i$i$i;
 }
 __ZdlPv($80);
 ___resumeException($$116|0);
 // unreachable;
 return (0)|0;
}
function __ZN9osgViewer10ViewerBase14setUpThreadingEv($0) {
 $0 = $0|0;
 var $$2 = 0, $$24 = 0, $$pre = 0, $$sroa$019$026 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i10 = 0;
 var $scevgep$i$i$i13 = 0, $scevgep$i$i$i5 = 0, $scevgep5$i$i$i = 0, $scevgep5$i$i$i11 = 0, $scevgep5$i$i$i14 = 0, $scevgep5$i$i$i6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $1 = sp + 12|0;
 $2 = sp;
 $3 = ((($0)) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(4);
 if ($5) {
  $6 = HEAP32[$0>>2]|0;
  $7 = ((($6)) + 36|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (FUNCTION_TABLE_ii[$8 & 8191]($0)|0);
  HEAP32[$3>>2] = $9;
 }
 $10 = ((($0)) + 14|0);
 $11 = HEAP8[$10>>0]|0;
 $12 = ($11<<24>>24)==(0);
 if (!($12)) {
  $13 = HEAP32[$0>>2]|0;
  $14 = ((($13)) + 24|0);
  $15 = HEAP32[$14>>2]|0;
  FUNCTION_TABLE_vi[$15 & 8191]($0);
 }
 HEAP32[$1>>2] = 0;
 $16 = ((($1)) + 4|0);
 HEAP32[$16>>2] = 0;
 $17 = ((($1)) + 8|0);
 HEAP32[$17>>2] = 0;
 $18 = HEAP32[$0>>2]|0;
 $19 = ((($18)) + 88|0);
 $20 = HEAP32[$19>>2]|0;
 __THREW__ = 0;
 invoke_viii($20|0,($0|0),($1|0),1);
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 L7: do {
  if ($22) {
   label = 14;
  } else {
   $23 = ((($0)) + 16|0);
   __THREW__ = 0;
   (invoke_ii(3442,($23|0))|0);
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   if ($25) {
    label = 14;
   } else {
    HEAP32[$2>>2] = 0;
    $26 = ((($2)) + 4|0);
    HEAP32[$26>>2] = 0;
    $27 = ((($2)) + 8|0);
    HEAP32[$27>>2] = 0;
    $28 = HEAP32[$0>>2]|0;
    $29 = ((($28)) + 104|0);
    $30 = HEAP32[$29>>2]|0;
    __THREW__ = 0;
    invoke_viii($30|0,($0|0),($2|0),1);
    $31 = __THREW__; __THREW__ = 0;
    $32 = $31&1;
    L10: do {
     if (!($32)) {
      $33 = HEAP32[$2>>2]|0;
      $34 = HEAP32[$26>>2]|0;
      $35 = ($33|0)==($34|0);
      if ($35) {
       $36 = $33;$38 = $33;
      } else {
       $$sroa$019$026 = $33;
       while(1) {
        $47 = HEAP32[$$sroa$019$026>>2]|0;
        __THREW__ = 0;
        $48 = (invoke_ii(3279,($47|0))|0);
        $49 = __THREW__; __THREW__ = 0;
        $50 = $49&1;
        if ($50) {
         break L10;
        }
        $51 = ($48|0)==(0|0);
        if (!($51)) {
         $52 = HEAP32[$$sroa$019$026>>2]|0;
         __THREW__ = 0;
         $53 = (invoke_ii(3279,($52|0))|0);
         $54 = __THREW__; __THREW__ = 0;
         $55 = $54&1;
         if ($55) {
          break L10;
         }
         $56 = HEAP32[$53>>2]|0;
         $57 = ((($56)) + 132|0);
         $58 = HEAP32[$57>>2]|0;
         __THREW__ = 0;
         $59 = (invoke_i(3285)|0);
         $60 = __THREW__; __THREW__ = 0;
         $61 = $60&1;
         if ($61) {
          break L10;
         }
         $62 = HEAP32[$59>>2]|0;
         __THREW__ = 0;
         $63 = (invoke_ii(3286,($62|0))|0);
         $64 = __THREW__; __THREW__ = 0;
         $65 = $64&1;
         if ($65) {
          break L10;
         }
         __THREW__ = 0;
         invoke_vii($58|0,($53|0),($63|0));
         $66 = __THREW__; __THREW__ = 0;
         $67 = $66&1;
         if ($67) {
          break L10;
         }
        }
        $68 = ((($$sroa$019$026)) + 4|0);
        $69 = HEAP32[$26>>2]|0;
        $70 = ($68|0)==($69|0);
        if ($70) {
         break;
        } else {
         $$sroa$019$026 = $68;
        }
       }
       $$pre = HEAP32[$2>>2]|0;
       $36 = $$pre;$38 = $68;
      }
      $37 = ($36|0)==(0|0);
      if (!($37)) {
       $39 = ($38|0)==($36|0);
       if (!($39)) {
        $scevgep$i$i$i13 = ((($38)) + -4|0);
        $40 = $scevgep$i$i$i13;
        $41 = $36;
        $42 = (($40) - ($41))|0;
        $43 = $42 >>> 2;
        $44 = $43 ^ -1;
        $scevgep5$i$i$i14 = (($38) + ($44<<2)|0);
        HEAP32[$26>>2] = $scevgep5$i$i$i14;
       }
       __ZdlPv($36);
      }
      $71 = HEAP32[$3>>2]|0;
      $72 = ($71|0)==(0);
      $73 = ((($0)) + 32|0);
      $74 = HEAP8[$73>>0]|0;
      $75 = ($74<<24>>24)!=(0);
      if ($72) {
       if ($75) {
        $76 = HEAP32[$0>>2]|0;
        $77 = ((($76)) + 44|0);
        $78 = HEAP32[$77>>2]|0;
        __THREW__ = 0;
        invoke_vi($78|0,($0|0));
        $79 = __THREW__; __THREW__ = 0;
        $80 = $79&1;
        if ($80) {
         label = 14;
         break L7;
        }
       }
      } else {
       if (!($75)) {
        $92 = HEAP32[$0>>2]|0;
        $93 = ((($92)) + 48|0);
        $94 = HEAP32[$93>>2]|0;
        __THREW__ = 0;
        invoke_vi($94|0,($0|0));
        $95 = __THREW__; __THREW__ = 0;
        $96 = $95&1;
        if ($96) {
         label = 14;
         break L7;
        }
       }
      }
      $97 = HEAP32[$1>>2]|0;
      $98 = ($97|0)==(0|0);
      if ($98) {
       STACKTOP = sp;return;
      }
      $99 = HEAP32[$16>>2]|0;
      $100 = ($99|0)==($97|0);
      if (!($100)) {
       $scevgep$i$i$i5 = ((($99)) + -4|0);
       $101 = $scevgep$i$i$i5;
       $102 = $97;
       $103 = (($101) - ($102))|0;
       $104 = $103 >>> 2;
       $105 = $104 ^ -1;
       $scevgep5$i$i$i6 = (($99) + ($105<<2)|0);
       HEAP32[$16>>2] = $scevgep5$i$i$i6;
      }
      __ZdlPv($97);
      STACKTOP = sp;return;
     }
    } while(0);
    $81 = ___cxa_find_matching_catch_2()|0;
    $82 = tempRet0;
    $83 = HEAP32[$2>>2]|0;
    $84 = ($83|0)==(0|0);
    if (!($84)) {
     $85 = HEAP32[$26>>2]|0;
     $86 = ($85|0)==($83|0);
     if (!($86)) {
      $scevgep$i$i$i10 = ((($85)) + -4|0);
      $87 = $scevgep$i$i$i10;
      $88 = $83;
      $89 = (($87) - ($88))|0;
      $90 = $89 >>> 2;
      $91 = $90 ^ -1;
      $scevgep5$i$i$i11 = (($85) + ($91<<2)|0);
      HEAP32[$26>>2] = $scevgep5$i$i$i11;
     }
     __ZdlPv($83);
    }
    $$2 = $82;$$24 = $81;
   }
  }
 } while(0);
 if ((label|0) == 14) {
  $45 = ___cxa_find_matching_catch_2()|0;
  $46 = tempRet0;
  $$2 = $46;$$24 = $45;
 }
 $106 = HEAP32[$1>>2]|0;
 $107 = ($106|0)==(0|0);
 if ($107) {
  ___resumeException($$24|0);
  // unreachable;
 }
 $108 = HEAP32[$16>>2]|0;
 $109 = ($108|0)==($106|0);
 if (!($109)) {
  $scevgep$i$i$i = ((($108)) + -4|0);
  $110 = $scevgep$i$i$i;
  $111 = $106;
  $112 = (($110) - ($111))|0;
  $113 = $112 >>> 2;
  $114 = $113 ^ -1;
  $scevgep5$i$i$i = (($108) + ($114<<2)|0);
  HEAP32[$16>>2] = $scevgep5$i$i$i;
 }
 __ZdlPv($106);
 ___resumeException($$24|0);
 // unreachable;
}
function __ZN9osgViewer10ViewerBase13stopThreadingEv($0) {
 $0 = $0|0;
 var $$5 = 0, $$528 = 0, $$pre = 0, $$pre100 = 0, $$pre98 = 0, $$pre99 = 0, $$sink81$index = 0, $$sink81$index7 = 0, $$sroa$054$085 = 0, $$sroa$065$094 = 0, $$sroa$070$086 = 0, $$sroa$075$090 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0;
 var $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0;
 var $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0;
 var $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i31 = 0, $scevgep$i$i$i34 = 0, $scevgep$i$i$i39 = 0, $scevgep5$i$i$i = 0, $scevgep5$i$i$i32 = 0, $scevgep5$i$i$i35 = 0, $scevgep5$i$i$i40 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $1 = sp + 28|0;
 $2 = sp + 24|0;
 $3 = sp + 12|0;
 $4 = sp;
 $5 = ((($0)) + 32|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = ($6<<24>>24)==(0);
 if ($7) {
  STACKTOP = sp;return;
 }
 $8 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
 do {
  if ($8) {
   $9 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
   $10 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($9,105860,48)|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = ((($11)) + -12|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($10) + ($13)|0);
   __ZNKSt3__28ios_base6getlocEv($2,$14);
   __THREW__ = 0;
   $15 = (invoke_iii(3255,($2|0),(215188|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = HEAP32[$15>>2]|0;
    $19 = ((($18)) + 28|0);
    $20 = HEAP32[$19>>2]|0;
    __THREW__ = 0;
    $21 = (invoke_iii($20|0,($15|0),10)|0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if (!($23)) {
     __ZNSt3__26localeD2Ev($2);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($10,$21)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($10)|0);
     break;
    }
   }
   $24 = ___cxa_find_matching_catch_2()|0;
   $25 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($2|0));
   $26 = __THREW__; __THREW__ = 0;
   $27 = $26&1;
   if ($27) {
    $28 = ___cxa_find_matching_catch_3(0|0)|0;
    $29 = tempRet0;
    ___clang_call_terminate($28);
    // unreachable;
   } else {
    ___resumeException($24|0);
    // unreachable;
   }
  }
 } while(0);
 HEAP32[$3>>2] = 0;
 $30 = ((($3)) + 4|0);
 HEAP32[$30>>2] = 0;
 $31 = ((($3)) + 8|0);
 HEAP32[$31>>2] = 0;
 $32 = HEAP32[$0>>2]|0;
 $33 = ((($32)) + 88|0);
 $34 = HEAP32[$33>>2]|0;
 __THREW__ = 0;
 invoke_viii($34|0,($0|0),($3|0),1);
 $35 = __THREW__; __THREW__ = 0;
 $36 = $35&1;
 if ($36) {
  $50 = ___cxa_find_matching_catch_2()|0;
  $51 = tempRet0;
  $$5 = $50;$$528 = $51;
 } else {
  HEAP32[$4>>2] = 0;
  $37 = ((($4)) + 4|0);
  HEAP32[$37>>2] = 0;
  $38 = ((($4)) + 8|0);
  HEAP32[$38>>2] = 0;
  $39 = HEAP32[$0>>2]|0;
  $40 = ((($39)) + 84|0);
  $41 = HEAP32[$40>>2]|0;
  __THREW__ = 0;
  invoke_viii($41|0,($0|0),($4|0),1);
  $42 = __THREW__; __THREW__ = 0;
  $43 = $42&1;
  L17: do {
   if ($43) {
    $52 = ___cxa_find_matching_catch_2()|0;
    $53 = tempRet0;
    $$sink81$index = $52;$$sink81$index7 = $53;
   } else {
    $44 = HEAP32[$4>>2]|0;
    $45 = HEAP32[$37>>2]|0;
    $46 = ($44|0)==($45|0);
    L20: do {
     if ($46) {
      $209 = $44;
     } else {
      $$sroa$065$094 = $44;$210 = $45;
      while(1) {
       $54 = HEAP32[$$sroa$065$094>>2]|0;
       $55 = ((($54)) + 628|0);
       $56 = HEAP32[$55>>2]|0;
       $57 = ($56|0)==(0|0);
       if ($57) {
        $66 = $210;
       } else {
        $58 = (___dynamic_cast($56,25048,8160,0)|0);
        $59 = ($58|0)==(0|0);
        if ($59) {
         $66 = $210;
        } else {
         $60 = HEAP32[$58>>2]|0;
         $61 = HEAP32[$60>>2]|0;
         __THREW__ = 0;
         invoke_vi($61|0,($58|0));
         $62 = __THREW__; __THREW__ = 0;
         $63 = $62&1;
         if ($63) {
          break;
         }
         $$pre = HEAP32[$37>>2]|0;
         $66 = $$pre;
        }
       }
       $64 = ((($$sroa$065$094)) + 4|0);
       $65 = ($64|0)==($66|0);
       if ($65) {
        $209 = $66;
        break L20;
       } else {
        $$sroa$065$094 = $64;$210 = $66;
       }
      }
      $67 = ___cxa_find_matching_catch_2()|0;
      $68 = tempRet0;
      $$sink81$index = $67;$$sink81$index7 = $68;
      break L17;
     }
    } while(0);
    $47 = HEAP32[$3>>2]|0;
    $48 = HEAP32[$30>>2]|0;
    $49 = ($47|0)==($48|0);
    do {
     if ($49) {
      $83 = $209;
     } else {
      $$sroa$075$090 = $47;
      while(1) {
       $69 = HEAP32[$$sroa$075$090>>2]|0;
       __THREW__ = 0;
       invoke_vii(3443,($69|0),(0|0));
       $70 = __THREW__; __THREW__ = 0;
       $71 = $70&1;
       if ($71) {
        label = 24;
        break;
       }
       $72 = ((($$sroa$075$090)) + 4|0);
       $73 = HEAP32[$30>>2]|0;
       $74 = ($72|0)==($73|0);
       if ($74) {
        label = 26;
        break;
       } else {
        $$sroa$075$090 = $72;
       }
      }
      if ((label|0) == 24) {
       $77 = ___cxa_find_matching_catch_2()|0;
       $78 = tempRet0;
       $$sink81$index = $77;$$sink81$index7 = $78;
       break L17;
      }
      else if ((label|0) == 26) {
       $$pre98 = HEAP32[$37>>2]|0;
       $83 = $$pre98;
       break;
      }
     }
    } while(0);
    $81 = HEAP32[$4>>2]|0;
    $82 = ($81|0)==($83|0);
    L38: do {
     if (!($82)) {
      $$sroa$070$086 = $81;
      while(1) {
       $84 = HEAP32[$$sroa$070$086>>2]|0;
       __THREW__ = 0;
       invoke_vii(3444,($84|0),(0|0));
       $85 = __THREW__; __THREW__ = 0;
       $86 = $85&1;
       if ($86) {
        label = 23;
        break;
       }
       $87 = ((($$sroa$070$086)) + 4|0);
       $88 = HEAP32[$37>>2]|0;
       $89 = ($87|0)==($88|0);
       if ($89) {
        break;
       } else {
        $$sroa$070$086 = $87;
       }
      }
      if ((label|0) == 23) {
       $75 = ___cxa_find_matching_catch_2()|0;
       $76 = tempRet0;
       $$sink81$index = $75;$$sink81$index7 = $76;
       break L17;
      }
      $$pre99 = HEAP32[$4>>2]|0;
      $90 = ($$pre99|0)==($87|0);
      if (!($90)) {
       $$sroa$054$085 = $$pre99;$211 = $87;
       while(1) {
        $103 = HEAP32[$$sroa$054$085>>2]|0;
        $104 = ((($103)) + 628|0);
        $105 = HEAP32[$104>>2]|0;
        $106 = ($105|0)==(0|0);
        if ($106) {
         $114 = $211;
        } else {
         $107 = (___dynamic_cast($105,25048,8160,0)|0);
         $108 = ($107|0)==(0|0);
         if ($108) {
          $114 = $211;
         } else {
          __THREW__ = 0;
          invoke_vii(3445,($107|0),1);
          $109 = __THREW__; __THREW__ = 0;
          $110 = $109&1;
          if ($110) {
           break;
          }
          $111 = ((($107)) + 28|0);
          HEAP8[$111>>0] = 0;
          $$pre100 = HEAP32[$37>>2]|0;
          $114 = $$pre100;
         }
        }
        $112 = ((($$sroa$054$085)) + 4|0);
        $113 = ($112|0)==($114|0);
        if ($113) {
         break L38;
        } else {
         $$sroa$054$085 = $112;$211 = $114;
        }
       }
       $115 = ___cxa_find_matching_catch_2()|0;
       $116 = tempRet0;
       $$sink81$index = $115;$$sink81$index7 = $116;
       break L17;
      }
     }
    } while(0);
    HEAP8[$5>>0] = 0;
    $91 = ((($0)) + 56|0);
    $92 = HEAP32[$91>>2]|0;
    $93 = ($92|0)==(0|0);
    if ($93) {
     label = 40;
    } else {
     HEAP32[$91>>2] = 0;
     $94 = HEAP32[$92>>2]|0;
     $95 = ((($94)) + -12|0);
     $96 = HEAP32[$95>>2]|0;
     $97 = (($92) + ($96)|0);
     $98 = ((($97)) + 8|0);
     $99 = HEAP32[$98>>2]|0;HEAP32[$98>>2] = (($99-1)|0);
     $100 = ($99|0)==(1);
     if ($100) {
      __THREW__ = 0;
      invoke_viii(3262,($97|0),1,1);
      $101 = __THREW__; __THREW__ = 0;
      $102 = $101&1;
      if (!($102)) {
       label = 40;
      }
     } else {
      label = 40;
     }
    }
    L57: do {
     if ((label|0) == 40) {
      $117 = ((($0)) + 60|0);
      $118 = HEAP32[$117>>2]|0;
      $119 = ($118|0)==(0|0);
      if (!($119)) {
       HEAP32[$117>>2] = 0;
       $120 = HEAP32[$118>>2]|0;
       $121 = ((($120)) + -12|0);
       $122 = HEAP32[$121>>2]|0;
       $123 = (($118) + ($122)|0);
       $124 = ((($123)) + 8|0);
       $125 = HEAP32[$124>>2]|0;HEAP32[$124>>2] = (($125-1)|0);
       $126 = ($125|0)==(1);
       if ($126) {
        __THREW__ = 0;
        invoke_viii(3262,($123|0),1,1);
        $127 = __THREW__; __THREW__ = 0;
        $128 = $127&1;
        if ($128) {
         break;
        }
       }
      }
      $129 = ((($0)) + 64|0);
      $130 = HEAP32[$129>>2]|0;
      $131 = ($130|0)==(0|0);
      if (!($131)) {
       HEAP32[$129>>2] = 0;
       $132 = ((($130)) + 8|0);
       $133 = HEAP32[$132>>2]|0;HEAP32[$132>>2] = (($133-1)|0);
       $134 = ($133|0)==(1);
       if ($134) {
        __THREW__ = 0;
        invoke_viii(3262,($130|0),1,1);
        $135 = __THREW__; __THREW__ = 0;
        $136 = $135&1;
        if ($136) {
         break;
        }
       }
      }
      __THREW__ = 0;
      $137 = (invoke_ii(3265,4)|0);
      $138 = __THREW__; __THREW__ = 0;
      $139 = $138&1;
      if (!($139)) {
       L68: do {
        if ($137) {
         __THREW__ = 0;
         $140 = (invoke_ii(3266,4)|0);
         $141 = __THREW__; __THREW__ = 0;
         $142 = $141&1;
         if ($142) {
          break L57;
         }
         __THREW__ = 0;
         $143 = (invoke_iiii(3267,($140|0),(105909|0),44)|0);
         $144 = __THREW__; __THREW__ = 0;
         $145 = $144&1;
         if ($145) {
          break L57;
         }
         $146 = HEAP32[$143>>2]|0;
         $147 = ((($146)) + -12|0);
         $148 = HEAP32[$147>>2]|0;
         $149 = (($143) + ($148)|0);
         __THREW__ = 0;
         invoke_vii(3257,($1|0),($149|0));
         $150 = __THREW__; __THREW__ = 0;
         $151 = $150&1;
         if ($151) {
          break L57;
         }
         __THREW__ = 0;
         $152 = (invoke_iii(3255,($1|0),(215188|0))|0);
         $153 = __THREW__; __THREW__ = 0;
         $154 = $153&1;
         do {
          if (!($154)) {
           $155 = HEAP32[$152>>2]|0;
           $156 = ((($155)) + 28|0);
           $157 = HEAP32[$156>>2]|0;
           __THREW__ = 0;
           $158 = (invoke_iii($157|0,($152|0),10)|0);
           $159 = __THREW__; __THREW__ = 0;
           $160 = $159&1;
           if ($160) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3263,($1|0));
           $167 = __THREW__; __THREW__ = 0;
           $168 = $167&1;
           if ($168) {
            break L57;
           }
           __THREW__ = 0;
           (invoke_iii(3268,($143|0),($158|0))|0);
           $169 = __THREW__; __THREW__ = 0;
           $170 = $169&1;
           if ($170) {
            break L57;
           }
           __THREW__ = 0;
           (invoke_ii(3269,($143|0))|0);
           $171 = __THREW__; __THREW__ = 0;
           $172 = $171&1;
           if ($172) {
            break L57;
           } else {
            break L68;
           }
          }
         } while(0);
         $161 = ___cxa_find_matching_catch_2()|0;
         $162 = tempRet0;
         __THREW__ = 0;
         invoke_vi(3263,($1|0));
         $163 = __THREW__; __THREW__ = 0;
         $164 = $163&1;
         if ($164) {
          $165 = ___cxa_find_matching_catch_3(0|0)|0;
          $166 = tempRet0;
          ___clang_call_terminate($165);
          // unreachable;
         } else {
          $$sink81$index = $161;$$sink81$index7 = $162;
          break L17;
         }
        }
       } while(0);
       $173 = HEAP32[$4>>2]|0;
       $174 = ($173|0)==(0|0);
       if (!($174)) {
        $175 = HEAP32[$37>>2]|0;
        $176 = ($175|0)==($173|0);
        if (!($176)) {
         $scevgep$i$i$i39 = ((($175)) + -4|0);
         $177 = $scevgep$i$i$i39;
         $178 = $173;
         $179 = (($177) - ($178))|0;
         $180 = $179 >>> 2;
         $181 = $180 ^ -1;
         $scevgep5$i$i$i40 = (($175) + ($181<<2)|0);
         HEAP32[$37>>2] = $scevgep5$i$i$i40;
        }
        __ZdlPv($173);
       }
       $182 = HEAP32[$3>>2]|0;
       $183 = ($182|0)==(0|0);
       if (!($183)) {
        $184 = HEAP32[$30>>2]|0;
        $185 = ($184|0)==($182|0);
        if (!($185)) {
         $scevgep$i$i$i34 = ((($184)) + -4|0);
         $186 = $scevgep$i$i$i34;
         $187 = $182;
         $188 = (($186) - ($187))|0;
         $189 = $188 >>> 2;
         $190 = $189 ^ -1;
         $scevgep5$i$i$i35 = (($184) + ($190<<2)|0);
         HEAP32[$30>>2] = $scevgep5$i$i$i35;
        }
        __ZdlPv($182);
       }
       STACKTOP = sp;return;
      }
     }
    } while(0);
    $79 = ___cxa_find_matching_catch_2()|0;
    $80 = tempRet0;
    $$sink81$index = $79;$$sink81$index7 = $80;
   }
  } while(0);
  $191 = HEAP32[$4>>2]|0;
  $192 = ($191|0)==(0|0);
  if (!($192)) {
   $193 = HEAP32[$37>>2]|0;
   $194 = ($193|0)==($191|0);
   if (!($194)) {
    $scevgep$i$i$i31 = ((($193)) + -4|0);
    $195 = $scevgep$i$i$i31;
    $196 = $191;
    $197 = (($195) - ($196))|0;
    $198 = $197 >>> 2;
    $199 = $198 ^ -1;
    $scevgep5$i$i$i32 = (($193) + ($199<<2)|0);
    HEAP32[$37>>2] = $scevgep5$i$i$i32;
   }
   __ZdlPv($191);
  }
  $$5 = $$sink81$index;$$528 = $$sink81$index7;
 }
 $200 = HEAP32[$3>>2]|0;
 $201 = ($200|0)==(0|0);
 if ($201) {
  ___resumeException($$5|0);
  // unreachable;
 }
 $202 = HEAP32[$30>>2]|0;
 $203 = ($202|0)==($200|0);
 if (!($203)) {
  $scevgep$i$i$i = ((($202)) + -4|0);
  $204 = $scevgep$i$i$i;
  $205 = $200;
  $206 = (($204) - ($205))|0;
  $207 = $206 >>> 2;
  $208 = $207 ^ -1;
  $scevgep5$i$i$i = (($202) + ($208<<2)|0);
  HEAP32[$30>>2] = $scevgep5$i$i$i;
 }
 __ZdlPv($200);
 ___resumeException($$5|0);
 // unreachable;
}
function __ZN9osgViewer10ViewerBase14startThreadingEv($0) {
 $0 = $0|0;
 var $$0101 = 0, $$0102 = 0, $$0103$lcssa = 0, $$0103303 = 0, $$10 = 0, $$1095 = 0, $$1104 = 0, $$13 = 0, $$1398 = 0, $$15 = 0, $$15100 = 0, $$5 = 0, $$590 = 0, $$7283 = 0, $$792281 = 0, $$pr$i = 0, $$pre = 0, $$pre313 = 0, $$pre314 = 0, $$sink108$index = 0;
 var $$sink108$index25 = 0, $$sroa$0233$0294 = 0, $$sroa$0233$1291 = 0, $$sroa$0256$0302 = 0, $$sroa$0261$0298 = 0, $$sroa$0261$1290 = 0, $$sroa$0271$0307 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0;
 var $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0;
 var $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0;
 var $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0;
 var $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0;
 var $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0;
 var $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0;
 var $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0;
 var $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0;
 var $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0;
 var $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0;
 var $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0;
 var $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0;
 var $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0;
 var $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0;
 var $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0;
 var $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0;
 var $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0;
 var $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0;
 var $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0;
 var $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0;
 var $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0;
 var $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0;
 var $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0;
 var $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0;
 var $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0;
 var $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0;
 var $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0;
 var $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0;
 var $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0;
 var $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0;
 var $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0;
 var $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0;
 var $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0;
 var $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0;
 var $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0;
 var $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0;
 var $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0;
 var $831 = 0, $832 = 0, $833 = 0, $834 = 0, $835 = 0, $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0;
 var $85 = 0, $850 = 0, $851 = 0, $852 = 0, $853 = 0, $854 = 0, $855 = 0, $856 = 0, $857 = 0, $858 = 0, $859 = 0, $86 = 0, $860 = 0, $861 = 0, $862 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, $eh$lpad$body120$index7Z2D = 0, $eh$lpad$body120$indexZ2D = 0, $eh$lpad$body132$index12Z2D = 0, $eh$lpad$body132$indexZ2D = 0, $eh$lpad$body159$index17Z2D = 0, $eh$lpad$body159$indexZ2D = 0, $eh$lpad$body197$index38Z2D = 0, $eh$lpad$body197$indexZ2D = 0, $eh$lpad$body209$index33Z2D = 0;
 var $eh$lpad$body209$indexZ2D = 0, $or$cond = 0, $phitmp$i$i = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i165 = 0, $scevgep$i$i$i168 = 0, $scevgep$i$i$i173 = 0, $scevgep$i$i$i178 = 0, $scevgep$i$i$i183 = 0, $scevgep5$i$i$i = 0, $scevgep5$i$i$i166 = 0, $scevgep5$i$i$i169 = 0, $scevgep5$i$i$i174 = 0, $scevgep5$i$i$i179 = 0, $scevgep5$i$i$i184 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(80|0);
 $1 = sp + 64|0;
 $2 = sp + 60|0;
 $3 = sp + 56|0;
 $4 = sp + 52|0;
 $5 = sp + 48|0;
 $6 = sp + 44|0;
 $7 = sp + 40|0;
 $8 = sp + 36|0;
 $9 = sp + 24|0;
 $10 = sp + 12|0;
 $11 = sp;
 $12 = ((($0)) + 32|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = ($13<<24>>24)==(0);
 if (!($14)) {
  STACKTOP = sp;return;
 }
 $15 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
 do {
  if ($15) {
   $16 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
   $17 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($16,105538,45)|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = ((($18)) + -12|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($17) + ($20)|0);
   __ZNKSt3__28ios_base6getlocEv($8,$21);
   __THREW__ = 0;
   $22 = (invoke_iii(3255,($8|0),(215188|0))|0);
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if (!($24)) {
    $25 = HEAP32[$22>>2]|0;
    $26 = ((($25)) + 28|0);
    $27 = HEAP32[$26>>2]|0;
    __THREW__ = 0;
    $28 = (invoke_iii($27|0,($22|0),10)|0);
    $29 = __THREW__; __THREW__ = 0;
    $30 = $29&1;
    if (!($30)) {
     __ZNSt3__26localeD2Ev($8);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($17,$28)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($17)|0);
     break;
    }
   }
   $31 = ___cxa_find_matching_catch_2()|0;
   $32 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($8|0));
   $33 = __THREW__; __THREW__ = 0;
   $34 = $33&1;
   if ($34) {
    $35 = ___cxa_find_matching_catch_3(0|0)|0;
    $36 = tempRet0;
    ___clang_call_terminate($35);
    // unreachable;
   } else {
    ___resumeException($31|0);
    // unreachable;
   }
  }
 } while(0);
 $37 = ((($0)) + 92|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = ($38|0)==(0|0);
 if (!($39)) {
  $40 = ((($38)) + 24|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = ($41|0)==(0|0);
  if (!($42)) {
   $43 = ((($0)) + 96|0);
   $44 = HEAP32[$43>>2]|0;
   $phitmp$i$i = ($44|0)==(0|0);
   if (!($phitmp$i$i)) {
    $45 = HEAP32[$44>>2]|0;
    $46 = ((($45)) + 144|0);
    $47 = HEAP32[$46>>2]|0;
    $48 = (FUNCTION_TABLE_ii[$47 & 8191]($44)|0);
    if ($48) {
     $49 = HEAP32[$43>>2]|0;
     (__ZN3osg15GraphicsContext14releaseContextEv($49)|0);
    }
   }
  }
  $$pr$i = HEAP32[$37>>2]|0;
  $50 = ($$pr$i|0)==(0|0);
  if (!($50)) {
   HEAP32[$37>>2] = 0;
   $51 = ((($$pr$i)) + 8|0);
   $52 = HEAP32[$51>>2]|0;HEAP32[$51>>2] = (($52-1)|0);
   $53 = ($52|0)==(1);
   if ($53) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($$pr$i,1,1);
   }
  }
 }
 $54 = ((($0)) + 96|0);
 HEAP32[$54>>2] = 0;
 HEAP32[$9>>2] = 0;
 $55 = ((($9)) + 4|0);
 HEAP32[$55>>2] = 0;
 $56 = ((($9)) + 8|0);
 HEAP32[$56>>2] = 0;
 $57 = HEAP32[$0>>2]|0;
 $58 = ((($57)) + 88|0);
 $59 = HEAP32[$58>>2]|0;
 __THREW__ = 0;
 invoke_viii($59|0,($0|0),($9|0),1);
 $60 = __THREW__; __THREW__ = 0;
 $61 = $60&1;
 L24: do {
  if ($61) {
   label = 32;
  } else {
   __THREW__ = 0;
   $62 = (invoke_ii(3265,4)|0);
   $63 = __THREW__; __THREW__ = 0;
   $64 = $63&1;
   if ($64) {
    label = 32;
   } else {
    do {
     if ($62) {
      __THREW__ = 0;
      $65 = (invoke_ii(3266,4)|0);
      $66 = __THREW__; __THREW__ = 0;
      $67 = $66&1;
      if ($67) {
       label = 32;
       break L24;
      }
      __THREW__ = 0;
      $68 = (invoke_iiii(3267,($65|0),(105584|0),43)|0);
      $69 = __THREW__; __THREW__ = 0;
      $70 = $69&1;
      if ($70) {
       label = 32;
       break L24;
      }
      $71 = HEAP32[$55>>2]|0;
      $72 = HEAP32[$9>>2]|0;
      $73 = (($71) - ($72))|0;
      $74 = $73 >> 2;
      __THREW__ = 0;
      $75 = (invoke_iii(3417,($68|0),($74|0))|0);
      $76 = __THREW__; __THREW__ = 0;
      $77 = $76&1;
      if ($77) {
       label = 32;
       break L24;
      }
      $78 = HEAP32[$75>>2]|0;
      $79 = ((($78)) + -12|0);
      $80 = HEAP32[$79>>2]|0;
      $81 = (($75) + ($80)|0);
      __THREW__ = 0;
      invoke_vii(3257,($7|0),($81|0));
      $82 = __THREW__; __THREW__ = 0;
      $83 = $82&1;
      if ($83) {
       label = 32;
       break L24;
      }
      __THREW__ = 0;
      $84 = (invoke_iii(3255,($7|0),(215188|0))|0);
      $85 = __THREW__; __THREW__ = 0;
      $86 = $85&1;
      if (!($86)) {
       $87 = HEAP32[$84>>2]|0;
       $88 = ((($87)) + 28|0);
       $89 = HEAP32[$88>>2]|0;
       __THREW__ = 0;
       $90 = (invoke_iii($89|0,($84|0),10)|0);
       $91 = __THREW__; __THREW__ = 0;
       $92 = $91&1;
       if (!($92)) {
        __THREW__ = 0;
        invoke_vi(3263,($7|0));
        $99 = __THREW__; __THREW__ = 0;
        $100 = $99&1;
        if ($100) {
         label = 32;
         break L24;
        }
        __THREW__ = 0;
        (invoke_iii(3268,($75|0),($90|0))|0);
        $101 = __THREW__; __THREW__ = 0;
        $102 = $101&1;
        if ($102) {
         label = 32;
         break L24;
        }
        __THREW__ = 0;
        (invoke_ii(3269,($75|0))|0);
        $103 = __THREW__; __THREW__ = 0;
        $104 = $103&1;
        if ($104) {
         label = 32;
         break L24;
        } else {
         break;
        }
       }
      }
      $93 = ___cxa_find_matching_catch_2()|0;
      $94 = tempRet0;
      __THREW__ = 0;
      invoke_vi(3263,($7|0));
      $95 = __THREW__; __THREW__ = 0;
      $96 = $95&1;
      if ($96) {
       $97 = ___cxa_find_matching_catch_3(0|0)|0;
       $98 = tempRet0;
       ___clang_call_terminate($97);
       // unreachable;
      } else {
       $eh$lpad$body$index2Z2D = $94;$eh$lpad$body$indexZ2D = $93;
       label = 33;
       break L24;
      }
     }
    } while(0);
    HEAP32[$10>>2] = 0;
    $107 = ((($10)) + 4|0);
    HEAP32[$107>>2] = 0;
    $108 = ((($10)) + 8|0);
    HEAP32[$108>>2] = 0;
    $109 = HEAP32[$0>>2]|0;
    $110 = ((($109)) + 84|0);
    $111 = HEAP32[$110>>2]|0;
    __THREW__ = 0;
    invoke_viii($111|0,($0|0),($10|0),1);
    $112 = __THREW__; __THREW__ = 0;
    $113 = $112&1;
    L43: do {
     if ($113) {
      $116 = ___cxa_find_matching_catch_2()|0;
      $117 = tempRet0;
      $$13 = $116;$$1398 = $117;
     } else {
      $114 = ((($0)) + 28|0);
      $115 = HEAP32[$114>>2]|0;
      L46: do {
       switch ($115|0) {
       case 0:  {
        break;
       }
       case 1:  {
        $118 = HEAP32[$55>>2]|0;
        $119 = HEAP32[$9>>2]|0;
        $120 = (($118) - ($119))|0;
        $121 = $120 >> 2;
        $122 = (($121) + 1)|0;
        $$0101 = $122;$$0102 = $122;
        label = 54;
        break;
       }
       case 2:  {
        $$0101 = 1;$$0102 = 1;
        label = 54;
        break;
       }
       case 3:  {
        $123 = HEAP32[$107>>2]|0;
        $124 = HEAP32[$10>>2]|0;
        $125 = (($123) - ($124))|0;
        $126 = $125 >> 2;
        $127 = (($126) + 1)|0;
        $$0101 = $127;$$0102 = 1;
        label = 54;
        break;
       }
       default: {
        __THREW__ = 0;
        $128 = (invoke_ii(3265,3)|0);
        $129 = __THREW__; __THREW__ = 0;
        $130 = $129&1;
        do {
         if ($130) {
          label = 52;
         } else {
          if (!($128)) {
           break L46;
          }
          __THREW__ = 0;
          $131 = (invoke_ii(3266,3)|0);
          $132 = __THREW__; __THREW__ = 0;
          $133 = $132&1;
          if ($133) {
           label = 52;
          } else {
           __THREW__ = 0;
           $134 = (invoke_iiii(3267,($131|0),(105628|0),35)|0);
           $135 = __THREW__; __THREW__ = 0;
           $136 = $135&1;
           if ($136) {
            label = 52;
           } else {
            $137 = HEAP32[$134>>2]|0;
            $138 = ((($137)) + -12|0);
            $139 = HEAP32[$138>>2]|0;
            $140 = (($134) + ($139)|0);
            __THREW__ = 0;
            invoke_vii(3257,($6|0),($140|0));
            $141 = __THREW__; __THREW__ = 0;
            $142 = $141&1;
            if ($142) {
             label = 52;
            } else {
             __THREW__ = 0;
             $143 = (invoke_iii(3255,($6|0),(215188|0))|0);
             $144 = __THREW__; __THREW__ = 0;
             $145 = $144&1;
             if (!($145)) {
              $146 = HEAP32[$143>>2]|0;
              $147 = ((($146)) + 28|0);
              $148 = HEAP32[$147>>2]|0;
              __THREW__ = 0;
              $149 = (invoke_iii($148|0,($143|0),10)|0);
              $150 = __THREW__; __THREW__ = 0;
              $151 = $150&1;
              if (!($151)) {
               __THREW__ = 0;
               invoke_vi(3263,($6|0));
               $158 = __THREW__; __THREW__ = 0;
               $159 = $158&1;
               if ($159) {
                label = 52;
                break;
               }
               __THREW__ = 0;
               (invoke_iii(3268,($134|0),($149|0))|0);
               $160 = __THREW__; __THREW__ = 0;
               $161 = $160&1;
               if ($161) {
                label = 52;
                break;
               }
               __THREW__ = 0;
               (invoke_ii(3269,($134|0))|0);
               $162 = __THREW__; __THREW__ = 0;
               $163 = $162&1;
               if ($163) {
                label = 52;
                break;
               } else {
                break L46;
               }
              }
             }
             $152 = ___cxa_find_matching_catch_2()|0;
             $153 = tempRet0;
             __THREW__ = 0;
             invoke_vi(3263,($6|0));
             $154 = __THREW__; __THREW__ = 0;
             $155 = $154&1;
             if ($155) {
              $156 = ___cxa_find_matching_catch_3(0|0)|0;
              $157 = tempRet0;
              ___clang_call_terminate($156);
              // unreachable;
             } else {
              $eh$lpad$body120$index7Z2D = $153;$eh$lpad$body120$indexZ2D = $152;
              break;
             }
            }
           }
          }
         }
        } while(0);
        if ((label|0) == 52) {
         $164 = ___cxa_find_matching_catch_2()|0;
         $165 = tempRet0;
         $eh$lpad$body120$index7Z2D = $165;$eh$lpad$body120$indexZ2D = $164;
        }
        $$13 = $eh$lpad$body120$indexZ2D;$$1398 = $eh$lpad$body120$index7Z2D;
        break L43;
       }
       }
      } while(0);
      L68: do {
       if ((label|0) == 54) {
        HEAP32[$11>>2] = 0;
        $166 = ((($11)) + 4|0);
        HEAP32[$166>>2] = 0;
        $167 = ((($11)) + 8|0);
        HEAP32[$167>>2] = 0;
        $168 = HEAP32[$0>>2]|0;
        $169 = ((($168)) + 104|0);
        $170 = HEAP32[$169>>2]|0;
        __THREW__ = 0;
        invoke_viii($170|0,($0|0),($11|0),1);
        $171 = __THREW__; __THREW__ = 0;
        $172 = $171&1;
        L70: do {
         if ($172) {
          $182 = ___cxa_find_matching_catch_2()|0;
          $183 = tempRet0;
          $$10 = $182;$$1095 = $183;
         } else {
          $173 = HEAP32[$11>>2]|0;
          $174 = HEAP32[$166>>2]|0;
          $175 = ($173|0)==($174|0);
          L73: do {
           if (!($175)) {
            $$sroa$0271$0307 = $173;
            while(1) {
             $184 = HEAP32[$$sroa$0271$0307>>2]|0;
             __THREW__ = 0;
             $185 = (invoke_ii(3279,($184|0))|0);
             $186 = __THREW__; __THREW__ = 0;
             $187 = $186&1;
             if ($187) {
              label = 74;
              break;
             }
             $188 = ($185|0)==(0|0);
             if (!($188)) {
              __THREW__ = 0;
              $189 = (invoke_ii(3265,4)|0);
              $190 = __THREW__; __THREW__ = 0;
              $191 = $190&1;
              if ($191) {
               label = 74;
               break;
              }
              if ($189) {
               __THREW__ = 0;
               $192 = (invoke_ii(3266,4)|0);
               $193 = __THREW__; __THREW__ = 0;
               $194 = $193&1;
               if ($194) {
                label = 74;
                break;
               }
               __THREW__ = 0;
               $195 = (invoke_iiii(3267,($192|0),(105664|0),24)|0);
               $196 = __THREW__; __THREW__ = 0;
               $197 = $196&1;
               if ($197) {
                label = 74;
                break;
               }
               $198 = HEAP32[$195>>2]|0;
               $199 = ((($198)) + -12|0);
               $200 = HEAP32[$199>>2]|0;
               $201 = (($195) + ($200)|0);
               __THREW__ = 0;
               invoke_vii(3257,($5|0),($201|0));
               $202 = __THREW__; __THREW__ = 0;
               $203 = $202&1;
               if ($203) {
                label = 74;
                break;
               }
               __THREW__ = 0;
               $204 = (invoke_iii(3255,($5|0),(215188|0))|0);
               $205 = __THREW__; __THREW__ = 0;
               $206 = $205&1;
               if ($206) {
                label = 68;
                break;
               }
               $207 = HEAP32[$204>>2]|0;
               $208 = ((($207)) + 28|0);
               $209 = HEAP32[$208>>2]|0;
               __THREW__ = 0;
               $210 = (invoke_iii($209|0,($204|0),10)|0);
               $211 = __THREW__; __THREW__ = 0;
               $212 = $211&1;
               if ($212) {
                label = 68;
                break;
               }
               __THREW__ = 0;
               invoke_vi(3263,($5|0));
               $219 = __THREW__; __THREW__ = 0;
               $220 = $219&1;
               if ($220) {
                label = 74;
                break;
               }
               __THREW__ = 0;
               (invoke_iii(3268,($195|0),($210|0))|0);
               $221 = __THREW__; __THREW__ = 0;
               $222 = $221&1;
               if ($222) {
                label = 74;
                break;
               }
               __THREW__ = 0;
               (invoke_ii(3269,($195|0))|0);
               $223 = __THREW__; __THREW__ = 0;
               $224 = $223&1;
               if ($224) {
                label = 74;
                break;
               }
              }
              $227 = HEAP32[$$sroa$0271$0307>>2]|0;
              __THREW__ = 0;
              $228 = (invoke_ii(3279,($227|0))|0);
              $229 = __THREW__; __THREW__ = 0;
              $230 = $229&1;
              if ($230) {
               label = 74;
               break;
              }
              $231 = HEAP32[$228>>2]|0;
              $232 = HEAP32[$231>>2]|0;
              __THREW__ = 0;
              invoke_vii($232|0,($228|0),1);
              $233 = __THREW__; __THREW__ = 0;
              $234 = $233&1;
              if ($234) {
               label = 74;
               break;
              }
              $235 = HEAP32[$$sroa$0271$0307>>2]|0;
              __THREW__ = 0;
              $236 = (invoke_ii(3279,($235|0))|0);
              $237 = __THREW__; __THREW__ = 0;
              $238 = $237&1;
              if ($238) {
               label = 74;
               break;
              }
              $239 = HEAP32[$236>>2]|0;
              $240 = ((($239)) + 132|0);
              $241 = HEAP32[$240>>2]|0;
              __THREW__ = 0;
              $242 = (invoke_i(3285)|0);
              $243 = __THREW__; __THREW__ = 0;
              $244 = $243&1;
              if ($244) {
               label = 74;
               break;
              }
              $245 = HEAP32[$242>>2]|0;
              __THREW__ = 0;
              $246 = (invoke_ii(3286,($245|0))|0);
              $247 = __THREW__; __THREW__ = 0;
              $248 = $247&1;
              if ($248) {
               label = 74;
               break;
              }
              __THREW__ = 0;
              invoke_vii($241|0,($236|0),($246|0));
              $249 = __THREW__; __THREW__ = 0;
              $250 = $249&1;
              if ($250) {
               label = 74;
               break;
              }
             }
             $251 = ((($$sroa$0271$0307)) + 4|0);
             $252 = HEAP32[$166>>2]|0;
             $253 = ($251|0)==($252|0);
             if ($253) {
              break L73;
             } else {
              $$sroa$0271$0307 = $251;
             }
            }
            do {
             if ((label|0) == 68) {
              $213 = ___cxa_find_matching_catch_2()|0;
              $214 = tempRet0;
              __THREW__ = 0;
              invoke_vi(3263,($5|0));
              $215 = __THREW__; __THREW__ = 0;
              $216 = $215&1;
              if ($216) {
               $217 = ___cxa_find_matching_catch_3(0|0)|0;
               $218 = tempRet0;
               ___clang_call_terminate($217);
               // unreachable;
              } else {
               $eh$lpad$body132$index12Z2D = $214;$eh$lpad$body132$indexZ2D = $213;
               break;
              }
             }
             else if ((label|0) == 74) {
              $225 = ___cxa_find_matching_catch_2()|0;
              $226 = tempRet0;
              $eh$lpad$body132$index12Z2D = $226;$eh$lpad$body132$indexZ2D = $225;
             }
            } while(0);
            $$10 = $eh$lpad$body132$indexZ2D;$$1095 = $eh$lpad$body132$index12Z2D;
            break L70;
           }
          } while(0);
          $176 = HEAP32[$114>>2]|0;
          $177 = $176 | 1;
          $178 = ($177|0)==(1);
          $179 = HEAP32[$10>>2]|0;
          $180 = HEAP32[$107>>2]|0;
          $181 = ($179|0)==($180|0);
          do {
           if ($181) {
            $$0103$lcssa = 0;$254 = $176;
           } else {
            $$0103303 = 0;$$sroa$0256$0302 = $179;$861 = $180;
            while(1) {
             $255 = HEAP32[$$sroa$0256$0302>>2]|0;
             $256 = ((($255)) + 628|0);
             $257 = HEAP32[$256>>2]|0;
             $258 = ($257|0)==(0|0);
             if ($258) {
              $$1104 = $$0103303;$272 = $861;
             } else {
              $259 = (___dynamic_cast($257,25048,8160,0)|0);
              $260 = ($259|0)==(0|0);
              if ($260) {
               $$1104 = $$0103303;$272 = $861;
              } else {
               __THREW__ = 0;
               invoke_vii(3445,($259|0),($178|0));
               $261 = __THREW__; __THREW__ = 0;
               $262 = $261&1;
               if ($262) {
                label = 91;
                break;
               }
               $263 = ((($259)) + 28|0);
               HEAP8[$263>>0] = 0;
               $264 = HEAP32[$259>>2]|0;
               $265 = ((($264)) + 36|0);
               $266 = HEAP32[$265>>2]|0;
               __THREW__ = 0;
               invoke_vi($266|0,($259|0));
               $267 = __THREW__; __THREW__ = 0;
               $268 = $267&1;
               if ($268) {
                label = 91;
                break;
               }
               $269 = (($$0103303) + 1)|0;
               $$pre = HEAP32[$107>>2]|0;
               $$1104 = $269;$272 = $$pre;
              }
             }
             $270 = ((($$sroa$0256$0302)) + 4|0);
             $271 = ($270|0)==($272|0);
             if ($271) {
              label = 83;
              break;
             } else {
              $$0103303 = $$1104;$$sroa$0256$0302 = $270;$861 = $272;
             }
            }
            if ((label|0) == 83) {
             $$pre313 = HEAP32[$114>>2]|0;
             $$0103$lcssa = $$1104;$254 = $$pre313;
             break;
            }
            else if ((label|0) == 91) {
             $273 = ___cxa_find_matching_catch_2()|0;
             $274 = tempRet0;
             $$10 = $273;$$1095 = $274;
             break L70;
            }
           }
          } while(0);
          L118: do {
           switch ($254|0) {
           case 1:  {
            $275 = ((($0)) + 56|0);
            $276 = HEAP32[$275>>2]|0;
            $277 = ($276|0)==(0|0);
            if (!($277)) {
             HEAP32[$275>>2] = 0;
             $278 = HEAP32[$276>>2]|0;
             $279 = ((($278)) + -12|0);
             $280 = HEAP32[$279>>2]|0;
             $281 = (($276) + ($280)|0);
             $282 = ((($281)) + 8|0);
             $283 = HEAP32[$282>>2]|0;HEAP32[$282>>2] = (($283-1)|0);
             $284 = ($283|0)==(1);
             if ($284) {
              __THREW__ = 0;
              invoke_viii(3262,($281|0),1,1);
              $285 = __THREW__; __THREW__ = 0;
              $286 = $285&1;
              if ($286) {
               break L118;
              }
             }
            }
            $287 = ((($0)) + 60|0);
            $288 = HEAP32[$287>>2]|0;
            $289 = ($288|0)==(0|0);
            if (!($289)) {
             HEAP32[$287>>2] = 0;
             $290 = HEAP32[$288>>2]|0;
             $291 = ((($290)) + -12|0);
             $292 = HEAP32[$291>>2]|0;
             $293 = (($288) + ($292)|0);
             $294 = ((($293)) + 8|0);
             $295 = HEAP32[$294>>2]|0;HEAP32[$294>>2] = (($295-1)|0);
             $296 = ($295|0)==(1);
             if ($296) {
              __THREW__ = 0;
              invoke_viii(3262,($293|0),1,1);
              $297 = __THREW__; __THREW__ = 0;
              $298 = $297&1;
              if ($298) {
               break L118;
              }
             }
            }
            $299 = ((($0)) + 64|0);
            $300 = HEAP32[$299>>2]|0;
            $301 = ($300|0)==(0|0);
            if ($301) {
             label = 115;
            } else {
             HEAP32[$299>>2] = 0;
             $302 = ((($300)) + 8|0);
             $303 = HEAP32[$302>>2]|0;HEAP32[$302>>2] = (($303-1)|0);
             $304 = ($303|0)==(1);
             if ($304) {
              __THREW__ = 0;
              invoke_viii(3262,($300|0),1,1);
              $305 = __THREW__; __THREW__ = 0;
              $306 = $305&1;
              if (!($306)) {
               label = 115;
              }
             } else {
              label = 115;
             }
            }
            break;
           }
           case 3: case 2:  {
            $309 = ((($0)) + 56|0);
            $310 = HEAP32[$309>>2]|0;
            $311 = ($310|0)==(0|0);
            if (!($311)) {
             HEAP32[$309>>2] = 0;
             $312 = HEAP32[$310>>2]|0;
             $313 = ((($312)) + -12|0);
             $314 = HEAP32[$313>>2]|0;
             $315 = (($310) + ($314)|0);
             $316 = ((($315)) + 8|0);
             $317 = HEAP32[$316>>2]|0;HEAP32[$316>>2] = (($317-1)|0);
             $318 = ($317|0)==(1);
             if ($318) {
              __THREW__ = 0;
              invoke_viii(3262,($315|0),1,1);
              $319 = __THREW__; __THREW__ = 0;
              $320 = $319&1;
              if ($320) {
               break L118;
              }
             }
            }
            $321 = ((($0)) + 60|0);
            $322 = HEAP32[$321>>2]|0;
            $323 = ($322|0)==(0|0);
            if (!($323)) {
             HEAP32[$321>>2] = 0;
             $324 = HEAP32[$322>>2]|0;
             $325 = ((($324)) + -12|0);
             $326 = HEAP32[$325>>2]|0;
             $327 = (($322) + ($326)|0);
             $328 = ((($327)) + 8|0);
             $329 = HEAP32[$328>>2]|0;HEAP32[$328>>2] = (($329-1)|0);
             $330 = ($329|0)==(1);
             if ($330) {
              __THREW__ = 0;
              invoke_viii(3262,($327|0),1,1);
              $331 = __THREW__; __THREW__ = 0;
              $332 = $331&1;
              if ($332) {
               break L118;
              }
             }
            }
            __THREW__ = 0;
            $333 = (invoke_ii(3276,40)|0);
            $334 = __THREW__; __THREW__ = 0;
            $335 = $334&1;
            if (!($335)) {
             __THREW__ = 0;
             invoke_vii(3446,($333|0),($$0103$lcssa|0));
             $336 = __THREW__; __THREW__ = 0;
             $337 = $336&1;
             if ($337) {
              $349 = ___cxa_find_matching_catch_2()|0;
              $350 = tempRet0;
              __ZdlPv($333);
              $$10 = $349;$$1095 = $350;
              break L70;
             }
             $338 = ((($0)) + 64|0);
             $339 = HEAP32[$338>>2]|0;
             $340 = ($339|0)==($333|0);
             if ($340) {
              label = 115;
             } else {
              HEAP32[$338>>2] = $333;
              $341 = ((($333)) + 8|0);
              $342 = HEAP32[$341>>2]|0;HEAP32[$341>>2] = (($342+1)|0);
              $343 = ($339|0)==(0|0);
              if ($343) {
               label = 115;
               break L118;
              }
              $344 = ((($339)) + 8|0);
              $345 = HEAP32[$344>>2]|0;HEAP32[$344>>2] = (($345-1)|0);
              $346 = ($345|0)==(1);
              if (!($346)) {
               label = 115;
               break L118;
              }
              __THREW__ = 0;
              invoke_viii(3262,($339|0),1,1);
              $347 = __THREW__; __THREW__ = 0;
              $348 = $347&1;
              if (!($348)) {
               label = 115;
              }
             }
            }
            break;
           }
           default: {
            label = 115;
           }
           }
          } while(0);
          L146: do {
           if ((label|0) == 115) {
            $351 = ($$0101>>>0)>(1);
            do {
             if ($351) {
              __THREW__ = 0;
              $352 = (invoke_ii(3276,48)|0);
              $353 = __THREW__; __THREW__ = 0;
              $354 = $353&1;
              if ($354) {
               break L146;
              }
              __THREW__ = 0;
              invoke_viiii(3447,($352|0),($$0101|0),0,1);
              $355 = __THREW__; __THREW__ = 0;
              $356 = $355&1;
              if ($356) {
               $376 = ___cxa_find_matching_catch_2()|0;
               $377 = tempRet0;
               __ZdlPv($352);
               $$10 = $376;$$1095 = $377;
               break L70;
              }
              $357 = ((($0)) + 56|0);
              $358 = HEAP32[$357>>2]|0;
              $359 = ($358|0)==($352|0);
              if (!($359)) {
               HEAP32[$357>>2] = $352;
               $360 = HEAP32[$352>>2]|0;
               $361 = ((($360)) + -12|0);
               $362 = HEAP32[$361>>2]|0;
               $363 = (($352) + ($362)|0);
               $364 = ((($363)) + 8|0);
               $365 = HEAP32[$364>>2]|0;HEAP32[$364>>2] = (($365+1)|0);
               $366 = ($358|0)==(0|0);
               if ($366) {
                break;
               }
               $367 = HEAP32[$358>>2]|0;
               $368 = ((($367)) + -12|0);
               $369 = HEAP32[$368>>2]|0;
               $370 = (($358) + ($369)|0);
               $371 = ((($370)) + 8|0);
               $372 = HEAP32[$371>>2]|0;HEAP32[$371>>2] = (($372-1)|0);
               $373 = ($372|0)==(1);
               if (!($373)) {
                break;
               }
               __THREW__ = 0;
               invoke_viii(3262,($370|0),1,1);
               $374 = __THREW__; __THREW__ = 0;
               $375 = $374&1;
               if ($375) {
                break L146;
               }
              }
             }
            } while(0);
            $378 = ($$0102>>>0)>(1);
            do {
             if ($378) {
              __THREW__ = 0;
              $379 = (invoke_ii(3276,48)|0);
              $380 = __THREW__; __THREW__ = 0;
              $381 = $380&1;
              if ($381) {
               break L146;
              }
              $382 = ((($0)) + 52|0);
              $383 = HEAP32[$382>>2]|0;
              __THREW__ = 0;
              invoke_viiii(3447,($379|0),($$0102|0),($383|0),1);
              $384 = __THREW__; __THREW__ = 0;
              $385 = $384&1;
              if ($385) {
               $405 = ___cxa_find_matching_catch_2()|0;
               $406 = tempRet0;
               __ZdlPv($379);
               $$10 = $405;$$1095 = $406;
               break L70;
              }
              $386 = ((($0)) + 60|0);
              $387 = HEAP32[$386>>2]|0;
              $388 = ($387|0)==($379|0);
              if ($388) {
               break;
              }
              HEAP32[$386>>2] = $379;
              $389 = HEAP32[$379>>2]|0;
              $390 = ((($389)) + -12|0);
              $391 = HEAP32[$390>>2]|0;
              $392 = (($379) + ($391)|0);
              $393 = ((($392)) + 8|0);
              $394 = HEAP32[$393>>2]|0;HEAP32[$393>>2] = (($394+1)|0);
              $395 = ($387|0)==(0|0);
              if ($395) {
               break;
              }
              $396 = HEAP32[$387>>2]|0;
              $397 = ((($396)) + -12|0);
              $398 = HEAP32[$397>>2]|0;
              $399 = (($387) + ($398)|0);
              $400 = ((($399)) + 8|0);
              $401 = HEAP32[$400>>2]|0;HEAP32[$400>>2] = (($401-1)|0);
              $402 = ($401|0)==(1);
              if (!($402)) {
               break;
              }
              __THREW__ = 0;
              invoke_viii(3262,($399|0),1,1);
              $403 = __THREW__; __THREW__ = 0;
              $404 = $403&1;
              if ($404) {
               break L146;
              }
             }
            } while(0);
            $407 = HEAP32[$9>>2]|0;
            $408 = HEAP32[$55>>2]|0;
            $409 = ($407|0)==($408|0);
            $410 = $408;
            $411 = $407;
            do {
             if ($409) {
              $443 = 0;$777 = 0;$862 = 1;
             } else {
              __THREW__ = 0;
              $412 = (invoke_ii(3276,48)|0);
              $413 = __THREW__; __THREW__ = 0;
              $414 = $413&1;
              if ($414) {
               break L146;
              }
              $415 = (($410) - ($411))|0;
              $416 = $415 >> 2;
              __THREW__ = 0;
              invoke_viiii(3447,($412|0),($416|0),0,1);
              $417 = __THREW__; __THREW__ = 0;
              $418 = $417&1;
              if ($418) {
               $491 = ___cxa_find_matching_catch_2()|0;
               $492 = tempRet0;
               __ZdlPv($412);
               $$10 = $491;$$1095 = $492;
               break L70;
              } else {
               $419 = HEAP32[$412>>2]|0;
               $420 = ((($419)) + -12|0);
               $421 = HEAP32[$420>>2]|0;
               $422 = (($412) + ($421)|0);
               $423 = ((($422)) + 8|0);
               $424 = HEAP32[$423>>2]|0;HEAP32[$423>>2] = (($424+1)|0);
               $443 = $412;$777 = $412;$862 = 0;
               break;
              }
             }
            } while(0);
            __THREW__ = 0;
            $425 = (invoke_ii(3276,32)|0);
            $426 = __THREW__; __THREW__ = 0;
            $427 = $426&1;
            L175: do {
             if ($427) {
              $493 = ___cxa_find_matching_catch_2()|0;
              $494 = tempRet0;
              if ($862) {
               $$10 = $493;$$1095 = $494;
               break L70;
              } else {
               $$7283 = $493;$$792281 = $494;
              }
             } else {
              __THREW__ = 0;
              invoke_vi(3448,($425|0));
              $428 = __THREW__; __THREW__ = 0;
              $429 = $428&1;
              if ($429) {
               $495 = ___cxa_find_matching_catch_2()|0;
               $496 = tempRet0;
               __ZdlPv($425);
               if ($862) {
                $$10 = $495;$$1095 = $496;
                break L70;
               } else {
                $$7283 = $495;$$792281 = $496;
                break;
               }
              }
              $430 = HEAP32[$425>>2]|0;
              $431 = ((($430)) + -12|0);
              $432 = HEAP32[$431>>2]|0;
              $433 = (($425) + ($432)|0);
              $434 = ((($433)) + 8|0);
              $435 = HEAP32[$434>>2]|0;HEAP32[$434>>2] = (($435+1)|0);
              $436 = HEAP32[$9>>2]|0;
              $437 = HEAP32[$55>>2]|0;
              $438 = ($436|0)==($437|0);
              L181: do {
               if ($438) {
                label = 187;
               } else {
                $439 = ((($0)) + 64|0);
                $440 = ((($0)) + 56|0);
                $441 = ((($0)) + 48|0);
                $442 = ((($0)) + 60|0);
                $444 = ($443|0)==(0|0);
                $$sroa$0261$0298 = $436;
                L183: while(1) {
                 $445 = HEAP32[$$sroa$0261$0298>>2]|0;
                 $446 = HEAP32[$445>>2]|0;
                 $447 = ((($446)) + 156|0);
                 $448 = HEAP32[$447>>2]|0;
                 __THREW__ = 0;
                 $449 = (invoke_ii($448|0,($445|0))|0);
                 $450 = __THREW__; __THREW__ = 0;
                 $451 = $450&1;
                 if ($451) {
                  label = 158;
                  break;
                 }
                 if (!($449)) {
                  __THREW__ = 0;
                  $452 = (invoke_ii(3265,4)|0);
                  $453 = __THREW__; __THREW__ = 0;
                  $454 = $453&1;
                  if ($454) {
                   label = 158;
                   break;
                  }
                  if ($452) {
                   __THREW__ = 0;
                   $455 = (invoke_ii(3266,4)|0);
                   $456 = __THREW__; __THREW__ = 0;
                   $457 = $456&1;
                   if ($457) {
                    label = 158;
                    break;
                   }
                   __THREW__ = 0;
                   $458 = (invoke_iiii(3267,($455|0),(105689|0),47)|0);
                   $459 = __THREW__; __THREW__ = 0;
                   $460 = $459&1;
                   if ($460) {
                    label = 158;
                    break;
                   }
                   __THREW__ = 0;
                   $461 = (invoke_iii(3275,($458|0),($445|0))|0);
                   $462 = __THREW__; __THREW__ = 0;
                   $463 = $462&1;
                   if ($463) {
                    label = 158;
                    break;
                   }
                   $464 = HEAP32[$461>>2]|0;
                   $465 = ((($464)) + -12|0);
                   $466 = HEAP32[$465>>2]|0;
                   $467 = (($461) + ($466)|0);
                   __THREW__ = 0;
                   invoke_vii(3257,($4|0),($467|0));
                   $468 = __THREW__; __THREW__ = 0;
                   $469 = $468&1;
                   if ($469) {
                    label = 158;
                    break;
                   }
                   __THREW__ = 0;
                   $470 = (invoke_iii(3255,($4|0),(215188|0))|0);
                   $471 = __THREW__; __THREW__ = 0;
                   $472 = $471&1;
                   if ($472) {
                    label = 149;
                    break;
                   }
                   $473 = HEAP32[$470>>2]|0;
                   $474 = ((($473)) + 28|0);
                   $475 = HEAP32[$474>>2]|0;
                   __THREW__ = 0;
                   $476 = (invoke_iii($475|0,($470|0),10)|0);
                   $477 = __THREW__; __THREW__ = 0;
                   $478 = $477&1;
                   if ($478) {
                    label = 149;
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3263,($4|0));
                   $485 = __THREW__; __THREW__ = 0;
                   $486 = $485&1;
                   if ($486) {
                    label = 158;
                    break;
                   }
                   __THREW__ = 0;
                   (invoke_iii(3268,($461|0),($476|0))|0);
                   $487 = __THREW__; __THREW__ = 0;
                   $488 = $487&1;
                   if ($488) {
                    label = 158;
                    break;
                   }
                   __THREW__ = 0;
                   (invoke_ii(3269,($461|0))|0);
                   $489 = __THREW__; __THREW__ = 0;
                   $490 = $489&1;
                   if ($490) {
                    label = 158;
                    break;
                   }
                  }
                  __THREW__ = 0;
                  (invoke_ii(3380,($445|0))|0);
                  $499 = __THREW__; __THREW__ = 0;
                  $500 = $499&1;
                  if ($500) {
                   label = 158;
                   break;
                  }
                 }
                 $501 = ((($445)) + 48|0);
                 $502 = HEAP32[$501>>2]|0;
                 $503 = HEAP32[$439>>2]|0;
                 $504 = ((($502)) + 792|0);
                 $505 = HEAP32[$504>>2]|0;
                 $506 = ($505|0)==($503|0);
                 do {
                  if (!($506)) {
                   HEAP32[$504>>2] = $503;
                   $507 = ($503|0)==(0|0);
                   if (!($507)) {
                    $508 = ((($503)) + 8|0);
                    $509 = HEAP32[$508>>2]|0;HEAP32[$508>>2] = (($509+1)|0);
                   }
                   $510 = ($505|0)==(0|0);
                   if ($510) {
                    break;
                   }
                   $511 = ((($505)) + 8|0);
                   $512 = HEAP32[$511>>2]|0;HEAP32[$511>>2] = (($512-1)|0);
                   $513 = ($512|0)==(1);
                   if (!($513)) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(3262,($505|0),1,1);
                   $514 = __THREW__; __THREW__ = 0;
                   $515 = $514&1;
                   if ($515) {
                    label = 158;
                    break L183;
                   }
                  }
                 } while(0);
                 __THREW__ = 0;
                 invoke_vi(3388,($445|0));
                 $516 = __THREW__; __THREW__ = 0;
                 $517 = $516&1;
                 if ($517) {
                  label = 158;
                  break;
                 }
                 $518 = HEAP32[$114>>2]|0;
                 $519 = ($518|0)==(1);
                 do {
                  if ($519) {
                   $520 = HEAP32[$440>>2]|0;
                   $521 = ($520|0)==(0|0);
                   if ($521) {
                    break;
                   }
                   $522 = ((($445)) + 108|0);
                   $523 = HEAP32[$522>>2]|0;
                   __THREW__ = 0;
                   invoke_vii(3449,($523|0),($520|0));
                   $524 = __THREW__; __THREW__ = 0;
                   $525 = $524&1;
                   if ($525) {
                    label = 158;
                    break L183;
                   }
                  }
                 } while(0);
                 $526 = ((($445)) + 108|0);
                 $527 = HEAP32[$526>>2]|0;
                 __THREW__ = 0;
                 $528 = (invoke_ii(3276,32)|0);
                 $529 = __THREW__; __THREW__ = 0;
                 $530 = $529&1;
                 if ($530) {
                  label = 158;
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3450,($528|0));
                 $531 = __THREW__; __THREW__ = 0;
                 $532 = $531&1;
                 if ($532) {
                  label = 178;
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vii(3449,($527|0),($528|0));
                 $533 = __THREW__; __THREW__ = 0;
                 $534 = $533&1;
                 if ($534) {
                  label = 158;
                  break;
                 }
                 $535 = HEAP32[$114>>2]|0;
                 $536 = ($535|0)==(1);
                 do {
                  if ($536) {
                   $537 = HEAP32[$441>>2]|0;
                   $538 = ($537|0)==(0);
                   if (!($538)) {
                    break;
                   }
                   $539 = HEAP32[$442>>2]|0;
                   $540 = ($539|0)==(0|0);
                   if ($540) {
                    break;
                   }
                   $541 = HEAP32[$526>>2]|0;
                   __THREW__ = 0;
                   invoke_vii(3449,($541|0),($539|0));
                   $542 = __THREW__; __THREW__ = 0;
                   $543 = $542&1;
                   if ($543) {
                    label = 158;
                    break L183;
                   }
                  }
                 } while(0);
                 if (!($444)) {
                  $546 = HEAP32[$526>>2]|0;
                  __THREW__ = 0;
                  invoke_vii(3449,($546|0),($443|0));
                  $547 = __THREW__; __THREW__ = 0;
                  $548 = $547&1;
                  if ($548) {
                   label = 158;
                   break;
                  }
                 }
                 $549 = HEAP32[$526>>2]|0;
                 __THREW__ = 0;
                 invoke_vii(3449,($549|0),($425|0));
                 $550 = __THREW__; __THREW__ = 0;
                 $551 = $550&1;
                 if ($551) {
                  label = 158;
                  break;
                 }
                 $552 = HEAP32[$114>>2]|0;
                 $553 = ($552|0)==(1);
                 do {
                  if ($553) {
                   $554 = HEAP32[$441>>2]|0;
                   $555 = ($554|0)==(1);
                   if (!($555)) {
                    break;
                   }
                   $556 = HEAP32[$442>>2]|0;
                   $557 = ($556|0)==(0|0);
                   if ($557) {
                    break;
                   }
                   $558 = HEAP32[$526>>2]|0;
                   __THREW__ = 0;
                   invoke_vii(3449,($558|0),($556|0));
                   $559 = __THREW__; __THREW__ = 0;
                   $560 = $559&1;
                   if ($560) {
                    label = 158;
                    break L183;
                   }
                  }
                 } while(0);
                 $561 = ((($$sroa$0261$0298)) + 4|0);
                 $562 = HEAP32[$55>>2]|0;
                 $563 = ($561|0)==($562|0);
                 if ($563) {
                  label = 187;
                  break L181;
                 } else {
                  $$sroa$0261$0298 = $561;
                 }
                }
                do {
                 if ((label|0) == 149) {
                  $479 = ___cxa_find_matching_catch_2()|0;
                  $480 = tempRet0;
                  __THREW__ = 0;
                  invoke_vi(3263,($4|0));
                  $481 = __THREW__; __THREW__ = 0;
                  $482 = $481&1;
                  if ($482) {
                   $483 = ___cxa_find_matching_catch_3(0|0)|0;
                   $484 = tempRet0;
                   ___clang_call_terminate($483);
                   // unreachable;
                  } else {
                   $eh$lpad$body159$index17Z2D = $480;$eh$lpad$body159$indexZ2D = $479;
                   break;
                  }
                 }
                 else if ((label|0) == 158) {
                  $497 = ___cxa_find_matching_catch_2()|0;
                  $498 = tempRet0;
                  $eh$lpad$body159$index17Z2D = $498;$eh$lpad$body159$indexZ2D = $497;
                 }
                 else if ((label|0) == 178) {
                  $544 = ___cxa_find_matching_catch_2()|0;
                  $545 = tempRet0;
                  __ZdlPv($528);
                  $$5 = $544;$$590 = $545;
                  break L181;
                 }
                } while(0);
                $$5 = $eh$lpad$body159$indexZ2D;$$590 = $eh$lpad$body159$index17Z2D;
               }
              } while(0);
              L239: do {
               if ((label|0) == 187) {
                $564 = HEAP32[$114>>2]|0;
                $565 = ($564|0)==(3);
                $or$cond = $351 & $565;
                L241: do {
                 if ($or$cond) {
                  $566 = HEAP32[$10>>2]|0;
                  $567 = HEAP32[$107>>2]|0;
                  $568 = ($566|0)==($567|0);
                  if ($568) {
                   break;
                  }
                  $569 = ((($0)) + 56|0);
                  $570 = ((($0)) + 60|0);
                  $$sroa$0233$0294 = $566;
                  L244: while(1) {
                   $571 = HEAP32[$$sroa$0233$0294>>2]|0;
                   __THREW__ = 0;
                   invoke_vi(3451,($571|0));
                   $572 = __THREW__; __THREW__ = 0;
                   $573 = $572&1;
                   if ($573) {
                    label = 193;
                    break;
                   }
                   $574 = ((($571)) + 624|0);
                   $575 = HEAP32[$574>>2]|0;
                   $576 = HEAP32[$569>>2]|0;
                   $577 = ($576|0)==(0|0);
                   if (!($577)) {
                    $578 = ((($571)) + 620|0);
                    $579 = HEAP32[$578>>2]|0;
                    __THREW__ = 0;
                    invoke_vii(3449,($579|0),($576|0));
                    $580 = __THREW__; __THREW__ = 0;
                    $581 = $580&1;
                    if ($581) {
                     label = 194;
                     break;
                    }
                   }
                   $586 = ((($571)) + 628|0);
                   $587 = HEAP32[$586>>2]|0;
                   $588 = ($587|0)==(0|0);
                   do {
                    if (!($588)) {
                     $589 = (___dynamic_cast($587,25048,8160,0)|0);
                     $590 = ($589|0)==(0|0);
                     if ($590) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vii(3445,($589|0),0);
                     $591 = __THREW__; __THREW__ = 0;
                     $592 = $591&1;
                     if ($592) {
                      label = 199;
                      break L244;
                     }
                     $593 = ((($571)) + 620|0);
                     $594 = HEAP32[$593>>2]|0;
                     __THREW__ = 0;
                     invoke_vii(3449,($594|0),($589|0));
                     $595 = __THREW__; __THREW__ = 0;
                     $596 = $595&1;
                     if ($596) {
                      label = 199;
                      break L244;
                     }
                    }
                   } while(0);
                   $599 = HEAP32[$570>>2]|0;
                   $600 = ($599|0)==(0|0);
                   if (!($600)) {
                    $601 = ((($575)) + 108|0);
                    $602 = HEAP32[$601>>2]|0;
                    __THREW__ = 0;
                    invoke_vii(3449,($602|0),($599|0));
                    $603 = __THREW__; __THREW__ = 0;
                    $604 = $603&1;
                    if ($604) {
                     label = 199;
                     break;
                    }
                   }
                   $605 = ((($$sroa$0233$0294)) + 4|0);
                   $606 = HEAP32[$107>>2]|0;
                   $607 = ($605|0)==($606|0);
                   if ($607) {
                    label = 203;
                    break;
                   } else {
                    $$sroa$0233$0294 = $605;
                   }
                  }
                  do {
                   if ((label|0) == 193) {
                    $582 = ___cxa_find_matching_catch_2()|0;
                    $583 = tempRet0;
                    $$sink108$index = $582;$$sink108$index25 = $583;
                   }
                   else if ((label|0) == 194) {
                    $584 = ___cxa_find_matching_catch_2()|0;
                    $585 = tempRet0;
                    $$sink108$index = $584;$$sink108$index25 = $585;
                   }
                   else if ((label|0) == 199) {
                    $597 = ___cxa_find_matching_catch_2()|0;
                    $598 = tempRet0;
                    $$sink108$index = $597;$$sink108$index25 = $598;
                   }
                   else if ((label|0) == 203) {
                    $$pre314 = HEAP32[$10>>2]|0;
                    $608 = ($$pre314|0)==($605|0);
                    if ($608) {
                     break L241;
                    }
                    $$sroa$0233$1291 = $$pre314;
                    L262: while(1) {
                     $609 = HEAP32[$$sroa$0233$1291>>2]|0;
                     $610 = ((($609)) + 620|0);
                     $611 = HEAP32[$610>>2]|0;
                     $612 = ($611|0)==(0|0);
                     do {
                      if (!($612)) {
                       $613 = ((($611)) + 12|0);
                       __THREW__ = 0;
                       $614 = (invoke_ii(3403,($613|0))|0);
                       $615 = __THREW__; __THREW__ = 0;
                       $616 = $615&1;
                       if ($616) {
                        label = 222;
                        break L262;
                       }
                       if ($614) {
                        break;
                       }
                       __THREW__ = 0;
                       $617 = (invoke_ii(3265,4)|0);
                       $618 = __THREW__; __THREW__ = 0;
                       $619 = $618&1;
                       if ($619) {
                        label = 222;
                        break L262;
                       }
                       if ($617) {
                        __THREW__ = 0;
                        $620 = (invoke_ii(3266,4)|0);
                        $621 = __THREW__; __THREW__ = 0;
                        $622 = $621&1;
                        if ($622) {
                         label = 222;
                         break L262;
                        }
                        __THREW__ = 0;
                        $623 = (invoke_iiii(3267,($620|0),(105737|0),30)|0);
                        $624 = __THREW__; __THREW__ = 0;
                        $625 = $624&1;
                        if ($625) {
                         label = 222;
                         break L262;
                        }
                        $626 = HEAP32[$610>>2]|0;
                        __THREW__ = 0;
                        $627 = (invoke_iii(3275,($623|0),($626|0))|0);
                        $628 = __THREW__; __THREW__ = 0;
                        $629 = $628&1;
                        if ($629) {
                         label = 222;
                         break L262;
                        }
                        $630 = HEAP32[$627>>2]|0;
                        $631 = ((($630)) + -12|0);
                        $632 = HEAP32[$631>>2]|0;
                        $633 = (($627) + ($632)|0);
                        __THREW__ = 0;
                        invoke_vii(3257,($1|0),($633|0));
                        $634 = __THREW__; __THREW__ = 0;
                        $635 = $634&1;
                        if ($635) {
                         label = 222;
                         break L262;
                        }
                        __THREW__ = 0;
                        $636 = (invoke_iii(3255,($1|0),(215188|0))|0);
                        $637 = __THREW__; __THREW__ = 0;
                        $638 = $637&1;
                        if ($638) {
                         break L262;
                        }
                        $639 = HEAP32[$636>>2]|0;
                        $640 = ((($639)) + 28|0);
                        $641 = HEAP32[$640>>2]|0;
                        __THREW__ = 0;
                        $642 = (invoke_iii($641|0,($636|0),10)|0);
                        $643 = __THREW__; __THREW__ = 0;
                        $644 = $643&1;
                        if ($644) {
                         break L262;
                        }
                        __THREW__ = 0;
                        invoke_vi(3263,($1|0));
                        $651 = __THREW__; __THREW__ = 0;
                        $652 = $651&1;
                        if ($652) {
                         label = 222;
                         break L262;
                        }
                        __THREW__ = 0;
                        (invoke_iii(3268,($627|0),($642|0))|0);
                        $653 = __THREW__; __THREW__ = 0;
                        $654 = $653&1;
                        if ($654) {
                         label = 222;
                         break L262;
                        }
                        __THREW__ = 0;
                        (invoke_ii(3269,($627|0))|0);
                        $655 = __THREW__; __THREW__ = 0;
                        $656 = $655&1;
                        if ($656) {
                         label = 222;
                         break L262;
                        }
                       }
                       $659 = HEAP32[$610>>2]|0;
                       $660 = ((($659)) + 12|0);
                       __THREW__ = 0;
                       (invoke_ii(3389,($660|0))|0);
                       $661 = __THREW__; __THREW__ = 0;
                       $662 = $661&1;
                       if ($662) {
                        label = 222;
                        break L262;
                       }
                      }
                     } while(0);
                     $663 = ((($$sroa$0233$1291)) + 4|0);
                     $664 = HEAP32[$107>>2]|0;
                     $665 = ($663|0)==($664|0);
                     if ($665) {
                      break L241;
                     } else {
                      $$sroa$0233$1291 = $663;
                     }
                    }
                    if ((label|0) == 222) {
                     $657 = ___cxa_find_matching_catch_2()|0;
                     $658 = tempRet0;
                     $$sink108$index = $657;$$sink108$index25 = $658;
                     break;
                    }
                    $645 = ___cxa_find_matching_catch_2()|0;
                    $646 = tempRet0;
                    __THREW__ = 0;
                    invoke_vi(3263,($1|0));
                    $647 = __THREW__; __THREW__ = 0;
                    $648 = $647&1;
                    if ($648) {
                     $649 = ___cxa_find_matching_catch_3(0|0)|0;
                     $650 = tempRet0;
                     ___clang_call_terminate($649);
                     // unreachable;
                    } else {
                     $$sink108$index = $645;$$sink108$index25 = $646;
                     break;
                    }
                   }
                  } while(0);
                  $$5 = $$sink108$index;$$590 = $$sink108$index25;
                  break L239;
                 }
                } while(0);
                $666 = HEAP32[$9>>2]|0;
                $667 = HEAP32[$55>>2]|0;
                $668 = ($666|0)==($667|0);
                L291: do {
                 if (!($668)) {
                  $$sroa$0261$1290 = $666;
                  L293: while(1) {
                   $669 = HEAP32[$$sroa$0261$1290>>2]|0;
                   $670 = ((($669)) + 108|0);
                   $671 = HEAP32[$670>>2]|0;
                   $672 = ($671|0)==(0|0);
                   do {
                    if (!($672)) {
                     $673 = ((($671)) + 12|0);
                     __THREW__ = 0;
                     $674 = (invoke_ii(3403,($673|0))|0);
                     $675 = __THREW__; __THREW__ = 0;
                     $676 = $675&1;
                     if ($676) {
                      label = 245;
                      break L293;
                     }
                     if ($674) {
                      break;
                     }
                     __THREW__ = 0;
                     $677 = (invoke_ii(3265,4)|0);
                     $678 = __THREW__; __THREW__ = 0;
                     $679 = $678&1;
                     if ($679) {
                      label = 245;
                      break L293;
                     }
                     if ($677) {
                      __THREW__ = 0;
                      $680 = (invoke_ii(3266,4)|0);
                      $681 = __THREW__; __THREW__ = 0;
                      $682 = $681&1;
                      if ($682) {
                       label = 245;
                       break L293;
                      }
                      __THREW__ = 0;
                      $683 = (invoke_iiii(3267,($680|0),(105768|0),41)|0);
                      $684 = __THREW__; __THREW__ = 0;
                      $685 = $684&1;
                      if ($685) {
                       label = 245;
                       break L293;
                      }
                      $686 = HEAP32[$670>>2]|0;
                      __THREW__ = 0;
                      $687 = (invoke_iii(3275,($683|0),($686|0))|0);
                      $688 = __THREW__; __THREW__ = 0;
                      $689 = $688&1;
                      if ($689) {
                       label = 245;
                       break L293;
                      }
                      $690 = HEAP32[$687>>2]|0;
                      $691 = ((($690)) + -12|0);
                      $692 = HEAP32[$691>>2]|0;
                      $693 = (($687) + ($692)|0);
                      __THREW__ = 0;
                      invoke_vii(3257,($2|0),($693|0));
                      $694 = __THREW__; __THREW__ = 0;
                      $695 = $694&1;
                      if ($695) {
                       label = 245;
                       break L293;
                      }
                      __THREW__ = 0;
                      $696 = (invoke_iii(3255,($2|0),(215188|0))|0);
                      $697 = __THREW__; __THREW__ = 0;
                      $698 = $697&1;
                      if ($698) {
                       label = 239;
                       break L293;
                      }
                      $699 = HEAP32[$696>>2]|0;
                      $700 = ((($699)) + 28|0);
                      $701 = HEAP32[$700>>2]|0;
                      __THREW__ = 0;
                      $702 = (invoke_iii($701|0,($696|0),10)|0);
                      $703 = __THREW__; __THREW__ = 0;
                      $704 = $703&1;
                      if ($704) {
                       label = 239;
                       break L293;
                      }
                      __THREW__ = 0;
                      invoke_vi(3263,($2|0));
                      $711 = __THREW__; __THREW__ = 0;
                      $712 = $711&1;
                      if ($712) {
                       label = 245;
                       break L293;
                      }
                      __THREW__ = 0;
                      (invoke_iii(3268,($687|0),($702|0))|0);
                      $713 = __THREW__; __THREW__ = 0;
                      $714 = $713&1;
                      if ($714) {
                       label = 245;
                       break L293;
                      }
                      __THREW__ = 0;
                      (invoke_ii(3269,($687|0))|0);
                      $715 = __THREW__; __THREW__ = 0;
                      $716 = $715&1;
                      if ($716) {
                       label = 245;
                       break L293;
                      }
                     }
                     $719 = HEAP32[$670>>2]|0;
                     $720 = ((($719)) + 12|0);
                     __THREW__ = 0;
                     (invoke_ii(3389,($720|0))|0);
                     $721 = __THREW__; __THREW__ = 0;
                     $722 = $721&1;
                     if ($722) {
                      label = 245;
                      break L293;
                     }
                    }
                   } while(0);
                   $723 = ((($$sroa$0261$1290)) + 4|0);
                   $724 = HEAP32[$55>>2]|0;
                   $725 = ($723|0)==($724|0);
                   if ($725) {
                    break L291;
                   } else {
                    $$sroa$0261$1290 = $723;
                   }
                  }
                  do {
                   if ((label|0) == 239) {
                    $705 = ___cxa_find_matching_catch_2()|0;
                    $706 = tempRet0;
                    __THREW__ = 0;
                    invoke_vi(3263,($2|0));
                    $707 = __THREW__; __THREW__ = 0;
                    $708 = $707&1;
                    if ($708) {
                     $709 = ___cxa_find_matching_catch_3(0|0)|0;
                     $710 = tempRet0;
                     ___clang_call_terminate($709);
                     // unreachable;
                    } else {
                     $eh$lpad$body209$index33Z2D = $706;$eh$lpad$body209$indexZ2D = $705;
                     break;
                    }
                   }
                   else if ((label|0) == 245) {
                    $717 = ___cxa_find_matching_catch_2()|0;
                    $718 = tempRet0;
                    $eh$lpad$body209$index33Z2D = $718;$eh$lpad$body209$indexZ2D = $717;
                   }
                  } while(0);
                  $$5 = $eh$lpad$body209$indexZ2D;$$590 = $eh$lpad$body209$index33Z2D;
                  break L239;
                 }
                } while(0);
                HEAP8[$12>>0] = 1;
                __THREW__ = 0;
                $726 = (invoke_ii(3265,4)|0);
                $727 = __THREW__; __THREW__ = 0;
                $728 = $727&1;
                L320: do {
                 if ($728) {
                  label = 262;
                 } else {
                  L322: do {
                   if ($726) {
                    __THREW__ = 0;
                    $729 = (invoke_ii(3266,4)|0);
                    $730 = __THREW__; __THREW__ = 0;
                    $731 = $730&1;
                    if ($731) {
                     label = 262;
                     break L320;
                    }
                    __THREW__ = 0;
                    $732 = (invoke_iiii(3267,($729|0),(105810|0),16)|0);
                    $733 = __THREW__; __THREW__ = 0;
                    $734 = $733&1;
                    if ($734) {
                     label = 262;
                     break L320;
                    }
                    $735 = HEAP32[$732>>2]|0;
                    $736 = ((($735)) + -12|0);
                    $737 = HEAP32[$736>>2]|0;
                    $738 = (($732) + ($737)|0);
                    __THREW__ = 0;
                    invoke_vii(3257,($3|0),($738|0));
                    $739 = __THREW__; __THREW__ = 0;
                    $740 = $739&1;
                    if ($740) {
                     label = 262;
                     break L320;
                    }
                    __THREW__ = 0;
                    $741 = (invoke_iii(3255,($3|0),(215188|0))|0);
                    $742 = __THREW__; __THREW__ = 0;
                    $743 = $742&1;
                    do {
                     if (!($743)) {
                      $744 = HEAP32[$741>>2]|0;
                      $745 = ((($744)) + 28|0);
                      $746 = HEAP32[$745>>2]|0;
                      __THREW__ = 0;
                      $747 = (invoke_iii($746|0,($741|0),10)|0);
                      $748 = __THREW__; __THREW__ = 0;
                      $749 = $748&1;
                      if ($749) {
                       break;
                      }
                      __THREW__ = 0;
                      invoke_vi(3263,($3|0));
                      $756 = __THREW__; __THREW__ = 0;
                      $757 = $756&1;
                      if ($757) {
                       label = 262;
                       break L320;
                      }
                      __THREW__ = 0;
                      (invoke_iii(3268,($732|0),($747|0))|0);
                      $758 = __THREW__; __THREW__ = 0;
                      $759 = $758&1;
                      if ($759) {
                       label = 262;
                       break L320;
                      }
                      __THREW__ = 0;
                      (invoke_ii(3269,($732|0))|0);
                      $760 = __THREW__; __THREW__ = 0;
                      $761 = $760&1;
                      if ($761) {
                       label = 262;
                       break L320;
                      } else {
                       break L322;
                      }
                     }
                    } while(0);
                    $750 = ___cxa_find_matching_catch_2()|0;
                    $751 = tempRet0;
                    __THREW__ = 0;
                    invoke_vi(3263,($3|0));
                    $752 = __THREW__; __THREW__ = 0;
                    $753 = $752&1;
                    if ($753) {
                     $754 = ___cxa_find_matching_catch_3(0|0)|0;
                     $755 = tempRet0;
                     ___clang_call_terminate($754);
                     // unreachable;
                    } else {
                     $eh$lpad$body197$index38Z2D = $751;$eh$lpad$body197$indexZ2D = $750;
                     break L320;
                    }
                   }
                  } while(0);
                  $764 = HEAP32[$425>>2]|0;
                  $765 = ((($764)) + -12|0);
                  $766 = HEAP32[$765>>2]|0;
                  $767 = (($425) + ($766)|0);
                  $768 = ((($767)) + 8|0);
                  $769 = HEAP32[$768>>2]|0;HEAP32[$768>>2] = (($769-1)|0);
                  $770 = ($769|0)==(1);
                  do {
                   if ($770) {
                    __THREW__ = 0;
                    invoke_viii(3262,($767|0),1,1);
                    $771 = __THREW__; __THREW__ = 0;
                    $772 = $771&1;
                    if (!($772)) {
                     break;
                    }
                    $810 = ___cxa_find_matching_catch_2()|0;
                    $811 = tempRet0;
                    if ($862) {
                     $$10 = $810;$$1095 = $811;
                     break L70;
                    } else {
                     $$7283 = $810;$$792281 = $811;
                     break L175;
                    }
                   }
                  } while(0);
                  do {
                   if (!($862)) {
                    $773 = HEAP32[$443>>2]|0;
                    $774 = ((($773)) + -12|0);
                    $775 = HEAP32[$774>>2]|0;
                    $776 = (($777) + ($775)|0);
                    $778 = ((($776)) + 8|0);
                    $779 = HEAP32[$778>>2]|0;HEAP32[$778>>2] = (($779-1)|0);
                    $780 = ($779|0)==(1);
                    if (!($780)) {
                     break;
                    }
                    __THREW__ = 0;
                    invoke_viii(3262,($776|0),1,1);
                    $781 = __THREW__; __THREW__ = 0;
                    $782 = $781&1;
                    if (!($782)) {
                     break;
                    }
                    $821 = ___cxa_find_matching_catch_2()|0;
                    $822 = tempRet0;
                    $$10 = $821;$$1095 = $822;
                    break L70;
                   }
                  } while(0);
                  $783 = HEAP32[$11>>2]|0;
                  $784 = ($783|0)==(0|0);
                  if (!($784)) {
                   $785 = HEAP32[$166>>2]|0;
                   $786 = ($785|0)==($783|0);
                   if (!($786)) {
                    $scevgep$i$i$i183 = ((($785)) + -4|0);
                    $787 = $scevgep$i$i$i183;
                    $788 = $783;
                    $789 = (($787) - ($788))|0;
                    $790 = $789 >>> 2;
                    $791 = $790 ^ -1;
                    $scevgep5$i$i$i184 = (($785) + ($791<<2)|0);
                    HEAP32[$166>>2] = $scevgep5$i$i$i184;
                   }
                   __ZdlPv($783);
                  }
                  break L68;
                 }
                } while(0);
                if ((label|0) == 262) {
                 $762 = ___cxa_find_matching_catch_2()|0;
                 $763 = tempRet0;
                 $eh$lpad$body197$index38Z2D = $763;$eh$lpad$body197$indexZ2D = $762;
                }
                $$5 = $eh$lpad$body197$indexZ2D;$$590 = $eh$lpad$body197$index38Z2D;
               }
              } while(0);
              $812 = HEAP32[$425>>2]|0;
              $813 = ((($812)) + -12|0);
              $814 = HEAP32[$813>>2]|0;
              $815 = (($425) + ($814)|0);
              $816 = ((($815)) + 8|0);
              $817 = HEAP32[$816>>2]|0;HEAP32[$816>>2] = (($817-1)|0);
              $818 = ($817|0)==(1);
              do {
               if ($818) {
                __THREW__ = 0;
                invoke_viii(3262,($815|0),1,1);
                $819 = __THREW__; __THREW__ = 0;
                $820 = $819&1;
                if (!($820)) {
                 break;
                }
                $859 = ___cxa_find_matching_catch_3(0|0)|0;
                $860 = tempRet0;
                ___clang_call_terminate($859);
                // unreachable;
               }
              } while(0);
              if ($862) {
               $$10 = $$5;$$1095 = $$590;
               break L70;
              } else {
               $$7283 = $$5;$$792281 = $$590;
              }
             }
            } while(0);
            $823 = HEAP32[$443>>2]|0;
            $824 = ((($823)) + -12|0);
            $825 = HEAP32[$824>>2]|0;
            $826 = (($777) + ($825)|0);
            $827 = ((($826)) + 8|0);
            $828 = HEAP32[$827>>2]|0;HEAP32[$827>>2] = (($828-1)|0);
            $829 = ($828|0)==(1);
            if (!($829)) {
             $$10 = $$7283;$$1095 = $$792281;
             break L70;
            }
            __THREW__ = 0;
            invoke_viii(3262,($826|0),1,1);
            $830 = __THREW__; __THREW__ = 0;
            $831 = $830&1;
            if (!($831)) {
             $$10 = $$7283;$$1095 = $$792281;
             break L70;
            }
            $859 = ___cxa_find_matching_catch_3(0|0)|0;
            $860 = tempRet0;
            ___clang_call_terminate($859);
            // unreachable;
           }
          } while(0);
          $307 = ___cxa_find_matching_catch_2()|0;
          $308 = tempRet0;
          $$10 = $307;$$1095 = $308;
         }
        } while(0);
        $832 = HEAP32[$11>>2]|0;
        $833 = ($832|0)==(0|0);
        if (!($833)) {
         $834 = HEAP32[$166>>2]|0;
         $835 = ($834|0)==($832|0);
         if (!($835)) {
          $scevgep$i$i$i168 = ((($834)) + -4|0);
          $836 = $scevgep$i$i$i168;
          $837 = $832;
          $838 = (($836) - ($837))|0;
          $839 = $838 >>> 2;
          $840 = $839 ^ -1;
          $scevgep5$i$i$i169 = (($834) + ($840<<2)|0);
          HEAP32[$166>>2] = $scevgep5$i$i$i169;
         }
         __ZdlPv($832);
        }
        $$13 = $$10;$$1398 = $$1095;
        break L43;
       }
      } while(0);
      $792 = HEAP32[$10>>2]|0;
      $793 = ($792|0)==(0|0);
      if (!($793)) {
       $794 = HEAP32[$107>>2]|0;
       $795 = ($794|0)==($792|0);
       if (!($795)) {
        $scevgep$i$i$i178 = ((($794)) + -4|0);
        $796 = $scevgep$i$i$i178;
        $797 = $792;
        $798 = (($796) - ($797))|0;
        $799 = $798 >>> 2;
        $800 = $799 ^ -1;
        $scevgep5$i$i$i179 = (($794) + ($800<<2)|0);
        HEAP32[$107>>2] = $scevgep5$i$i$i179;
       }
       __ZdlPv($792);
      }
      $801 = HEAP32[$9>>2]|0;
      $802 = ($801|0)==(0|0);
      if (!($802)) {
       $803 = HEAP32[$55>>2]|0;
       $804 = ($803|0)==($801|0);
       if (!($804)) {
        $scevgep$i$i$i173 = ((($803)) + -4|0);
        $805 = $scevgep$i$i$i173;
        $806 = $801;
        $807 = (($805) - ($806))|0;
        $808 = $807 >>> 2;
        $809 = $808 ^ -1;
        $scevgep5$i$i$i174 = (($803) + ($809<<2)|0);
        HEAP32[$55>>2] = $scevgep5$i$i$i174;
       }
       __ZdlPv($801);
      }
      STACKTOP = sp;return;
     }
    } while(0);
    $841 = HEAP32[$10>>2]|0;
    $842 = ($841|0)==(0|0);
    if (!($842)) {
     $843 = HEAP32[$107>>2]|0;
     $844 = ($843|0)==($841|0);
     if (!($844)) {
      $scevgep$i$i$i165 = ((($843)) + -4|0);
      $845 = $scevgep$i$i$i165;
      $846 = $841;
      $847 = (($845) - ($846))|0;
      $848 = $847 >>> 2;
      $849 = $848 ^ -1;
      $scevgep5$i$i$i166 = (($843) + ($849<<2)|0);
      HEAP32[$107>>2] = $scevgep5$i$i$i166;
     }
     __ZdlPv($841);
    }
    $$15 = $$13;$$15100 = $$1398;
   }
  }
 } while(0);
 if ((label|0) == 32) {
  $105 = ___cxa_find_matching_catch_2()|0;
  $106 = tempRet0;
  $eh$lpad$body$index2Z2D = $106;$eh$lpad$body$indexZ2D = $105;
  label = 33;
 }
 if ((label|0) == 33) {
  $$15 = $eh$lpad$body$indexZ2D;$$15100 = $eh$lpad$body$index2Z2D;
 }
 $850 = HEAP32[$9>>2]|0;
 $851 = ($850|0)==(0|0);
 if ($851) {
  ___resumeException($$15|0);
  // unreachable;
 }
 $852 = HEAP32[$55>>2]|0;
 $853 = ($852|0)==($850|0);
 if (!($853)) {
  $scevgep$i$i$i = ((($852)) + -4|0);
  $854 = $scevgep$i$i$i;
  $855 = $850;
  $856 = (($854) - ($855))|0;
  $857 = $856 >>> 2;
  $858 = $857 ^ -1;
  $scevgep5$i$i$i = (($852) + ($858<<2)|0);
  HEAP32[$55>>2] = $scevgep5$i$i$i;
 }
 __ZdlPv($850);
 ___resumeException($$15|0);
 // unreachable;
}
function __ZN9osgViewer10ViewerBase3runEv($0) {
 $0 = $0|0;
 var $$0 = 0.0, $$0$us = 0.0, $$sink$i = 0.0, $$sink$i$us = 0.0, $1 = 0, $10 = 0, $100 = 0.0, $101 = 0, $102 = 0, $103 = 0.0, $104 = 0.0, $105 = 0, $106 = 0.0, $107 = 0.0, $108 = 0, $109 = 0.0, $11 = 0, $110 = 0.0, $111 = 0, $112 = 0;
 var $113 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0.0, $17 = 0, $18 = 0.0, $19 = 0.0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0.0;
 var $48 = 0.0, $49 = 0, $5 = 0, $50 = 0, $51 = 0.0, $52 = 0, $53 = 0.0, $54 = 0.0, $55 = 0, $56 = 0.0, $57 = 0.0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0.0, $7 = 0, $70 = 0, $71 = 0.0, $72 = 0.0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (FUNCTION_TABLE_ii[$3 & 8191]($0)|0);
 if (!($4)) {
  $5 = HEAP32[$0>>2]|0;
  $6 = ((($5)) + 20|0);
  $7 = HEAP32[$6>>2]|0;
  FUNCTION_TABLE_vi[$7 & 8191]($0);
 }
 $8 = (_getenv((105518|0))|0);
 $9 = ($8|0)==(0|0);
 if ($9) {
  $68 = -1;
 } else {
  $10 = (_atoi($8)|0);
  $68 = $10;
 }
 $11 = ((($0)) + 5|0);
 $12 = HEAP8[$11>>0]|0;
 $13 = ($12<<24>>24)==(0);
 if (!($13)) {
  return 0;
 }
 $14 = ((($0)) + 40|0);
 $15 = ((($0)) + 36|0);
 if ($9) {
  while(1) {
   $16 = +HEAPF64[$14>>3];
   $17 = $16 > 0.0;
   $18 = 1.0 / $16;
   $19 = $17 ? $18 : 0.0;
   $20 = (__ZN3osg5Timer8instanceEv()|0);
   $21 = (__ZNK3osg5Timer4tickEv($20)|0);
   $22 = tempRet0;
   $23 = HEAP32[$15>>2]|0;
   $24 = ($23|0)==(0);
   do {
    if ($24) {
     $28 = HEAP32[$0>>2]|0;
     $29 = ((($28)) + 56|0);
     $30 = HEAP32[$29>>2]|0;
     $31 = (FUNCTION_TABLE_ii[$30 & 8191]($0)|0);
     if ($31) {
      $33 = HEAP32[$0>>2]|0;
      $34 = ((($33)) + 64|0);
      $35 = HEAP32[$34>>2]|0;
      FUNCTION_TABLE_vid[$35 & 8191]($0,1.7976931348623157E+308);
      $$0$us = $19;
      break;
     }
     $32 = $19 == 0.0;
     if ($32) {
      $$0$us = 0.01;
     } else {
      $$0$us = $19;
     }
    } else {
     $25 = HEAP32[$0>>2]|0;
     $26 = ((($25)) + 64|0);
     $27 = HEAP32[$26>>2]|0;
     FUNCTION_TABLE_vid[$27 & 8191]($0,1.7976931348623157E+308);
     $$0$us = $19;
    }
   } while(0);
   $36 = (__ZN3osg5Timer8instanceEv()|0);
   $37 = (__ZNK3osg5Timer4tickEv($36)|0);
   $38 = tempRet0;
   $39 = (__ZN3osg5Timer8instanceEv()|0);
   $40 = ($38>>>0)>($22>>>0);
   $41 = ($37>>>0)>($21>>>0);
   $42 = ($38|0)==($22|0);
   $43 = $42 & $41;
   $44 = $40 | $43;
   if ($44) {
    $49 = (_i64Subtract(($37|0),($38|0),($21|0),($22|0))|0);
    $50 = tempRet0;
    $51 = (+($49>>>0)) + (4294967296.0*(+($50>>>0)));
    $$sink$i$us = $51;
   } else {
    $45 = (_i64Subtract(($21|0),($22|0),($37|0),($38|0))|0);
    $46 = tempRet0;
    $47 = (+($45>>>0)) + (4294967296.0*(+($46>>>0)));
    $48 = -$47;
    $$sink$i$us = $48;
   }
   $52 = ((($39)) + 8|0);
   $53 = +HEAPF64[$52>>3];
   $54 = $$sink$i$us * $53;
   $55 = $54 < $$0$us;
   if ($55) {
    $56 = $$0$us - $54;
    $57 = $56 * 1.0E+6;
    $58 = (~~(($57))>>>0);
    (__ZN11OpenThreads6Thread10microSleepEj($58)|0);
   }
   $59 = HEAP8[$11>>0]|0;
   $60 = ($59<<24>>24)==(0);
   if (!($60)) {
    break;
   }
  }
  return 0;
 }
 while(1) {
  $61 = HEAP32[$0>>2]|0;
  $62 = ((($61)) + 116|0);
  $63 = HEAP32[$62>>2]|0;
  $64 = (FUNCTION_TABLE_ii[$63 & 8191]($0)|0);
  $65 = ((($64)) + 12|0);
  $66 = HEAP32[$65>>2]|0;
  $67 = ($66>>>0)<($68>>>0);
  if (!($67)) {
   label = 32;
   break;
  }
  $69 = +HEAPF64[$14>>3];
  $70 = $69 > 0.0;
  $71 = 1.0 / $69;
  $72 = $70 ? $71 : 0.0;
  $73 = (__ZN3osg5Timer8instanceEv()|0);
  $74 = (__ZNK3osg5Timer4tickEv($73)|0);
  $75 = tempRet0;
  $76 = HEAP32[$15>>2]|0;
  $77 = ($76|0)==(0);
  do {
   if ($77) {
    $78 = HEAP32[$0>>2]|0;
    $79 = ((($78)) + 56|0);
    $80 = HEAP32[$79>>2]|0;
    $81 = (FUNCTION_TABLE_ii[$80 & 8191]($0)|0);
    if ($81) {
     $82 = HEAP32[$0>>2]|0;
     $83 = ((($82)) + 64|0);
     $84 = HEAP32[$83>>2]|0;
     FUNCTION_TABLE_vid[$84 & 8191]($0,1.7976931348623157E+308);
     $$0 = $72;
     break;
    }
    $85 = $72 == 0.0;
    if ($85) {
     $$0 = 0.01;
    } else {
     $$0 = $72;
    }
   } else {
    $86 = HEAP32[$0>>2]|0;
    $87 = ((($86)) + 64|0);
    $88 = HEAP32[$87>>2]|0;
    FUNCTION_TABLE_vid[$88 & 8191]($0,1.7976931348623157E+308);
    $$0 = $72;
   }
  } while(0);
  $89 = (__ZN3osg5Timer8instanceEv()|0);
  $90 = (__ZNK3osg5Timer4tickEv($89)|0);
  $91 = tempRet0;
  $92 = (__ZN3osg5Timer8instanceEv()|0);
  $93 = ($91>>>0)>($75>>>0);
  $94 = ($90>>>0)>($74>>>0);
  $95 = ($91|0)==($75|0);
  $96 = $95 & $94;
  $97 = $93 | $96;
  if ($97) {
   $98 = (_i64Subtract(($90|0),($91|0),($74|0),($75|0))|0);
   $99 = tempRet0;
   $100 = (+($98>>>0)) + (4294967296.0*(+($99>>>0)));
   $$sink$i = $100;
  } else {
   $101 = (_i64Subtract(($74|0),($75|0),($90|0),($91|0))|0);
   $102 = tempRet0;
   $103 = (+($101>>>0)) + (4294967296.0*(+($102>>>0)));
   $104 = -$103;
   $$sink$i = $104;
  }
  $105 = ((($92)) + 8|0);
  $106 = +HEAPF64[$105>>3];
  $107 = $$sink$i * $106;
  $108 = $107 < $$0;
  if ($108) {
   $109 = $$0 - $107;
   $110 = $109 * 1.0E+6;
   $111 = (~~(($110))>>>0);
   (__ZN11OpenThreads6Thread10microSleepEj($111)|0);
  }
  $112 = HEAP8[$11>>0]|0;
  $113 = ($112<<24>>24)==(0);
  if (!($113)) {
   label = 32;
   break;
  }
 }
 if ((label|0) == 32) {
  return 0;
 }
 return (0)|0;
}
function __ZN9osgViewer10ViewerBase5frameEd($0,$1) {
 $0 = $0|0;
 $1 = +$1;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 5|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if (!($4)) {
  return;
 }
 $5 = ((($0)) + 4|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = ($6<<24>>24)==(0);
 if (!($7)) {
  $8 = HEAP32[$0>>2]|0;
  $9 = ((($8)) + 124|0);
  $10 = HEAP32[$9>>2]|0;
  FUNCTION_TABLE_vi[$10 & 8191]($0);
  $11 = HEAP32[$0>>2]|0;
  $12 = ((($11)) + 16|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (FUNCTION_TABLE_ii[$13 & 8191]($0)|0);
  if (!($14)) {
   $15 = HEAP32[$0>>2]|0;
   $16 = ((($15)) + 20|0);
   $17 = HEAP32[$16>>2]|0;
   FUNCTION_TABLE_vi[$17 & 8191]($0);
  }
  HEAP8[$5>>0] = 0;
 }
 $18 = HEAP32[$0>>2]|0;
 $19 = ((($18)) + 68|0);
 $20 = HEAP32[$19>>2]|0;
 FUNCTION_TABLE_vid[$20 & 8191]($0,$1);
 $21 = HEAP32[$0>>2]|0;
 $22 = ((($21)) + 72|0);
 $23 = HEAP32[$22>>2]|0;
 FUNCTION_TABLE_vi[$23 & 8191]($0);
 $24 = HEAP32[$0>>2]|0;
 $25 = ((($24)) + 76|0);
 $26 = HEAP32[$25>>2]|0;
 FUNCTION_TABLE_vi[$26 & 8191]($0);
 $27 = HEAP32[$0>>2]|0;
 $28 = ((($27)) + 80|0);
 $29 = HEAP32[$28>>2]|0;
 FUNCTION_TABLE_vi[$29 & 8191]($0);
 return;
}
function __ZN9osgViewer10ViewerBase19renderingTraversalsEv($0) {
 $0 = $0|0;
 var $$0$i$i$i$i = 0, $$0$i$i$i$i329 = 0, $$0208$lcssa = 0, $$02081089 = 0, $$0209$lcssa = 0, $$02091094 = 0, $$0210$off0$lcssa = 0, $$0210$off01074 = 0, $$1 = 0, $$10 = 0, $$10166 = 0, $$11 = 0, $$11167 = 0, $$1157 = 0, $$12 = 0, $$1211$off0 = 0, $$12168 = 0, $$13 = 0, $$13169 = 0, $$14 = 0;
 var $$14170 = 0, $$15 = 0, $$15171 = 0, $$16 = 0, $$16172 = 0, $$17 = 0, $$17173 = 0, $$18 = 0, $$18174 = 0, $$19 = 0, $$19175 = 0, $$2 = 0, $$20 = 0, $$20176 = 0, $$2158 = 0, $$2212$off0$lcssa = 0, $$2212$off0$not = 0, $$2212$off01068 = 0, $$23 = 0, $$23179 = 0;
 var $$24 = 0, $$24180 = 0, $$28 = 0, $$28184 = 0, $$3 = 0, $$3159 = 0, $$3213$off0 = 0, $$36 = 0, $$36192 = 0, $$37 = 0, $$37193 = 0, $$38 = 0, $$38194 = 0, $$4 = 0, $$41 = 0, $$41197 = 0, $$4160 = 0, $$43 = 0, $$43199 = 0, $$47 = 0;
 var $$47203 = 0, $$5 = 0, $$5161 = 0, $$6 = 0, $$6162 = 0, $$7 = 0, $$7163 = 0, $$8 = 0, $$8164 = 0, $$9 = 0, $$9165 = 0, $$pr$i = 0, $$pre = 0, $$pre$i442 = 0, $$pre1104 = 0, $$pre1106 = 0, $$sroa$0495$01066 = 0, $$sroa$0508$01080 = 0, $$sroa$0513$01073 = 0, $$sroa$0513$11067 = 0;
 var $$sroa$0529$01084 = 0, $$sroa$0540$0$be = 0, $$sroa$0540$01088 = 0, $$sroa$0540$1$be = 0, $$sroa$0540$11093 = 0, $$sroa$0550$01097 = 0, $1 = 0, $10 = 0, $100 = 0, $1000 = 0, $1001 = 0, $1002 = 0, $1003 = 0, $1004 = 0, $1005 = 0, $1006 = 0, $1007 = 0, $1008 = 0, $1009 = 0, $101 = 0;
 var $1010 = 0, $1011 = 0, $1012 = 0, $1013 = 0, $1014 = 0, $1015 = 0, $1016 = 0, $1017 = 0, $1018 = 0, $1019 = 0, $102 = 0, $1020 = 0, $1021 = 0, $1022 = 0, $1023 = 0, $1024 = 0, $1025 = 0, $1026 = 0, $1027 = 0, $1028 = 0;
 var $1029 = 0, $103 = 0, $1030 = 0, $1031 = 0, $1032 = 0, $1033 = 0, $1034 = 0, $1035 = 0, $1036 = 0, $1037 = 0, $1038 = 0, $1039 = 0, $104 = 0, $1040 = 0, $1041 = 0, $1042 = 0, $1043 = 0, $1044 = 0, $1045 = 0, $1046 = 0;
 var $1047 = 0, $1048 = 0, $1049 = 0, $105 = 0, $1050 = 0, $1051 = 0, $1052 = 0, $1053 = 0, $1054 = 0, $1055 = 0, $1056 = 0, $1057 = 0, $1058 = 0, $1059 = 0, $106 = 0, $1060 = 0, $1061 = 0, $1062 = 0, $1063 = 0, $1064 = 0;
 var $1065 = 0, $1066 = 0, $1067 = 0, $1068 = 0, $1069 = 0, $107 = 0, $1070 = 0, $1071 = 0, $1072 = 0, $1073 = 0, $1074 = 0, $1075 = 0, $1076 = 0, $1077 = 0, $1078 = 0, $1079 = 0, $108 = 0, $1080 = 0, $1081 = 0, $1082 = 0;
 var $1083 = 0, $1084 = 0, $1085 = 0, $1086 = 0, $1087 = 0, $1088 = 0, $1089 = 0, $109 = 0, $1090 = 0, $1091 = 0, $1092 = 0, $1093 = 0, $1094 = 0, $1095 = 0, $1096 = 0, $1097 = 0, $1098 = 0, $1099 = 0, $11 = 0, $110 = 0;
 var $1100 = 0, $1101 = 0, $1102 = 0, $1103 = 0, $1104 = 0, $1105 = 0, $1106 = 0, $1107 = 0, $1108 = 0, $1109 = 0, $111 = 0, $1110 = 0, $1111 = 0, $1112 = 0, $1113 = 0, $1114 = 0, $1115 = 0, $1116 = 0, $1117 = 0, $1118 = 0;
 var $1119 = 0, $112 = 0, $1120 = 0, $1121 = 0, $1122 = 0, $1123 = 0, $1124 = 0, $1125 = 0, $1126 = 0, $1127 = 0, $1128 = 0, $1129 = 0, $113 = 0, $1130 = 0, $1131 = 0, $1132 = 0, $1133 = 0, $1134 = 0, $1135 = 0.0, $1136 = 0;
 var $1137 = 0, $1138 = 0, $1139 = 0, $114 = 0, $1140 = 0, $1141 = 0, $1142 = 0, $1143 = 0, $1144 = 0, $1145 = 0, $1146 = 0, $1147 = 0, $1148 = 0, $1149 = 0, $115 = 0, $1150 = 0, $1151 = 0, $1152 = 0, $1153 = 0, $1154 = 0;
 var $1155 = 0, $1156 = 0, $1157 = 0, $1158 = 0, $1159 = 0, $116 = 0, $1160 = 0, $1161 = 0, $1162 = 0, $1163 = 0, $1164 = 0, $1165 = 0, $1166 = 0, $1167 = 0, $1168 = 0, $1169 = 0, $117 = 0, $1170 = 0, $1171 = 0, $1172 = 0;
 var $1173 = 0, $1174 = 0, $1175 = 0, $1176 = 0, $1177 = 0, $1178 = 0, $1179 = 0, $118 = 0, $1180 = 0, $1181 = 0, $1182 = 0, $1183 = 0, $1184 = 0, $1185 = 0, $1186 = 0.0, $1187 = 0, $1188 = 0, $1189 = 0, $119 = 0, $1190 = 0;
 var $1191 = 0, $1192 = 0, $1193 = 0, $1194 = 0, $1195 = 0, $1196 = 0, $1197 = 0, $1198 = 0, $1199 = 0, $12 = 0, $120 = 0, $1200 = 0, $1201 = 0, $1202 = 0, $1203 = 0, $1204 = 0, $1205 = 0, $1206 = 0, $1207 = 0, $1208 = 0;
 var $1209 = 0, $121 = 0, $1210 = 0, $1211 = 0, $1212 = 0, $1213 = 0, $1214 = 0, $1215 = 0, $1216 = 0, $1217 = 0, $1218 = 0, $1219 = 0, $122 = 0, $1220 = 0, $1221 = 0, $1222 = 0, $1223 = 0, $1224 = 0, $1225 = 0, $1226 = 0;
 var $1227 = 0, $1228 = 0, $1229 = 0, $123 = 0, $1230 = 0, $1231 = 0, $1232 = 0, $1233 = 0, $1234 = 0, $1235 = 0, $1236 = 0, $1237 = 0, $1238 = 0, $1239 = 0, $124 = 0, $1240 = 0, $1241 = 0, $1242 = 0, $1243 = 0, $1244 = 0;
 var $1245 = 0, $1246 = 0, $1247 = 0, $1248 = 0, $1249 = 0, $125 = 0, $1250 = 0, $1251 = 0, $1252 = 0, $1253 = 0, $1254 = 0, $1255 = 0, $1256 = 0, $1257 = 0, $1258 = 0, $1259 = 0, $126 = 0, $1260 = 0, $1261 = 0, $1262 = 0;
 var $1263 = 0, $1264 = 0, $1265 = 0, $1266 = 0, $1267 = 0, $1268 = 0, $1269 = 0, $127 = 0, $1270 = 0, $1271 = 0, $1272 = 0, $1273 = 0, $1274 = 0, $1275 = 0, $1276 = 0, $1277 = 0, $1278 = 0, $1279 = 0, $128 = 0, $1280 = 0;
 var $1281 = 0, $1282 = 0, $1283 = 0, $1284 = 0, $1285 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0;
 var $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0;
 var $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0;
 var $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0;
 var $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0;
 var $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0;
 var $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0;
 var $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0.0, $284 = 0, $285 = 0, $286 = 0;
 var $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0.0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0;
 var $304 = 0, $305 = 0, $306 = 0.0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0.0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0;
 var $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0.0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0.0, $34 = 0;
 var $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0.0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0;
 var $359 = 0, $36 = 0, $360 = 0, $361 = 0.0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0.0, $373 = 0, $374 = 0, $375 = 0, $376 = 0;
 var $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0.0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0;
 var $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0;
 var $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0;
 var $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0;
 var $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0;
 var $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0.0;
 var $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0.0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0;
 var $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0.0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0.0, $518 = 0, $519 = 0, $52 = 0;
 var $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0.0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0;
 var $539 = 0.0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0.0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0;
 var $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0.0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0.0, $573 = 0, $574 = 0;
 var $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0.0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0.0, $590 = 0, $591 = 0, $592 = 0;
 var $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0;
 var $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0;
 var $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0;
 var $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0;
 var $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0;
 var $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0;
 var $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0;
 var $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0;
 var $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0.0, $749 = 0, $75 = 0, $750 = 0, $751 = 0.0, $752 = 0, $753 = 0.0, $754 = 0.0;
 var $755 = 0.0, $756 = 0, $757 = 0.0, $758 = 0.0, $759 = 0.0, $76 = 0, $760 = 0, $761 = 0.0, $762 = 0.0, $763 = 0.0, $764 = 0.0, $765 = 0.0, $766 = 0.0, $767 = 0.0, $768 = 0.0, $769 = 0.0, $77 = 0, $770 = 0.0, $771 = 0.0, $772 = 0.0;
 var $773 = 0.0, $774 = 0, $775 = 0.0, $776 = 0, $777 = 0.0, $778 = 0.0, $779 = 0.0, $78 = 0, $780 = 0.0, $781 = 0.0, $782 = 0.0, $783 = 0.0, $784 = 0.0, $785 = 0.0, $786 = 0.0, $787 = 0.0, $788 = 0.0, $789 = 0.0, $79 = 0, $790 = 0.0;
 var $791 = 0.0, $792 = 0.0, $793 = 0.0, $794 = 0.0, $795 = 0.0, $796 = 0.0, $797 = 0.0, $798 = 0.0, $799 = 0.0, $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0.0, $806 = 0, $807 = 0, $808 = 0.0;
 var $809 = 0, $81 = 0, $810 = 0.0, $811 = 0.0, $812 = 0.0, $813 = 0, $814 = 0.0, $815 = 0.0, $816 = 0.0, $817 = 0, $818 = 0.0, $819 = 0.0, $82 = 0, $820 = 0.0, $821 = 0.0, $822 = 0.0, $823 = 0.0, $824 = 0.0, $825 = 0.0, $826 = 0.0;
 var $827 = 0.0, $828 = 0.0, $829 = 0.0, $83 = 0, $830 = 0.0, $831 = 0, $832 = 0.0, $833 = 0, $834 = 0.0, $835 = 0.0, $836 = 0.0, $837 = 0.0, $838 = 0.0, $839 = 0.0, $84 = 0, $840 = 0.0, $841 = 0.0, $842 = 0.0, $843 = 0.0, $844 = 0.0;
 var $845 = 0.0, $846 = 0.0, $847 = 0.0, $848 = 0.0, $849 = 0.0, $85 = 0, $850 = 0.0, $851 = 0.0, $852 = 0.0, $853 = 0.0, $854 = 0.0, $855 = 0.0, $856 = 0.0, $857 = 0, $858 = 0, $859 = 0, $86 = 0, $860 = 0, $861 = 0, $862 = 0;
 var $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0, $869 = 0, $87 = 0, $870 = 0, $871 = 0, $872 = 0, $873 = 0, $874 = 0, $875 = 0, $876 = 0, $877 = 0, $878 = 0, $879 = 0, $88 = 0, $880 = 0;
 var $881 = 0, $882 = 0, $883 = 0, $884 = 0, $885 = 0, $886 = 0, $887 = 0, $888 = 0, $889 = 0, $89 = 0, $890 = 0, $891 = 0, $892 = 0, $893 = 0, $894 = 0, $895 = 0, $896 = 0, $897 = 0, $898 = 0, $899 = 0;
 var $9 = 0, $90 = 0, $900 = 0, $901 = 0, $902 = 0, $903 = 0, $904 = 0, $905 = 0, $906 = 0, $907 = 0, $908 = 0, $909 = 0, $91 = 0, $910 = 0, $911 = 0, $912 = 0, $913 = 0, $914 = 0, $915 = 0, $916 = 0;
 var $917 = 0, $918 = 0, $919 = 0, $92 = 0, $920 = 0, $921 = 0, $922 = 0, $923 = 0, $924 = 0, $925 = 0, $926 = 0, $927 = 0, $928 = 0, $929 = 0, $93 = 0, $930 = 0, $931 = 0, $932 = 0, $933 = 0, $934 = 0;
 var $935 = 0, $936 = 0, $937 = 0, $938 = 0, $939 = 0, $94 = 0, $940 = 0, $941 = 0, $942 = 0, $943 = 0, $944 = 0, $945 = 0, $946 = 0, $947 = 0, $948 = 0, $949 = 0, $95 = 0, $950 = 0, $951 = 0, $952 = 0;
 var $953 = 0, $954 = 0, $955 = 0, $956 = 0, $957 = 0, $958 = 0, $959 = 0, $96 = 0, $960 = 0, $961 = 0, $962 = 0, $963 = 0, $964 = 0, $965 = 0, $966 = 0, $967 = 0, $968 = 0, $969 = 0, $97 = 0, $970 = 0;
 var $971 = 0, $972 = 0, $973 = 0, $974 = 0, $975 = 0, $976 = 0, $977 = 0, $978 = 0, $979 = 0, $98 = 0, $980 = 0, $981 = 0, $982 = 0, $983 = 0, $984 = 0, $985 = 0, $986 = 0, $987 = 0, $988 = 0, $989 = 0;
 var $99 = 0, $990 = 0, $991 = 0, $992 = 0, $993 = 0, $994 = 0, $995 = 0, $996 = 0, $997 = 0, $998 = 0, $999 = 0, $brmerge = 0, $eh$lpad$body$index6Z2D = 0, $eh$lpad$body$indexZ2D = 0, $eh$lpad$body417$index11Z2D = 0, $eh$lpad$body417$indexZ2D = 0, $eh$lpad$body430$indexZ2D = 0, $eh$lpad$body448$index19Z2D = 0, $eh$lpad$body448$indexZ2D = 0, $eh$lpad$body484$index27Z2D = 0;
 var $eh$lpad$body484$indexZ2D = 0, $or$cond = 0, $phitmp$i$i = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i231 = 0, $scevgep$i$i$i236 = 0, $scevgep$i$i$i239 = 0, $scevgep$i$i$i242 = 0, $scevgep$i$i$i247 = 0, $scevgep$i$i$i252 = 0, $scevgep$i$i$i432 = 0, $scevgep5$i$i$i = 0, $scevgep5$i$i$i232 = 0, $scevgep5$i$i$i237 = 0, $scevgep5$i$i$i240 = 0, $scevgep5$i$i$i243 = 0, $scevgep5$i$i$i248 = 0, $scevgep5$i$i$i253 = 0, $scevgep5$i$i$i433 = 0, dest = 0;
 var label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 800|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(800|0);
 $1 = sp + 776|0;
 $2 = sp + 760|0;
 $3 = sp + 744|0;
 $4 = sp + 732|0;
 $5 = sp + 720|0;
 $6 = sp + 312|0;
 $7 = sp + 300|0;
 $8 = sp + 288|0;
 $9 = sp + 276|0;
 $10 = sp + 264|0;
 $11 = sp + 252|0;
 $12 = sp + 240|0;
 $13 = sp + 228|0;
 $14 = sp + 216|0;
 $15 = sp + 204|0;
 $16 = sp + 192|0;
 $17 = sp + 180|0;
 $18 = sp + 168|0;
 $19 = sp + 156|0;
 $20 = sp + 144|0;
 $21 = sp + 132|0;
 $22 = sp + 120|0;
 $23 = sp + 108|0;
 $24 = sp + 96|0;
 $25 = sp + 84|0;
 $26 = sp + 72|0;
 $27 = sp + 60|0;
 $28 = sp + 48|0;
 $29 = sp + 36|0;
 $30 = sp + 24|0;
 $31 = sp + 12|0;
 $32 = sp;
 HEAP32[$3>>2] = 0;
 $33 = ((($3)) + 4|0);
 HEAP32[$33>>2] = 0;
 $34 = ((($3)) + 8|0);
 HEAP32[$34>>2] = 0;
 $35 = HEAP32[$0>>2]|0;
 $36 = ((($35)) + 88|0);
 $37 = HEAP32[$36>>2]|0;
 __THREW__ = 0;
 invoke_viii($37|0,($0|0),($3|0),1);
 $38 = __THREW__; __THREW__ = 0;
 $39 = $38&1;
 L1: do {
  if ($39) {
   label = 6;
  } else {
   $40 = HEAP32[$33>>2]|0;
   $41 = HEAP32[$3>>2]|0;
   $42 = ($40|0)==($41|0);
   $43 = ((($0)) + 5|0);
   if ($42) {
    HEAP8[$43>>0] = 1;
    $44 = ((($0)) + 32|0);
    $45 = HEAP8[$44>>0]|0;
    $46 = ($45<<24>>24)==(0);
    if (!($46)) {
     $47 = HEAP32[$0>>2]|0;
     $48 = ((($47)) + 44|0);
     $49 = HEAP32[$48>>2]|0;
     __THREW__ = 0;
     invoke_vi($49|0,($0|0));
     $50 = __THREW__; __THREW__ = 0;
     $51 = $50&1;
     if ($51) {
      label = 6;
      break;
     }
    }
   }
   $52 = HEAP8[$43>>0]|0;
   $53 = ($52<<24>>24)==(0);
   L7: do {
    if ($53) {
     $56 = HEAP32[$0>>2]|0;
     $57 = ((($56)) + 112|0);
     $58 = HEAP32[$57>>2]|0;
     __THREW__ = 0;
     $59 = (+invoke_di($58|0,($0|0)));
     $60 = __THREW__; __THREW__ = 0;
     $61 = $60&1;
     if ($61) {
      label = 6;
      break L1;
     }
     $62 = HEAP32[$0>>2]|0;
     $63 = ((($62)) + 116|0);
     $64 = HEAP32[$63>>2]|0;
     __THREW__ = 0;
     $65 = (invoke_ii($64|0,($0|0))|0);
     $66 = __THREW__; __THREW__ = 0;
     $67 = $66&1;
     if ($67) {
      $220 = ___cxa_find_matching_catch_2()|0;
      $221 = tempRet0;
      $$47 = $220;$$47203 = $221;
      break L1;
     }
     $68 = ($65|0)==(0|0);
     if ($68) {
      $284 = 0;
     } else {
      $69 = ((($65)) + 12|0);
      $70 = HEAP32[$69>>2]|0;
      $284 = $70;
     }
     $71 = HEAP32[$0>>2]|0;
     $72 = ((($71)) + 4|0);
     $73 = HEAP32[$72>>2]|0;
     __THREW__ = 0;
     $74 = (invoke_ii($73|0,($0|0))|0);
     $75 = __THREW__; __THREW__ = 0;
     $76 = $75&1;
     L16: do {
      if (!($76)) {
       $77 = ($74|0)==(0|0);
       L18: do {
        if (!($77)) {
         $78 = HEAP32[$0>>2]|0;
         $79 = ((($78)) + 4|0);
         $80 = HEAP32[$79>>2]|0;
         __THREW__ = 0;
         $81 = (invoke_ii($80|0,($0|0))|0);
         $82 = __THREW__; __THREW__ = 0;
         $83 = $82&1;
         if ($83) {
          break L16;
         }
         ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;
         $84 = ((($4)) + 11|0);
         HEAP8[$84>>0] = 5;
         ;HEAP8[$4>>0]=HEAP8[108343>>0]|0;HEAP8[$4+1>>0]=HEAP8[108343+1>>0]|0;HEAP8[$4+2>>0]=HEAP8[108343+2>>0]|0;HEAP8[$4+3>>0]=HEAP8[108343+3>>0]|0;HEAP8[$4+4>>0]=HEAP8[108343+4>>0]|0;
         $85 = ((($4)) + 5|0);
         HEAP8[$85>>0] = 0;
         $86 = ((($81)) + 24|0);
         $87 = HEAP32[$86>>2]|0;
         $88 = ((($87)) + 8|0);
         $89 = HEAP32[$88>>2]|0;
         __THREW__ = 0;
         (invoke_ii($89|0,($86|0))|0);
         $90 = __THREW__; __THREW__ = 0;
         $91 = $90&1;
         do {
          if ($91) {
           label = 34;
          } else {
           $92 = ((($81)) + 68|0);
           __THREW__ = 0;
           $93 = (invoke_iii(3391,($92|0),($4|0))|0);
           $94 = __THREW__; __THREW__ = 0;
           $95 = $94&1;
           if ($95) {
            $106 = ___cxa_find_matching_catch_2()|0;
            $107 = tempRet0;
            $108 = HEAP32[$86>>2]|0;
            $109 = ((($108)) + 12|0);
            $110 = HEAP32[$109>>2]|0;
            __THREW__ = 0;
            (invoke_ii($110|0,($86|0))|0);
            $111 = __THREW__; __THREW__ = 0;
            $112 = $111&1;
            if (!($112)) {
             $eh$lpad$body$index6Z2D = $107;$eh$lpad$body$indexZ2D = $106;
             break;
            }
            $113 = ___cxa_find_matching_catch_3(0|0)|0;
            $114 = tempRet0;
            ___clang_call_terminate($113);
            // unreachable;
           }
           $96 = ((($81)) + 72|0);
           $97 = ($93|0)==($96|0);
           if ($97) {
            $1281 = 0;
           } else {
            $98 = ((($93)) + 28|0);
            $99 = HEAP8[$98>>0]|0;
            $100 = ($99<<24>>24)!=(0);
            $1281 = $100;
           }
           $101 = HEAP32[$86>>2]|0;
           $102 = ((($101)) + 12|0);
           $103 = HEAP32[$102>>2]|0;
           __THREW__ = 0;
           (invoke_ii($103|0,($86|0))|0);
           $104 = __THREW__; __THREW__ = 0;
           $105 = $104&1;
           if ($105) {
            label = 34;
           } else {
            $115 = HEAP8[$84>>0]|0;
            $116 = ($115<<24>>24)<(0);
            if ($116) {
             $117 = HEAP32[$4>>2]|0;
             __ZdlPv($117);
            }
            if (!($1281)) {
             break L18;
            }
            HEAP32[$5>>2] = 0;
            $118 = ((($5)) + 4|0);
            HEAP32[$118>>2] = 0;
            $119 = ((($5)) + 8|0);
            HEAP32[$119>>2] = 0;
            $120 = HEAP32[$0>>2]|0;
            $121 = ((($120)) + 108|0);
            $122 = HEAP32[$121>>2]|0;
            __THREW__ = 0;
            invoke_viii($122|0,($0|0),($5|0),1);
            $123 = __THREW__; __THREW__ = 0;
            $124 = $123&1;
            L35: do {
             if ($124) {
              $229 = ___cxa_find_matching_catch_2()|0;
              $230 = tempRet0;
              $$28 = $229;$$28184 = $230;
             } else {
              $125 = HEAP32[$5>>2]|0;
              $126 = HEAP32[$118>>2]|0;
              $127 = ($125|0)==($126|0);
              L38: do {
               if ($127) {
                $211 = $125;$213 = $125;
               } else {
                $128 = ((($6)) + 268|0);
                $129 = ((($6)) + 272|0);
                $130 = ((($7)) + 8|0);
                $131 = ((($7)) + 4|0);
                $132 = ((($6)) + 196|0);
                $133 = ((($7)) + 11|0);
                $134 = ((($8)) + 8|0);
                $135 = ((($8)) + 4|0);
                $136 = ((($6)) + 100|0);
                $137 = ((($8)) + 11|0);
                $138 = ((($9)) + 8|0);
                $139 = ((($9)) + 4|0);
                $140 = ((($6)) + 112|0);
                $141 = ((($9)) + 11|0);
                $142 = ((($10)) + 8|0);
                $143 = ((($10)) + 4|0);
                $144 = ((($6)) + 124|0);
                $145 = ((($10)) + 11|0);
                $146 = ((($11)) + 8|0);
                $147 = ((($11)) + 4|0);
                $148 = ((($6)) + 136|0);
                $149 = ((($11)) + 11|0);
                $150 = ((($12)) + 8|0);
                $151 = ((($12)) + 4|0);
                $152 = ((($6)) + 148|0);
                $153 = ((($12)) + 11|0);
                $154 = ((($13)) + 8|0);
                $155 = ((($13)) + 4|0);
                $156 = ((($6)) + 160|0);
                $157 = ((($13)) + 11|0);
                $158 = ((($14)) + 8|0);
                $159 = ((($14)) + 4|0);
                $160 = ((($6)) + 172|0);
                $161 = ((($14)) + 11|0);
                $162 = ((($15)) + 8|0);
                $163 = ((($15)) + 4|0);
                $164 = ((($6)) + 248|0);
                $165 = ((($15)) + 11|0);
                $166 = ((($16)) + 8|0);
                $167 = ((($16)) + 4|0);
                $168 = ((($16)) + 11|0);
                $169 = ((($6)) + 356|0);
                $170 = ((($6)) + 360|0);
                $171 = ((($17)) + 8|0);
                $172 = ((($17)) + 4|0);
                $173 = ((($6)) + 88|0);
                $174 = ((($17)) + 11|0);
                $175 = ((($18)) + 8|0);
                $176 = ((($18)) + 4|0);
                $177 = ((($6)) + 56|0);
                $178 = ((($18)) + 11|0);
                $179 = ((($19)) + 8|0);
                $180 = ((($19)) + 4|0);
                $181 = ((($6)) + 68|0);
                $182 = ((($19)) + 11|0);
                $183 = ((($20)) + 8|0);
                $184 = ((($20)) + 4|0);
                $185 = ((($6)) + 64|0);
                $186 = ((($20)) + 11|0);
                $187 = ((($21)) + 8|0);
                $188 = ((($21)) + 4|0);
                $189 = ((($6)) + 60|0);
                $190 = ((($21)) + 11|0);
                $191 = ((($22)) + 8|0);
                $192 = ((($22)) + 4|0);
                $193 = ((($6)) + 72|0);
                $194 = ((($22)) + 11|0);
                $195 = ((($23)) + 8|0);
                $196 = ((($23)) + 4|0);
                $197 = ((($6)) + 76|0);
                $198 = ((($23)) + 11|0);
                $199 = ((($24)) + 8|0);
                $200 = ((($24)) + 4|0);
                $201 = ((($6)) + 80|0);
                $202 = ((($24)) + 11|0);
                $203 = ((($25)) + 8|0);
                $204 = ((($25)) + 4|0);
                $205 = ((($6)) + 336|0);
                $206 = ((($25)) + 11|0);
                $207 = ((($26)) + 8|0);
                $208 = ((($26)) + 4|0);
                $209 = ((($26)) + 11|0);
                $210 = ((($6)) + 376|0);
                $$sroa$0550$01097 = $125;
                L40: while(1) {
                 $231 = HEAP32[$$sroa$0550$01097>>2]|0;
                 $232 = ((($231)) + 4|0);
                 $233 = HEAP32[$232>>2]|0;
                 $234 = ((($231)) + 68|0);
                 $235 = HEAP32[$234>>2]|0;
                 $236 = ($235|0)==(0|0);
                 do {
                  if (!($236)) {
                   __THREW__ = 0;
                   $237 = (invoke_ii(3279,($235|0))|0);
                   $238 = __THREW__; __THREW__ = 0;
                   $239 = $238&1;
                   if ($239) {
                    label = 52;
                    break L40;
                   }
                   $240 = ($237|0)!=(0|0);
                   $241 = ($233|0)!=(0|0);
                   $or$cond = $241 & $240;
                   if (!($or$cond)) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3452,($6|0));
                   $242 = __THREW__; __THREW__ = 0;
                   $243 = $242&1;
                   if ($243) {
                    label = 53;
                    break L40;
                   }
                   $244 = HEAP32[$237>>2]|0;
                   $245 = ((($244)) + 188|0);
                   $246 = HEAP32[$245>>2]|0;
                   __THREW__ = 0;
                   invoke_vii($246|0,($237|0),($6|0));
                   $247 = __THREW__; __THREW__ = 0;
                   $248 = $247&1;
                   if ($248) {
                    label = 54;
                    break L40;
                   }
                   __THREW__ = 0;
                   invoke_vi(1155,($6|0));
                   $249 = __THREW__; __THREW__ = 0;
                   $250 = $249&1;
                   if ($250) {
                    label = 54;
                    break L40;
                   }
                   $251 = HEAP32[$128>>2]|0;
                   $252 = ($251|0)==($129|0);
                   if ($252) {
                    $$0208$lcssa = 0;
                   } else {
                    $$02081089 = 0;$$sroa$0540$01088 = $251;
                    while(1) {
                     $253 = ((($$sroa$0540$01088)) + 20|0);
                     $254 = HEAP32[$253>>2]|0;
                     $255 = (($254) + ($$02081089))|0;
                     $256 = ((($$sroa$0540$01088)) + 4|0);
                     $257 = HEAP32[$256>>2]|0;
                     $258 = ($257|0)==(0|0);
                     do {
                      if ($258) {
                       $259 = ((($$sroa$0540$01088)) + 8|0);
                       $260 = HEAP32[$259>>2]|0;
                       $261 = HEAP32[$260>>2]|0;
                       $262 = ($261|0)==($$sroa$0540$01088|0);
                       if ($262) {
                        $$sroa$0540$0$be = $260;
                        break;
                       } else {
                        $267 = $259;
                       }
                       while(1) {
                        $266 = HEAP32[$267>>2]|0;
                        $268 = ((($266)) + 8|0);
                        $269 = HEAP32[$268>>2]|0;
                        $270 = HEAP32[$269>>2]|0;
                        $271 = ($270|0)==($266|0);
                        if ($271) {
                         $$sroa$0540$0$be = $269;
                         break;
                        } else {
                         $267 = $268;
                        }
                       }
                      } else {
                       $$0$i$i$i$i = $257;
                       while(1) {
                        $264 = HEAP32[$$0$i$i$i$i>>2]|0;
                        $265 = ($264|0)==(0|0);
                        if ($265) {
                         break;
                        } else {
                         $$0$i$i$i$i = $264;
                        }
                       }
                       $$sroa$0540$0$be = $$0$i$i$i$i;
                      }
                     } while(0);
                     $263 = ($$sroa$0540$0$be|0)==($129|0);
                     if ($263) {
                      $$0208$lcssa = $255;
                      break;
                     } else {
                      $$02081089 = $255;$$sroa$0540$01088 = $$sroa$0540$0$be;
                     }
                    }
                   }
                   ;HEAP32[$7>>2]=0|0;HEAP32[$7+4>>2]=0|0;HEAP32[$7+8>>2]=0|0;
                   __THREW__ = 0;
                   $278 = (invoke_ii(3276,32)|0);
                   $279 = __THREW__; __THREW__ = 0;
                   $280 = $279&1;
                   if ($280) {
                    label = 102;
                    break L40;
                   }
                   HEAP32[$7>>2] = $278;
                   HEAP32[$130>>2] = -2147483616;
                   HEAP32[$131>>2] = 25;
                   dest=$278; src=104885; stop=dest+25|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                   $281 = ((($278)) + 25|0);
                   HEAP8[$281>>0] = 0;
                   $282 = HEAP32[$132>>2]|0;
                   $283 = (+($282>>>0));
                   __THREW__ = 0;
                   (invoke_iiiid(3392,($233|0),($284|0),($7|0),(+$283))|0);
                   $285 = __THREW__; __THREW__ = 0;
                   $286 = $285&1;
                   if ($286) {
                    label = 103;
                    break L40;
                   }
                   $287 = HEAP8[$133>>0]|0;
                   $288 = ($287<<24>>24)<(0);
                   if ($288) {
                    $289 = HEAP32[$7>>2]|0;
                    __ZdlPv($289);
                   }
                   ;HEAP32[$8>>2]=0|0;HEAP32[$8+4>>2]=0|0;HEAP32[$8+8>>2]=0|0;
                   __THREW__ = 0;
                   $290 = (invoke_ii(3276,32)|0);
                   $291 = __THREW__; __THREW__ = 0;
                   $292 = $291&1;
                   if ($292) {
                    label = 106;
                    break L40;
                   }
                   HEAP32[$8>>2] = $290;
                   HEAP32[$134>>2] = -2147483616;
                   HEAP32[$135>>2] = 22;
                   dest=$290; src=104911; stop=dest+22|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                   $293 = ((($290)) + 22|0);
                   HEAP8[$293>>0] = 0;
                   $294 = HEAP32[$136>>2]|0;
                   $295 = (+($294>>>0));
                   __THREW__ = 0;
                   (invoke_iiiid(3392,($233|0),($284|0),($8|0),(+$295))|0);
                   $296 = __THREW__; __THREW__ = 0;
                   $297 = $296&1;
                   if ($297) {
                    label = 107;
                    break L40;
                   }
                   $298 = HEAP8[$137>>0]|0;
                   $299 = ($298<<24>>24)<(0);
                   if ($299) {
                    $300 = HEAP32[$8>>2]|0;
                    __ZdlPv($300);
                   }
                   ;HEAP32[$9>>2]=0|0;HEAP32[$9+4>>2]=0|0;HEAP32[$9+8>>2]=0|0;
                   __THREW__ = 0;
                   $301 = (invoke_ii(3276,32)|0);
                   $302 = __THREW__; __THREW__ = 0;
                   $303 = $302&1;
                   if ($303) {
                    label = 110;
                    break L40;
                   }
                   HEAP32[$9>>2] = $301;
                   HEAP32[$138>>2] = -2147483616;
                   HEAP32[$139>>2] = 26;
                   dest=$301; src=104934; stop=dest+26|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                   $304 = ((($301)) + 26|0);
                   HEAP8[$304>>0] = 0;
                   $305 = HEAP32[$140>>2]|0;
                   $306 = (+($305>>>0));
                   __THREW__ = 0;
                   (invoke_iiiid(3392,($233|0),($284|0),($9|0),(+$306))|0);
                   $307 = __THREW__; __THREW__ = 0;
                   $308 = $307&1;
                   if ($308) {
                    label = 111;
                    break L40;
                   }
                   $309 = HEAP8[$141>>0]|0;
                   $310 = ($309<<24>>24)<(0);
                   if ($310) {
                    $311 = HEAP32[$9>>2]|0;
                    __ZdlPv($311);
                   }
                   ;HEAP32[$10>>2]=0|0;HEAP32[$10+4>>2]=0|0;HEAP32[$10+8>>2]=0|0;
                   __THREW__ = 0;
                   $312 = (invoke_ii(3276,32)|0);
                   $313 = __THREW__; __THREW__ = 0;
                   $314 = $313&1;
                   if ($314) {
                    label = 114;
                    break L40;
                   }
                   HEAP32[$10>>2] = $312;
                   HEAP32[$142>>2] = -2147483616;
                   HEAP32[$143>>2] = 20;
                   dest=$312; src=104961; stop=dest+20|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                   $315 = ((($312)) + 20|0);
                   HEAP8[$315>>0] = 0;
                   $316 = HEAP32[$144>>2]|0;
                   $317 = (+($316>>>0));
                   __THREW__ = 0;
                   (invoke_iiiid(3392,($233|0),($284|0),($10|0),(+$317))|0);
                   $318 = __THREW__; __THREW__ = 0;
                   $319 = $318&1;
                   if ($319) {
                    label = 115;
                    break L40;
                   }
                   $320 = HEAP8[$145>>0]|0;
                   $321 = ($320<<24>>24)<(0);
                   if ($321) {
                    $322 = HEAP32[$10>>2]|0;
                    __ZdlPv($322);
                   }
                   ;HEAP32[$11>>2]=0|0;HEAP32[$11+4>>2]=0|0;HEAP32[$11+8>>2]=0|0;
                   __THREW__ = 0;
                   $323 = (invoke_ii(3276,32)|0);
                   $324 = __THREW__; __THREW__ = 0;
                   $325 = $324&1;
                   if ($325) {
                    label = 118;
                    break L40;
                   }
                   HEAP32[$11>>2] = $323;
                   HEAP32[$146>>2] = -2147483616;
                   HEAP32[$147>>2] = 23;
                   dest=$323; src=104982; stop=dest+23|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                   $326 = ((($323)) + 23|0);
                   HEAP8[$326>>0] = 0;
                   $327 = HEAP32[$148>>2]|0;
                   $328 = (+($327>>>0));
                   __THREW__ = 0;
                   (invoke_iiiid(3392,($233|0),($284|0),($11|0),(+$328))|0);
                   $329 = __THREW__; __THREW__ = 0;
                   $330 = $329&1;
                   if ($330) {
                    label = 119;
                    break L40;
                   }
                   $331 = HEAP8[$149>>0]|0;
                   $332 = ($331<<24>>24)<(0);
                   if ($332) {
                    $333 = HEAP32[$11>>2]|0;
                    __ZdlPv($333);
                   }
                   ;HEAP32[$12>>2]=0|0;HEAP32[$12+4>>2]=0|0;HEAP32[$12+8>>2]=0|0;
                   __THREW__ = 0;
                   $334 = (invoke_ii(3276,32)|0);
                   $335 = __THREW__; __THREW__ = 0;
                   $336 = $335&1;
                   if ($336) {
                    label = 122;
                    break L40;
                   }
                   HEAP32[$12>>2] = $334;
                   HEAP32[$150>>2] = -2147483616;
                   HEAP32[$151>>2] = 22;
                   dest=$334; src=105006; stop=dest+22|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                   $337 = ((($334)) + 22|0);
                   HEAP8[$337>>0] = 0;
                   $338 = HEAP32[$152>>2]|0;
                   $339 = (+($338>>>0));
                   __THREW__ = 0;
                   (invoke_iiiid(3392,($233|0),($284|0),($12|0),(+$339))|0);
                   $340 = __THREW__; __THREW__ = 0;
                   $341 = $340&1;
                   if ($341) {
                    label = 123;
                    break L40;
                   }
                   $342 = HEAP8[$153>>0]|0;
                   $343 = ($342<<24>>24)<(0);
                   if ($343) {
                    $344 = HEAP32[$12>>2]|0;
                    __ZdlPv($344);
                   }
                   ;HEAP32[$13>>2]=0|0;HEAP32[$13+4>>2]=0|0;HEAP32[$13+8>>2]=0|0;
                   __THREW__ = 0;
                   $345 = (invoke_ii(3276,32)|0);
                   $346 = __THREW__; __THREW__ = 0;
                   $347 = $346&1;
                   if ($347) {
                    label = 126;
                    break L40;
                   }
                   HEAP32[$13>>2] = $345;
                   HEAP32[$154>>2] = -2147483616;
                   HEAP32[$155>>2] = 25;
                   dest=$345; src=105029; stop=dest+25|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                   $348 = ((($345)) + 25|0);
                   HEAP8[$348>>0] = 0;
                   $349 = HEAP32[$156>>2]|0;
                   $350 = (+($349>>>0));
                   __THREW__ = 0;
                   (invoke_iiiid(3392,($233|0),($284|0),($13|0),(+$350))|0);
                   $351 = __THREW__; __THREW__ = 0;
                   $352 = $351&1;
                   if ($352) {
                    label = 127;
                    break L40;
                   }
                   $353 = HEAP8[$157>>0]|0;
                   $354 = ($353<<24>>24)<(0);
                   if ($354) {
                    $355 = HEAP32[$13>>2]|0;
                    __ZdlPv($355);
                   }
                   ;HEAP32[$14>>2]=0|0;HEAP32[$14+4>>2]=0|0;HEAP32[$14+8>>2]=0|0;
                   __THREW__ = 0;
                   $356 = (invoke_ii(3276,32)|0);
                   $357 = __THREW__; __THREW__ = 0;
                   $358 = $357&1;
                   if ($358) {
                    label = 130;
                    break L40;
                   }
                   HEAP32[$14>>2] = $356;
                   HEAP32[$158>>2] = -2147483616;
                   HEAP32[$159>>2] = 25;
                   dest=$356; src=105055; stop=dest+25|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                   $359 = ((($356)) + 25|0);
                   HEAP8[$359>>0] = 0;
                   $360 = HEAP32[$160>>2]|0;
                   $361 = (+($360>>>0));
                   __THREW__ = 0;
                   (invoke_iiiid(3392,($233|0),($284|0),($14|0),(+$361))|0);
                   $362 = __THREW__; __THREW__ = 0;
                   $363 = $362&1;
                   if ($363) {
                    label = 131;
                    break L40;
                   }
                   $364 = HEAP8[$161>>0]|0;
                   $365 = ($364<<24>>24)<(0);
                   if ($365) {
                    $366 = HEAP32[$14>>2]|0;
                    __ZdlPv($366);
                   }
                   ;HEAP32[$15>>2]=0|0;HEAP32[$15+4>>2]=0|0;HEAP32[$15+8>>2]=0|0;
                   __THREW__ = 0;
                   $367 = (invoke_ii(3276,32)|0);
                   $368 = __THREW__; __THREW__ = 0;
                   $369 = $368&1;
                   if ($369) {
                    label = 134;
                    break L40;
                   }
                   HEAP32[$15>>2] = $367;
                   HEAP32[$162>>2] = -2147483616;
                   HEAP32[$163>>2] = 25;
                   dest=$367; src=105081; stop=dest+25|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                   $370 = ((($367)) + 25|0);
                   HEAP8[$370>>0] = 0;
                   $371 = HEAP32[$164>>2]|0;
                   $372 = (+($371>>>0));
                   __THREW__ = 0;
                   (invoke_iiiid(3392,($233|0),($284|0),($15|0),(+$372))|0);
                   $373 = __THREW__; __THREW__ = 0;
                   $374 = $373&1;
                   if ($374) {
                    label = 135;
                    break L40;
                   }
                   $375 = HEAP8[$165>>0]|0;
                   $376 = ($375<<24>>24)<(0);
                   if ($376) {
                    $377 = HEAP32[$15>>2]|0;
                    __ZdlPv($377);
                   }
                   ;HEAP32[$16>>2]=0|0;HEAP32[$16+4>>2]=0|0;HEAP32[$16+8>>2]=0|0;
                   __THREW__ = 0;
                   $378 = (invoke_ii(3276,32)|0);
                   $379 = __THREW__; __THREW__ = 0;
                   $380 = $379&1;
                   if ($380) {
                    label = 138;
                    break L40;
                   }
                   HEAP32[$16>>2] = $378;
                   HEAP32[$166>>2] = -2147483616;
                   HEAP32[$167>>2] = 27;
                   dest=$378; src=105107; stop=dest+27|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                   $381 = ((($378)) + 27|0);
                   HEAP8[$381>>0] = 0;
                   $382 = (+($$0208$lcssa>>>0));
                   __THREW__ = 0;
                   (invoke_iiiid(3392,($233|0),($284|0),($16|0),(+$382))|0);
                   $383 = __THREW__; __THREW__ = 0;
                   $384 = $383&1;
                   if ($384) {
                    label = 139;
                    break L40;
                   }
                   $385 = HEAP8[$168>>0]|0;
                   $386 = ($385<<24>>24)<(0);
                   if ($386) {
                    $387 = HEAP32[$16>>2]|0;
                    __ZdlPv($387);
                   }
                   $388 = HEAP32[$169>>2]|0;
                   $389 = ($388|0)==($170|0);
                   if ($389) {
                    $$0209$lcssa = 0;
                   } else {
                    $$02091094 = 0;$$sroa$0540$11093 = $388;
                    while(1) {
                     $390 = ((($$sroa$0540$11093)) + 20|0);
                     $391 = HEAP32[$390>>2]|0;
                     $392 = (($391) + ($$02091094))|0;
                     $393 = ((($$sroa$0540$11093)) + 4|0);
                     $394 = HEAP32[$393>>2]|0;
                     $395 = ($394|0)==(0|0);
                     do {
                      if ($395) {
                       $396 = ((($$sroa$0540$11093)) + 8|0);
                       $397 = HEAP32[$396>>2]|0;
                       $398 = HEAP32[$397>>2]|0;
                       $399 = ($398|0)==($$sroa$0540$11093|0);
                       if ($399) {
                        $$sroa$0540$1$be = $397;
                        break;
                       } else {
                        $404 = $396;
                       }
                       while(1) {
                        $403 = HEAP32[$404>>2]|0;
                        $405 = ((($403)) + 8|0);
                        $406 = HEAP32[$405>>2]|0;
                        $407 = HEAP32[$406>>2]|0;
                        $408 = ($407|0)==($403|0);
                        if ($408) {
                         $$sroa$0540$1$be = $406;
                         break;
                        } else {
                         $404 = $405;
                        }
                       }
                      } else {
                       $$0$i$i$i$i329 = $394;
                       while(1) {
                        $401 = HEAP32[$$0$i$i$i$i329>>2]|0;
                        $402 = ($401|0)==(0|0);
                        if ($402) {
                         break;
                        } else {
                         $$0$i$i$i$i329 = $401;
                        }
                       }
                       $$sroa$0540$1$be = $$0$i$i$i$i329;
                      }
                     } while(0);
                     $400 = ($$sroa$0540$1$be|0)==($170|0);
                     if ($400) {
                      $$0209$lcssa = $392;
                      break;
                     } else {
                      $$02091094 = $392;$$sroa$0540$11093 = $$sroa$0540$1$be;
                     }
                    }
                   }
                   ;HEAP32[$17>>2]=0|0;HEAP32[$17+4>>2]=0|0;HEAP32[$17+8>>2]=0|0;
                   __THREW__ = 0;
                   $479 = (invoke_ii(3276,32)|0);
                   $480 = __THREW__; __THREW__ = 0;
                   $481 = $480&1;
                   if ($481) {
                    label = 187;
                    break L40;
                   }
                   HEAP32[$17>>2] = $479;
                   HEAP32[$171>>2] = -2147483616;
                   HEAP32[$172>>2] = 28;
                   dest=$479; src=105135; stop=dest+28|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                   $482 = ((($479)) + 28|0);
                   HEAP8[$482>>0] = 0;
                   $483 = HEAP32[$173>>2]|0;
                   $484 = (+($483>>>0));
                   __THREW__ = 0;
                   (invoke_iiiid(3392,($233|0),($284|0),($17|0),(+$484))|0);
                   $485 = __THREW__; __THREW__ = 0;
                   $486 = $485&1;
                   if ($486) {
                    label = 188;
                    break L40;
                   }
                   $487 = HEAP8[$174>>0]|0;
                   $488 = ($487<<24>>24)<(0);
                   if ($488) {
                    $489 = HEAP32[$17>>2]|0;
                    __ZdlPv($489);
                   }
                   ;HEAP32[$18>>2]=0|0;HEAP32[$18+4>>2]=0|0;HEAP32[$18+8>>2]=0|0;
                   __THREW__ = 0;
                   $490 = (invoke_ii(3276,32)|0);
                   $491 = __THREW__; __THREW__ = 0;
                   $492 = $491&1;
                   if ($492) {
                    label = 191;
                    break L40;
                   }
                   HEAP32[$18>>2] = $490;
                   HEAP32[$175>>2] = -2147483616;
                   HEAP32[$176>>2] = 25;
                   dest=$490; src=105164; stop=dest+25|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                   $493 = ((($490)) + 25|0);
                   HEAP8[$493>>0] = 0;
                   $494 = HEAP32[$177>>2]|0;
                   $495 = (+($494>>>0));
                   __THREW__ = 0;
                   (invoke_iiiid(3392,($233|0),($284|0),($18|0),(+$495))|0);
                   $496 = __THREW__; __THREW__ = 0;
                   $497 = $496&1;
                   if ($497) {
                    label = 192;
                    break L40;
                   }
                   $498 = HEAP8[$178>>0]|0;
                   $499 = ($498<<24>>24)<(0);
                   if ($499) {
                    $500 = HEAP32[$18>>2]|0;
                    __ZdlPv($500);
                   }
                   ;HEAP32[$19>>2]=0|0;HEAP32[$19+4>>2]=0|0;HEAP32[$19+8>>2]=0|0;
                   __THREW__ = 0;
                   $501 = (invoke_ii(3276,32)|0);
                   $502 = __THREW__; __THREW__ = 0;
                   $503 = $502&1;
                   if ($503) {
                    label = 195;
                    break L40;
                   }
                   HEAP32[$19>>2] = $501;
                   HEAP32[$179>>2] = -2147483616;
                   HEAP32[$180>>2] = 29;
                   dest=$501; src=105190; stop=dest+29|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                   $504 = ((($501)) + 29|0);
                   HEAP8[$504>>0] = 0;
                   $505 = HEAP32[$181>>2]|0;
                   $506 = (+($505>>>0));
                   __THREW__ = 0;
                   (invoke_iiiid(3392,($233|0),($284|0),($19|0),(+$506))|0);
                   $507 = __THREW__; __THREW__ = 0;
                   $508 = $507&1;
                   if ($508) {
                    label = 196;
                    break L40;
                   }
                   $509 = HEAP8[$182>>0]|0;
                   $510 = ($509<<24>>24)<(0);
                   if ($510) {
                    $511 = HEAP32[$19>>2]|0;
                    __ZdlPv($511);
                   }
                   ;HEAP32[$20>>2]=0|0;HEAP32[$20+4>>2]=0|0;HEAP32[$20+8>>2]=0|0;
                   __THREW__ = 0;
                   $512 = (invoke_ii(3276,32)|0);
                   $513 = __THREW__; __THREW__ = 0;
                   $514 = $513&1;
                   if ($514) {
                    label = 199;
                    break L40;
                   }
                   HEAP32[$20>>2] = $512;
                   HEAP32[$183>>2] = -2147483616;
                   HEAP32[$184>>2] = 23;
                   dest=$512; src=105220; stop=dest+23|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                   $515 = ((($512)) + 23|0);
                   HEAP8[$515>>0] = 0;
                   $516 = HEAP32[$185>>2]|0;
                   $517 = (+($516>>>0));
                   __THREW__ = 0;
                   (invoke_iiiid(3392,($233|0),($284|0),($20|0),(+$517))|0);
                   $518 = __THREW__; __THREW__ = 0;
                   $519 = $518&1;
                   if ($519) {
                    label = 200;
                    break L40;
                   }
                   $520 = HEAP8[$186>>0]|0;
                   $521 = ($520<<24>>24)<(0);
                   if ($521) {
                    $522 = HEAP32[$20>>2]|0;
                    __ZdlPv($522);
                   }
                   ;HEAP32[$21>>2]=0|0;HEAP32[$21+4>>2]=0|0;HEAP32[$21+8>>2]=0|0;
                   __THREW__ = 0;
                   $523 = (invoke_ii(3276,32)|0);
                   $524 = __THREW__; __THREW__ = 0;
                   $525 = $524&1;
                   if ($525) {
                    label = 203;
                    break L40;
                   }
                   HEAP32[$21>>2] = $523;
                   HEAP32[$187>>2] = -2147483616;
                   HEAP32[$188>>2] = 26;
                   dest=$523; src=105244; stop=dest+26|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                   $526 = ((($523)) + 26|0);
                   HEAP8[$526>>0] = 0;
                   $527 = HEAP32[$189>>2]|0;
                   $528 = (+($527>>>0));
                   __THREW__ = 0;
                   (invoke_iiiid(3392,($233|0),($284|0),($21|0),(+$528))|0);
                   $529 = __THREW__; __THREW__ = 0;
                   $530 = $529&1;
                   if ($530) {
                    label = 204;
                    break L40;
                   }
                   $531 = HEAP8[$190>>0]|0;
                   $532 = ($531<<24>>24)<(0);
                   if ($532) {
                    $533 = HEAP32[$21>>2]|0;
                    __ZdlPv($533);
                   }
                   ;HEAP32[$22>>2]=0|0;HEAP32[$22+4>>2]=0|0;HEAP32[$22+8>>2]=0|0;
                   __THREW__ = 0;
                   $534 = (invoke_ii(3276,32)|0);
                   $535 = __THREW__; __THREW__ = 0;
                   $536 = $535&1;
                   if ($536) {
                    label = 207;
                    break L40;
                   }
                   HEAP32[$22>>2] = $534;
                   HEAP32[$191>>2] = -2147483616;
                   HEAP32[$192>>2] = 25;
                   dest=$534; src=105271; stop=dest+25|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                   $537 = ((($534)) + 25|0);
                   HEAP8[$537>>0] = 0;
                   $538 = HEAP32[$193>>2]|0;
                   $539 = (+($538>>>0));
                   __THREW__ = 0;
                   (invoke_iiiid(3392,($233|0),($284|0),($22|0),(+$539))|0);
                   $540 = __THREW__; __THREW__ = 0;
                   $541 = $540&1;
                   if ($541) {
                    label = 208;
                    break L40;
                   }
                   $542 = HEAP8[$194>>0]|0;
                   $543 = ($542<<24>>24)<(0);
                   if ($543) {
                    $544 = HEAP32[$22>>2]|0;
                    __ZdlPv($544);
                   }
                   ;HEAP32[$23>>2]=0|0;HEAP32[$23+4>>2]=0|0;HEAP32[$23+8>>2]=0|0;
                   __THREW__ = 0;
                   $545 = (invoke_ii(3276,32)|0);
                   $546 = __THREW__; __THREW__ = 0;
                   $547 = $546&1;
                   if ($547) {
                    label = 211;
                    break L40;
                   }
                   HEAP32[$23>>2] = $545;
                   HEAP32[$195>>2] = -2147483616;
                   HEAP32[$196>>2] = 28;
                   dest=$545; src=105297; stop=dest+28|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                   $548 = ((($545)) + 28|0);
                   HEAP8[$548>>0] = 0;
                   $549 = HEAP32[$197>>2]|0;
                   $550 = (+($549>>>0));
                   __THREW__ = 0;
                   (invoke_iiiid(3392,($233|0),($284|0),($23|0),(+$550))|0);
                   $551 = __THREW__; __THREW__ = 0;
                   $552 = $551&1;
                   if ($552) {
                    label = 212;
                    break L40;
                   }
                   $553 = HEAP8[$198>>0]|0;
                   $554 = ($553<<24>>24)<(0);
                   if ($554) {
                    $555 = HEAP32[$23>>2]|0;
                    __ZdlPv($555);
                   }
                   ;HEAP32[$24>>2]=0|0;HEAP32[$24+4>>2]=0|0;HEAP32[$24+8>>2]=0|0;
                   __THREW__ = 0;
                   $556 = (invoke_ii(3276,32)|0);
                   $557 = __THREW__; __THREW__ = 0;
                   $558 = $557&1;
                   if ($558) {
                    label = 215;
                    break L40;
                   }
                   HEAP32[$24>>2] = $556;
                   HEAP32[$199>>2] = -2147483616;
                   HEAP32[$200>>2] = 28;
                   dest=$556; src=105326; stop=dest+28|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                   $559 = ((($556)) + 28|0);
                   HEAP8[$559>>0] = 0;
                   $560 = HEAP32[$201>>2]|0;
                   $561 = (+($560>>>0));
                   __THREW__ = 0;
                   (invoke_iiiid(3392,($233|0),($284|0),($24|0),(+$561))|0);
                   $562 = __THREW__; __THREW__ = 0;
                   $563 = $562&1;
                   if ($563) {
                    label = 216;
                    break L40;
                   }
                   $564 = HEAP8[$202>>0]|0;
                   $565 = ($564<<24>>24)<(0);
                   if ($565) {
                    $566 = HEAP32[$24>>2]|0;
                    __ZdlPv($566);
                   }
                   ;HEAP32[$25>>2]=0|0;HEAP32[$25+4>>2]=0|0;HEAP32[$25+8>>2]=0|0;
                   __THREW__ = 0;
                   $567 = (invoke_ii(3276,32)|0);
                   $568 = __THREW__; __THREW__ = 0;
                   $569 = $568&1;
                   if ($569) {
                    label = 219;
                    break L40;
                   }
                   HEAP32[$25>>2] = $567;
                   HEAP32[$203>>2] = -2147483616;
                   HEAP32[$204>>2] = 28;
                   dest=$567; src=105355; stop=dest+28|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                   $570 = ((($567)) + 28|0);
                   HEAP8[$570>>0] = 0;
                   $571 = HEAP32[$205>>2]|0;
                   $572 = (+($571>>>0));
                   __THREW__ = 0;
                   (invoke_iiiid(3392,($233|0),($284|0),($25|0),(+$572))|0);
                   $573 = __THREW__; __THREW__ = 0;
                   $574 = $573&1;
                   if ($574) {
                    label = 220;
                    break L40;
                   }
                   $575 = HEAP8[$206>>0]|0;
                   $576 = ($575<<24>>24)<(0);
                   if ($576) {
                    $577 = HEAP32[$25>>2]|0;
                    __ZdlPv($577);
                   }
                   ;HEAP32[$26>>2]=0|0;HEAP32[$26+4>>2]=0|0;HEAP32[$26+8>>2]=0|0;
                   __THREW__ = 0;
                   $578 = (invoke_ii(3276,32)|0);
                   $579 = __THREW__; __THREW__ = 0;
                   $580 = $579&1;
                   if ($580) {
                    label = 223;
                    break L40;
                   }
                   HEAP32[$26>>2] = $578;
                   HEAP32[$207>>2] = -2147483616;
                   HEAP32[$208>>2] = 30;
                   dest=$578; src=105384; stop=dest+30|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                   $581 = ((($578)) + 30|0);
                   HEAP8[$581>>0] = 0;
                   $582 = (+($$0209$lcssa>>>0));
                   __THREW__ = 0;
                   (invoke_iiiid(3392,($233|0),($284|0),($26|0),(+$582))|0);
                   $583 = __THREW__; __THREW__ = 0;
                   $584 = $583&1;
                   if ($584) {
                    label = 224;
                    break L40;
                   }
                   $585 = HEAP8[$209>>0]|0;
                   $586 = ($585<<24>>24)<(0);
                   if ($586) {
                    $587 = HEAP32[$26>>2]|0;
                    __ZdlPv($587);
                   }
                   __THREW__ = 0;
                   invoke_vii(3453,($6|0),(50840|0));
                   $588 = __THREW__; __THREW__ = 0;
                   $589 = $588&1;
                   if ($589) {
                    label = 184;
                    break L40;
                   }
                   __THREW__ = 0;
                   invoke_vi(388,($210|0));
                   $590 = __THREW__; __THREW__ = 0;
                   $591 = $590&1;
                   if ($591) {
                    label = 227;
                    break L40;
                   }
                  }
                 } while(0);
                 $680 = ((($$sroa$0550$01097)) + 4|0);
                 $681 = HEAP32[$118>>2]|0;
                 $682 = ($680|0)==($681|0);
                 if ($682) {
                  label = 27;
                  break;
                 } else {
                  $$sroa$0550$01097 = $680;
                 }
                }
                switch (label|0) {
                 case 27: {
                  $$pre = HEAP32[$5>>2]|0;
                  $211 = $$pre;$213 = $680;
                  break L38;
                  break;
                 }
                 case 52: {
                  $272 = ___cxa_find_matching_catch_2()|0;
                  $273 = tempRet0;
                  $$28 = $272;$$28184 = $273;
                  break L35;
                  break;
                 }
                 case 53: {
                  $274 = ___cxa_find_matching_catch_2()|0;
                  $275 = tempRet0;
                  $$28 = $274;$$28184 = $275;
                  break L35;
                  break;
                 }
                 case 54: {
                  $276 = ___cxa_find_matching_catch_2()|0;
                  $277 = tempRet0;
                  $$23 = $276;$$23179 = $277;
                  label = 229;
                  break;
                 }
                 case 102: {
                  $409 = ___cxa_find_matching_catch_2()|0;
                  $410 = tempRet0;
                  $$1 = $409;$$1157 = $410;
                  label = 105;
                  break;
                 }
                 case 103: {
                  $411 = ___cxa_find_matching_catch_2()|0;
                  $412 = tempRet0;
                  $413 = HEAP8[$133>>0]|0;
                  $414 = ($413<<24>>24)<(0);
                  if (!($414)) {
                   $$1 = $411;$$1157 = $412;
                   label = 105;
                   break;
                  }
                  $415 = HEAP32[$7>>2]|0;
                  __ZdlPv($415);
                  $$1 = $411;$$1157 = $412;
                  label = 105;
                  break;
                 }
                 case 106: {
                  $416 = ___cxa_find_matching_catch_2()|0;
                  $417 = tempRet0;
                  $$2 = $416;$$2158 = $417;
                  label = 109;
                  break;
                 }
                 case 107: {
                  $418 = ___cxa_find_matching_catch_2()|0;
                  $419 = tempRet0;
                  $420 = HEAP8[$137>>0]|0;
                  $421 = ($420<<24>>24)<(0);
                  if (!($421)) {
                   $$2 = $418;$$2158 = $419;
                   label = 109;
                   break;
                  }
                  $422 = HEAP32[$8>>2]|0;
                  __ZdlPv($422);
                  $$2 = $418;$$2158 = $419;
                  label = 109;
                  break;
                 }
                 case 110: {
                  $423 = ___cxa_find_matching_catch_2()|0;
                  $424 = tempRet0;
                  $$3 = $423;$$3159 = $424;
                  label = 113;
                  break;
                 }
                 case 111: {
                  $425 = ___cxa_find_matching_catch_2()|0;
                  $426 = tempRet0;
                  $427 = HEAP8[$141>>0]|0;
                  $428 = ($427<<24>>24)<(0);
                  if (!($428)) {
                   $$3 = $425;$$3159 = $426;
                   label = 113;
                   break;
                  }
                  $429 = HEAP32[$9>>2]|0;
                  __ZdlPv($429);
                  $$3 = $425;$$3159 = $426;
                  label = 113;
                  break;
                 }
                 case 114: {
                  $430 = ___cxa_find_matching_catch_2()|0;
                  $431 = tempRet0;
                  $$4 = $430;$$4160 = $431;
                  label = 117;
                  break;
                 }
                 case 115: {
                  $432 = ___cxa_find_matching_catch_2()|0;
                  $433 = tempRet0;
                  $434 = HEAP8[$145>>0]|0;
                  $435 = ($434<<24>>24)<(0);
                  if (!($435)) {
                   $$4 = $432;$$4160 = $433;
                   label = 117;
                   break;
                  }
                  $436 = HEAP32[$10>>2]|0;
                  __ZdlPv($436);
                  $$4 = $432;$$4160 = $433;
                  label = 117;
                  break;
                 }
                 case 118: {
                  $437 = ___cxa_find_matching_catch_2()|0;
                  $438 = tempRet0;
                  $$5 = $437;$$5161 = $438;
                  label = 121;
                  break;
                 }
                 case 119: {
                  $439 = ___cxa_find_matching_catch_2()|0;
                  $440 = tempRet0;
                  $441 = HEAP8[$149>>0]|0;
                  $442 = ($441<<24>>24)<(0);
                  if (!($442)) {
                   $$5 = $439;$$5161 = $440;
                   label = 121;
                   break;
                  }
                  $443 = HEAP32[$11>>2]|0;
                  __ZdlPv($443);
                  $$5 = $439;$$5161 = $440;
                  label = 121;
                  break;
                 }
                 case 122: {
                  $444 = ___cxa_find_matching_catch_2()|0;
                  $445 = tempRet0;
                  $$6 = $444;$$6162 = $445;
                  label = 125;
                  break;
                 }
                 case 123: {
                  $446 = ___cxa_find_matching_catch_2()|0;
                  $447 = tempRet0;
                  $448 = HEAP8[$153>>0]|0;
                  $449 = ($448<<24>>24)<(0);
                  if (!($449)) {
                   $$6 = $446;$$6162 = $447;
                   label = 125;
                   break;
                  }
                  $450 = HEAP32[$12>>2]|0;
                  __ZdlPv($450);
                  $$6 = $446;$$6162 = $447;
                  label = 125;
                  break;
                 }
                 case 126: {
                  $451 = ___cxa_find_matching_catch_2()|0;
                  $452 = tempRet0;
                  $$7 = $451;$$7163 = $452;
                  label = 129;
                  break;
                 }
                 case 127: {
                  $453 = ___cxa_find_matching_catch_2()|0;
                  $454 = tempRet0;
                  $455 = HEAP8[$157>>0]|0;
                  $456 = ($455<<24>>24)<(0);
                  if (!($456)) {
                   $$7 = $453;$$7163 = $454;
                   label = 129;
                   break;
                  }
                  $457 = HEAP32[$13>>2]|0;
                  __ZdlPv($457);
                  $$7 = $453;$$7163 = $454;
                  label = 129;
                  break;
                 }
                 case 130: {
                  $458 = ___cxa_find_matching_catch_2()|0;
                  $459 = tempRet0;
                  $$8 = $458;$$8164 = $459;
                  label = 133;
                  break;
                 }
                 case 131: {
                  $460 = ___cxa_find_matching_catch_2()|0;
                  $461 = tempRet0;
                  $462 = HEAP8[$161>>0]|0;
                  $463 = ($462<<24>>24)<(0);
                  if (!($463)) {
                   $$8 = $460;$$8164 = $461;
                   label = 133;
                   break;
                  }
                  $464 = HEAP32[$14>>2]|0;
                  __ZdlPv($464);
                  $$8 = $460;$$8164 = $461;
                  label = 133;
                  break;
                 }
                 case 134: {
                  $465 = ___cxa_find_matching_catch_2()|0;
                  $466 = tempRet0;
                  $$9 = $465;$$9165 = $466;
                  label = 137;
                  break;
                 }
                 case 135: {
                  $467 = ___cxa_find_matching_catch_2()|0;
                  $468 = tempRet0;
                  $469 = HEAP8[$165>>0]|0;
                  $470 = ($469<<24>>24)<(0);
                  if (!($470)) {
                   $$9 = $467;$$9165 = $468;
                   label = 137;
                   break;
                  }
                  $471 = HEAP32[$15>>2]|0;
                  __ZdlPv($471);
                  $$9 = $467;$$9165 = $468;
                  label = 137;
                  break;
                 }
                 case 138: {
                  $472 = ___cxa_find_matching_catch_2()|0;
                  $473 = tempRet0;
                  $$10 = $472;$$10166 = $473;
                  label = 141;
                  break;
                 }
                 case 139: {
                  $474 = ___cxa_find_matching_catch_2()|0;
                  $475 = tempRet0;
                  $476 = HEAP8[$168>>0]|0;
                  $477 = ($476<<24>>24)<(0);
                  if (!($477)) {
                   $$10 = $474;$$10166 = $475;
                   label = 141;
                   break;
                  }
                  $478 = HEAP32[$16>>2]|0;
                  __ZdlPv($478);
                  $$10 = $474;$$10166 = $475;
                  label = 141;
                  break;
                 }
                 case 184: {
                  $592 = ___cxa_find_matching_catch_2()|0;
                  $593 = tempRet0;
                  __THREW__ = 0;
                  invoke_vi(388,($210|0));
                  $594 = __THREW__; __THREW__ = 0;
                  $595 = $594&1;
                  if (!($595)) {
                   $eh$lpad$body417$index11Z2D = $593;$eh$lpad$body417$indexZ2D = $592;
                   label = 228;
                   break;
                  }
                  $596 = ___cxa_find_matching_catch_3(0|0)|0;
                  $597 = tempRet0;
                  ___clang_call_terminate($596);
                  // unreachable;
                  break;
                 }
                 case 187: {
                  $598 = ___cxa_find_matching_catch_2()|0;
                  $599 = tempRet0;
                  $$11 = $598;$$11167 = $599;
                  label = 190;
                  break;
                 }
                 case 188: {
                  $600 = ___cxa_find_matching_catch_2()|0;
                  $601 = tempRet0;
                  $602 = HEAP8[$174>>0]|0;
                  $603 = ($602<<24>>24)<(0);
                  if (!($603)) {
                   $$11 = $600;$$11167 = $601;
                   label = 190;
                   break;
                  }
                  $604 = HEAP32[$17>>2]|0;
                  __ZdlPv($604);
                  $$11 = $600;$$11167 = $601;
                  label = 190;
                  break;
                 }
                 case 191: {
                  $605 = ___cxa_find_matching_catch_2()|0;
                  $606 = tempRet0;
                  $$12 = $605;$$12168 = $606;
                  label = 194;
                  break;
                 }
                 case 192: {
                  $607 = ___cxa_find_matching_catch_2()|0;
                  $608 = tempRet0;
                  $609 = HEAP8[$178>>0]|0;
                  $610 = ($609<<24>>24)<(0);
                  if (!($610)) {
                   $$12 = $607;$$12168 = $608;
                   label = 194;
                   break;
                  }
                  $611 = HEAP32[$18>>2]|0;
                  __ZdlPv($611);
                  $$12 = $607;$$12168 = $608;
                  label = 194;
                  break;
                 }
                 case 195: {
                  $612 = ___cxa_find_matching_catch_2()|0;
                  $613 = tempRet0;
                  $$13 = $612;$$13169 = $613;
                  label = 198;
                  break;
                 }
                 case 196: {
                  $614 = ___cxa_find_matching_catch_2()|0;
                  $615 = tempRet0;
                  $616 = HEAP8[$182>>0]|0;
                  $617 = ($616<<24>>24)<(0);
                  if (!($617)) {
                   $$13 = $614;$$13169 = $615;
                   label = 198;
                   break;
                  }
                  $618 = HEAP32[$19>>2]|0;
                  __ZdlPv($618);
                  $$13 = $614;$$13169 = $615;
                  label = 198;
                  break;
                 }
                 case 199: {
                  $619 = ___cxa_find_matching_catch_2()|0;
                  $620 = tempRet0;
                  $$14 = $619;$$14170 = $620;
                  label = 202;
                  break;
                 }
                 case 200: {
                  $621 = ___cxa_find_matching_catch_2()|0;
                  $622 = tempRet0;
                  $623 = HEAP8[$186>>0]|0;
                  $624 = ($623<<24>>24)<(0);
                  if (!($624)) {
                   $$14 = $621;$$14170 = $622;
                   label = 202;
                   break;
                  }
                  $625 = HEAP32[$20>>2]|0;
                  __ZdlPv($625);
                  $$14 = $621;$$14170 = $622;
                  label = 202;
                  break;
                 }
                 case 203: {
                  $626 = ___cxa_find_matching_catch_2()|0;
                  $627 = tempRet0;
                  $$15 = $626;$$15171 = $627;
                  label = 206;
                  break;
                 }
                 case 204: {
                  $628 = ___cxa_find_matching_catch_2()|0;
                  $629 = tempRet0;
                  $630 = HEAP8[$190>>0]|0;
                  $631 = ($630<<24>>24)<(0);
                  if (!($631)) {
                   $$15 = $628;$$15171 = $629;
                   label = 206;
                   break;
                  }
                  $632 = HEAP32[$21>>2]|0;
                  __ZdlPv($632);
                  $$15 = $628;$$15171 = $629;
                  label = 206;
                  break;
                 }
                 case 207: {
                  $633 = ___cxa_find_matching_catch_2()|0;
                  $634 = tempRet0;
                  $$16 = $633;$$16172 = $634;
                  label = 210;
                  break;
                 }
                 case 208: {
                  $635 = ___cxa_find_matching_catch_2()|0;
                  $636 = tempRet0;
                  $637 = HEAP8[$194>>0]|0;
                  $638 = ($637<<24>>24)<(0);
                  if (!($638)) {
                   $$16 = $635;$$16172 = $636;
                   label = 210;
                   break;
                  }
                  $639 = HEAP32[$22>>2]|0;
                  __ZdlPv($639);
                  $$16 = $635;$$16172 = $636;
                  label = 210;
                  break;
                 }
                 case 211: {
                  $640 = ___cxa_find_matching_catch_2()|0;
                  $641 = tempRet0;
                  $$17 = $640;$$17173 = $641;
                  label = 214;
                  break;
                 }
                 case 212: {
                  $642 = ___cxa_find_matching_catch_2()|0;
                  $643 = tempRet0;
                  $644 = HEAP8[$198>>0]|0;
                  $645 = ($644<<24>>24)<(0);
                  if (!($645)) {
                   $$17 = $642;$$17173 = $643;
                   label = 214;
                   break;
                  }
                  $646 = HEAP32[$23>>2]|0;
                  __ZdlPv($646);
                  $$17 = $642;$$17173 = $643;
                  label = 214;
                  break;
                 }
                 case 215: {
                  $647 = ___cxa_find_matching_catch_2()|0;
                  $648 = tempRet0;
                  $$18 = $647;$$18174 = $648;
                  label = 218;
                  break;
                 }
                 case 216: {
                  $649 = ___cxa_find_matching_catch_2()|0;
                  $650 = tempRet0;
                  $651 = HEAP8[$202>>0]|0;
                  $652 = ($651<<24>>24)<(0);
                  if (!($652)) {
                   $$18 = $649;$$18174 = $650;
                   label = 218;
                   break;
                  }
                  $653 = HEAP32[$24>>2]|0;
                  __ZdlPv($653);
                  $$18 = $649;$$18174 = $650;
                  label = 218;
                  break;
                 }
                 case 219: {
                  $654 = ___cxa_find_matching_catch_2()|0;
                  $655 = tempRet0;
                  $$19 = $654;$$19175 = $655;
                  label = 222;
                  break;
                 }
                 case 220: {
                  $656 = ___cxa_find_matching_catch_2()|0;
                  $657 = tempRet0;
                  $658 = HEAP8[$206>>0]|0;
                  $659 = ($658<<24>>24)<(0);
                  if (!($659)) {
                   $$19 = $656;$$19175 = $657;
                   label = 222;
                   break;
                  }
                  $660 = HEAP32[$25>>2]|0;
                  __ZdlPv($660);
                  $$19 = $656;$$19175 = $657;
                  label = 222;
                  break;
                 }
                 case 223: {
                  $661 = ___cxa_find_matching_catch_2()|0;
                  $662 = tempRet0;
                  $$20 = $661;$$20176 = $662;
                  label = 226;
                  break;
                 }
                 case 224: {
                  $663 = ___cxa_find_matching_catch_2()|0;
                  $664 = tempRet0;
                  $665 = HEAP8[$209>>0]|0;
                  $666 = ($665<<24>>24)<(0);
                  if (!($666)) {
                   $$20 = $663;$$20176 = $664;
                   label = 226;
                   break;
                  }
                  $667 = HEAP32[$26>>2]|0;
                  __ZdlPv($667);
                  $$20 = $663;$$20176 = $664;
                  label = 226;
                  break;
                 }
                 case 227: {
                  $668 = ___cxa_find_matching_catch_2()|0;
                  $669 = tempRet0;
                  $eh$lpad$body417$index11Z2D = $669;$eh$lpad$body417$indexZ2D = $668;
                  label = 228;
                  break;
                 }
                }
                switch (label|0) {
                 case 105: {
                  $$23 = $$1;$$23179 = $$1157;
                  label = 229;
                  break;
                 }
                 case 109: {
                  $$23 = $$2;$$23179 = $$2158;
                  label = 229;
                  break;
                 }
                 case 113: {
                  $$23 = $$3;$$23179 = $$3159;
                  label = 229;
                  break;
                 }
                 case 117: {
                  $$23 = $$4;$$23179 = $$4160;
                  label = 229;
                  break;
                 }
                 case 121: {
                  $$23 = $$5;$$23179 = $$5161;
                  label = 229;
                  break;
                 }
                 case 125: {
                  $$23 = $$6;$$23179 = $$6162;
                  label = 229;
                  break;
                 }
                 case 129: {
                  $$23 = $$7;$$23179 = $$7163;
                  label = 229;
                  break;
                 }
                 case 133: {
                  $$23 = $$8;$$23179 = $$8164;
                  label = 229;
                  break;
                 }
                 case 137: {
                  $$23 = $$9;$$23179 = $$9165;
                  label = 229;
                  break;
                 }
                 case 141: {
                  $$23 = $$10;$$23179 = $$10166;
                  label = 229;
                  break;
                 }
                 case 190: {
                  $$23 = $$11;$$23179 = $$11167;
                  label = 229;
                  break;
                 }
                 case 194: {
                  $$23 = $$12;$$23179 = $$12168;
                  label = 229;
                  break;
                 }
                 case 198: {
                  $$23 = $$13;$$23179 = $$13169;
                  label = 229;
                  break;
                 }
                 case 202: {
                  $$23 = $$14;$$23179 = $$14170;
                  label = 229;
                  break;
                 }
                 case 206: {
                  $$23 = $$15;$$23179 = $$15171;
                  label = 229;
                  break;
                 }
                 case 210: {
                  $$23 = $$16;$$23179 = $$16172;
                  label = 229;
                  break;
                 }
                 case 214: {
                  $$23 = $$17;$$23179 = $$17173;
                  label = 229;
                  break;
                 }
                 case 218: {
                  $$23 = $$18;$$23179 = $$18174;
                  label = 229;
                  break;
                 }
                 case 222: {
                  $$23 = $$19;$$23179 = $$19175;
                  label = 229;
                  break;
                 }
                 case 226: {
                  $$23 = $$20;$$23179 = $$20176;
                  label = 229;
                  break;
                 }
                 case 228: {
                  $$24 = $eh$lpad$body417$indexZ2D;$$24180 = $eh$lpad$body417$index11Z2D;
                  break;
                 }
                }
                do {
                 if ((label|0) == 229) {
                  __THREW__ = 0;
                  invoke_vii(3453,($6|0),(50840|0));
                  $670 = __THREW__; __THREW__ = 0;
                  $671 = $670&1;
                  if ($671) {
                   $674 = ___cxa_find_matching_catch_3(0|0)|0;
                   $675 = tempRet0;
                   __THREW__ = 0;
                   invoke_vi(388,($210|0));
                   $676 = __THREW__; __THREW__ = 0;
                   $677 = $676&1;
                   if ($677) {
                    $678 = ___cxa_find_matching_catch_3(0|0)|0;
                    $679 = tempRet0;
                    ___clang_call_terminate($678);
                    // unreachable;
                   } else {
                    $eh$lpad$body430$indexZ2D = $674;
                    ___clang_call_terminate($eh$lpad$body430$indexZ2D);
                    // unreachable;
                   }
                  } else {
                   __THREW__ = 0;
                   invoke_vi(388,($210|0));
                   $672 = __THREW__; __THREW__ = 0;
                   $673 = $672&1;
                   if (!($673)) {
                    $$24 = $$23;$$24180 = $$23179;
                    break;
                   }
                   $1279 = ___cxa_find_matching_catch_3(0|0)|0;
                   $1280 = tempRet0;
                   $eh$lpad$body430$indexZ2D = $1279;
                   ___clang_call_terminate($eh$lpad$body430$indexZ2D);
                   // unreachable;
                  }
                 }
                } while(0);
                $$28 = $$24;$$28184 = $$24180;
                break L35;
               }
              } while(0);
              $212 = ($211|0)==(0|0);
              if (!($212)) {
               $214 = ($213|0)==($211|0);
               if (!($214)) {
                $scevgep$i$i$i231 = ((($213)) + -4|0);
                $215 = $scevgep$i$i$i231;
                $216 = $211;
                $217 = (($215) - ($216))|0;
                $218 = $217 >>> 2;
                $219 = $218 ^ -1;
                $scevgep5$i$i$i232 = (($213) + ($219<<2)|0);
                HEAP32[$118>>2] = $scevgep5$i$i$i232;
               }
               __ZdlPv($211);
              }
              break L18;
             }
            } while(0);
            $683 = HEAP32[$5>>2]|0;
            $684 = ($683|0)==(0|0);
            if (!($684)) {
             $685 = HEAP32[$118>>2]|0;
             $686 = ($685|0)==($683|0);
             if (!($686)) {
              $scevgep$i$i$i432 = ((($685)) + -4|0);
              $687 = $scevgep$i$i$i432;
              $688 = $683;
              $689 = (($687) - ($688))|0;
              $690 = $689 >>> 2;
              $691 = $690 ^ -1;
              $scevgep5$i$i$i433 = (($685) + ($691<<2)|0);
              HEAP32[$118>>2] = $scevgep5$i$i$i433;
             }
             __ZdlPv($683);
            }
            $$47 = $$28;$$47203 = $$28184;
            break L1;
           }
          }
         } while(0);
         if ((label|0) == 34) {
          $224 = ___cxa_find_matching_catch_2()|0;
          $225 = tempRet0;
          $eh$lpad$body$index6Z2D = $225;$eh$lpad$body$indexZ2D = $224;
         }
         $226 = HEAP8[$84>>0]|0;
         $227 = ($226<<24>>24)<(0);
         if ($227) {
          $228 = HEAP32[$4>>2]|0;
          __ZdlPv($228);
         }
         $$47 = $eh$lpad$body$indexZ2D;$$47203 = $eh$lpad$body$index6Z2D;
         break L1;
        }
       } while(0);
       HEAP32[$27>>2] = 0;
       $692 = ((($27)) + 4|0);
       HEAP32[$692>>2] = 0;
       $693 = ((($27)) + 8|0);
       HEAP32[$693>>2] = 0;
       $694 = HEAP32[$0>>2]|0;
       $695 = ((($694)) + 104|0);
       $696 = HEAP32[$695>>2]|0;
       __THREW__ = 0;
       invoke_viii($696|0,($0|0),($27|0),1);
       $697 = __THREW__; __THREW__ = 0;
       $698 = $697&1;
       L298: do {
        if ($698) {
         $708 = ___cxa_find_matching_catch_2()|0;
         $709 = tempRet0;
         $$43 = $708;$$43199 = $709;
        } else {
         $699 = HEAP32[$27>>2]|0;
         $700 = HEAP32[$692>>2]|0;
         $701 = ($699|0)==($700|0);
         L301: do {
          if (!($701)) {
           $702 = ((($2)) + 12|0);
           $703 = ((($2)) + 4|0);
           $704 = ((($2)) + 8|0);
           $705 = ((($1)) + 12|0);
           $706 = ((($1)) + 4|0);
           $707 = ((($1)) + 8|0);
           $$sroa$0529$01084 = $699;
           L303: while(1) {
            $710 = HEAP32[$$sroa$0529$01084>>2]|0;
            $711 = ($710|0)==(0|0);
            do {
             if (!($711)) {
              $712 = ((($710)) + 16|0);
              $713 = HEAP32[$712>>2]|0;
              $714 = ($713|0)==(0|0);
              if (!($714)) {
               $715 = HEAP32[$713>>2]|0;
               $716 = ((($715)) + 44|0);
               $717 = HEAP32[$716>>2]|0;
               __THREW__ = 0;
               invoke_vii($717|0,($713|0),($65|0));
               $718 = __THREW__; __THREW__ = 0;
               $719 = $718&1;
               if ($719) {
                break L303;
               }
              }
              $720 = ((($710)) + 20|0);
              $721 = HEAP32[$720>>2]|0;
              $722 = ($721|0)==(0|0);
              if (!($722)) {
               $723 = HEAP32[$721>>2]|0;
               $724 = ((($723)) + 32|0);
               $725 = HEAP32[$724>>2]|0;
               __THREW__ = 0;
               invoke_vii($725|0,($721|0),($65|0));
               $726 = __THREW__; __THREW__ = 0;
               $727 = $726&1;
               if ($727) {
                break L303;
               }
              }
              __THREW__ = 0;
              $728 = (invoke_ii(3279,($710|0))|0);
              $729 = __THREW__; __THREW__ = 0;
              $730 = $729&1;
              if ($730) {
               break L303;
              }
              $731 = ($728|0)==(0|0);
              if ($731) {
               break;
              }
              __THREW__ = 0;
              $732 = (invoke_ii(3279,($710|0))|0);
              $733 = __THREW__; __THREW__ = 0;
              $734 = $733&1;
              if ($734) {
               break L303;
              }
              $735 = ((($732)) + 68|0);
              $736 = HEAP8[$735>>0]|0;
              $737 = ($736<<24>>24)==(0);
              if (!($737)) {
               break;
              }
              $738 = ((($732)) + 32|0);
              $739 = ((($732)) + 52|0);
              ;HEAP32[$739>>2]=HEAP32[$738>>2]|0;HEAP32[$739+4>>2]=HEAP32[$738+4>>2]|0;HEAP32[$739+8>>2]=HEAP32[$738+8>>2]|0;HEAP32[$739+12>>2]=HEAP32[$738+12>>2]|0;
              $740 = ((($732)) + 48|0);
              $741 = HEAP32[$740>>2]|0;
              $742 = ($741|0)==(0|0);
              if ($742) {
               $800 = HEAP32[$732>>2]|0;
               $801 = ((($800)) + 200|0);
               $802 = HEAP32[$801>>2]|0;
               __THREW__ = 0;
               invoke_vii($802|0,($2|0),($732|0));
               $803 = __THREW__; __THREW__ = 0;
               $804 = $803&1;
               if ($804) {
                break L303;
               }
               $805 = +HEAPF32[$702>>2];
               $806 = !($805 >= 0.0);
               do {
                if (!($806)) {
                 $807 = ((($732)) + 64|0);
                 $808 = +HEAPF32[$807>>2];
                 $809 = !($808 >= 0.0);
                 if ($809) {
                  ;HEAP32[$739>>2]=HEAP32[$2>>2]|0;HEAP32[$739+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$739+8>>2]=HEAP32[$2+8>>2]|0;
                  HEAPF32[$807>>2] = $805;
                  break;
                 }
                 $810 = +HEAPF32[$739>>2];
                 $811 = +HEAPF32[$2>>2];
                 $812 = $810 - $811;
                 $813 = ((($732)) + 56|0);
                 $814 = +HEAPF32[$813>>2];
                 $815 = +HEAPF32[$703>>2];
                 $816 = $814 - $815;
                 $817 = ((($732)) + 60|0);
                 $818 = +HEAPF32[$817>>2];
                 $819 = +HEAPF32[$704>>2];
                 $820 = $818 - $819;
                 $821 = $812 * $812;
                 $822 = $816 * $816;
                 $823 = $821 + $822;
                 $824 = $820 * $820;
                 $825 = $823 + $824;
                 $826 = (+Math_sqrt((+$825)));
                 $827 = $826;
                 $828 = $805;
                 $829 = $828 + $827;
                 $830 = $808;
                 $831 = !($829 <= $830);
                 if (!($831)) {
                  break;
                 }
                 $832 = $830 + $827;
                 $833 = !($832 <= $828);
                 if ($833) {
                  $834 = $828 + $832;
                  $835 = $834 * 0.5;
                  $836 = $835 - $830;
                  $837 = $836 / $827;
                  $838 = $811 - $810;
                  $839 = $838;
                  $840 = $839 * $837;
                  $841 = $810;
                  $842 = $841 + $840;
                  $843 = $842;
                  HEAPF32[$739>>2] = $843;
                  $844 = $815 - $814;
                  $845 = $844;
                  $846 = $837 * $845;
                  $847 = $814;
                  $848 = $847 + $846;
                  $849 = $848;
                  HEAPF32[$813>>2] = $849;
                  $850 = $819 - $818;
                  $851 = $850;
                  $852 = $837 * $851;
                  $853 = $818;
                  $854 = $853 + $852;
                  $855 = $854;
                  HEAPF32[$817>>2] = $855;
                  $856 = $835;
                  HEAPF32[$807>>2] = $856;
                  break;
                 } else {
                  ;HEAP32[$739>>2]=HEAP32[$2>>2]|0;HEAP32[$739+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$739+8>>2]=HEAP32[$2+8>>2]|0;
                  HEAPF32[$807>>2] = $805;
                  break;
                 }
                }
               } while(0);
              } else {
               $743 = HEAP32[$741>>2]|0;
               $744 = ((($743)) + 140|0);
               $745 = HEAP32[$744>>2]|0;
               __THREW__ = 0;
               invoke_viii($745|0,($1|0),($741|0),($732|0));
               $746 = __THREW__; __THREW__ = 0;
               $747 = $746&1;
               if ($747) {
                break L303;
               }
               $748 = +HEAPF32[$705>>2];
               $749 = !($748 >= 0.0);
               do {
                if (!($749)) {
                 $750 = ((($732)) + 64|0);
                 $751 = +HEAPF32[$750>>2];
                 $752 = !($751 >= 0.0);
                 if ($752) {
                  ;HEAP32[$739>>2]=HEAP32[$1>>2]|0;HEAP32[$739+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$739+8>>2]=HEAP32[$1+8>>2]|0;
                  HEAPF32[$750>>2] = $748;
                  break;
                 }
                 $753 = +HEAPF32[$739>>2];
                 $754 = +HEAPF32[$1>>2];
                 $755 = $753 - $754;
                 $756 = ((($732)) + 56|0);
                 $757 = +HEAPF32[$756>>2];
                 $758 = +HEAPF32[$706>>2];
                 $759 = $757 - $758;
                 $760 = ((($732)) + 60|0);
                 $761 = +HEAPF32[$760>>2];
                 $762 = +HEAPF32[$707>>2];
                 $763 = $761 - $762;
                 $764 = $755 * $755;
                 $765 = $759 * $759;
                 $766 = $764 + $765;
                 $767 = $763 * $763;
                 $768 = $766 + $767;
                 $769 = (+Math_sqrt((+$768)));
                 $770 = $769;
                 $771 = $748;
                 $772 = $771 + $770;
                 $773 = $751;
                 $774 = !($772 <= $773);
                 if (!($774)) {
                  break;
                 }
                 $775 = $773 + $770;
                 $776 = !($775 <= $771);
                 if ($776) {
                  $777 = $771 + $775;
                  $778 = $777 * 0.5;
                  $779 = $778 - $773;
                  $780 = $779 / $770;
                  $781 = $754 - $753;
                  $782 = $781;
                  $783 = $782 * $780;
                  $784 = $753;
                  $785 = $784 + $783;
                  $786 = $785;
                  HEAPF32[$739>>2] = $786;
                  $787 = $758 - $757;
                  $788 = $787;
                  $789 = $780 * $788;
                  $790 = $757;
                  $791 = $790 + $789;
                  $792 = $791;
                  HEAPF32[$756>>2] = $792;
                  $793 = $762 - $761;
                  $794 = $793;
                  $795 = $780 * $794;
                  $796 = $761;
                  $797 = $796 + $795;
                  $798 = $797;
                  HEAPF32[$760>>2] = $798;
                  $799 = $778;
                  HEAPF32[$750>>2] = $799;
                  break;
                 } else {
                  ;HEAP32[$739>>2]=HEAP32[$1>>2]|0;HEAP32[$739+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$739+8>>2]=HEAP32[$1+8>>2]|0;
                  HEAPF32[$750>>2] = $748;
                  break;
                 }
                }
               } while(0);
              }
              HEAP8[$735>>0] = 1;
             }
            } while(0);
            $857 = ((($$sroa$0529$01084)) + 4|0);
            $858 = HEAP32[$692>>2]|0;
            $859 = ($857|0)==($858|0);
            if ($859) {
             break L301;
            } else {
             $$sroa$0529$01084 = $857;
            }
           }
           $860 = ___cxa_find_matching_catch_2()|0;
           $861 = tempRet0;
           $$43 = $860;$$43199 = $861;
           break L298;
          }
         } while(0);
         HEAP32[$28>>2] = 0;
         $862 = ((($28)) + 4|0);
         HEAP32[$862>>2] = 0;
         $863 = ((($28)) + 8|0);
         HEAP32[$863>>2] = 0;
         $864 = HEAP32[$0>>2]|0;
         $865 = ((($864)) + 84|0);
         $866 = HEAP32[$865>>2]|0;
         __THREW__ = 0;
         invoke_viii($866|0,($0|0),($28|0),1);
         $867 = __THREW__; __THREW__ = 0;
         $868 = $867&1;
         L346: do {
          if ($868) {
           $902 = ___cxa_find_matching_catch_2()|0;
           $903 = tempRet0;
           $$41 = $902;$$41197 = $903;
          } else {
           $869 = ((($0)) + 64|0);
           $870 = HEAP32[$869>>2]|0;
           $871 = ($870|0)==(0|0);
           L349: do {
            if ($871) {
             label = 292;
            } else {
             $872 = ((($870)) + 12|0);
             $873 = HEAP32[$872>>2]|0;
             $874 = ((($873)) + 8|0);
             $875 = HEAP32[$874>>2]|0;
             __THREW__ = 0;
             (invoke_ii($875|0,($872|0))|0);
             $876 = __THREW__; __THREW__ = 0;
             $877 = $876&1;
             if ($877) {
              label = 290;
             } else {
              $878 = ((($870)) + 36|0);
              $879 = HEAP32[$878>>2]|0;
              $880 = ((($870)) + 32|0);
              $881 = HEAP32[$880>>2]|0;
              $882 = ($879|0)==($881|0);
              if (!($882)) {
               $883 = ($881|0)==(0);
               do {
                if ($883) {
                 $884 = ((($870)) + 24|0);
                 __THREW__ = 0;
                 (invoke_ii(2504,($884|0))|0);
                 $885 = __THREW__; __THREW__ = 0;
                 $886 = $885&1;
                 if (!($886)) {
                  $$pre$i442 = HEAP32[$880>>2]|0;
                  $894 = $$pre$i442;
                  break;
                 }
                 $887 = ___cxa_find_matching_catch_2()|0;
                 $888 = tempRet0;
                 $889 = HEAP32[$872>>2]|0;
                 $890 = ((($889)) + 12|0);
                 $891 = HEAP32[$890>>2]|0;
                 __THREW__ = 0;
                 (invoke_ii($891|0,($872|0))|0);
                 $892 = __THREW__; __THREW__ = 0;
                 $893 = $892&1;
                 if (!($893)) {
                  $eh$lpad$body448$index19Z2D = $888;$eh$lpad$body448$indexZ2D = $887;
                  break L349;
                 }
                 $900 = ___cxa_find_matching_catch_3(0|0)|0;
                 $901 = tempRet0;
                 ___clang_call_terminate($900);
                 // unreachable;
                } else {
                 $894 = $881;
                }
               } while(0);
               HEAP32[$878>>2] = $894;
              }
              $895 = HEAP32[$872>>2]|0;
              $896 = ((($895)) + 12|0);
              $897 = HEAP32[$896>>2]|0;
              __THREW__ = 0;
              (invoke_ii($897|0,($872|0))|0);
              $898 = __THREW__; __THREW__ = 0;
              $899 = $898&1;
              if ($899) {
               label = 290;
              } else {
               label = 292;
              }
             }
            }
           } while(0);
           L362: do {
            if ((label|0) == 292) {
             $910 = ((($0)) + 56|0);
             $911 = HEAP32[$910>>2]|0;
             $912 = ($911|0)==(0|0);
             if (!($912)) {
              $913 = ((($911)) + 20|0);
              $914 = HEAP32[$913>>2]|0;
              $915 = ((($914)) + 12|0);
              $916 = HEAP32[$915>>2]|0;
              __THREW__ = 0;
              invoke_vii($916|0,($913|0),0);
              $917 = __THREW__; __THREW__ = 0;
              $918 = $917&1;
              if ($918) {
               label = 290;
               break;
              }
             }
             $919 = HEAP32[$28>>2]|0;
             $920 = HEAP32[$862>>2]|0;
             $921 = ($919|0)==($920|0);
             L367: do {
              if (!($921)) {
               $$sroa$0508$01080 = $919;$1282 = $920;
               L368: while(1) {
                $925 = HEAP32[$$sroa$0508$01080>>2]|0;
                $926 = ((($925)) + 628|0);
                $927 = HEAP32[$926>>2]|0;
                $928 = ($927|0)==(0|0);
                do {
                 if ($928) {
                  $944 = $1282;
                 } else {
                  $929 = (___dynamic_cast($927,25048,8160,0)|0);
                  $930 = ($929|0)==(0|0);
                  if ($930) {
                   $944 = $1282;
                   break;
                  }
                  $931 = ((($929)) + 29|0);
                  $932 = HEAP8[$931>>0]|0;
                  $933 = ($932<<24>>24)==(0);
                  if (!($933)) {
                   $944 = $1282;
                   break;
                  }
                  $934 = ((($925)) + 620|0);
                  $935 = HEAP32[$934>>2]|0;
                  $936 = ($935|0)==(0|0);
                  if (!($936)) {
                   $944 = $1282;
                   break;
                  }
                  $937 = HEAP32[$929>>2]|0;
                  $938 = ((($937)) + 20|0);
                  $939 = HEAP32[$938>>2]|0;
                  __THREW__ = 0;
                  invoke_vi($939|0,($929|0));
                  $940 = __THREW__; __THREW__ = 0;
                  $941 = $940&1;
                  if ($941) {
                   break L368;
                  }
                  $$pre1104 = HEAP32[$862>>2]|0;
                  $944 = $$pre1104;
                 }
                } while(0);
                $942 = ((($$sroa$0508$01080)) + 4|0);
                $943 = ($942|0)==($944|0);
                if ($943) {
                 break L367;
                } else {
                 $$sroa$0508$01080 = $942;$1282 = $944;
                }
               }
               $945 = ___cxa_find_matching_catch_2()|0;
               $946 = tempRet0;
               $$41 = $945;$$41197 = $946;
               break L346;
              }
             } while(0);
             $922 = HEAP32[$3>>2]|0;
             $923 = HEAP32[$33>>2]|0;
             $924 = ($922|0)==($923|0);
             L379: do {
              if ($924) {
               $$0210$off0$lcssa = 0;$1283 = $922;
              } else {
               $$0210$off01074 = 0;$$sroa$0513$01073 = $922;$1284 = $923;
               L380: while(1) {
                $947 = HEAP8[$43>>0]|0;
                $948 = ($947<<24>>24)==(0);
                if (!($948)) {
                 $$0210$off0$lcssa = $$0210$off01074;$1283 = $1284;
                 break L379;
                }
                $949 = HEAP32[$$sroa$0513$01073>>2]|0;
                $950 = ((($949)) + 108|0);
                $951 = HEAP32[$950>>2]|0;
                $952 = ($951|0)==(0|0);
                do {
                 if ($952) {
                  $953 = HEAP32[$949>>2]|0;
                  $954 = ((($953)) + 144|0);
                  $955 = HEAP32[$954>>2]|0;
                  __THREW__ = 0;
                  $956 = (invoke_ii($955|0,($949|0))|0);
                  $957 = __THREW__; __THREW__ = 0;
                  $958 = $957&1;
                  if ($958) {
                   break L380;
                  }
                  if (!($956)) {
                   $$1211$off0 = $$0210$off01074;
                   break;
                  }
                  $959 = HEAP32[$$sroa$0513$01073>>2]|0;
                  __THREW__ = 0;
                  invoke_vii(3454,($0|0),($959|0));
                  $960 = __THREW__; __THREW__ = 0;
                  $961 = $960&1;
                  if ($961) {
                   break L380;
                  }
                  $962 = HEAP32[$$sroa$0513$01073>>2]|0;
                  $963 = HEAP32[$962>>2]|0;
                  $964 = ((($963)) + 140|0);
                  $965 = HEAP32[$964>>2]|0;
                  __THREW__ = 0;
                  invoke_vi($965|0,($962|0));
                  $966 = __THREW__; __THREW__ = 0;
                  $967 = $966&1;
                  if ($967) {
                   break L380;
                  } else {
                   $$1211$off0 = 1;
                  }
                 } else {
                  $$1211$off0 = $$0210$off01074;
                 }
                } while(0);
                $968 = ((($$sroa$0513$01073)) + 4|0);
                $969 = HEAP32[$33>>2]|0;
                $970 = ($968|0)==($969|0);
                if ($970) {
                 $$0210$off0$lcssa = $$1211$off0;$1283 = $968;
                 break L379;
                } else {
                 $$0210$off01074 = $$1211$off0;$$sroa$0513$01073 = $968;$1284 = $969;
                }
               }
               $906 = ___cxa_find_matching_catch_2()|0;
               $907 = tempRet0;
               $eh$lpad$body448$index19Z2D = $907;$eh$lpad$body448$indexZ2D = $906;
               break L362;
              }
             } while(0);
             $971 = ((($0)) + 60|0);
             $972 = HEAP32[$971>>2]|0;
             $973 = ($972|0)==(0|0);
             if ($973) {
              $982 = $1283;
             } else {
              $974 = ((($972)) + 20|0);
              $975 = HEAP32[$974>>2]|0;
              $976 = ((($975)) + 12|0);
              $977 = HEAP32[$976>>2]|0;
              __THREW__ = 0;
              invoke_vii($977|0,($974|0),0);
              $978 = __THREW__; __THREW__ = 0;
              $979 = $978&1;
              if ($979) {
               label = 290;
               break;
              }
              $$pre1106 = HEAP32[$33>>2]|0;
              $982 = $$pre1106;
             }
             $980 = HEAP32[$3>>2]|0;
             $981 = ($980|0)==($982|0);
             L395: do {
              if ($981) {
               $$2212$off0$lcssa = $$0210$off0$lcssa;
              } else {
               $$2212$off01068 = $$0210$off0$lcssa;$$sroa$0513$11067 = $980;
               L396: while(1) {
                $983 = HEAP8[$43>>0]|0;
                $984 = ($983<<24>>24)==(0);
                if (!($984)) {
                 $$2212$off0$lcssa = $$2212$off01068;
                 break L395;
                }
                $985 = HEAP32[$$sroa$0513$11067>>2]|0;
                $986 = ((($985)) + 108|0);
                $987 = HEAP32[$986>>2]|0;
                $988 = ($987|0)==(0|0);
                do {
                 if ($988) {
                  $989 = HEAP32[$985>>2]|0;
                  $990 = ((($989)) + 144|0);
                  $991 = HEAP32[$990>>2]|0;
                  __THREW__ = 0;
                  $992 = (invoke_ii($991|0,($985|0))|0);
                  $993 = __THREW__; __THREW__ = 0;
                  $994 = $993&1;
                  if ($994) {
                   break L396;
                  }
                  if (!($992)) {
                   $$3213$off0 = $$2212$off01068;
                   break;
                  }
                  $995 = HEAP32[$$sroa$0513$11067>>2]|0;
                  __THREW__ = 0;
                  invoke_vii(3454,($0|0),($995|0));
                  $996 = __THREW__; __THREW__ = 0;
                  $997 = $996&1;
                  if ($997) {
                   break L396;
                  }
                  $998 = HEAP32[$$sroa$0513$11067>>2]|0;
                  __THREW__ = 0;
                  invoke_vi(3455,($998|0));
                  $999 = __THREW__; __THREW__ = 0;
                  $1000 = $999&1;
                  if ($1000) {
                   break L396;
                  } else {
                   $$3213$off0 = 1;
                  }
                 } else {
                  $$3213$off0 = $$2212$off01068;
                 }
                } while(0);
                $1001 = ((($$sroa$0513$11067)) + 4|0);
                $1002 = HEAP32[$33>>2]|0;
                $1003 = ($1001|0)==($1002|0);
                if ($1003) {
                 $$2212$off0$lcssa = $$3213$off0;
                 break L395;
                } else {
                 $$2212$off01068 = $$3213$off0;$$sroa$0513$11067 = $1001;
                }
               }
               $904 = ___cxa_find_matching_catch_2()|0;
               $905 = tempRet0;
               $eh$lpad$body448$index19Z2D = $905;$eh$lpad$body448$indexZ2D = $904;
               break L362;
              }
             } while(0);
             $1004 = HEAP32[$27>>2]|0;
             $1005 = HEAP32[$692>>2]|0;
             $1006 = ($1004|0)==($1005|0);
             L407: do {
              if (!($1006)) {
               $$sroa$0495$01066 = $1004;
               L408: while(1) {
                $1009 = HEAP32[$$sroa$0495$01066>>2]|0;
                $1010 = ($1009|0)==(0|0);
                do {
                 if (!($1010)) {
                  $1011 = ((($1009)) + 16|0);
                  $1012 = HEAP32[$1011>>2]|0;
                  $1013 = ($1012|0)==(0|0);
                  if (!($1013)) {
                   $1014 = HEAP32[$1012>>2]|0;
                   $1015 = ((($1014)) + 48|0);
                   $1016 = HEAP32[$1015>>2]|0;
                   __THREW__ = 0;
                   invoke_vi($1016|0,($1012|0));
                   $1017 = __THREW__; __THREW__ = 0;
                   $1018 = $1017&1;
                   if ($1018) {
                    break L408;
                   }
                  }
                  $1019 = ((($1009)) + 20|0);
                  $1020 = HEAP32[$1019>>2]|0;
                  $1021 = ($1020|0)==(0|0);
                  if ($1021) {
                   break;
                  }
                  $1022 = HEAP32[$1020>>2]|0;
                  $1023 = ((($1022)) + 36|0);
                  $1024 = HEAP32[$1023>>2]|0;
                  __THREW__ = 0;
                  invoke_vi($1024|0,($1020|0));
                  $1025 = __THREW__; __THREW__ = 0;
                  $1026 = $1025&1;
                  if ($1026) {
                   break L408;
                  }
                 }
                } while(0);
                $1027 = ((($$sroa$0495$01066)) + 4|0);
                $1028 = HEAP32[$692>>2]|0;
                $1029 = ($1027|0)==($1028|0);
                if ($1029) {
                 break L407;
                } else {
                 $$sroa$0495$01066 = $1027;
                }
               }
               $1030 = ___cxa_find_matching_catch_2()|0;
               $1031 = tempRet0;
               $$41 = $1030;$$41197 = $1031;
               break L346;
              }
             } while(0);
             $1007 = HEAP32[$869>>2]|0;
             $1008 = ($1007|0)==(0|0);
             if (!($1008)) {
              $1032 = ((($1007)) + 12|0);
              $1033 = HEAP32[$1032>>2]|0;
              $1034 = ((($1033)) + 8|0);
              $1035 = HEAP32[$1034>>2]|0;
              __THREW__ = 0;
              (invoke_ii($1035|0,($1032|0))|0);
              $1036 = __THREW__; __THREW__ = 0;
              $1037 = $1036&1;
              if ($1037) {
               label = 290;
               break;
              }
              $1038 = ((($1007)) + 36|0);
              $1039 = HEAP32[$1038>>2]|0;
              $1040 = ($1039|0)==(0);
              do {
               if (!($1040)) {
                $1041 = ((($1007)) + 24|0);
                __THREW__ = 0;
                (invoke_iii(2501,($1041|0),($1032|0))|0);
                $1042 = __THREW__; __THREW__ = 0;
                $1043 = $1042&1;
                if (!($1043)) {
                 break;
                }
                $1044 = ___cxa_find_matching_catch_2()|0;
                $1045 = tempRet0;
                $1046 = HEAP32[$1032>>2]|0;
                $1047 = ((($1046)) + 12|0);
                $1048 = HEAP32[$1047>>2]|0;
                __THREW__ = 0;
                (invoke_ii($1048|0,($1032|0))|0);
                $1049 = __THREW__; __THREW__ = 0;
                $1050 = $1049&1;
                if (!($1050)) {
                 $eh$lpad$body448$index19Z2D = $1045;$eh$lpad$body448$indexZ2D = $1044;
                 break L362;
                }
                $1056 = ___cxa_find_matching_catch_3(0|0)|0;
                $1057 = tempRet0;
                ___clang_call_terminate($1056);
                // unreachable;
               }
              } while(0);
              $1051 = HEAP32[$1032>>2]|0;
              $1052 = ((($1051)) + 12|0);
              $1053 = HEAP32[$1052>>2]|0;
              __THREW__ = 0;
              (invoke_ii($1053|0,($1032|0))|0);
              $1054 = __THREW__; __THREW__ = 0;
              $1055 = $1054&1;
              if ($1055) {
               label = 290;
               break;
              }
             }
             $1058 = ((($0)) + 13|0);
             $1059 = HEAP8[$1058>>0]|0;
             $1060 = ($1059<<24>>24)==(0);
             $$2212$off0$not = $$2212$off0$lcssa ^ 1;
             $brmerge = $1060 | $$2212$off0$not;
             if (!($brmerge)) {
              $1061 = ((($0)) + 92|0);
              $1062 = HEAP32[$1061>>2]|0;
              $1063 = ($1062|0)==(0|0);
              do {
               if (!($1063)) {
                $1064 = ((($1062)) + 24|0);
                $1065 = HEAP32[$1064>>2]|0;
                $1066 = ($1065|0)==(0|0);
                do {
                 if (!($1066)) {
                  $1067 = ((($0)) + 96|0);
                  $1068 = HEAP32[$1067>>2]|0;
                  $phitmp$i$i = ($1068|0)==(0|0);
                  if ($phitmp$i$i) {
                   break;
                  }
                  $1069 = HEAP32[$1068>>2]|0;
                  $1070 = ((($1069)) + 144|0);
                  $1071 = HEAP32[$1070>>2]|0;
                  __THREW__ = 0;
                  $1072 = (invoke_ii($1071|0,($1068|0))|0);
                  $1073 = __THREW__; __THREW__ = 0;
                  $1074 = $1073&1;
                  if ($1074) {
                   label = 290;
                   break L362;
                  }
                  if (!($1072)) {
                   break;
                  }
                  $1075 = HEAP32[$1067>>2]|0;
                  __THREW__ = 0;
                  (invoke_ii(3382,($1075|0))|0);
                  $1076 = __THREW__; __THREW__ = 0;
                  $1077 = $1076&1;
                  if ($1077) {
                   label = 290;
                   break L362;
                  }
                 }
                } while(0);
                $$pr$i = HEAP32[$1061>>2]|0;
                $1078 = ($$pr$i|0)==(0|0);
                if ($1078) {
                 break;
                }
                HEAP32[$1061>>2] = 0;
                $1079 = ((($$pr$i)) + 8|0);
                $1080 = HEAP32[$1079>>2]|0;HEAP32[$1079>>2] = (($1080-1)|0);
                $1081 = ($1080|0)==(1);
                if (!($1081)) {
                 break;
                }
                __THREW__ = 0;
                invoke_viii(3262,($$pr$i|0),1,1);
                $1082 = __THREW__; __THREW__ = 0;
                $1083 = $1082&1;
                if ($1083) {
                 label = 290;
                 break L362;
                }
               }
              } while(0);
              $1084 = ((($0)) + 96|0);
              HEAP32[$1084>>2] = 0;
             }
             $1085 = HEAP32[$0>>2]|0;
             $1086 = ((($1085)) + 4|0);
             $1087 = HEAP32[$1086>>2]|0;
             __THREW__ = 0;
             $1088 = (invoke_ii($1087|0,($0|0))|0);
             $1089 = __THREW__; __THREW__ = 0;
             $1090 = $1089&1;
             if ($1090) {
              label = 290;
              break;
             }
             $1091 = ($1088|0)==(0|0);
             L443: do {
              if (!($1091)) {
               $1092 = HEAP32[$0>>2]|0;
               $1093 = ((($1092)) + 4|0);
               $1094 = HEAP32[$1093>>2]|0;
               __THREW__ = 0;
               $1095 = (invoke_ii($1094|0,($0|0))|0);
               $1096 = __THREW__; __THREW__ = 0;
               $1097 = $1096&1;
               if ($1097) {
                label = 290;
                break L362;
               }
               ;HEAP32[$29>>2]=0|0;HEAP32[$29+4>>2]=0|0;HEAP32[$29+8>>2]=0|0;
               $1098 = ((($29)) + 11|0);
               HEAP8[$1098>>0] = 6;
               ;HEAP8[$29>>0]=HEAP8[105415>>0]|0;HEAP8[$29+1>>0]=HEAP8[105415+1>>0]|0;HEAP8[$29+2>>0]=HEAP8[105415+2>>0]|0;HEAP8[$29+3>>0]=HEAP8[105415+3>>0]|0;HEAP8[$29+4>>0]=HEAP8[105415+4>>0]|0;HEAP8[$29+5>>0]=HEAP8[105415+5>>0]|0;
               $1099 = ((($29)) + 6|0);
               HEAP8[$1099>>0] = 0;
               $1100 = ((($1095)) + 24|0);
               $1101 = HEAP32[$1100>>2]|0;
               $1102 = ((($1101)) + 8|0);
               $1103 = HEAP32[$1102>>2]|0;
               __THREW__ = 0;
               (invoke_ii($1103|0,($1100|0))|0);
               $1104 = __THREW__; __THREW__ = 0;
               $1105 = $1104&1;
               do {
                if ($1105) {
                 label = 378;
                } else {
                 $1106 = ((($1095)) + 68|0);
                 __THREW__ = 0;
                 $1107 = (invoke_iii(3391,($1106|0),($29|0))|0);
                 $1108 = __THREW__; __THREW__ = 0;
                 $1109 = $1108&1;
                 if ($1109) {
                  $1120 = ___cxa_find_matching_catch_2()|0;
                  $1121 = tempRet0;
                  $1122 = HEAP32[$1100>>2]|0;
                  $1123 = ((($1122)) + 12|0);
                  $1124 = HEAP32[$1123>>2]|0;
                  __THREW__ = 0;
                  (invoke_ii($1124|0,($1100|0))|0);
                  $1125 = __THREW__; __THREW__ = 0;
                  $1126 = $1125&1;
                  if (!($1126)) {
                   $eh$lpad$body484$index27Z2D = $1121;$eh$lpad$body484$indexZ2D = $1120;
                   break;
                  }
                  $1127 = ___cxa_find_matching_catch_3(0|0)|0;
                  $1128 = tempRet0;
                  ___clang_call_terminate($1127);
                  // unreachable;
                 }
                 $1110 = ((($1095)) + 72|0);
                 $1111 = ($1107|0)==($1110|0);
                 if ($1111) {
                  $1285 = 0;
                 } else {
                  $1112 = ((($1107)) + 28|0);
                  $1113 = HEAP8[$1112>>0]|0;
                  $1114 = ($1113<<24>>24)!=(0);
                  $1285 = $1114;
                 }
                 $1115 = HEAP32[$1100>>2]|0;
                 $1116 = ((($1115)) + 12|0);
                 $1117 = HEAP32[$1116>>2]|0;
                 __THREW__ = 0;
                 (invoke_ii($1117|0,($1100|0))|0);
                 $1118 = __THREW__; __THREW__ = 0;
                 $1119 = $1118&1;
                 if ($1119) {
                  label = 378;
                  break;
                 }
                 $1129 = HEAP8[$1098>>0]|0;
                 $1130 = ($1129<<24>>24)<(0);
                 if ($1130) {
                  $1131 = HEAP32[$29>>2]|0;
                  __ZdlPv($1131);
                 }
                 if (!($1285)) {
                  break L443;
                 }
                 $1132 = HEAP32[$0>>2]|0;
                 $1133 = ((($1132)) + 112|0);
                 $1134 = HEAP32[$1133>>2]|0;
                 __THREW__ = 0;
                 $1135 = (+invoke_di($1134|0,($0|0)));
                 $1136 = __THREW__; __THREW__ = 0;
                 $1137 = $1136&1;
                 if ($1137) {
                  label = 290;
                  break L362;
                 }
                 $1138 = HEAP32[$0>>2]|0;
                 $1139 = ((($1138)) + 4|0);
                 $1140 = HEAP32[$1139>>2]|0;
                 __THREW__ = 0;
                 $1141 = (invoke_ii($1140|0,($0|0))|0);
                 $1142 = __THREW__; __THREW__ = 0;
                 $1143 = $1142&1;
                 L461: do {
                  if (!($1143)) {
                   ;HEAP32[$30>>2]=0|0;HEAP32[$30+4>>2]=0|0;HEAP32[$30+8>>2]=0|0;
                   __THREW__ = 0;
                   $1144 = (invoke_ii(3276,48)|0);
                   $1145 = __THREW__; __THREW__ = 0;
                   $1146 = $1145&1;
                   do {
                    if ($1146) {
                     $1200 = ___cxa_find_matching_catch_2()|0;
                     $1201 = tempRet0;
                     $$36 = $1200;$$36192 = $1201;
                    } else {
                     HEAP32[$30>>2] = $1144;
                     $1147 = ((($30)) + 8|0);
                     HEAP32[$1147>>2] = -2147483600;
                     $1148 = ((($30)) + 4|0);
                     HEAP32[$1148>>2] = 32;
                     dest=$1144; src=105422; stop=dest+32|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                     $1149 = ((($1144)) + 32|0);
                     HEAP8[$1149>>0] = 0;
                     __THREW__ = 0;
                     (invoke_iiiid(3392,($1141|0),($284|0),($30|0),(+$59))|0);
                     $1150 = __THREW__; __THREW__ = 0;
                     $1151 = $1150&1;
                     if ($1151) {
                      $1202 = ___cxa_find_matching_catch_2()|0;
                      $1203 = tempRet0;
                      $1204 = ((($30)) + 11|0);
                      $1205 = HEAP8[$1204>>0]|0;
                      $1206 = ($1205<<24>>24)<(0);
                      if (!($1206)) {
                       $$36 = $1202;$$36192 = $1203;
                       break;
                      }
                      $1207 = HEAP32[$30>>2]|0;
                      __ZdlPv($1207);
                      $$36 = $1202;$$36192 = $1203;
                      break;
                     }
                     $1152 = ((($30)) + 11|0);
                     $1153 = HEAP8[$1152>>0]|0;
                     $1154 = ($1153<<24>>24)<(0);
                     if ($1154) {
                      $1155 = HEAP32[$30>>2]|0;
                      __ZdlPv($1155);
                     }
                     $1156 = HEAP32[$0>>2]|0;
                     $1157 = ((($1156)) + 4|0);
                     $1158 = HEAP32[$1157>>2]|0;
                     __THREW__ = 0;
                     $1159 = (invoke_ii($1158|0,($0|0))|0);
                     $1160 = __THREW__; __THREW__ = 0;
                     $1161 = $1160&1;
                     if ($1161) {
                      break L461;
                     }
                     ;HEAP32[$31>>2]=0|0;HEAP32[$31+4>>2]=0|0;HEAP32[$31+8>>2]=0|0;
                     __THREW__ = 0;
                     $1162 = (invoke_ii(3276,32)|0);
                     $1163 = __THREW__; __THREW__ = 0;
                     $1164 = $1163&1;
                     do {
                      if ($1164) {
                       $1208 = ___cxa_find_matching_catch_2()|0;
                       $1209 = tempRet0;
                       $$37 = $1208;$$37193 = $1209;
                      } else {
                       HEAP32[$31>>2] = $1162;
                       $1165 = ((($31)) + 8|0);
                       HEAP32[$1165>>2] = -2147483616;
                       $1166 = ((($31)) + 4|0);
                       HEAP32[$1166>>2] = 30;
                       dest=$1162; src=105455; stop=dest+30|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                       $1167 = ((($1162)) + 30|0);
                       HEAP8[$1167>>0] = 0;
                       __THREW__ = 0;
                       (invoke_iiiid(3392,($1159|0),($284|0),($31|0),(+$1135))|0);
                       $1168 = __THREW__; __THREW__ = 0;
                       $1169 = $1168&1;
                       if ($1169) {
                        $1210 = ___cxa_find_matching_catch_2()|0;
                        $1211 = tempRet0;
                        $1212 = ((($31)) + 11|0);
                        $1213 = HEAP8[$1212>>0]|0;
                        $1214 = ($1213<<24>>24)<(0);
                        if (!($1214)) {
                         $$37 = $1210;$$37193 = $1211;
                         break;
                        }
                        $1215 = HEAP32[$31>>2]|0;
                        __ZdlPv($1215);
                        $$37 = $1210;$$37193 = $1211;
                        break;
                       }
                       $1170 = ((($31)) + 11|0);
                       $1171 = HEAP8[$1170>>0]|0;
                       $1172 = ($1171<<24>>24)<(0);
                       if ($1172) {
                        $1173 = HEAP32[$31>>2]|0;
                        __ZdlPv($1173);
                       }
                       $1174 = HEAP32[$0>>2]|0;
                       $1175 = ((($1174)) + 4|0);
                       $1176 = HEAP32[$1175>>2]|0;
                       __THREW__ = 0;
                       $1177 = (invoke_ii($1176|0,($0|0))|0);
                       $1178 = __THREW__; __THREW__ = 0;
                       $1179 = $1178&1;
                       if ($1179) {
                        break L461;
                       }
                       ;HEAP32[$32>>2]=0|0;HEAP32[$32+4>>2]=0|0;HEAP32[$32+8>>2]=0|0;
                       __THREW__ = 0;
                       $1180 = (invoke_ii(3276,32)|0);
                       $1181 = __THREW__; __THREW__ = 0;
                       $1182 = $1181&1;
                       do {
                        if ($1182) {
                         $1216 = ___cxa_find_matching_catch_2()|0;
                         $1217 = tempRet0;
                         $$38 = $1216;$$38194 = $1217;
                        } else {
                         HEAP32[$32>>2] = $1180;
                         $1183 = ((($32)) + 8|0);
                         HEAP32[$1183>>2] = -2147483616;
                         $1184 = ((($32)) + 4|0);
                         HEAP32[$1184>>2] = 31;
                         dest=$1180; src=105486; stop=dest+31|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                         $1185 = ((($1180)) + 31|0);
                         HEAP8[$1185>>0] = 0;
                         $1186 = $1135 - $59;
                         __THREW__ = 0;
                         (invoke_iiiid(3392,($1177|0),($284|0),($32|0),(+$1186))|0);
                         $1187 = __THREW__; __THREW__ = 0;
                         $1188 = $1187&1;
                         if ($1188) {
                          $1218 = ___cxa_find_matching_catch_2()|0;
                          $1219 = tempRet0;
                          $1220 = ((($32)) + 11|0);
                          $1221 = HEAP8[$1220>>0]|0;
                          $1222 = ($1221<<24>>24)<(0);
                          if (!($1222)) {
                           $$38 = $1218;$$38194 = $1219;
                           break;
                          }
                          $1223 = HEAP32[$32>>2]|0;
                          __ZdlPv($1223);
                          $$38 = $1218;$$38194 = $1219;
                          break;
                         }
                         $1189 = ((($32)) + 11|0);
                         $1190 = HEAP8[$1189>>0]|0;
                         $1191 = ($1190<<24>>24)<(0);
                         if ($1191) {
                          $1192 = HEAP32[$32>>2]|0;
                          __ZdlPv($1192);
                         }
                         break L443;
                        }
                       } while(0);
                       $$41 = $$38;$$41197 = $$38194;
                       break L346;
                      }
                     } while(0);
                     $$41 = $$37;$$41197 = $$37193;
                     break L346;
                    }
                   } while(0);
                   $$41 = $$36;$$41197 = $$36192;
                   break L346;
                  }
                 } while(0);
                 $1198 = ___cxa_find_matching_catch_2()|0;
                 $1199 = tempRet0;
                 $$41 = $1198;$$41197 = $1199;
                 break L346;
                }
               } while(0);
               if ((label|0) == 378) {
                $1193 = ___cxa_find_matching_catch_2()|0;
                $1194 = tempRet0;
                $eh$lpad$body484$index27Z2D = $1194;$eh$lpad$body484$indexZ2D = $1193;
               }
               $1195 = HEAP8[$1098>>0]|0;
               $1196 = ($1195<<24>>24)<(0);
               if ($1196) {
                $1197 = HEAP32[$29>>2]|0;
                __ZdlPv($1197);
               }
               $$41 = $eh$lpad$body484$indexZ2D;$$41197 = $eh$lpad$body484$index27Z2D;
               break L346;
              }
             } while(0);
             $1224 = ((($0)) + 33|0);
             HEAP8[$1224>>0] = 0;
             $1225 = HEAP32[$28>>2]|0;
             $1226 = ($1225|0)==(0|0);
             if (!($1226)) {
              $1227 = HEAP32[$862>>2]|0;
              $1228 = ($1227|0)==($1225|0);
              if (!($1228)) {
               $scevgep$i$i$i252 = ((($1227)) + -4|0);
               $1229 = $scevgep$i$i$i252;
               $1230 = $1225;
               $1231 = (($1229) - ($1230))|0;
               $1232 = $1231 >>> 2;
               $1233 = $1232 ^ -1;
               $scevgep5$i$i$i253 = (($1227) + ($1233<<2)|0);
               HEAP32[$862>>2] = $scevgep5$i$i$i253;
              }
              __ZdlPv($1225);
             }
             $1234 = HEAP32[$27>>2]|0;
             $1235 = ($1234|0)==(0|0);
             if (!($1235)) {
              $1236 = HEAP32[$692>>2]|0;
              $1237 = ($1236|0)==($1234|0);
              if (!($1237)) {
               $scevgep$i$i$i247 = ((($1236)) + -4|0);
               $1238 = $scevgep$i$i$i247;
               $1239 = $1234;
               $1240 = (($1238) - ($1239))|0;
               $1241 = $1240 >>> 2;
               $1242 = $1241 ^ -1;
               $scevgep5$i$i$i248 = (($1236) + ($1242<<2)|0);
               HEAP32[$692>>2] = $scevgep5$i$i$i248;
              }
              __ZdlPv($1234);
             }
             break L7;
            }
           } while(0);
           if ((label|0) == 290) {
            $908 = ___cxa_find_matching_catch_2()|0;
            $909 = tempRet0;
            $eh$lpad$body448$index19Z2D = $909;$eh$lpad$body448$indexZ2D = $908;
           }
           $$41 = $eh$lpad$body448$indexZ2D;$$41197 = $eh$lpad$body448$index19Z2D;
          }
         } while(0);
         $1252 = HEAP32[$28>>2]|0;
         $1253 = ($1252|0)==(0|0);
         if (!($1253)) {
          $1254 = HEAP32[$862>>2]|0;
          $1255 = ($1254|0)==($1252|0);
          if (!($1255)) {
           $scevgep$i$i$i239 = ((($1254)) + -4|0);
           $1256 = $scevgep$i$i$i239;
           $1257 = $1252;
           $1258 = (($1256) - ($1257))|0;
           $1259 = $1258 >>> 2;
           $1260 = $1259 ^ -1;
           $scevgep5$i$i$i240 = (($1254) + ($1260<<2)|0);
           HEAP32[$862>>2] = $scevgep5$i$i$i240;
          }
          __ZdlPv($1252);
         }
         $$43 = $$41;$$43199 = $$41197;
        }
       } while(0);
       $1261 = HEAP32[$27>>2]|0;
       $1262 = ($1261|0)==(0|0);
       if (!($1262)) {
        $1263 = HEAP32[$692>>2]|0;
        $1264 = ($1263|0)==($1261|0);
        if (!($1264)) {
         $scevgep$i$i$i236 = ((($1263)) + -4|0);
         $1265 = $scevgep$i$i$i236;
         $1266 = $1261;
         $1267 = (($1265) - ($1266))|0;
         $1268 = $1267 >>> 2;
         $1269 = $1268 ^ -1;
         $scevgep5$i$i$i237 = (($1263) + ($1269<<2)|0);
         HEAP32[$692>>2] = $scevgep5$i$i$i237;
        }
        __ZdlPv($1261);
       }
       $$47 = $$43;$$47203 = $$43199;
       break L1;
      }
     } while(0);
     $222 = ___cxa_find_matching_catch_2()|0;
     $223 = tempRet0;
     $$47 = $222;$$47203 = $223;
     break L1;
    }
   } while(0);
   $1243 = HEAP32[$3>>2]|0;
   $1244 = ($1243|0)==(0|0);
   if ($1244) {
    STACKTOP = sp;return;
   }
   $1245 = HEAP32[$33>>2]|0;
   $1246 = ($1245|0)==($1243|0);
   if (!($1246)) {
    $scevgep$i$i$i242 = ((($1245)) + -4|0);
    $1247 = $scevgep$i$i$i242;
    $1248 = $1243;
    $1249 = (($1247) - ($1248))|0;
    $1250 = $1249 >>> 2;
    $1251 = $1250 ^ -1;
    $scevgep5$i$i$i243 = (($1245) + ($1251<<2)|0);
    HEAP32[$33>>2] = $scevgep5$i$i$i243;
   }
   __ZdlPv($1243);
   STACKTOP = sp;return;
  }
 } while(0);
 if ((label|0) == 6) {
  $54 = ___cxa_find_matching_catch_2()|0;
  $55 = tempRet0;
  $$47 = $54;$$47203 = $55;
 }
 $1270 = HEAP32[$3>>2]|0;
 $1271 = ($1270|0)==(0|0);
 if ($1271) {
  ___resumeException($$47|0);
  // unreachable;
 }
 $1272 = HEAP32[$33>>2]|0;
 $1273 = ($1272|0)==($1270|0);
 if (!($1273)) {
  $scevgep$i$i$i = ((($1272)) + -4|0);
  $1274 = $scevgep$i$i$i;
  $1275 = $1270;
  $1276 = (($1274) - ($1275))|0;
  $1277 = $1276 >>> 2;
  $1278 = $1277 ^ -1;
  $scevgep5$i$i$i = (($1272) + ($1278<<2)|0);
  HEAP32[$33>>2] = $scevgep5$i$i$i;
 }
 __ZdlPv($1270);
 ___resumeException($$47|0);
 // unreachable;
}
function __ZN9osgViewer10ViewerBase10getWindowsERNSt3__26vectorIPNS_14GraphicsWindowENS1_9allocatorIS4_EEEEb($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$05 = 0, $$pre = 0, $$sroa$015$020 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i6 = 0, $scevgep$i$i$i9 = 0, $scevgep5$i$i$i = 0, $scevgep5$i$i$i10 = 0, $scevgep5$i$i$i7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp + 4|0;
 $4 = sp;
 $5 = HEAP32[$1>>2]|0;
 $6 = ((($1)) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==($5|0);
 if (!($8)) {
  $scevgep$i$i$i = ((($7)) + -4|0);
  $9 = $scevgep$i$i$i;
  $10 = $5;
  $11 = (($9) - ($10))|0;
  $12 = $11 >>> 2;
  $13 = $12 ^ -1;
  $scevgep5$i$i$i = (($7) + ($13<<2)|0);
  HEAP32[$6>>2] = $scevgep5$i$i$i;
 }
 HEAP32[$3>>2] = 0;
 $14 = ((($3)) + 4|0);
 HEAP32[$14>>2] = 0;
 $15 = ((($3)) + 8|0);
 HEAP32[$15>>2] = 0;
 $16 = HEAP32[$0>>2]|0;
 $17 = ((($16)) + 88|0);
 $18 = HEAP32[$17>>2]|0;
 __THREW__ = 0;
 invoke_viii($18|0,($0|0),($3|0),($2|0));
 $19 = __THREW__; __THREW__ = 0;
 $20 = $19&1;
 L4: do {
  if ($20) {
   $34 = ___cxa_find_matching_catch_2()|0;
   $35 = tempRet0;
   $$0 = $35;$$05 = $34;
  } else {
   $21 = HEAP32[$3>>2]|0;
   $22 = HEAP32[$14>>2]|0;
   $23 = ($21|0)==($22|0);
   do {
    if ($23) {
     $25 = $21;$27 = $21;
    } else {
     $24 = ((($1)) + 8|0);
     $$sroa$015$020 = $21;
     L9: while(1) {
      $36 = HEAP32[$$sroa$015$020>>2]|0;
      $37 = ($36|0)==(0|0);
      do {
       if ($37) {
        HEAP32[$4>>2] = 0;
       } else {
        $38 = (___dynamic_cast($36,24816,3888,0)|0);
        HEAP32[$4>>2] = $38;
        $39 = ($38|0)==(0|0);
        $40 = $38;
        if (!($39)) {
         $41 = HEAP32[$6>>2]|0;
         $42 = HEAP32[$24>>2]|0;
         $43 = ($41|0)==($42|0);
         if ($43) {
          __THREW__ = 0;
          invoke_vii(3456,($1|0),($4|0));
          $46 = __THREW__; __THREW__ = 0;
          $47 = $46&1;
          if ($47) {
           label = 19;
           break L9;
          } else {
           break;
          }
         } else {
          HEAP32[$41>>2] = $40;
          $44 = HEAP32[$6>>2]|0;
          $45 = ((($44)) + 4|0);
          HEAP32[$6>>2] = $45;
          break;
         }
        }
       }
      } while(0);
      $50 = ((($$sroa$015$020)) + 4|0);
      $51 = HEAP32[$14>>2]|0;
      $52 = ($50|0)==($51|0);
      if ($52) {
       label = 6;
       break;
      } else {
       $$sroa$015$020 = $50;
      }
     }
     if ((label|0) == 6) {
      $$pre = HEAP32[$3>>2]|0;
      $25 = $$pre;$27 = $50;
      break;
     }
     else if ((label|0) == 19) {
      $48 = ___cxa_find_matching_catch_2()|0;
      $49 = tempRet0;
      $$0 = $49;$$05 = $48;
      break L4;
     }
    }
   } while(0);
   $26 = ($25|0)==(0|0);
   if ($26) {
    STACKTOP = sp;return;
   }
   $28 = ($27|0)==($25|0);
   if (!($28)) {
    $scevgep$i$i$i9 = ((($27)) + -4|0);
    $29 = $scevgep$i$i$i9;
    $30 = $25;
    $31 = (($29) - ($30))|0;
    $32 = $31 >>> 2;
    $33 = $32 ^ -1;
    $scevgep5$i$i$i10 = (($27) + ($33<<2)|0);
    HEAP32[$14>>2] = $scevgep5$i$i$i10;
   }
   __ZdlPv($25);
   STACKTOP = sp;return;
  }
 } while(0);
 $53 = HEAP32[$3>>2]|0;
 $54 = ($53|0)==(0|0);
 if ($54) {
  ___resumeException($$05|0);
  // unreachable;
 }
 $55 = HEAP32[$14>>2]|0;
 $56 = ($55|0)==($53|0);
 if (!($56)) {
  $scevgep$i$i$i6 = ((($55)) + -4|0);
  $57 = $scevgep$i$i$i6;
  $58 = $53;
  $59 = (($57) - ($58))|0;
  $60 = $59 >>> 2;
  $61 = $60 ^ -1;
  $scevgep5$i$i$i7 = (($55) + ($61<<2)|0);
  HEAP32[$14>>2] = $scevgep5$i$i$i7;
 }
 __ZdlPv($53);
 ___resumeException($$05|0);
 // unreachable;
}
function __ZNSt3__26vectorIPN9osgViewer14GraphicsWindowENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(1073741823);
 if ($8) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $9 = ((($0)) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) - ($4))|0;
 $12 = $11 >> 2;
 $13 = ($12>>>0)<(536870911);
 $14 = $11 >> 1;
 $15 = ($14>>>0)<($7>>>0);
 $$sroa$speculated$i = $15 ? $7 : $14;
 $$sroa$speculated$$i = $13 ? $$sroa$speculated$i : 1073741823;
 $16 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($16) {
   $26 = 0;
  } else {
   $17 = ($$sroa$speculated$$i>>>0)>(1073741823);
   if (!($17)) {
    $23 = $$sroa$speculated$$i << 2;
    $24 = (__Znwj($23)|0);
    $26 = $24;
    break;
   }
   $18 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($18|0),(204840|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if ($20) {
    $21 = ___cxa_find_matching_catch_2()|0;
    $22 = tempRet0;
    ___cxa_free_exception(($18|0));
    ___resumeException($21|0);
    // unreachable;
   } else {
    HEAP32[$18>>2] = (99824);
    ___cxa_throw(($18|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $25 = (($26) + ($6<<2)|0);
 $27 = (($26) + ($$sroa$speculated$$i<<2)|0);
 $28 = $27;
 $29 = HEAP32[$1>>2]|0;
 HEAP32[$25>>2] = $29;
 $30 = ((($25)) + 4|0);
 $31 = $30;
 $32 = (0 - ($6))|0;
 $33 = (($25) + ($32<<2)|0);
 $34 = $33;
 $35 = ($5|0)>(0);
 if ($35) {
  $36 = $4;
  _memcpy(($33|0),($36|0),($5|0))|0;
 }
 HEAP32[$0>>2] = $34;
 HEAP32[$2>>2] = $31;
 HEAP32[$9>>2] = $28;
 $37 = ($4|0)==(0);
 if ($37) {
  return;
 }
 $38 = $4;
 __ZdlPv($38);
 return;
}
function __ZN7osgUtil12StatsVisitorD2Ev($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$cast = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $2;
 $3 = ((($1)) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $$cast = $2;
 $5 = ((($$cast)) + -12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($0) + ($6)|0);
 HEAP32[$7>>2] = $4;
 $8 = ((($0)) + 288|0);
 HEAP32[$8>>2] = (50252);
 $9 = ((($0)) + 356|0);
 $10 = ((($0)) + 360|0);
 $11 = HEAP32[$10>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIjjEENS_19__map_value_compareIjS2_NS_4lessIjEELb1EEENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($9,$11);
 $12 = ((($0)) + 340|0);
 $13 = ((($0)) + 344|0);
 $14 = HEAP32[$13>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIjNS_4pairIjjEEEENS_19__map_value_compareIjS4_NS_4lessIjEELb1EEENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($12,$14);
 $15 = ((($0)) + 200|0);
 HEAP32[$15>>2] = (50252);
 $16 = ((($0)) + 268|0);
 $17 = ((($0)) + 272|0);
 $18 = HEAP32[$17>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIjjEENS_19__map_value_compareIjS2_NS_4lessIjEELb1EEENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($16,$18);
 $19 = ((($0)) + 252|0);
 $20 = ((($0)) + 256|0);
 $21 = HEAP32[$20>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIjNS_4pairIjjEEEENS_19__map_value_compareIjS4_NS_4lessIjEELb1EEENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($19,$21);
 $22 = ((($0)) + 188|0);
 $23 = ((($0)) + 192|0);
 $24 = HEAP32[$23>>2]|0;
 __ZNSt3__26__treeIPN3osg8StateSetENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($22,$24);
 $25 = ((($0)) + 176|0);
 $26 = ((($0)) + 180|0);
 $27 = HEAP32[$26>>2]|0;
 __ZNSt3__26__treeIPN3osg8DrawableENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($25,$27);
 $28 = ((($0)) + 164|0);
 $29 = ((($0)) + 168|0);
 $30 = HEAP32[$29>>2]|0;
 __ZNSt3__26__treeIPN3osg8DrawableENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($28,$30);
 $31 = ((($0)) + 152|0);
 $32 = ((($0)) + 156|0);
 $33 = HEAP32[$32>>2]|0;
 __ZNSt3__26__treeIPN3osg8DrawableENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($31,$33);
 $34 = ((($0)) + 140|0);
 $35 = ((($0)) + 144|0);
 $36 = HEAP32[$35>>2]|0;
 __ZNSt3__26__treeIPN3osg4NodeENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($34,$36);
 $37 = ((($0)) + 128|0);
 $38 = ((($0)) + 132|0);
 $39 = HEAP32[$38>>2]|0;
 __ZNSt3__26__treeIPN3osg4NodeENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($37,$39);
 $40 = ((($0)) + 116|0);
 $41 = ((($0)) + 120|0);
 $42 = HEAP32[$41>>2]|0;
 __ZNSt3__26__treeIPN3osg4NodeENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($40,$42);
 $43 = ((($0)) + 104|0);
 $44 = ((($0)) + 108|0);
 $45 = HEAP32[$44>>2]|0;
 __ZNSt3__26__treeIPN3osg4NodeENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($43,$45);
 $46 = ((($0)) + 92|0);
 $47 = ((($0)) + 96|0);
 $48 = HEAP32[$47>>2]|0;
 __ZNSt3__26__treeIPN3osg4NodeENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($46,$48);
 $49 = ((($1)) + 4|0);
 __ZN3osg11NodeVisitorD2Ev($0,$49);
 return;
}
function __ZN9osgViewer10ViewerBase11makeCurrentEPN3osg15GraphicsContextE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$$i = 0, $$pr$i = 0, $$pr$i6 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $phitmp$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 96|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==($1|0);
 if ($4) {
  return;
 }
 $5 = ((($0)) + 92|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if (!($7)) {
  $8 = ((($6)) + 24|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($9|0)==(0|0);
  $phitmp$i$i = ($3|0)==(0|0);
  $or$cond = $10 | $phitmp$i$i;
  if (!($or$cond)) {
   $11 = HEAP32[$3>>2]|0;
   $12 = ((($11)) + 144|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (FUNCTION_TABLE_ii[$13 & 8191]($3)|0);
   if ($14) {
    $15 = HEAP32[$2>>2]|0;
    (__ZN3osg15GraphicsContext14releaseContextEv($15)|0);
   }
  }
  $$pr$i6 = HEAP32[$5>>2]|0;
  $16 = ($$pr$i6|0)==(0|0);
  if (!($16)) {
   HEAP32[$5>>2] = 0;
   $17 = ((($$pr$i6)) + 8|0);
   $18 = HEAP32[$17>>2]|0;HEAP32[$17>>2] = (($18-1)|0);
   $19 = ($18|0)==(1);
   if ($19) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($$pr$i6,1,1);
   }
  }
 }
 HEAP32[$2>>2] = 0;
 $20 = ($1|0)==(0|0);
 if ($20) {
  return;
 }
 $21 = HEAP32[$1>>2]|0;
 $22 = ((($21)) + 144|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (FUNCTION_TABLE_ii[$23 & 8191]($1)|0);
 if (!($24)) {
  return;
 }
 $25 = (__ZN3osg15GraphicsContext11makeCurrentEv($1)|0);
 if (!($25)) {
  return;
 }
 $26 = (__ZNK3osg10Referenced22getOrCreateObserverSetEv($1)|0);
 $27 = HEAP32[$5>>2]|0;
 $28 = ($27|0)==($26|0);
 if ($28) {
  $36 = $26;
 } else {
  HEAP32[$5>>2] = $26;
  $29 = ($26|0)==(0|0);
  if (!($29)) {
   $30 = ((($26)) + 8|0);
   $31 = HEAP32[$30>>2]|0;HEAP32[$30>>2] = (($31+1)|0);
  }
  $32 = ($27|0)==(0|0);
  if (!($32)) {
   $33 = ((($27)) + 8|0);
   $34 = HEAP32[$33>>2]|0;HEAP32[$33>>2] = (($34-1)|0);
   $35 = ($34|0)==(1);
   if ($35) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($27,1,1);
   }
  }
  $$pr$i = HEAP32[$5>>2]|0;
  $36 = $$pr$i;
 }
 $37 = ($36|0)==(0|0);
 if ($37) {
  $41 = 0;
 } else {
  $38 = ((($36)) + 24|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = ($39|0)!=(0|0);
  $$$i = $40 ? $1 : 0;
  $41 = $$$i;
 }
 HEAP32[$2>>2] = $41;
 return;
}
function __ZNSt3__26__treeINS_12__value_typeIjjEENS_19__map_value_compareIjS2_NS_4lessIjEELb1EEENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 } else {
  $3 = HEAP32[$1>>2]|0;
  __ZNSt3__26__treeINS_12__value_typeIjjEENS_19__map_value_compareIjS2_NS_4lessIjEELb1EEENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($0,$3);
  $4 = ((($1)) + 4|0);
  $5 = HEAP32[$4>>2]|0;
  __ZNSt3__26__treeINS_12__value_typeIjjEENS_19__map_value_compareIjS2_NS_4lessIjEELb1EEENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($0,$5);
  __ZdlPv($1);
  return;
 }
}
function __ZNSt3__26__treeINS_12__value_typeIjNS_4pairIjjEEEENS_19__map_value_compareIjS4_NS_4lessIjEELb1EEENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 } else {
  $3 = HEAP32[$1>>2]|0;
  __ZNSt3__26__treeINS_12__value_typeIjNS_4pairIjjEEEENS_19__map_value_compareIjS4_NS_4lessIjEELb1EEENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($0,$3);
  $4 = ((($1)) + 4|0);
  $5 = HEAP32[$4>>2]|0;
  __ZNSt3__26__treeINS_12__value_typeIjNS_4pairIjjEEEENS_19__map_value_compareIjS4_NS_4lessIjEELb1EEENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($0,$5);
  __ZdlPv($1);
  return;
 }
}
function __ZNSt3__26__treeIPN3osg8StateSetENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 } else {
  $3 = HEAP32[$1>>2]|0;
  __ZNSt3__26__treeIPN3osg8StateSetENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($0,$3);
  $4 = ((($1)) + 4|0);
  $5 = HEAP32[$4>>2]|0;
  __ZNSt3__26__treeIPN3osg8StateSetENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($0,$5);
  __ZdlPv($1);
  return;
 }
}
function __ZNSt3__26__treeIPN3osg8DrawableENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 } else {
  $3 = HEAP32[$1>>2]|0;
  __ZNSt3__26__treeIPN3osg8DrawableENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($0,$3);
  $4 = ((($1)) + 4|0);
  $5 = HEAP32[$4>>2]|0;
  __ZNSt3__26__treeIPN3osg8DrawableENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($0,$5);
  __ZdlPv($1);
  return;
 }
}
function __ZNSt3__26__treeIPN3osg4NodeENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 } else {
  $3 = HEAP32[$1>>2]|0;
  __ZNSt3__26__treeIPN3osg4NodeENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($0,$3);
  $4 = ((($1)) + 4|0);
  $5 = HEAP32[$4>>2]|0;
  __ZNSt3__26__treeIPN3osg4NodeENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($0,$5);
  __ZdlPv($1);
  return;
 }
}
function __ZN3osg16BarrierOperationC1EiNS0_10PreBlockOpEb($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$1 = 0, $$16 = 0, $$cast$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $4 = sp;
 $5 = ((($0)) + 36|0);
 __ZN3osg10ReferencedC2Eb($5,1);
 $6 = ((($4)) + 8|0);
 HEAP32[$6>>2] = 0;
 $7 = ((($4)) + 11|0);
 HEAP8[$7>>0] = 7;
 ;HEAP8[$4>>0]=HEAP8[105852>>0]|0;HEAP8[$4+1>>0]=HEAP8[105852+1>>0]|0;HEAP8[$4+2>>0]=HEAP8[105852+2>>0]|0;HEAP8[$4+3>>0]=HEAP8[105852+3>>0]|0;HEAP8[$4+4>>0]=HEAP8[105852+4>>0]|0;HEAP8[$4+5>>0]=HEAP8[105852+5>>0]|0;HEAP8[$4+6>>0]=HEAP8[105852+6>>0]|0;
 $8 = ((($4)) + 7|0);
 HEAP8[$8>>0] = 0;
 $9 = HEAP32[(61016)>>2]|0;
 HEAP32[$0>>2] = $9;
 $10 = HEAP32[(61020)>>2]|0;
 $$cast$i = $9;
 $11 = ((($$cast$i)) + -12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($0) + ($12)|0);
 HEAP32[$13>>2] = $10;
 $14 = ((($0)) + 4|0);
 __THREW__ = 0;
 invoke_vii(3457,($14|0),($4|0));
 $15 = __THREW__; __THREW__ = 0;
 $16 = $15&1;
 if ($16) {
  $26 = ___cxa_find_matching_catch_2()|0;
  $27 = tempRet0;
  $28 = HEAP8[$7>>0]|0;
  $29 = ($28<<24>>24)<(0);
  if ($29) {
   $30 = HEAP32[$4>>2]|0;
   __ZdlPv($30);
  }
  $$1 = $27;$$16 = $26;
 } else {
  $17 = $3&1;
  $18 = ((($0)) + 16|0);
  HEAP8[$18>>0] = $17;
  $19 = HEAP8[$7>>0]|0;
  $20 = ($19<<24>>24)<(0);
  if ($20) {
   $21 = HEAP32[$4>>2]|0;
   __ZdlPv($21);
  }
  $22 = ((($0)) + 20|0);
  __THREW__ = 0;
  invoke_vii(3458,($22|0),($1|0));
  $23 = __THREW__; __THREW__ = 0;
  $24 = $23&1;
  if (!($24)) {
   HEAP32[$0>>2] = (60936);
   HEAP32[$5>>2] = (61000);
   HEAP32[$22>>2] = (60960);
   $25 = ((($0)) + 32|0);
   HEAP32[$25>>2] = $2;
   STACKTOP = sp;return;
  }
  $31 = ___cxa_find_matching_catch_2()|0;
  $32 = tempRet0;
  HEAP32[$0>>2] = $9;
  $33 = HEAP32[$11>>2]|0;
  $34 = (($0) + ($33)|0);
  HEAP32[$34>>2] = $10;
  $35 = ((($14)) + 11|0);
  $36 = HEAP8[$35>>0]|0;
  $37 = ($36<<24>>24)<(0);
  if ($37) {
   $38 = HEAP32[$14>>2]|0;
   __ZdlPv($38);
   $$1 = $32;$$16 = $31;
  } else {
   $$1 = $32;$$16 = $31;
  }
 }
 __THREW__ = 0;
 invoke_vi(712,($5|0));
 $39 = __THREW__; __THREW__ = 0;
 $40 = $39&1;
 if ($40) {
  $41 = ___cxa_find_matching_catch_3(0|0)|0;
  $42 = tempRet0;
  ___clang_call_terminate($41);
  // unreachable;
 } else {
  ___resumeException($$16|0);
  // unreachable;
 }
}
function __ZN3osg20SwapBuffersOperationC1Ev($0) {
 $0 = $0|0;
 var $$0 = 0, $$02 = 0, $$cast$i = 0, $$cast$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $2 = ((($0)) + 20|0);
 __ZN3osg10ReferencedC2Eb($2,1);
 ;HEAP32[$1>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;
 __THREW__ = 0;
 $3 = (invoke_ii(3276,16)|0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 do {
  if ($5) {
   $27 = ___cxa_find_matching_catch_2()|0;
   $28 = tempRet0;
   $$0 = $28;$$02 = $27;
  } else {
   HEAP32[$1>>2] = $3;
   $6 = ((($1)) + 8|0);
   HEAP32[$6>>2] = -2147483632;
   $7 = ((($1)) + 4|0);
   HEAP32[$7>>2] = 11;
   dest=$3; src=105840; stop=dest+11|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
   $8 = ((($3)) + 11|0);
   HEAP8[$8>>0] = 0;
   $9 = HEAP32[(60908)>>2]|0;
   HEAP32[$0>>2] = $9;
   $10 = HEAP32[(60912)>>2]|0;
   $$cast$i$i = $9;
   $11 = ((($$cast$i$i)) + -12|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = (($0) + ($12)|0);
   HEAP32[$13>>2] = $10;
   $14 = ((($0)) + 4|0);
   __THREW__ = 0;
   invoke_vii(3457,($14|0),($1|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if ($16) {
    $29 = ___cxa_find_matching_catch_2()|0;
    $30 = tempRet0;
    $31 = ((($1)) + 11|0);
    $32 = HEAP8[$31>>0]|0;
    $33 = ($32<<24>>24)<(0);
    if (!($33)) {
     $$0 = $30;$$02 = $29;
     break;
    }
    $34 = HEAP32[$1>>2]|0;
    __ZdlPv($34);
    $$0 = $30;$$02 = $29;
    break;
   }
   $17 = ((($0)) + 16|0);
   HEAP8[$17>>0] = 1;
   $18 = HEAP32[(60904)>>2]|0;
   HEAP32[$0>>2] = $18;
   $19 = HEAP32[(60916)>>2]|0;
   $$cast$i = $18;
   $20 = ((($$cast$i)) + -12|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = (($0) + ($21)|0);
   HEAP32[$22>>2] = $19;
   $23 = ((($1)) + 11|0);
   $24 = HEAP8[$23>>0]|0;
   $25 = ($24<<24>>24)<(0);
   if (!($25)) {
    HEAP32[$0>>2] = (60852);
    HEAP32[$2>>2] = (60888);
    STACKTOP = sp;return;
   }
   $26 = HEAP32[$1>>2]|0;
   __ZdlPv($26);
   HEAP32[$0>>2] = (60852);
   HEAP32[$2>>2] = (60888);
   STACKTOP = sp;return;
  }
 } while(0);
 __THREW__ = 0;
 invoke_vi(712,($2|0));
 $35 = __THREW__; __THREW__ = 0;
 $36 = $35&1;
 if ($36) {
  $37 = ___cxa_find_matching_catch_3(0|0)|0;
  $38 = tempRet0;
  ___clang_call_terminate($37);
  // unreachable;
 } else {
  ___resumeException($$02|0);
  // unreachable;
 }
}
function __ZN3osg13RunOperationsC1Ev($0) {
 $0 = $0|0;
 var $$0 = 0, $$02 = 0, $$cast$i = 0, $$cast$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $2 = ((($0)) + 20|0);
 __ZN3osg10ReferencedC2Ev($2);
 ;HEAP32[$1>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;
 __THREW__ = 0;
 $3 = (invoke_ii(3276,16)|0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 do {
  if ($5) {
   $27 = ___cxa_find_matching_catch_2()|0;
   $28 = tempRet0;
   $$0 = $28;$$02 = $27;
  } else {
   HEAP32[$1>>2] = $3;
   $6 = ((($1)) + 8|0);
   HEAP32[$6>>2] = -2147483632;
   $7 = ((($1)) + 4|0);
   HEAP32[$7>>2] = 12;
   dest=$3; src=105827; stop=dest+12|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
   $8 = ((($3)) + 12|0);
   HEAP8[$8>>0] = 0;
   $9 = HEAP32[(61096)>>2]|0;
   HEAP32[$0>>2] = $9;
   $10 = HEAP32[(61100)>>2]|0;
   $$cast$i$i = $9;
   $11 = ((($$cast$i$i)) + -12|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = (($0) + ($12)|0);
   HEAP32[$13>>2] = $10;
   $14 = ((($0)) + 4|0);
   __THREW__ = 0;
   invoke_vii(3457,($14|0),($1|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if ($16) {
    $29 = ___cxa_find_matching_catch_2()|0;
    $30 = tempRet0;
    $31 = ((($1)) + 11|0);
    $32 = HEAP8[$31>>0]|0;
    $33 = ($32<<24>>24)<(0);
    if (!($33)) {
     $$0 = $30;$$02 = $29;
     break;
    }
    $34 = HEAP32[$1>>2]|0;
    __ZdlPv($34);
    $$0 = $30;$$02 = $29;
    break;
   }
   $17 = ((($0)) + 16|0);
   HEAP8[$17>>0] = 1;
   $18 = HEAP32[(61092)>>2]|0;
   HEAP32[$0>>2] = $18;
   $19 = HEAP32[(61104)>>2]|0;
   $$cast$i = $18;
   $20 = ((($$cast$i)) + -12|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = (($0) + ($21)|0);
   HEAP32[$22>>2] = $19;
   $23 = ((($1)) + 11|0);
   $24 = HEAP8[$23>>0]|0;
   $25 = ($24<<24>>24)<(0);
   if (!($25)) {
    HEAP32[$0>>2] = (61040);
    HEAP32[$2>>2] = (61076);
    STACKTOP = sp;return;
   }
   $26 = HEAP32[$1>>2]|0;
   __ZdlPv($26);
   HEAP32[$0>>2] = (61040);
   HEAP32[$2>>2] = (61076);
   STACKTOP = sp;return;
  }
 } while(0);
 __THREW__ = 0;
 invoke_vi(712,($2|0));
 $35 = __THREW__; __THREW__ = 0;
 $36 = $35&1;
 if ($36) {
  $37 = ___cxa_find_matching_catch_3(0|0)|0;
  $38 = tempRet0;
  ___clang_call_terminate($37);
  // unreachable;
 } else {
  ___resumeException($$02|0);
  // unreachable;
 }
}
function __ZNSt3__26vectorIjNS_9allocatorIjEEE21__push_back_slow_pathIKjEEvRT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(1073741823);
 if ($8) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $9 = ((($0)) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) - ($4))|0;
 $12 = $11 >> 2;
 $13 = ($12>>>0)<(536870911);
 $14 = $11 >> 1;
 $15 = ($14>>>0)<($7>>>0);
 $$sroa$speculated$i = $15 ? $7 : $14;
 $$sroa$speculated$$i = $13 ? $$sroa$speculated$i : 1073741823;
 $16 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($16) {
   $26 = 0;
  } else {
   $17 = ($$sroa$speculated$$i>>>0)>(1073741823);
   if (!($17)) {
    $23 = $$sroa$speculated$$i << 2;
    $24 = (__Znwj($23)|0);
    $26 = $24;
    break;
   }
   $18 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($18|0),(204840|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if ($20) {
    $21 = ___cxa_find_matching_catch_2()|0;
    $22 = tempRet0;
    ___cxa_free_exception(($18|0));
    ___resumeException($21|0);
    // unreachable;
   } else {
    HEAP32[$18>>2] = (99824);
    ___cxa_throw(($18|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $25 = (($26) + ($6<<2)|0);
 $27 = (($26) + ($$sroa$speculated$$i<<2)|0);
 $28 = $27;
 $29 = HEAP32[$1>>2]|0;
 HEAP32[$25>>2] = $29;
 $30 = ((($25)) + 4|0);
 $31 = $30;
 $32 = (0 - ($6))|0;
 $33 = (($25) + ($32<<2)|0);
 $34 = $33;
 $35 = ($5|0)>(0);
 if ($35) {
  $36 = $4;
  _memcpy(($33|0),($36|0),($5|0))|0;
 }
 HEAP32[$0>>2] = $34;
 HEAP32[$2>>2] = $31;
 HEAP32[$9>>2] = $28;
 $37 = ($4|0)==(0);
 if ($37) {
  return;
 }
 $38 = $4;
 __ZdlPv($38);
 return;
}
function __ZN11OpenThreads8AffinityC2Ejj($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$i$i$i$i = 0, $$0$ph$i$i$i$i = 0, $$018 = 0, $$024$i$i$i$i = 0, $$025$i$i$i$i = 0, $$036$i$i$i = 0, $$0517 = 0, $$in$i$i$i$i = 0, $$pre = 0, $$pre$i$i$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = ((($0)) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = ((($0)) + 4|0);
 HEAP32[$0>>2] = $5;
 $6 = ($2|0)==(0);
 if ($6) {
  return;
 }
 $$018 = $1;$$0517 = $2;$7 = 0;
 while(1) {
  $8 = ($7|0)==(0|0);
  do {
   if ($8) {
    $$025$i$i$i$i = $5;$$036$i$i$i = $5;
   } else {
    $$0$i$i$i$i = $3;$$024$i$i$i$i = $7;
    while(1) {
     $9 = ((($$024$i$i$i$i)) + 16|0);
     $10 = HEAP32[$9>>2]|0;
     $11 = ($$018>>>0)<($10>>>0);
     if ($11) {
      $12 = HEAP32[$$024$i$i$i$i>>2]|0;
      $13 = ($12|0)==(0|0);
      if ($13) {
       label = 7;
       break;
      } else {
       $$0$ph$i$i$i$i = $$024$i$i$i$i;$$in$i$i$i$i = $12;
      }
     } else {
      $14 = ($10>>>0)<($$018>>>0);
      if (!($14)) {
       label = 11;
       break;
      }
      $15 = ((($$024$i$i$i$i)) + 4|0);
      $16 = HEAP32[$15>>2]|0;
      $17 = ($16|0)==(0|0);
      if ($17) {
       label = 10;
       break;
      } else {
       $$0$ph$i$i$i$i = $15;$$in$i$i$i$i = $16;
      }
     }
     $$0$i$i$i$i = $$0$ph$i$i$i$i;$$024$i$i$i$i = $$in$i$i$i$i;
    }
    if ((label|0) == 7) {
     label = 0;
     $$025$i$i$i$i = $$024$i$i$i$i;$$036$i$i$i = $$024$i$i$i$i;
     break;
    }
    else if ((label|0) == 10) {
     label = 0;
     $$025$i$i$i$i = $15;$$036$i$i$i = $$024$i$i$i$i;
     break;
    }
    else if ((label|0) == 11) {
     label = 0;
     $$025$i$i$i$i = $$0$i$i$i$i;$$036$i$i$i = $$024$i$i$i$i;
     break;
    }
   }
  } while(0);
  $18 = HEAP32[$$025$i$i$i$i>>2]|0;
  $19 = ($18|0)==(0|0);
  if ($19) {
   __THREW__ = 0;
   $20 = (invoke_ii(3276,20)|0);
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if ($22) {
    label = 20;
    break;
   }
   $23 = ((($20)) + 16|0);
   HEAP32[$23>>2] = $$018;
   HEAP32[$20>>2] = 0;
   $24 = ((($20)) + 4|0);
   HEAP32[$24>>2] = 0;
   $25 = ((($20)) + 8|0);
   HEAP32[$25>>2] = $$036$i$i$i;
   HEAP32[$$025$i$i$i$i>>2] = $20;
   $26 = HEAP32[$0>>2]|0;
   $27 = HEAP32[$26>>2]|0;
   $28 = ($27|0)==(0|0);
   if ($28) {
    $31 = $20;
   } else {
    $29 = $27;
    HEAP32[$0>>2] = $29;
    $$pre$i$i$i$i = HEAP32[$$025$i$i$i$i>>2]|0;
    $31 = $$pre$i$i$i$i;
   }
   $30 = HEAP32[$3>>2]|0;
   __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($30,$31);
   $32 = HEAP32[$4>>2]|0;
   $33 = (($32) + 1)|0;
   HEAP32[$4>>2] = $33;
  }
  $34 = (($$0517) + -1)|0;
  $35 = ($34|0)==(0);
  if ($35) {
   label = 19;
   break;
  }
  $36 = (($$018) + 1)|0;
  $$pre = HEAP32[$5>>2]|0;
  $$018 = $36;$$0517 = $34;$7 = $$pre;
 }
 if ((label|0) == 19) {
  return;
 }
 else if ((label|0) == 20) {
  $37 = ___cxa_find_matching_catch_2()|0;
  $38 = tempRet0;
  __ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEE7destroyEPNS_11__tree_nodeIjPvEE($0,$7);
  ___resumeException($37|0);
  // unreachable;
 }
}
function __GLOBAL__sub_I_ViewerBase_cpp() {
 var $$0$i = 0, $$0$i14 = 0, $$0$i22 = 0, $$0$i30 = 0, $$0$i38 = 0, $$0$i6 = 0, $$01$i = 0, $$01$i13 = 0, $$01$i21 = 0, $$01$i29 = 0, $$01$i37 = 0, $$01$i5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0;
 var $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0;
 var $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0;
 var $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0;
 var $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0;
 var $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(144|0);
 $0 = sp + 132|0;
 $1 = sp + 120|0;
 $2 = sp + 108|0;
 $3 = sp + 96|0;
 $4 = sp + 84|0;
 $5 = sp + 72|0;
 $6 = sp + 60|0;
 $7 = sp + 48|0;
 $8 = sp + 36|0;
 $9 = sp + 24|0;
 $10 = sp + 12|0;
 $11 = sp;
 HEAPF32[51939] = 1.0;
 HEAPF32[(207760)>>2] = 0.0;
 HEAPF32[(207764)>>2] = 0.0;
 HEAPF32[51942] = 0.0;
 HEAPF32[(207772)>>2] = 1.0;
 HEAPF32[(207776)>>2] = 0.0;
 HEAPF32[51945] = 0.0;
 HEAPF32[(207784)>>2] = 0.0;
 HEAPF32[(207788)>>2] = 1.0;
 $12 = (__Znwj(32)|0);
 HEAP32[$8>>2] = $12;
 $13 = ((($8)) + 8|0);
 HEAP32[$13>>2] = -2147483616;
 $14 = ((($8)) + 4|0);
 HEAP32[$14>>2] = 26;
 dest=$12; src=106161; stop=dest+26|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $15 = ((($12)) + 26|0);
 HEAP8[$15>>0] = 0;
 ;HEAP32[$9>>2]=0|0;HEAP32[$9+4>>2]=0|0;HEAP32[$9+8>>2]=0|0;
 __THREW__ = 0;
 $16 = (invoke_ii(3276,64)|0);
 $17 = __THREW__; __THREW__ = 0;
 $18 = $17&1;
 if ($18) {
  $35 = ___cxa_find_matching_catch_2()|0;
  $36 = tempRet0;
  $$0$i6 = $36;$$01$i5 = $35;
 } else {
  HEAP32[$9>>2] = $16;
  $19 = ((($9)) + 8|0);
  HEAP32[$19>>2] = -2147483584;
  $20 = ((($9)) + 4|0);
  HEAP32[$20>>2] = 55;
  dest=$16; src=106188; stop=dest+55|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
  $21 = ((($16)) + 55|0);
  HEAP8[$21>>0] = 0;
  __THREW__ = 0;
  $22 = (invoke_i(3459)|0);
  $23 = __THREW__; __THREW__ = 0;
  $24 = $23&1;
  if (!($24)) {
   __THREW__ = 0;
   invoke_viiii(3460,($22|0),2,($8|0),($9|0));
   $25 = __THREW__; __THREW__ = 0;
   $26 = $25&1;
   if (!($26)) {
    $27 = ((($9)) + 11|0);
    $28 = HEAP8[$27>>0]|0;
    $29 = ($28<<24>>24)<(0);
    if ($29) {
     $30 = HEAP32[$9>>2]|0;
     __ZdlPv($30);
    }
    $31 = ((($8)) + 11|0);
    $32 = HEAP8[$31>>0]|0;
    $33 = ($32<<24>>24)<(0);
    if ($33) {
     $34 = HEAP32[$8>>2]|0;
     __ZdlPv($34);
    }
    $47 = (__Znwj(32)|0);
    HEAP32[$6>>2] = $47;
    $48 = ((($6)) + 8|0);
    HEAP32[$48>>2] = -2147483616;
    $49 = ((($6)) + 4|0);
    HEAP32[$49>>2] = 21;
    dest=$47; src=106244; stop=dest+21|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
    $50 = ((($47)) + 21|0);
    HEAP8[$50>>0] = 0;
    ;HEAP32[$7>>2]=0|0;HEAP32[$7+4>>2]=0|0;HEAP32[$7+8>>2]=0|0;
    __THREW__ = 0;
    $51 = (invoke_ii(3276,176)|0);
    $52 = __THREW__; __THREW__ = 0;
    $53 = $52&1;
    if ($53) {
     $70 = ___cxa_find_matching_catch_2()|0;
     $71 = tempRet0;
     $$0$i14 = $71;$$01$i13 = $70;
    } else {
     HEAP32[$7>>2] = $51;
     $54 = ((($7)) + 8|0);
     HEAP32[$54>>2] = -2147483472;
     $55 = ((($7)) + 4|0);
     HEAP32[$55>>2] = 162;
     _memcpy(($51|0),(106266|0),162)|0;
     $56 = ((($51)) + 162|0);
     HEAP8[$56>>0] = 0;
     __THREW__ = 0;
     $57 = (invoke_i(3459)|0);
     $58 = __THREW__; __THREW__ = 0;
     $59 = $58&1;
     if (!($59)) {
      __THREW__ = 0;
      invoke_viiii(3460,($57|0),2,($6|0),($7|0));
      $60 = __THREW__; __THREW__ = 0;
      $61 = $60&1;
      if (!($61)) {
       $62 = ((($7)) + 11|0);
       $63 = HEAP8[$62>>0]|0;
       $64 = ($63<<24>>24)<(0);
       if ($64) {
        $65 = HEAP32[$7>>2]|0;
        __ZdlPv($65);
       }
       $66 = ((($6)) + 11|0);
       $67 = HEAP8[$66>>0]|0;
       $68 = ($67<<24>>24)<(0);
       if ($68) {
        $69 = HEAP32[$6>>2]|0;
        __ZdlPv($69);
       }
       $82 = (__Znwj(32)|0);
       HEAP32[$4>>2] = $82;
       $83 = ((($4)) + 8|0);
       HEAP32[$83>>2] = -2147483616;
       $84 = ((($4)) + 4|0);
       HEAP32[$84>>2] = 18;
       dest=$82; src=106429; stop=dest+18|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
       $85 = ((($82)) + 18|0);
       HEAP8[$85>>0] = 0;
       ;HEAP32[$5>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;
       __THREW__ = 0;
       $86 = (invoke_ii(3276,64)|0);
       $87 = __THREW__; __THREW__ = 0;
       $88 = $87&1;
       if ($88) {
        $105 = ___cxa_find_matching_catch_2()|0;
        $106 = tempRet0;
        $$0$i22 = $106;$$01$i21 = $105;
       } else {
        HEAP32[$5>>2] = $86;
        $89 = ((($5)) + 8|0);
        HEAP32[$89>>2] = -2147483584;
        $90 = ((($5)) + 4|0);
        HEAP32[$90>>2] = 54;
        dest=$86; src=106448; stop=dest+54|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
        $91 = ((($86)) + 54|0);
        HEAP8[$91>>0] = 0;
        __THREW__ = 0;
        $92 = (invoke_i(3459)|0);
        $93 = __THREW__; __THREW__ = 0;
        $94 = $93&1;
        if (!($94)) {
         __THREW__ = 0;
         invoke_viiii(3460,($92|0),2,($4|0),($5|0));
         $95 = __THREW__; __THREW__ = 0;
         $96 = $95&1;
         if (!($96)) {
          $97 = ((($5)) + 11|0);
          $98 = HEAP8[$97>>0]|0;
          $99 = ($98<<24>>24)<(0);
          if ($99) {
           $100 = HEAP32[$5>>2]|0;
           __ZdlPv($100);
          }
          $101 = ((($4)) + 11|0);
          $102 = HEAP8[$101>>0]|0;
          $103 = ($102<<24>>24)<(0);
          if ($103) {
           $104 = HEAP32[$4>>2]|0;
           __ZdlPv($104);
          }
          $117 = (__Znwj(32)|0);
          HEAP32[$2>>2] = $117;
          $118 = ((($2)) + 8|0);
          HEAP32[$118>>2] = -2147483616;
          $119 = ((($2)) + 4|0);
          HEAP32[$119>>2] = 27;
          dest=$117; src=106503; stop=dest+27|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
          $120 = ((($117)) + 27|0);
          HEAP8[$120>>0] = 0;
          ;HEAP32[$3>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;
          __THREW__ = 0;
          $121 = (invoke_ii(3276,80)|0);
          $122 = __THREW__; __THREW__ = 0;
          $123 = $122&1;
          do {
           if ($123) {
            $140 = ___cxa_find_matching_catch_2()|0;
            $141 = tempRet0;
            $$0$i30 = $141;$$01$i29 = $140;
           } else {
            HEAP32[$3>>2] = $121;
            $124 = ((($3)) + 8|0);
            HEAP32[$124>>2] = -2147483568;
            $125 = ((($3)) + 4|0);
            HEAP32[$125>>2] = 65;
            dest=$121; src=106531; stop=dest+65|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
            $126 = ((($121)) + 65|0);
            HEAP8[$126>>0] = 0;
            __THREW__ = 0;
            $127 = (invoke_i(3459)|0);
            $128 = __THREW__; __THREW__ = 0;
            $129 = $128&1;
            do {
             if (!($129)) {
              __THREW__ = 0;
              invoke_viiii(3460,($127|0),2,($2|0),($3|0));
              $130 = __THREW__; __THREW__ = 0;
              $131 = $130&1;
              if ($131) {
               break;
              }
              $132 = ((($3)) + 11|0);
              $133 = HEAP8[$132>>0]|0;
              $134 = ($133<<24>>24)<(0);
              if ($134) {
               $135 = HEAP32[$3>>2]|0;
               __ZdlPv($135);
              }
              $136 = ((($2)) + 11|0);
              $137 = HEAP8[$136>>0]|0;
              $138 = ($137<<24>>24)<(0);
              if ($138) {
               $139 = HEAP32[$2>>2]|0;
               __ZdlPv($139);
              }
              $152 = (__Znwj(32)|0);
              HEAP32[$0>>2] = $152;
              $153 = ((($0)) + 8|0);
              HEAP32[$153>>2] = -2147483616;
              $154 = ((($0)) + 4|0);
              HEAP32[$154>>2] = 20;
              dest=$152; src=106597; stop=dest+20|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
              $155 = ((($152)) + 20|0);
              HEAP8[$155>>0] = 0;
              ;HEAP32[$1>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;
              __THREW__ = 0;
              $156 = (invoke_ii(3276,96)|0);
              $157 = __THREW__; __THREW__ = 0;
              $158 = $157&1;
              do {
               if ($158) {
                $175 = ___cxa_find_matching_catch_2()|0;
                $176 = tempRet0;
                $$0$i38 = $176;$$01$i37 = $175;
               } else {
                HEAP32[$1>>2] = $156;
                $159 = ((($1)) + 8|0);
                HEAP32[$159>>2] = -2147483552;
                $160 = ((($1)) + 4|0);
                HEAP32[$160>>2] = 88;
                dest=$156; src=106618; stop=dest+88|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                $161 = ((($156)) + 88|0);
                HEAP8[$161>>0] = 0;
                __THREW__ = 0;
                $162 = (invoke_i(3459)|0);
                $163 = __THREW__; __THREW__ = 0;
                $164 = $163&1;
                do {
                 if (!($164)) {
                  __THREW__ = 0;
                  invoke_viiii(3460,($162|0),2,($0|0),($1|0));
                  $165 = __THREW__; __THREW__ = 0;
                  $166 = $165&1;
                  if ($166) {
                   break;
                  }
                  $167 = ((($1)) + 11|0);
                  $168 = HEAP8[$167>>0]|0;
                  $169 = ($168<<24>>24)<(0);
                  if ($169) {
                   $170 = HEAP32[$1>>2]|0;
                   __ZdlPv($170);
                  }
                  $171 = ((($0)) + 11|0);
                  $172 = HEAP8[$171>>0]|0;
                  $173 = ($172<<24>>24)<(0);
                  if ($173) {
                   $174 = HEAP32[$0>>2]|0;
                   __ZdlPv($174);
                  }
                  $187 = (__Znwj(32)|0);
                  HEAP32[$10>>2] = $187;
                  $188 = ((($10)) + 8|0);
                  HEAP32[$188>>2] = -2147483616;
                  $189 = ((($10)) + 4|0);
                  HEAP32[$189>>2] = 22;
                  dest=$187; src=106707; stop=dest+22|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                  $190 = ((($187)) + 22|0);
                  HEAP8[$190>>0] = 0;
                  ;HEAP32[$11>>2]=0|0;HEAP32[$11+4>>2]=0|0;HEAP32[$11+8>>2]=0|0;
                  __THREW__ = 0;
                  $191 = (invoke_ii(3276,112)|0);
                  $192 = __THREW__; __THREW__ = 0;
                  $193 = $192&1;
                  do {
                   if ($193) {
                    $210 = ___cxa_find_matching_catch_2()|0;
                    $211 = tempRet0;
                    $$0$i = $211;$$01$i = $210;
                   } else {
                    HEAP32[$11>>2] = $191;
                    $194 = ((($11)) + 8|0);
                    HEAP32[$194>>2] = -2147483536;
                    $195 = ((($11)) + 4|0);
                    HEAP32[$195>>2] = 109;
                    dest=$191; src=106730; stop=dest+109|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                    $196 = ((($191)) + 109|0);
                    HEAP8[$196>>0] = 0;
                    __THREW__ = 0;
                    $197 = (invoke_i(3459)|0);
                    $198 = __THREW__; __THREW__ = 0;
                    $199 = $198&1;
                    do {
                     if (!($199)) {
                      __THREW__ = 0;
                      invoke_viiii(3460,($197|0),2,($10|0),($11|0));
                      $200 = __THREW__; __THREW__ = 0;
                      $201 = $200&1;
                      if ($201) {
                       break;
                      }
                      $202 = ((($11)) + 11|0);
                      $203 = HEAP8[$202>>0]|0;
                      $204 = ($203<<24>>24)<(0);
                      if ($204) {
                       $205 = HEAP32[$11>>2]|0;
                       __ZdlPv($205);
                      }
                      $206 = ((($10)) + 11|0);
                      $207 = HEAP8[$206>>0]|0;
                      $208 = ($207<<24>>24)<(0);
                      if (!($208)) {
                       STACKTOP = sp;return;
                      }
                      $209 = HEAP32[$10>>2]|0;
                      __ZdlPv($209);
                      STACKTOP = sp;return;
                     }
                    } while(0);
                    $212 = ___cxa_find_matching_catch_2()|0;
                    $213 = tempRet0;
                    $214 = ((($11)) + 11|0);
                    $215 = HEAP8[$214>>0]|0;
                    $216 = ($215<<24>>24)<(0);
                    if (!($216)) {
                     $$0$i = $213;$$01$i = $212;
                     break;
                    }
                    $217 = HEAP32[$11>>2]|0;
                    __ZdlPv($217);
                    $$0$i = $213;$$01$i = $212;
                   }
                  } while(0);
                  $218 = ((($10)) + 11|0);
                  $219 = HEAP8[$218>>0]|0;
                  $220 = ($219<<24>>24)<(0);
                  if (!($220)) {
                   ___resumeException($$01$i|0);
                   // unreachable;
                  }
                  $221 = HEAP32[$10>>2]|0;
                  __ZdlPv($221);
                  ___resumeException($$01$i|0);
                  // unreachable;
                 }
                } while(0);
                $177 = ___cxa_find_matching_catch_2()|0;
                $178 = tempRet0;
                $179 = ((($1)) + 11|0);
                $180 = HEAP8[$179>>0]|0;
                $181 = ($180<<24>>24)<(0);
                if (!($181)) {
                 $$0$i38 = $178;$$01$i37 = $177;
                 break;
                }
                $182 = HEAP32[$1>>2]|0;
                __ZdlPv($182);
                $$0$i38 = $178;$$01$i37 = $177;
               }
              } while(0);
              $183 = ((($0)) + 11|0);
              $184 = HEAP8[$183>>0]|0;
              $185 = ($184<<24>>24)<(0);
              if (!($185)) {
               ___resumeException($$01$i37|0);
               // unreachable;
              }
              $186 = HEAP32[$0>>2]|0;
              __ZdlPv($186);
              ___resumeException($$01$i37|0);
              // unreachable;
             }
            } while(0);
            $142 = ___cxa_find_matching_catch_2()|0;
            $143 = tempRet0;
            $144 = ((($3)) + 11|0);
            $145 = HEAP8[$144>>0]|0;
            $146 = ($145<<24>>24)<(0);
            if (!($146)) {
             $$0$i30 = $143;$$01$i29 = $142;
             break;
            }
            $147 = HEAP32[$3>>2]|0;
            __ZdlPv($147);
            $$0$i30 = $143;$$01$i29 = $142;
           }
          } while(0);
          $148 = ((($2)) + 11|0);
          $149 = HEAP8[$148>>0]|0;
          $150 = ($149<<24>>24)<(0);
          if (!($150)) {
           ___resumeException($$01$i29|0);
           // unreachable;
          }
          $151 = HEAP32[$2>>2]|0;
          __ZdlPv($151);
          ___resumeException($$01$i29|0);
          // unreachable;
         }
        }
        $107 = ___cxa_find_matching_catch_2()|0;
        $108 = tempRet0;
        $109 = ((($5)) + 11|0);
        $110 = HEAP8[$109>>0]|0;
        $111 = ($110<<24>>24)<(0);
        if ($111) {
         $112 = HEAP32[$5>>2]|0;
         __ZdlPv($112);
         $$0$i22 = $108;$$01$i21 = $107;
        } else {
         $$0$i22 = $108;$$01$i21 = $107;
        }
       }
       $113 = ((($4)) + 11|0);
       $114 = HEAP8[$113>>0]|0;
       $115 = ($114<<24>>24)<(0);
       if (!($115)) {
        ___resumeException($$01$i21|0);
        // unreachable;
       }
       $116 = HEAP32[$4>>2]|0;
       __ZdlPv($116);
       ___resumeException($$01$i21|0);
       // unreachable;
      }
     }
     $72 = ___cxa_find_matching_catch_2()|0;
     $73 = tempRet0;
     $74 = ((($7)) + 11|0);
     $75 = HEAP8[$74>>0]|0;
     $76 = ($75<<24>>24)<(0);
     if ($76) {
      $77 = HEAP32[$7>>2]|0;
      __ZdlPv($77);
      $$0$i14 = $73;$$01$i13 = $72;
     } else {
      $$0$i14 = $73;$$01$i13 = $72;
     }
    }
    $78 = ((($6)) + 11|0);
    $79 = HEAP8[$78>>0]|0;
    $80 = ($79<<24>>24)<(0);
    if (!($80)) {
     ___resumeException($$01$i13|0);
     // unreachable;
    }
    $81 = HEAP32[$6>>2]|0;
    __ZdlPv($81);
    ___resumeException($$01$i13|0);
    // unreachable;
   }
  }
  $37 = ___cxa_find_matching_catch_2()|0;
  $38 = tempRet0;
  $39 = ((($9)) + 11|0);
  $40 = HEAP8[$39>>0]|0;
  $41 = ($40<<24>>24)<(0);
  if ($41) {
   $42 = HEAP32[$9>>2]|0;
   __ZdlPv($42);
   $$0$i6 = $38;$$01$i5 = $37;
  } else {
   $$0$i6 = $38;$$01$i5 = $37;
  }
 }
 $43 = ((($8)) + 11|0);
 $44 = HEAP8[$43>>0]|0;
 $45 = ($44<<24>>24)<(0);
 if (!($45)) {
  ___resumeException($$01$i5|0);
  // unreachable;
 }
 $46 = HEAP32[$8>>2]|0;
 __ZdlPv($46);
 ___resumeException($$01$i5|0);
 // unreachable;
}
function __ZN9osgViewer10ViewerBaseC2Ev($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$cast = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0;
 var $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $2;
 $3 = ((($1)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $$cast = $2;
 $5 = ((($$cast)) + -12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($0) + ($6)|0);
 HEAP32[$7>>2] = $4;
 $8 = ((($0)) + 16|0);
 $9 = ((($0)) + 20|0);
 HEAP32[$9>>2] = 0;
 $10 = ((($0)) + 24|0);
 HEAP32[$10>>2] = 0;
 $11 = ((($0)) + 20|0);
 HEAP32[$8>>2] = $11;
 $12 = ((($0)) + 56|0);
 $13 = ((($0)) + 60|0);
 $14 = ((($0)) + 64|0);
 $15 = ((($0)) + 68|0);
 $16 = ((($0)) + 72|0);
 $17 = ((($0)) + 76|0);
 $18 = ((($0)) + 80|0);
 $19 = ((($0)) + 84|0);
 $20 = ((($0)) + 88|0);
 $21 = ((($0)) + 92|0);
 dest=$12; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 __THREW__ = 0;
 invoke_vi(3461,($0|0));
 $22 = __THREW__; __THREW__ = 0;
 $23 = $22&1;
 if (!($23)) {
  return;
 }
 $24 = ___cxa_find_matching_catch_2()|0;
 $25 = tempRet0;
 $26 = HEAP32[$21>>2]|0;
 $27 = ($26|0)==(0|0);
 if ($27) {
  label = 6;
 } else {
  $28 = ((($26)) + 8|0);
  $29 = HEAP32[$28>>2]|0;HEAP32[$28>>2] = (($29-1)|0);
  $30 = ($29|0)==(1);
  if ($30) {
   __THREW__ = 0;
   invoke_viii(3262,($26|0),1,1);
   $31 = __THREW__; __THREW__ = 0;
   $32 = $31&1;
   if (!($32)) {
    label = 6;
   }
  } else {
   label = 6;
  }
 }
 do {
  if ((label|0) == 6) {
   HEAP32[$21>>2] = 0;
   $33 = HEAP32[$20>>2]|0;
   $34 = ($33|0)==(0|0);
   if (!($34)) {
    $35 = HEAP32[$33>>2]|0;
    $36 = ((($35)) + -12|0);
    $37 = HEAP32[$36>>2]|0;
    $38 = (($33) + ($37)|0);
    $39 = ((($38)) + 8|0);
    $40 = HEAP32[$39>>2]|0;HEAP32[$39>>2] = (($40-1)|0);
    $41 = ($40|0)==(1);
    if ($41) {
     __THREW__ = 0;
     invoke_viii(3262,($38|0),1,1);
     $42 = __THREW__; __THREW__ = 0;
     $43 = $42&1;
     if ($43) {
      break;
     }
    }
   }
   HEAP32[$20>>2] = 0;
   $44 = HEAP32[$19>>2]|0;
   $45 = ($44|0)==(0|0);
   if (!($45)) {
    $46 = HEAP32[$44>>2]|0;
    $47 = ((($46)) + -12|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = (($44) + ($48)|0);
    $50 = ((($49)) + 8|0);
    $51 = HEAP32[$50>>2]|0;HEAP32[$50>>2] = (($51-1)|0);
    $52 = ($51|0)==(1);
    if ($52) {
     __THREW__ = 0;
     invoke_viii(3262,($49|0),1,1);
     $53 = __THREW__; __THREW__ = 0;
     $54 = $53&1;
     if ($54) {
      break;
     }
    }
   }
   HEAP32[$19>>2] = 0;
   $55 = HEAP32[$18>>2]|0;
   $56 = ($55|0)==(0|0);
   if (!($56)) {
    $57 = HEAP32[$55>>2]|0;
    $58 = ((($57)) + -12|0);
    $59 = HEAP32[$58>>2]|0;
    $60 = (($55) + ($59)|0);
    $61 = ((($60)) + 8|0);
    $62 = HEAP32[$61>>2]|0;HEAP32[$61>>2] = (($62-1)|0);
    $63 = ($62|0)==(1);
    if ($63) {
     __THREW__ = 0;
     invoke_viii(3262,($60|0),1,1);
     $64 = __THREW__; __THREW__ = 0;
     $65 = $64&1;
     if ($65) {
      break;
     }
    }
   }
   HEAP32[$18>>2] = 0;
   $66 = HEAP32[$17>>2]|0;
   $67 = ($66|0)==(0|0);
   if (!($67)) {
    $68 = HEAP32[$66>>2]|0;
    $69 = ((($68)) + -12|0);
    $70 = HEAP32[$69>>2]|0;
    $71 = (($66) + ($70)|0);
    $72 = ((($71)) + 8|0);
    $73 = HEAP32[$72>>2]|0;HEAP32[$72>>2] = (($73-1)|0);
    $74 = ($73|0)==(1);
    if ($74) {
     __THREW__ = 0;
     invoke_viii(3262,($71|0),1,1);
     $75 = __THREW__; __THREW__ = 0;
     $76 = $75&1;
     if ($76) {
      break;
     }
    }
   }
   HEAP32[$17>>2] = 0;
   $77 = HEAP32[$16>>2]|0;
   $78 = ($77|0)==(0|0);
   if (!($78)) {
    $79 = ((($77)) + 8|0);
    $80 = HEAP32[$79>>2]|0;HEAP32[$79>>2] = (($80-1)|0);
    $81 = ($80|0)==(1);
    if ($81) {
     __THREW__ = 0;
     invoke_viii(3262,($77|0),1,1);
     $82 = __THREW__; __THREW__ = 0;
     $83 = $82&1;
     if ($83) {
      break;
     }
    }
   }
   HEAP32[$16>>2] = 0;
   $84 = HEAP32[$15>>2]|0;
   $85 = ($84|0)==(0|0);
   if (!($85)) {
    $86 = HEAP32[$84>>2]|0;
    $87 = ((($86)) + -12|0);
    $88 = HEAP32[$87>>2]|0;
    $89 = (($84) + ($88)|0);
    $90 = ((($89)) + 8|0);
    $91 = HEAP32[$90>>2]|0;HEAP32[$90>>2] = (($91-1)|0);
    $92 = ($91|0)==(1);
    if ($92) {
     __THREW__ = 0;
     invoke_viii(3262,($89|0),1,1);
     $93 = __THREW__; __THREW__ = 0;
     $94 = $93&1;
     if ($94) {
      break;
     }
    }
   }
   HEAP32[$15>>2] = 0;
   $95 = HEAP32[$14>>2]|0;
   $96 = ($95|0)==(0|0);
   if (!($96)) {
    $97 = ((($95)) + 8|0);
    $98 = HEAP32[$97>>2]|0;HEAP32[$97>>2] = (($98-1)|0);
    $99 = ($98|0)==(1);
    if ($99) {
     __THREW__ = 0;
     invoke_viii(3262,($95|0),1,1);
     $100 = __THREW__; __THREW__ = 0;
     $101 = $100&1;
     if ($101) {
      break;
     }
    }
   }
   HEAP32[$14>>2] = 0;
   $102 = HEAP32[$13>>2]|0;
   $103 = ($102|0)==(0|0);
   if (!($103)) {
    $104 = HEAP32[$102>>2]|0;
    $105 = ((($104)) + -12|0);
    $106 = HEAP32[$105>>2]|0;
    $107 = (($102) + ($106)|0);
    $108 = ((($107)) + 8|0);
    $109 = HEAP32[$108>>2]|0;HEAP32[$108>>2] = (($109-1)|0);
    $110 = ($109|0)==(1);
    if ($110) {
     __THREW__ = 0;
     invoke_viii(3262,($107|0),1,1);
     $111 = __THREW__; __THREW__ = 0;
     $112 = $111&1;
     if ($112) {
      break;
     }
    }
   }
   HEAP32[$13>>2] = 0;
   $113 = HEAP32[$12>>2]|0;
   $114 = ($113|0)==(0|0);
   if ($114) {
    HEAP32[$12>>2] = 0;
    $124 = HEAP32[$11>>2]|0;
    __ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEE7destroyEPNS_11__tree_nodeIjPvEE($8,$124);
    ___resumeException($24|0);
    // unreachable;
   }
   $115 = HEAP32[$113>>2]|0;
   $116 = ((($115)) + -12|0);
   $117 = HEAP32[$116>>2]|0;
   $118 = (($113) + ($117)|0);
   $119 = ((($118)) + 8|0);
   $120 = HEAP32[$119>>2]|0;HEAP32[$119>>2] = (($120-1)|0);
   $121 = ($120|0)==(1);
   if (!($121)) {
    HEAP32[$12>>2] = 0;
    $124 = HEAP32[$11>>2]|0;
    __ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEE7destroyEPNS_11__tree_nodeIjPvEE($8,$124);
    ___resumeException($24|0);
    // unreachable;
   }
   __THREW__ = 0;
   invoke_viii(3262,($118|0),1,1);
   $122 = __THREW__; __THREW__ = 0;
   $123 = $122&1;
   if (!($123)) {
    HEAP32[$12>>2] = 0;
    $124 = HEAP32[$11>>2]|0;
    __ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEE7destroyEPNS_11__tree_nodeIjPvEE($8,$124);
    ___resumeException($24|0);
    // unreachable;
   }
  }
 } while(0);
 $125 = ___cxa_find_matching_catch_3(0|0)|0;
 $126 = tempRet0;
 ___clang_call_terminate($125);
 // unreachable;
}
function __ZN9osgViewer10ViewerBase14viewerBaseInitEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0.0, $23 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 4|0);
 HEAP8[$1>>0] = 1;
 $2 = ((($0)) + 5|0);
 HEAP8[$2>>0] = 0;
 $3 = ((($0)) + 8|0);
 HEAP32[$3>>2] = 65307;
 $4 = ((($0)) + 12|0);
 HEAP8[$4>>0] = 1;
 $5 = ((($0)) + 13|0);
 HEAP8[$5>>0] = 1;
 $6 = ((($0)) + 28|0);
 HEAP32[$6>>2] = 4;
 $7 = ((($0)) + 32|0);
 HEAP8[$7>>0] = 0;
 $8 = ((($0)) + 48|0);
 HEAP32[$8>>2] = 1;
 $9 = ((($0)) + 52|0);
 HEAP32[$9>>2] = 0;
 $10 = ((($0)) + 33|0);
 HEAP8[$10>>0] = 1;
 $11 = ((($0)) + 34|0);
 HEAP8[$11>>0] = 0;
 $12 = ((($0)) + 36|0);
 HEAP32[$12>>2] = 1;
 $13 = ((($0)) + 40|0);
 HEAPF64[$13>>3] = 0.0;
 $14 = (_getenv((106597|0))|0);
 $15 = ($14|0)==(0|0);
 do {
  if (!($15)) {
   $16 = (_strcmp($14,106840)|0);
   $17 = ($16|0)==(0);
   if ($17) {
    HEAP32[$12>>2] = 0;
    break;
   }
   $18 = (_strcmp($14,106850)|0);
   $19 = ($18|0)==(0);
   if ($19) {
    HEAP32[$12>>2] = 1;
   }
  }
 } while(0);
 $20 = (_getenv((106707|0))|0);
 $21 = ($20|0)==(0|0);
 if ($21) {
  $23 = ((($0)) + 14|0);
  HEAP8[$23>>0] = 1;
  return;
 }
 $22 = (+__ZN3osg13asciiToDoubleEPKc($20));
 HEAPF64[$13>>3] = $22;
 $23 = ((($0)) + 14|0);
 HEAP8[$23>>0] = 1;
 return;
}
function __ZN9osgViewer10ViewerBaseC2ERKS0_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$cast = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0;
 var $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $3 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $3;
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $$cast = $3;
 $6 = ((($$cast)) + -12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($0) + ($7)|0);
 HEAP32[$8>>2] = $5;
 $9 = ((($0)) + 16|0);
 $10 = ((($0)) + 20|0);
 HEAP32[$10>>2] = 0;
 $11 = ((($0)) + 24|0);
 HEAP32[$11>>2] = 0;
 $12 = ((($0)) + 20|0);
 HEAP32[$9>>2] = $12;
 $13 = ((($0)) + 56|0);
 $14 = ((($0)) + 60|0);
 $15 = ((($0)) + 64|0);
 $16 = ((($0)) + 68|0);
 $17 = ((($0)) + 72|0);
 $18 = ((($0)) + 76|0);
 $19 = ((($0)) + 80|0);
 $20 = ((($0)) + 84|0);
 $21 = ((($0)) + 88|0);
 $22 = ((($0)) + 92|0);
 dest=$13; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 __THREW__ = 0;
 invoke_vi(3461,($0|0));
 $23 = __THREW__; __THREW__ = 0;
 $24 = $23&1;
 if (!($24)) {
  return;
 }
 $25 = ___cxa_find_matching_catch_2()|0;
 $26 = tempRet0;
 $27 = HEAP32[$22>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  label = 6;
 } else {
  $29 = ((($27)) + 8|0);
  $30 = HEAP32[$29>>2]|0;HEAP32[$29>>2] = (($30-1)|0);
  $31 = ($30|0)==(1);
  if ($31) {
   __THREW__ = 0;
   invoke_viii(3262,($27|0),1,1);
   $32 = __THREW__; __THREW__ = 0;
   $33 = $32&1;
   if (!($33)) {
    label = 6;
   }
  } else {
   label = 6;
  }
 }
 do {
  if ((label|0) == 6) {
   HEAP32[$22>>2] = 0;
   $34 = HEAP32[$21>>2]|0;
   $35 = ($34|0)==(0|0);
   if (!($35)) {
    $36 = HEAP32[$34>>2]|0;
    $37 = ((($36)) + -12|0);
    $38 = HEAP32[$37>>2]|0;
    $39 = (($34) + ($38)|0);
    $40 = ((($39)) + 8|0);
    $41 = HEAP32[$40>>2]|0;HEAP32[$40>>2] = (($41-1)|0);
    $42 = ($41|0)==(1);
    if ($42) {
     __THREW__ = 0;
     invoke_viii(3262,($39|0),1,1);
     $43 = __THREW__; __THREW__ = 0;
     $44 = $43&1;
     if ($44) {
      break;
     }
    }
   }
   HEAP32[$21>>2] = 0;
   $45 = HEAP32[$20>>2]|0;
   $46 = ($45|0)==(0|0);
   if (!($46)) {
    $47 = HEAP32[$45>>2]|0;
    $48 = ((($47)) + -12|0);
    $49 = HEAP32[$48>>2]|0;
    $50 = (($45) + ($49)|0);
    $51 = ((($50)) + 8|0);
    $52 = HEAP32[$51>>2]|0;HEAP32[$51>>2] = (($52-1)|0);
    $53 = ($52|0)==(1);
    if ($53) {
     __THREW__ = 0;
     invoke_viii(3262,($50|0),1,1);
     $54 = __THREW__; __THREW__ = 0;
     $55 = $54&1;
     if ($55) {
      break;
     }
    }
   }
   HEAP32[$20>>2] = 0;
   $56 = HEAP32[$19>>2]|0;
   $57 = ($56|0)==(0|0);
   if (!($57)) {
    $58 = HEAP32[$56>>2]|0;
    $59 = ((($58)) + -12|0);
    $60 = HEAP32[$59>>2]|0;
    $61 = (($56) + ($60)|0);
    $62 = ((($61)) + 8|0);
    $63 = HEAP32[$62>>2]|0;HEAP32[$62>>2] = (($63-1)|0);
    $64 = ($63|0)==(1);
    if ($64) {
     __THREW__ = 0;
     invoke_viii(3262,($61|0),1,1);
     $65 = __THREW__; __THREW__ = 0;
     $66 = $65&1;
     if ($66) {
      break;
     }
    }
   }
   HEAP32[$19>>2] = 0;
   $67 = HEAP32[$18>>2]|0;
   $68 = ($67|0)==(0|0);
   if (!($68)) {
    $69 = HEAP32[$67>>2]|0;
    $70 = ((($69)) + -12|0);
    $71 = HEAP32[$70>>2]|0;
    $72 = (($67) + ($71)|0);
    $73 = ((($72)) + 8|0);
    $74 = HEAP32[$73>>2]|0;HEAP32[$73>>2] = (($74-1)|0);
    $75 = ($74|0)==(1);
    if ($75) {
     __THREW__ = 0;
     invoke_viii(3262,($72|0),1,1);
     $76 = __THREW__; __THREW__ = 0;
     $77 = $76&1;
     if ($77) {
      break;
     }
    }
   }
   HEAP32[$18>>2] = 0;
   $78 = HEAP32[$17>>2]|0;
   $79 = ($78|0)==(0|0);
   if (!($79)) {
    $80 = ((($78)) + 8|0);
    $81 = HEAP32[$80>>2]|0;HEAP32[$80>>2] = (($81-1)|0);
    $82 = ($81|0)==(1);
    if ($82) {
     __THREW__ = 0;
     invoke_viii(3262,($78|0),1,1);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if ($84) {
      break;
     }
    }
   }
   HEAP32[$17>>2] = 0;
   $85 = HEAP32[$16>>2]|0;
   $86 = ($85|0)==(0|0);
   if (!($86)) {
    $87 = HEAP32[$85>>2]|0;
    $88 = ((($87)) + -12|0);
    $89 = HEAP32[$88>>2]|0;
    $90 = (($85) + ($89)|0);
    $91 = ((($90)) + 8|0);
    $92 = HEAP32[$91>>2]|0;HEAP32[$91>>2] = (($92-1)|0);
    $93 = ($92|0)==(1);
    if ($93) {
     __THREW__ = 0;
     invoke_viii(3262,($90|0),1,1);
     $94 = __THREW__; __THREW__ = 0;
     $95 = $94&1;
     if ($95) {
      break;
     }
    }
   }
   HEAP32[$16>>2] = 0;
   $96 = HEAP32[$15>>2]|0;
   $97 = ($96|0)==(0|0);
   if (!($97)) {
    $98 = ((($96)) + 8|0);
    $99 = HEAP32[$98>>2]|0;HEAP32[$98>>2] = (($99-1)|0);
    $100 = ($99|0)==(1);
    if ($100) {
     __THREW__ = 0;
     invoke_viii(3262,($96|0),1,1);
     $101 = __THREW__; __THREW__ = 0;
     $102 = $101&1;
     if ($102) {
      break;
     }
    }
   }
   HEAP32[$15>>2] = 0;
   $103 = HEAP32[$14>>2]|0;
   $104 = ($103|0)==(0|0);
   if (!($104)) {
    $105 = HEAP32[$103>>2]|0;
    $106 = ((($105)) + -12|0);
    $107 = HEAP32[$106>>2]|0;
    $108 = (($103) + ($107)|0);
    $109 = ((($108)) + 8|0);
    $110 = HEAP32[$109>>2]|0;HEAP32[$109>>2] = (($110-1)|0);
    $111 = ($110|0)==(1);
    if ($111) {
     __THREW__ = 0;
     invoke_viii(3262,($108|0),1,1);
     $112 = __THREW__; __THREW__ = 0;
     $113 = $112&1;
     if ($113) {
      break;
     }
    }
   }
   HEAP32[$14>>2] = 0;
   $114 = HEAP32[$13>>2]|0;
   $115 = ($114|0)==(0|0);
   if ($115) {
    HEAP32[$13>>2] = 0;
    $125 = HEAP32[$12>>2]|0;
    __ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEE7destroyEPNS_11__tree_nodeIjPvEE($9,$125);
    ___resumeException($25|0);
    // unreachable;
   }
   $116 = HEAP32[$114>>2]|0;
   $117 = ((($116)) + -12|0);
   $118 = HEAP32[$117>>2]|0;
   $119 = (($114) + ($118)|0);
   $120 = ((($119)) + 8|0);
   $121 = HEAP32[$120>>2]|0;HEAP32[$120>>2] = (($121-1)|0);
   $122 = ($121|0)==(1);
   if (!($122)) {
    HEAP32[$13>>2] = 0;
    $125 = HEAP32[$12>>2]|0;
    __ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEE7destroyEPNS_11__tree_nodeIjPvEE($9,$125);
    ___resumeException($25|0);
    // unreachable;
   }
   __THREW__ = 0;
   invoke_viii(3262,($119|0),1,1);
   $123 = __THREW__; __THREW__ = 0;
   $124 = $123&1;
   if (!($124)) {
    HEAP32[$13>>2] = 0;
    $125 = HEAP32[$12>>2]|0;
    __ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEE7destroyEPNS_11__tree_nodeIjPvEE($9,$125);
    ___resumeException($25|0);
    // unreachable;
   }
  }
 } while(0);
 $126 = ___cxa_find_matching_catch_3(0|0)|0;
 $127 = tempRet0;
 ___clang_call_terminate($126);
 // unreachable;
}
function __ZN9osgViewer10ViewerBase17checkWindowStatusERKNSt3__26vectorIPN3osg15GraphicsContextENS1_9allocatorIS5_EEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$1>>2]|0;
 $5 = ($3|0)==($4|0);
 if (!($5)) {
  return;
 }
 $6 = ((($0)) + 5|0);
 HEAP8[$6>>0] = 1;
 $7 = ((($0)) + 32|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = ($8<<24>>24)==(0);
 if ($9) {
  return;
 }
 $10 = HEAP32[$0>>2]|0;
 $11 = ((($10)) + 44|0);
 $12 = HEAP32[$11>>2]|0;
 FUNCTION_TABLE_vi[$12 & 8191]($0);
 return;
}
function __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = (($5|0) / 12)&-1;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(357913941);
 if ($8) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $9 = ((($0)) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) - ($4))|0;
 $12 = (($11|0) / 12)&-1;
 $13 = ($12>>>0)<(178956970);
 $14 = $12 << 1;
 $15 = ($14>>>0)<($7>>>0);
 $$sroa$speculated$i = $15 ? $7 : $14;
 $$sroa$speculated$$i = $13 ? $$sroa$speculated$i : 357913941;
 $16 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($16) {
   $26 = 0;
  } else {
   $17 = ($$sroa$speculated$$i>>>0)>(357913941);
   if (!($17)) {
    $23 = ($$sroa$speculated$$i*12)|0;
    $24 = (__Znwj($23)|0);
    $26 = $24;
    break;
   }
   $18 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($18|0),(204840|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if ($20) {
    $21 = ___cxa_find_matching_catch_2()|0;
    $22 = tempRet0;
    ___cxa_free_exception(($18|0));
    ___resumeException($21|0);
    // unreachable;
   } else {
    HEAP32[$18>>2] = (99824);
    ___cxa_throw(($18|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $25 = (($26) + (($6*12)|0)|0);
 $27 = (($26) + (($$sroa$speculated$$i*12)|0)|0);
 $28 = $27;
 ;HEAP32[$25>>2]=HEAP32[$1>>2]|0;HEAP32[$25+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$25+8>>2]=HEAP32[$1+8>>2]|0;
 $29 = ((($25)) + 12|0);
 $30 = $29;
 $31 = (($5|0) / -12)&-1;
 $32 = (($25) + (($31*12)|0)|0);
 $33 = $32;
 $34 = ($5|0)>(0);
 if ($34) {
  $35 = $4;
  _memcpy(($32|0),($35|0),($5|0))|0;
 }
 HEAP32[$0>>2] = $33;
 HEAP32[$2>>2] = $30;
 HEAP32[$9>>2] = $28;
 $36 = ($4|0)==(0);
 if ($36) {
  return;
 }
 $37 = $4;
 __ZdlPv($37);
 return;
}
function __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 3;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(536870911);
 if ($8) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $9 = ((($0)) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) - ($4))|0;
 $12 = $11 >> 3;
 $13 = ($12>>>0)<(268435455);
 $14 = $11 >> 2;
 $15 = ($14>>>0)<($7>>>0);
 $$sroa$speculated$i = $15 ? $7 : $14;
 $$sroa$speculated$$i = $13 ? $$sroa$speculated$i : 536870911;
 $16 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($16) {
   $26 = 0;
  } else {
   $17 = ($$sroa$speculated$$i>>>0)>(536870911);
   if (!($17)) {
    $23 = $$sroa$speculated$$i << 3;
    $24 = (__Znwj($23)|0);
    $26 = $24;
    break;
   }
   $18 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($18|0),(204840|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if ($20) {
    $21 = ___cxa_find_matching_catch_2()|0;
    $22 = tempRet0;
    ___cxa_free_exception(($18|0));
    ___resumeException($21|0);
    // unreachable;
   } else {
    HEAP32[$18>>2] = (99824);
    ___cxa_throw(($18|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $25 = (($26) + ($6<<3)|0);
 $27 = (($26) + ($$sroa$speculated$$i<<3)|0);
 $28 = $27;
 $29 = $1;
 $30 = $29;
 $31 = HEAP32[$30>>2]|0;
 $32 = (($29) + 4)|0;
 $33 = $32;
 $34 = HEAP32[$33>>2]|0;
 $35 = $25;
 $36 = $35;
 HEAP32[$36>>2] = $31;
 $37 = (($35) + 4)|0;
 $38 = $37;
 HEAP32[$38>>2] = $34;
 $39 = ((($25)) + 8|0);
 $40 = $39;
 $41 = (0 - ($6))|0;
 $42 = (($25) + ($41<<3)|0);
 $43 = $42;
 $44 = ($5|0)>(0);
 if ($44) {
  $45 = $4;
  _memcpy(($42|0),($45|0),($5|0))|0;
 }
 HEAP32[$0>>2] = $43;
 HEAP32[$2>>2] = $40;
 HEAP32[$9>>2] = $28;
 $46 = ($4|0)==(0);
 if ($46) {
  return;
 }
 $47 = $4;
 __ZdlPv($47);
 return;
}
function __ZNSt3__26vectorIN3osg5Vec4fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 4;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(268435455);
 if ($8) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $9 = ((($0)) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) - ($4))|0;
 $12 = $11 >> 4;
 $13 = ($12>>>0)<(134217727);
 $14 = $11 >> 3;
 $15 = ($14>>>0)<($7>>>0);
 $$sroa$speculated$i = $15 ? $7 : $14;
 $$sroa$speculated$$i = $13 ? $$sroa$speculated$i : 268435455;
 $16 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($16) {
   $26 = 0;
  } else {
   $17 = ($$sroa$speculated$$i>>>0)>(268435455);
   if (!($17)) {
    $23 = $$sroa$speculated$$i << 4;
    $24 = (__Znwj($23)|0);
    $26 = $24;
    break;
   }
   $18 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($18|0),(204840|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if ($20) {
    $21 = ___cxa_find_matching_catch_2()|0;
    $22 = tempRet0;
    ___cxa_free_exception(($18|0));
    ___resumeException($21|0);
    // unreachable;
   } else {
    HEAP32[$18>>2] = (99824);
    ___cxa_throw(($18|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $25 = (($26) + ($6<<4)|0);
 $27 = (($26) + ($$sroa$speculated$$i<<4)|0);
 $28 = $27;
 ;HEAP32[$25>>2]=HEAP32[$1>>2]|0;HEAP32[$25+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$25+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$25+12>>2]=HEAP32[$1+12>>2]|0;
 $29 = ((($25)) + 16|0);
 $30 = $29;
 $31 = (0 - ($6))|0;
 $32 = (($25) + ($31<<4)|0);
 $33 = $32;
 $34 = ($5|0)>(0);
 if ($34) {
  $35 = $4;
  _memcpy(($32|0),($35|0),($5|0))|0;
 }
 HEAP32[$0>>2] = $33;
 HEAP32[$2>>2] = $30;
 HEAP32[$9>>2] = $28;
 $36 = ($4|0)==(0);
 if ($36) {
  return;
 }
 $37 = $4;
 __ZdlPv($37);
 return;
}
function __ZNSt3__26vectorItNS_9allocatorItEEE21__push_back_slow_pathIKtEEvRT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 1;
 $7 = (($6) + 1)|0;
 $8 = ($5|0)<(-2);
 if ($8) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $9 = ((($0)) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) - ($4))|0;
 $12 = $11 >> 1;
 $13 = ($12>>>0)<(1073741823);
 $14 = ($11>>>0)<($7>>>0);
 $$sroa$speculated$i = $14 ? $7 : $11;
 $$sroa$speculated$$i = $13 ? $$sroa$speculated$i : 2147483647;
 $15 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($15) {
   $25 = 0;
  } else {
   $16 = ($$sroa$speculated$$i|0)<(0);
   if (!($16)) {
    $22 = $$sroa$speculated$$i << 1;
    $23 = (__Znwj($22)|0);
    $25 = $23;
    break;
   }
   $17 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($17|0),(204840|0));
   $18 = __THREW__; __THREW__ = 0;
   $19 = $18&1;
   if ($19) {
    $20 = ___cxa_find_matching_catch_2()|0;
    $21 = tempRet0;
    ___cxa_free_exception(($17|0));
    ___resumeException($20|0);
    // unreachable;
   } else {
    HEAP32[$17>>2] = (99824);
    ___cxa_throw(($17|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $24 = (($25) + ($6<<1)|0);
 $26 = (($25) + ($$sroa$speculated$$i<<1)|0);
 $27 = $26;
 $28 = HEAP16[$1>>1]|0;
 HEAP16[$24>>1] = $28;
 $29 = ((($24)) + 2|0);
 $30 = $29;
 $31 = (0 - ($6))|0;
 $32 = (($24) + ($31<<1)|0);
 $33 = $32;
 $34 = ($5|0)>(0);
 if ($34) {
  $35 = $4;
  _memcpy(($32|0),($35|0),($5|0))|0;
 }
 HEAP32[$0>>2] = $33;
 HEAP32[$2>>2] = $30;
 HEAP32[$9>>2] = $27;
 $36 = ($4|0)==(0);
 if ($36) {
  return;
 }
 $37 = $4;
 __ZdlPv($37);
 return;
}
function __ZN3osg13TemplateArrayINS_5Vec4fELNS_5Array4TypeE29ELi4ELi5126EED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i = 0, $scevgep5$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 72|0);
 HEAP32[$1>>2] = (38520);
 $2 = ((($0)) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  __ZN3osg10BufferDataD2Ev($0);
  return;
 }
 $5 = ((($0)) + 80|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==($3|0);
 if (!($7)) {
  $scevgep$i$i$i$i = ((($6)) + -16|0);
  $8 = $scevgep$i$i$i$i;
  $9 = $3;
  $10 = (($8) - ($9))|0;
  $11 = $10 >>> 4;
  $12 = $11 ^ -1;
  $scevgep5$i$i$i$i = (($6) + ($12<<4)|0);
  HEAP32[$5>>2] = $scevgep5$i$i$i$i;
 }
 __ZdlPv($3);
 __ZN3osg10BufferDataD2Ev($0);
 return;
}
function __ZN3osg13TemplateArrayINS_5Vec4fELNS_5Array4TypeE29ELi4ELi5126EED0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 72|0);
 HEAP32[$1>>2] = (38520);
 $2 = ((($0)) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = ((($0)) + 80|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==($3|0);
  if (!($7)) {
   $scevgep$i$i$i$i$i = ((($6)) + -16|0);
   $8 = $scevgep$i$i$i$i$i;
   $9 = $3;
   $10 = (($8) - ($9))|0;
   $11 = $10 >>> 4;
   $12 = $11 ^ -1;
   $scevgep5$i$i$i$i$i = (($6) + ($12<<4)|0);
   HEAP32[$5>>2] = $scevgep5$i$i$i$i$i;
  }
  __ZdlPv($3);
 }
 __THREW__ = 0;
 invoke_vi(1265,($0|0));
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 if ($14) {
  $15 = ___cxa_find_matching_catch_2()|0;
  $16 = tempRet0;
  __ZdlPv($0);
  ___resumeException($15|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK3osg13TemplateArrayINS_5Vec4fELNS_5Array4TypeE29ELi4ELi5126EE9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(88)|0);
 __THREW__ = 0;
 invoke_vii(3435,($1|0),1);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $17 = ___cxa_find_matching_catch_2()|0;
  $18 = tempRet0;
  __ZdlPv($1);
  ___resumeException($17|0);
  // unreachable;
 } else {
  $4 = ((($1)) + 12|0);
  ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;
  $5 = ((($1)) + 24|0);
  HEAP32[$5>>2] = 2;
  $6 = ((($1)) + 28|0);
  ;HEAP32[$6>>2]=0|0;HEAP32[$6+4>>2]=0|0;HEAP32[$6+8>>2]=0|0;HEAP32[$6+12>>2]=0|0;HEAP32[$6+16>>2]=0|0;HEAP32[$6+20>>2]=0|0;
  $7 = ((($1)) + 52|0);
  HEAP32[$7>>2] = 29;
  $8 = ((($1)) + 56|0);
  HEAP32[$8>>2] = 4;
  $9 = ((($1)) + 60|0);
  HEAP32[$9>>2] = 5126;
  $10 = ((($1)) + 64|0);
  HEAP32[$10>>2] = -1;
  $11 = ((($1)) + 68|0);
  HEAP8[$11>>0] = 0;
  $12 = ((($1)) + 69|0);
  HEAP8[$12>>0] = 0;
  $13 = ((($1)) + 72|0);
  $14 = ((($1)) + 76|0);
  HEAP32[$14>>2] = 0;
  $15 = ((($1)) + 80|0);
  HEAP32[$15>>2] = 0;
  $16 = ((($1)) + 84|0);
  HEAP32[$16>>2] = 0;
  HEAP32[$1>>2] = (38280);
  HEAP32[$13>>2] = (38504);
  return ($1|0);
 }
 return (0)|0;
}
function __ZNK3osg13TemplateArrayINS_5Vec4fELNS_5Array4TypeE29ELi4ELi5126EE5cloneERKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(88)|0);
 __THREW__ = 0;
 invoke_viii(3462,($2|0),($0|0),($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch_2()|0;
  $6 = tempRet0;
  __ZdlPv($2);
  ___resumeException($5|0);
  // unreachable;
 } else {
  return ($2|0);
 }
 return (0)|0;
}
function __ZNK3osg5Array12isSameKindAsEPKNS_6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,23016,0)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK3osg5Array11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175113|0);
}
function __ZNK3osg13TemplateArrayINS_5Vec4fELNS_5Array4TypeE29ELi4ELi5126EE14getDataPointerEv($0) {
 $0 = $0|0;
 var $$ = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 76|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 80|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2|0)==($4|0);
 $$ = $5 ? 0 : $2;
 return ($$|0);
}
function __ZNK3osg13TemplateArrayINS_5Vec4fELNS_5Array4TypeE29ELi4ELi5126EE16getTotalDataSizeEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 76|0);
 $2 = ((($0)) + 80|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$1>>2]|0;
 $5 = (($3) - ($4))|0;
 return ($5|0);
}
function __ZN3osg5Array7asArrayEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ($0|0);
}
function __ZNK3osg5Array7asArrayEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ($0|0);
}
function __ZN3osg10BufferData14asPrimitiveSetEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZNK3osg10BufferData14asPrimitiveSetEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZN3osg10BufferData7asImageEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZNK3osg10BufferData7asImageEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZN3osg13TemplateArrayINS_5Vec4fELNS_5Array4TypeE29ELi4ELi5126EE6acceptERNS_12ArrayVisitorE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 124|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 8191]($1,$0);
 return;
}
function __ZNK3osg13TemplateArrayINS_5Vec4fELNS_5Array4TypeE29ELi4ELi5126EE6acceptERNS_17ConstArrayVisitorE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 124|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 8191]($1,$0);
 return;
}
function __ZN3osg13TemplateArrayINS_5Vec4fELNS_5Array4TypeE29ELi4ELi5126EE6acceptEjRNS_12ValueVisitorE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + 120|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($0)) + 76|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($1<<4)|0);
 FUNCTION_TABLE_vii[$5 & 8191]($2,$8);
 return;
}
function __ZNK3osg13TemplateArrayINS_5Vec4fELNS_5Array4TypeE29ELi4ELi5126EE6acceptEjRNS_17ConstValueVisitorE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + 120|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($0)) + 76|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($1<<4)|0);
 FUNCTION_TABLE_vii[$5 & 8191]($2,$8);
 return;
}
function __ZNK3osg13TemplateArrayINS_5Vec4fELNS_5Array4TypeE29ELi4ELi5126EE7compareEjj($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0.0, $13 = 0, $14 = 0.0, $15 = 0, $16 = 0, $17 = 0, $18 = 0.0, $19 = 0, $20 = 0.0, $21 = 0, $22 = 0, $23 = 0, $24 = 0.0, $25 = 0, $26 = 0.0, $27 = 0, $28 = 0;
 var $29 = 0.0, $3 = 0, $30 = 0, $31 = 0.0, $32 = 0, $33 = 0, $34 = 0, $35 = 0.0, $36 = 0, $37 = 0.0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0.0, $42 = 0, $43 = 0.0, $44 = 0, $5 = 0, $6 = 0.0;
 var $7 = 0, $8 = 0.0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 76|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + ($1<<4)|0);
 $6 = +HEAPF32[$5>>2];
 $7 = (($4) + ($2<<4)|0);
 $8 = +HEAPF32[$7>>2];
 $9 = $6 < $8;
 if ($9) {
  $$0 = -1;
  return ($$0|0);
 }
 $10 = $6 > $8;
 if (!($10)) {
  $11 = (((($4) + ($1<<4)|0)) + 4|0);
  $12 = +HEAPF32[$11>>2];
  $13 = (((($4) + ($2<<4)|0)) + 4|0);
  $14 = +HEAPF32[$13>>2];
  $15 = $12 < $14;
  if ($15) {
   $$0 = -1;
   return ($$0|0);
  }
  $16 = $12 > $14;
  if (!($16)) {
   $17 = (((($4) + ($1<<4)|0)) + 8|0);
   $18 = +HEAPF32[$17>>2];
   $19 = (((($4) + ($2<<4)|0)) + 8|0);
   $20 = +HEAPF32[$19>>2];
   $21 = $18 < $20;
   if ($21) {
    $$0 = -1;
    return ($$0|0);
   }
   $22 = $18 > $20;
   if (!($22)) {
    $23 = (((($4) + ($1<<4)|0)) + 12|0);
    $24 = +HEAPF32[$23>>2];
    $25 = (((($4) + ($2<<4)|0)) + 12|0);
    $26 = +HEAPF32[$25>>2];
    $27 = $24 < $26;
    if ($27) {
     $$0 = -1;
     return ($$0|0);
    }
   }
  }
  $28 = (((($4) + ($2<<4)|0)) + 4|0);
  $29 = +HEAPF32[$28>>2];
  $30 = (((($4) + ($1<<4)|0)) + 4|0);
  $31 = +HEAPF32[$30>>2];
  $32 = $29 < $31;
  if (!($32)) {
   $33 = $29 > $31;
   if ($33) {
    $$0 = 0;
    return ($$0|0);
   }
   $34 = (((($4) + ($2<<4)|0)) + 8|0);
   $35 = +HEAPF32[$34>>2];
   $36 = (((($4) + ($1<<4)|0)) + 8|0);
   $37 = +HEAPF32[$36>>2];
   $38 = $35 < $37;
   if (!($38)) {
    $39 = $35 > $37;
    if ($39) {
     $$0 = 0;
     return ($$0|0);
    }
    $40 = (((($4) + ($2<<4)|0)) + 12|0);
    $41 = +HEAPF32[$40>>2];
    $42 = (((($4) + ($1<<4)|0)) + 12|0);
    $43 = +HEAPF32[$42>>2];
    $44 = $41 < $43;
    if (!($44)) {
     $$0 = 0;
     return ($$0|0);
    }
   }
  }
 }
 $$0 = 1;
 return ($$0|0);
}
function __ZNK3osg13TemplateArrayINS_5Vec4fELNS_5Array4TypeE29ELi4ELi5126EE14getElementSizeEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 16;
}
function __ZNK3osg13TemplateArrayINS_5Vec4fELNS_5Array4TypeE29ELi4ELi5126EE14getDataPointerEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$ = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 80|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 $7 = (($3) + ($1<<4)|0);
 $$ = $6 ? 0 : $7;
 return ($$|0);
}
function __ZNK3osg13TemplateArrayINS_5Vec4fELNS_5Array4TypeE29ELi4ELi5126EE14getNumElementsEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 76|0);
 $2 = ((($0)) + 80|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$1>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 4;
 return ($6|0);
}
function __ZN3osg13TemplateArrayINS_5Vec4fELNS_5Array4TypeE29ELi4ELi5126EE12reserveArrayEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 76|0);
 __ZNSt3__26vectorIN3osg5Vec4fENS_9allocatorIS2_EEE7reserveEj($2,$1);
 return;
}
function __ZN3osg13TemplateArrayINS_5Vec4fELNS_5Array4TypeE29ELi4ELi5126EE11resizeArrayEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i = 0;
 var $scevgep5$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 ;HEAP32[$2>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;HEAP32[$2+12>>2]=0|0;
 $3 = ((($0)) + 76|0);
 $4 = ((($0)) + 80|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$3>>2]|0;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 4;
 $9 = ($8>>>0)<($1>>>0);
 $10 = $6;
 $11 = $5;
 if ($9) {
  $12 = (($1) - ($8))|0;
  __ZNSt3__26vectorIN3osg5Vec4fENS_9allocatorIS2_EEE8__appendEjRKS2_($3,$12,$2);
  STACKTOP = sp;return;
 }
 $13 = ($8>>>0)>($1>>>0);
 if (!($13)) {
  STACKTOP = sp;return;
 }
 $14 = (($10) + ($1<<4)|0);
 $15 = ($11|0)==($14|0);
 if ($15) {
  STACKTOP = sp;return;
 }
 $scevgep$i$i$i$i = ((($11)) + -16|0);
 $16 = $scevgep$i$i$i$i;
 $17 = $14;
 $18 = (($16) - ($17))|0;
 $19 = $18 >>> 4;
 $20 = $19 ^ -1;
 $scevgep5$i$i$i$i = (($11) + ($20<<4)|0);
 HEAP32[$4>>2] = $scevgep5$i$i$i$i;
 STACKTOP = sp;return;
}
function __ZN3osg13TemplateArrayINS_5Vec4fELNS_5Array4TypeE29ELi4ELi5126EE4trimEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $scevgep$i$i$i$i = 0, $scevgep5$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 HEAP32[$1>>2] = (38520);
 $2 = ((($1)) + 4|0);
 $3 = ((($0)) + 76|0);
 __ZNSt3__26vectorIN3osg5Vec4fENS_9allocatorIS2_EEEC2ERKS5_($2,$3);
 $4 = HEAP32[$2>>2]|0;
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$2>>2] = $5;
 HEAP32[$3>>2] = $4;
 $6 = ((($1)) + 8|0);
 $7 = ((($0)) + 80|0);
 $8 = HEAP32[$6>>2]|0;
 $9 = HEAP32[$7>>2]|0;
 HEAP32[$6>>2] = $9;
 HEAP32[$7>>2] = $8;
 $10 = ((($1)) + 12|0);
 $11 = ((($0)) + 84|0);
 $12 = HEAP32[$10>>2]|0;
 $13 = HEAP32[$11>>2]|0;
 HEAP32[$10>>2] = $13;
 HEAP32[$11>>2] = $12;
 HEAP32[$1>>2] = (38520);
 $14 = ($5|0)==(0);
 $15 = $5;
 $16 = $9;
 if ($14) {
  STACKTOP = sp;return;
 }
 $17 = $5;
 $18 = ($16|0)==($17|0);
 if (!($18)) {
  $scevgep$i$i$i$i = ((($16)) + -16|0);
  $19 = $scevgep$i$i$i$i;
  $20 = (($19) - ($5))|0;
  $21 = $20 >>> 4;
  $22 = $21 ^ -1;
  $scevgep5$i$i$i$i = (($16) + ($22<<4)|0);
  HEAP32[$6>>2] = $scevgep5$i$i$i$i;
 }
 __ZdlPv($15);
 STACKTOP = sp;return;
}
function __ZThn72_N3osg13TemplateArrayINS_5Vec4fELNS_5Array4TypeE29ELi4ELi5126EED1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -72|0);
 $2 = ((($1)) + 72|0);
 HEAP32[$2>>2] = (38520);
 $3 = ((($1)) + 76|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  __ZN3osg10BufferDataD2Ev($1);
  return;
 }
 $6 = ((($1)) + 80|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==($4|0);
 if (!($8)) {
  $scevgep$i$i$i$i$i = ((($7)) + -16|0);
  $9 = $scevgep$i$i$i$i$i;
  $10 = $4;
  $11 = (($9) - ($10))|0;
  $12 = $11 >>> 4;
  $13 = $12 ^ -1;
  $scevgep5$i$i$i$i$i = (($7) + ($13<<4)|0);
  HEAP32[$6>>2] = $scevgep5$i$i$i$i$i;
 }
 __ZdlPv($4);
 __ZN3osg10BufferDataD2Ev($1);
 return;
}
function __ZThn72_N3osg13TemplateArrayINS_5Vec4fELNS_5Array4TypeE29ELi4ELi5126EED0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -72|0);
 $2 = ((($1)) + 72|0);
 HEAP32[$2>>2] = (38520);
 $3 = ((($1)) + 76|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if (!($5)) {
  $6 = ((($1)) + 80|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)==($4|0);
  if (!($8)) {
   $scevgep$i$i$i$i$i$i = ((($7)) + -16|0);
   $9 = $scevgep$i$i$i$i$i$i;
   $10 = $4;
   $11 = (($9) - ($10))|0;
   $12 = $11 >>> 4;
   $13 = $12 ^ -1;
   $scevgep5$i$i$i$i$i$i = (($7) + ($13<<4)|0);
   HEAP32[$6>>2] = $scevgep5$i$i$i$i$i$i;
  }
  __ZdlPv($4);
 }
 __THREW__ = 0;
 invoke_vi(1265,($1|0));
 $14 = __THREW__; __THREW__ = 0;
 $15 = $14&1;
 if ($15) {
  $16 = ___cxa_find_matching_catch_2()|0;
  $17 = tempRet0;
  __ZdlPv($1);
  ___resumeException($16|0);
  // unreachable;
 } else {
  __ZdlPv($1);
  return;
 }
}
function __ZN3osg11MixinVectorINS_5Vec4fEED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i = 0, $scevgep5$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (38520);
 $1 = ((($0)) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  return;
 }
 $4 = ((($0)) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==($2|0);
 if (!($6)) {
  $scevgep$i$i$i = ((($5)) + -16|0);
  $7 = $scevgep$i$i$i;
  $8 = $2;
  $9 = (($7) - ($8))|0;
  $10 = $9 >>> 4;
  $11 = $10 ^ -1;
  $scevgep5$i$i$i = (($5) + ($11<<4)|0);
  HEAP32[$4>>2] = $scevgep5$i$i$i;
 }
 __ZdlPv($2);
 return;
}
function __ZN3osg11MixinVectorINS_5Vec4fEED0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i = 0, $scevgep5$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (38520);
 $1 = ((($0)) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  __ZdlPv($0);
  return;
 }
 $4 = ((($0)) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==($2|0);
 if (!($6)) {
  $scevgep$i$i$i$i = ((($5)) + -16|0);
  $7 = $scevgep$i$i$i$i;
  $8 = $2;
  $9 = (($7) - ($8))|0;
  $10 = $9 >>> 4;
  $11 = $10 ^ -1;
  $scevgep5$i$i$i$i = (($5) + ($11<<4)|0);
  HEAP32[$4>>2] = $scevgep5$i$i$i$i;
 }
 __ZdlPv($2);
 __ZdlPv($0);
 return;
}
function __ZNSt3__26vectorIN3osg5Vec4fENS_9allocatorIS2_EEEC2ERKS5_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i = 0, $scevgep5$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = 0;
 $2 = ((($0)) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = ((($0)) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$1>>2]|0;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 4;
 $9 = ($8|0)==(0);
 if ($9) {
  return;
 }
 $10 = ($8>>>0)>(268435455);
 if ($10) {
  __THREW__ = 0;
  invoke_vi(3307,($0|0));
  $11 = __THREW__; __THREW__ = 0;
 } else {
  __THREW__ = 0;
  $12 = (invoke_ii(3276,($7|0))|0);
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if (!($14)) {
   HEAP32[$2>>2] = $12;
   HEAP32[$0>>2] = $12;
   $15 = (($12) + ($8<<4)|0);
   $16 = ((($0)) + 8|0);
   HEAP32[$16>>2] = $15;
   $17 = HEAP32[$1>>2]|0;
   $18 = HEAP32[$4>>2]|0;
   $19 = $17;
   $20 = (($18) - ($19))|0;
   $21 = ($20|0)>(0);
   if (!($21)) {
    return;
   }
   $22 = $20 >>> 4;
   _memcpy(($12|0),($17|0),($20|0))|0;
   $23 = (($12) + ($22<<4)|0);
   HEAP32[$2>>2] = $23;
   return;
  }
 }
 $24 = ___cxa_find_matching_catch_2()|0;
 $25 = tempRet0;
 $26 = HEAP32[$0>>2]|0;
 $27 = ($26|0)==(0|0);
 if ($27) {
  ___resumeException($24|0);
  // unreachable;
 }
 $28 = HEAP32[$2>>2]|0;
 $29 = ($28|0)==($26|0);
 if (!($29)) {
  $scevgep$i$i$i = ((($28)) + -16|0);
  $30 = $scevgep$i$i$i;
  $31 = $26;
  $32 = (($30) - ($31))|0;
  $33 = $32 >>> 4;
  $34 = $33 ^ -1;
  $scevgep5$i$i$i = (($28) + ($34<<4)|0);
  HEAP32[$2>>2] = $scevgep5$i$i$i;
 }
 __ZdlPv($26);
 ___resumeException($24|0);
 // unreachable;
}
function __ZNSt3__26vectorIN3osg5Vec4fENS_9allocatorIS2_EEE8__appendEjRKS2_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$i = 0, $$0$i18 = 0, $$in = 0, $$sroa$15$0 = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) - ($6))|0;
 $8 = $7 >> 4;
 $9 = ($8>>>0)<($1>>>0);
 if (!($9)) {
  $10 = $6;
  $$0$i = $1;$11 = $10;
  while(1) {
   ;HEAP32[$11>>2]=HEAP32[$2>>2]|0;HEAP32[$11+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$11+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$11+12>>2]=HEAP32[$2+12>>2]|0;
   $12 = HEAP32[$5>>2]|0;
   $13 = ((($12)) + 16|0);
   HEAP32[$5>>2] = $13;
   $14 = (($$0$i) + -1)|0;
   $15 = ($14|0)==(0);
   if ($15) {
    break;
   } else {
    $$0$i = $14;$11 = $13;
   }
  }
  return;
 }
 $16 = HEAP32[$0>>2]|0;
 $17 = (($6) - ($16))|0;
 $18 = $17 >> 4;
 $19 = (($18) + ($1))|0;
 $20 = ($19>>>0)>(268435455);
 if ($20) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $21 = (($4) - ($16))|0;
 $22 = $21 >> 4;
 $23 = ($22>>>0)<(134217727);
 $24 = $21 >> 3;
 $25 = ($24>>>0)<($19>>>0);
 $$sroa$speculated$i = $25 ? $19 : $24;
 $$sroa$speculated$$i = $23 ? $$sroa$speculated$i : 268435455;
 $26 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($26) {
   $36 = 0;
  } else {
   $27 = ($$sroa$speculated$$i>>>0)>(268435455);
   if (!($27)) {
    $33 = $$sroa$speculated$$i << 4;
    $34 = (__Znwj($33)|0);
    $36 = $34;
    break;
   }
   $28 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($28|0),(204840|0));
   $29 = __THREW__; __THREW__ = 0;
   $30 = $29&1;
   if ($30) {
    $31 = ___cxa_find_matching_catch_2()|0;
    $32 = tempRet0;
    ___cxa_free_exception(($28|0));
    ___resumeException($31|0);
    // unreachable;
   } else {
    HEAP32[$28>>2] = (99824);
    ___cxa_throw(($28|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $35 = (($36) + ($18<<4)|0);
 $37 = $35;
 $38 = (($36) + ($$sroa$speculated$$i<<4)|0);
 $$0$i18 = $1;$$in = $35;$$sroa$15$0 = $37;
 while(1) {
  ;HEAP32[$$in>>2]=HEAP32[$2>>2]|0;HEAP32[$$in+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$$in+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$$in+12>>2]=HEAP32[$2+12>>2]|0;
  $39 = $$sroa$15$0;
  $40 = ((($39)) + 16|0);
  $41 = $40;
  $42 = (($$0$i18) + -1)|0;
  $43 = ($42|0)==(0);
  if ($43) {
   break;
  } else {
   $$0$i18 = $42;$$in = $40;$$sroa$15$0 = $41;
  }
 }
 $44 = $38;
 $45 = HEAP32[$0>>2]|0;
 $46 = HEAP32[$5>>2]|0;
 $47 = $45;
 $48 = (($46) - ($47))|0;
 $49 = $48 >> 4;
 $50 = (0 - ($49))|0;
 $51 = (($35) + ($50<<4)|0);
 $52 = $51;
 $53 = ($48|0)>(0);
 if ($53) {
  _memcpy(($51|0),($45|0),($48|0))|0;
 }
 HEAP32[$0>>2] = $52;
 HEAP32[$5>>2] = $41;
 HEAP32[$3>>2] = $44;
 $54 = ($45|0)==(0|0);
 if ($54) {
  return;
 }
 __ZdlPv($45);
 return;
}
function __ZNSt3__26vectorIN3osg5Vec4fENS_9allocatorIS2_EEE7reserveEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 4;
 $7 = ($6>>>0)<($1>>>0);
 if (!($7)) {
  return;
 }
 $8 = ((($0)) + 4|0);
 $9 = ($1>>>0)>(268435455);
 if ($9) {
  $10 = (___cxa_allocate_exception(8)|0);
  __THREW__ = 0;
  invoke_vii(3366,($10|0),(204840|0));
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if ($12) {
   $13 = ___cxa_find_matching_catch_2()|0;
   $14 = tempRet0;
   ___cxa_free_exception(($10|0));
   ___resumeException($13|0);
   // unreachable;
  } else {
   HEAP32[$10>>2] = (99824);
   ___cxa_throw(($10|0),(34608|0),(3230|0));
   // unreachable;
  }
 }
 $15 = HEAP32[$8>>2]|0;
 $16 = (($15) - ($4))|0;
 $17 = $16 >> 4;
 $18 = $1 << 4;
 $19 = (__Znwj($18)|0);
 $20 = (($19) + ($17<<4)|0);
 $21 = $20;
 $22 = (($19) + ($1<<4)|0);
 $23 = $22;
 $24 = (0 - ($17))|0;
 $25 = (($20) + ($24<<4)|0);
 $26 = $25;
 $27 = ($16|0)>(0);
 if ($27) {
  $28 = $4;
  _memcpy(($25|0),($28|0),($16|0))|0;
 }
 HEAP32[$0>>2] = $26;
 HEAP32[$8>>2] = $21;
 HEAP32[$2>>2] = $23;
 $29 = ($4|0)==(0);
 if ($29) {
  return;
 }
 $30 = $4;
 __ZdlPv($30);
 return;
}
function __ZN3osg13TemplateArrayINS_5Vec4fELNS_5Array4TypeE29ELi4ELi5126EEC2ERKS4_RKNS_6CopyOpE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg6ObjectC2ERKS0_RKNS_6CopyOpE($0,$1,$2);
 HEAP32[$0>>2] = (55116);
 $3 = ((($0)) + 32|0);
 HEAP32[$3>>2] = 0;
 $4 = ((($0)) + 36|0);
 HEAP32[$4>>2] = 0;
 $5 = ((($0)) + 40|0);
 HEAP32[$5>>2] = 0;
 $6 = ((($0)) + 44|0);
 $7 = ((($1)) + 44|0);
 $8 = HEAP32[$7>>2]|0;
 HEAP32[$6>>2] = $8;
 $9 = ($8|0)==(0|0);
 if (!($9)) {
  $10 = HEAP32[$8>>2]|0;
  $11 = ((($10)) + -12|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($8) + ($12)|0);
  $14 = ((($13)) + 8|0);
  $15 = HEAP32[$14>>2]|0;HEAP32[$14>>2] = (($15+1)|0);
 }
 $16 = ((($0)) + 48|0);
 HEAP32[$16>>2] = 0;
 HEAP32[$0>>2] = (54500);
 $17 = ((($0)) + 52|0);
 $18 = ((($1)) + 52|0);
 $19 = HEAP32[$18>>2]|0;
 HEAP32[$17>>2] = $19;
 $20 = ((($0)) + 56|0);
 $21 = ((($1)) + 56|0);
 $22 = HEAP32[$21>>2]|0;
 HEAP32[$20>>2] = $22;
 $23 = ((($0)) + 60|0);
 $24 = ((($1)) + 60|0);
 $25 = HEAP32[$24>>2]|0;
 HEAP32[$23>>2] = $25;
 $26 = ((($0)) + 64|0);
 $27 = ((($1)) + 64|0);
 $28 = HEAP32[$27>>2]|0;
 HEAP32[$26>>2] = $28;
 $29 = ((($0)) + 68|0);
 $30 = ((($1)) + 68|0);
 $31 = HEAP8[$30>>0]|0;
 HEAP8[$29>>0] = $31;
 $32 = ((($0)) + 69|0);
 $33 = ((($1)) + 69|0);
 $34 = HEAP8[$33>>0]|0;
 HEAP8[$32>>0] = $34;
 $35 = ((($0)) + 72|0);
 HEAP32[$35>>2] = (38520);
 $36 = ((($0)) + 76|0);
 $37 = ((($1)) + 76|0);
 __THREW__ = 0;
 invoke_vii(3463,($36|0),($37|0));
 $38 = __THREW__; __THREW__ = 0;
 $39 = $38&1;
 if (!($39)) {
  HEAP32[$0>>2] = (38280);
  HEAP32[$35>>2] = (38504);
  return;
 }
 $40 = ___cxa_find_matching_catch_2()|0;
 $41 = tempRet0;
 __THREW__ = 0;
 invoke_vi(1265,($0|0));
 $42 = __THREW__; __THREW__ = 0;
 $43 = $42&1;
 if ($43) {
  $44 = ___cxa_find_matching_catch_3(0|0)|0;
  $45 = tempRet0;
  ___clang_call_terminate($44);
  // unreachable;
 } else {
  ___resumeException($40|0);
  // unreachable;
 }
}
function __ZN3osg13TemplateArrayINS_5Vec2fELNS_5Array4TypeE27ELi2ELi5126EED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i = 0, $scevgep5$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 72|0);
 HEAP32[$1>>2] = (38536);
 $2 = ((($0)) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  __ZN3osg10BufferDataD2Ev($0);
  return;
 }
 $5 = ((($0)) + 80|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==($3|0);
 if (!($7)) {
  $scevgep$i$i$i$i = ((($6)) + -8|0);
  $8 = $scevgep$i$i$i$i;
  $9 = $3;
  $10 = (($8) - ($9))|0;
  $11 = $10 >>> 3;
  $12 = $11 ^ -1;
  $scevgep5$i$i$i$i = (($6) + ($12<<3)|0);
  HEAP32[$5>>2] = $scevgep5$i$i$i$i;
 }
 __ZdlPv($3);
 __ZN3osg10BufferDataD2Ev($0);
 return;
}
function __ZN3osg13TemplateArrayINS_5Vec2fELNS_5Array4TypeE27ELi2ELi5126EED0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 72|0);
 HEAP32[$1>>2] = (38536);
 $2 = ((($0)) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = ((($0)) + 80|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==($3|0);
  if (!($7)) {
   $scevgep$i$i$i$i$i = ((($6)) + -8|0);
   $8 = $scevgep$i$i$i$i$i;
   $9 = $3;
   $10 = (($8) - ($9))|0;
   $11 = $10 >>> 3;
   $12 = $11 ^ -1;
   $scevgep5$i$i$i$i$i = (($6) + ($12<<3)|0);
   HEAP32[$5>>2] = $scevgep5$i$i$i$i$i;
  }
  __ZdlPv($3);
 }
 __THREW__ = 0;
 invoke_vi(1265,($0|0));
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 if ($14) {
  $15 = ___cxa_find_matching_catch_2()|0;
  $16 = tempRet0;
  __ZdlPv($0);
  ___resumeException($15|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK3osg13TemplateArrayINS_5Vec2fELNS_5Array4TypeE27ELi2ELi5126EE9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(88)|0);
 __THREW__ = 0;
 invoke_vii(3435,($1|0),1);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $17 = ___cxa_find_matching_catch_2()|0;
  $18 = tempRet0;
  __ZdlPv($1);
  ___resumeException($17|0);
  // unreachable;
 } else {
  $4 = ((($1)) + 12|0);
  ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;
  $5 = ((($1)) + 24|0);
  HEAP32[$5>>2] = 2;
  $6 = ((($1)) + 28|0);
  ;HEAP32[$6>>2]=0|0;HEAP32[$6+4>>2]=0|0;HEAP32[$6+8>>2]=0|0;HEAP32[$6+12>>2]=0|0;HEAP32[$6+16>>2]=0|0;HEAP32[$6+20>>2]=0|0;
  $7 = ((($1)) + 52|0);
  HEAP32[$7>>2] = 27;
  $8 = ((($1)) + 56|0);
  HEAP32[$8>>2] = 2;
  $9 = ((($1)) + 60|0);
  HEAP32[$9>>2] = 5126;
  $10 = ((($1)) + 64|0);
  HEAP32[$10>>2] = -1;
  $11 = ((($1)) + 68|0);
  HEAP8[$11>>0] = 0;
  $12 = ((($1)) + 69|0);
  HEAP8[$12>>0] = 0;
  $13 = ((($1)) + 72|0);
  $14 = ((($1)) + 76|0);
  HEAP32[$14>>2] = 0;
  $15 = ((($1)) + 80|0);
  HEAP32[$15>>2] = 0;
  $16 = ((($1)) + 84|0);
  HEAP32[$16>>2] = 0;
  HEAP32[$1>>2] = (38040);
  HEAP32[$13>>2] = (38264);
  return ($1|0);
 }
 return (0)|0;
}
function __ZNK3osg13TemplateArrayINS_5Vec2fELNS_5Array4TypeE27ELi2ELi5126EE5cloneERKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(88)|0);
 __THREW__ = 0;
 invoke_viii(3464,($2|0),($0|0),($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch_2()|0;
  $6 = tempRet0;
  __ZdlPv($2);
  ___resumeException($5|0);
  // unreachable;
 } else {
  return ($2|0);
 }
 return (0)|0;
}
function __ZNK3osg13TemplateArrayINS_5Vec2fELNS_5Array4TypeE27ELi2ELi5126EE14getDataPointerEv($0) {
 $0 = $0|0;
 var $$ = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 76|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 80|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2|0)==($4|0);
 $$ = $5 ? 0 : $2;
 return ($$|0);
}
function __ZNK3osg13TemplateArrayINS_5Vec2fELNS_5Array4TypeE27ELi2ELi5126EE16getTotalDataSizeEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 76|0);
 $2 = ((($0)) + 80|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$1>>2]|0;
 $5 = (($3) - ($4))|0;
 return ($5|0);
}
function __ZN3osg13TemplateArrayINS_5Vec2fELNS_5Array4TypeE27ELi2ELi5126EE6acceptERNS_12ArrayVisitorE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 116|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 8191]($1,$0);
 return;
}
function __ZNK3osg13TemplateArrayINS_5Vec2fELNS_5Array4TypeE27ELi2ELi5126EE6acceptERNS_17ConstArrayVisitorE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 116|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 8191]($1,$0);
 return;
}
function __ZN3osg13TemplateArrayINS_5Vec2fELNS_5Array4TypeE27ELi2ELi5126EE6acceptEjRNS_12ValueVisitorE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + 112|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($0)) + 76|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($1<<3)|0);
 FUNCTION_TABLE_vii[$5 & 8191]($2,$8);
 return;
}
function __ZNK3osg13TemplateArrayINS_5Vec2fELNS_5Array4TypeE27ELi2ELi5126EE6acceptEjRNS_17ConstValueVisitorE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + 112|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($0)) + 76|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($1<<3)|0);
 FUNCTION_TABLE_vii[$5 & 8191]($2,$8);
 return;
}
function __ZNK3osg13TemplateArrayINS_5Vec2fELNS_5Array4TypeE27ELi2ELi5126EE7compareEjj($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0.0, $13 = 0, $14 = 0.0, $15 = 0, $16 = 0, $17 = 0.0, $18 = 0, $19 = 0.0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0.0, $7 = 0, $8 = 0.0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 76|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + ($1<<3)|0);
 $6 = +HEAPF32[$5>>2];
 $7 = (($4) + ($2<<3)|0);
 $8 = +HEAPF32[$7>>2];
 $9 = $6 < $8;
 if ($9) {
  $$0 = -1;
  return ($$0|0);
 }
 $10 = $6 > $8;
 if (!($10)) {
  $11 = (((($4) + ($1<<3)|0)) + 4|0);
  $12 = +HEAPF32[$11>>2];
  $13 = (((($4) + ($2<<3)|0)) + 4|0);
  $14 = +HEAPF32[$13>>2];
  $15 = $12 < $14;
  if ($15) {
   $$0 = -1;
   return ($$0|0);
  }
  $16 = (((($4) + ($2<<3)|0)) + 4|0);
  $17 = +HEAPF32[$16>>2];
  $18 = (((($4) + ($1<<3)|0)) + 4|0);
  $19 = +HEAPF32[$18>>2];
  $20 = $17 < $19;
  if (!($20)) {
   $$0 = 0;
   return ($$0|0);
  }
 }
 $$0 = 1;
 return ($$0|0);
}
function __ZNK3osg13TemplateArrayINS_5Vec2fELNS_5Array4TypeE27ELi2ELi5126EE14getElementSizeEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 8;
}
function __ZNK3osg13TemplateArrayINS_5Vec2fELNS_5Array4TypeE27ELi2ELi5126EE14getDataPointerEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$ = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 80|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 $7 = (($3) + ($1<<3)|0);
 $$ = $6 ? 0 : $7;
 return ($$|0);
}
function __ZNK3osg13TemplateArrayINS_5Vec2fELNS_5Array4TypeE27ELi2ELi5126EE14getNumElementsEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 76|0);
 $2 = ((($0)) + 80|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$1>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 3;
 return ($6|0);
}
function __ZN3osg13TemplateArrayINS_5Vec2fELNS_5Array4TypeE27ELi2ELi5126EE12reserveArrayEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 76|0);
 __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE7reserveEj($2,$1);
 return;
}
function __ZN3osg13TemplateArrayINS_5Vec2fELNS_5Array4TypeE27ELi2ELi5126EE11resizeArrayEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $scevgep$i$i$i$i = 0, $scevgep5$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 HEAPF32[$2>>2] = 0.0;
 $3 = ((($2)) + 4|0);
 HEAPF32[$3>>2] = 0.0;
 $4 = ((($0)) + 76|0);
 $5 = ((($0)) + 80|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$4>>2]|0;
 $8 = (($6) - ($7))|0;
 $9 = $8 >> 3;
 $10 = ($9>>>0)<($1>>>0);
 $11 = $7;
 $12 = $6;
 if ($10) {
  $13 = (($1) - ($9))|0;
  __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE8__appendEjRKS2_($4,$13,$2);
  STACKTOP = sp;return;
 }
 $14 = ($9>>>0)>($1>>>0);
 if (!($14)) {
  STACKTOP = sp;return;
 }
 $15 = (($11) + ($1<<3)|0);
 $16 = ($12|0)==($15|0);
 if ($16) {
  STACKTOP = sp;return;
 }
 $scevgep$i$i$i$i = ((($12)) + -8|0);
 $17 = $scevgep$i$i$i$i;
 $18 = $15;
 $19 = (($17) - ($18))|0;
 $20 = $19 >>> 3;
 $21 = $20 ^ -1;
 $scevgep5$i$i$i$i = (($12) + ($21<<3)|0);
 HEAP32[$5>>2] = $scevgep5$i$i$i$i;
 STACKTOP = sp;return;
}
function __ZN3osg13TemplateArrayINS_5Vec2fELNS_5Array4TypeE27ELi2ELi5126EE4trimEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $scevgep$i$i$i$i = 0, $scevgep5$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 HEAP32[$1>>2] = (38536);
 $2 = ((($1)) + 4|0);
 $3 = ((($0)) + 76|0);
 __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEEC2ERKS5_($2,$3);
 $4 = HEAP32[$2>>2]|0;
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$2>>2] = $5;
 HEAP32[$3>>2] = $4;
 $6 = ((($1)) + 8|0);
 $7 = ((($0)) + 80|0);
 $8 = HEAP32[$6>>2]|0;
 $9 = HEAP32[$7>>2]|0;
 HEAP32[$6>>2] = $9;
 HEAP32[$7>>2] = $8;
 $10 = ((($1)) + 12|0);
 $11 = ((($0)) + 84|0);
 $12 = HEAP32[$10>>2]|0;
 $13 = HEAP32[$11>>2]|0;
 HEAP32[$10>>2] = $13;
 HEAP32[$11>>2] = $12;
 HEAP32[$1>>2] = (38536);
 $14 = ($5|0)==(0);
 $15 = $5;
 $16 = $9;
 if ($14) {
  STACKTOP = sp;return;
 }
 $17 = $5;
 $18 = ($16|0)==($17|0);
 if (!($18)) {
  $scevgep$i$i$i$i = ((($16)) + -8|0);
  $19 = $scevgep$i$i$i$i;
  $20 = (($19) - ($5))|0;
  $21 = $20 >>> 3;
  $22 = $21 ^ -1;
  $scevgep5$i$i$i$i = (($16) + ($22<<3)|0);
  HEAP32[$6>>2] = $scevgep5$i$i$i$i;
 }
 __ZdlPv($15);
 STACKTOP = sp;return;
}
function __ZThn72_N3osg13TemplateArrayINS_5Vec2fELNS_5Array4TypeE27ELi2ELi5126EED1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -72|0);
 $2 = ((($1)) + 72|0);
 HEAP32[$2>>2] = (38536);
 $3 = ((($1)) + 76|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  __ZN3osg10BufferDataD2Ev($1);
  return;
 }
 $6 = ((($1)) + 80|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==($4|0);
 if (!($8)) {
  $scevgep$i$i$i$i$i = ((($7)) + -8|0);
  $9 = $scevgep$i$i$i$i$i;
  $10 = $4;
  $11 = (($9) - ($10))|0;
  $12 = $11 >>> 3;
  $13 = $12 ^ -1;
  $scevgep5$i$i$i$i$i = (($7) + ($13<<3)|0);
  HEAP32[$6>>2] = $scevgep5$i$i$i$i$i;
 }
 __ZdlPv($4);
 __ZN3osg10BufferDataD2Ev($1);
 return;
}
function __ZThn72_N3osg13TemplateArrayINS_5Vec2fELNS_5Array4TypeE27ELi2ELi5126EED0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -72|0);
 $2 = ((($1)) + 72|0);
 HEAP32[$2>>2] = (38536);
 $3 = ((($1)) + 76|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if (!($5)) {
  $6 = ((($1)) + 80|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)==($4|0);
  if (!($8)) {
   $scevgep$i$i$i$i$i$i = ((($7)) + -8|0);
   $9 = $scevgep$i$i$i$i$i$i;
   $10 = $4;
   $11 = (($9) - ($10))|0;
   $12 = $11 >>> 3;
   $13 = $12 ^ -1;
   $scevgep5$i$i$i$i$i$i = (($7) + ($13<<3)|0);
   HEAP32[$6>>2] = $scevgep5$i$i$i$i$i$i;
  }
  __ZdlPv($4);
 }
 __THREW__ = 0;
 invoke_vi(1265,($1|0));
 $14 = __THREW__; __THREW__ = 0;
 $15 = $14&1;
 if ($15) {
  $16 = ___cxa_find_matching_catch_2()|0;
  $17 = tempRet0;
  __ZdlPv($1);
  ___resumeException($16|0);
  // unreachable;
 } else {
  __ZdlPv($1);
  return;
 }
}
function __ZN3osg11MixinVectorINS_5Vec2fEED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i = 0, $scevgep5$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (38536);
 $1 = ((($0)) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  return;
 }
 $4 = ((($0)) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==($2|0);
 if (!($6)) {
  $scevgep$i$i$i = ((($5)) + -8|0);
  $7 = $scevgep$i$i$i;
  $8 = $2;
  $9 = (($7) - ($8))|0;
  $10 = $9 >>> 3;
  $11 = $10 ^ -1;
  $scevgep5$i$i$i = (($5) + ($11<<3)|0);
  HEAP32[$4>>2] = $scevgep5$i$i$i;
 }
 __ZdlPv($2);
 return;
}
function __ZN3osg11MixinVectorINS_5Vec2fEED0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i = 0, $scevgep5$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (38536);
 $1 = ((($0)) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  __ZdlPv($0);
  return;
 }
 $4 = ((($0)) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==($2|0);
 if (!($6)) {
  $scevgep$i$i$i$i = ((($5)) + -8|0);
  $7 = $scevgep$i$i$i$i;
  $8 = $2;
  $9 = (($7) - ($8))|0;
  $10 = $9 >>> 3;
  $11 = $10 ^ -1;
  $scevgep5$i$i$i$i = (($5) + ($11<<3)|0);
  HEAP32[$4>>2] = $scevgep5$i$i$i$i;
 }
 __ZdlPv($2);
 __ZdlPv($0);
 return;
}
function __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEEC2ERKS5_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i = 0, $scevgep5$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = 0;
 $2 = ((($0)) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = ((($0)) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$1>>2]|0;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 3;
 $9 = ($8|0)==(0);
 if ($9) {
  return;
 }
 $10 = ($8>>>0)>(536870911);
 if ($10) {
  __THREW__ = 0;
  invoke_vi(3307,($0|0));
  $11 = __THREW__; __THREW__ = 0;
 } else {
  __THREW__ = 0;
  $12 = (invoke_ii(3276,($7|0))|0);
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if (!($14)) {
   HEAP32[$2>>2] = $12;
   HEAP32[$0>>2] = $12;
   $15 = (($12) + ($8<<3)|0);
   $16 = ((($0)) + 8|0);
   HEAP32[$16>>2] = $15;
   $17 = HEAP32[$1>>2]|0;
   $18 = HEAP32[$4>>2]|0;
   $19 = $17;
   $20 = (($18) - ($19))|0;
   $21 = ($20|0)>(0);
   if (!($21)) {
    return;
   }
   $22 = $20 >>> 3;
   _memcpy(($12|0),($17|0),($20|0))|0;
   $23 = (($12) + ($22<<3)|0);
   HEAP32[$2>>2] = $23;
   return;
  }
 }
 $24 = ___cxa_find_matching_catch_2()|0;
 $25 = tempRet0;
 $26 = HEAP32[$0>>2]|0;
 $27 = ($26|0)==(0|0);
 if ($27) {
  ___resumeException($24|0);
  // unreachable;
 }
 $28 = HEAP32[$2>>2]|0;
 $29 = ($28|0)==($26|0);
 if (!($29)) {
  $scevgep$i$i$i = ((($28)) + -8|0);
  $30 = $scevgep$i$i$i;
  $31 = $26;
  $32 = (($30) - ($31))|0;
  $33 = $32 >>> 3;
  $34 = $33 ^ -1;
  $scevgep5$i$i$i = (($28) + ($34<<3)|0);
  HEAP32[$2>>2] = $scevgep5$i$i$i;
 }
 __ZdlPv($26);
 ___resumeException($24|0);
 // unreachable;
}
function __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE8__appendEjRKS2_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$i = 0, $$0$i18 = 0, $$in = 0, $$sroa$15$0 = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) - ($6))|0;
 $8 = $7 >> 3;
 $9 = ($8>>>0)<($1>>>0);
 if (!($9)) {
  $10 = $6;
  $$0$i = $1;$17 = $10;
  while(1) {
   $11 = $2;
   $12 = $11;
   $13 = HEAP32[$12>>2]|0;
   $14 = (($11) + 4)|0;
   $15 = $14;
   $16 = HEAP32[$15>>2]|0;
   $18 = $17;
   $19 = $18;
   HEAP32[$19>>2] = $13;
   $20 = (($18) + 4)|0;
   $21 = $20;
   HEAP32[$21>>2] = $16;
   $22 = HEAP32[$5>>2]|0;
   $23 = ((($22)) + 8|0);
   HEAP32[$5>>2] = $23;
   $24 = (($$0$i) + -1)|0;
   $25 = ($24|0)==(0);
   if ($25) {
    break;
   } else {
    $$0$i = $24;$17 = $23;
   }
  }
  return;
 }
 $26 = HEAP32[$0>>2]|0;
 $27 = (($6) - ($26))|0;
 $28 = $27 >> 3;
 $29 = (($28) + ($1))|0;
 $30 = ($29>>>0)>(536870911);
 if ($30) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $31 = (($4) - ($26))|0;
 $32 = $31 >> 3;
 $33 = ($32>>>0)<(268435455);
 $34 = $31 >> 2;
 $35 = ($34>>>0)<($29>>>0);
 $$sroa$speculated$i = $35 ? $29 : $34;
 $$sroa$speculated$$i = $33 ? $$sroa$speculated$i : 536870911;
 $36 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($36) {
   $46 = 0;
  } else {
   $37 = ($$sroa$speculated$$i>>>0)>(536870911);
   if (!($37)) {
    $43 = $$sroa$speculated$$i << 3;
    $44 = (__Znwj($43)|0);
    $46 = $44;
    break;
   }
   $38 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($38|0),(204840|0));
   $39 = __THREW__; __THREW__ = 0;
   $40 = $39&1;
   if ($40) {
    $41 = ___cxa_find_matching_catch_2()|0;
    $42 = tempRet0;
    ___cxa_free_exception(($38|0));
    ___resumeException($41|0);
    // unreachable;
   } else {
    HEAP32[$38>>2] = (99824);
    ___cxa_throw(($38|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $45 = (($46) + ($28<<3)|0);
 $47 = $45;
 $48 = (($46) + ($$sroa$speculated$$i<<3)|0);
 $$0$i18 = $1;$$in = $45;$$sroa$15$0 = $47;
 while(1) {
  $49 = $2;
  $50 = $49;
  $51 = HEAP32[$50>>2]|0;
  $52 = (($49) + 4)|0;
  $53 = $52;
  $54 = HEAP32[$53>>2]|0;
  $55 = $$in;
  $56 = $55;
  HEAP32[$56>>2] = $51;
  $57 = (($55) + 4)|0;
  $58 = $57;
  HEAP32[$58>>2] = $54;
  $59 = $$sroa$15$0;
  $60 = ((($59)) + 8|0);
  $61 = $60;
  $62 = (($$0$i18) + -1)|0;
  $63 = ($62|0)==(0);
  if ($63) {
   break;
  } else {
   $$0$i18 = $62;$$in = $60;$$sroa$15$0 = $61;
  }
 }
 $64 = $48;
 $65 = HEAP32[$0>>2]|0;
 $66 = HEAP32[$5>>2]|0;
 $67 = $65;
 $68 = (($66) - ($67))|0;
 $69 = $68 >> 3;
 $70 = (0 - ($69))|0;
 $71 = (($45) + ($70<<3)|0);
 $72 = $71;
 $73 = ($68|0)>(0);
 if ($73) {
  _memcpy(($71|0),($65|0),($68|0))|0;
 }
 HEAP32[$0>>2] = $72;
 HEAP32[$5>>2] = $61;
 HEAP32[$3>>2] = $64;
 $74 = ($65|0)==(0|0);
 if ($74) {
  return;
 }
 __ZdlPv($65);
 return;
}
function __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE7reserveEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 3;
 $7 = ($6>>>0)<($1>>>0);
 if (!($7)) {
  return;
 }
 $8 = ((($0)) + 4|0);
 $9 = ($1>>>0)>(536870911);
 if ($9) {
  $10 = (___cxa_allocate_exception(8)|0);
  __THREW__ = 0;
  invoke_vii(3366,($10|0),(204840|0));
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if ($12) {
   $13 = ___cxa_find_matching_catch_2()|0;
   $14 = tempRet0;
   ___cxa_free_exception(($10|0));
   ___resumeException($13|0);
   // unreachable;
  } else {
   HEAP32[$10>>2] = (99824);
   ___cxa_throw(($10|0),(34608|0),(3230|0));
   // unreachable;
  }
 }
 $15 = HEAP32[$8>>2]|0;
 $16 = (($15) - ($4))|0;
 $17 = $16 >> 3;
 $18 = $1 << 3;
 $19 = (__Znwj($18)|0);
 $20 = (($19) + ($17<<3)|0);
 $21 = $20;
 $22 = (($19) + ($1<<3)|0);
 $23 = $22;
 $24 = (0 - ($17))|0;
 $25 = (($20) + ($24<<3)|0);
 $26 = $25;
 $27 = ($16|0)>(0);
 if ($27) {
  $28 = $4;
  _memcpy(($25|0),($28|0),($16|0))|0;
 }
 HEAP32[$0>>2] = $26;
 HEAP32[$8>>2] = $21;
 HEAP32[$2>>2] = $23;
 $29 = ($4|0)==(0);
 if ($29) {
  return;
 }
 $30 = $4;
 __ZdlPv($30);
 return;
}
function __ZN3osg13TemplateArrayINS_5Vec2fELNS_5Array4TypeE27ELi2ELi5126EEC2ERKS4_RKNS_6CopyOpE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg6ObjectC2ERKS0_RKNS_6CopyOpE($0,$1,$2);
 HEAP32[$0>>2] = (55116);
 $3 = ((($0)) + 32|0);
 HEAP32[$3>>2] = 0;
 $4 = ((($0)) + 36|0);
 HEAP32[$4>>2] = 0;
 $5 = ((($0)) + 40|0);
 HEAP32[$5>>2] = 0;
 $6 = ((($0)) + 44|0);
 $7 = ((($1)) + 44|0);
 $8 = HEAP32[$7>>2]|0;
 HEAP32[$6>>2] = $8;
 $9 = ($8|0)==(0|0);
 if (!($9)) {
  $10 = HEAP32[$8>>2]|0;
  $11 = ((($10)) + -12|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($8) + ($12)|0);
  $14 = ((($13)) + 8|0);
  $15 = HEAP32[$14>>2]|0;HEAP32[$14>>2] = (($15+1)|0);
 }
 $16 = ((($0)) + 48|0);
 HEAP32[$16>>2] = 0;
 HEAP32[$0>>2] = (54500);
 $17 = ((($0)) + 52|0);
 $18 = ((($1)) + 52|0);
 $19 = HEAP32[$18>>2]|0;
 HEAP32[$17>>2] = $19;
 $20 = ((($0)) + 56|0);
 $21 = ((($1)) + 56|0);
 $22 = HEAP32[$21>>2]|0;
 HEAP32[$20>>2] = $22;
 $23 = ((($0)) + 60|0);
 $24 = ((($1)) + 60|0);
 $25 = HEAP32[$24>>2]|0;
 HEAP32[$23>>2] = $25;
 $26 = ((($0)) + 64|0);
 $27 = ((($1)) + 64|0);
 $28 = HEAP32[$27>>2]|0;
 HEAP32[$26>>2] = $28;
 $29 = ((($0)) + 68|0);
 $30 = ((($1)) + 68|0);
 $31 = HEAP8[$30>>0]|0;
 HEAP8[$29>>0] = $31;
 $32 = ((($0)) + 69|0);
 $33 = ((($1)) + 69|0);
 $34 = HEAP8[$33>>0]|0;
 HEAP8[$32>>0] = $34;
 $35 = ((($0)) + 72|0);
 HEAP32[$35>>2] = (38536);
 $36 = ((($0)) + 76|0);
 $37 = ((($1)) + 76|0);
 __THREW__ = 0;
 invoke_vii(3465,($36|0),($37|0));
 $38 = __THREW__; __THREW__ = 0;
 $39 = $38&1;
 if (!($39)) {
  HEAP32[$0>>2] = (38040);
  HEAP32[$35>>2] = (38264);
  return;
 }
 $40 = ___cxa_find_matching_catch_2()|0;
 $41 = tempRet0;
 __THREW__ = 0;
 invoke_vi(1265,($0|0));
 $42 = __THREW__; __THREW__ = 0;
 $43 = $42&1;
 if ($43) {
  $44 = ___cxa_find_matching_catch_3(0|0)|0;
  $45 = tempRet0;
  ___clang_call_terminate($44);
  // unreachable;
 } else {
  ___resumeException($40|0);
  // unreachable;
 }
}
function __ZN3osg13TemplateArrayINS_5Vec3fELNS_5Array4TypeE28ELi3ELi5126EED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i = 0, $scevgep5$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 72|0);
 HEAP32[$1>>2] = (38552);
 $2 = ((($0)) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  __ZN3osg10BufferDataD2Ev($0);
  return;
 }
 $5 = ((($0)) + 80|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==($3|0);
 if (!($7)) {
  $scevgep$i$i$i$i = ((($6)) + -12|0);
  $8 = $scevgep$i$i$i$i;
  $9 = $3;
  $10 = (($8) - ($9))|0;
  $11 = (($10>>>0) / 12)&-1;
  $12 = $11 ^ -1;
  $scevgep5$i$i$i$i = (($6) + (($12*12)|0)|0);
  HEAP32[$5>>2] = $scevgep5$i$i$i$i;
 }
 __ZdlPv($3);
 __ZN3osg10BufferDataD2Ev($0);
 return;
}
function __ZN3osg13TemplateArrayINS_5Vec3fELNS_5Array4TypeE28ELi3ELi5126EED0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 72|0);
 HEAP32[$1>>2] = (38552);
 $2 = ((($0)) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = ((($0)) + 80|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==($3|0);
  if (!($7)) {
   $scevgep$i$i$i$i$i = ((($6)) + -12|0);
   $8 = $scevgep$i$i$i$i$i;
   $9 = $3;
   $10 = (($8) - ($9))|0;
   $11 = (($10>>>0) / 12)&-1;
   $12 = $11 ^ -1;
   $scevgep5$i$i$i$i$i = (($6) + (($12*12)|0)|0);
   HEAP32[$5>>2] = $scevgep5$i$i$i$i$i;
  }
  __ZdlPv($3);
 }
 __THREW__ = 0;
 invoke_vi(1265,($0|0));
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 if ($14) {
  $15 = ___cxa_find_matching_catch_2()|0;
  $16 = tempRet0;
  __ZdlPv($0);
  ___resumeException($15|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK3osg13TemplateArrayINS_5Vec3fELNS_5Array4TypeE28ELi3ELi5126EE9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(88)|0);
 __THREW__ = 0;
 invoke_vii(3435,($1|0),1);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $17 = ___cxa_find_matching_catch_2()|0;
  $18 = tempRet0;
  __ZdlPv($1);
  ___resumeException($17|0);
  // unreachable;
 } else {
  $4 = ((($1)) + 12|0);
  ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;
  $5 = ((($1)) + 24|0);
  HEAP32[$5>>2] = 2;
  $6 = ((($1)) + 28|0);
  ;HEAP32[$6>>2]=0|0;HEAP32[$6+4>>2]=0|0;HEAP32[$6+8>>2]=0|0;HEAP32[$6+12>>2]=0|0;HEAP32[$6+16>>2]=0|0;HEAP32[$6+20>>2]=0|0;
  $7 = ((($1)) + 52|0);
  HEAP32[$7>>2] = 28;
  $8 = ((($1)) + 56|0);
  HEAP32[$8>>2] = 3;
  $9 = ((($1)) + 60|0);
  HEAP32[$9>>2] = 5126;
  $10 = ((($1)) + 64|0);
  HEAP32[$10>>2] = -1;
  $11 = ((($1)) + 68|0);
  HEAP8[$11>>0] = 0;
  $12 = ((($1)) + 69|0);
  HEAP8[$12>>0] = 0;
  $13 = ((($1)) + 72|0);
  $14 = ((($1)) + 76|0);
  HEAP32[$14>>2] = 0;
  $15 = ((($1)) + 80|0);
  HEAP32[$15>>2] = 0;
  $16 = ((($1)) + 84|0);
  HEAP32[$16>>2] = 0;
  HEAP32[$1>>2] = (37800);
  HEAP32[$13>>2] = (38024);
  return ($1|0);
 }
 return (0)|0;
}
function __ZNK3osg13TemplateArrayINS_5Vec3fELNS_5Array4TypeE28ELi3ELi5126EE5cloneERKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(88)|0);
 __THREW__ = 0;
 invoke_viii(3466,($2|0),($0|0),($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch_2()|0;
  $6 = tempRet0;
  __ZdlPv($2);
  ___resumeException($5|0);
  // unreachable;
 } else {
  return ($2|0);
 }
 return (0)|0;
}
function __ZNK3osg13TemplateArrayINS_5Vec3fELNS_5Array4TypeE28ELi3ELi5126EE14getDataPointerEv($0) {
 $0 = $0|0;
 var $$ = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 76|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 80|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2|0)==($4|0);
 $$ = $5 ? 0 : $2;
 return ($$|0);
}
function __ZNK3osg13TemplateArrayINS_5Vec3fELNS_5Array4TypeE28ELi3ELi5126EE16getTotalDataSizeEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 76|0);
 $2 = ((($0)) + 80|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$1>>2]|0;
 $5 = (($3) - ($4))|0;
 return ($5|0);
}
function __ZN3osg13TemplateArrayINS_5Vec3fELNS_5Array4TypeE28ELi3ELi5126EE6acceptERNS_12ArrayVisitorE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 120|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 8191]($1,$0);
 return;
}
function __ZNK3osg13TemplateArrayINS_5Vec3fELNS_5Array4TypeE28ELi3ELi5126EE6acceptERNS_17ConstArrayVisitorE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 120|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 8191]($1,$0);
 return;
}
function __ZN3osg13TemplateArrayINS_5Vec3fELNS_5Array4TypeE28ELi3ELi5126EE6acceptEjRNS_12ValueVisitorE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + 116|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($0)) + 76|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + (($1*12)|0)|0);
 FUNCTION_TABLE_vii[$5 & 8191]($2,$8);
 return;
}
function __ZNK3osg13TemplateArrayINS_5Vec3fELNS_5Array4TypeE28ELi3ELi5126EE6acceptEjRNS_17ConstValueVisitorE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + 116|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($0)) + 76|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + (($1*12)|0)|0);
 FUNCTION_TABLE_vii[$5 & 8191]($2,$8);
 return;
}
function __ZNK3osg13TemplateArrayINS_5Vec3fELNS_5Array4TypeE28ELi3ELi5126EE7compareEjj($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0.0, $13 = 0, $14 = 0.0, $15 = 0, $16 = 0, $17 = 0, $18 = 0.0, $19 = 0, $20 = 0.0, $21 = 0, $22 = 0, $23 = 0.0, $24 = 0, $25 = 0.0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0.0, $3 = 0, $30 = 0, $31 = 0.0, $32 = 0, $4 = 0, $5 = 0, $6 = 0.0, $7 = 0, $8 = 0.0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 76|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + (($1*12)|0)|0);
 $6 = +HEAPF32[$5>>2];
 $7 = (($4) + (($2*12)|0)|0);
 $8 = +HEAPF32[$7>>2];
 $9 = $6 < $8;
 if ($9) {
  $$0 = -1;
  return ($$0|0);
 }
 $10 = $6 > $8;
 if (!($10)) {
  $11 = (((($4) + (($1*12)|0)|0)) + 4|0);
  $12 = +HEAPF32[$11>>2];
  $13 = (((($4) + (($2*12)|0)|0)) + 4|0);
  $14 = +HEAPF32[$13>>2];
  $15 = $12 < $14;
  if ($15) {
   $$0 = -1;
   return ($$0|0);
  }
  $16 = $12 > $14;
  if (!($16)) {
   $17 = (((($4) + (($1*12)|0)|0)) + 8|0);
   $18 = +HEAPF32[$17>>2];
   $19 = (((($4) + (($2*12)|0)|0)) + 8|0);
   $20 = +HEAPF32[$19>>2];
   $21 = $18 < $20;
   if ($21) {
    $$0 = -1;
    return ($$0|0);
   }
  }
  $22 = (((($4) + (($2*12)|0)|0)) + 4|0);
  $23 = +HEAPF32[$22>>2];
  $24 = (((($4) + (($1*12)|0)|0)) + 4|0);
  $25 = +HEAPF32[$24>>2];
  $26 = $23 < $25;
  if (!($26)) {
   $27 = $23 > $25;
   if ($27) {
    $$0 = 0;
    return ($$0|0);
   }
   $28 = (((($4) + (($2*12)|0)|0)) + 8|0);
   $29 = +HEAPF32[$28>>2];
   $30 = (((($4) + (($1*12)|0)|0)) + 8|0);
   $31 = +HEAPF32[$30>>2];
   $32 = $29 < $31;
   if (!($32)) {
    $$0 = 0;
    return ($$0|0);
   }
  }
 }
 $$0 = 1;
 return ($$0|0);
}
function __ZNK3osg13TemplateArrayINS_5Vec3fELNS_5Array4TypeE28ELi3ELi5126EE14getElementSizeEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 12;
}
function __ZNK3osg13TemplateArrayINS_5Vec3fELNS_5Array4TypeE28ELi3ELi5126EE14getDataPointerEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$ = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 80|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 $7 = (($3) + (($1*12)|0)|0);
 $$ = $6 ? 0 : $7;
 return ($$|0);
}
function __ZNK3osg13TemplateArrayINS_5Vec3fELNS_5Array4TypeE28ELi3ELi5126EE14getNumElementsEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 76|0);
 $2 = ((($0)) + 80|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$1>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = (($5|0) / 12)&-1;
 return ($6|0);
}
function __ZN3osg13TemplateArrayINS_5Vec3fELNS_5Array4TypeE28ELi3ELi5126EE12reserveArrayEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 76|0);
 __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE7reserveEj($2,$1);
 return;
}
function __ZN3osg13TemplateArrayINS_5Vec3fELNS_5Array4TypeE28ELi3ELi5126EE11resizeArrayEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $scevgep$i$i$i$i = 0, $scevgep5$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 HEAPF32[$2>>2] = 0.0;
 $3 = ((($2)) + 4|0);
 HEAPF32[$3>>2] = 0.0;
 $4 = ((($2)) + 8|0);
 HEAPF32[$4>>2] = 0.0;
 $5 = ((($0)) + 76|0);
 $6 = ((($0)) + 80|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$5>>2]|0;
 $9 = (($7) - ($8))|0;
 $10 = (($9|0) / 12)&-1;
 $11 = ($10>>>0)<($1>>>0);
 $12 = $8;
 $13 = $7;
 if ($11) {
  $14 = (($1) - ($10))|0;
  __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE8__appendEjRKS2_($5,$14,$2);
  STACKTOP = sp;return;
 }
 $15 = ($10>>>0)>($1>>>0);
 if (!($15)) {
  STACKTOP = sp;return;
 }
 $16 = (($12) + (($1*12)|0)|0);
 $17 = ($13|0)==($16|0);
 if ($17) {
  STACKTOP = sp;return;
 }
 $scevgep$i$i$i$i = ((($13)) + -12|0);
 $18 = $scevgep$i$i$i$i;
 $19 = $16;
 $20 = (($18) - ($19))|0;
 $21 = (($20>>>0) / 12)&-1;
 $22 = $21 ^ -1;
 $scevgep5$i$i$i$i = (($13) + (($22*12)|0)|0);
 HEAP32[$6>>2] = $scevgep5$i$i$i$i;
 STACKTOP = sp;return;
}
function __ZN3osg13TemplateArrayINS_5Vec3fELNS_5Array4TypeE28ELi3ELi5126EE4trimEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $scevgep$i$i$i$i = 0, $scevgep5$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 HEAP32[$1>>2] = (38552);
 $2 = ((($1)) + 4|0);
 $3 = ((($0)) + 76|0);
 __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEEC2ERKS5_($2,$3);
 $4 = HEAP32[$2>>2]|0;
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$2>>2] = $5;
 HEAP32[$3>>2] = $4;
 $6 = ((($1)) + 8|0);
 $7 = ((($0)) + 80|0);
 $8 = HEAP32[$6>>2]|0;
 $9 = HEAP32[$7>>2]|0;
 HEAP32[$6>>2] = $9;
 HEAP32[$7>>2] = $8;
 $10 = ((($1)) + 12|0);
 $11 = ((($0)) + 84|0);
 $12 = HEAP32[$10>>2]|0;
 $13 = HEAP32[$11>>2]|0;
 HEAP32[$10>>2] = $13;
 HEAP32[$11>>2] = $12;
 HEAP32[$1>>2] = (38552);
 $14 = ($5|0)==(0);
 $15 = $5;
 $16 = $9;
 if ($14) {
  STACKTOP = sp;return;
 }
 $17 = $5;
 $18 = ($16|0)==($17|0);
 if (!($18)) {
  $scevgep$i$i$i$i = ((($16)) + -12|0);
  $19 = $scevgep$i$i$i$i;
  $20 = (($19) - ($5))|0;
  $21 = (($20>>>0) / 12)&-1;
  $22 = $21 ^ -1;
  $scevgep5$i$i$i$i = (($16) + (($22*12)|0)|0);
  HEAP32[$6>>2] = $scevgep5$i$i$i$i;
 }
 __ZdlPv($15);
 STACKTOP = sp;return;
}
function __ZThn72_N3osg13TemplateArrayINS_5Vec3fELNS_5Array4TypeE28ELi3ELi5126EED1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -72|0);
 $2 = ((($1)) + 72|0);
 HEAP32[$2>>2] = (38552);
 $3 = ((($1)) + 76|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  __ZN3osg10BufferDataD2Ev($1);
  return;
 }
 $6 = ((($1)) + 80|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==($4|0);
 if (!($8)) {
  $scevgep$i$i$i$i$i = ((($7)) + -12|0);
  $9 = $scevgep$i$i$i$i$i;
  $10 = $4;
  $11 = (($9) - ($10))|0;
  $12 = (($11>>>0) / 12)&-1;
  $13 = $12 ^ -1;
  $scevgep5$i$i$i$i$i = (($7) + (($13*12)|0)|0);
  HEAP32[$6>>2] = $scevgep5$i$i$i$i$i;
 }
 __ZdlPv($4);
 __ZN3osg10BufferDataD2Ev($1);
 return;
}
function __ZThn72_N3osg13TemplateArrayINS_5Vec3fELNS_5Array4TypeE28ELi3ELi5126EED0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -72|0);
 $2 = ((($1)) + 72|0);
 HEAP32[$2>>2] = (38552);
 $3 = ((($1)) + 76|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if (!($5)) {
  $6 = ((($1)) + 80|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)==($4|0);
  if (!($8)) {
   $scevgep$i$i$i$i$i$i = ((($7)) + -12|0);
   $9 = $scevgep$i$i$i$i$i$i;
   $10 = $4;
   $11 = (($9) - ($10))|0;
   $12 = (($11>>>0) / 12)&-1;
   $13 = $12 ^ -1;
   $scevgep5$i$i$i$i$i$i = (($7) + (($13*12)|0)|0);
   HEAP32[$6>>2] = $scevgep5$i$i$i$i$i$i;
  }
  __ZdlPv($4);
 }
 __THREW__ = 0;
 invoke_vi(1265,($1|0));
 $14 = __THREW__; __THREW__ = 0;
 $15 = $14&1;
 if ($15) {
  $16 = ___cxa_find_matching_catch_2()|0;
  $17 = tempRet0;
  __ZdlPv($1);
  ___resumeException($16|0);
  // unreachable;
 } else {
  __ZdlPv($1);
  return;
 }
}
function __ZN3osg11MixinVectorINS_5Vec3fEED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i = 0, $scevgep5$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (38552);
 $1 = ((($0)) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  return;
 }
 $4 = ((($0)) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==($2|0);
 if (!($6)) {
  $scevgep$i$i$i = ((($5)) + -12|0);
  $7 = $scevgep$i$i$i;
  $8 = $2;
  $9 = (($7) - ($8))|0;
  $10 = (($9>>>0) / 12)&-1;
  $11 = $10 ^ -1;
  $scevgep5$i$i$i = (($5) + (($11*12)|0)|0);
  HEAP32[$4>>2] = $scevgep5$i$i$i;
 }
 __ZdlPv($2);
 return;
}
function __ZN3osg11MixinVectorINS_5Vec3fEED0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i = 0, $scevgep5$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (38552);
 $1 = ((($0)) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  __ZdlPv($0);
  return;
 }
 $4 = ((($0)) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==($2|0);
 if (!($6)) {
  $scevgep$i$i$i$i = ((($5)) + -12|0);
  $7 = $scevgep$i$i$i$i;
  $8 = $2;
  $9 = (($7) - ($8))|0;
  $10 = (($9>>>0) / 12)&-1;
  $11 = $10 ^ -1;
  $scevgep5$i$i$i$i = (($5) + (($11*12)|0)|0);
  HEAP32[$4>>2] = $scevgep5$i$i$i$i;
 }
 __ZdlPv($2);
 __ZdlPv($0);
 return;
}
function __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEEC2ERKS5_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i = 0, $scevgep5$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = 0;
 $2 = ((($0)) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = ((($0)) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$1>>2]|0;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 12)&-1;
 $9 = ($7|0)==(0);
 if ($9) {
  return;
 }
 $10 = ($8>>>0)>(357913941);
 if ($10) {
  __THREW__ = 0;
  invoke_vi(3307,($0|0));
  $11 = __THREW__; __THREW__ = 0;
 } else {
  __THREW__ = 0;
  $12 = (invoke_ii(3276,($7|0))|0);
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if (!($14)) {
   HEAP32[$2>>2] = $12;
   HEAP32[$0>>2] = $12;
   $15 = (($12) + (($8*12)|0)|0);
   $16 = ((($0)) + 8|0);
   HEAP32[$16>>2] = $15;
   $17 = HEAP32[$1>>2]|0;
   $18 = HEAP32[$4>>2]|0;
   $19 = $17;
   $20 = (($18) - ($19))|0;
   $21 = ($20|0)>(0);
   if (!($21)) {
    return;
   }
   $22 = (($20>>>0) / 12)&-1;
   _memcpy(($12|0),($17|0),($20|0))|0;
   $23 = (($12) + (($22*12)|0)|0);
   HEAP32[$2>>2] = $23;
   return;
  }
 }
 $24 = ___cxa_find_matching_catch_2()|0;
 $25 = tempRet0;
 $26 = HEAP32[$0>>2]|0;
 $27 = ($26|0)==(0|0);
 if ($27) {
  ___resumeException($24|0);
  // unreachable;
 }
 $28 = HEAP32[$2>>2]|0;
 $29 = ($28|0)==($26|0);
 if (!($29)) {
  $scevgep$i$i$i = ((($28)) + -12|0);
  $30 = $scevgep$i$i$i;
  $31 = $26;
  $32 = (($30) - ($31))|0;
  $33 = (($32>>>0) / 12)&-1;
  $34 = $33 ^ -1;
  $scevgep5$i$i$i = (($28) + (($34*12)|0)|0);
  HEAP32[$2>>2] = $scevgep5$i$i$i;
 }
 __ZdlPv($26);
 ___resumeException($24|0);
 // unreachable;
}
function __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE8__appendEjRKS2_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$i = 0, $$0$i18 = 0, $$in = 0, $$sroa$15$0 = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) - ($6))|0;
 $8 = (($7|0) / 12)&-1;
 $9 = ($8>>>0)<($1>>>0);
 if (!($9)) {
  $10 = $6;
  $$0$i = $1;$11 = $10;
  while(1) {
   ;HEAP32[$11>>2]=HEAP32[$2>>2]|0;HEAP32[$11+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$11+8>>2]=HEAP32[$2+8>>2]|0;
   $12 = HEAP32[$5>>2]|0;
   $13 = ((($12)) + 12|0);
   HEAP32[$5>>2] = $13;
   $14 = (($$0$i) + -1)|0;
   $15 = ($14|0)==(0);
   if ($15) {
    break;
   } else {
    $$0$i = $14;$11 = $13;
   }
  }
  return;
 }
 $16 = HEAP32[$0>>2]|0;
 $17 = (($6) - ($16))|0;
 $18 = (($17|0) / 12)&-1;
 $19 = (($18) + ($1))|0;
 $20 = ($19>>>0)>(357913941);
 if ($20) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $21 = (($4) - ($16))|0;
 $22 = (($21|0) / 12)&-1;
 $23 = ($22>>>0)<(178956970);
 $24 = $22 << 1;
 $25 = ($24>>>0)<($19>>>0);
 $$sroa$speculated$i = $25 ? $19 : $24;
 $$sroa$speculated$$i = $23 ? $$sroa$speculated$i : 357913941;
 $26 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($26) {
   $36 = 0;
  } else {
   $27 = ($$sroa$speculated$$i>>>0)>(357913941);
   if (!($27)) {
    $33 = ($$sroa$speculated$$i*12)|0;
    $34 = (__Znwj($33)|0);
    $36 = $34;
    break;
   }
   $28 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($28|0),(204840|0));
   $29 = __THREW__; __THREW__ = 0;
   $30 = $29&1;
   if ($30) {
    $31 = ___cxa_find_matching_catch_2()|0;
    $32 = tempRet0;
    ___cxa_free_exception(($28|0));
    ___resumeException($31|0);
    // unreachable;
   } else {
    HEAP32[$28>>2] = (99824);
    ___cxa_throw(($28|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $35 = (($36) + (($18*12)|0)|0);
 $37 = $35;
 $38 = (($36) + (($$sroa$speculated$$i*12)|0)|0);
 $$0$i18 = $1;$$in = $35;$$sroa$15$0 = $37;
 while(1) {
  ;HEAP32[$$in>>2]=HEAP32[$2>>2]|0;HEAP32[$$in+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$$in+8>>2]=HEAP32[$2+8>>2]|0;
  $39 = $$sroa$15$0;
  $40 = ((($39)) + 12|0);
  $41 = $40;
  $42 = (($$0$i18) + -1)|0;
  $43 = ($42|0)==(0);
  if ($43) {
   break;
  } else {
   $$0$i18 = $42;$$in = $40;$$sroa$15$0 = $41;
  }
 }
 $44 = $38;
 $45 = HEAP32[$0>>2]|0;
 $46 = HEAP32[$5>>2]|0;
 $47 = $45;
 $48 = (($46) - ($47))|0;
 $49 = (($48|0) / -12)&-1;
 $50 = (($35) + (($49*12)|0)|0);
 $51 = $50;
 $52 = ($48|0)>(0);
 if ($52) {
  _memcpy(($50|0),($45|0),($48|0))|0;
 }
 HEAP32[$0>>2] = $51;
 HEAP32[$5>>2] = $41;
 HEAP32[$3>>2] = $44;
 $53 = ($45|0)==(0|0);
 if ($53) {
  return;
 }
 __ZdlPv($45);
 return;
}
function __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE7reserveEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = (($5|0) / 12)&-1;
 $7 = ($6>>>0)<($1>>>0);
 if (!($7)) {
  return;
 }
 $8 = ((($0)) + 4|0);
 $9 = ($1>>>0)>(357913941);
 if ($9) {
  $10 = (___cxa_allocate_exception(8)|0);
  __THREW__ = 0;
  invoke_vii(3366,($10|0),(204840|0));
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if ($12) {
   $13 = ___cxa_find_matching_catch_2()|0;
   $14 = tempRet0;
   ___cxa_free_exception(($10|0));
   ___resumeException($13|0);
   // unreachable;
  } else {
   HEAP32[$10>>2] = (99824);
   ___cxa_throw(($10|0),(34608|0),(3230|0));
   // unreachable;
  }
 }
 $15 = HEAP32[$8>>2]|0;
 $16 = (($15) - ($4))|0;
 $17 = (($16|0) / 12)&-1;
 $18 = ($1*12)|0;
 $19 = (__Znwj($18)|0);
 $20 = (($19) + (($17*12)|0)|0);
 $21 = $20;
 $22 = (($19) + (($1*12)|0)|0);
 $23 = $22;
 $24 = (($16|0) / -12)&-1;
 $25 = (($20) + (($24*12)|0)|0);
 $26 = $25;
 $27 = ($16|0)>(0);
 if ($27) {
  $28 = $4;
  _memcpy(($25|0),($28|0),($16|0))|0;
 }
 HEAP32[$0>>2] = $26;
 HEAP32[$8>>2] = $21;
 HEAP32[$2>>2] = $23;
 $29 = ($4|0)==(0);
 if ($29) {
  return;
 }
 $30 = $4;
 __ZdlPv($30);
 return;
}
function __ZN3osg13TemplateArrayINS_5Vec3fELNS_5Array4TypeE28ELi3ELi5126EEC2ERKS4_RKNS_6CopyOpE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg6ObjectC2ERKS0_RKNS_6CopyOpE($0,$1,$2);
 HEAP32[$0>>2] = (55116);
 $3 = ((($0)) + 32|0);
 HEAP32[$3>>2] = 0;
 $4 = ((($0)) + 36|0);
 HEAP32[$4>>2] = 0;
 $5 = ((($0)) + 40|0);
 HEAP32[$5>>2] = 0;
 $6 = ((($0)) + 44|0);
 $7 = ((($1)) + 44|0);
 $8 = HEAP32[$7>>2]|0;
 HEAP32[$6>>2] = $8;
 $9 = ($8|0)==(0|0);
 if (!($9)) {
  $10 = HEAP32[$8>>2]|0;
  $11 = ((($10)) + -12|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($8) + ($12)|0);
  $14 = ((($13)) + 8|0);
  $15 = HEAP32[$14>>2]|0;HEAP32[$14>>2] = (($15+1)|0);
 }
 $16 = ((($0)) + 48|0);
 HEAP32[$16>>2] = 0;
 HEAP32[$0>>2] = (54500);
 $17 = ((($0)) + 52|0);
 $18 = ((($1)) + 52|0);
 $19 = HEAP32[$18>>2]|0;
 HEAP32[$17>>2] = $19;
 $20 = ((($0)) + 56|0);
 $21 = ((($1)) + 56|0);
 $22 = HEAP32[$21>>2]|0;
 HEAP32[$20>>2] = $22;
 $23 = ((($0)) + 60|0);
 $24 = ((($1)) + 60|0);
 $25 = HEAP32[$24>>2]|0;
 HEAP32[$23>>2] = $25;
 $26 = ((($0)) + 64|0);
 $27 = ((($1)) + 64|0);
 $28 = HEAP32[$27>>2]|0;
 HEAP32[$26>>2] = $28;
 $29 = ((($0)) + 68|0);
 $30 = ((($1)) + 68|0);
 $31 = HEAP8[$30>>0]|0;
 HEAP8[$29>>0] = $31;
 $32 = ((($0)) + 69|0);
 $33 = ((($1)) + 69|0);
 $34 = HEAP8[$33>>0]|0;
 HEAP8[$32>>0] = $34;
 $35 = ((($0)) + 72|0);
 HEAP32[$35>>2] = (38552);
 $36 = ((($0)) + 76|0);
 $37 = ((($1)) + 76|0);
 __THREW__ = 0;
 invoke_vii(3467,($36|0),($37|0));
 $38 = __THREW__; __THREW__ = 0;
 $39 = $38&1;
 if (!($39)) {
  HEAP32[$0>>2] = (37800);
  HEAP32[$35>>2] = (38024);
  return;
 }
 $40 = ___cxa_find_matching_catch_2()|0;
 $41 = tempRet0;
 __THREW__ = 0;
 invoke_vi(1265,($0|0));
 $42 = __THREW__; __THREW__ = 0;
 $43 = $42&1;
 if ($43) {
  $44 = ___cxa_find_matching_catch_3(0|0)|0;
  $45 = tempRet0;
  ___clang_call_terminate($44);
  // unreachable;
 } else {
  ___resumeException($40|0);
  // unreachable;
 }
}
function __ZN9osgViewer12SingleWindowD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(388,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK9osgViewer12SingleWindow9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(56)|0);
 __THREW__ = 0;
 invoke_vi(3282,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $14 = ___cxa_find_matching_catch_2()|0;
  $15 = tempRet0;
  __ZdlPv($1);
  ___resumeException($14|0);
  // unreachable;
 } else {
  $4 = ((($1)) + 12|0);
  ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;
  $5 = ((($1)) + 24|0);
  HEAP32[$5>>2] = 2;
  $6 = ((($1)) + 28|0);
  HEAP32[$6>>2] = 0;
  HEAP32[$1>>2] = (38568);
  $7 = ((($1)) + 32|0);
  HEAP32[$7>>2] = 0;
  $8 = ((($1)) + 36|0);
  HEAP32[$8>>2] = 0;
  $9 = ((($1)) + 40|0);
  HEAP32[$9>>2] = -1;
  $10 = ((($1)) + 44|0);
  HEAP32[$10>>2] = -1;
  $11 = ((($1)) + 48|0);
  HEAP32[$11>>2] = 0;
  $12 = ((($1)) + 52|0);
  HEAP8[$12>>0] = 1;
  $13 = ((($1)) + 53|0);
  HEAP8[$13>>0] = 0;
  return ($1|0);
 }
 return (0)|0;
}
function __ZNK9osgViewer12SingleWindow5cloneERKN3osg6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(56)|0);
 __THREW__ = 0;
 invoke_viii(3468,($2|0),($0|0),($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $26 = ___cxa_find_matching_catch_2()|0;
  $27 = tempRet0;
  __ZdlPv($2);
  ___resumeException($26|0);
  // unreachable;
 } else {
  HEAP32[$2>>2] = (38568);
  $5 = ((($2)) + 32|0);
  $6 = ((($0)) + 32|0);
  $7 = HEAP32[$6>>2]|0;
  HEAP32[$5>>2] = $7;
  $8 = ((($2)) + 36|0);
  $9 = ((($0)) + 36|0);
  $10 = HEAP32[$9>>2]|0;
  HEAP32[$8>>2] = $10;
  $11 = ((($2)) + 40|0);
  $12 = ((($0)) + 40|0);
  $13 = HEAP32[$12>>2]|0;
  HEAP32[$11>>2] = $13;
  $14 = ((($2)) + 44|0);
  $15 = ((($0)) + 44|0);
  $16 = HEAP32[$15>>2]|0;
  HEAP32[$14>>2] = $16;
  $17 = ((($2)) + 48|0);
  $18 = ((($0)) + 48|0);
  $19 = HEAP32[$18>>2]|0;
  HEAP32[$17>>2] = $19;
  $20 = ((($2)) + 52|0);
  $21 = ((($0)) + 52|0);
  $22 = HEAP8[$21>>0]|0;
  HEAP8[$20>>0] = $22;
  $23 = ((($2)) + 53|0);
  $24 = ((($0)) + 53|0);
  $25 = HEAP8[$24>>0]|0;
  HEAP8[$23>>0] = $25;
  return ($2|0);
 }
 return (0)|0;
}
function __ZNK9osgViewer12SingleWindow12isSameKindAsEPKN3osg6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,5536,0)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK9osgViewer12SingleWindow11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (107921|0);
}
function __ZNK9osgViewer12SingleWindow9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (107321|0);
}
function __ZNK9osgViewer12SingleWindow9configureERNS_4ViewE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$10 = 0, $$1059 = 0, $$12 = 0, $$1261 = 0, $$3 = 0, $$352 = 0, $$6 = 0, $$655 = 0, $$8 = 0, $$857 = 0, $$pre$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0;
 var $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0;
 var $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0;
 var $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0;
 var $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0;
 var $234 = 0, $235 = 0, $236 = 0, $237 = 0.0, $238 = 0, $239 = 0.0, $24 = 0, $240 = 0.0, $241 = 0.0, $242 = 0.0, $243 = 0, $244 = 0, $245 = 0, $246 = 0.0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0;
 var $252 = 0.0, $253 = 0, $254 = 0.0, $255 = 0, $256 = 0, $257 = 0.0, $258 = 0, $259 = 0, $26 = 0, $260 = 0.0, $261 = 0, $262 = 0, $263 = 0.0, $264 = 0, $265 = 0, $266 = 0.0, $267 = 0, $268 = 0, $269 = 0.0, $27 = 0;
 var $270 = 0, $271 = 0, $272 = 0.0, $273 = 0, $274 = 0, $275 = 0.0, $276 = 0, $277 = 0, $278 = 0.0, $279 = 0, $28 = 0, $280 = 0, $281 = 0.0, $282 = 0, $283 = 0, $284 = 0.0, $285 = 0, $286 = 0, $287 = 0.0, $288 = 0;
 var $289 = 0, $29 = 0, $290 = 0.0, $291 = 0, $292 = 0, $293 = 0.0, $294 = 0, $295 = 0, $296 = 0.0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0;
 var $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0.0, $319 = 0.0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0;
 var $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0;
 var $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0;
 var $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0;
 var $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0;
 var $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0;
 var $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$sink146$index12Z2D = 0;
 var $eh$lpad$body$sink146$indexZ2D = 0, $eh$lpad$body92$index5Z2D = 0, $eh$lpad$body92$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 368|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(368|0);
 $2 = sp + 356|0;
 $3 = sp + 352|0;
 $4 = sp + 184|0;
 $5 = sp + 160|0;
 $6 = sp + 348|0;
 $7 = sp + 336|0;
 $8 = sp + 316|0;
 $9 = sp + 152|0;
 $10 = sp + 144|0;
 $11 = sp + 136|0;
 $12 = sp + 128|0;
 $13 = sp;
 $14 = sp + 312|0;
 $15 = ((($7)) + 11|0);
 ;HEAP32[$7>>2]=0|0;HEAP32[$7+4>>2]=0|0;HEAP32[$7+8>>2]=0|0;
 __THREW__ = 0;
 $16 = (invoke_ii(3376,($7|0))|0);
 $17 = __THREW__; __THREW__ = 0;
 $18 = $17&1;
 if ($18) {
  $45 = ___cxa_find_matching_catch_2()|0;
  $46 = tempRet0;
  $47 = HEAP8[$15>>0]|0;
  $48 = ($47<<24>>24)<(0);
  if ($48) {
   $49 = HEAP32[$7>>2]|0;
   __ZdlPv($49);
  }
  $$12 = $45;$$1261 = $46;
  ___resumeException($$12|0);
  // unreachable;
 }
 $19 = HEAP8[$15>>0]|0;
 $20 = ($19<<24>>24)<(0);
 if ($20) {
  $21 = HEAP32[$7>>2]|0;
  __ZdlPv($21);
 }
 $22 = ($16|0)==(0|0);
 if ($22) {
  $23 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
  if (!($23)) {
   STACKTOP = sp;return;
  }
  $24 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
  $25 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($24,107149,93)|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = ((($26)) + -12|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (($25) + ($28)|0);
  __ZNKSt3__28ios_base6getlocEv($6,$29);
  __THREW__ = 0;
  $30 = (invoke_iii(3255,($6|0),(215188|0))|0);
  $31 = __THREW__; __THREW__ = 0;
  $32 = $31&1;
  if (!($32)) {
   $33 = HEAP32[$30>>2]|0;
   $34 = ((($33)) + 28|0);
   $35 = HEAP32[$34>>2]|0;
   __THREW__ = 0;
   $36 = (invoke_iii($35|0,($30|0),10)|0);
   $37 = __THREW__; __THREW__ = 0;
   $38 = $37&1;
   if (!($38)) {
    __ZNSt3__26localeD2Ev($6);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($25,$36)|0);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($25)|0);
    STACKTOP = sp;return;
   }
  }
  $39 = ___cxa_find_matching_catch_2()|0;
  $40 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3263,($6|0));
  $41 = __THREW__; __THREW__ = 0;
  $42 = $41&1;
  if ($42) {
   $43 = ___cxa_find_matching_catch_3(0|0)|0;
   $44 = tempRet0;
   ___clang_call_terminate($43);
   // unreachable;
  } else {
   ___resumeException($39|0);
   // unreachable;
  }
 }
 $50 = HEAP32[$0>>2]|0;
 $51 = ((($50)) + 144|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = (FUNCTION_TABLE_iii[$52 & 8191]($0,$1)|0);
 $54 = (__Znwj(200)|0);
 __THREW__ = 0;
 invoke_vii(3419,($54|0),($53|0));
 $55 = __THREW__; __THREW__ = 0;
 $56 = $55&1;
 if ($56) {
  $65 = ___cxa_find_matching_catch_2()|0;
  $66 = tempRet0;
  __ZdlPv($54);
  $$12 = $65;$$1261 = $66;
  ___resumeException($$12|0);
  // unreachable;
 }
 $57 = ((($54)) + 8|0);
 $58 = HEAP32[$57>>2]|0;HEAP32[$57>>2] = (($58+1)|0);
 $59 = ((($54)) + 12|0);
 __THREW__ = 0;
 invoke_vi(3469,($59|0));
 $60 = __THREW__; __THREW__ = 0;
 $61 = $60&1;
 L29: do {
  if ($61) {
   label = 20;
  } else {
   $62 = ((($54)) + 24|0);
   $63 = HEAP32[$62>>2]|0;
   $64 = ($63|0)<(0);
   if ($64) {
    HEAP32[$62>>2] = 0;
   }
   $69 = ((($0)) + 48|0);
   $70 = HEAP32[$69>>2]|0;
   $71 = ((($54)) + 28|0);
   HEAP32[$71>>2] = $70;
   $72 = ((($0)) + 32|0);
   $73 = HEAP32[$72>>2]|0;
   $74 = ((($54)) + 32|0);
   HEAP32[$74>>2] = $73;
   $75 = ((($0)) + 36|0);
   $76 = HEAP32[$75>>2]|0;
   $77 = ((($54)) + 36|0);
   HEAP32[$77>>2] = $76;
   $78 = ((($0)) + 40|0);
   $79 = HEAP32[$78>>2]|0;
   $80 = ((($54)) + 40|0);
   HEAP32[$80>>2] = $79;
   $81 = ((($0)) + 44|0);
   $82 = HEAP32[$81>>2]|0;
   $83 = ((($54)) + 44|0);
   HEAP32[$83>>2] = $82;
   $84 = ((($0)) + 52|0);
   $85 = HEAP8[$84>>0]|0;
   $86 = ((($54)) + 72|0);
   HEAP8[$86>>0] = $85;
   $87 = ((($0)) + 53|0);
   $88 = HEAP8[$87>>0]|0;
   $89 = ((($54)) + 181|0);
   HEAP8[$89>>0] = $88;
   $90 = ((($54)) + 110|0);
   HEAP8[$90>>0] = 1;
   $91 = ((($54)) + 168|0);
   $92 = HEAP32[$91>>2]|0;
   $93 = ($92|0)==(0|0);
   if (!($93)) {
    HEAP32[$91>>2] = 0;
    $94 = ((($92)) + 8|0);
    $95 = HEAP32[$94>>2]|0;HEAP32[$94>>2] = (($95-1)|0);
    $96 = ($95|0)==(1);
    if ($96) {
     __THREW__ = 0;
     invoke_viii(3262,($92|0),1,1);
     $97 = __THREW__; __THREW__ = 0;
     $98 = $97&1;
     if ($98) {
      label = 20;
      break;
     }
    }
   }
   $99 = ((($54)) + 172|0);
   HEAP32[$99>>2] = 0;
   $100 = HEAP32[$80>>2]|0;
   $101 = ($100|0)<(1);
   if ($101) {
    label = 26;
   } else {
    $102 = HEAP32[$83>>2]|0;
    $103 = ($102|0)<(1);
    if ($103) {
     label = 26;
    }
   }
   do {
    if ((label|0) == 26) {
     __THREW__ = 0;
     invoke_vi(3470,($8|0));
     $104 = __THREW__; __THREW__ = 0;
     $105 = $104&1;
     if ($105) {
      label = 20;
      break L29;
     }
     __THREW__ = 0;
     invoke_vi(3469,($8|0));
     $106 = __THREW__; __THREW__ = 0;
     $107 = $106&1;
     if (!($107)) {
      $108 = ((($8)) + 12|0);
      $109 = HEAP32[$108>>2]|0;
      $110 = ($109|0)<(0);
      if ($110) {
       HEAP32[$108>>2] = 0;
      }
      $111 = HEAP32[$69>>2]|0;
      $112 = ((($8)) + 16|0);
      HEAP32[$112>>2] = $111;
      ;HEAP32[$5>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;HEAP32[$5+12>>2]=0|0;HEAP32[$5+16>>2]=0|0;
      $113 = HEAP32[$16>>2]|0;
      $114 = ((($113)) + 16|0);
      $115 = HEAP32[$114>>2]|0;
      __THREW__ = 0;
      invoke_viii($115|0,($16|0),($8|0),($5|0));
      $116 = __THREW__; __THREW__ = 0;
      $117 = $116&1;
      if (!($117)) {
       $118 = HEAP32[$5>>2]|0;
       $119 = ((($5)) + 4|0);
       $120 = HEAP32[$119>>2]|0;
       $121 = HEAP32[$80>>2]|0;
       $122 = ($121|0)<(1);
       if ($122) {
        HEAP32[$80>>2] = $118;
       }
       $123 = HEAP32[$83>>2]|0;
       $124 = ($123|0)<(1);
       if ($124) {
        HEAP32[$83>>2] = $120;
       }
       $125 = ((($8)) + 11|0);
       $126 = HEAP8[$125>>0]|0;
       $127 = ($126<<24>>24)<(0);
       if ($127) {
        $128 = HEAP32[$8>>2]|0;
        __ZdlPv($128);
       }
       break;
      }
     }
     $129 = ___cxa_find_matching_catch_2()|0;
     $130 = tempRet0;
     $131 = ((($8)) + 11|0);
     $132 = HEAP8[$131>>0]|0;
     $133 = ($132<<24>>24)<(0);
     if ($133) {
      $134 = HEAP32[$8>>2]|0;
      __ZdlPv($134);
     }
     $$10 = $129;$$1059 = $130;
     break L29;
    }
   } while(0);
   __THREW__ = 0;
   $135 = (invoke_ii(3471,($54|0))|0);
   $136 = __THREW__; __THREW__ = 0;
   $137 = $136&1;
   if ($137) {
    label = 20;
   } else {
    $138 = ($135|0)==(0|0);
    if (!($138)) {
     $139 = ((($135)) + 8|0);
     $140 = HEAP32[$139>>2]|0;HEAP32[$139>>2] = (($140+1)|0);
    }
    $141 = ((($1)) + 16|0);
    $142 = HEAP32[$141>>2]|0;
    __THREW__ = 0;
    invoke_vii(3338,($142|0),($135|0));
    $143 = __THREW__; __THREW__ = 0;
    $144 = $143&1;
    L67: do {
     if ($144) {
      $145 = ___cxa_find_matching_catch_2()|0;
      $146 = tempRet0;
      $$8 = $145;$$857 = $146;
     } else {
      L70: do {
       if ($138) {
        label = 64;
       } else {
        $147 = (___dynamic_cast($135,24816,3888,0)|0);
        $148 = ($147|0)==(0|0);
        if ($148) {
         label = 64;
        } else {
         __THREW__ = 0;
         $149 = (invoke_ii(3265,4)|0);
         $150 = __THREW__; __THREW__ = 0;
         $151 = $150&1;
         if ($151) {
          label = 61;
         } else {
          L74: do {
           if ($149) {
            __THREW__ = 0;
            $152 = (invoke_ii(3266,4)|0);
            $153 = __THREW__; __THREW__ = 0;
            $154 = $153&1;
            if ($154) {
             label = 61;
             break L70;
            }
            __THREW__ = 0;
            $155 = (invoke_iiii(3267,($152|0),(107243|0),77)|0);
            $156 = __THREW__; __THREW__ = 0;
            $157 = $156&1;
            if ($157) {
             label = 61;
             break L70;
            }
            $158 = HEAP32[$155>>2]|0;
            $159 = ((($158)) + -12|0);
            $160 = HEAP32[$159>>2]|0;
            $161 = (($155) + ($160)|0);
            __THREW__ = 0;
            invoke_vii(3257,($3|0),($161|0));
            $162 = __THREW__; __THREW__ = 0;
            $163 = $162&1;
            if ($163) {
             label = 61;
             break L70;
            }
            __THREW__ = 0;
            $164 = (invoke_iii(3255,($3|0),(215188|0))|0);
            $165 = __THREW__; __THREW__ = 0;
            $166 = $165&1;
            do {
             if (!($166)) {
              $167 = HEAP32[$164>>2]|0;
              $168 = ((($167)) + 28|0);
              $169 = HEAP32[$168>>2]|0;
              __THREW__ = 0;
              $170 = (invoke_iii($169|0,($164|0),10)|0);
              $171 = __THREW__; __THREW__ = 0;
              $172 = $171&1;
              if ($172) {
               break;
              }
              __THREW__ = 0;
              invoke_vi(3263,($3|0));
              $173 = __THREW__; __THREW__ = 0;
              $174 = $173&1;
              if ($174) {
               label = 61;
               break L70;
              }
              __THREW__ = 0;
              (invoke_iii(3268,($155|0),($170|0))|0);
              $181 = __THREW__; __THREW__ = 0;
              $182 = $181&1;
              if ($182) {
               label = 61;
               break L70;
              }
              __THREW__ = 0;
              (invoke_ii(3269,($155|0))|0);
              $183 = __THREW__; __THREW__ = 0;
              $184 = $183&1;
              if ($184) {
               label = 61;
               break L70;
              } else {
               break L74;
              }
             }
            } while(0);
            $175 = ___cxa_find_matching_catch_2()|0;
            $176 = tempRet0;
            __THREW__ = 0;
            invoke_vi(3263,($3|0));
            $177 = __THREW__; __THREW__ = 0;
            $178 = $177&1;
            if ($178) {
             $179 = ___cxa_find_matching_catch_3(0|0)|0;
             $180 = tempRet0;
             ___clang_call_terminate($179);
             // unreachable;
            } else {
             $eh$lpad$body92$index5Z2D = $176;$eh$lpad$body92$indexZ2D = $175;
             break L70;
            }
           }
          } while(0);
          $187 = ((($147)) + 136|0);
          $188 = HEAP32[$187>>2]|0;
          $189 = ((($188)) + 12|0);
          $190 = HEAP32[$189>>2]|0;
          $191 = HEAP32[$74>>2]|0;
          $192 = HEAP32[$77>>2]|0;
          $193 = HEAP32[$80>>2]|0;
          $194 = HEAP32[$83>>2]|0;
          __THREW__ = 0;
          invoke_viiiiii(3472,($190|0),($191|0),($192|0),($193|0),($194|0),1);
          $195 = __THREW__; __THREW__ = 0;
          $196 = $195&1;
          if ($196) {
           label = 61;
          } else {
           $233 = HEAP32[$141>>2]|0;
           __THREW__ = 0;
           (invoke_iiiiii(3473,($233|0),($9|0),($10|0),($11|0),($12|0))|0);
           $234 = __THREW__; __THREW__ = 0;
           $235 = $234&1;
           L90: do {
            if ($235) {
             $304 = ___cxa_find_matching_catch_2()|0;
             $305 = tempRet0;
             $$6 = $304;$$655 = $305;
            } else {
             $236 = HEAP32[$80>>2]|0;
             $237 = (+($236|0));
             $238 = HEAP32[$83>>2]|0;
             $239 = (+($238|0));
             $240 = $237 / $239;
             $241 = +HEAPF64[$10>>3];
             $242 = $240 / $241;
             $243 = $242 != 1.0;
             L93: do {
              if ($243) {
               __THREW__ = 0;
               invoke_vi(3299,($13|0));
               $244 = __THREW__; __THREW__ = 0;
               $245 = $244&1;
               L95: do {
                if ($245) {
                 label = 88;
                } else {
                 $246 = 1.0 / $242;
                 __THREW__ = 0;
                 invoke_viddd(3305,($13|0),(+$246),1.0,1.0);
                 $247 = __THREW__; __THREW__ = 0;
                 $248 = $247&1;
                 if ($248) {
                  label = 88;
                  break;
                 }
                 $249 = HEAP32[$141>>2]|0;
                 $250 = ((($249)) + 304|0);
                 $251 = ($250|0)==($13|0);
                 do {
                  if ($251) {
                   $252 = +HEAPF64[$13>>3];
                   HEAPF64[$4>>3] = $252;
                   $253 = ((($249)) + 312|0);
                   $254 = +HEAPF64[$253>>3];
                   $255 = ((($4)) + 8|0);
                   HEAPF64[$255>>3] = $254;
                   $256 = ((($249)) + 320|0);
                   $257 = +HEAPF64[$256>>3];
                   $258 = ((($4)) + 16|0);
                   HEAPF64[$258>>3] = $257;
                   $259 = ((($249)) + 328|0);
                   $260 = +HEAPF64[$259>>3];
                   $261 = ((($4)) + 24|0);
                   HEAPF64[$261>>3] = $260;
                   $262 = ((($249)) + 336|0);
                   $263 = +HEAPF64[$262>>3];
                   $264 = ((($4)) + 32|0);
                   HEAPF64[$264>>3] = $263;
                   $265 = ((($249)) + 344|0);
                   $266 = +HEAPF64[$265>>3];
                   $267 = ((($4)) + 40|0);
                   HEAPF64[$267>>3] = $266;
                   $268 = ((($249)) + 352|0);
                   $269 = +HEAPF64[$268>>3];
                   $270 = ((($4)) + 48|0);
                   HEAPF64[$270>>3] = $269;
                   $271 = ((($249)) + 360|0);
                   $272 = +HEAPF64[$271>>3];
                   $273 = ((($4)) + 56|0);
                   HEAPF64[$273>>3] = $272;
                   $274 = ((($249)) + 368|0);
                   $275 = +HEAPF64[$274>>3];
                   $276 = ((($4)) + 64|0);
                   HEAPF64[$276>>3] = $275;
                   $277 = ((($249)) + 376|0);
                   $278 = +HEAPF64[$277>>3];
                   $279 = ((($4)) + 72|0);
                   HEAPF64[$279>>3] = $278;
                   $280 = ((($249)) + 384|0);
                   $281 = +HEAPF64[$280>>3];
                   $282 = ((($4)) + 80|0);
                   HEAPF64[$282>>3] = $281;
                   $283 = ((($249)) + 392|0);
                   $284 = +HEAPF64[$283>>3];
                   $285 = ((($4)) + 88|0);
                   HEAPF64[$285>>3] = $284;
                   $286 = ((($249)) + 400|0);
                   $287 = +HEAPF64[$286>>3];
                   $288 = ((($4)) + 96|0);
                   HEAPF64[$288>>3] = $287;
                   $289 = ((($249)) + 408|0);
                   $290 = +HEAPF64[$289>>3];
                   $291 = ((($4)) + 104|0);
                   HEAPF64[$291>>3] = $290;
                   $292 = ((($249)) + 416|0);
                   $293 = +HEAPF64[$292>>3];
                   $294 = ((($4)) + 112|0);
                   HEAPF64[$294>>3] = $293;
                   $295 = ((($249)) + 424|0);
                   $296 = +HEAPF64[$295>>3];
                   $297 = ((($4)) + 120|0);
                   HEAPF64[$297>>3] = $296;
                   __THREW__ = 0;
                   invoke_vii(3302,($13|0),($4|0));
                   $298 = __THREW__; __THREW__ = 0;
                   $299 = $298&1;
                   if ($299) {
                    $300 = ___cxa_find_matching_catch_2()|0;
                    $301 = tempRet0;
                    $eh$lpad$body$sink146$index12Z2D = $301;$eh$lpad$body$sink146$indexZ2D = $300;
                    break L95;
                   } else {
                    break;
                   }
                  } else {
                   __THREW__ = 0;
                   invoke_vii(3302,($250|0),($13|0));
                   $302 = __THREW__; __THREW__ = 0;
                   $303 = $302&1;
                   if (!($303)) {
                    break;
                   }
                   $308 = ___cxa_find_matching_catch_2()|0;
                   $309 = tempRet0;
                   $eh$lpad$body$sink146$index12Z2D = $309;$eh$lpad$body$sink146$indexZ2D = $308;
                   break L95;
                  }
                 } while(0);
                 break L93;
                }
               } while(0);
               if ((label|0) == 88) {
                $306 = ___cxa_find_matching_catch_2()|0;
                $307 = tempRet0;
                $eh$lpad$body$sink146$index12Z2D = $307;$eh$lpad$body$sink146$indexZ2D = $306;
               }
               $$6 = $eh$lpad$body$sink146$indexZ2D;$$655 = $eh$lpad$body$sink146$index12Z2D;
               break L90;
              }
             } while(0);
             $310 = HEAP32[$141>>2]|0;
             __THREW__ = 0;
             $311 = (invoke_ii(3276,88)|0);
             $312 = __THREW__; __THREW__ = 0;
             $313 = $312&1;
             do {
              if (!($313)) {
               $314 = HEAP32[$80>>2]|0;
               $315 = HEAP32[$83>>2]|0;
               __THREW__ = 0;
               invoke_vi(3339,($311|0));
               $316 = __THREW__; __THREW__ = 0;
               $317 = $316&1;
               if ($317) {
                $351 = ___cxa_find_matching_catch_2()|0;
                $352 = tempRet0;
                __ZdlPv($311);
                $$6 = $351;$$655 = $352;
                break L90;
               }
               $318 = (+($315|0));
               $319 = (+($314|0));
               HEAP32[$311>>2] = (70172);
               $320 = ((($311)) + 56|0);
               $321 = ((($311)) + 72|0);
               ;HEAP32[$320>>2]=0|0;HEAP32[$320+4>>2]=0|0;HEAP32[$320+8>>2]=0|0;HEAP32[$320+12>>2]=0|0;
               HEAPF64[$321>>3] = $319;
               $322 = ((($311)) + 80|0);
               HEAPF64[$322>>3] = $318;
               __THREW__ = 0;
               invoke_vii(3340,($310|0),($311|0));
               $323 = __THREW__; __THREW__ = 0;
               $324 = $323&1;
               if ($324) {
                break;
               }
               $325 = HEAP8[$90>>0]|0;
               $326 = ($325<<24>>24)!=(0);
               $327 = $326 ? 1029 : 1028;
               $328 = HEAP32[$141>>2]|0;
               $329 = ((($328)) + 568|0);
               HEAP32[$329>>2] = $327;
               $330 = ((($328)) + 152|0);
               $331 = HEAP32[$330>>2]|0;
               $332 = ($331|0)==(0);
               $333 = ((($328)) + 148|0);
               if ($332) {
                $335 = HEAP32[$333>>2]|0;
                $336 = $335 & -131073;
                HEAP32[$333>>2] = $336;
                $337 = ((($328)) + 572|0);
                HEAP32[$337>>2] = $327;
                $338 = $335 & -393217;
                HEAP32[$333>>2] = $338;
               } else {
                $334 = ((($328)) + 572|0);
                HEAP32[$334>>2] = $327;
               }
               $339 = ((($53)) + 168|0);
               $340 = HEAP8[$339>>0]|0;
               $341 = ($340<<24>>24)==(0);
               do {
                if ($341) {
                 $402 = ((($53)) + 16|0);
                 $403 = HEAP8[$402>>0]|0;
                 $404 = ($403<<24>>24)==(0);
                 if ($404) {
                  label = 126;
                  break;
                 }
                 $405 = ((($53)) + 94|0);
                 $406 = HEAP8[$405>>0]|0;
                 $407 = ($406<<24>>24)==(0);
                 if ($407) {
                  label = 126;
                  break;
                 }
                 __THREW__ = 0;
                 invoke_viii(3476,($1|0),($328|0),($53|0));
                 $408 = __THREW__; __THREW__ = 0;
                 $409 = $408&1;
                 if ($409) {
                  label = 102;
                 } else {
                  label = 126;
                 }
                } else {
                 $342 = ((($53)) + 172|0);
                 $343 = HEAP32[$342>>2]|0;
                 $344 = ((($53)) + 176|0);
                 $345 = HEAP32[$344>>2]|0;
                 $346 = ($343|0)==($345|0);
                 if (!($346)) {
                  __THREW__ = 0;
                  (invoke_ii(3474,($53|0))|0);
                  $347 = __THREW__; __THREW__ = 0;
                  $348 = $347&1;
                  if ($348) {
                   label = 102;
                   break;
                  }
                 }
                 $355 = ((($53)) + 184|0);
                 $356 = HEAP32[$355>>2]|0;
                 $357 = ((($53)) + 188|0);
                 $358 = HEAP32[$357>>2]|0;
                 $359 = ($356|0)==($358|0);
                 L128: do {
                  if ($359) {
                   __THREW__ = 0;
                   $360 = (invoke_ii(3276,120)|0);
                   $361 = __THREW__; __THREW__ = 0;
                   $362 = $361&1;
                   L130: do {
                    if ($362) {
                     label = 115;
                    } else {
                     __THREW__ = 0;
                     invoke_vi(3349,($360|0));
                     $363 = __THREW__; __THREW__ = 0;
                     $364 = $363&1;
                     if ($364) {
                      $388 = ___cxa_find_matching_catch_2()|0;
                      $389 = tempRet0;
                      __ZdlPv($360);
                      $$3 = $388;$$352 = $389;
                      break;
                     }
                     HEAP32[$14>>2] = $360;
                     $365 = ((($360)) + 8|0);
                     $366 = HEAP32[$365>>2]|0;HEAP32[$365>>2] = (($366+1)|0);
                     $367 = HEAP32[$357>>2]|0;
                     $368 = ((($53)) + 192|0);
                     $369 = HEAP32[$368>>2]|0;
                     $370 = ($367|0)==($369|0);
                     do {
                      if ($370) {
                       __THREW__ = 0;
                       invoke_vii(3475,($355|0),($14|0));
                       $377 = __THREW__; __THREW__ = 0;
                       $378 = $377&1;
                       if (!($378)) {
                        break;
                       }
                       $390 = ___cxa_find_matching_catch_2()|0;
                       $391 = tempRet0;
                       $392 = HEAP32[$14>>2]|0;
                       $393 = ($392|0)==(0|0);
                       do {
                        if (!($393)) {
                         $394 = ((($392)) + 8|0);
                         $395 = HEAP32[$394>>2]|0;HEAP32[$394>>2] = (($395-1)|0);
                         $396 = ($395|0)==(1);
                         if (!($396)) {
                          break;
                         }
                         __THREW__ = 0;
                         invoke_viii(3262,($392|0),1,1);
                         $397 = __THREW__; __THREW__ = 0;
                         $398 = $397&1;
                         if (!($398)) {
                          break;
                         }
                         $428 = ___cxa_find_matching_catch_3(0|0)|0;
                         $429 = tempRet0;
                         ___clang_call_terminate($428);
                         // unreachable;
                        }
                       } while(0);
                       HEAP32[$14>>2] = 0;
                       $$3 = $390;$$352 = $391;
                       break L130;
                      } else {
                       $371 = HEAP32[$14>>2]|0;
                       HEAP32[$367>>2] = $371;
                       $372 = ($371|0)==(0|0);
                       if ($372) {
                        $376 = $367;
                       } else {
                        $373 = ((($371)) + 8|0);
                        $374 = HEAP32[$373>>2]|0;HEAP32[$373>>2] = (($374+1)|0);
                        $$pre$i = HEAP32[$357>>2]|0;
                        $376 = $$pre$i;
                       }
                       $375 = ((($376)) + 4|0);
                       HEAP32[$357>>2] = $375;
                      }
                     } while(0);
                     $379 = HEAP32[$14>>2]|0;
                     $380 = ($379|0)==(0|0);
                     do {
                      if (!($380)) {
                       $381 = ((($379)) + 8|0);
                       $382 = HEAP32[$381>>2]|0;HEAP32[$381>>2] = (($382-1)|0);
                       $383 = ($382|0)==(1);
                       if (!($383)) {
                        break;
                       }
                       __THREW__ = 0;
                       invoke_viii(3262,($379|0),1,1);
                       $384 = __THREW__; __THREW__ = 0;
                       $385 = $384&1;
                       if ($385) {
                        label = 115;
                        break L130;
                       }
                      }
                     } while(0);
                     break L128;
                    }
                   } while(0);
                   if ((label|0) == 115) {
                    $386 = ___cxa_find_matching_catch_2()|0;
                    $387 = tempRet0;
                    $$3 = $386;$$352 = $387;
                   }
                   $$6 = $$3;$$655 = $$352;
                   break L90;
                  }
                 } while(0);
                 $399 = HEAP32[$141>>2]|0;
                 __THREW__ = 0;
                 invoke_viii(3476,($1|0),($399|0),($53|0));
                 $400 = __THREW__; __THREW__ = 0;
                 $401 = $400&1;
                 if ($401) {
                  label = 102;
                 } else {
                  label = 126;
                 }
                }
               } while(0);
               if ((label|0) == 102) {
                $353 = ___cxa_find_matching_catch_2()|0;
                $354 = tempRet0;
                $$6 = $353;$$655 = $354;
                break L90;
               }
               else if ((label|0) == 126) {
                label = 127;
                break L70;
               }
              }
             } while(0);
             $349 = ___cxa_find_matching_catch_2()|0;
             $350 = tempRet0;
             $$6 = $349;$$655 = $350;
            }
           } while(0);
           $$8 = $$6;$$857 = $$655;
           break L67;
          }
         }
        }
       }
      } while(0);
      L161: do {
       if ((label|0) == 64) {
        __THREW__ = 0;
        $197 = (invoke_ii(3265,3)|0);
        $198 = __THREW__; __THREW__ = 0;
        $199 = $198&1;
        if ($199) {
         label = 61;
        } else {
         if ($197) {
          __THREW__ = 0;
          $200 = (invoke_ii(3266,3)|0);
          $201 = __THREW__; __THREW__ = 0;
          $202 = $201&1;
          if ($202) {
           label = 61;
          } else {
           __THREW__ = 0;
           $203 = (invoke_iiii(3267,($200|0),(107547|0),51)|0);
           $204 = __THREW__; __THREW__ = 0;
           $205 = $204&1;
           if ($205) {
            label = 61;
           } else {
            $206 = HEAP32[$203>>2]|0;
            $207 = ((($206)) + -12|0);
            $208 = HEAP32[$207>>2]|0;
            $209 = (($203) + ($208)|0);
            __THREW__ = 0;
            invoke_vii(3257,($2|0),($209|0));
            $210 = __THREW__; __THREW__ = 0;
            $211 = $210&1;
            if ($211) {
             label = 61;
            } else {
             __THREW__ = 0;
             $212 = (invoke_iii(3255,($2|0),(215188|0))|0);
             $213 = __THREW__; __THREW__ = 0;
             $214 = $213&1;
             do {
              if (!($214)) {
               $215 = HEAP32[$212>>2]|0;
               $216 = ((($215)) + 28|0);
               $217 = HEAP32[$216>>2]|0;
               __THREW__ = 0;
               $218 = (invoke_iii($217|0,($212|0),10)|0);
               $219 = __THREW__; __THREW__ = 0;
               $220 = $219&1;
               if ($220) {
                break;
               }
               __THREW__ = 0;
               invoke_vi(3263,($2|0));
               $221 = __THREW__; __THREW__ = 0;
               $222 = $221&1;
               if ($222) {
                label = 61;
                break L161;
               }
               __THREW__ = 0;
               (invoke_iii(3268,($203|0),($218|0))|0);
               $229 = __THREW__; __THREW__ = 0;
               $230 = $229&1;
               if ($230) {
                label = 61;
                break L161;
               }
               __THREW__ = 0;
               (invoke_ii(3269,($203|0))|0);
               $231 = __THREW__; __THREW__ = 0;
               $232 = $231&1;
               if ($232) {
                label = 61;
                break L161;
               } else {
                label = 127;
                break L161;
               }
              }
             } while(0);
             $223 = ___cxa_find_matching_catch_2()|0;
             $224 = tempRet0;
             __THREW__ = 0;
             invoke_vi(3263,($2|0));
             $225 = __THREW__; __THREW__ = 0;
             $226 = $225&1;
             if ($226) {
              $227 = ___cxa_find_matching_catch_3(0|0)|0;
              $228 = tempRet0;
              ___clang_call_terminate($227);
              // unreachable;
             } else {
              $eh$lpad$body92$index5Z2D = $224;$eh$lpad$body92$indexZ2D = $223;
              break;
             }
            }
           }
          }
         } else {
          label = 127;
         }
        }
       }
      } while(0);
      if ((label|0) == 61) {
       $185 = ___cxa_find_matching_catch_2()|0;
       $186 = tempRet0;
       $eh$lpad$body92$index5Z2D = $186;$eh$lpad$body92$indexZ2D = $185;
      }
      else if ((label|0) == 127) {
       if (!($138)) {
        $410 = ((($135)) + 8|0);
        $411 = HEAP32[$410>>2]|0;HEAP32[$410>>2] = (($411-1)|0);
        $412 = ($411|0)==(1);
        if ($412) {
         __THREW__ = 0;
         invoke_viii(3262,($135|0),1,1);
         $413 = __THREW__; __THREW__ = 0;
         $414 = $413&1;
         if ($414) {
          $417 = ___cxa_find_matching_catch_2()|0;
          $418 = tempRet0;
          $$10 = $417;$$1059 = $418;
          break L29;
         }
        }
       }
       $415 = HEAP32[$57>>2]|0;HEAP32[$57>>2] = (($415-1)|0);
       $416 = ($415|0)==(1);
       if (!($416)) {
        STACKTOP = sp;return;
       }
       __ZNK3osg10Referenced24signalObserversAndDeleteEbb($54,1,1);
       STACKTOP = sp;return;
      }
      $$8 = $eh$lpad$body92$indexZ2D;$$857 = $eh$lpad$body92$index5Z2D;
     }
    } while(0);
    if ($138) {
     $$10 = $$8;$$1059 = $$857;
    } else {
     $419 = ((($135)) + 8|0);
     $420 = HEAP32[$419>>2]|0;HEAP32[$419>>2] = (($420-1)|0);
     $421 = ($420|0)==(1);
     if ($421) {
      __THREW__ = 0;
      invoke_viii(3262,($135|0),1,1);
      $422 = __THREW__; __THREW__ = 0;
      $423 = $422&1;
      if ($423) {
       $428 = ___cxa_find_matching_catch_3(0|0)|0;
       $429 = tempRet0;
       ___clang_call_terminate($428);
       // unreachable;
      } else {
       $$10 = $$8;$$1059 = $$857;
      }
     } else {
      $$10 = $$8;$$1059 = $$857;
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 20) {
  $67 = ___cxa_find_matching_catch_2()|0;
  $68 = tempRet0;
  $$10 = $67;$$1059 = $68;
 }
 $424 = HEAP32[$57>>2]|0;HEAP32[$57>>2] = (($424-1)|0);
 $425 = ($424|0)==(1);
 if (!($425)) {
  $$12 = $$10;$$1261 = $$1059;
  ___resumeException($$12|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(3262,($54|0),1,1);
 $426 = __THREW__; __THREW__ = 0;
 $427 = $426&1;
 if ($427) {
  $428 = ___cxa_find_matching_catch_3(0|0)|0;
  $429 = tempRet0;
  ___clang_call_terminate($428);
  // unreachable;
 } else {
  $$12 = $$10;$$1261 = $$1059;
  ___resumeException($$12|0);
  // unreachable;
 }
}
function __ZNSt3__26vectorIN3osg7ref_ptrINS1_6ObjectEEENS_9allocatorIS4_EEE21__push_back_slow_pathIKS4_EEvRT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$06$i$i = 0, $$pre = 0, $$pre$i = 0, $$pre38 = 0, $$pre39 = 0, $$sroa$7$0 = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(1073741823);
 $9 = $4;
 $10 = $3;
 if ($8) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $11 = ((($0)) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) - ($4))|0;
 $14 = $13 >> 2;
 $15 = ($14>>>0)<(536870911);
 $16 = $13 >> 1;
 $17 = ($16>>>0)<($7>>>0);
 $$sroa$speculated$i = $17 ? $7 : $16;
 $$sroa$speculated$$i = $15 ? $$sroa$speculated$i : 1073741823;
 $18 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($18) {
   $28 = 0;
  } else {
   $19 = ($$sroa$speculated$$i>>>0)>(1073741823);
   if (!($19)) {
    $25 = $$sroa$speculated$$i << 2;
    $26 = (__Znwj($25)|0);
    $28 = $26;
    break;
   }
   $20 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($20|0),(204840|0));
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if ($22) {
    $23 = ___cxa_find_matching_catch_2()|0;
    $24 = tempRet0;
    ___cxa_free_exception(($20|0));
    ___resumeException($23|0);
    // unreachable;
   } else {
    HEAP32[$20>>2] = (99824);
    ___cxa_throw(($20|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $27 = (($28) + ($6<<2)|0);
 $29 = $27;
 $30 = (($28) + ($$sroa$speculated$$i<<2)|0);
 $31 = $30;
 $32 = HEAP32[$1>>2]|0;
 HEAP32[$27>>2] = $32;
 $33 = ($32|0)==(0|0);
 if ($33) {
  $38 = $10;$40 = $9;
 } else {
  $34 = ((($32)) + 8|0);
  $35 = HEAP32[$34>>2]|0;HEAP32[$34>>2] = (($35+1)|0);
  $$pre = HEAP32[$0>>2]|0;
  $$pre38 = HEAP32[$2>>2]|0;
  $38 = $$pre38;$40 = $$pre;
 }
 $36 = ((($27)) + 4|0);
 $37 = $36;
 $39 = ($38|0)==($40|0);
 if ($39) {
  $41 = $38;
  $53 = $29;$54 = $41;$56 = $38;
 } else {
  $$06$i$i = $38;$$sroa$7$0 = $29;$44 = $27;
  while(1) {
   $42 = ((($$06$i$i)) + -4|0);
   $43 = ((($44)) + -4|0);
   $45 = HEAP32[$42>>2]|0;
   HEAP32[$43>>2] = $45;
   $46 = ($45|0)==(0|0);
   if (!($46)) {
    $47 = ((($45)) + 8|0);
    $48 = HEAP32[$47>>2]|0;HEAP32[$47>>2] = (($48+1)|0);
   }
   $49 = $$sroa$7$0;
   $50 = ((($49)) + -4|0);
   $51 = $50;
   $52 = ($42|0)==($40|0);
   if ($52) {
    break;
   } else {
    $$06$i$i = $42;$$sroa$7$0 = $51;$44 = $50;
   }
  }
  $$pre$i = HEAP32[$0>>2]|0;
  $$pre39 = HEAP32[$2>>2]|0;
  $53 = $51;$54 = $$pre$i;$56 = $$pre39;
 }
 HEAP32[$0>>2] = $53;
 HEAP32[$2>>2] = $37;
 HEAP32[$11>>2] = $31;
 $55 = $54;
 $57 = ($56|0)==($55|0);
 L25: do {
  if (!($57)) {
   $59 = $56;
   while(1) {
    $58 = ((($59)) + -4|0);
    $60 = HEAP32[$58>>2]|0;
    $61 = ($60|0)==(0|0);
    if (!($61)) {
     $62 = ((($60)) + 8|0);
     $63 = HEAP32[$62>>2]|0;HEAP32[$62>>2] = (($63-1)|0);
     $64 = ($63|0)==(1);
     if ($64) {
      __THREW__ = 0;
      invoke_viii(3262,($60|0),1,1);
      $65 = __THREW__; __THREW__ = 0;
      $66 = $65&1;
      if ($66) {
       break;
      }
     }
    }
    HEAP32[$58>>2] = 0;
    $67 = ($58|0)==($55|0);
    if ($67) {
     break L25;
    } else {
     $59 = $58;
    }
   }
   $68 = ___cxa_find_matching_catch_2()|0;
   $69 = tempRet0;
   ___cxa_call_unexpected(($68|0));
   // unreachable;
  }
 } while(0);
 $70 = ($54|0)==(0);
 if ($70) {
  return;
 }
 $71 = $54;
 __ZdlPv($71);
 return;
}
function __ZN9osgViewer12SingleScreenD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(388,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK9osgViewer12SingleScreen9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(36)|0);
 __THREW__ = 0;
 invoke_vi(3282,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $8 = ___cxa_find_matching_catch_2()|0;
  $9 = tempRet0;
  __ZdlPv($1);
  ___resumeException($8|0);
  // unreachable;
 } else {
  $4 = ((($1)) + 12|0);
  ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;
  $5 = ((($1)) + 24|0);
  HEAP32[$5>>2] = 2;
  $6 = ((($1)) + 28|0);
  HEAP32[$6>>2] = 0;
  HEAP32[$1>>2] = (38724);
  $7 = ((($1)) + 32|0);
  HEAP32[$7>>2] = 0;
  return ($1|0);
 }
 return (0)|0;
}
function __ZNK9osgViewer12SingleScreen5cloneERKN3osg6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(36)|0);
 __THREW__ = 0;
 invoke_viii(3468,($2|0),($0|0),($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $8 = ___cxa_find_matching_catch_2()|0;
  $9 = tempRet0;
  __ZdlPv($2);
  ___resumeException($8|0);
  // unreachable;
 } else {
  HEAP32[$2>>2] = (38724);
  $5 = ((($2)) + 32|0);
  $6 = ((($0)) + 32|0);
  $7 = HEAP32[$6>>2]|0;
  HEAP32[$5>>2] = $7;
  return ($2|0);
 }
 return (0)|0;
}
function __ZNK9osgViewer12SingleScreen12isSameKindAsEPKN3osg6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,5552,0)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK9osgViewer12SingleScreen11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (107921|0);
}
function __ZNK9osgViewer12SingleScreen9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (107361|0);
}
function __ZNK9osgViewer12SingleScreen9configureERNS_4ViewE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$03 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(56)|0);
 $3 = ((($0)) + 32|0);
 $4 = HEAP32[$3>>2]|0;
 __THREW__ = 0;
 invoke_vi(3282,($2|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $26 = ___cxa_find_matching_catch_2()|0;
  $27 = tempRet0;
  __ZdlPv($2);
  $$0 = $27;$$03 = $26;
  ___resumeException($$03|0);
  // unreachable;
 }
 $7 = ((($2)) + 12|0);
 ;HEAP32[$7>>2]=0|0;HEAP32[$7+4>>2]=0|0;HEAP32[$7+8>>2]=0|0;
 $8 = ((($2)) + 24|0);
 HEAP32[$8>>2] = 2;
 $9 = ((($2)) + 28|0);
 HEAP32[$9>>2] = 0;
 HEAP32[$2>>2] = (38568);
 $10 = ((($2)) + 32|0);
 HEAP32[$10>>2] = 0;
 $11 = ((($2)) + 36|0);
 HEAP32[$11>>2] = 0;
 $12 = ((($2)) + 40|0);
 HEAP32[$12>>2] = -1;
 $13 = ((($2)) + 44|0);
 HEAP32[$13>>2] = -1;
 $14 = ((($2)) + 48|0);
 HEAP32[$14>>2] = $4;
 $15 = ((($2)) + 52|0);
 HEAP8[$15>>0] = 1;
 $16 = ((($2)) + 53|0);
 HEAP8[$16>>0] = 0;
 $17 = ((($2)) + 8|0);
 $18 = HEAP32[$17>>2]|0;HEAP32[$17>>2] = (($18+1)|0);
 HEAP8[$15>>0] = 0;
 $19 = HEAP32[$2>>2]|0;
 $20 = ((($19)) + 140|0);
 $21 = HEAP32[$20>>2]|0;
 __THREW__ = 0;
 invoke_vii($21|0,($2|0),($1|0));
 $22 = __THREW__; __THREW__ = 0;
 $23 = $22&1;
 if (!($23)) {
  $24 = HEAP32[$17>>2]|0;HEAP32[$17>>2] = (($24-1)|0);
  $25 = ($24|0)==(1);
  if (!($25)) {
   return;
  }
  __ZNK3osg10Referenced24signalObserversAndDeleteEbb($2,1,1);
  return;
 }
 $28 = ___cxa_find_matching_catch_2()|0;
 $29 = tempRet0;
 $30 = HEAP32[$17>>2]|0;HEAP32[$17>>2] = (($30-1)|0);
 $31 = ($30|0)==(1);
 if ($31) {
  __THREW__ = 0;
  invoke_viii(3262,($2|0),1,1);
  $32 = __THREW__; __THREW__ = 0;
  $33 = $32&1;
  if ($33) {
   $34 = ___cxa_find_matching_catch_3(0|0)|0;
   $35 = tempRet0;
   ___clang_call_terminate($34);
   // unreachable;
  }
 }
 $$0 = $29;$$03 = $28;
 ___resumeException($$03|0);
 // unreachable;
}
function __ZN9osgViewer16AcrossAllScreensD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(388,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK9osgViewer16AcrossAllScreens9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(32)|0);
 __THREW__ = 0;
 invoke_vi(3282,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $7 = ___cxa_find_matching_catch_2()|0;
  $8 = tempRet0;
  __ZdlPv($1);
  ___resumeException($7|0);
  // unreachable;
 } else {
  $4 = ((($1)) + 12|0);
  ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;
  $5 = ((($1)) + 24|0);
  HEAP32[$5>>2] = 2;
  $6 = ((($1)) + 28|0);
  HEAP32[$6>>2] = 0;
  HEAP32[$1>>2] = (38880);
  return ($1|0);
 }
 return (0)|0;
}
function __ZNK9osgViewer16AcrossAllScreens5cloneERKN3osg6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(32)|0);
 __THREW__ = 0;
 invoke_viii(3468,($2|0),($0|0),($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch_2()|0;
  $6 = tempRet0;
  __ZdlPv($2);
  ___resumeException($5|0);
  // unreachable;
 } else {
  HEAP32[$2>>2] = (38880);
  return ($2|0);
 }
 return (0)|0;
}
function __ZNK9osgViewer16AcrossAllScreens12isSameKindAsEPKN3osg6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,5568,0)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK9osgViewer16AcrossAllScreens11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (107921|0);
}
function __ZNK9osgViewer16AcrossAllScreens9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (107599|0);
}
function __ZNK9osgViewer16AcrossAllScreens9configureERNS_4ViewE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0101407 = 0, $$0102405 = 0, $$098408 = 0.0, $$12 = 0, $$1287 = 0, $$14579 = 0, $$1489578 = 0, $$16 = 0, $$1691 = 0, $$199406 = 0.0, $$2 = 0, $$21 = 0, $$2100 = 0.0, $$2196 = 0, $$22 = 0, $$2297 = 0, $$277 = 0, $$3 = 0, $$378 = 0, $$8 = 0;
 var $$883 = 0, $$9 = 0, $$984 = 0, $$lcssa483 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0.0, $116 = 0.0, $117 = 0.0, $118 = 0.0, $119 = 0.0, $12 = 0, $120 = 0.0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0;
 var $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0;
 var $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0;
 var $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0;
 var $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0.0, $293 = 0.0, $294 = 0;
 var $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0;
 var $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0;
 var $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0;
 var $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0.0, $364 = 0, $365 = 0.0, $366 = 0.0;
 var $367 = 0.0, $368 = 0.0, $369 = 0, $37 = 0, $370 = 0, $371 = 0.0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0.0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0;
 var $385 = 0, $386 = 0, $387 = 0.0, $388 = 0.0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0;
 var $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0;
 var $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0;
 var $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index7Z2D = 0, $eh$lpad$body$indexZ2D = 0, $not$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 896|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(896|0);
 $2 = sp + 888|0;
 $3 = sp + 884|0;
 $4 = sp + 824|0;
 $5 = sp + 800|0;
 $6 = sp + 880|0;
 $7 = sp + 868|0;
 $8 = sp + 792|0;
 $9 = sp + 784|0;
 $10 = sp + 776|0;
 $11 = sp + 768|0;
 $12 = sp + 848|0;
 $13 = sp + 640|0;
 $14 = sp + 512|0;
 $15 = sp + 384|0;
 $16 = sp + 256|0;
 $17 = sp + 128|0;
 $18 = sp;
 $19 = ((($7)) + 11|0);
 ;HEAP32[$7>>2]=0|0;HEAP32[$7+4>>2]=0|0;HEAP32[$7+8>>2]=0|0;
 __THREW__ = 0;
 $20 = (invoke_ii(3376,($7|0))|0);
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if ($22) {
  $49 = ___cxa_find_matching_catch_2()|0;
  $50 = tempRet0;
  $51 = HEAP8[$19>>0]|0;
  $52 = ($51<<24>>24)<(0);
  if ($52) {
   $53 = HEAP32[$7>>2]|0;
   __ZdlPv($53);
  }
  $$22 = $49;$$2297 = $50;
  ___resumeException($$22|0);
  // unreachable;
 }
 $23 = HEAP8[$19>>0]|0;
 $24 = ($23<<24>>24)<(0);
 if ($24) {
  $25 = HEAP32[$7>>2]|0;
  __ZdlPv($25);
 }
 $26 = ($20|0)==(0|0);
 if ($26) {
  $27 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
  if (!($27)) {
   STACKTOP = sp;return;
  }
  $28 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
  $29 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($28,107401,97)|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = ((($30)) + -12|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = (($29) + ($32)|0);
  __ZNKSt3__28ios_base6getlocEv($6,$33);
  __THREW__ = 0;
  $34 = (invoke_iii(3255,($6|0),(215188|0))|0);
  $35 = __THREW__; __THREW__ = 0;
  $36 = $35&1;
  if (!($36)) {
   $37 = HEAP32[$34>>2]|0;
   $38 = ((($37)) + 28|0);
   $39 = HEAP32[$38>>2]|0;
   __THREW__ = 0;
   $40 = (invoke_iii($39|0,($34|0),10)|0);
   $41 = __THREW__; __THREW__ = 0;
   $42 = $41&1;
   if (!($42)) {
    __ZNSt3__26localeD2Ev($6);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($29,$40)|0);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($29)|0);
    STACKTOP = sp;return;
   }
  }
  $43 = ___cxa_find_matching_catch_2()|0;
  $44 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3263,($6|0));
  $45 = __THREW__; __THREW__ = 0;
  $46 = $45&1;
  if ($46) {
   $47 = ___cxa_find_matching_catch_3(0|0)|0;
   $48 = tempRet0;
   ___clang_call_terminate($47);
   // unreachable;
  } else {
   ___resumeException($43|0);
   // unreachable;
  }
 }
 $54 = HEAP32[$0>>2]|0;
 $55 = ((($54)) + 144|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = (FUNCTION_TABLE_iii[$56 & 8191]($0,$1)|0);
 $58 = ((($1)) + 16|0);
 $59 = HEAP32[$58>>2]|0;
 (__ZNK3osg6Camera32getProjectionMatrixAsPerspectiveERdS1_S1_S1_($59,$8,$9,$10,$11)|0);
 __ZN3osg15GraphicsContext16ScreenIdentifierC2Ev($12);
 __THREW__ = 0;
 invoke_vi(3469,($12|0));
 $60 = __THREW__; __THREW__ = 0;
 $61 = $60&1;
 L25: do {
  if ($61) {
   label = 18;
  } else {
   $62 = ((($12)) + 12|0);
   $63 = HEAP32[$62>>2]|0;
   $64 = ($63|0)<(0);
   if ($64) {
    HEAP32[$62>>2] = 0;
   }
   $67 = HEAP32[$20>>2]|0;
   $68 = ((($67)) + 12|0);
   $69 = HEAP32[$68>>2]|0;
   __THREW__ = 0;
   $70 = (invoke_iii($69|0,($20|0),($12|0))|0);
   $71 = __THREW__; __THREW__ = 0;
   $72 = $71&1;
   if ($72) {
    label = 18;
   } else {
    L31: do {
     switch ($70|0) {
     case 1:  {
      __THREW__ = 0;
      $75 = (invoke_ii(3276,36)|0);
      $76 = __THREW__; __THREW__ = 0;
      $77 = $76&1;
      if (!($77)) {
       __THREW__ = 0;
       invoke_vi(3282,($75|0));
       $78 = __THREW__; __THREW__ = 0;
       $79 = $78&1;
       if ($79) {
        $97 = ___cxa_find_matching_catch_2()|0;
        $98 = tempRet0;
        __ZdlPv($75);
        $$21 = $97;$$2196 = $98;
        break L25;
       }
       $80 = ((($75)) + 12|0);
       ;HEAP32[$80>>2]=0|0;HEAP32[$80+4>>2]=0|0;HEAP32[$80+8>>2]=0|0;
       $81 = ((($75)) + 24|0);
       HEAP32[$81>>2] = 2;
       $82 = ((($75)) + 28|0);
       HEAP32[$82>>2] = 0;
       HEAP32[$75>>2] = (38724);
       $83 = ((($75)) + 32|0);
       HEAP32[$83>>2] = 0;
       $84 = ((($75)) + 8|0);
       $85 = HEAP32[$84>>2]|0;HEAP32[$84>>2] = (($85+1)|0);
       $86 = HEAP32[$75>>2]|0;
       $87 = ((($86)) + 140|0);
       $88 = HEAP32[$87>>2]|0;
       __THREW__ = 0;
       invoke_vii($88|0,($75|0),($1|0));
       $89 = __THREW__; __THREW__ = 0;
       $90 = $89&1;
       if ($90) {
        $99 = ___cxa_find_matching_catch_2()|0;
        $100 = tempRet0;
        $101 = HEAP32[$84>>2]|0;HEAP32[$84>>2] = (($101-1)|0);
        $102 = ($101|0)==(1);
        if (!($102)) {
         $$21 = $99;$$2196 = $100;
         break L25;
        }
        __THREW__ = 0;
        invoke_viii(3262,($75|0),1,1);
        $103 = __THREW__; __THREW__ = 0;
        $104 = $103&1;
        if (!($104)) {
         $$21 = $99;$$2196 = $100;
         break L25;
        }
        $441 = ___cxa_find_matching_catch_3(0|0)|0;
        $442 = tempRet0;
        ___clang_call_terminate($441);
        // unreachable;
       } else {
        $91 = HEAP32[$84>>2]|0;HEAP32[$84>>2] = (($91-1)|0);
        $92 = ($91|0)==(1);
        if (!($92)) {
         label = 151;
         break L31;
        }
        __THREW__ = 0;
        invoke_viii(3262,($75|0),1,1);
        $93 = __THREW__; __THREW__ = 0;
        $94 = $93&1;
        if (!($94)) {
         label = 151;
         break L31;
        }
        $105 = ___cxa_find_matching_catch_2()|0;
        $106 = tempRet0;
        $$21 = $105;$$2196 = $106;
        break L25;
       }
      }
      break;
     }
     case 0:  {
      label = 151;
      break;
     }
     default: {
      $73 = ((($12)) + 16|0);
      $74 = ((($5)) + 4|0);
      $$0101407 = 0;$$098408 = 0.0;
      while(1) {
       HEAP32[$73>>2] = $$0101407;
       ;HEAP32[$5>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;HEAP32[$5+12>>2]=0|0;HEAP32[$5+16>>2]=0|0;
       $108 = HEAP32[$20>>2]|0;
       $109 = ((($108)) + 16|0);
       $110 = HEAP32[$109>>2]|0;
       __THREW__ = 0;
       invoke_viii($110|0,($20|0),($12|0),($5|0));
       $111 = __THREW__; __THREW__ = 0;
       $112 = $111&1;
       if ($112) {
        label = 35;
        break;
       }
       $113 = HEAP32[$5>>2]|0;
       $114 = HEAP32[$74>>2]|0;
       $115 = (+($113>>>0));
       $116 = (+($114>>>0));
       $117 = +HEAPF64[$9>>3];
       $118 = $116 * $117;
       $119 = $115 / $118;
       $120 = $$098408 + $119;
       $121 = (($$0101407) + 1)|0;
       $122 = ($121>>>0)<($70>>>0);
       if ($122) {
        $$0101407 = $121;$$098408 = $120;
       } else {
        break;
       }
      }
      if ((label|0) == 35) {
       $123 = ___cxa_find_matching_catch_2()|0;
       $124 = tempRet0;
       $$21 = $123;$$2196 = $124;
       break L25;
      }
      $107 = ($70|0)==(2);
      if ($107) {
       $125 = ((($57)) + 20|0);
       $126 = HEAP32[$125>>2]|0;
       $127 = ($126|0)==(2);
       if ($127) {
        $128 = ((($57)) + 16|0);
        $129 = HEAP8[$128>>0]|0;
        $130 = ($129<<24>>24)!=(0);
        $443 = $130;
       } else {
        $443 = 0;
       }
      } else {
       $443 = 0;
      }
      $131 = ((($12)) + 16|0);
      $132 = ((($4)) + 4|0);
      $133 = ((($57)) + 40|0);
      $$0102405 = 0;$$199406 = $120;
      L43: while(1) {
       HEAP32[$131>>2] = $$0102405;
       ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;HEAP32[$4+12>>2]=0|0;HEAP32[$4+16>>2]=0|0;
       $134 = HEAP32[$20>>2]|0;
       $135 = ((($134)) + 16|0);
       $136 = HEAP32[$135>>2]|0;
       __THREW__ = 0;
       invoke_viii($136|0,($20|0),($12|0),($4|0));
       $137 = __THREW__; __THREW__ = 0;
       $138 = $137&1;
       if ($138) {
        label = 53;
        break;
       }
       $139 = HEAP32[$4>>2]|0;
       $140 = HEAP32[$132>>2]|0;
       __THREW__ = 0;
       $141 = (invoke_ii(3276,200)|0);
       $142 = __THREW__; __THREW__ = 0;
       $143 = $142&1;
       if ($143) {
        label = 53;
        break;
       }
       __THREW__ = 0;
       invoke_vii(3419,($141|0),($57|0));
       $144 = __THREW__; __THREW__ = 0;
       $145 = $144&1;
       if ($145) {
        label = 54;
        break;
       }
       $146 = ((($141)) + 8|0);
       $147 = HEAP32[$146>>2]|0;HEAP32[$146>>2] = (($147+1)|0);
       $148 = ((($141)) + 12|0);
       __THREW__ = 0;
       (invoke_iii(3477,($148|0),($12|0))|0);
       $149 = __THREW__; __THREW__ = 0;
       $150 = $149&1;
       if ($150) {
        label = 55;
        break;
       }
       $151 = HEAP32[$62>>2]|0;
       $152 = ((($141)) + 24|0);
       HEAP32[$152>>2] = $151;
       $153 = ((($141)) + 28|0);
       HEAP32[$153>>2] = $$0102405;
       $154 = ((($141)) + 32|0);
       HEAP32[$154>>2] = 0;
       $155 = ((($141)) + 36|0);
       HEAP32[$155>>2] = 0;
       $156 = ((($141)) + 40|0);
       HEAP32[$156>>2] = $139;
       $157 = ((($141)) + 44|0);
       HEAP32[$157>>2] = $140;
       $158 = ((($141)) + 72|0);
       HEAP8[$158>>0] = 0;
       $159 = ((($141)) + 110|0);
       HEAP8[$159>>0] = 1;
       $160 = ((($141)) + 168|0);
       $161 = HEAP32[$160>>2]|0;
       $162 = ($161|0)==(0|0);
       if (!($162)) {
        HEAP32[$160>>2] = 0;
        $163 = ((($161)) + 8|0);
        $164 = HEAP32[$163>>2]|0;HEAP32[$163>>2] = (($164-1)|0);
        $165 = ($164|0)==(1);
        if ($165) {
         __THREW__ = 0;
         invoke_viii(3262,($161|0),1,1);
         $166 = __THREW__; __THREW__ = 0;
         $167 = $166&1;
         if ($167) {
          label = 55;
          break;
         }
        }
       }
       $168 = ((($141)) + 172|0);
       HEAP32[$168>>2] = 0;
       __THREW__ = 0;
       $169 = (invoke_ii(3471,($141|0))|0);
       $170 = __THREW__; __THREW__ = 0;
       $171 = $170&1;
       if ($171) {
        label = 55;
        break;
       }
       $172 = ($169|0)==(0|0);
       if (!($172)) {
        $173 = ((($169)) + 8|0);
        $174 = HEAP32[$173>>2]|0;HEAP32[$173>>2] = (($174+1)|0);
       }
       __THREW__ = 0;
       $175 = (invoke_ii(3276,656)|0);
       $176 = __THREW__; __THREW__ = 0;
       $177 = $176&1;
       if ($177) {
        label = 56;
        break;
       }
       __THREW__ = 0;
       invoke_vi(3336,($175|0));
       $178 = __THREW__; __THREW__ = 0;
       $179 = $178&1;
       if ($179) {
        label = 57;
        break;
       }
       $180 = ((($175)) + 8|0);
       $181 = HEAP32[$180>>2]|0;HEAP32[$180>>2] = (($181+1)|0);
       __THREW__ = 0;
       invoke_vii(3338,($175|0),($169|0));
       $182 = __THREW__; __THREW__ = 0;
       $183 = $182&1;
       if ($183) {
        label = 58;
        break;
       }
       do {
        if ($172) {
         label = 77;
        } else {
         $196 = (___dynamic_cast($169,24816,3888,0)|0);
         $197 = ($196|0)==(0|0);
         if ($197) {
          label = 77;
          break;
         }
         __THREW__ = 0;
         $198 = (invoke_ii(3265,4)|0);
         $199 = __THREW__; __THREW__ = 0;
         $200 = $199&1;
         if ($200) {
          $$lcssa483 = 0;
          label = 74;
          break L43;
         }
         if ($198) {
          __THREW__ = 0;
          $201 = (invoke_ii(3266,4)|0);
          $202 = __THREW__; __THREW__ = 0;
          $203 = $202&1;
          if ($203) {
           $$lcssa483 = 0;
           label = 74;
           break L43;
          }
          __THREW__ = 0;
          $204 = (invoke_iiii(3267,($201|0),(107499|0),47)|0);
          $205 = __THREW__; __THREW__ = 0;
          $206 = $205&1;
          if ($206) {
           $$lcssa483 = 0;
           label = 74;
           break L43;
          }
          __THREW__ = 0;
          $207 = (invoke_iii(3275,($204|0),($196|0))|0);
          $208 = __THREW__; __THREW__ = 0;
          $209 = $208&1;
          if ($209) {
           $$lcssa483 = 0;
           label = 74;
           break L43;
          }
          $210 = HEAP32[$207>>2]|0;
          $211 = ((($210)) + -12|0);
          $212 = HEAP32[$211>>2]|0;
          $213 = (($207) + ($212)|0);
          __THREW__ = 0;
          invoke_vii(3257,($3|0),($213|0));
          $214 = __THREW__; __THREW__ = 0;
          $215 = $214&1;
          if ($215) {
           $$lcssa483 = 0;
           label = 74;
           break L43;
          }
          __THREW__ = 0;
          $216 = (invoke_iii(3255,($3|0),(215188|0))|0);
          $217 = __THREW__; __THREW__ = 0;
          $218 = $217&1;
          if ($218) {
           label = 69;
           break L43;
          }
          $219 = HEAP32[$216>>2]|0;
          $220 = ((($219)) + 28|0);
          $221 = HEAP32[$220>>2]|0;
          __THREW__ = 0;
          $222 = (invoke_iii($221|0,($216|0),10)|0);
          $223 = __THREW__; __THREW__ = 0;
          $224 = $223&1;
          if ($224) {
           label = 69;
           break L43;
          }
          __THREW__ = 0;
          invoke_vi(3263,($3|0));
          $225 = __THREW__; __THREW__ = 0;
          $226 = $225&1;
          if ($226) {
           $$lcssa483 = 0;
           label = 74;
           break L43;
          }
          __THREW__ = 0;
          (invoke_iii(3268,($207|0),($222|0))|0);
          $233 = __THREW__; __THREW__ = 0;
          $234 = $233&1;
          if ($234) {
           $$lcssa483 = 0;
           label = 74;
           break L43;
          }
          __THREW__ = 0;
          (invoke_ii(3269,($207|0))|0);
          $235 = __THREW__; __THREW__ = 0;
          $236 = $235&1;
          if ($236) {
           $$lcssa483 = 0;
           label = 74;
           break L43;
          }
         }
         $239 = ((($196)) + 136|0);
         $240 = HEAP32[$239>>2]|0;
         $241 = ((($240)) + 12|0);
         $242 = HEAP32[$241>>2]|0;
         $243 = HEAP32[$154>>2]|0;
         $244 = HEAP32[$155>>2]|0;
         $245 = HEAP32[$156>>2]|0;
         $246 = HEAP32[$157>>2]|0;
         __THREW__ = 0;
         invoke_viiiiii(3472,($242|0),($243|0),($244|0),($245|0),($246|0),1);
         $247 = __THREW__; __THREW__ = 0;
         $248 = $247&1;
         if ($248) {
          $$lcssa483 = 0;
          label = 74;
          break L43;
         }
        }
       } while(0);
       do {
        if ((label|0) == 77) {
         label = 0;
         __THREW__ = 0;
         $249 = (invoke_ii(3265,3)|0);
         $250 = __THREW__; __THREW__ = 0;
         $251 = $250&1;
         if ($251) {
          $$lcssa483 = $172;
          label = 74;
          break L43;
         }
         if (!($249)) {
          break;
         }
         __THREW__ = 0;
         $252 = (invoke_ii(3266,3)|0);
         $253 = __THREW__; __THREW__ = 0;
         $254 = $253&1;
         if ($254) {
          $$lcssa483 = $172;
          label = 74;
          break L43;
         }
         __THREW__ = 0;
         $255 = (invoke_iiii(3267,($252|0),(107547|0),51)|0);
         $256 = __THREW__; __THREW__ = 0;
         $257 = $256&1;
         if ($257) {
          $$lcssa483 = $172;
          label = 74;
          break L43;
         }
         $258 = HEAP32[$255>>2]|0;
         $259 = ((($258)) + -12|0);
         $260 = HEAP32[$259>>2]|0;
         $261 = (($255) + ($260)|0);
         __THREW__ = 0;
         invoke_vii(3257,($2|0),($261|0));
         $262 = __THREW__; __THREW__ = 0;
         $263 = $262&1;
         if ($263) {
          $$lcssa483 = $172;
          label = 74;
          break L43;
         }
         __THREW__ = 0;
         $264 = (invoke_iii(3255,($2|0),(215188|0))|0);
         $265 = __THREW__; __THREW__ = 0;
         $266 = $265&1;
         if ($266) {
          label = 85;
          break L43;
         }
         $267 = HEAP32[$264>>2]|0;
         $268 = ((($267)) + 28|0);
         $269 = HEAP32[$268>>2]|0;
         __THREW__ = 0;
         $270 = (invoke_iii($269|0,($264|0),10)|0);
         $271 = __THREW__; __THREW__ = 0;
         $272 = $271&1;
         if ($272) {
          label = 85;
          break L43;
         }
         __THREW__ = 0;
         invoke_vi(3263,($2|0));
         $273 = __THREW__; __THREW__ = 0;
         $274 = $273&1;
         if ($274) {
          $$lcssa483 = $172;
          label = 74;
          break L43;
         }
         __THREW__ = 0;
         (invoke_iii(3268,($255|0),($270|0))|0);
         $281 = __THREW__; __THREW__ = 0;
         $282 = $281&1;
         if ($282) {
          $$lcssa483 = $172;
          label = 74;
          break L43;
         }
         __THREW__ = 0;
         (invoke_ii(3269,($255|0))|0);
         $283 = __THREW__; __THREW__ = 0;
         $284 = $283&1;
         if ($284) {
          $$lcssa483 = $172;
          label = 74;
          break L43;
         }
        }
       } while(0);
       __THREW__ = 0;
       $285 = (invoke_ii(3276,88)|0);
       $286 = __THREW__; __THREW__ = 0;
       $287 = $286&1;
       if ($287) {
        $$lcssa483 = $172;
        label = 74;
        break;
       }
       $288 = HEAP32[$156>>2]|0;
       $289 = HEAP32[$157>>2]|0;
       __THREW__ = 0;
       invoke_vi(3339,($285|0));
       $290 = __THREW__; __THREW__ = 0;
       $291 = $290&1;
       if ($291) {
        label = 108;
        break;
       }
       $292 = (+($289|0));
       $293 = (+($288|0));
       HEAP32[$285>>2] = (70172);
       $294 = ((($285)) + 56|0);
       $295 = ((($285)) + 72|0);
       ;HEAP32[$294>>2]=0|0;HEAP32[$294+4>>2]=0|0;HEAP32[$294+8>>2]=0|0;HEAP32[$294+12>>2]=0|0;
       HEAPF64[$295>>3] = $293;
       $296 = ((($285)) + 80|0);
       HEAPF64[$296>>3] = $292;
       __THREW__ = 0;
       invoke_vii(3340,($175|0),($285|0));
       $297 = __THREW__; __THREW__ = 0;
       $298 = $297&1;
       if ($298) {
        $$lcssa483 = $172;
        label = 74;
        break;
       }
       $299 = HEAP8[$159>>0]|0;
       $300 = ($299<<24>>24)!=(0);
       $301 = $300 ? 1029 : 1028;
       $302 = ((($175)) + 568|0);
       HEAP32[$302>>2] = $301;
       $303 = ((($175)) + 152|0);
       $304 = HEAP32[$303>>2]|0;
       $305 = ($304|0)==(0);
       $306 = ((($175)) + 148|0);
       if ($305) {
        $308 = HEAP32[$306>>2]|0;
        $309 = $308 & -131073;
        HEAP32[$306>>2] = $309;
        $310 = ((($175)) + 572|0);
        HEAP32[$310>>2] = $301;
        $311 = $308 & -393217;
        HEAP32[$306>>2] = $311;
       } else {
        $307 = ((($175)) + 572|0);
        HEAP32[$307>>2] = $301;
       }
       do {
        if ($443) {
         $312 = HEAP32[$133>>2]|0;
         $not$ = ($312|0)!=(0);
         $313 = $not$&1;
         __THREW__ = 0;
         $314 = (invoke_ii(3276,200)|0);
         $315 = __THREW__; __THREW__ = 0;
         $316 = $315&1;
         if ($316) {
          label = 109;
          break L43;
         }
         __THREW__ = 0;
         invoke_vii(3478,($314|0),($57|0));
         $317 = __THREW__; __THREW__ = 0;
         $318 = $317&1;
         if ($318) {
          label = 110;
          break L43;
         }
         $319 = ((($314)) + 8|0);
         $320 = HEAP32[$319>>2]|0;HEAP32[$319>>2] = (($320+1)|0);
         $321 = ($313|0)==($$0102405|0);
         $322 = $321 ? 4 : 5;
         $323 = ((($314)) + 20|0);
         HEAP32[$323>>2] = $322;
         $324 = ((($175)) + 232|0);
         $325 = HEAP32[$324>>2]|0;
         $326 = ($325|0)==($314|0);
         do {
          if (!($326)) {
           HEAP32[$324>>2] = $314;
           $327 = HEAP32[$319>>2]|0;HEAP32[$319>>2] = (($327+1)|0);
           $328 = ($325|0)==(0|0);
           if ($328) {
            break;
           }
           $329 = ((($325)) + 8|0);
           $330 = HEAP32[$329>>2]|0;HEAP32[$329>>2] = (($330-1)|0);
           $331 = ($330|0)==(1);
           if (!($331)) {
            break;
           }
           __THREW__ = 0;
           invoke_viii(3262,($325|0),1,1);
           $332 = __THREW__; __THREW__ = 0;
           $333 = $332&1;
           if ($333) {
            label = 111;
            break L43;
           }
          }
         } while(0);
         __THREW__ = 0;
         invoke_vi(3299,($13|0));
         $334 = __THREW__; __THREW__ = 0;
         $335 = $334&1;
         if ($335) {
          label = 112;
          break L43;
         }
         __THREW__ = 0;
         invoke_vi(3299,($14|0));
         $336 = __THREW__; __THREW__ = 0;
         $337 = $336&1;
         if ($337) {
          label = 113;
          break L43;
         }
         __THREW__ = 0;
         (invoke_iiiiii(3343,($1|0),($175|0),($13|0),($14|0),1)|0);
         $338 = __THREW__; __THREW__ = 0;
         $339 = $338&1;
         if ($339) {
          label = 113;
          break L43;
         }
         $340 = HEAP32[$319>>2]|0;HEAP32[$319>>2] = (($340-1)|0);
         $341 = ($340|0)==(1);
         if (!($341)) {
          $$2100 = $$199406;
          break;
         }
         __THREW__ = 0;
         invoke_viii(3262,($314|0),1,1);
         $342 = __THREW__; __THREW__ = 0;
         $343 = $342&1;
         if ($343) {
          label = 115;
          break L43;
         } else {
          $$2100 = $$199406;
         }
        } else {
         $362 = HEAP32[$156>>2]|0;
         $363 = (+($362|0));
         $364 = HEAP32[$157>>2]|0;
         $365 = (+($364|0));
         $366 = $363 / $365;
         $367 = +HEAPF64[$9>>3];
         $368 = $366 / $367;
         __THREW__ = 0;
         invoke_vi(3299,($16|0));
         $369 = __THREW__; __THREW__ = 0;
         $370 = $369&1;
         if ($370) {
          label = 127;
          break L43;
         }
         $371 = $$199406 - $368;
         __THREW__ = 0;
         invoke_viddd(3306,($16|0),(+$371),0.0,0.0);
         $372 = __THREW__; __THREW__ = 0;
         $373 = $372&1;
         if ($373) {
          label = 127;
          break L43;
         }
         __THREW__ = 0;
         invoke_vi(3299,($17|0));
         $374 = __THREW__; __THREW__ = 0;
         $375 = $374&1;
         if ($375) {
          label = 128;
          break L43;
         }
         $376 = 1.0 / $368;
         __THREW__ = 0;
         invoke_viddd(3305,($17|0),(+$376),1.0,1.0);
         $377 = __THREW__; __THREW__ = 0;
         $378 = $377&1;
         if ($378) {
          label = 128;
          break L43;
         }
         __THREW__ = 0;
         invoke_vi(3299,($15|0));
         $379 = __THREW__; __THREW__ = 0;
         $380 = $379&1;
         if ($380) {
          label = 129;
          break L43;
         }
         __THREW__ = 0;
         invoke_viii(3300,($15|0),($16|0),($17|0));
         $381 = __THREW__; __THREW__ = 0;
         $382 = $381&1;
         if ($382) {
          label = 129;
          break L43;
         }
         __THREW__ = 0;
         invoke_vi(3299,($18|0));
         $383 = __THREW__; __THREW__ = 0;
         $384 = $383&1;
         if ($384) {
          label = 130;
          break L43;
         }
         __THREW__ = 0;
         (invoke_iiiiii(3343,($1|0),($175|0),($15|0),($18|0),1)|0);
         $385 = __THREW__; __THREW__ = 0;
         $386 = $385&1;
         if ($386) {
          label = 130;
          break L43;
         }
         $387 = $368 * 2.0;
         $388 = $$199406 - $387;
         $$2100 = $388;
        }
       } while(0);
       $397 = HEAP32[$180>>2]|0;HEAP32[$180>>2] = (($397-1)|0);
       $398 = ($397|0)==(1);
       if ($398) {
        __THREW__ = 0;
        invoke_viii(3262,($175|0),1,1);
        $399 = __THREW__; __THREW__ = 0;
        $400 = $399&1;
        if ($400) {
         label = 141;
         break;
        }
       }
       do {
        if (!($172)) {
         $401 = ((($169)) + 8|0);
         $402 = HEAP32[$401>>2]|0;HEAP32[$401>>2] = (($402-1)|0);
         $403 = ($402|0)==(1);
         if (!($403)) {
          break;
         }
         __THREW__ = 0;
         invoke_viii(3262,($169|0),1,1);
         $404 = __THREW__; __THREW__ = 0;
         $405 = $404&1;
         if ($405) {
          label = 144;
          break L43;
         }
        }
       } while(0);
       $406 = HEAP32[$146>>2]|0;HEAP32[$146>>2] = (($406-1)|0);
       $407 = ($406|0)==(1);
       if ($407) {
        __THREW__ = 0;
        invoke_viii(3262,($141|0),1,1);
        $408 = __THREW__; __THREW__ = 0;
        $409 = $408&1;
        if ($409) {
         label = 148;
         break;
        }
       }
       $410 = (($$0102405) + 1)|0;
       $411 = ($410>>>0)<($70>>>0);
       if ($411) {
        $$0102405 = $410;$$199406 = $$2100;
       } else {
        label = 151;
        break L31;
       }
      }
      switch (label|0) {
       case 53: {
        $184 = ___cxa_find_matching_catch_2()|0;
        $185 = tempRet0;
        $$21 = $184;$$2196 = $185;
        break L25;
        break;
       }
       case 54: {
        $186 = ___cxa_find_matching_catch_2()|0;
        $187 = tempRet0;
        __ZdlPv($141);
        $$21 = $186;$$2196 = $187;
        break L25;
        break;
       }
       case 55: {
        $188 = ___cxa_find_matching_catch_2()|0;
        $189 = tempRet0;
        $$16 = $188;$$1691 = $189;
        break;
       }
       case 56: {
        $190 = ___cxa_find_matching_catch_2()|0;
        $191 = tempRet0;
        if ($172) {
         $$16 = $190;$$1691 = $191;
        } else {
         $$14579 = $190;$$1489578 = $191;
         label = 146;
        }
        break;
       }
       case 57: {
        $192 = ___cxa_find_matching_catch_2()|0;
        $193 = tempRet0;
        __ZdlPv($175);
        if ($172) {
         $$16 = $192;$$1691 = $193;
        } else {
         $$14579 = $192;$$1489578 = $193;
         label = 146;
        }
        break;
       }
       case 58: {
        $194 = ___cxa_find_matching_catch_2()|0;
        $195 = tempRet0;
        $$12 = $194;$$1287 = $195;$444 = $172;
        label = 142;
        break;
       }
       case 69: {
        $227 = ___cxa_find_matching_catch_2()|0;
        $228 = tempRet0;
        __THREW__ = 0;
        invoke_vi(3263,($3|0));
        $229 = __THREW__; __THREW__ = 0;
        $230 = $229&1;
        if ($230) {
         $231 = ___cxa_find_matching_catch_3(0|0)|0;
         $232 = tempRet0;
         ___clang_call_terminate($231);
         // unreachable;
        } else {
         $445 = 0;$eh$lpad$body$index7Z2D = $228;$eh$lpad$body$indexZ2D = $227;
         label = 75;
         break;
        }
        break;
       }
       case 74: {
        $237 = ___cxa_find_matching_catch_2()|0;
        $238 = tempRet0;
        $445 = $$lcssa483;$eh$lpad$body$index7Z2D = $238;$eh$lpad$body$indexZ2D = $237;
        label = 75;
        break;
       }
       case 85: {
        $275 = ___cxa_find_matching_catch_2()|0;
        $276 = tempRet0;
        __THREW__ = 0;
        invoke_vi(3263,($2|0));
        $277 = __THREW__; __THREW__ = 0;
        $278 = $277&1;
        if ($278) {
         $279 = ___cxa_find_matching_catch_3(0|0)|0;
         $280 = tempRet0;
         ___clang_call_terminate($279);
         // unreachable;
        } else {
         $445 = $172;$eh$lpad$body$index7Z2D = $276;$eh$lpad$body$indexZ2D = $275;
         label = 75;
         break;
        }
        break;
       }
       case 108: {
        $344 = ___cxa_find_matching_catch_2()|0;
        $345 = tempRet0;
        __ZdlPv($285);
        $$12 = $344;$$1287 = $345;$444 = $172;
        label = 142;
        break;
       }
       case 109: {
        $346 = ___cxa_find_matching_catch_2()|0;
        $347 = tempRet0;
        $$12 = $346;$$1287 = $347;$444 = $172;
        label = 142;
        break;
       }
       case 110: {
        $348 = ___cxa_find_matching_catch_2()|0;
        $349 = tempRet0;
        __ZdlPv($314);
        $$12 = $348;$$1287 = $349;$444 = $172;
        label = 142;
        break;
       }
       case 111: {
        $350 = ___cxa_find_matching_catch_2()|0;
        $351 = tempRet0;
        $$3 = $350;$$378 = $351;
        label = 116;
        break;
       }
       case 112: {
        $352 = ___cxa_find_matching_catch_2()|0;
        $353 = tempRet0;
        $$2 = $352;$$277 = $353;
        label = 114;
        break;
       }
       case 113: {
        $354 = ___cxa_find_matching_catch_2()|0;
        $355 = tempRet0;
        $$2 = $354;$$277 = $355;
        label = 114;
        break;
       }
       case 115: {
        $356 = ___cxa_find_matching_catch_2()|0;
        $357 = tempRet0;
        $$12 = $356;$$1287 = $357;$444 = $172;
        label = 142;
        break;
       }
       case 127: {
        $389 = ___cxa_find_matching_catch_2()|0;
        $390 = tempRet0;
        $$9 = $389;$$984 = $390;
        label = 132;
        break;
       }
       case 128: {
        $391 = ___cxa_find_matching_catch_2()|0;
        $392 = tempRet0;
        $$8 = $391;$$883 = $392;
        label = 131;
        break;
       }
       case 129: {
        $393 = ___cxa_find_matching_catch_2()|0;
        $394 = tempRet0;
        $$8 = $393;$$883 = $394;
        label = 131;
        break;
       }
       case 130: {
        $395 = ___cxa_find_matching_catch_2()|0;
        $396 = tempRet0;
        $$8 = $395;$$883 = $396;
        label = 131;
        break;
       }
       case 141: {
        $412 = ___cxa_find_matching_catch_2()|0;
        $413 = tempRet0;
        if ($172) {
         $$16 = $412;$$1691 = $413;
        } else {
         $$14579 = $412;$$1489578 = $413;
         label = 146;
        }
        break;
       }
       case 144: {
        $418 = ___cxa_find_matching_catch_2()|0;
        $419 = tempRet0;
        $$16 = $418;$$1691 = $419;
        break;
       }
       case 148: {
        $425 = ___cxa_find_matching_catch_2()|0;
        $426 = tempRet0;
        $$21 = $425;$$2196 = $426;
        break L25;
        break;
       }
      }
      if ((label|0) == 75) {
       $$12 = $eh$lpad$body$indexZ2D;$$1287 = $eh$lpad$body$index7Z2D;$444 = $445;
       label = 142;
      }
      else if ((label|0) == 114) {
       $$3 = $$2;$$378 = $$277;
       label = 116;
      }
      else if ((label|0) == 131) {
       $$9 = $$8;$$984 = $$883;
       label = 132;
      }
      if ((label|0) == 116) {
       $358 = HEAP32[$319>>2]|0;HEAP32[$319>>2] = (($358-1)|0);
       $359 = ($358|0)==(1);
       if ($359) {
        __THREW__ = 0;
        invoke_viii(3262,($314|0),1,1);
        $360 = __THREW__; __THREW__ = 0;
        $361 = $360&1;
        if ($361) {
         $441 = ___cxa_find_matching_catch_3(0|0)|0;
         $442 = tempRet0;
         ___clang_call_terminate($441);
         // unreachable;
        } else {
         $$12 = $$3;$$1287 = $$378;$444 = $172;
         label = 142;
        }
       } else {
        $$12 = $$3;$$1287 = $$378;$444 = $172;
        label = 142;
       }
      }
      else if ((label|0) == 132) {
       $$12 = $$9;$$1287 = $$984;$444 = $172;
       label = 142;
      }
      if ((label|0) == 142) {
       $414 = HEAP32[$180>>2]|0;HEAP32[$180>>2] = (($414-1)|0);
       $415 = ($414|0)==(1);
       if ($415) {
        __THREW__ = 0;
        invoke_viii(3262,($175|0),1,1);
        $416 = __THREW__; __THREW__ = 0;
        $417 = $416&1;
        if ($417) {
         $441 = ___cxa_find_matching_catch_3(0|0)|0;
         $442 = tempRet0;
         ___clang_call_terminate($441);
         // unreachable;
        }
       }
       if ($444) {
        $$16 = $$12;$$1691 = $$1287;
       } else {
        $$14579 = $$12;$$1489578 = $$1287;
        label = 146;
       }
      }
      if ((label|0) == 146) {
       $420 = ((($169)) + 8|0);
       $421 = HEAP32[$420>>2]|0;HEAP32[$420>>2] = (($421-1)|0);
       $422 = ($421|0)==(1);
       if ($422) {
        __THREW__ = 0;
        invoke_viii(3262,($169|0),1,1);
        $423 = __THREW__; __THREW__ = 0;
        $424 = $423&1;
        if ($424) {
         $441 = ___cxa_find_matching_catch_3(0|0)|0;
         $442 = tempRet0;
         ___clang_call_terminate($441);
         // unreachable;
        } else {
         $$16 = $$14579;$$1691 = $$1489578;
        }
       } else {
        $$16 = $$14579;$$1691 = $$1489578;
       }
      }
      $427 = HEAP32[$146>>2]|0;HEAP32[$146>>2] = (($427-1)|0);
      $428 = ($427|0)==(1);
      if (!($428)) {
       $$21 = $$16;$$2196 = $$1691;
       break L25;
      }
      __THREW__ = 0;
      invoke_viii(3262,($141|0),1,1);
      $429 = __THREW__; __THREW__ = 0;
      $430 = $429&1;
      if (!($430)) {
       $$21 = $$16;$$2196 = $$1691;
       break L25;
      }
      $441 = ___cxa_find_matching_catch_3(0|0)|0;
      $442 = tempRet0;
      ___clang_call_terminate($441);
      // unreachable;
     }
     }
    } while(0);
    if ((label|0) == 151) {
     __THREW__ = 0;
     invoke_vi(3289,($1|0));
     $431 = __THREW__; __THREW__ = 0;
     $432 = $431&1;
     if (!($432)) {
      $433 = ((($12)) + 11|0);
      $434 = HEAP8[$433>>0]|0;
      $435 = ($434<<24>>24)<(0);
      if ($435) {
       $436 = HEAP32[$12>>2]|0;
       __ZdlPv($436);
      }
      STACKTOP = sp;return;
     }
    }
    $95 = ___cxa_find_matching_catch_2()|0;
    $96 = tempRet0;
    $$21 = $95;$$2196 = $96;
   }
  }
 } while(0);
 if ((label|0) == 18) {
  $65 = ___cxa_find_matching_catch_2()|0;
  $66 = tempRet0;
  $$21 = $65;$$2196 = $66;
 }
 $437 = ((($12)) + 11|0);
 $438 = HEAP8[$437>>0]|0;
 $439 = ($438<<24>>24)<(0);
 if ($439) {
  $440 = HEAP32[$12>>2]|0;
  __ZdlPv($440);
 }
 $$22 = $$21;$$2297 = $$2196;
 ___resumeException($$22|0);
 // unreachable;
}
function __ZNK5osgGA15GUIEventHandler9cloneTypeEv($0) {
 $0 = $0|0;
 var $$cast$i$i = 0, $$cast$i$i$i = 0, $$cast$i2$i$i = 0, $$cast$i3$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(48)|0);
 $2 = ((($1)) + 16|0);
 __THREW__ = 0;
 invoke_vi(3282,($2|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $48 = ___cxa_find_matching_catch_2()|0;
  $49 = tempRet0;
  __ZdlPv($1);
  ___resumeException($48|0);
  // unreachable;
 } else {
  HEAP32[$2>>2] = (63412);
  $5 = ((($1)) + 28|0);
  ;HEAP32[$5>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;
  $6 = ((($1)) + 40|0);
  HEAP32[$6>>2] = 2;
  $7 = ((($1)) + 44|0);
  HEAP32[$7>>2] = 0;
  $8 = ((($1)) + 8|0);
  $9 = HEAP32[(43464)>>2]|0;
  HEAP32[$8>>2] = $9;
  $10 = HEAP32[(43468)>>2]|0;
  $$cast$i$i = $9;
  $11 = ((($$cast$i$i)) + -12|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($8) + ($12)|0);
  HEAP32[$13>>2] = $10;
  $14 = ((($1)) + 12|0);
  HEAP32[$14>>2] = 0;
  $15 = HEAP32[(43416)>>2]|0;
  HEAP32[$1>>2] = $15;
  $16 = HEAP32[(43420)>>2]|0;
  $$cast$i$i$i = $15;
  $17 = ((($$cast$i$i$i)) + -12|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (($1) + ($18)|0);
  HEAP32[$19>>2] = $16;
  $20 = HEAP32[(43424)>>2]|0;
  $21 = HEAP32[$1>>2]|0;
  $22 = ((($21)) + -16|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (($1) + ($23)|0);
  HEAP32[$24>>2] = $20;
  $25 = ((($1)) + 4|0);
  $26 = HEAP32[(43428)>>2]|0;
  HEAP32[$25>>2] = $26;
  $27 = HEAP32[(43432)>>2]|0;
  $$cast$i2$i$i = $26;
  $28 = ((($$cast$i2$i$i)) + -12|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = (($25) + ($29)|0);
  HEAP32[$30>>2] = $27;
  $31 = HEAP32[(43436)>>2]|0;
  $32 = HEAP32[$25>>2]|0;
  $33 = ((($32)) + -16|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = (($25) + ($34)|0);
  HEAP32[$35>>2] = $31;
  $36 = HEAP32[(43412)>>2]|0;
  HEAP32[$1>>2] = $36;
  $37 = HEAP32[(43440)>>2]|0;
  $$cast$i3$i = $36;
  $38 = ((($$cast$i3$i)) + -12|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = (($1) + ($39)|0);
  HEAP32[$40>>2] = $37;
  $41 = HEAP32[(43444)>>2]|0;
  $42 = HEAP32[$1>>2]|0;
  $43 = ((($42)) + -16|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = (($1) + ($44)|0);
  HEAP32[$45>>2] = $41;
  HEAP32[$1>>2] = (42768);
  HEAP32[$8>>2] = (43020);
  HEAP32[$2>>2] = (43268);
  HEAP32[$25>>2] = (42864);
  $46 = HEAP32[10688]|0;
  $47 = (($1) + ($46)|0);
  return ($47|0);
 }
 return (0)|0;
}
function __ZNK5osgGA15GUIEventHandler5cloneERKN3osg6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(48)|0);
 __THREW__ = 0;
 invoke_viii(3479,($2|0),($0|0),($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $9 = ___cxa_find_matching_catch_2()|0;
  $10 = tempRet0;
  __ZdlPv($2);
  ___resumeException($9|0);
  // unreachable;
 } else {
  $5 = HEAP32[$2>>2]|0;
  $6 = ((($5)) + -16|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($2) + ($7)|0);
  return ($8|0);
 }
 return (0)|0;
}
function __ZNK5osgGA15GUIEventHandler12isSameKindAsEPKN3osg6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,8992,-1)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK5osgGA15GUIEventHandler11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (109961|0);
}
function __ZNK5osgGA15GUIEventHandler9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (107677|0);
}
function __ZN5osgGA12EventHandler14asNodeCallbackEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ($0|0);
}
function __ZNK5osgGA12EventHandler14asNodeCallbackEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ($0|0);
}
function __ZN5osgGA12EventHandler3runEPN3osg6ObjectES3_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = HEAP32[$1>>2]|0;
 $4 = ((($3)) + 32|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_ii[$5 & 8191]($1)|0);
 $7 = HEAP32[$2>>2]|0;
 $8 = ((($7)) + 40|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (FUNCTION_TABLE_ii[$9 & 8191]($2)|0);
 $11 = HEAP32[$0>>2]|0;
 $12 = ((($11)) + 32|0);
 $13 = HEAP32[$12>>2]|0;
 FUNCTION_TABLE_viii[$13 & 8191]($0,$6,$10);
 return 1;
}
function __ZN9osgViewer15KeystoneHandlerD1Ev($0) {
 $0 = $0|0;
 var $$0 = 0, $$02 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vii(3480,($0|0),(39684|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if ($2) {
   $18 = ___cxa_find_matching_catch_2()|0;
   $19 = tempRet0;
   $20 = ((($0)) + 108|0);
   HEAP32[$20>>2] = ((29984));
   $21 = ((($20)) + 8|0);
   HEAP32[$21>>2] = ((30232));
   $22 = ((($0)) + 112|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = ($23|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$23>>2]|0;
    $26 = ((($25)) + -12|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = (($23) + ($27)|0);
    $29 = ((($28)) + 8|0);
    $30 = HEAP32[$29>>2]|0;HEAP32[$29>>2] = (($30-1)|0);
    $31 = ($30|0)==(1);
    if ($31) {
     __THREW__ = 0;
     invoke_viii(3262,($28|0),1,1);
     $32 = __THREW__; __THREW__ = 0;
     $33 = $32&1;
     if ($33) {
      $39 = ___cxa_find_matching_catch_3(0|0)|0;
      $40 = tempRet0;
      ___clang_call_terminate($39);
      // unreachable;
     }
    }
   }
   HEAP32[$22>>2] = 0;
   $$0 = $19;$$02 = $18;
  } else {
   $3 = ((($0)) + 108|0);
   HEAP32[$3>>2] = ((29984));
   $4 = ((($3)) + 8|0);
   HEAP32[$4>>2] = ((30232));
   $5 = ((($0)) + 112|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($6|0)==(0|0);
   if ($7) {
    HEAP32[$5>>2] = 0;
    $17 = ((($0)) + 116|0);
    __ZN3osg6ObjectD2Ev($17);
    return;
   }
   $8 = HEAP32[$6>>2]|0;
   $9 = ((($8)) + -12|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (($6) + ($10)|0);
   $12 = ((($11)) + 8|0);
   $13 = HEAP32[$12>>2]|0;HEAP32[$12>>2] = (($13-1)|0);
   $14 = ($13|0)==(1);
   if (!($14)) {
    HEAP32[$5>>2] = 0;
    $17 = ((($0)) + 116|0);
    __ZN3osg6ObjectD2Ev($17);
    return;
   }
   __THREW__ = 0;
   invoke_viii(3262,($11|0),1,1);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if ($16) {
    $34 = ___cxa_find_matching_catch_2()|0;
    $35 = tempRet0;
    $$0 = $35;$$02 = $34;
    break;
   } else {
    HEAP32[$5>>2] = 0;
    $17 = ((($0)) + 116|0);
    __ZN3osg6ObjectD2Ev($17);
    return;
   }
  }
 } while(0);
 $36 = ((($0)) + 116|0);
 __THREW__ = 0;
 invoke_vi(388,($36|0));
 $37 = __THREW__; __THREW__ = 0;
 $38 = $37&1;
 if ($38) {
  $39 = ___cxa_find_matching_catch_3(0|0)|0;
  $40 = tempRet0;
  ___clang_call_terminate($39);
  // unreachable;
 } else {
  ___resumeException($$02|0);
  // unreachable;
 }
}
function __ZN9osgViewer15KeystoneHandlerD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(420,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZN5osgGA12EventHandler23asDrawableEventCallbackEv($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 4|0);
 return ($1|0);
}
function __ZNK5osgGA12EventHandler23asDrawableEventCallbackEv($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 4|0);
 return ($1|0);
}
function __ZN5osgGA12EventHandler14asEventHandlerEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ($0|0);
}
function __ZNK5osgGA12EventHandler14asEventHandlerEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ($0|0);
}
function __ZNK5osgGA12EventHandler8getUsageERN3osg16ApplicationUsageE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN9osgViewer15KeystoneHandler6handleERKN5osgGA15GUIEventAdapterERNS1_16GUIActionAdapterEPN3osg6ObjectEPNS7_11NodeVisitorE($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$068240 = 0, $$1 = 0, $$off$i = 0, $$off$i108 = 0, $$off$i120 = 0, $$off$i131 = 0, $$off$i86 = 0, $$off$i97 = 0, $$sroa$0$0$$sroa_idx = 0, $$sroa$0141$0$$sroa_idx = 0, $$sroa$0146$0$$sroa_idx = 0, $$sroa$0151$0$$sroa_idx = 0, $$sroa$0156$0 = 0.0, $$sroa$0156$0$$sroa_idx = 0, $$sroa$0156$0$pre = 0.0, $$sroa$0167$0 = 0.0, $$sroa$0167$0$$sroa_idx = 0, $$sroa$0167$0$pre = 0.0, $$sroa$0199$0 = 0.0, $$sroa$0199$0$$sroa_idx = 0;
 var $$sroa$0199$0$pre = 0.0, $$sroa$0219$0 = 0.0, $$sroa$0219$0$$sroa_idx = 0, $$sroa$0219$0$pre = 0.0, $$sroa$3$0$$sroa_idx183 = 0, $$sroa$3$0$$sroa_idx184 = 0, $$sroa$3$0$$sroa_idx186 = 0, $$sroa$3$0$$sroa_idx186$sink = 0, $$sroa$3$0$copyload187 = 0.0, $$sroa$3193$0$$sroa_idx194 = 0, $$sroa$3193$0$$sroa_idx195 = 0, $$sroa$3193$0$$sroa_idx197 = 0, $$sroa$3193$0$$sroa_idx197$sink = 0, $$sroa$3193$0$copyload198 = 0.0, $$sroa$4$0$$sroa_idx140 = 0, $$sroa$4143$0$$sroa_idx145 = 0, $$sroa$4148$0$$sroa_idx150 = 0, $$sroa$4153$0$$sroa_idx155 = 0, $$sroa$6$0$$sroa_idx206 = 0, $$sroa$6$0$$sroa_idx207 = 0;
 var $$sroa$6$0$$sroa_idx209 = 0, $$sroa$6$0$$sroa_idx209$sink = 0, $$sroa$6$0$copyload210 = 0.0, $$sroa$6225$0$$sroa_idx227 = 0, $$sroa$6225$0$$sroa_idx228 = 0, $$sroa$6225$0$$sroa_idx230 = 0, $$sroa$6225$0$$sroa_idx230$sink = 0, $$sroa$6225$0$copyload231 = 0.0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0.0, $106 = 0, $107 = 0, $108 = 0.0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0.0, $114 = 0, $115 = 0, $116 = 0.0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0.0, $121 = 0.0, $122 = 0.0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0.0, $144 = 0.0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0;
 var $165 = 0, $166 = 0, $167 = 0, $168 = 0.0, $169 = 0.0, $17 = 0, $170 = 0, $171 = 0.0, $172 = 0.0, $173 = 0, $174 = 0.0, $175 = 0.0, $176 = 0, $177 = 0.0, $178 = 0, $179 = 0, $18 = 0, $180 = 0.0, $181 = 0, $182 = 0;
 var $183 = 0, $184 = 0, $185 = 0.0, $186 = 0, $187 = 0, $188 = 0.0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0.0, $194 = 0.0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0;
 var $201 = 0, $202 = 0, $203 = 0, $204 = 0.0, $205 = 0, $206 = 0.0, $207 = 0, $208 = 0, $209 = 0.0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0.0, $215 = 0, $216 = 0, $217 = 0.0, $218 = 0, $219 = 0;
 var $22 = 0, $220 = 0, $221 = 0.0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0.0, $231 = 0, $232 = 0.0, $233 = 0, $234 = 0, $235 = 0.0, $236 = 0, $237 = 0;
 var $238 = 0, $239 = 0, $24 = 0, $240 = 0.0, $241 = 0, $242 = 0, $243 = 0.0, $244 = 0, $245 = 0, $246 = 0, $247 = 0.0, $248 = 0.0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0;
 var $256 = 0, $257 = 0.0, $258 = 0, $259 = 0.0, $26 = 0, $260 = 0, $261 = 0, $262 = 0.0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0.0, $268 = 0, $269 = 0, $27 = 0, $270 = 0.0, $271 = 0, $272 = 0, $273 = 0;
 var $274 = 0.0, $275 = 0.0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0.0, $285 = 0, $286 = 0.0, $287 = 0, $288 = 0, $289 = 0.0, $29 = 0, $290 = 0, $291 = 0;
 var $292 = 0, $293 = 0, $294 = 0.0, $295 = 0, $296 = 0, $297 = 0.0, $298 = 0, $299 = 0, $30 = 0, $300 = 0, $301 = 0.0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0;
 var $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0.0, $315 = 0.0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0.0, $328 = 0.0;
 var $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0.0, $341 = 0.0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0;
 var $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0.0, $354 = 0.0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0.0, $74 = 0, $75 = 0.0, $76 = 0.0, $77 = 0, $78 = 0.0, $79 = 0.0, $8 = 0, $80 = 0.0, $81 = 0.0, $82 = 0.0;
 var $83 = 0, $84 = 0.0, $85 = 0, $86 = 0.0, $87 = 0.0, $88 = 0, $89 = 0.0, $9 = 0, $90 = 0.0, $91 = 0.0, $92 = 0.0, $93 = 0.0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $switch$i = 0, $switch$i109 = 0;
 var $switch$i121 = 0, $switch$i132 = 0, $switch$i87 = 0, $switch$i98 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(80|0);
 $5 = sp + 64|0;
 $6 = sp + 48|0;
 $7 = sp + 32|0;
 $8 = sp + 16|0;
 $9 = sp;
 $10 = ($3|0)==(0|0);
 if ($10) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $11 = HEAP32[$3>>2]|0;
 $12 = ((($11)) + 72|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (FUNCTION_TABLE_ii[$13 & 8191]($3)|0);
 $15 = ($14|0)==(0|0);
 if ($15) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $16 = ((($14)) + 288|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==(0|0);
 if ($18) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $19 = HEAP32[$1>>2]|0;
 $20 = ((($19)) + 148|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (FUNCTION_TABLE_ii[$21 & 8191]($1)|0);
 $23 = ($22|0)==(32);
 L10: do {
  if ($23) {
   $24 = ((($1)) + 116|0);
   $25 = HEAP32[$24>>2]|0;
   switch ($25|0) {
   case 8: case 4:  {
    break;
   }
   default: {
    break L10;
   }
   }
   $26 = ((($1)) + 80|0);
   $27 = HEAP32[$26>>2]|0;
   switch ($27|0) {
   case 103:  {
    $28 = ((($0)) + 104|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = ($29|0)==(0|0);
    if ($30) {
     $$1 = 1;
     STACKTOP = sp;return ($$1|0);
    }
    $31 = ((($29)) + 32|0);
    $32 = HEAP8[$31>>0]|0;
    $33 = $32 ^ 1;
    HEAP8[$31>>0] = $33;
    $$1 = 1;
    STACKTOP = sp;return ($$1|0);
    break;
   }
   case 114:  {
    $34 = ((($0)) + 100|0);
    HEAP32[$34>>2] = 0;
    $35 = ((($0)) + 96|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = ((($36)) + 56|0);
    HEAPF64[$37>>3] = -1.0;
    $38 = ((($36)) + 64|0);
    HEAPF64[$38>>3] = -1.0;
    $39 = ((($36)) + 72|0);
    HEAPF64[$39>>3] = 1.0;
    $40 = ((($36)) + 80|0);
    HEAPF64[$40>>3] = -1.0;
    $41 = ((($36)) + 88|0);
    HEAPF64[$41>>3] = -1.0;
    $42 = ((($36)) + 96|0);
    HEAPF64[$42>>3] = 1.0;
    $43 = ((($36)) + 104|0);
    HEAPF64[$43>>3] = 1.0;
    $44 = ((($36)) + 112|0);
    HEAPF64[$44>>3] = 1.0;
    $45 = ((($0)) + 104|0);
    $46 = HEAP32[$45>>2]|0;
    $47 = ((($46)) + 56|0);
    HEAPF64[$47>>3] = -1.0;
    $48 = ((($46)) + 64|0);
    HEAPF64[$48>>3] = -1.0;
    $49 = ((($46)) + 72|0);
    HEAPF64[$49>>3] = 1.0;
    $50 = ((($46)) + 80|0);
    HEAPF64[$50>>3] = -1.0;
    $51 = ((($46)) + 88|0);
    HEAPF64[$51>>3] = -1.0;
    $52 = ((($46)) + 96|0);
    HEAPF64[$52>>3] = 1.0;
    $53 = ((($46)) + 104|0);
    HEAPF64[$53>>3] = 1.0;
    $54 = ((($46)) + 112|0);
    HEAPF64[$54>>3] = 1.0;
    $$1 = 1;
    STACKTOP = sp;return ($$1|0);
    break;
   }
   case 115:  {
    $55 = ((($0)) + 8|0);
    $56 = HEAP32[$55>>2]|0;
    (__ZN9osgViewer8Keystone11writeToFileEv($56)|0);
    $$1 = 1;
    STACKTOP = sp;return ($$1|0);
    break;
   }
   default: {
    break L10;
   }
   }
  }
 } while(0);
 $57 = ((($1)) + 160|0);
 $58 = ((($1)) + 164|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = HEAP32[$57>>2]|0;
 $61 = ($59|0)==($60|0);
 $62 = $60;
 if ($61) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $63 = (($59) - ($60))|0;
 $64 = $63 >> 2;
 $$068240 = 0;
 while(1) {
  $67 = (($62) + ($$068240<<2)|0);
  $68 = HEAP32[$67>>2]|0;
  $69 = ((($68)) + 16|0);
  $70 = HEAP32[$69>>2]|0;
  $71 = ($70|0)==($3|0);
  $65 = (($$068240) + 1)|0;
  if ($71) {
   break;
  }
  $66 = ($65>>>0)<($64>>>0);
  if ($66) {
   $$068240 = $65;
  } else {
   $$1 = 0;
   label = 98;
   break;
  }
 }
 if ((label|0) == 98) {
  STACKTOP = sp;return ($$1|0);
 }
 $72 = ((($68)) + 20|0);
 $73 = +HEAPF32[$72>>2];
 $74 = ((($68)) + 24|0);
 $75 = +HEAPF32[$74>>2];
 $76 = $73 - $75;
 $77 = ((($68)) + 28|0);
 $78 = +HEAPF32[$77>>2];
 $79 = $78 - $75;
 $80 = $76 / $79;
 $81 = $80 * 2.0;
 $82 = $81 + -1.0;
 $83 = ((($68)) + 32|0);
 $84 = +HEAPF32[$83>>2];
 $85 = ((($68)) + 36|0);
 $86 = +HEAPF32[$85>>2];
 $87 = $84 - $86;
 $88 = ((($68)) + 40|0);
 $89 = +HEAPF32[$88>>2];
 $90 = $89 - $86;
 $91 = $87 / $90;
 $92 = $91 * 2.0;
 $93 = $92 + -1.0;
 $94 = ((($0)) + 104|0);
 $95 = HEAP32[$94>>2]|0;
 $96 = ($95|0)==(0|0);
 if ($96) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $97 = ((($95)) + 32|0);
 $98 = HEAP8[$97>>0]|0;
 $99 = ($98<<24>>24)==(0);
 if ($99) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $100 = HEAP32[$1>>2]|0;
 $101 = ((($100)) + 148|0);
 $102 = HEAP32[$101>>2]|0;
 $103 = (FUNCTION_TABLE_ii[$102 & 8191]($1)|0);
 switch ($103|0) {
 case 1:  {
  $104 = ((($0)) + 32|0);
  $105 = +HEAPF64[$104>>3];
  $106 = $105 != 0.0;
  if ($106) {
   label = 20;
  } else {
   $107 = ((($0)) + 40|0);
   $108 = +HEAPF64[$107>>3];
   $109 = $108 != 0.0;
   if ($109) {
    label = 20;
   } else {
    label = 22;
   }
  }
  L43: do {
   if ((label|0) == 20) {
    $110 = ((($1)) + 116|0);
    $111 = HEAP32[$110>>2]|0;
    switch ($111|0) {
    case 8: case 4:  {
     break;
    }
    default: {
     label = 22;
     break L43;
    }
    }
    $$sroa$6225$0$$sroa_idx230 = ((($0)) + 40|0);
    $$sroa$0219$0 = $105;$$sroa$6225$0$$sroa_idx230$sink = $$sroa$6225$0$$sroa_idx230;
   }
  } while(0);
  do {
   if ((label|0) == 22) {
    $112 = ((($0)) + 48|0);
    $113 = +HEAPF64[$112>>3];
    $114 = $113 != 0.0;
    if ($114) {
     label = 24;
    } else {
     $115 = ((($0)) + 56|0);
     $116 = +HEAPF64[$115>>3];
     $117 = $116 != 0.0;
     if ($117) {
      label = 24;
     }
    }
    if ((label|0) == 24) {
     $118 = ((($1)) + 116|0);
     $119 = HEAP32[$118>>2]|0;
     $$off$i120 = (($119) + -1)|0;
     $switch$i121 = ($$off$i120>>>0)<(2);
     if ($switch$i121) {
      $$sroa$6225$0$$sroa_idx228 = ((($0)) + 56|0);
      $$sroa$0219$0 = $113;$$sroa$6225$0$$sroa_idx230$sink = $$sroa$6225$0$$sroa_idx228;
      break;
     }
    }
    $$sroa$0219$0$$sroa_idx = ((($0)) + 16|0);
    $$sroa$6225$0$$sroa_idx227 = ((($0)) + 24|0);
    $$sroa$0219$0$pre = +HEAPF64[$$sroa$0219$0$$sroa_idx>>3];
    $$sroa$0219$0 = $$sroa$0219$0$pre;$$sroa$6225$0$$sroa_idx230$sink = $$sroa$6225$0$$sroa_idx227;
   }
  } while(0);
  $$sroa$6225$0$copyload231 = +HEAPF64[$$sroa$6225$0$$sroa_idx230$sink>>3];
  $120 = $$sroa$0219$0 * $$sroa$0219$0;
  $121 = $$sroa$6225$0$copyload231 * $$sroa$6225$0$copyload231;
  $122 = $120 + $121;
  $123 = $122 != 0.0;
  if (!($123)) {
   $147 = ((($0)) + 100|0);
   HEAP32[$147>>2] = 0;
   $$1 = 0;
   STACKTOP = sp;return ($$1|0);
  }
  $124 = (__ZNK9osgViewer15KeystoneHandler13computeRegionERKN5osgGA15GUIEventAdapterE(0,$1)|0);
  $125 = ((($0)) + 100|0);
  HEAP32[$125>>2] = $124;
  $126 = HEAP32[$94>>2]|0;
  $127 = ((($0)) + 96|0);
  $128 = HEAP32[$127>>2]|0;
  $129 = ($126|0)==($128|0);
  if (!($129)) {
   $130 = ((($126)) + 32|0);
   $131 = HEAP8[$130>>0]|0;
   $132 = ((($128)) + 32|0);
   HEAP8[$132>>0] = $131;
   $133 = ((($126)) + 36|0);
   $134 = ((($128)) + 36|0);
   ;HEAP32[$134>>2]=HEAP32[$133>>2]|0;HEAP32[$134+4>>2]=HEAP32[$133+4>>2]|0;HEAP32[$134+8>>2]=HEAP32[$133+8>>2]|0;HEAP32[$134+12>>2]=HEAP32[$133+12>>2]|0;
   $135 = ((($126)) + 56|0);
   $136 = ((($128)) + 56|0);
   ;HEAP32[$136>>2]=HEAP32[$135>>2]|0;HEAP32[$136+4>>2]=HEAP32[$135+4>>2]|0;HEAP32[$136+8>>2]=HEAP32[$135+8>>2]|0;HEAP32[$136+12>>2]=HEAP32[$135+12>>2]|0;
   $137 = ((($126)) + 72|0);
   $138 = ((($128)) + 72|0);
   ;HEAP32[$138>>2]=HEAP32[$137>>2]|0;HEAP32[$138+4>>2]=HEAP32[$137+4>>2]|0;HEAP32[$138+8>>2]=HEAP32[$137+8>>2]|0;HEAP32[$138+12>>2]=HEAP32[$137+12>>2]|0;
   $139 = ((($126)) + 88|0);
   $140 = ((($128)) + 88|0);
   ;HEAP32[$140>>2]=HEAP32[$139>>2]|0;HEAP32[$140+4>>2]=HEAP32[$139+4>>2]|0;HEAP32[$140+8>>2]=HEAP32[$139+8>>2]|0;HEAP32[$140+12>>2]=HEAP32[$139+12>>2]|0;
   $141 = ((($126)) + 104|0);
   $142 = ((($128)) + 104|0);
   ;HEAP32[$142>>2]=HEAP32[$141>>2]|0;HEAP32[$142+4>>2]=HEAP32[$141+4>>2]|0;HEAP32[$142+8>>2]=HEAP32[$141+8>>2]|0;HEAP32[$142+12>>2]=HEAP32[$141+12>>2]|0;
  }
  $143 = $82;
  $144 = $93;
  $145 = ((($0)) + 80|0);
  HEAPF64[$145>>3] = $143;
  $146 = ((($0)) + 88|0);
  HEAPF64[$146>>3] = $144;
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
  break;
 }
 case 8:  {
  $148 = ((($0)) + 100|0);
  $149 = HEAP32[$148>>2]|0;
  $150 = ($149|0)==(0);
  if ($150) {
   $$1 = 0;
   STACKTOP = sp;return ($$1|0);
  }
  $151 = ((($0)) + 96|0);
  $152 = HEAP32[$151>>2]|0;
  $153 = HEAP32[$94>>2]|0;
  $154 = ($152|0)==($153|0);
  if (!($154)) {
   $155 = ((($152)) + 32|0);
   $156 = HEAP8[$155>>0]|0;
   $157 = ((($153)) + 32|0);
   HEAP8[$157>>0] = $156;
   $158 = ((($152)) + 36|0);
   $159 = ((($153)) + 36|0);
   ;HEAP32[$159>>2]=HEAP32[$158>>2]|0;HEAP32[$159+4>>2]=HEAP32[$158+4>>2]|0;HEAP32[$159+8>>2]=HEAP32[$158+8>>2]|0;HEAP32[$159+12>>2]=HEAP32[$158+12>>2]|0;
   $160 = ((($152)) + 56|0);
   $161 = ((($153)) + 56|0);
   ;HEAP32[$161>>2]=HEAP32[$160>>2]|0;HEAP32[$161+4>>2]=HEAP32[$160+4>>2]|0;HEAP32[$161+8>>2]=HEAP32[$160+8>>2]|0;HEAP32[$161+12>>2]=HEAP32[$160+12>>2]|0;
   $162 = ((($152)) + 72|0);
   $163 = ((($153)) + 72|0);
   ;HEAP32[$163>>2]=HEAP32[$162>>2]|0;HEAP32[$163+4>>2]=HEAP32[$162+4>>2]|0;HEAP32[$163+8>>2]=HEAP32[$162+8>>2]|0;HEAP32[$163+12>>2]=HEAP32[$162+12>>2]|0;
   $164 = ((($152)) + 88|0);
   $165 = ((($153)) + 88|0);
   ;HEAP32[$165>>2]=HEAP32[$164>>2]|0;HEAP32[$165+4>>2]=HEAP32[$164+4>>2]|0;HEAP32[$165+8>>2]=HEAP32[$164+8>>2]|0;HEAP32[$165+12>>2]=HEAP32[$164+12>>2]|0;
   $166 = ((($152)) + 104|0);
   $167 = ((($153)) + 104|0);
   ;HEAP32[$167>>2]=HEAP32[$166>>2]|0;HEAP32[$167+4>>2]=HEAP32[$166+4>>2]|0;HEAP32[$167+8>>2]=HEAP32[$166+8>>2]|0;HEAP32[$167+12>>2]=HEAP32[$166+12>>2]|0;
  }
  $168 = $82;
  $169 = $93;
  $170 = ((($0)) + 80|0);
  $171 = +HEAPF64[$170>>3];
  $172 = $168 - $171;
  $173 = ((($0)) + 88|0);
  $174 = +HEAPF64[$173>>3];
  $175 = $169 - $174;
  $176 = ((($0)) + 32|0);
  $177 = +HEAPF64[$176>>3];
  $178 = $177 != 0.0;
  if ($178) {
   label = 37;
  } else {
   $179 = ((($0)) + 40|0);
   $180 = +HEAPF64[$179>>3];
   $181 = $180 != 0.0;
   if ($181) {
    label = 37;
   } else {
    label = 39;
   }
  }
  L72: do {
   if ((label|0) == 37) {
    $182 = ((($1)) + 116|0);
    $183 = HEAP32[$182>>2]|0;
    switch ($183|0) {
    case 8: case 4:  {
     break;
    }
    default: {
     label = 39;
     break L72;
    }
    }
    $$sroa$6$0$$sroa_idx209 = ((($0)) + 40|0);
    $$sroa$0199$0 = $177;$$sroa$6$0$$sroa_idx209$sink = $$sroa$6$0$$sroa_idx209;
   }
  } while(0);
  do {
   if ((label|0) == 39) {
    $184 = ((($0)) + 48|0);
    $185 = +HEAPF64[$184>>3];
    $186 = $185 != 0.0;
    if ($186) {
     label = 41;
    } else {
     $187 = ((($0)) + 56|0);
     $188 = +HEAPF64[$187>>3];
     $189 = $188 != 0.0;
     if ($189) {
      label = 41;
     }
    }
    if ((label|0) == 41) {
     $190 = ((($1)) + 116|0);
     $191 = HEAP32[$190>>2]|0;
     $$off$i131 = (($191) + -1)|0;
     $switch$i132 = ($$off$i131>>>0)<(2);
     if ($switch$i132) {
      $$sroa$6$0$$sroa_idx207 = ((($0)) + 56|0);
      $$sroa$0199$0 = $185;$$sroa$6$0$$sroa_idx209$sink = $$sroa$6$0$$sroa_idx207;
      break;
     }
    }
    $$sroa$0199$0$$sroa_idx = ((($0)) + 16|0);
    $$sroa$6$0$$sroa_idx206 = ((($0)) + 24|0);
    $$sroa$0199$0$pre = +HEAPF64[$$sroa$0199$0$$sroa_idx>>3];
    $$sroa$0199$0 = $$sroa$0199$0$pre;$$sroa$6$0$$sroa_idx209$sink = $$sroa$6$0$$sroa_idx206;
   }
  } while(0);
  $$sroa$6$0$copyload210 = +HEAPF64[$$sroa$6$0$$sroa_idx209$sink>>3];
  $192 = HEAP32[$148>>2]|0;
  $193 = $172 * $$sroa$0199$0;
  $194 = $175 * $$sroa$6$0$copyload210;
  HEAPF64[$5>>3] = $193;
  $195 = ((($5)) + 8|0);
  HEAPF64[$195>>3] = $194;
  __ZN9osgViewer15KeystoneHandler4moveENS0_6RegionERKN3osg5Vec2dE($0,$192,$5);
  $$1 = 1;
  STACKTOP = sp;return ($$1|0);
  break;
 }
 case 2:  {
  $196 = ((($0)) + 100|0);
  HEAP32[$196>>2] = 0;
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
  break;
 }
 case 32:  {
  $197 = HEAP32[$1>>2]|0;
  $198 = ((($197)) + 152|0);
  $199 = HEAP32[$198>>2]|0;
  $200 = (FUNCTION_TABLE_ii[$199 & 8191]($1)|0);
  $201 = ($200|0)==(65362);
  if ($201) {
   $202 = (__ZNK9osgViewer15KeystoneHandler13computeRegionERKN5osgGA15GUIEventAdapterE(0,$1)|0);
   $203 = ((($0)) + 72|0);
   $204 = +HEAPF64[$203>>3];
   $205 = ((($0)) + 32|0);
   $206 = +HEAPF64[$205>>3];
   $207 = $206 != 0.0;
   if ($207) {
    label = 49;
   } else {
    $208 = ((($0)) + 40|0);
    $209 = +HEAPF64[$208>>3];
    $210 = $209 != 0.0;
    if ($210) {
     label = 49;
    } else {
     label = 51;
    }
   }
   L92: do {
    if ((label|0) == 49) {
     $211 = ((($1)) + 116|0);
     $212 = HEAP32[$211>>2]|0;
     switch ($212|0) {
     case 8: case 4:  {
      break;
     }
     default: {
      label = 51;
      break L92;
     }
     }
     $$sroa$3193$0$$sroa_idx197 = ((($0)) + 40|0);
     $$sroa$3193$0$$sroa_idx197$sink = $$sroa$3193$0$$sroa_idx197;
    }
   } while(0);
   do {
    if ((label|0) == 51) {
     $213 = ((($0)) + 48|0);
     $214 = +HEAPF64[$213>>3];
     $215 = $214 != 0.0;
     if ($215) {
      label = 53;
     } else {
      $216 = ((($0)) + 56|0);
      $217 = +HEAPF64[$216>>3];
      $218 = $217 != 0.0;
      if ($218) {
       label = 53;
      }
     }
     if ((label|0) == 53) {
      $219 = ((($1)) + 116|0);
      $220 = HEAP32[$219>>2]|0;
      $$off$i108 = (($220) + -1)|0;
      $switch$i109 = ($$off$i108>>>0)<(2);
      if ($switch$i109) {
       $$sroa$3193$0$$sroa_idx195 = ((($0)) + 56|0);
       $$sroa$3193$0$$sroa_idx197$sink = $$sroa$3193$0$$sroa_idx195;
       break;
      }
     }
     $$sroa$3193$0$$sroa_idx194 = ((($0)) + 24|0);
     $$sroa$3193$0$$sroa_idx197$sink = $$sroa$3193$0$$sroa_idx194;
    }
   } while(0);
   $$sroa$3193$0$copyload198 = +HEAPF64[$$sroa$3193$0$$sroa_idx197$sink>>3];
   $221 = $204 * $$sroa$3193$0$copyload198;
   HEAPF64[$6>>3] = 0.0;
   $222 = ((($6)) + 8|0);
   HEAPF64[$222>>3] = $221;
   __ZN9osgViewer15KeystoneHandler4moveENS0_6RegionERKN3osg5Vec2dE($0,$202,$6);
   $$1 = 0;
   STACKTOP = sp;return ($$1|0);
  }
  $223 = HEAP32[$1>>2]|0;
  $224 = ((($223)) + 152|0);
  $225 = HEAP32[$224>>2]|0;
  $226 = (FUNCTION_TABLE_ii[$225 & 8191]($1)|0);
  $227 = ($226|0)==(65364);
  if ($227) {
   $228 = (__ZNK9osgViewer15KeystoneHandler13computeRegionERKN5osgGA15GUIEventAdapterE(0,$1)|0);
   $229 = ((($0)) + 72|0);
   $230 = +HEAPF64[$229>>3];
   $231 = ((($0)) + 32|0);
   $232 = +HEAPF64[$231>>3];
   $233 = $232 != 0.0;
   if ($233) {
    label = 60;
   } else {
    $234 = ((($0)) + 40|0);
    $235 = +HEAPF64[$234>>3];
    $236 = $235 != 0.0;
    if ($236) {
     label = 60;
    } else {
     label = 62;
    }
   }
   L110: do {
    if ((label|0) == 60) {
     $237 = ((($1)) + 116|0);
     $238 = HEAP32[$237>>2]|0;
     switch ($238|0) {
     case 8: case 4:  {
      break;
     }
     default: {
      label = 62;
      break L110;
     }
     }
     $$sroa$3$0$$sroa_idx186 = ((($0)) + 40|0);
     $$sroa$3$0$$sroa_idx186$sink = $$sroa$3$0$$sroa_idx186;
    }
   } while(0);
   do {
    if ((label|0) == 62) {
     $239 = ((($0)) + 48|0);
     $240 = +HEAPF64[$239>>3];
     $241 = $240 != 0.0;
     if ($241) {
      label = 64;
     } else {
      $242 = ((($0)) + 56|0);
      $243 = +HEAPF64[$242>>3];
      $244 = $243 != 0.0;
      if ($244) {
       label = 64;
      }
     }
     if ((label|0) == 64) {
      $245 = ((($1)) + 116|0);
      $246 = HEAP32[$245>>2]|0;
      $$off$i97 = (($246) + -1)|0;
      $switch$i98 = ($$off$i97>>>0)<(2);
      if ($switch$i98) {
       $$sroa$3$0$$sroa_idx184 = ((($0)) + 56|0);
       $$sroa$3$0$$sroa_idx186$sink = $$sroa$3$0$$sroa_idx184;
       break;
      }
     }
     $$sroa$3$0$$sroa_idx183 = ((($0)) + 24|0);
     $$sroa$3$0$$sroa_idx186$sink = $$sroa$3$0$$sroa_idx183;
    }
   } while(0);
   $$sroa$3$0$copyload187 = +HEAPF64[$$sroa$3$0$$sroa_idx186$sink>>3];
   $247 = $230 * $$sroa$3$0$copyload187;
   $248 = -$247;
   HEAPF64[$7>>3] = 0.0;
   $249 = ((($7)) + 8|0);
   HEAPF64[$249>>3] = $248;
   __ZN9osgViewer15KeystoneHandler4moveENS0_6RegionERKN3osg5Vec2dE($0,$228,$7);
   $$1 = 0;
   STACKTOP = sp;return ($$1|0);
  }
  $250 = HEAP32[$1>>2]|0;
  $251 = ((($250)) + 152|0);
  $252 = HEAP32[$251>>2]|0;
  $253 = (FUNCTION_TABLE_ii[$252 & 8191]($1)|0);
  $254 = ($253|0)==(65361);
  if ($254) {
   $255 = (__ZNK9osgViewer15KeystoneHandler13computeRegionERKN5osgGA15GUIEventAdapterE(0,$1)|0);
   $256 = ((($0)) + 64|0);
   $257 = +HEAPF64[$256>>3];
   $258 = ((($0)) + 32|0);
   $259 = +HEAPF64[$258>>3];
   $260 = $259 != 0.0;
   if ($260) {
    label = 71;
   } else {
    $261 = ((($0)) + 40|0);
    $262 = +HEAPF64[$261>>3];
    $263 = $262 != 0.0;
    if ($263) {
     label = 71;
    } else {
     label = 72;
    }
   }
   if ((label|0) == 71) {
    $264 = ((($1)) + 116|0);
    $265 = HEAP32[$264>>2]|0;
    switch ($265|0) {
    case 8: case 4:  {
     $$sroa$0167$0 = $259;
     break;
    }
    default: {
     label = 72;
    }
    }
   }
   do {
    if ((label|0) == 72) {
     $266 = ((($0)) + 48|0);
     $267 = +HEAPF64[$266>>3];
     $268 = $267 != 0.0;
     if ($268) {
      label = 74;
     } else {
      $269 = ((($0)) + 56|0);
      $270 = +HEAPF64[$269>>3];
      $271 = $270 != 0.0;
      if ($271) {
       label = 74;
      }
     }
     if ((label|0) == 74) {
      $272 = ((($1)) + 116|0);
      $273 = HEAP32[$272>>2]|0;
      $$off$i86 = (($273) + -1)|0;
      $switch$i87 = ($$off$i86>>>0)<(2);
      if ($switch$i87) {
       $$sroa$0167$0 = $267;
       break;
      }
     }
     $$sroa$0167$0$$sroa_idx = ((($0)) + 16|0);
     $$sroa$0167$0$pre = +HEAPF64[$$sroa$0167$0$$sroa_idx>>3];
     $$sroa$0167$0 = $$sroa$0167$0$pre;
    }
   } while(0);
   $274 = $257 * $$sroa$0167$0;
   $275 = -$274;
   HEAPF64[$8>>3] = $275;
   $276 = ((($8)) + 8|0);
   HEAPF64[$276>>3] = 0.0;
   __ZN9osgViewer15KeystoneHandler4moveENS0_6RegionERKN3osg5Vec2dE($0,$255,$8);
   $$1 = 0;
   STACKTOP = sp;return ($$1|0);
  }
  $277 = HEAP32[$1>>2]|0;
  $278 = ((($277)) + 152|0);
  $279 = HEAP32[$278>>2]|0;
  $280 = (FUNCTION_TABLE_ii[$279 & 8191]($1)|0);
  $281 = ($280|0)==(65363);
  if ($281) {
   $282 = (__ZNK9osgViewer15KeystoneHandler13computeRegionERKN5osgGA15GUIEventAdapterE(0,$1)|0);
   $283 = ((($0)) + 64|0);
   $284 = +HEAPF64[$283>>3];
   $285 = ((($0)) + 32|0);
   $286 = +HEAPF64[$285>>3];
   $287 = $286 != 0.0;
   if ($287) {
    label = 80;
   } else {
    $288 = ((($0)) + 40|0);
    $289 = +HEAPF64[$288>>3];
    $290 = $289 != 0.0;
    if ($290) {
     label = 80;
    } else {
     label = 81;
    }
   }
   if ((label|0) == 80) {
    $291 = ((($1)) + 116|0);
    $292 = HEAP32[$291>>2]|0;
    switch ($292|0) {
    case 8: case 4:  {
     $$sroa$0156$0 = $286;
     break;
    }
    default: {
     label = 81;
    }
    }
   }
   do {
    if ((label|0) == 81) {
     $293 = ((($0)) + 48|0);
     $294 = +HEAPF64[$293>>3];
     $295 = $294 != 0.0;
     if ($295) {
      label = 83;
     } else {
      $296 = ((($0)) + 56|0);
      $297 = +HEAPF64[$296>>3];
      $298 = $297 != 0.0;
      if ($298) {
       label = 83;
      }
     }
     if ((label|0) == 83) {
      $299 = ((($1)) + 116|0);
      $300 = HEAP32[$299>>2]|0;
      $$off$i = (($300) + -1)|0;
      $switch$i = ($$off$i>>>0)<(2);
      if ($switch$i) {
       $$sroa$0156$0 = $294;
       break;
      }
     }
     $$sroa$0156$0$$sroa_idx = ((($0)) + 16|0);
     $$sroa$0156$0$pre = +HEAPF64[$$sroa$0156$0$$sroa_idx>>3];
     $$sroa$0156$0 = $$sroa$0156$0$pre;
    }
   } while(0);
   $301 = $284 * $$sroa$0156$0;
   HEAPF64[$9>>3] = $301;
   $302 = ((($9)) + 8|0);
   HEAPF64[$302>>3] = 0.0;
   __ZN9osgViewer15KeystoneHandler4moveENS0_6RegionERKN3osg5Vec2dE($0,$282,$9);
   $$1 = 0;
   STACKTOP = sp;return ($$1|0);
  }
  $303 = HEAP32[$1>>2]|0;
  $304 = ((($303)) + 152|0);
  $305 = HEAP32[$304>>2]|0;
  $306 = (FUNCTION_TABLE_ii[$305 & 8191]($1)|0);
  $307 = ($306|0)==(65463);
  if (!($307)) {
   $308 = HEAP32[$1>>2]|0;
   $309 = ((($308)) + 152|0);
   $310 = HEAP32[$309>>2]|0;
   $311 = (FUNCTION_TABLE_ii[$310 & 8191]($1)|0);
   $312 = ($311|0)==(65429);
   if (!($312)) {
    $316 = HEAP32[$1>>2]|0;
    $317 = ((($316)) + 152|0);
    $318 = HEAP32[$317>>2]|0;
    $319 = (FUNCTION_TABLE_ii[$318 & 8191]($1)|0);
    $320 = ($319|0)==(65465);
    if (!($320)) {
     $321 = HEAP32[$1>>2]|0;
     $322 = ((($321)) + 152|0);
     $323 = HEAP32[$322>>2]|0;
     $324 = (FUNCTION_TABLE_ii[$323 & 8191]($1)|0);
     $325 = ($324|0)==(65434);
     if (!($325)) {
      $329 = HEAP32[$1>>2]|0;
      $330 = ((($329)) + 152|0);
      $331 = HEAP32[$330>>2]|0;
      $332 = (FUNCTION_TABLE_ii[$331 & 8191]($1)|0);
      $333 = ($332|0)==(65459);
      do {
       if (!($333)) {
        $334 = HEAP32[$1>>2]|0;
        $335 = ((($334)) + 152|0);
        $336 = HEAP32[$335>>2]|0;
        $337 = (FUNCTION_TABLE_ii[$336 & 8191]($1)|0);
        $338 = ($337|0)==(65435);
        if ($338) {
         break;
        }
        $342 = HEAP32[$1>>2]|0;
        $343 = ((($342)) + 152|0);
        $344 = HEAP32[$343>>2]|0;
        $345 = (FUNCTION_TABLE_ii[$344 & 8191]($1)|0);
        $346 = ($345|0)==(65457);
        do {
         if (!($346)) {
          $347 = HEAP32[$1>>2]|0;
          $348 = ((($347)) + 152|0);
          $349 = HEAP32[$348>>2]|0;
          $350 = (FUNCTION_TABLE_ii[$349 & 8191]($1)|0);
          $351 = ($350|0)==(65436);
          if ($351) {
           break;
          } else {
           $$1 = 0;
          }
          STACKTOP = sp;return ($$1|0);
         }
        } while(0);
        $352 = HEAP32[$94>>2]|0;
        $353 = $82;
        $354 = $93;
        $$sroa$0$0$$sroa_idx = ((($352)) + 56|0);
        HEAPF64[$$sroa$0$0$$sroa_idx>>3] = $353;
        $$sroa$4$0$$sroa_idx140 = ((($352)) + 64|0);
        HEAPF64[$$sroa$4$0$$sroa_idx140>>3] = $354;
        $$1 = 0;
        STACKTOP = sp;return ($$1|0);
       }
      } while(0);
      $339 = HEAP32[$94>>2]|0;
      $340 = $82;
      $341 = $93;
      $$sroa$0141$0$$sroa_idx = ((($339)) + 72|0);
      HEAPF64[$$sroa$0141$0$$sroa_idx>>3] = $340;
      $$sroa$4143$0$$sroa_idx145 = ((($339)) + 80|0);
      HEAPF64[$$sroa$4143$0$$sroa_idx145>>3] = $341;
      $$1 = 0;
      STACKTOP = sp;return ($$1|0);
     }
    }
    $326 = HEAP32[$94>>2]|0;
    $327 = $82;
    $328 = $93;
    $$sroa$0146$0$$sroa_idx = ((($326)) + 104|0);
    HEAPF64[$$sroa$0146$0$$sroa_idx>>3] = $327;
    $$sroa$4148$0$$sroa_idx150 = ((($326)) + 112|0);
    HEAPF64[$$sroa$4148$0$$sroa_idx150>>3] = $328;
    $$1 = 0;
    STACKTOP = sp;return ($$1|0);
   }
  }
  $313 = HEAP32[$94>>2]|0;
  $314 = $82;
  $315 = $93;
  $$sroa$0151$0$$sroa_idx = ((($313)) + 88|0);
  HEAPF64[$$sroa$0151$0$$sroa_idx>>3] = $314;
  $$sroa$4153$0$$sroa_idx155 = ((($313)) + 96|0);
  HEAPF64[$$sroa$4153$0$$sroa_idx155>>3] = $315;
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
  break;
 }
 default: {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 }
 return (0)|0;
}
function __ZN5osgGA15GUIEventHandler6handleERKNS_15GUIEventAdapterERNS_16GUIActionAdapterE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function __ZThn4_NK5osgGA15GUIEventHandler9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -4|0);
 $2 = (__ZNK5osgGA15GUIEventHandler9cloneTypeEv($1)|0);
 return ($2|0);
}
function __ZThn4_NK5osgGA15GUIEventHandler5cloneERKN3osg6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + -4|0);
 $3 = (__Znwj(48)|0);
 __THREW__ = 0;
 invoke_viii(3479,($3|0),($2|0),($1|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch_2()|0;
  $7 = tempRet0;
  __ZdlPv($3);
  ___resumeException($6|0);
  // unreachable;
 } else {
  $8 = HEAP32[$3>>2]|0;
  $9 = ((($8)) + -16|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($3) + ($10)|0);
  return ($11|0);
 }
 return (0)|0;
}
function __ZThn4_NK5osgGA15GUIEventHandler12isSameKindAsEPKN3osg6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,8992,-1)|0);
 $phitmp$i = ($3|0)!=(0|0);
 $4 = $phitmp$i;
 return ($4|0);
}
function __ZThn4_NK5osgGA15GUIEventHandler11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (109961|0);
}
function __ZThn4_NK5osgGA15GUIEventHandler9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (107677|0);
}
function __ZThn4_N5osgGA12EventHandler23asDrawableEventCallbackEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -4|0);
 $2 = ((($1)) + 4|0);
 return ($2|0);
}
function __ZThn4_NK5osgGA12EventHandler23asDrawableEventCallbackEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -4|0);
 $2 = ((($1)) + 4|0);
 return ($2|0);
}
function __ZThn4_N5osgGA12EventHandler3runEPN3osg6ObjectES3_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + -4|0);
 $4 = HEAP32[$1>>2]|0;
 $5 = ((($4)) + 32|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_ii[$6 & 8191]($1)|0);
 $8 = HEAP32[$2>>2]|0;
 $9 = ((($8)) + 40|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (FUNCTION_TABLE_ii[$10 & 8191]($2)|0);
 $12 = HEAP32[$3>>2]|0;
 $13 = ((($12)) + 32|0);
 $14 = HEAP32[$13>>2]|0;
 FUNCTION_TABLE_viii[$14 & 8191]($3,$7,$11);
 return 1;
}
function __ZThn4_N9osgViewer15KeystoneHandlerD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -4|0);
 __ZN9osgViewer15KeystoneHandlerD1Ev($1);
 return;
}
function __ZThn4_N9osgViewer15KeystoneHandlerD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -4|0);
 __THREW__ = 0;
 invoke_vi(420,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch_2()|0;
  $5 = tempRet0;
  __ZdlPv($1);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZdlPv($1);
  return;
 }
}
function __ZTv0_n16_NK5osgGA15GUIEventHandler9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 $5 = (__ZNK5osgGA15GUIEventHandler9cloneTypeEv($4)|0);
 return ($5|0);
}
function __ZTv0_n20_NK5osgGA15GUIEventHandler5cloneERKN3osg6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $3 = ((($2)) + -20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($0) + ($4)|0);
 $6 = (__Znwj(48)|0);
 __THREW__ = 0;
 invoke_viii(3479,($6|0),($5|0),($1|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch_2()|0;
  $10 = tempRet0;
  __ZdlPv($6);
  ___resumeException($9|0);
  // unreachable;
 } else {
  $11 = HEAP32[$6>>2]|0;
  $12 = ((($11)) + -16|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($6) + ($13)|0);
  return ($14|0);
 }
 return (0)|0;
}
function __ZTv0_n24_NK5osgGA15GUIEventHandler12isSameKindAsEPKN3osg6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,8992,-1)|0);
 $phitmp$i = ($3|0)!=(0|0);
 $4 = $phitmp$i;
 return ($4|0);
}
function __ZTv0_n28_NK5osgGA15GUIEventHandler11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (109961|0);
}
function __ZTv0_n32_NK5osgGA15GUIEventHandler9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (107677|0);
}
function __ZN3osg8Callback10asCallbackEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ($0|0);
}
function __ZNK3osg8Callback10asCallbackEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ($0|0);
}
function __ZN3osg8Callback16asCallbackObjectEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZNK3osg8Callback16asCallbackObjectEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZTv0_n52_N5osgGA12EventHandler14asNodeCallbackEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -52|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 return ($4|0);
}
function __ZTv0_n56_NK5osgGA12EventHandler14asNodeCallbackEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -56|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 return ($4|0);
}
function __ZN3osg8Callback24asStateAttributeCallbackEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZNK3osg8Callback24asStateAttributeCallbackEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZN3osg8Callback17asUniformCallbackEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZNK3osg8Callback17asUniformCallbackEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZN3osg8Callback24asDrawableUpdateCallbackEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZNK3osg8Callback24asDrawableUpdateCallbackEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZTv0_n84_N5osgGA12EventHandler23asDrawableEventCallbackEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -84|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 $5 = ((($4)) + 4|0);
 return ($5|0);
}
function __ZTv0_n88_NK5osgGA12EventHandler23asDrawableEventCallbackEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -88|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 $5 = ((($4)) + 4|0);
 return ($5|0);
}
function __ZN3osg8Callback22asDrawableCullCallbackEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZNK3osg8Callback22asDrawableCullCallbackEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZTv0_n100_N5osgGA12EventHandler14asEventHandlerEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -100|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 return ($4|0);
}
function __ZTv0_n104_NK5osgGA12EventHandler14asEventHandlerEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -104|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 return ($4|0);
}
function __ZTv0_n108_N5osgGA12EventHandler3runEPN3osg6ObjectES3_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = HEAP32[$0>>2]|0;
 $4 = ((($3)) + -108|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($0) + ($5)|0);
 $7 = HEAP32[$1>>2]|0;
 $8 = ((($7)) + 32|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (FUNCTION_TABLE_ii[$9 & 8191]($1)|0);
 $11 = HEAP32[$2>>2]|0;
 $12 = ((($11)) + 40|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (FUNCTION_TABLE_ii[$13 & 8191]($2)|0);
 $15 = HEAP32[$6>>2]|0;
 $16 = ((($15)) + 32|0);
 $17 = HEAP32[$16>>2]|0;
 FUNCTION_TABLE_viii[$17 & 8191]($6,$10,$14);
 return 1;
}
function __ZTv0_n112_N9osgViewer15KeystoneHandlerD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -112|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __ZN9osgViewer15KeystoneHandlerD1Ev($4);
 return;
}
function __ZTv0_n112_N9osgViewer15KeystoneHandlerD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -112|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __THREW__ = 0;
 invoke_vi(420,($4|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $7 = ___cxa_find_matching_catch_2()|0;
  $8 = tempRet0;
  __ZdlPv($4);
  ___resumeException($7|0);
  // unreachable;
 } else {
  __ZdlPv($4);
  return;
 }
}
function __ZTv0_n16_N9osgViewer15KeystoneHandlerD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __ZN9osgViewer15KeystoneHandlerD1Ev($4);
 return;
}
function __ZTv0_n16_N9osgViewer15KeystoneHandlerD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __THREW__ = 0;
 invoke_vi(420,($4|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $7 = ___cxa_find_matching_catch_2()|0;
  $8 = tempRet0;
  __ZdlPv($4);
  ___resumeException($7|0);
  // unreachable;
 } else {
  __ZdlPv($4);
  return;
 }
}
function __ZTv0_n20_NK5osgGA15GUIEventHandler9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -20|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 $5 = (__ZNK5osgGA15GUIEventHandler9cloneTypeEv($4)|0);
 return ($5|0);
}
function __ZTv0_n24_NK5osgGA15GUIEventHandler5cloneERKN3osg6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $3 = ((($2)) + -24|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($0) + ($4)|0);
 $6 = (__Znwj(48)|0);
 __THREW__ = 0;
 invoke_viii(3479,($6|0),($5|0),($1|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch_2()|0;
  $10 = tempRet0;
  __ZdlPv($6);
  ___resumeException($9|0);
  // unreachable;
 } else {
  $11 = HEAP32[$6>>2]|0;
  $12 = ((($11)) + -16|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($6) + ($13)|0);
  return ($14|0);
 }
 return (0)|0;
}
function __ZTv0_n28_NK5osgGA15GUIEventHandler12isSameKindAsEPKN3osg6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,8992,-1)|0);
 $phitmp$i = ($3|0)!=(0|0);
 $4 = $phitmp$i;
 return ($4|0);
}
function __ZTv0_n32_NK5osgGA15GUIEventHandler11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (109961|0);
}
function __ZTv0_n36_NK5osgGA15GUIEventHandler9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (107677|0);
}
function __ZTv0_n96_N3osg8Callback10asCallbackEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -96|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 return ($4|0);
}
function __ZTv0_n100_NK3osg8Callback10asCallbackEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -100|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 return ($4|0);
}
function __ZTv0_n104_N3osg8Callback16asCallbackObjectEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZTv0_n108_NK3osg8Callback16asCallbackObjectEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZN5osgGA15GUIEventHandlerC1ERKS0_RKN3osg6CopyOpE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$cast$i = 0, $$cast$i$i = 0, $$cast$i6$i = 0, $$cast$i9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 16|0);
 $4 = HEAP32[$1>>2]|0;
 $5 = ((($4)) + -16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($1) + ($6)|0);
 __ZN3osg6ObjectC2ERKS0_RKNS_6CopyOpE($3,$7,$2);
 $8 = ((($0)) + 8|0);
 $9 = HEAP32[$1>>2]|0;
 $10 = ((($9)) + -12|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($1) + ($11)|0);
 $13 = HEAP32[(43464)>>2]|0;
 HEAP32[$8>>2] = $13;
 $14 = HEAP32[(43468)>>2]|0;
 $$cast$i = $13;
 $15 = ((($$cast$i)) + -12|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($8) + ($16)|0);
 HEAP32[$17>>2] = $14;
 $18 = ((($0)) + 12|0);
 $19 = ((($12)) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 HEAP32[$18>>2] = $20;
 $21 = ($20|0)==(0|0);
 if (!($21)) {
  $22 = HEAP32[$20>>2]|0;
  $23 = ((($22)) + -12|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = (($20) + ($24)|0);
  $26 = ((($25)) + 8|0);
  $27 = HEAP32[$26>>2]|0;HEAP32[$26>>2] = (($27+1)|0);
 }
 $28 = HEAP32[(43416)>>2]|0;
 HEAP32[$0>>2] = $28;
 $29 = HEAP32[(43420)>>2]|0;
 $$cast$i$i = $28;
 $30 = ((($$cast$i$i)) + -12|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (($0) + ($31)|0);
 HEAP32[$32>>2] = $29;
 $33 = HEAP32[(43424)>>2]|0;
 $34 = HEAP32[$0>>2]|0;
 $35 = ((($34)) + -16|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = (($0) + ($36)|0);
 HEAP32[$37>>2] = $33;
 $38 = ((($0)) + 4|0);
 $39 = HEAP32[(43428)>>2]|0;
 HEAP32[$38>>2] = $39;
 $40 = HEAP32[(43432)>>2]|0;
 $$cast$i6$i = $39;
 $41 = ((($$cast$i6$i)) + -12|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = (($38) + ($42)|0);
 HEAP32[$43>>2] = $40;
 $44 = HEAP32[(43436)>>2]|0;
 $45 = HEAP32[$38>>2]|0;
 $46 = ((($45)) + -16|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = (($38) + ($47)|0);
 HEAP32[$48>>2] = $44;
 $49 = HEAP32[(43412)>>2]|0;
 HEAP32[$0>>2] = $49;
 $50 = HEAP32[(43440)>>2]|0;
 $$cast$i9 = $49;
 $51 = ((($$cast$i9)) + -12|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = (($0) + ($52)|0);
 HEAP32[$53>>2] = $50;
 $54 = HEAP32[(43444)>>2]|0;
 $55 = HEAP32[$0>>2]|0;
 $56 = ((($55)) + -16|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = (($0) + ($57)|0);
 HEAP32[$58>>2] = $54;
 HEAP32[$0>>2] = (42768);
 HEAP32[$8>>2] = (43020);
 HEAP32[$3>>2] = (43268);
 $59 = ((($0)) + 4|0);
 HEAP32[$59>>2] = (42864);
 return;
}
function __ZN9osgViewer8Keystone11writeToFileEv($0) {
 $0 = $0|0;
 var $$012 = 0, $$01617$i = 0, $$2 = 0, $$211 = 0, $$ph = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $1 = sp + 24|0;
 $2 = sp + 12|0;
 $3 = sp;
 ;HEAP32[$2>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;
 $4 = ((($0)) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 L1: do {
  if ($6) {
   $$012 = 0;
  } else {
   ;HEAP32[$3>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;
   $7 = ((($3)) + 11|0);
   HEAP8[$7>>0] = 8;
   $8 = $3;
   $9 = $8;
   HEAP32[$9>>2] = 1701603686;
   $10 = (($8) + 4)|0;
   $11 = $10;
   HEAP32[$11>>2] = 1701667182;
   $12 = ((($3)) + 8|0);
   HEAP8[$12>>0] = 0;
   $13 = HEAP32[$0>>2]|0;
   $14 = ((($13)) + 108|0);
   $15 = HEAP32[$14>>2]|0;
   __THREW__ = 0;
   $16 = (invoke_ii($15|0,($0|0))|0);
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   L3: do {
    if ($18) {
     label = 29;
    } else {
     $19 = ($16|0)==(0|0);
     if ($19) {
      $20 = HEAP32[$4>>2]|0;
      $21 = ($20|0)==(0|0);
      if ($21) {
       $$ph = 0;
      } else {
       $$01617$i = $20;
       label = 5;
      }
     } else {
      $$01617$i = $16;
      label = 5;
     }
     if ((label|0) == 5) {
      $22 = HEAP32[$$01617$i>>2]|0;
      $23 = ((($22)) + 176|0);
      $24 = HEAP32[$23>>2]|0;
      __THREW__ = 0;
      $25 = (invoke_iiii($24|0,($$01617$i|0),($3|0),0)|0);
      $26 = __THREW__; __THREW__ = 0;
      $27 = $26&1;
      if ($27) {
       label = 29;
       break;
      }
      $28 = ($25|0)==(0|0);
      if ($28) {
       $$ph = 0;
      } else {
       $29 = HEAP32[$25>>2]|0;
       $30 = ((($29)) + -4|0);
       $31 = HEAP32[$30>>2]|0;
       $32 = ((($31)) + 4|0);
       $33 = HEAP32[$32>>2]|0;
       $34 = ($33|0)==(107693|0);
       if ($34) {
        $35 = ((($25)) + 32|0);
        __THREW__ = 0;
        (invoke_iii(3477,($2|0),($35|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         label = 29;
         break;
        } else {
         $$ph = 1;
        }
       } else {
        $$ph = 0;
       }
      }
     }
     $38 = HEAP8[$7>>0]|0;
     $39 = ($38<<24>>24)<(0);
     if ($39) {
      $40 = HEAP32[$3>>2]|0;
      __ZdlPv($40);
     }
     if (!($$ph)) {
      $$012 = 0;
      break L1;
     }
     $41 = HEAP32[$4>>2]|0;
     $42 = ($41|0)==(0|0);
     if (!($42)) {
      $43 = ((($41)) + 8|0);
      $44 = HEAP32[$43>>2]|0;HEAP32[$43>>2] = (($44+1)|0);
     }
     __THREW__ = 0;
     invoke_vii(3481,($0|0),(0|0));
     $45 = __THREW__; __THREW__ = 0;
     $46 = $45&1;
     L20: do {
      if ($46) {
       label = 32;
      } else {
       __THREW__ = 0;
       $47 = (invoke_ii(3265,3)|0);
       $48 = __THREW__; __THREW__ = 0;
       $49 = $48&1;
       if ($49) {
        label = 32;
       } else {
        do {
         if ($47) {
          __THREW__ = 0;
          $50 = (invoke_ii(3266,3)|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           label = 32;
           break L20;
          }
          __THREW__ = 0;
          $53 = (invoke_iiii(3267,($50|0),(107787|0),21)|0);
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           label = 32;
           break L20;
          }
          $56 = ((($2)) + 11|0);
          $57 = HEAP8[$56>>0]|0;
          $58 = ($57<<24>>24)<(0);
          $59 = HEAP32[$2>>2]|0;
          $60 = $58 ? $59 : $2;
          $61 = ((($2)) + 4|0);
          $62 = HEAP32[$61>>2]|0;
          $63 = $57&255;
          $64 = $58 ? $62 : $63;
          __THREW__ = 0;
          $65 = (invoke_iiii(3267,($53|0),($60|0),($64|0))|0);
          $66 = __THREW__; __THREW__ = 0;
          $67 = $66&1;
          if ($67) {
           label = 32;
           break L20;
          }
          $68 = HEAP32[$65>>2]|0;
          $69 = ((($68)) + -12|0);
          $70 = HEAP32[$69>>2]|0;
          $71 = (($65) + ($70)|0);
          __THREW__ = 0;
          invoke_vii(3257,($1|0),($71|0));
          $72 = __THREW__; __THREW__ = 0;
          $73 = $72&1;
          if ($73) {
           label = 32;
           break L20;
          }
          __THREW__ = 0;
          $74 = (invoke_iii(3255,($1|0),(215188|0))|0);
          $75 = __THREW__; __THREW__ = 0;
          $76 = $75&1;
          if (!($76)) {
           $77 = HEAP32[$74>>2]|0;
           $78 = ((($77)) + 28|0);
           $79 = HEAP32[$78>>2]|0;
           __THREW__ = 0;
           $80 = (invoke_iii($79|0,($74|0),10)|0);
           $81 = __THREW__; __THREW__ = 0;
           $82 = $81&1;
           if (!($82)) {
            __THREW__ = 0;
            invoke_vi(3263,($1|0));
            $83 = __THREW__; __THREW__ = 0;
            $84 = $83&1;
            if ($84) {
             label = 32;
             break L20;
            }
            __THREW__ = 0;
            (invoke_iii(3268,($65|0),($80|0))|0);
            $91 = __THREW__; __THREW__ = 0;
            $92 = $91&1;
            if ($92) {
             label = 32;
             break L20;
            }
            __THREW__ = 0;
            (invoke_ii(3269,($65|0))|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             label = 32;
             break L20;
            } else {
             break;
            }
           }
          }
          $85 = ___cxa_find_matching_catch_2()|0;
          $86 = tempRet0;
          __THREW__ = 0;
          invoke_vi(3263,($1|0));
          $87 = __THREW__; __THREW__ = 0;
          $88 = $87&1;
          if ($88) {
           $89 = ___cxa_find_matching_catch_3(0|0)|0;
           $90 = tempRet0;
           ___clang_call_terminate($89);
           // unreachable;
          } else {
           $eh$lpad$body$index2Z2D = $86;$eh$lpad$body$indexZ2D = $85;
           break L20;
          }
         }
        } while(0);
        __THREW__ = 0;
        $107 = (invoke_ii(3482,0)|0);
        $108 = __THREW__; __THREW__ = 0;
        $109 = $108&1;
        if ($109) {
         label = 32;
        } else {
         $110 = ((($107)) + 160|0);
         $111 = HEAP32[$110>>2]|0;
         __THREW__ = 0;
         (invoke_iiii(3483,($0|0),($2|0),($111|0))|0);
         $112 = __THREW__; __THREW__ = 0;
         $113 = $112&1;
         if ($113) {
          label = 32;
         } else {
          __THREW__ = 0;
          invoke_vii(3481,($0|0),($41|0));
          $114 = __THREW__; __THREW__ = 0;
          $115 = $114&1;
          if ($115) {
           label = 32;
          } else {
           if ($42) {
            $$012 = 1;
            break L1;
           }
           $116 = ((($41)) + 8|0);
           $117 = HEAP32[$116>>2]|0;HEAP32[$116>>2] = (($117-1)|0);
           $118 = ($117|0)==(1);
           if (!($118)) {
            $$012 = 1;
            break L1;
           }
           __THREW__ = 0;
           invoke_viii(3262,($41|0),1,1);
           $119 = __THREW__; __THREW__ = 0;
           $120 = $119&1;
           if (!($120)) {
            $$012 = 1;
            break L1;
           }
           $121 = ___cxa_find_matching_catch_2()|0;
           $122 = tempRet0;
           $$2 = $122;$$211 = $121;
           break L3;
          }
         }
        }
       }
      }
     } while(0);
     if ((label|0) == 32) {
      $100 = ___cxa_find_matching_catch_2()|0;
      $101 = tempRet0;
      $eh$lpad$body$index2Z2D = $101;$eh$lpad$body$indexZ2D = $100;
     }
     if ($42) {
      $$2 = $eh$lpad$body$index2Z2D;$$211 = $eh$lpad$body$indexZ2D;
     } else {
      $102 = ((($41)) + 8|0);
      $103 = HEAP32[$102>>2]|0;HEAP32[$102>>2] = (($103-1)|0);
      $104 = ($103|0)==(1);
      if ($104) {
       __THREW__ = 0;
       invoke_viii(3262,($41|0),1,1);
       $105 = __THREW__; __THREW__ = 0;
       $106 = $105&1;
       if ($106) {
        $131 = ___cxa_find_matching_catch_3(0|0)|0;
        $132 = tempRet0;
        ___clang_call_terminate($131);
        // unreachable;
       } else {
        $$2 = $eh$lpad$body$index2Z2D;$$211 = $eh$lpad$body$indexZ2D;
       }
      } else {
       $$2 = $eh$lpad$body$index2Z2D;$$211 = $eh$lpad$body$indexZ2D;
      }
     }
    }
   } while(0);
   if ((label|0) == 29) {
    $95 = ___cxa_find_matching_catch_2()|0;
    $96 = tempRet0;
    $97 = HEAP8[$7>>0]|0;
    $98 = ($97<<24>>24)<(0);
    if ($98) {
     $99 = HEAP32[$3>>2]|0;
     __ZdlPv($99);
    }
    $$2 = $96;$$211 = $95;
   }
   $127 = ((($2)) + 11|0);
   $128 = HEAP8[$127>>0]|0;
   $129 = ($128<<24>>24)<(0);
   if (!($129)) {
    ___resumeException($$211|0);
    // unreachable;
   }
   $130 = HEAP32[$2>>2]|0;
   __ZdlPv($130);
   ___resumeException($$211|0);
   // unreachable;
  }
 } while(0);
 $123 = ((($2)) + 11|0);
 $124 = HEAP8[$123>>0]|0;
 $125 = ($124<<24>>24)<(0);
 if (!($125)) {
  STACKTOP = sp;return ($$012|0);
 }
 $126 = HEAP32[$2>>2]|0;
 __ZdlPv($126);
 STACKTOP = sp;return ($$012|0);
}
function __ZNK9osgViewer15KeystoneHandler13computeRegionERKN5osgGA15GUIEventAdapterE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$ = 0, $$$i = 0.0, $$0 = 0, $$13 = 0, $$14 = 0, $$in = 0.0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0.0, $15 = 0, $16 = 0.0, $17 = 0.0, $18 = 0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0.0, $22 = 0.0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0.0, $29 = 0, $3 = 0, $30 = 0.0, $31 = 0.0, $32 = 0, $33 = 0.0, $34 = 0.0, $35 = 0.0, $36 = 0.0, $37 = 0.0, $38 = 0, $39 = 0.0, $4 = 0, $40 = 0;
 var $41 = 0.0, $42 = 0.0, $43 = 0.0, $44 = 0, $45 = 0.0, $46 = 0.0, $47 = 0.0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0.0, $53 = 0, $54 = 0.0, $55 = 0.0, $56 = 0.0, $57 = 0, $58 = 0.0, $59 = 0.0;
 var $6 = 0, $60 = 0.0, $61 = 0.0, $62 = 0.0, $63 = 0.0, $64 = 0.0, $65 = 0, $66 = 0.0, $67 = 0.0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 160|0);
 $3 = ((($1)) + 164|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$2>>2]|0;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 2;
 $8 = ($7|0)==(0);
 if ($8) {
  $38 = ((($1)) + 104|0);
  $39 = +HEAPF32[$38>>2];
  $40 = ((($1)) + 88|0);
  $41 = +HEAPF32[$40>>2];
  $42 = $39 - $41;
  $43 = $42 * 2.0;
  $44 = ((($1)) + 92|0);
  $45 = +HEAPF32[$44>>2];
  $46 = $45 - $41;
  $47 = $43 / $46;
  $48 = ((($1)) + 120|0);
  $49 = HEAP32[$48>>2]|0;
  $50 = ($49|0)==(0);
  $51 = ((($1)) + 108|0);
  $52 = +HEAPF32[$51>>2];
  $53 = ((($1)) + 96|0);
  $54 = +HEAPF32[$53>>2];
  $55 = $52 - $54;
  $56 = $55 * 2.0;
  $57 = ((($1)) + 100|0);
  $58 = +HEAPF32[$57>>2];
  $59 = $58 - $54;
  $60 = $56 / $59;
  $61 = $60 + -1.0;
  $62 = -$61;
  $$$i = $50 ? $61 : $62;
  $$in = $47;$67 = $$$i;
 } else {
  $9 = $5;
  $10 = (($7) + -1)|0;
  $11 = (($9) + ($10<<2)|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ((($12)) + 20|0);
  $14 = +HEAPF32[$13>>2];
  $15 = ((($12)) + 24|0);
  $16 = +HEAPF32[$15>>2];
  $17 = $14 - $16;
  $18 = ((($12)) + 28|0);
  $19 = +HEAPF32[$18>>2];
  $20 = $19 - $16;
  $21 = $17 / $20;
  $22 = $21 * 2.0;
  $23 = $5;
  $24 = (($7) + -1)|0;
  $25 = (($23) + ($24<<2)|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = ((($26)) + 32|0);
  $28 = +HEAPF32[$27>>2];
  $29 = ((($26)) + 36|0);
  $30 = +HEAPF32[$29>>2];
  $31 = $28 - $30;
  $32 = ((($26)) + 40|0);
  $33 = +HEAPF32[$32>>2];
  $34 = $33 - $30;
  $35 = $31 / $34;
  $36 = $35 * 2.0;
  $37 = $36 + -1.0;
  $$in = $22;$67 = $37;
 }
 $63 = $$in + -1.0;
 $64 = $63;
 $65 = $64 < -0.33000000000000002;
 $66 = $67;
 $68 = $66 < -0.33000000000000002;
 if ($65) {
  if ($68) {
   $$0 = 7;
   return ($$0|0);
  }
  $69 = $66 < 0.33000000000000002;
  $$ = $69 ? 8 : 1;
  $$0 = $$;
  return ($$0|0);
 }
 $70 = $64 < 0.33000000000000002;
 $71 = $66 < 0.33000000000000002;
 if ($70) {
  if ($68) {
   $$0 = 6;
   return ($$0|0);
  }
  $$13 = $71 ? 9 : 2;
  $$0 = $$13;
  return ($$0|0);
 } else {
  if ($68) {
   $$0 = 5;
   return ($$0|0);
  }
  $$14 = $71 ? 4 : 3;
  $$0 = $$14;
  return ($$0|0);
 }
 return (0)|0;
}
function __ZN9osgViewer15KeystoneHandler4moveENS0_6RegionERKN3osg5Vec2dE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$sink = 0, $$sink20 = 0, $10 = 0, $100 = 0.0, $101 = 0.0, $102 = 0.0, $103 = 0, $104 = 0.0, $105 = 0.0, $106 = 0.0, $107 = 0, $108 = 0.0, $109 = 0.0, $11 = 0, $110 = 0.0, $111 = 0, $112 = 0.0, $113 = 0.0, $114 = 0.0, $115 = 0;
 var $116 = 0.0, $117 = 0.0, $118 = 0, $119 = 0.0, $12 = 0.0, $120 = 0.0, $121 = 0.0, $122 = 0.0, $123 = 0, $124 = 0.0, $125 = 0.0, $13 = 0, $14 = 0.0, $15 = 0.0, $16 = 0, $17 = 0.0, $18 = 0, $19 = 0.0, $20 = 0.0, $21 = 0;
 var $22 = 0.0, $23 = 0.0, $24 = 0.0, $25 = 0, $26 = 0, $27 = 0, $28 = 0.0, $29 = 0.0, $3 = 0, $30 = 0.0, $31 = 0, $32 = 0, $33 = 0, $34 = 0.0, $35 = 0, $36 = 0.0, $37 = 0.0, $38 = 0, $39 = 0.0, $4 = 0;
 var $40 = 0, $41 = 0.0, $42 = 0.0, $43 = 0, $44 = 0.0, $45 = 0.0, $46 = 0.0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0.0, $51 = 0.0, $52 = 0.0, $53 = 0, $54 = 0, $55 = 0, $56 = 0.0, $57 = 0, $58 = 0.0;
 var $59 = 0.0, $6 = 0.0, $60 = 0, $61 = 0.0, $62 = 0, $63 = 0.0, $64 = 0.0, $65 = 0, $66 = 0.0, $67 = 0.0, $68 = 0.0, $69 = 0, $7 = 0.0, $70 = 0, $71 = 0, $72 = 0.0, $73 = 0.0, $74 = 0.0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0.0, $79 = 0, $8 = 0.0, $80 = 0.0, $81 = 0.0, $82 = 0, $83 = 0.0, $84 = 0, $85 = 0.0, $86 = 0.0, $87 = 0, $88 = 0.0, $89 = 0.0, $9 = 0, $90 = 0.0, $91 = 0, $92 = 0, $93 = 0.0, $94 = 0;
 var $95 = 0.0, $96 = 0.0, $97 = 0, $98 = 0.0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 do {
  switch ($1|0) {
  case 1:  {
   $3 = ((($0)) + 104|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = ((($4)) + 88|0);
   $6 = +HEAPF64[$2>>3];
   $7 = +HEAPF64[$5>>3];
   $8 = $6 + $7;
   HEAPF64[$5>>3] = $8;
   $9 = ((($2)) + 8|0);
   $$sink = $9;$$sink20 = $5;
   break;
  }
  case 2:  {
   $10 = ((($0)) + 104|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = +HEAPF64[$2>>3];
   $13 = ((($11)) + 88|0);
   $14 = +HEAPF64[$13>>3];
   $15 = $12 + $14;
   HEAPF64[$13>>3] = $15;
   $16 = ((($2)) + 8|0);
   $17 = +HEAPF64[$16>>3];
   $18 = ((($11)) + 96|0);
   $19 = +HEAPF64[$18>>3];
   $20 = $17 + $19;
   HEAPF64[$18>>3] = $20;
   $21 = ((($11)) + 104|0);
   $22 = +HEAPF64[$2>>3];
   $23 = +HEAPF64[$21>>3];
   $24 = $22 + $23;
   HEAPF64[$21>>3] = $24;
   $$sink = $16;$$sink20 = $21;
   break;
  }
  case 3:  {
   $25 = ((($0)) + 104|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = ((($26)) + 104|0);
   $28 = +HEAPF64[$2>>3];
   $29 = +HEAPF64[$27>>3];
   $30 = $28 + $29;
   HEAPF64[$27>>3] = $30;
   $31 = ((($2)) + 8|0);
   $$sink = $31;$$sink20 = $27;
   break;
  }
  case 4:  {
   $32 = ((($0)) + 104|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = +HEAPF64[$2>>3];
   $35 = ((($33)) + 104|0);
   $36 = +HEAPF64[$35>>3];
   $37 = $34 + $36;
   HEAPF64[$35>>3] = $37;
   $38 = ((($2)) + 8|0);
   $39 = +HEAPF64[$38>>3];
   $40 = ((($33)) + 112|0);
   $41 = +HEAPF64[$40>>3];
   $42 = $39 + $41;
   HEAPF64[$40>>3] = $42;
   $43 = ((($33)) + 72|0);
   $44 = +HEAPF64[$2>>3];
   $45 = +HEAPF64[$43>>3];
   $46 = $44 + $45;
   HEAPF64[$43>>3] = $46;
   $$sink = $38;$$sink20 = $43;
   break;
  }
  case 5:  {
   $47 = ((($0)) + 104|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = ((($48)) + 72|0);
   $50 = +HEAPF64[$2>>3];
   $51 = +HEAPF64[$49>>3];
   $52 = $50 + $51;
   HEAPF64[$49>>3] = $52;
   $53 = ((($2)) + 8|0);
   $$sink = $53;$$sink20 = $49;
   break;
  }
  case 6:  {
   $54 = ((($0)) + 104|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = +HEAPF64[$2>>3];
   $57 = ((($55)) + 72|0);
   $58 = +HEAPF64[$57>>3];
   $59 = $56 + $58;
   HEAPF64[$57>>3] = $59;
   $60 = ((($2)) + 8|0);
   $61 = +HEAPF64[$60>>3];
   $62 = ((($55)) + 80|0);
   $63 = +HEAPF64[$62>>3];
   $64 = $61 + $63;
   HEAPF64[$62>>3] = $64;
   $65 = ((($55)) + 56|0);
   $66 = +HEAPF64[$2>>3];
   $67 = +HEAPF64[$65>>3];
   $68 = $66 + $67;
   HEAPF64[$65>>3] = $68;
   $$sink = $60;$$sink20 = $65;
   break;
  }
  case 7:  {
   $69 = ((($0)) + 104|0);
   $70 = HEAP32[$69>>2]|0;
   $71 = ((($70)) + 56|0);
   $72 = +HEAPF64[$2>>3];
   $73 = +HEAPF64[$71>>3];
   $74 = $72 + $73;
   HEAPF64[$71>>3] = $74;
   $75 = ((($2)) + 8|0);
   $$sink = $75;$$sink20 = $71;
   break;
  }
  case 8:  {
   $76 = ((($0)) + 104|0);
   $77 = HEAP32[$76>>2]|0;
   $78 = +HEAPF64[$2>>3];
   $79 = ((($77)) + 56|0);
   $80 = +HEAPF64[$79>>3];
   $81 = $78 + $80;
   HEAPF64[$79>>3] = $81;
   $82 = ((($2)) + 8|0);
   $83 = +HEAPF64[$82>>3];
   $84 = ((($77)) + 64|0);
   $85 = +HEAPF64[$84>>3];
   $86 = $83 + $85;
   HEAPF64[$84>>3] = $86;
   $87 = ((($77)) + 88|0);
   $88 = +HEAPF64[$2>>3];
   $89 = +HEAPF64[$87>>3];
   $90 = $88 + $89;
   HEAPF64[$87>>3] = $90;
   $$sink = $82;$$sink20 = $87;
   break;
  }
  case 9:  {
   $91 = ((($0)) + 104|0);
   $92 = HEAP32[$91>>2]|0;
   $93 = +HEAPF64[$2>>3];
   $94 = ((($92)) + 56|0);
   $95 = +HEAPF64[$94>>3];
   $96 = $93 + $95;
   HEAPF64[$94>>3] = $96;
   $97 = ((($2)) + 8|0);
   $98 = +HEAPF64[$97>>3];
   $99 = ((($92)) + 64|0);
   $100 = +HEAPF64[$99>>3];
   $101 = $98 + $100;
   HEAPF64[$99>>3] = $101;
   $102 = +HEAPF64[$2>>3];
   $103 = ((($92)) + 88|0);
   $104 = +HEAPF64[$103>>3];
   $105 = $102 + $104;
   HEAPF64[$103>>3] = $105;
   $106 = +HEAPF64[$97>>3];
   $107 = ((($92)) + 96|0);
   $108 = +HEAPF64[$107>>3];
   $109 = $106 + $108;
   HEAPF64[$107>>3] = $109;
   $110 = +HEAPF64[$2>>3];
   $111 = ((($92)) + 72|0);
   $112 = +HEAPF64[$111>>3];
   $113 = $110 + $112;
   HEAPF64[$111>>3] = $113;
   $114 = +HEAPF64[$97>>3];
   $115 = ((($92)) + 80|0);
   $116 = +HEAPF64[$115>>3];
   $117 = $114 + $116;
   HEAPF64[$115>>3] = $117;
   $118 = ((($92)) + 104|0);
   $119 = +HEAPF64[$2>>3];
   $120 = +HEAPF64[$118>>3];
   $121 = $119 + $120;
   HEAPF64[$118>>3] = $121;
   $$sink = $97;$$sink20 = $118;
   break;
  }
  default: {
   return;
  }
  }
 } while(0);
 $122 = +HEAPF64[$$sink>>3];
 $123 = ((($$sink20)) + 8|0);
 $124 = +HEAPF64[$123>>3];
 $125 = $122 + $124;
 HEAPF64[$123>>3] = $125;
 return;
}
function __ZN9osgViewer15KeystoneHandlerD2Ev($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$03 = 0, $$1 = 0, $$14 = 0, $$cast = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $2;
 $3 = ((($1)) + 60|0);
 $4 = HEAP32[$3>>2]|0;
 $$cast = $2;
 $5 = ((($$cast)) + -12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($0) + ($6)|0);
 HEAP32[$7>>2] = $4;
 $8 = ((($1)) + 64|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$0>>2]|0;
 $11 = ((($10)) + -16|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($0) + ($12)|0);
 HEAP32[$13>>2] = $9;
 $14 = ((($1)) + 68|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ((($0)) + 4|0);
 HEAP32[$16>>2] = $15;
 $17 = ((($0)) + 104|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ($18|0)==(0|0);
 if ($19) {
  label = 4;
 } else {
  $20 = ((($18)) + 8|0);
  $21 = HEAP32[$20>>2]|0;HEAP32[$20>>2] = (($21-1)|0);
  $22 = ($21|0)==(1);
  if ($22) {
   __THREW__ = 0;
   invoke_viii(3262,($18|0),1,1);
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if ($24) {
    $42 = ___cxa_find_matching_catch_2()|0;
    $43 = tempRet0;
    $44 = ((($0)) + 96|0);
    $45 = HEAP32[$44>>2]|0;
    $46 = ($45|0)==(0|0);
    if (!($46)) {
     $47 = ((($45)) + 8|0);
     $48 = HEAP32[$47>>2]|0;HEAP32[$47>>2] = (($48-1)|0);
     $49 = ($48|0)==(1);
     if ($49) {
      __THREW__ = 0;
      invoke_viii(3262,($45|0),1,1);
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       $67 = ___cxa_find_matching_catch_3(0|0)|0;
       $68 = tempRet0;
       ___clang_call_terminate($67);
       // unreachable;
      }
     }
    }
    HEAP32[$44>>2] = 0;
    $$0 = $43;$$03 = $42;
    label = 17;
   } else {
    label = 4;
   }
  } else {
   label = 4;
  }
 }
 do {
  if ((label|0) == 4) {
   HEAP32[$17>>2] = 0;
   $25 = ((($0)) + 96|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = ($26|0)==(0|0);
   if (!($27)) {
    $28 = ((($26)) + 8|0);
    $29 = HEAP32[$28>>2]|0;HEAP32[$28>>2] = (($29-1)|0);
    $30 = ($29|0)==(1);
    if ($30) {
     __THREW__ = 0;
     invoke_viii(3262,($26|0),1,1);
     $31 = __THREW__; __THREW__ = 0;
     $32 = $31&1;
     if ($32) {
      $52 = ___cxa_find_matching_catch_2()|0;
      $53 = tempRet0;
      $$0 = $53;$$03 = $52;
      label = 17;
      break;
     }
    }
   }
   HEAP32[$25>>2] = 0;
   $33 = ((($0)) + 8|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = ($34|0)==(0|0);
   if ($35) {
    HEAP32[$33>>2] = 0;
    $41 = ((($1)) + 4|0);
    __ZN5osgGA15GUIEventHandlerD2Ev($0,$41);
    return;
   }
   $36 = ((($34)) + 8|0);
   $37 = HEAP32[$36>>2]|0;HEAP32[$36>>2] = (($37-1)|0);
   $38 = ($37|0)==(1);
   if (!($38)) {
    HEAP32[$33>>2] = 0;
    $41 = ((($1)) + 4|0);
    __ZN5osgGA15GUIEventHandlerD2Ev($0,$41);
    return;
   }
   __THREW__ = 0;
   invoke_viii(3262,($34|0),1,1);
   $39 = __THREW__; __THREW__ = 0;
   $40 = $39&1;
   if ($40) {
    $54 = ___cxa_find_matching_catch_2()|0;
    $55 = tempRet0;
    $$1 = $55;$$14 = $54;
    break;
   } else {
    HEAP32[$33>>2] = 0;
    $41 = ((($1)) + 4|0);
    __ZN5osgGA15GUIEventHandlerD2Ev($0,$41);
    return;
   }
  }
 } while(0);
 if ((label|0) == 17) {
  $56 = ((($0)) + 8|0);
  $57 = HEAP32[$56>>2]|0;
  $58 = ($57|0)==(0|0);
  if (!($58)) {
   $59 = ((($57)) + 8|0);
   $60 = HEAP32[$59>>2]|0;HEAP32[$59>>2] = (($60-1)|0);
   $61 = ($60|0)==(1);
   if ($61) {
    __THREW__ = 0;
    invoke_viii(3262,($57|0),1,1);
    $62 = __THREW__; __THREW__ = 0;
    $63 = $62&1;
    if ($63) {
     $67 = ___cxa_find_matching_catch_3(0|0)|0;
     $68 = tempRet0;
     ___clang_call_terminate($67);
     // unreachable;
    }
   }
  }
  HEAP32[$56>>2] = 0;
  $$1 = $$0;$$14 = $$03;
 }
 $64 = ((($1)) + 4|0);
 __THREW__ = 0;
 invoke_vii(3484,($0|0),($64|0));
 $65 = __THREW__; __THREW__ = 0;
 $66 = $65&1;
 if ($66) {
  $67 = ___cxa_find_matching_catch_3(0|0)|0;
  $68 = tempRet0;
  ___clang_call_terminate($67);
  // unreachable;
 } else {
  ___resumeException($$14|0);
  // unreachable;
 }
}
function __ZNK3osg8Callback9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(40)|0);
 $2 = ((($1)) + 8|0);
 __THREW__ = 0;
 invoke_vi(3282,($2|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $9 = ___cxa_find_matching_catch_2()|0;
  $10 = tempRet0;
  __ZdlPv($1);
  ___resumeException($9|0);
  // unreachable;
 } else {
  $5 = ((($1)) + 20|0);
  ;HEAP32[$5>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;
  $6 = ((($1)) + 32|0);
  HEAP32[$6>>2] = 2;
  $7 = ((($1)) + 36|0);
  HEAP32[$7>>2] = 0;
  HEAP32[$1>>2] = (39776);
  HEAP32[$2>>2] = (40024);
  $8 = ((($1)) + 4|0);
  HEAP32[$8>>2] = 0;
  return ($2|0);
 }
 return (0)|0;
}
function __ZNK3osg8Callback5cloneERKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$pre = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(40)|0);
 $3 = ((($2)) + 8|0);
 $4 = HEAP32[$0>>2]|0;
 $5 = ((($4)) + -12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($0) + ($6)|0);
 __THREW__ = 0;
 invoke_viii(3468,($3|0),($7|0),($1|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $24 = ___cxa_find_matching_catch_2()|0;
  $25 = tempRet0;
  __ZdlPv($2);
  ___resumeException($24|0);
  // unreachable;
 }
 HEAP32[$2>>2] = (39776);
 HEAP32[$3>>2] = (40024);
 $10 = ((($2)) + 4|0);
 $11 = ((($0)) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 HEAP32[$10>>2] = $12;
 $13 = ($12|0)==(0|0);
 if ($13) {
  $21 = (39776);
  $20 = ((($21)) + -12|0);
  $22 = HEAP32[$20>>2]|0;
  $23 = (($2) + ($22)|0);
  return ($23|0);
 }
 $14 = HEAP32[$12>>2]|0;
 $15 = ((($14)) + -12|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($12) + ($16)|0);
 $18 = ((($17)) + 8|0);
 $19 = HEAP32[$18>>2]|0;HEAP32[$18>>2] = (($19+1)|0);
 $$pre = HEAP32[$2>>2]|0;
 $21 = $$pre;
 $20 = ((($21)) + -12|0);
 $22 = HEAP32[$20>>2]|0;
 $23 = (($2) + ($22)|0);
 return ($23|0);
}
function __ZNK3osg8Callback12isSameKindAsEPKNS_6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,5616,-1)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK3osg8Callback11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175113|0);
}
function __ZNK3osg8Callback9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (107809|0);
}
function __ZN3osg8Callback14asNodeCallbackEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZNK3osg8Callback14asNodeCallbackEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZN3osg8Callback23asDrawableEventCallbackEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZNK3osg8Callback23asDrawableEventCallbackEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZN3osg8Callback14asEventHandlerEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZNK3osg8Callback14asEventHandlerEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZN3osg8Callback3runEPNS_6ObjectES2_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (__ZN3osg8Callback8traverseEPNS_6ObjectES2_($0,$1,$2)|0);
 return ($3|0);
}
function __ZN3osg8CallbackD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = ((39776));
 $1 = ((($0)) + 8|0);
 HEAP32[$1>>2] = ((40024));
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  HEAP32[$2>>2] = 0;
  __ZN3osg6ObjectD2Ev($1);
  return;
 }
 $5 = HEAP32[$3>>2]|0;
 $6 = ((($5)) + -12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($3) + ($7)|0);
 $9 = ((($8)) + 8|0);
 $10 = HEAP32[$9>>2]|0;HEAP32[$9>>2] = (($10-1)|0);
 $11 = ($10|0)==(1);
 if (!($11)) {
  HEAP32[$2>>2] = 0;
  __ZN3osg6ObjectD2Ev($1);
  return;
 }
 __THREW__ = 0;
 invoke_viii(3262,($8|0),1,1);
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if (!($13)) {
  HEAP32[$2>>2] = 0;
  __ZN3osg6ObjectD2Ev($1);
  return;
 }
 $14 = ___cxa_find_matching_catch_2()|0;
 $15 = tempRet0;
 __THREW__ = 0;
 invoke_vi(388,($1|0));
 $16 = __THREW__; __THREW__ = 0;
 $17 = $16&1;
 if ($17) {
  $18 = ___cxa_find_matching_catch_3(0|0)|0;
  $19 = tempRet0;
  ___clang_call_terminate($18);
  // unreachable;
 } else {
  ___resumeException($14|0);
  // unreachable;
 }
}
function __ZN3osg8CallbackD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = ((39776));
 $1 = ((($0)) + 8|0);
 HEAP32[$1>>2] = ((40024));
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = HEAP32[$3>>2]|0;
  $6 = ((($5)) + -12|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($3) + ($7)|0);
  $9 = ((($8)) + 8|0);
  $10 = HEAP32[$9>>2]|0;HEAP32[$9>>2] = (($10-1)|0);
  $11 = ($10|0)==(1);
  if ($11) {
   __THREW__ = 0;
   invoke_viii(3262,($8|0),1,1);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if ($13) {
    $16 = ___cxa_find_matching_catch_2()|0;
    $17 = tempRet0;
    __THREW__ = 0;
    invoke_vi(388,($1|0));
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     $20 = ___cxa_find_matching_catch_3(0|0)|0;
     $21 = tempRet0;
     ___clang_call_terminate($20);
     // unreachable;
    } else {
     $eh$lpad$body$index2Z2D = $17;$eh$lpad$body$indexZ2D = $16;
     __ZdlPv($0);
     ___resumeException($eh$lpad$body$indexZ2D|0);
     // unreachable;
    }
   }
  }
 }
 HEAP32[$2>>2] = 0;
 __THREW__ = 0;
 invoke_vi(388,($1|0));
 $14 = __THREW__; __THREW__ = 0;
 $15 = $14&1;
 if (!($15)) {
  __ZdlPv($0);
  return;
 }
 $22 = ___cxa_find_matching_catch_2()|0;
 $23 = tempRet0;
 $eh$lpad$body$index2Z2D = $23;$eh$lpad$body$indexZ2D = $22;
 __ZdlPv($0);
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
}
function __ZTv0_n16_N3osg8CallbackD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 HEAP32[$4>>2] = ((39776));
 $5 = ((($4)) + 8|0);
 HEAP32[$5>>2] = ((40024));
 $6 = ((($4)) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if ($8) {
  HEAP32[$6>>2] = 0;
  __ZN3osg6ObjectD2Ev($5);
  return;
 }
 $9 = HEAP32[$7>>2]|0;
 $10 = ((($9)) + -12|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($7) + ($11)|0);
 $13 = ((($12)) + 8|0);
 $14 = HEAP32[$13>>2]|0;HEAP32[$13>>2] = (($14-1)|0);
 $15 = ($14|0)==(1);
 if (!($15)) {
  HEAP32[$6>>2] = 0;
  __ZN3osg6ObjectD2Ev($5);
  return;
 }
 __THREW__ = 0;
 invoke_viii(3262,($12|0),1,1);
 $16 = __THREW__; __THREW__ = 0;
 $17 = $16&1;
 if (!($17)) {
  HEAP32[$6>>2] = 0;
  __ZN3osg6ObjectD2Ev($5);
  return;
 }
 $18 = ___cxa_find_matching_catch_2()|0;
 $19 = tempRet0;
 __THREW__ = 0;
 invoke_vi(388,($5|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if ($21) {
  $22 = ___cxa_find_matching_catch_3(0|0)|0;
  $23 = tempRet0;
  ___clang_call_terminate($22);
  // unreachable;
 } else {
  ___resumeException($18|0);
  // unreachable;
 }
}
function __ZTv0_n16_N3osg8CallbackD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __ZN3osg8CallbackD0Ev($4);
 return;
}
function __ZTv0_n20_NK3osg8Callback9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(40)|0);
 $2 = ((($1)) + 8|0);
 __THREW__ = 0;
 invoke_vi(3282,($2|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch_2()|0;
  $6 = tempRet0;
  __ZdlPv($1);
  ___resumeException($5|0);
  // unreachable;
 } else {
  $7 = ((($1)) + 20|0);
  ;HEAP32[$7>>2]=0|0;HEAP32[$7+4>>2]=0|0;HEAP32[$7+8>>2]=0|0;
  $8 = ((($1)) + 32|0);
  HEAP32[$8>>2] = 2;
  $9 = ((($1)) + 36|0);
  HEAP32[$9>>2] = 0;
  HEAP32[$1>>2] = (39776);
  HEAP32[$2>>2] = (40024);
  $10 = ((($1)) + 4|0);
  HEAP32[$10>>2] = 0;
  return ($2|0);
 }
 return (0)|0;
}
function __ZTv0_n24_NK3osg8Callback5cloneERKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$pre$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $3 = ((($2)) + -24|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($0) + ($4)|0);
 $6 = (__Znwj(40)|0);
 $7 = ((($6)) + 8|0);
 $8 = HEAP32[$5>>2]|0;
 $9 = ((($8)) + -12|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($5) + ($10)|0);
 __THREW__ = 0;
 invoke_viii(3468,($7|0),($11|0),($1|0));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $24 = ___cxa_find_matching_catch_2()|0;
  $25 = tempRet0;
  __ZdlPv($6);
  ___resumeException($24|0);
  // unreachable;
 }
 HEAP32[$6>>2] = (39776);
 HEAP32[$7>>2] = (40024);
 $14 = ((($6)) + 4|0);
 $15 = ((($5)) + 4|0);
 $16 = HEAP32[$15>>2]|0;
 HEAP32[$14>>2] = $16;
 $17 = ($16|0)==(0|0);
 if ($17) {
  $27 = (39776);
  $26 = ((($27)) + -12|0);
  $28 = HEAP32[$26>>2]|0;
  $29 = (($6) + ($28)|0);
  return ($29|0);
 }
 $18 = HEAP32[$16>>2]|0;
 $19 = ((($18)) + -12|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($16) + ($20)|0);
 $22 = ((($21)) + 8|0);
 $23 = HEAP32[$22>>2]|0;HEAP32[$22>>2] = (($23+1)|0);
 $$pre$i = HEAP32[$6>>2]|0;
 $27 = $$pre$i;
 $26 = ((($27)) + -12|0);
 $28 = HEAP32[$26>>2]|0;
 $29 = (($6) + ($28)|0);
 return ($29|0);
}
function __ZTv0_n28_NK3osg8Callback12isSameKindAsEPKNS_6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,5616,-1)|0);
 $phitmp$i = ($3|0)!=(0|0);
 $4 = $phitmp$i;
 return ($4|0);
}
function __ZTv0_n32_NK3osg8Callback11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175113|0);
}
function __ZTv0_n36_NK3osg8Callback9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (107809|0);
}
function __ZNK3osg21DrawableEventCallback9cloneTypeEv($0) {
 $0 = $0|0;
 var $$cast$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(44)|0);
 $2 = ((($1)) + 12|0);
 __THREW__ = 0;
 invoke_vi(3282,($2|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $17 = ___cxa_find_matching_catch_2()|0;
  $18 = tempRet0;
  __ZdlPv($1);
  ___resumeException($17|0);
  // unreachable;
 } else {
  HEAP32[$2>>2] = (63412);
  $5 = ((($1)) + 24|0);
  ;HEAP32[$5>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;
  $6 = ((($1)) + 36|0);
  HEAP32[$6>>2] = 2;
  $7 = ((($1)) + 40|0);
  HEAP32[$7>>2] = 0;
  $8 = ((($1)) + 4|0);
  $9 = HEAP32[(56324)>>2]|0;
  HEAP32[$8>>2] = $9;
  $10 = HEAP32[(56328)>>2]|0;
  $$cast$i$i = $9;
  $11 = ((($$cast$i$i)) + -12|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($8) + ($12)|0);
  HEAP32[$13>>2] = $10;
  $14 = ((($1)) + 8|0);
  HEAP32[$14>>2] = 0;
  HEAP32[$1>>2] = (2080);
  HEAP32[$8>>2] = (2236);
  HEAP32[$2>>2] = (2484);
  $15 = HEAP32[516]|0;
  $16 = (($1) + ($15)|0);
  return ($16|0);
 }
 return (0)|0;
}
function __ZNK3osg21DrawableEventCallback5cloneERKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$cast$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(44)|0);
 $3 = ((($2)) + 12|0);
 $4 = HEAP32[$0>>2]|0;
 $5 = ((($4)) + -16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($0) + ($6)|0);
 __THREW__ = 0;
 invoke_viii(3468,($3|0),($7|0),($1|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $32 = ___cxa_find_matching_catch_2()|0;
  $33 = tempRet0;
  __ZdlPv($2);
  ___resumeException($32|0);
  // unreachable;
 }
 $10 = ((($2)) + 4|0);
 $11 = HEAP32[$0>>2]|0;
 $12 = ((($11)) + -12|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($0) + ($13)|0);
 $15 = HEAP32[(56324)>>2]|0;
 HEAP32[$10>>2] = $15;
 $16 = HEAP32[(56328)>>2]|0;
 $$cast$i$i = $15;
 $17 = ((($$cast$i$i)) + -12|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($10) + ($18)|0);
 HEAP32[$19>>2] = $16;
 $20 = ((($2)) + 8|0);
 $21 = ((($14)) + 4|0);
 $22 = HEAP32[$21>>2]|0;
 HEAP32[$20>>2] = $22;
 $23 = ($22|0)==(0|0);
 if ($23) {
  HEAP32[$2>>2] = (2080);
  HEAP32[$10>>2] = (2236);
  HEAP32[$3>>2] = (2484);
  $30 = HEAP32[516]|0;
  $31 = (($2) + ($30)|0);
  return ($31|0);
 }
 $24 = HEAP32[$22>>2]|0;
 $25 = ((($24)) + -12|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (($22) + ($26)|0);
 $28 = ((($27)) + 8|0);
 $29 = HEAP32[$28>>2]|0;HEAP32[$28>>2] = (($29+1)|0);
 HEAP32[$2>>2] = (2080);
 HEAP32[$10>>2] = (2236);
 HEAP32[$3>>2] = (2484);
 $30 = HEAP32[516]|0;
 $31 = (($2) + ($30)|0);
 return ($31|0);
}
function __ZNK3osg21DrawableEventCallback12isSameKindAsEPKNS_6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,23256,-1)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK3osg21DrawableEventCallback11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175113|0);
}
function __ZNK3osg21DrawableEventCallback9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (107834|0);
}
function __ZN3osg21DrawableEventCallback23asDrawableEventCallbackEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ($0|0);
}
function __ZNK3osg21DrawableEventCallback23asDrawableEventCallbackEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ($0|0);
}
function __ZN3osg21DrawableEventCallback5eventEPNS_11NodeVisitorEPNS_8DrawableE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN3osg21DrawableEventCallbackD1Ev($0) {
 $0 = $0|0;
 var $$cast$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 4|0);
 $2 = HEAP32[(56324)>>2]|0;
 HEAP32[$1>>2] = $2;
 $3 = HEAP32[(56328)>>2]|0;
 $$cast$i = $2;
 $4 = ((($$cast$i)) + -12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($1) + ($5)|0);
 HEAP32[$6>>2] = $3;
 $7 = ((($0)) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if ($9) {
  HEAP32[$7>>2] = 0;
  $19 = ((($0)) + 12|0);
  __ZN3osg6ObjectD2Ev($19);
  return;
 }
 $10 = HEAP32[$8>>2]|0;
 $11 = ((($10)) + -12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($8) + ($12)|0);
 $14 = ((($13)) + 8|0);
 $15 = HEAP32[$14>>2]|0;HEAP32[$14>>2] = (($15-1)|0);
 $16 = ($15|0)==(1);
 if (!($16)) {
  HEAP32[$7>>2] = 0;
  $19 = ((($0)) + 12|0);
  __ZN3osg6ObjectD2Ev($19);
  return;
 }
 __THREW__ = 0;
 invoke_viii(3262,($13|0),1,1);
 $17 = __THREW__; __THREW__ = 0;
 $18 = $17&1;
 if (!($18)) {
  HEAP32[$7>>2] = 0;
  $19 = ((($0)) + 12|0);
  __ZN3osg6ObjectD2Ev($19);
  return;
 }
 $20 = ___cxa_find_matching_catch_2()|0;
 $21 = tempRet0;
 $22 = ((($0)) + 12|0);
 __THREW__ = 0;
 invoke_vi(388,($22|0));
 $23 = __THREW__; __THREW__ = 0;
 $24 = $23&1;
 if ($24) {
  $25 = ___cxa_find_matching_catch_3(0|0)|0;
  $26 = tempRet0;
  ___clang_call_terminate($25);
  // unreachable;
 } else {
  ___resumeException($20|0);
  // unreachable;
 }
}
function __ZN3osg21DrawableEventCallbackD0Ev($0) {
 $0 = $0|0;
 var $$cast$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 4|0);
 $2 = HEAP32[(56324)>>2]|0;
 HEAP32[$1>>2] = $2;
 $3 = HEAP32[(56328)>>2]|0;
 $$cast$i$i = $2;
 $4 = ((($$cast$i$i)) + -12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($1) + ($5)|0);
 HEAP32[$6>>2] = $3;
 $7 = ((($0)) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if (!($9)) {
  $10 = HEAP32[$8>>2]|0;
  $11 = ((($10)) + -12|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($8) + ($12)|0);
  $14 = ((($13)) + 8|0);
  $15 = HEAP32[$14>>2]|0;HEAP32[$14>>2] = (($15-1)|0);
  $16 = ($15|0)==(1);
  if ($16) {
   __THREW__ = 0;
   invoke_viii(3262,($13|0),1,1);
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if ($18) {
    $22 = ___cxa_find_matching_catch_2()|0;
    $23 = tempRet0;
    $24 = ((($0)) + 12|0);
    __THREW__ = 0;
    invoke_vi(388,($24|0));
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if ($26) {
     $27 = ___cxa_find_matching_catch_3(0|0)|0;
     $28 = tempRet0;
     ___clang_call_terminate($27);
     // unreachable;
    } else {
     $eh$lpad$body$index2Z2D = $23;$eh$lpad$body$indexZ2D = $22;
     __ZdlPv($0);
     ___resumeException($eh$lpad$body$indexZ2D|0);
     // unreachable;
    }
   }
  }
 }
 HEAP32[$7>>2] = 0;
 $19 = ((($0)) + 12|0);
 __THREW__ = 0;
 invoke_vi(388,($19|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if (!($21)) {
  __ZdlPv($0);
  return;
 }
 $29 = ___cxa_find_matching_catch_2()|0;
 $30 = tempRet0;
 $eh$lpad$body$index2Z2D = $30;$eh$lpad$body$indexZ2D = $29;
 __ZdlPv($0);
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
}
function __ZTv0_n16_NK3osg21DrawableEventCallback9cloneTypeEv($0) {
 $0 = $0|0;
 var $$cast$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(44)|0);
 $2 = ((($1)) + 12|0);
 __THREW__ = 0;
 invoke_vi(3282,($2|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch_2()|0;
  $6 = tempRet0;
  __ZdlPv($1);
  ___resumeException($5|0);
  // unreachable;
 } else {
  HEAP32[$2>>2] = (63412);
  $7 = ((($1)) + 24|0);
  ;HEAP32[$7>>2]=0|0;HEAP32[$7+4>>2]=0|0;HEAP32[$7+8>>2]=0|0;
  $8 = ((($1)) + 36|0);
  HEAP32[$8>>2] = 2;
  $9 = ((($1)) + 40|0);
  HEAP32[$9>>2] = 0;
  $10 = ((($1)) + 4|0);
  $11 = HEAP32[(56324)>>2]|0;
  HEAP32[$10>>2] = $11;
  $12 = HEAP32[(56328)>>2]|0;
  $$cast$i$i$i = $11;
  $13 = ((($$cast$i$i$i)) + -12|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($10) + ($14)|0);
  HEAP32[$15>>2] = $12;
  $16 = ((($1)) + 8|0);
  HEAP32[$16>>2] = 0;
  HEAP32[$1>>2] = (2080);
  HEAP32[$10>>2] = (2236);
  HEAP32[$2>>2] = (2484);
  $17 = HEAP32[516]|0;
  $18 = (($1) + ($17)|0);
  return ($18|0);
 }
 return (0)|0;
}
function __ZTv0_n20_NK3osg21DrawableEventCallback5cloneERKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$cast$i$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $3 = ((($2)) + -20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($0) + ($4)|0);
 $6 = (__Znwj(44)|0);
 $7 = ((($6)) + 12|0);
 $8 = HEAP32[$5>>2]|0;
 $9 = ((($8)) + -16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($5) + ($10)|0);
 __THREW__ = 0;
 invoke_viii(3468,($7|0),($11|0),($1|0));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $34 = ___cxa_find_matching_catch_2()|0;
  $35 = tempRet0;
  __ZdlPv($6);
  ___resumeException($34|0);
  // unreachable;
 }
 $14 = ((($6)) + 4|0);
 $15 = HEAP32[$5>>2]|0;
 $16 = ((($15)) + -12|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($5) + ($17)|0);
 $19 = HEAP32[(56324)>>2]|0;
 HEAP32[$14>>2] = $19;
 $20 = HEAP32[(56328)>>2]|0;
 $$cast$i$i$i = $19;
 $21 = ((($$cast$i$i$i)) + -12|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($14) + ($22)|0);
 HEAP32[$23>>2] = $20;
 $24 = ((($6)) + 8|0);
 $25 = ((($18)) + 4|0);
 $26 = HEAP32[$25>>2]|0;
 HEAP32[$24>>2] = $26;
 $27 = ($26|0)==(0|0);
 if ($27) {
  HEAP32[$6>>2] = (2080);
  HEAP32[$14>>2] = (2236);
  HEAP32[$7>>2] = (2484);
  $36 = HEAP32[516]|0;
  $37 = (($6) + ($36)|0);
  return ($37|0);
 }
 $28 = HEAP32[$26>>2]|0;
 $29 = ((($28)) + -12|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($26) + ($30)|0);
 $32 = ((($31)) + 8|0);
 $33 = HEAP32[$32>>2]|0;HEAP32[$32>>2] = (($33+1)|0);
 HEAP32[$6>>2] = (2080);
 HEAP32[$14>>2] = (2236);
 HEAP32[$7>>2] = (2484);
 $36 = HEAP32[516]|0;
 $37 = (($6) + ($36)|0);
 return ($37|0);
}
function __ZTv0_n24_NK3osg21DrawableEventCallback12isSameKindAsEPKNS_6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,23256,-1)|0);
 $phitmp$i = ($3|0)!=(0|0);
 $4 = $phitmp$i;
 return ($4|0);
}
function __ZTv0_n28_NK3osg21DrawableEventCallback11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175113|0);
}
function __ZTv0_n32_NK3osg21DrawableEventCallback9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (107834|0);
}
function __ZTv0_n84_N3osg21DrawableEventCallback23asDrawableEventCallbackEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -84|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 return ($4|0);
}
function __ZTv0_n88_NK3osg21DrawableEventCallback23asDrawableEventCallbackEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -88|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 return ($4|0);
}
function __ZTv0_n112_N3osg21DrawableEventCallbackD1Ev($0) {
 $0 = $0|0;
 var $$cast$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -112|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 $5 = ((($4)) + 4|0);
 $6 = HEAP32[(56324)>>2]|0;
 HEAP32[$5>>2] = $6;
 $7 = HEAP32[(56328)>>2]|0;
 $$cast$i$i = $6;
 $8 = ((($$cast$i$i)) + -12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($5) + ($9)|0);
 HEAP32[$10>>2] = $7;
 $11 = ((($4)) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0|0);
 if ($13) {
  HEAP32[$11>>2] = 0;
  $30 = ((($4)) + 12|0);
  __ZN3osg6ObjectD2Ev($30);
  return;
 }
 $14 = HEAP32[$12>>2]|0;
 $15 = ((($14)) + -12|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($12) + ($16)|0);
 $18 = ((($17)) + 8|0);
 $19 = HEAP32[$18>>2]|0;HEAP32[$18>>2] = (($19-1)|0);
 $20 = ($19|0)==(1);
 if (!($20)) {
  HEAP32[$11>>2] = 0;
  $30 = ((($4)) + 12|0);
  __ZN3osg6ObjectD2Ev($30);
  return;
 }
 __THREW__ = 0;
 invoke_viii(3262,($17|0),1,1);
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if (!($22)) {
  HEAP32[$11>>2] = 0;
  $30 = ((($4)) + 12|0);
  __ZN3osg6ObjectD2Ev($30);
  return;
 }
 $23 = ___cxa_find_matching_catch_2()|0;
 $24 = tempRet0;
 $25 = ((($4)) + 12|0);
 __THREW__ = 0;
 invoke_vi(388,($25|0));
 $26 = __THREW__; __THREW__ = 0;
 $27 = $26&1;
 if ($27) {
  $28 = ___cxa_find_matching_catch_3(0|0)|0;
  $29 = tempRet0;
  ___clang_call_terminate($28);
  // unreachable;
 } else {
  ___resumeException($23|0);
  // unreachable;
 }
}
function __ZTv0_n112_N3osg21DrawableEventCallbackD0Ev($0) {
 $0 = $0|0;
 var $$cast$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$i$index2Z2D = 0, $eh$lpad$body$i$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -112|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 $5 = ((($4)) + 4|0);
 $6 = HEAP32[(56324)>>2]|0;
 HEAP32[$5>>2] = $6;
 $7 = HEAP32[(56328)>>2]|0;
 $$cast$i$i$i = $6;
 $8 = ((($$cast$i$i$i)) + -12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($5) + ($9)|0);
 HEAP32[$10>>2] = $7;
 $11 = ((($4)) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0|0);
 if (!($13)) {
  $14 = HEAP32[$12>>2]|0;
  $15 = ((($14)) + -12|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (($12) + ($16)|0);
  $18 = ((($17)) + 8|0);
  $19 = HEAP32[$18>>2]|0;HEAP32[$18>>2] = (($19-1)|0);
  $20 = ($19|0)==(1);
  if ($20) {
   __THREW__ = 0;
   invoke_viii(3262,($17|0),1,1);
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if ($22) {
    $26 = ___cxa_find_matching_catch_2()|0;
    $27 = tempRet0;
    $28 = ((($4)) + 12|0);
    __THREW__ = 0;
    invoke_vi(388,($28|0));
    $29 = __THREW__; __THREW__ = 0;
    $30 = $29&1;
    if ($30) {
     $31 = ___cxa_find_matching_catch_3(0|0)|0;
     $32 = tempRet0;
     ___clang_call_terminate($31);
     // unreachable;
    } else {
     $eh$lpad$body$i$index2Z2D = $27;$eh$lpad$body$i$indexZ2D = $26;
     __ZdlPv($4);
     ___resumeException($eh$lpad$body$i$indexZ2D|0);
     // unreachable;
    }
   }
  }
 }
 HEAP32[$11>>2] = 0;
 $23 = ((($4)) + 12|0);
 __THREW__ = 0;
 invoke_vi(388,($23|0));
 $24 = __THREW__; __THREW__ = 0;
 $25 = $24&1;
 if (!($25)) {
  __ZdlPv($4);
  return;
 }
 $33 = ___cxa_find_matching_catch_2()|0;
 $34 = tempRet0;
 $eh$lpad$body$i$index2Z2D = $34;$eh$lpad$body$i$indexZ2D = $33;
 __ZdlPv($4);
 ___resumeException($eh$lpad$body$i$indexZ2D|0);
 // unreachable;
}
function __ZTv0_n16_N3osg21DrawableEventCallbackD1Ev($0) {
 $0 = $0|0;
 var $$cast$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 $5 = ((($4)) + 4|0);
 $6 = HEAP32[(56324)>>2]|0;
 HEAP32[$5>>2] = $6;
 $7 = HEAP32[(56328)>>2]|0;
 $$cast$i$i = $6;
 $8 = ((($$cast$i$i)) + -12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($5) + ($9)|0);
 HEAP32[$10>>2] = $7;
 $11 = ((($4)) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0|0);
 if ($13) {
  HEAP32[$11>>2] = 0;
  $30 = ((($4)) + 12|0);
  __ZN3osg6ObjectD2Ev($30);
  return;
 }
 $14 = HEAP32[$12>>2]|0;
 $15 = ((($14)) + -12|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($12) + ($16)|0);
 $18 = ((($17)) + 8|0);
 $19 = HEAP32[$18>>2]|0;HEAP32[$18>>2] = (($19-1)|0);
 $20 = ($19|0)==(1);
 if (!($20)) {
  HEAP32[$11>>2] = 0;
  $30 = ((($4)) + 12|0);
  __ZN3osg6ObjectD2Ev($30);
  return;
 }
 __THREW__ = 0;
 invoke_viii(3262,($17|0),1,1);
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if (!($22)) {
  HEAP32[$11>>2] = 0;
  $30 = ((($4)) + 12|0);
  __ZN3osg6ObjectD2Ev($30);
  return;
 }
 $23 = ___cxa_find_matching_catch_2()|0;
 $24 = tempRet0;
 $25 = ((($4)) + 12|0);
 __THREW__ = 0;
 invoke_vi(388,($25|0));
 $26 = __THREW__; __THREW__ = 0;
 $27 = $26&1;
 if ($27) {
  $28 = ___cxa_find_matching_catch_3(0|0)|0;
  $29 = tempRet0;
  ___clang_call_terminate($28);
  // unreachable;
 } else {
  ___resumeException($23|0);
  // unreachable;
 }
}
function __ZTv0_n16_N3osg21DrawableEventCallbackD0Ev($0) {
 $0 = $0|0;
 var $$cast$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$i$index2Z2D = 0, $eh$lpad$body$i$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 $5 = ((($4)) + 4|0);
 $6 = HEAP32[(56324)>>2]|0;
 HEAP32[$5>>2] = $6;
 $7 = HEAP32[(56328)>>2]|0;
 $$cast$i$i$i = $6;
 $8 = ((($$cast$i$i$i)) + -12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($5) + ($9)|0);
 HEAP32[$10>>2] = $7;
 $11 = ((($4)) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0|0);
 if (!($13)) {
  $14 = HEAP32[$12>>2]|0;
  $15 = ((($14)) + -12|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (($12) + ($16)|0);
  $18 = ((($17)) + 8|0);
  $19 = HEAP32[$18>>2]|0;HEAP32[$18>>2] = (($19-1)|0);
  $20 = ($19|0)==(1);
  if ($20) {
   __THREW__ = 0;
   invoke_viii(3262,($17|0),1,1);
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if ($22) {
    $26 = ___cxa_find_matching_catch_2()|0;
    $27 = tempRet0;
    $28 = ((($4)) + 12|0);
    __THREW__ = 0;
    invoke_vi(388,($28|0));
    $29 = __THREW__; __THREW__ = 0;
    $30 = $29&1;
    if ($30) {
     $31 = ___cxa_find_matching_catch_3(0|0)|0;
     $32 = tempRet0;
     ___clang_call_terminate($31);
     // unreachable;
    } else {
     $eh$lpad$body$i$index2Z2D = $27;$eh$lpad$body$i$indexZ2D = $26;
     __ZdlPv($4);
     ___resumeException($eh$lpad$body$i$indexZ2D|0);
     // unreachable;
    }
   }
  }
 }
 HEAP32[$11>>2] = 0;
 $23 = ((($4)) + 12|0);
 __THREW__ = 0;
 invoke_vi(388,($23|0));
 $24 = __THREW__; __THREW__ = 0;
 $25 = $24&1;
 if (!($25)) {
  __ZdlPv($4);
  return;
 }
 $33 = ___cxa_find_matching_catch_2()|0;
 $34 = tempRet0;
 $eh$lpad$body$i$index2Z2D = $34;$eh$lpad$body$i$indexZ2D = $33;
 __ZdlPv($4);
 ___resumeException($eh$lpad$body$i$indexZ2D|0);
 // unreachable;
}
function __ZTv0_n20_NK3osg21DrawableEventCallback9cloneTypeEv($0) {
 $0 = $0|0;
 var $$cast$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(44)|0);
 $2 = ((($1)) + 12|0);
 __THREW__ = 0;
 invoke_vi(3282,($2|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch_2()|0;
  $6 = tempRet0;
  __ZdlPv($1);
  ___resumeException($5|0);
  // unreachable;
 } else {
  HEAP32[$2>>2] = (63412);
  $7 = ((($1)) + 24|0);
  ;HEAP32[$7>>2]=0|0;HEAP32[$7+4>>2]=0|0;HEAP32[$7+8>>2]=0|0;
  $8 = ((($1)) + 36|0);
  HEAP32[$8>>2] = 2;
  $9 = ((($1)) + 40|0);
  HEAP32[$9>>2] = 0;
  $10 = ((($1)) + 4|0);
  $11 = HEAP32[(56324)>>2]|0;
  HEAP32[$10>>2] = $11;
  $12 = HEAP32[(56328)>>2]|0;
  $$cast$i$i$i = $11;
  $13 = ((($$cast$i$i$i)) + -12|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($10) + ($14)|0);
  HEAP32[$15>>2] = $12;
  $16 = ((($1)) + 8|0);
  HEAP32[$16>>2] = 0;
  HEAP32[$1>>2] = (2080);
  HEAP32[$10>>2] = (2236);
  HEAP32[$2>>2] = (2484);
  $17 = HEAP32[516]|0;
  $18 = (($1) + ($17)|0);
  return ($18|0);
 }
 return (0)|0;
}
function __ZTv0_n24_NK3osg21DrawableEventCallback5cloneERKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$cast$i$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $3 = ((($2)) + -24|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($0) + ($4)|0);
 $6 = (__Znwj(44)|0);
 $7 = ((($6)) + 12|0);
 $8 = HEAP32[$5>>2]|0;
 $9 = ((($8)) + -16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($5) + ($10)|0);
 __THREW__ = 0;
 invoke_viii(3468,($7|0),($11|0),($1|0));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $34 = ___cxa_find_matching_catch_2()|0;
  $35 = tempRet0;
  __ZdlPv($6);
  ___resumeException($34|0);
  // unreachable;
 }
 $14 = ((($6)) + 4|0);
 $15 = HEAP32[$5>>2]|0;
 $16 = ((($15)) + -12|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($5) + ($17)|0);
 $19 = HEAP32[(56324)>>2]|0;
 HEAP32[$14>>2] = $19;
 $20 = HEAP32[(56328)>>2]|0;
 $$cast$i$i$i = $19;
 $21 = ((($$cast$i$i$i)) + -12|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($14) + ($22)|0);
 HEAP32[$23>>2] = $20;
 $24 = ((($6)) + 8|0);
 $25 = ((($18)) + 4|0);
 $26 = HEAP32[$25>>2]|0;
 HEAP32[$24>>2] = $26;
 $27 = ($26|0)==(0|0);
 if ($27) {
  HEAP32[$6>>2] = (2080);
  HEAP32[$14>>2] = (2236);
  HEAP32[$7>>2] = (2484);
  $36 = HEAP32[516]|0;
  $37 = (($6) + ($36)|0);
  return ($37|0);
 }
 $28 = HEAP32[$26>>2]|0;
 $29 = ((($28)) + -12|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($26) + ($30)|0);
 $32 = ((($31)) + 8|0);
 $33 = HEAP32[$32>>2]|0;HEAP32[$32>>2] = (($33+1)|0);
 HEAP32[$6>>2] = (2080);
 HEAP32[$14>>2] = (2236);
 HEAP32[$7>>2] = (2484);
 $36 = HEAP32[516]|0;
 $37 = (($6) + ($36)|0);
 return ($37|0);
}
function __ZTv0_n28_NK3osg21DrawableEventCallback12isSameKindAsEPKNS_6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,23256,-1)|0);
 $phitmp$i = ($3|0)!=(0|0);
 $4 = $phitmp$i;
 return ($4|0);
}
function __ZTv0_n32_NK3osg21DrawableEventCallback11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175113|0);
}
function __ZTv0_n36_NK3osg21DrawableEventCallback9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (107834|0);
}
function __ZNK3osg12NodeCallback9cloneTypeEv($0) {
 $0 = $0|0;
 var $$cast$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(44)|0);
 $2 = ((($1)) + 12|0);
 __THREW__ = 0;
 invoke_vi(3282,($2|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $17 = ___cxa_find_matching_catch_2()|0;
  $18 = tempRet0;
  __ZdlPv($1);
  ___resumeException($17|0);
  // unreachable;
 } else {
  HEAP32[$2>>2] = (63412);
  $5 = ((($1)) + 24|0);
  ;HEAP32[$5>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;
  $6 = ((($1)) + 36|0);
  HEAP32[$6>>2] = 2;
  $7 = ((($1)) + 40|0);
  HEAP32[$7>>2] = 0;
  $8 = ((($1)) + 4|0);
  $9 = HEAP32[(56304)>>2]|0;
  HEAP32[$8>>2] = $9;
  $10 = HEAP32[(56308)>>2]|0;
  $$cast$i$i = $9;
  $11 = ((($$cast$i$i)) + -12|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($8) + ($12)|0);
  HEAP32[$13>>2] = $10;
  $14 = ((($1)) + 8|0);
  HEAP32[$14>>2] = 0;
  HEAP32[$1>>2] = (55748);
  HEAP32[$8>>2] = (55904);
  HEAP32[$2>>2] = (56152);
  $15 = HEAP32[13933]|0;
  $16 = (($1) + ($15)|0);
  return ($16|0);
 }
 return (0)|0;
}
function __ZNK3osg12NodeCallback5cloneERKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$cast$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(44)|0);
 $3 = ((($2)) + 12|0);
 $4 = HEAP32[$0>>2]|0;
 $5 = ((($4)) + -16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($0) + ($6)|0);
 __THREW__ = 0;
 invoke_viii(3468,($3|0),($7|0),($1|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $32 = ___cxa_find_matching_catch_2()|0;
  $33 = tempRet0;
  __ZdlPv($2);
  ___resumeException($32|0);
  // unreachable;
 }
 $10 = ((($2)) + 4|0);
 $11 = HEAP32[$0>>2]|0;
 $12 = ((($11)) + -12|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($0) + ($13)|0);
 $15 = HEAP32[(56304)>>2]|0;
 HEAP32[$10>>2] = $15;
 $16 = HEAP32[(56308)>>2]|0;
 $$cast$i$i = $15;
 $17 = ((($$cast$i$i)) + -12|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($10) + ($18)|0);
 HEAP32[$19>>2] = $16;
 $20 = ((($2)) + 8|0);
 $21 = ((($14)) + 4|0);
 $22 = HEAP32[$21>>2]|0;
 HEAP32[$20>>2] = $22;
 $23 = ($22|0)==(0|0);
 if ($23) {
  HEAP32[$2>>2] = (55748);
  HEAP32[$10>>2] = (55904);
  HEAP32[$3>>2] = (56152);
  $30 = HEAP32[13933]|0;
  $31 = (($2) + ($30)|0);
  return ($31|0);
 }
 $24 = HEAP32[$22>>2]|0;
 $25 = ((($24)) + -12|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (($22) + ($26)|0);
 $28 = ((($27)) + 8|0);
 $29 = HEAP32[$28>>2]|0;HEAP32[$28>>2] = (($29+1)|0);
 HEAP32[$2>>2] = (55748);
 HEAP32[$10>>2] = (55904);
 HEAP32[$3>>2] = (56152);
 $30 = HEAP32[13933]|0;
 $31 = (($2) + ($30)|0);
 return ($31|0);
}
function __ZNK3osg12NodeCallback12isSameKindAsEPKNS_6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,23160,-1)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK3osg12NodeCallback11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175113|0);
}
function __ZNK3osg12NodeCallback9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (107856|0);
}
function __ZN3osg12NodeCallback14asNodeCallbackEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ($0|0);
}
function __ZNK3osg12NodeCallback14asNodeCallbackEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ($0|0);
}
function __ZN3osg12NodeCallbackD1Ev($0) {
 $0 = $0|0;
 var $$cast$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 4|0);
 $2 = HEAP32[(56304)>>2]|0;
 HEAP32[$1>>2] = $2;
 $3 = HEAP32[(56308)>>2]|0;
 $$cast$i = $2;
 $4 = ((($$cast$i)) + -12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($1) + ($5)|0);
 HEAP32[$6>>2] = $3;
 $7 = ((($0)) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if ($9) {
  HEAP32[$7>>2] = 0;
  $19 = ((($0)) + 12|0);
  __ZN3osg6ObjectD2Ev($19);
  return;
 }
 $10 = HEAP32[$8>>2]|0;
 $11 = ((($10)) + -12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($8) + ($12)|0);
 $14 = ((($13)) + 8|0);
 $15 = HEAP32[$14>>2]|0;HEAP32[$14>>2] = (($15-1)|0);
 $16 = ($15|0)==(1);
 if (!($16)) {
  HEAP32[$7>>2] = 0;
  $19 = ((($0)) + 12|0);
  __ZN3osg6ObjectD2Ev($19);
  return;
 }
 __THREW__ = 0;
 invoke_viii(3262,($13|0),1,1);
 $17 = __THREW__; __THREW__ = 0;
 $18 = $17&1;
 if (!($18)) {
  HEAP32[$7>>2] = 0;
  $19 = ((($0)) + 12|0);
  __ZN3osg6ObjectD2Ev($19);
  return;
 }
 $20 = ___cxa_find_matching_catch_2()|0;
 $21 = tempRet0;
 $22 = ((($0)) + 12|0);
 __THREW__ = 0;
 invoke_vi(388,($22|0));
 $23 = __THREW__; __THREW__ = 0;
 $24 = $23&1;
 if ($24) {
  $25 = ___cxa_find_matching_catch_3(0|0)|0;
  $26 = tempRet0;
  ___clang_call_terminate($25);
  // unreachable;
 } else {
  ___resumeException($20|0);
  // unreachable;
 }
}
function __ZN3osg12NodeCallbackD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(547,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZTv0_n16_NK3osg12NodeCallback9cloneTypeEv($0) {
 $0 = $0|0;
 var $$cast$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(44)|0);
 $2 = ((($1)) + 12|0);
 __THREW__ = 0;
 invoke_vi(3282,($2|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch_2()|0;
  $6 = tempRet0;
  __ZdlPv($1);
  ___resumeException($5|0);
  // unreachable;
 } else {
  HEAP32[$2>>2] = (63412);
  $7 = ((($1)) + 24|0);
  ;HEAP32[$7>>2]=0|0;HEAP32[$7+4>>2]=0|0;HEAP32[$7+8>>2]=0|0;
  $8 = ((($1)) + 36|0);
  HEAP32[$8>>2] = 2;
  $9 = ((($1)) + 40|0);
  HEAP32[$9>>2] = 0;
  $10 = ((($1)) + 4|0);
  $11 = HEAP32[(56304)>>2]|0;
  HEAP32[$10>>2] = $11;
  $12 = HEAP32[(56308)>>2]|0;
  $$cast$i$i$i = $11;
  $13 = ((($$cast$i$i$i)) + -12|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($10) + ($14)|0);
  HEAP32[$15>>2] = $12;
  $16 = ((($1)) + 8|0);
  HEAP32[$16>>2] = 0;
  HEAP32[$1>>2] = (55748);
  HEAP32[$10>>2] = (55904);
  HEAP32[$2>>2] = (56152);
  $17 = HEAP32[13933]|0;
  $18 = (($1) + ($17)|0);
  return ($18|0);
 }
 return (0)|0;
}
function __ZTv0_n20_NK3osg12NodeCallback5cloneERKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$cast$i$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $3 = ((($2)) + -20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($0) + ($4)|0);
 $6 = (__Znwj(44)|0);
 $7 = ((($6)) + 12|0);
 $8 = HEAP32[$5>>2]|0;
 $9 = ((($8)) + -16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($5) + ($10)|0);
 __THREW__ = 0;
 invoke_viii(3468,($7|0),($11|0),($1|0));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $34 = ___cxa_find_matching_catch_2()|0;
  $35 = tempRet0;
  __ZdlPv($6);
  ___resumeException($34|0);
  // unreachable;
 }
 $14 = ((($6)) + 4|0);
 $15 = HEAP32[$5>>2]|0;
 $16 = ((($15)) + -12|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($5) + ($17)|0);
 $19 = HEAP32[(56304)>>2]|0;
 HEAP32[$14>>2] = $19;
 $20 = HEAP32[(56308)>>2]|0;
 $$cast$i$i$i = $19;
 $21 = ((($$cast$i$i$i)) + -12|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($14) + ($22)|0);
 HEAP32[$23>>2] = $20;
 $24 = ((($6)) + 8|0);
 $25 = ((($18)) + 4|0);
 $26 = HEAP32[$25>>2]|0;
 HEAP32[$24>>2] = $26;
 $27 = ($26|0)==(0|0);
 if ($27) {
  HEAP32[$6>>2] = (55748);
  HEAP32[$14>>2] = (55904);
  HEAP32[$7>>2] = (56152);
  $36 = HEAP32[13933]|0;
  $37 = (($6) + ($36)|0);
  return ($37|0);
 }
 $28 = HEAP32[$26>>2]|0;
 $29 = ((($28)) + -12|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($26) + ($30)|0);
 $32 = ((($31)) + 8|0);
 $33 = HEAP32[$32>>2]|0;HEAP32[$32>>2] = (($33+1)|0);
 HEAP32[$6>>2] = (55748);
 HEAP32[$14>>2] = (55904);
 HEAP32[$7>>2] = (56152);
 $36 = HEAP32[13933]|0;
 $37 = (($6) + ($36)|0);
 return ($37|0);
}
function __ZTv0_n24_NK3osg12NodeCallback12isSameKindAsEPKNS_6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,23160,-1)|0);
 $phitmp$i = ($3|0)!=(0|0);
 $4 = $phitmp$i;
 return ($4|0);
}
function __ZTv0_n28_NK3osg12NodeCallback11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175113|0);
}
function __ZTv0_n32_NK3osg12NodeCallback9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (107856|0);
}
function __ZTv0_n52_N3osg12NodeCallback14asNodeCallbackEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -52|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 return ($4|0);
}
function __ZTv0_n56_NK3osg12NodeCallback14asNodeCallbackEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -56|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 return ($4|0);
}
function __ZTv0_n112_N3osg12NodeCallbackD1Ev($0) {
 $0 = $0|0;
 var $$cast$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -112|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 $5 = ((($4)) + 4|0);
 $6 = HEAP32[(56304)>>2]|0;
 HEAP32[$5>>2] = $6;
 $7 = HEAP32[(56308)>>2]|0;
 $$cast$i$i = $6;
 $8 = ((($$cast$i$i)) + -12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($5) + ($9)|0);
 HEAP32[$10>>2] = $7;
 $11 = ((($4)) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0|0);
 if ($13) {
  HEAP32[$11>>2] = 0;
  $30 = ((($4)) + 12|0);
  __ZN3osg6ObjectD2Ev($30);
  return;
 }
 $14 = HEAP32[$12>>2]|0;
 $15 = ((($14)) + -12|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($12) + ($16)|0);
 $18 = ((($17)) + 8|0);
 $19 = HEAP32[$18>>2]|0;HEAP32[$18>>2] = (($19-1)|0);
 $20 = ($19|0)==(1);
 if (!($20)) {
  HEAP32[$11>>2] = 0;
  $30 = ((($4)) + 12|0);
  __ZN3osg6ObjectD2Ev($30);
  return;
 }
 __THREW__ = 0;
 invoke_viii(3262,($17|0),1,1);
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if (!($22)) {
  HEAP32[$11>>2] = 0;
  $30 = ((($4)) + 12|0);
  __ZN3osg6ObjectD2Ev($30);
  return;
 }
 $23 = ___cxa_find_matching_catch_2()|0;
 $24 = tempRet0;
 $25 = ((($4)) + 12|0);
 __THREW__ = 0;
 invoke_vi(388,($25|0));
 $26 = __THREW__; __THREW__ = 0;
 $27 = $26&1;
 if ($27) {
  $28 = ___cxa_find_matching_catch_3(0|0)|0;
  $29 = tempRet0;
  ___clang_call_terminate($28);
  // unreachable;
 } else {
  ___resumeException($23|0);
  // unreachable;
 }
}
function __ZTv0_n112_N3osg12NodeCallbackD0Ev($0) {
 $0 = $0|0;
 var $$cast$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -112|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 $5 = ((($4)) + 4|0);
 $6 = HEAP32[(56304)>>2]|0;
 HEAP32[$5>>2] = $6;
 $7 = HEAP32[(56308)>>2]|0;
 $$cast$i$i = $6;
 $8 = ((($$cast$i$i)) + -12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($5) + ($9)|0);
 HEAP32[$10>>2] = $7;
 $11 = ((($4)) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0|0);
 if (!($13)) {
  $14 = HEAP32[$12>>2]|0;
  $15 = ((($14)) + -12|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (($12) + ($16)|0);
  $18 = ((($17)) + 8|0);
  $19 = HEAP32[$18>>2]|0;HEAP32[$18>>2] = (($19-1)|0);
  $20 = ($19|0)==(1);
  if ($20) {
   __THREW__ = 0;
   invoke_viii(3262,($17|0),1,1);
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if ($22) {
    $26 = ___cxa_find_matching_catch_2()|0;
    $27 = tempRet0;
    $28 = ((($4)) + 12|0);
    __THREW__ = 0;
    invoke_vi(388,($28|0));
    $29 = __THREW__; __THREW__ = 0;
    $30 = $29&1;
    if ($30) {
     $31 = ___cxa_find_matching_catch_3(0|0)|0;
     $32 = tempRet0;
     ___clang_call_terminate($31);
     // unreachable;
    } else {
     $eh$lpad$body$index2Z2D = $27;$eh$lpad$body$indexZ2D = $26;
     __ZdlPv($4);
     ___resumeException($eh$lpad$body$indexZ2D|0);
     // unreachable;
    }
   }
  }
 }
 HEAP32[$11>>2] = 0;
 $23 = ((($4)) + 12|0);
 __THREW__ = 0;
 invoke_vi(388,($23|0));
 $24 = __THREW__; __THREW__ = 0;
 $25 = $24&1;
 if (!($25)) {
  __ZdlPv($4);
  return;
 }
 $33 = ___cxa_find_matching_catch_2()|0;
 $34 = tempRet0;
 $eh$lpad$body$index2Z2D = $34;$eh$lpad$body$indexZ2D = $33;
 __ZdlPv($4);
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
}
function __ZTv0_n16_N3osg12NodeCallbackD1Ev($0) {
 $0 = $0|0;
 var $$cast$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 $5 = ((($4)) + 4|0);
 $6 = HEAP32[(56304)>>2]|0;
 HEAP32[$5>>2] = $6;
 $7 = HEAP32[(56308)>>2]|0;
 $$cast$i$i = $6;
 $8 = ((($$cast$i$i)) + -12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($5) + ($9)|0);
 HEAP32[$10>>2] = $7;
 $11 = ((($4)) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0|0);
 if ($13) {
  HEAP32[$11>>2] = 0;
  $30 = ((($4)) + 12|0);
  __ZN3osg6ObjectD2Ev($30);
  return;
 }
 $14 = HEAP32[$12>>2]|0;
 $15 = ((($14)) + -12|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($12) + ($16)|0);
 $18 = ((($17)) + 8|0);
 $19 = HEAP32[$18>>2]|0;HEAP32[$18>>2] = (($19-1)|0);
 $20 = ($19|0)==(1);
 if (!($20)) {
  HEAP32[$11>>2] = 0;
  $30 = ((($4)) + 12|0);
  __ZN3osg6ObjectD2Ev($30);
  return;
 }
 __THREW__ = 0;
 invoke_viii(3262,($17|0),1,1);
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if (!($22)) {
  HEAP32[$11>>2] = 0;
  $30 = ((($4)) + 12|0);
  __ZN3osg6ObjectD2Ev($30);
  return;
 }
 $23 = ___cxa_find_matching_catch_2()|0;
 $24 = tempRet0;
 $25 = ((($4)) + 12|0);
 __THREW__ = 0;
 invoke_vi(388,($25|0));
 $26 = __THREW__; __THREW__ = 0;
 $27 = $26&1;
 if ($27) {
  $28 = ___cxa_find_matching_catch_3(0|0)|0;
  $29 = tempRet0;
  ___clang_call_terminate($28);
  // unreachable;
 } else {
  ___resumeException($23|0);
  // unreachable;
 }
}
function __ZTv0_n16_N3osg12NodeCallbackD0Ev($0) {
 $0 = $0|0;
 var $$cast$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 $5 = ((($4)) + 4|0);
 $6 = HEAP32[(56304)>>2]|0;
 HEAP32[$5>>2] = $6;
 $7 = HEAP32[(56308)>>2]|0;
 $$cast$i$i = $6;
 $8 = ((($$cast$i$i)) + -12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($5) + ($9)|0);
 HEAP32[$10>>2] = $7;
 $11 = ((($4)) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0|0);
 if (!($13)) {
  $14 = HEAP32[$12>>2]|0;
  $15 = ((($14)) + -12|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (($12) + ($16)|0);
  $18 = ((($17)) + 8|0);
  $19 = HEAP32[$18>>2]|0;HEAP32[$18>>2] = (($19-1)|0);
  $20 = ($19|0)==(1);
  if ($20) {
   __THREW__ = 0;
   invoke_viii(3262,($17|0),1,1);
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if ($22) {
    $26 = ___cxa_find_matching_catch_2()|0;
    $27 = tempRet0;
    $28 = ((($4)) + 12|0);
    __THREW__ = 0;
    invoke_vi(388,($28|0));
    $29 = __THREW__; __THREW__ = 0;
    $30 = $29&1;
    if ($30) {
     $31 = ___cxa_find_matching_catch_3(0|0)|0;
     $32 = tempRet0;
     ___clang_call_terminate($31);
     // unreachable;
    } else {
     $eh$lpad$body$index2Z2D = $27;$eh$lpad$body$indexZ2D = $26;
     __ZdlPv($4);
     ___resumeException($eh$lpad$body$indexZ2D|0);
     // unreachable;
    }
   }
  }
 }
 HEAP32[$11>>2] = 0;
 $23 = ((($4)) + 12|0);
 __THREW__ = 0;
 invoke_vi(388,($23|0));
 $24 = __THREW__; __THREW__ = 0;
 $25 = $24&1;
 if (!($25)) {
  __ZdlPv($4);
  return;
 }
 $33 = ___cxa_find_matching_catch_2()|0;
 $34 = tempRet0;
 $eh$lpad$body$index2Z2D = $34;$eh$lpad$body$indexZ2D = $33;
 __ZdlPv($4);
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
}
function __ZTv0_n20_NK3osg12NodeCallback9cloneTypeEv($0) {
 $0 = $0|0;
 var $$cast$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(44)|0);
 $2 = ((($1)) + 12|0);
 __THREW__ = 0;
 invoke_vi(3282,($2|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch_2()|0;
  $6 = tempRet0;
  __ZdlPv($1);
  ___resumeException($5|0);
  // unreachable;
 } else {
  HEAP32[$2>>2] = (63412);
  $7 = ((($1)) + 24|0);
  ;HEAP32[$7>>2]=0|0;HEAP32[$7+4>>2]=0|0;HEAP32[$7+8>>2]=0|0;
  $8 = ((($1)) + 36|0);
  HEAP32[$8>>2] = 2;
  $9 = ((($1)) + 40|0);
  HEAP32[$9>>2] = 0;
  $10 = ((($1)) + 4|0);
  $11 = HEAP32[(56304)>>2]|0;
  HEAP32[$10>>2] = $11;
  $12 = HEAP32[(56308)>>2]|0;
  $$cast$i$i$i = $11;
  $13 = ((($$cast$i$i$i)) + -12|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($10) + ($14)|0);
  HEAP32[$15>>2] = $12;
  $16 = ((($1)) + 8|0);
  HEAP32[$16>>2] = 0;
  HEAP32[$1>>2] = (55748);
  HEAP32[$10>>2] = (55904);
  HEAP32[$2>>2] = (56152);
  $17 = HEAP32[13933]|0;
  $18 = (($1) + ($17)|0);
  return ($18|0);
 }
 return (0)|0;
}
function __ZTv0_n24_NK3osg12NodeCallback5cloneERKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$cast$i$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $3 = ((($2)) + -24|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($0) + ($4)|0);
 $6 = (__Znwj(44)|0);
 $7 = ((($6)) + 12|0);
 $8 = HEAP32[$5>>2]|0;
 $9 = ((($8)) + -16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($5) + ($10)|0);
 __THREW__ = 0;
 invoke_viii(3468,($7|0),($11|0),($1|0));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $34 = ___cxa_find_matching_catch_2()|0;
  $35 = tempRet0;
  __ZdlPv($6);
  ___resumeException($34|0);
  // unreachable;
 }
 $14 = ((($6)) + 4|0);
 $15 = HEAP32[$5>>2]|0;
 $16 = ((($15)) + -12|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($5) + ($17)|0);
 $19 = HEAP32[(56304)>>2]|0;
 HEAP32[$14>>2] = $19;
 $20 = HEAP32[(56308)>>2]|0;
 $$cast$i$i$i = $19;
 $21 = ((($$cast$i$i$i)) + -12|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($14) + ($22)|0);
 HEAP32[$23>>2] = $20;
 $24 = ((($6)) + 8|0);
 $25 = ((($18)) + 4|0);
 $26 = HEAP32[$25>>2]|0;
 HEAP32[$24>>2] = $26;
 $27 = ($26|0)==(0|0);
 if ($27) {
  HEAP32[$6>>2] = (55748);
  HEAP32[$14>>2] = (55904);
  HEAP32[$7>>2] = (56152);
  $36 = HEAP32[13933]|0;
  $37 = (($6) + ($36)|0);
  return ($37|0);
 }
 $28 = HEAP32[$26>>2]|0;
 $29 = ((($28)) + -12|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($26) + ($30)|0);
 $32 = ((($31)) + 8|0);
 $33 = HEAP32[$32>>2]|0;HEAP32[$32>>2] = (($33+1)|0);
 HEAP32[$6>>2] = (55748);
 HEAP32[$14>>2] = (55904);
 HEAP32[$7>>2] = (56152);
 $36 = HEAP32[13933]|0;
 $37 = (($6) + ($36)|0);
 return ($37|0);
}
function __ZTv0_n28_NK3osg12NodeCallback12isSameKindAsEPKNS_6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,23160,-1)|0);
 $phitmp$i = ($3|0)!=(0|0);
 $4 = $phitmp$i;
 return ($4|0);
}
function __ZTv0_n32_NK3osg12NodeCallback11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175113|0);
}
function __ZTv0_n36_NK3osg12NodeCallback9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (107856|0);
}
function __ZNK5osgGA12EventHandler9cloneTypeEv($0) {
 $0 = $0|0;
 var $$cast$i$i = 0, $$cast$i2$i = 0, $$cast$i3$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(48)|0);
 $2 = ((($1)) + 16|0);
 __THREW__ = 0;
 invoke_vi(3282,($2|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $38 = ___cxa_find_matching_catch_2()|0;
  $39 = tempRet0;
  __ZdlPv($1);
  ___resumeException($38|0);
  // unreachable;
 } else {
  HEAP32[$2>>2] = (63412);
  $5 = ((($1)) + 28|0);
  ;HEAP32[$5>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;
  $6 = ((($1)) + 40|0);
  HEAP32[$6>>2] = 2;
  $7 = ((($1)) + 44|0);
  HEAP32[$7>>2] = 0;
  $8 = ((($1)) + 8|0);
  $9 = HEAP32[(42048)>>2]|0;
  HEAP32[$8>>2] = $9;
  $10 = HEAP32[(42052)>>2]|0;
  $$cast$i$i = $9;
  $11 = ((($$cast$i$i)) + -12|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($8) + ($12)|0);
  HEAP32[$13>>2] = $10;
  $14 = ((($1)) + 12|0);
  HEAP32[$14>>2] = 0;
  $15 = HEAP32[(42012)>>2]|0;
  HEAP32[$1>>2] = $15;
  $16 = HEAP32[(42016)>>2]|0;
  $$cast$i2$i = $15;
  $17 = ((($$cast$i2$i)) + -12|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (($1) + ($18)|0);
  HEAP32[$19>>2] = $16;
  $20 = HEAP32[(42020)>>2]|0;
  $21 = HEAP32[$1>>2]|0;
  $22 = ((($21)) + -16|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (($1) + ($23)|0);
  HEAP32[$24>>2] = $20;
  $25 = ((($1)) + 4|0);
  $26 = HEAP32[(42024)>>2]|0;
  HEAP32[$25>>2] = $26;
  $27 = HEAP32[(42028)>>2]|0;
  $$cast$i3$i = $26;
  $28 = ((($$cast$i3$i)) + -12|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = (($25) + ($29)|0);
  HEAP32[$30>>2] = $27;
  $31 = HEAP32[(42032)>>2]|0;
  $32 = HEAP32[$25>>2]|0;
  $33 = ((($32)) + -16|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = (($25) + ($34)|0);
  HEAP32[$35>>2] = $31;
  HEAP32[$1>>2] = (32);
  HEAP32[$8>>2] = (276);
  HEAP32[$2>>2] = (524);
  HEAP32[$25>>2] = (120);
  $36 = HEAP32[4]|0;
  $37 = (($1) + ($36)|0);
  return ($37|0);
 }
 return (0)|0;
}
function __ZNK5osgGA12EventHandler5cloneERKN3osg6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$cast$i$i = 0, $$cast$i10$i = 0, $$cast$i11$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(48)|0);
 $3 = ((($2)) + 16|0);
 $4 = HEAP32[$0>>2]|0;
 $5 = ((($4)) + -16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($0) + ($6)|0);
 __THREW__ = 0;
 invoke_viii(3468,($3|0),($7|0),($1|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $53 = ___cxa_find_matching_catch_2()|0;
  $54 = tempRet0;
  __ZdlPv($2);
  ___resumeException($53|0);
  // unreachable;
 }
 $10 = ((($2)) + 8|0);
 $11 = HEAP32[$0>>2]|0;
 $12 = ((($11)) + -12|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($0) + ($13)|0);
 $15 = HEAP32[(42048)>>2]|0;
 HEAP32[$10>>2] = $15;
 $16 = HEAP32[(42052)>>2]|0;
 $$cast$i$i = $15;
 $17 = ((($$cast$i$i)) + -12|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($10) + ($18)|0);
 HEAP32[$19>>2] = $16;
 $20 = ((($2)) + 12|0);
 $21 = ((($14)) + 4|0);
 $22 = HEAP32[$21>>2]|0;
 HEAP32[$20>>2] = $22;
 $23 = ($22|0)==(0|0);
 if (!($23)) {
  $24 = HEAP32[$22>>2]|0;
  $25 = ((($24)) + -12|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($22) + ($26)|0);
  $28 = ((($27)) + 8|0);
  $29 = HEAP32[$28>>2]|0;HEAP32[$28>>2] = (($29+1)|0);
 }
 $30 = HEAP32[(42012)>>2]|0;
 HEAP32[$2>>2] = $30;
 $31 = HEAP32[(42016)>>2]|0;
 $$cast$i10$i = $30;
 $32 = ((($$cast$i10$i)) + -12|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = (($2) + ($33)|0);
 HEAP32[$34>>2] = $31;
 $35 = HEAP32[(42020)>>2]|0;
 $36 = HEAP32[$2>>2]|0;
 $37 = ((($36)) + -16|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (($2) + ($38)|0);
 HEAP32[$39>>2] = $35;
 $40 = ((($2)) + 4|0);
 $41 = HEAP32[(42024)>>2]|0;
 HEAP32[$40>>2] = $41;
 $42 = HEAP32[(42028)>>2]|0;
 $$cast$i11$i = $41;
 $43 = ((($$cast$i11$i)) + -12|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = (($40) + ($44)|0);
 HEAP32[$45>>2] = $42;
 $46 = HEAP32[(42032)>>2]|0;
 $47 = HEAP32[$40>>2]|0;
 $48 = ((($47)) + -16|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = (($40) + ($49)|0);
 HEAP32[$50>>2] = $46;
 HEAP32[$2>>2] = (32);
 HEAP32[$10>>2] = (276);
 HEAP32[$3>>2] = (524);
 HEAP32[$40>>2] = (120);
 $51 = HEAP32[4]|0;
 $52 = (($2) + ($51)|0);
 return ($52|0);
}
function __ZNK5osgGA12EventHandler12isSameKindAsEPKN3osg6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,8384,-1)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK5osgGA12EventHandler11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (109961|0);
}
function __ZNK5osgGA12EventHandler9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (107869|0);
}
function __ZN5osgGA12EventHandlerD1Ev($0) {
 $0 = $0|0;
 var $$cast$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 8|0);
 $2 = HEAP32[(42048)>>2]|0;
 HEAP32[$1>>2] = $2;
 $3 = HEAP32[(42052)>>2]|0;
 $$cast$i = $2;
 $4 = ((($$cast$i)) + -12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($1) + ($5)|0);
 HEAP32[$6>>2] = $3;
 $7 = ((($0)) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if ($9) {
  HEAP32[$7>>2] = 0;
  $19 = ((($0)) + 16|0);
  __ZN3osg6ObjectD2Ev($19);
  return;
 }
 $10 = HEAP32[$8>>2]|0;
 $11 = ((($10)) + -12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($8) + ($12)|0);
 $14 = ((($13)) + 8|0);
 $15 = HEAP32[$14>>2]|0;HEAP32[$14>>2] = (($15-1)|0);
 $16 = ($15|0)==(1);
 if (!($16)) {
  HEAP32[$7>>2] = 0;
  $19 = ((($0)) + 16|0);
  __ZN3osg6ObjectD2Ev($19);
  return;
 }
 __THREW__ = 0;
 invoke_viii(3262,($13|0),1,1);
 $17 = __THREW__; __THREW__ = 0;
 $18 = $17&1;
 if (!($18)) {
  HEAP32[$7>>2] = 0;
  $19 = ((($0)) + 16|0);
  __ZN3osg6ObjectD2Ev($19);
  return;
 }
 $20 = ___cxa_find_matching_catch_2()|0;
 $21 = tempRet0;
 $22 = ((($0)) + 16|0);
 __THREW__ = 0;
 invoke_vi(388,($22|0));
 $23 = __THREW__; __THREW__ = 0;
 $24 = $23&1;
 if ($24) {
  $25 = ___cxa_find_matching_catch_3(0|0)|0;
  $26 = tempRet0;
  ___clang_call_terminate($25);
  // unreachable;
 } else {
  ___resumeException($20|0);
  // unreachable;
 }
}
function __ZN5osgGA12EventHandlerD0Ev($0) {
 $0 = $0|0;
 var $$cast$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 8|0);
 $2 = HEAP32[(42048)>>2]|0;
 HEAP32[$1>>2] = $2;
 $3 = HEAP32[(42052)>>2]|0;
 $$cast$i$i = $2;
 $4 = ((($$cast$i$i)) + -12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($1) + ($5)|0);
 HEAP32[$6>>2] = $3;
 $7 = ((($0)) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if (!($9)) {
  $10 = HEAP32[$8>>2]|0;
  $11 = ((($10)) + -12|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($8) + ($12)|0);
  $14 = ((($13)) + 8|0);
  $15 = HEAP32[$14>>2]|0;HEAP32[$14>>2] = (($15-1)|0);
  $16 = ($15|0)==(1);
  if ($16) {
   __THREW__ = 0;
   invoke_viii(3262,($13|0),1,1);
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if ($18) {
    $22 = ___cxa_find_matching_catch_2()|0;
    $23 = tempRet0;
    $24 = ((($0)) + 16|0);
    __THREW__ = 0;
    invoke_vi(388,($24|0));
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if ($26) {
     $27 = ___cxa_find_matching_catch_3(0|0)|0;
     $28 = tempRet0;
     ___clang_call_terminate($27);
     // unreachable;
    } else {
     $eh$lpad$body$index2Z2D = $23;$eh$lpad$body$indexZ2D = $22;
     __ZdlPv($0);
     ___resumeException($eh$lpad$body$indexZ2D|0);
     // unreachable;
    }
   }
  }
 }
 HEAP32[$7>>2] = 0;
 $19 = ((($0)) + 16|0);
 __THREW__ = 0;
 invoke_vi(388,($19|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if (!($21)) {
  __ZdlPv($0);
  return;
 }
 $29 = ___cxa_find_matching_catch_2()|0;
 $30 = tempRet0;
 $eh$lpad$body$index2Z2D = $30;$eh$lpad$body$indexZ2D = $29;
 __ZdlPv($0);
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
}
function __ZThn4_NK5osgGA12EventHandler9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -4|0);
 $2 = (__ZNK5osgGA12EventHandler9cloneTypeEv($1)|0);
 return ($2|0);
}
function __ZThn4_NK5osgGA12EventHandler5cloneERKN3osg6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + -4|0);
 $3 = (__ZNK5osgGA12EventHandler5cloneERKN3osg6CopyOpE($2,$1)|0);
 return ($3|0);
}
function __ZThn4_NK5osgGA12EventHandler12isSameKindAsEPKN3osg6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,8384,-1)|0);
 $phitmp$i = ($3|0)!=(0|0);
 $4 = $phitmp$i;
 return ($4|0);
}
function __ZThn4_NK5osgGA12EventHandler11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (109961|0);
}
function __ZThn4_NK5osgGA12EventHandler9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (107869|0);
}
function __ZThn4_N5osgGA12EventHandlerD1Ev($0) {
 $0 = $0|0;
 var $$cast$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -4|0);
 $2 = ((($1)) + 8|0);
 $3 = HEAP32[(42048)>>2]|0;
 HEAP32[$2>>2] = $3;
 $4 = HEAP32[(42052)>>2]|0;
 $$cast$i$i = $3;
 $5 = ((($$cast$i$i)) + -12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($2) + ($6)|0);
 HEAP32[$7>>2] = $4;
 $8 = ((($1)) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if ($10) {
  HEAP32[$8>>2] = 0;
  $27 = ((($1)) + 16|0);
  __ZN3osg6ObjectD2Ev($27);
  return;
 }
 $11 = HEAP32[$9>>2]|0;
 $12 = ((($11)) + -12|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($9) + ($13)|0);
 $15 = ((($14)) + 8|0);
 $16 = HEAP32[$15>>2]|0;HEAP32[$15>>2] = (($16-1)|0);
 $17 = ($16|0)==(1);
 if (!($17)) {
  HEAP32[$8>>2] = 0;
  $27 = ((($1)) + 16|0);
  __ZN3osg6ObjectD2Ev($27);
  return;
 }
 __THREW__ = 0;
 invoke_viii(3262,($14|0),1,1);
 $18 = __THREW__; __THREW__ = 0;
 $19 = $18&1;
 if (!($19)) {
  HEAP32[$8>>2] = 0;
  $27 = ((($1)) + 16|0);
  __ZN3osg6ObjectD2Ev($27);
  return;
 }
 $20 = ___cxa_find_matching_catch_2()|0;
 $21 = tempRet0;
 $22 = ((($1)) + 16|0);
 __THREW__ = 0;
 invoke_vi(388,($22|0));
 $23 = __THREW__; __THREW__ = 0;
 $24 = $23&1;
 if ($24) {
  $25 = ___cxa_find_matching_catch_3(0|0)|0;
  $26 = tempRet0;
  ___clang_call_terminate($25);
  // unreachable;
 } else {
  ___resumeException($20|0);
  // unreachable;
 }
}
function __ZThn4_N5osgGA12EventHandlerD0Ev($0) {
 $0 = $0|0;
 var $$cast$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$i$index2Z2D = 0, $eh$lpad$body$i$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -4|0);
 $2 = ((($1)) + 8|0);
 $3 = HEAP32[(42048)>>2]|0;
 HEAP32[$2>>2] = $3;
 $4 = HEAP32[(42052)>>2]|0;
 $$cast$i$i$i = $3;
 $5 = ((($$cast$i$i$i)) + -12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($2) + ($6)|0);
 HEAP32[$7>>2] = $4;
 $8 = ((($1)) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if (!($10)) {
  $11 = HEAP32[$9>>2]|0;
  $12 = ((($11)) + -12|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($9) + ($13)|0);
  $15 = ((($14)) + 8|0);
  $16 = HEAP32[$15>>2]|0;HEAP32[$15>>2] = (($16-1)|0);
  $17 = ($16|0)==(1);
  if ($17) {
   __THREW__ = 0;
   invoke_viii(3262,($14|0),1,1);
   $18 = __THREW__; __THREW__ = 0;
   $19 = $18&1;
   if ($19) {
    $23 = ___cxa_find_matching_catch_2()|0;
    $24 = tempRet0;
    $25 = ((($1)) + 16|0);
    __THREW__ = 0;
    invoke_vi(388,($25|0));
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if ($27) {
     $28 = ___cxa_find_matching_catch_3(0|0)|0;
     $29 = tempRet0;
     ___clang_call_terminate($28);
     // unreachable;
    } else {
     $eh$lpad$body$i$index2Z2D = $24;$eh$lpad$body$i$indexZ2D = $23;
     __ZdlPv($1);
     ___resumeException($eh$lpad$body$i$indexZ2D|0);
     // unreachable;
    }
   }
  }
 }
 HEAP32[$8>>2] = 0;
 $20 = ((($1)) + 16|0);
 __THREW__ = 0;
 invoke_vi(388,($20|0));
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if (!($22)) {
  __ZdlPv($1);
  return;
 }
 $30 = ___cxa_find_matching_catch_2()|0;
 $31 = tempRet0;
 $eh$lpad$body$i$index2Z2D = $31;$eh$lpad$body$i$indexZ2D = $30;
 __ZdlPv($1);
 ___resumeException($eh$lpad$body$i$indexZ2D|0);
 // unreachable;
}
function __ZTv0_n16_NK5osgGA12EventHandler9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 $5 = (__ZNK5osgGA12EventHandler9cloneTypeEv($4)|0);
 return ($5|0);
}
function __ZTv0_n20_NK5osgGA12EventHandler5cloneERKN3osg6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $3 = ((($2)) + -20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($0) + ($4)|0);
 $6 = (__ZNK5osgGA12EventHandler5cloneERKN3osg6CopyOpE($5,$1)|0);
 return ($6|0);
}
function __ZTv0_n24_NK5osgGA12EventHandler12isSameKindAsEPKN3osg6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,8384,-1)|0);
 $phitmp$i = ($3|0)!=(0|0);
 $4 = $phitmp$i;
 return ($4|0);
}
function __ZTv0_n28_NK5osgGA12EventHandler11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (109961|0);
}
function __ZTv0_n32_NK5osgGA12EventHandler9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (107869|0);
}
function __ZTv0_n112_N5osgGA12EventHandlerD1Ev($0) {
 $0 = $0|0;
 var $$cast$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -112|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 $5 = ((($4)) + 8|0);
 $6 = HEAP32[(42048)>>2]|0;
 HEAP32[$5>>2] = $6;
 $7 = HEAP32[(42052)>>2]|0;
 $$cast$i$i = $6;
 $8 = ((($$cast$i$i)) + -12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($5) + ($9)|0);
 HEAP32[$10>>2] = $7;
 $11 = ((($4)) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0|0);
 if ($13) {
  HEAP32[$11>>2] = 0;
  $30 = ((($4)) + 16|0);
  __ZN3osg6ObjectD2Ev($30);
  return;
 }
 $14 = HEAP32[$12>>2]|0;
 $15 = ((($14)) + -12|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($12) + ($16)|0);
 $18 = ((($17)) + 8|0);
 $19 = HEAP32[$18>>2]|0;HEAP32[$18>>2] = (($19-1)|0);
 $20 = ($19|0)==(1);
 if (!($20)) {
  HEAP32[$11>>2] = 0;
  $30 = ((($4)) + 16|0);
  __ZN3osg6ObjectD2Ev($30);
  return;
 }
 __THREW__ = 0;
 invoke_viii(3262,($17|0),1,1);
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if (!($22)) {
  HEAP32[$11>>2] = 0;
  $30 = ((($4)) + 16|0);
  __ZN3osg6ObjectD2Ev($30);
  return;
 }
 $23 = ___cxa_find_matching_catch_2()|0;
 $24 = tempRet0;
 $25 = ((($4)) + 16|0);
 __THREW__ = 0;
 invoke_vi(388,($25|0));
 $26 = __THREW__; __THREW__ = 0;
 $27 = $26&1;
 if ($27) {
  $28 = ___cxa_find_matching_catch_3(0|0)|0;
  $29 = tempRet0;
  ___clang_call_terminate($28);
  // unreachable;
 } else {
  ___resumeException($23|0);
  // unreachable;
 }
}
function __ZTv0_n112_N5osgGA12EventHandlerD0Ev($0) {
 $0 = $0|0;
 var $$cast$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$i$index2Z2D = 0, $eh$lpad$body$i$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -112|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 $5 = ((($4)) + 8|0);
 $6 = HEAP32[(42048)>>2]|0;
 HEAP32[$5>>2] = $6;
 $7 = HEAP32[(42052)>>2]|0;
 $$cast$i$i$i = $6;
 $8 = ((($$cast$i$i$i)) + -12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($5) + ($9)|0);
 HEAP32[$10>>2] = $7;
 $11 = ((($4)) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0|0);
 if (!($13)) {
  $14 = HEAP32[$12>>2]|0;
  $15 = ((($14)) + -12|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (($12) + ($16)|0);
  $18 = ((($17)) + 8|0);
  $19 = HEAP32[$18>>2]|0;HEAP32[$18>>2] = (($19-1)|0);
  $20 = ($19|0)==(1);
  if ($20) {
   __THREW__ = 0;
   invoke_viii(3262,($17|0),1,1);
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if ($22) {
    $26 = ___cxa_find_matching_catch_2()|0;
    $27 = tempRet0;
    $28 = ((($4)) + 16|0);
    __THREW__ = 0;
    invoke_vi(388,($28|0));
    $29 = __THREW__; __THREW__ = 0;
    $30 = $29&1;
    if ($30) {
     $31 = ___cxa_find_matching_catch_3(0|0)|0;
     $32 = tempRet0;
     ___clang_call_terminate($31);
     // unreachable;
    } else {
     $eh$lpad$body$i$index2Z2D = $27;$eh$lpad$body$i$indexZ2D = $26;
     __ZdlPv($4);
     ___resumeException($eh$lpad$body$i$indexZ2D|0);
     // unreachable;
    }
   }
  }
 }
 HEAP32[$11>>2] = 0;
 $23 = ((($4)) + 16|0);
 __THREW__ = 0;
 invoke_vi(388,($23|0));
 $24 = __THREW__; __THREW__ = 0;
 $25 = $24&1;
 if (!($25)) {
  __ZdlPv($4);
  return;
 }
 $33 = ___cxa_find_matching_catch_2()|0;
 $34 = tempRet0;
 $eh$lpad$body$i$index2Z2D = $34;$eh$lpad$body$i$indexZ2D = $33;
 __ZdlPv($4);
 ___resumeException($eh$lpad$body$i$indexZ2D|0);
 // unreachable;
}
function __ZTv0_n16_N5osgGA12EventHandlerD1Ev($0) {
 $0 = $0|0;
 var $$cast$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 $5 = ((($4)) + 8|0);
 $6 = HEAP32[(42048)>>2]|0;
 HEAP32[$5>>2] = $6;
 $7 = HEAP32[(42052)>>2]|0;
 $$cast$i$i = $6;
 $8 = ((($$cast$i$i)) + -12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($5) + ($9)|0);
 HEAP32[$10>>2] = $7;
 $11 = ((($4)) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0|0);
 if ($13) {
  HEAP32[$11>>2] = 0;
  $30 = ((($4)) + 16|0);
  __ZN3osg6ObjectD2Ev($30);
  return;
 }
 $14 = HEAP32[$12>>2]|0;
 $15 = ((($14)) + -12|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($12) + ($16)|0);
 $18 = ((($17)) + 8|0);
 $19 = HEAP32[$18>>2]|0;HEAP32[$18>>2] = (($19-1)|0);
 $20 = ($19|0)==(1);
 if (!($20)) {
  HEAP32[$11>>2] = 0;
  $30 = ((($4)) + 16|0);
  __ZN3osg6ObjectD2Ev($30);
  return;
 }
 __THREW__ = 0;
 invoke_viii(3262,($17|0),1,1);
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if (!($22)) {
  HEAP32[$11>>2] = 0;
  $30 = ((($4)) + 16|0);
  __ZN3osg6ObjectD2Ev($30);
  return;
 }
 $23 = ___cxa_find_matching_catch_2()|0;
 $24 = tempRet0;
 $25 = ((($4)) + 16|0);
 __THREW__ = 0;
 invoke_vi(388,($25|0));
 $26 = __THREW__; __THREW__ = 0;
 $27 = $26&1;
 if ($27) {
  $28 = ___cxa_find_matching_catch_3(0|0)|0;
  $29 = tempRet0;
  ___clang_call_terminate($28);
  // unreachable;
 } else {
  ___resumeException($23|0);
  // unreachable;
 }
}
function __ZTv0_n16_N5osgGA12EventHandlerD0Ev($0) {
 $0 = $0|0;
 var $$cast$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$i$index2Z2D = 0, $eh$lpad$body$i$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 $5 = ((($4)) + 8|0);
 $6 = HEAP32[(42048)>>2]|0;
 HEAP32[$5>>2] = $6;
 $7 = HEAP32[(42052)>>2]|0;
 $$cast$i$i$i = $6;
 $8 = ((($$cast$i$i$i)) + -12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($5) + ($9)|0);
 HEAP32[$10>>2] = $7;
 $11 = ((($4)) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0|0);
 if (!($13)) {
  $14 = HEAP32[$12>>2]|0;
  $15 = ((($14)) + -12|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (($12) + ($16)|0);
  $18 = ((($17)) + 8|0);
  $19 = HEAP32[$18>>2]|0;HEAP32[$18>>2] = (($19-1)|0);
  $20 = ($19|0)==(1);
  if ($20) {
   __THREW__ = 0;
   invoke_viii(3262,($17|0),1,1);
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if ($22) {
    $26 = ___cxa_find_matching_catch_2()|0;
    $27 = tempRet0;
    $28 = ((($4)) + 16|0);
    __THREW__ = 0;
    invoke_vi(388,($28|0));
    $29 = __THREW__; __THREW__ = 0;
    $30 = $29&1;
    if ($30) {
     $31 = ___cxa_find_matching_catch_3(0|0)|0;
     $32 = tempRet0;
     ___clang_call_terminate($31);
     // unreachable;
    } else {
     $eh$lpad$body$i$index2Z2D = $27;$eh$lpad$body$i$indexZ2D = $26;
     __ZdlPv($4);
     ___resumeException($eh$lpad$body$i$indexZ2D|0);
     // unreachable;
    }
   }
  }
 }
 HEAP32[$11>>2] = 0;
 $23 = ((($4)) + 16|0);
 __THREW__ = 0;
 invoke_vi(388,($23|0));
 $24 = __THREW__; __THREW__ = 0;
 $25 = $24&1;
 if (!($25)) {
  __ZdlPv($4);
  return;
 }
 $33 = ___cxa_find_matching_catch_2()|0;
 $34 = tempRet0;
 $eh$lpad$body$i$index2Z2D = $34;$eh$lpad$body$i$indexZ2D = $33;
 __ZdlPv($4);
 ___resumeException($eh$lpad$body$i$indexZ2D|0);
 // unreachable;
}
function __ZTv0_n20_NK5osgGA12EventHandler9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -20|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 $5 = (__ZNK5osgGA12EventHandler9cloneTypeEv($4)|0);
 return ($5|0);
}
function __ZTv0_n24_NK5osgGA12EventHandler5cloneERKN3osg6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $3 = ((($2)) + -24|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($0) + ($4)|0);
 $6 = (__ZNK5osgGA12EventHandler5cloneERKN3osg6CopyOpE($5,$1)|0);
 return ($6|0);
}
function __ZTv0_n28_NK5osgGA12EventHandler12isSameKindAsEPKN3osg6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,8384,-1)|0);
 $phitmp$i = ($3|0)!=(0|0);
 $4 = $phitmp$i;
 return ($4|0);
}
function __ZTv0_n32_NK5osgGA12EventHandler11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (109961|0);
}
function __ZTv0_n36_NK5osgGA12EventHandler9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (107869|0);
}
function __ZN5osgGA15GUIEventHandler6handleERKNS_15GUIEventAdapterERNS_16GUIActionAdapterEPN3osg6ObjectEPNS6_11NodeVisitorE($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = HEAP32[$0>>2]|0;
 $6 = ((($5)) + 76|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_iiii[$7 & 8191]($0,$1,$2)|0);
 return ($8|0);
}
function __ZN9osgViewer8KeystoneC2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg10ReferencedC2Ev($0);
 $1 = ((($0)) + 12|0);
 ;HEAP32[$1>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;
 $2 = ((($0)) + 24|0);
 HEAP32[$2>>2] = 2;
 $3 = ((($0)) + 28|0);
 HEAP32[$3>>2] = 0;
 HEAP32[$0>>2] = (40172);
 $4 = ((($0)) + 32|0);
 HEAP8[$4>>0] = 0;
 $5 = ((($0)) + 36|0);
 HEAPF32[$5>>2] = 1.0;
 $6 = ((($0)) + 40|0);
 HEAPF32[$6>>2] = 1.0;
 $7 = ((($0)) + 44|0);
 HEAPF32[$7>>2] = 1.0;
 $8 = ((($0)) + 48|0);
 HEAPF32[$8>>2] = 1.0;
 $9 = ((($0)) + 56|0);
 HEAPF64[$9>>3] = -1.0;
 $10 = ((($0)) + 64|0);
 HEAPF64[$10>>3] = -1.0;
 $11 = ((($0)) + 72|0);
 HEAPF64[$11>>3] = 1.0;
 $12 = ((($0)) + 80|0);
 HEAPF64[$12>>3] = -1.0;
 $13 = ((($0)) + 88|0);
 HEAPF64[$13>>3] = -1.0;
 $14 = ((($0)) + 96|0);
 HEAPF64[$14>>3] = 1.0;
 $15 = ((($0)) + 104|0);
 HEAPF64[$15>>3] = 1.0;
 $16 = ((($0)) + 112|0);
 HEAPF64[$16>>3] = 1.0;
 return;
}
function __ZN9osgViewer8KeystoneD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(388,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK9osgViewer8Keystone9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(120)|0);
 __THREW__ = 0;
 invoke_vi(3282,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $20 = ___cxa_find_matching_catch_2()|0;
  $21 = tempRet0;
  __ZdlPv($1);
  ___resumeException($20|0);
  // unreachable;
 } else {
  $4 = ((($1)) + 12|0);
  ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;
  $5 = ((($1)) + 24|0);
  HEAP32[$5>>2] = 2;
  $6 = ((($1)) + 28|0);
  HEAP32[$6>>2] = 0;
  HEAP32[$1>>2] = (40172);
  $7 = ((($1)) + 32|0);
  HEAP8[$7>>0] = 0;
  $8 = ((($1)) + 36|0);
  HEAPF32[$8>>2] = 1.0;
  $9 = ((($1)) + 40|0);
  HEAPF32[$9>>2] = 1.0;
  $10 = ((($1)) + 44|0);
  HEAPF32[$10>>2] = 1.0;
  $11 = ((($1)) + 48|0);
  HEAPF32[$11>>2] = 1.0;
  $12 = ((($1)) + 56|0);
  HEAPF64[$12>>3] = -1.0;
  $13 = ((($1)) + 64|0);
  HEAPF64[$13>>3] = -1.0;
  $14 = ((($1)) + 72|0);
  HEAPF64[$14>>3] = 1.0;
  $15 = ((($1)) + 80|0);
  HEAPF64[$15>>3] = -1.0;
  $16 = ((($1)) + 88|0);
  HEAPF64[$16>>3] = -1.0;
  $17 = ((($1)) + 96|0);
  HEAPF64[$17>>3] = 1.0;
  $18 = ((($1)) + 104|0);
  HEAPF64[$18>>3] = 1.0;
  $19 = ((($1)) + 112|0);
  HEAPF64[$19>>3] = 1.0;
  return ($1|0);
 }
 return (0)|0;
}
function __ZNK9osgViewer8Keystone5cloneERKN3osg6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(120)|0);
 __THREW__ = 0;
 invoke_viii(3468,($2|0),($0|0),($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $18 = ___cxa_find_matching_catch_2()|0;
  $19 = tempRet0;
  __ZdlPv($2);
  ___resumeException($18|0);
  // unreachable;
 } else {
  HEAP32[$2>>2] = (40172);
  $5 = ((($2)) + 32|0);
  $6 = ((($0)) + 32|0);
  $7 = HEAP8[$6>>0]|0;
  HEAP8[$5>>0] = $7;
  $8 = ((($2)) + 36|0);
  $9 = ((($0)) + 36|0);
  ;HEAP32[$8>>2]=HEAP32[$9>>2]|0;HEAP32[$8+4>>2]=HEAP32[$9+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$9+8>>2]|0;HEAP32[$8+12>>2]=HEAP32[$9+12>>2]|0;
  $10 = ((($2)) + 56|0);
  $11 = ((($0)) + 56|0);
  ;HEAP32[$10>>2]=HEAP32[$11>>2]|0;HEAP32[$10+4>>2]=HEAP32[$11+4>>2]|0;HEAP32[$10+8>>2]=HEAP32[$11+8>>2]|0;HEAP32[$10+12>>2]=HEAP32[$11+12>>2]|0;
  $12 = ((($2)) + 72|0);
  $13 = ((($0)) + 72|0);
  ;HEAP32[$12>>2]=HEAP32[$13>>2]|0;HEAP32[$12+4>>2]=HEAP32[$13+4>>2]|0;HEAP32[$12+8>>2]=HEAP32[$13+8>>2]|0;HEAP32[$12+12>>2]=HEAP32[$13+12>>2]|0;
  $14 = ((($2)) + 88|0);
  $15 = ((($0)) + 88|0);
  ;HEAP32[$14>>2]=HEAP32[$15>>2]|0;HEAP32[$14+4>>2]=HEAP32[$15+4>>2]|0;HEAP32[$14+8>>2]=HEAP32[$15+8>>2]|0;HEAP32[$14+12>>2]=HEAP32[$15+12>>2]|0;
  $16 = ((($2)) + 104|0);
  $17 = ((($0)) + 104|0);
  ;HEAP32[$16>>2]=HEAP32[$17>>2]|0;HEAP32[$16+4>>2]=HEAP32[$17+4>>2]|0;HEAP32[$16+8>>2]=HEAP32[$17+8>>2]|0;HEAP32[$16+12>>2]=HEAP32[$17+12>>2]|0;
  return ($2|0);
 }
 return (0)|0;
}
function __ZNK9osgViewer8Keystone12isSameKindAsEPKN3osg6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,4080,0)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK9osgViewer8Keystone11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (107921|0);
}
function __ZNK9osgViewer8Keystone9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (107912|0);
}
function __ZNK9osgViewer8Keystone18compute3DPositionsEPN3osg15DisplaySettingsERNS1_5Vec3fES5_S5_S5_($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$sroa$456$0$$sroa_idx57 = 0, $$sroa$469$0$$sroa_idx70 = 0, $$sroa$483$0$$sroa_idx84 = 0, $$sroa$497$0$$sroa_idx98 = 0, $$sroa$5$0$$sroa_idx59 = 0, $$sroa$5100$0$$sroa_idx101 = 0, $$sroa$572$0$$sroa_idx73 = 0, $$sroa$586$0$$sroa_idx87 = 0, $10 = 0.0, $100 = 0.0, $101 = 0.0, $102 = 0.0, $103 = 0.0, $104 = 0.0, $105 = 0.0, $106 = 0.0, $107 = 0.0, $108 = 0.0, $109 = 0.0, $11 = 0;
 var $110 = 0.0, $12 = 0.0, $13 = 0, $14 = 0.0, $15 = 0.0, $16 = 0.0, $17 = 0.0, $18 = 0.0, $19 = 0.0, $20 = 0, $21 = 0.0, $22 = 0, $23 = 0.0, $24 = 0.0, $25 = 0, $26 = 0.0, $27 = 0, $28 = 0.0, $29 = 0.0, $30 = 0.0;
 var $31 = 0.0, $32 = 0.0, $33 = 0.0, $34 = 0.0, $35 = 0.0, $36 = 0.0, $37 = 0.0, $38 = 0.0, $39 = 0.0, $40 = 0.0, $41 = 0.0, $42 = 0.0, $43 = 0.0, $44 = 0.0, $45 = 0.0, $46 = 0.0, $47 = 0.0, $48 = 0.0, $49 = 0.0, $50 = 0.0;
 var $51 = 0.0, $52 = 0, $53 = 0.0, $54 = 0, $55 = 0.0, $56 = 0.0, $57 = 0, $58 = 0.0, $59 = 0.0, $6 = 0, $60 = 0.0, $61 = 0.0, $62 = 0.0, $63 = 0.0, $64 = 0.0, $65 = 0.0, $66 = 0.0, $67 = 0.0, $68 = 0.0, $69 = 0.0;
 var $7 = 0.0, $70 = 0.0, $71 = 0.0, $72 = 0.0, $73 = 0.0, $74 = 0.0, $75 = 0.0, $76 = 0.0, $77 = 0.0, $78 = 0.0, $79 = 0.0, $8 = 0, $80 = 0.0, $81 = 0.0, $82 = 0.0, $83 = 0.0, $84 = 0.0, $85 = 0.0, $86 = 0.0, $87 = 0.0;
 var $88 = 0.0, $89 = 0.0, $9 = 0.0, $90 = 0.0, $91 = 0.0, $92 = 0.0, $93 = 0.0, $94 = 0.0, $95 = 0.0, $96 = 0.0, $97 = 0.0, $98 = 0.0, $99 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $6 = ((($0)) + 104|0);
 $7 = +HEAPF64[$6>>3];
 $8 = ((($0)) + 72|0);
 $9 = +HEAPF64[$8>>3];
 $10 = $7 - $9;
 $11 = ((($0)) + 112|0);
 $12 = +HEAPF64[$11>>3];
 $13 = ((($0)) + 80|0);
 $14 = +HEAPF64[$13>>3];
 $15 = $12 - $14;
 $16 = $10 * $10;
 $17 = $15 * $15;
 $18 = $16 + $17;
 $19 = (+Math_sqrt((+$18)));
 $20 = ((($0)) + 88|0);
 $21 = +HEAPF64[$20>>3];
 $22 = ((($0)) + 56|0);
 $23 = +HEAPF64[$22>>3];
 $24 = $21 - $23;
 $25 = ((($0)) + 96|0);
 $26 = +HEAPF64[$25>>3];
 $27 = ((($0)) + 64|0);
 $28 = +HEAPF64[$27>>3];
 $29 = $26 - $28;
 $30 = $24 * $24;
 $31 = $29 * $29;
 $32 = $30 + $31;
 $33 = (+Math_sqrt((+$32)));
 $34 = $19 / $33;
 $35 = (+Math_sqrt((+$34)));
 $36 = $35 / $34;
 $37 = $7 - $21;
 $38 = $12 - $26;
 $39 = $37 * $37;
 $40 = $38 * $38;
 $41 = $39 + $40;
 $42 = (+Math_sqrt((+$41)));
 $43 = $9 - $23;
 $44 = $14 - $28;
 $45 = $43 * $43;
 $46 = $44 * $44;
 $47 = $45 + $46;
 $48 = (+Math_sqrt((+$47)));
 $49 = $42 / $48;
 $50 = (+Math_sqrt((+$49)));
 $51 = $50 / $49;
 $52 = ((($1)) + 36|0);
 $53 = +HEAPF32[$52>>2];
 $54 = ((($1)) + 28|0);
 $55 = +HEAPF32[$54>>2];
 $56 = $55;
 $57 = ((($1)) + 32|0);
 $58 = +HEAPF32[$57>>2];
 $59 = $58;
 $60 = $56 * 0.5;
 $61 = $21 * $60;
 $62 = $61;
 $63 = $59 * 0.5;
 $64 = $26 * $63;
 $65 = $64;
 $66 = -$53;
 $67 = $35;
 $68 = $67 * $62;
 $69 = $67 * $65;
 $70 = $67 * $66;
 $71 = $51;
 $72 = $71 * $68;
 $73 = $71 * $69;
 $74 = $70 * $71;
 HEAPF32[$2>>2] = $72;
 $$sroa$497$0$$sroa_idx98 = ((($2)) + 4|0);
 HEAPF32[$$sroa$497$0$$sroa_idx98>>2] = $73;
 $$sroa$5100$0$$sroa_idx101 = ((($2)) + 8|0);
 HEAPF32[$$sroa$5100$0$$sroa_idx101>>2] = $74;
 $75 = +HEAPF64[$6>>3];
 $76 = $60 * $75;
 $77 = $76;
 $78 = +HEAPF64[$11>>3];
 $79 = $63 * $78;
 $80 = $79;
 $81 = $36;
 $82 = $81 * $77;
 $83 = $81 * $80;
 $84 = $81 * $66;
 $85 = $71 * $82;
 $86 = $71 * $83;
 $87 = $84 * $71;
 HEAPF32[$3>>2] = $85;
 $$sroa$483$0$$sroa_idx84 = ((($3)) + 4|0);
 HEAPF32[$$sroa$483$0$$sroa_idx84>>2] = $86;
 $$sroa$586$0$$sroa_idx87 = ((($3)) + 8|0);
 HEAPF32[$$sroa$586$0$$sroa_idx87>>2] = $87;
 $88 = +HEAPF64[$8>>3];
 $89 = $60 * $88;
 $90 = $89;
 $91 = +HEAPF64[$13>>3];
 $92 = $63 * $91;
 $93 = $92;
 $94 = $81 * $90;
 $95 = $81 * $93;
 $96 = $50;
 $97 = $96 * $94;
 $98 = $96 * $95;
 $99 = $96 * $84;
 HEAPF32[$4>>2] = $97;
 $$sroa$469$0$$sroa_idx70 = ((($4)) + 4|0);
 HEAPF32[$$sroa$469$0$$sroa_idx70>>2] = $98;
 $$sroa$572$0$$sroa_idx73 = ((($4)) + 8|0);
 HEAPF32[$$sroa$572$0$$sroa_idx73>>2] = $99;
 $100 = +HEAPF64[$22>>3];
 $101 = $60 * $100;
 $102 = $101;
 $103 = +HEAPF64[$27>>3];
 $104 = $63 * $103;
 $105 = $104;
 $106 = $67 * $102;
 $107 = $67 * $105;
 $108 = $96 * $106;
 $109 = $96 * $107;
 $110 = $96 * $70;
 HEAPF32[$5>>2] = $108;
 $$sroa$456$0$$sroa_idx57 = ((($5)) + 4|0);
 HEAPF32[$$sroa$456$0$$sroa_idx57>>2] = $109;
 $$sroa$5$0$$sroa_idx59 = ((($5)) + 8|0);
 HEAPF32[$$sroa$5$0$$sroa_idx59>>2] = $110;
 return;
}
function __ZN9osgViewer8Keystone28createKeystoneDistortionMeshEv($0) {
 $0 = $0|0;
 var $$063214 = 0, $$064215 = 0, $$083217 = 0, $$11 = 0, $$1176 = 0, $$13 = 0, $$1378 = 0, $$15189 = 0, $$1580187 = 0, $$16 = 0, $$1681 = 0, $$2 = 0, $$267 = 0, $$5 = 0, $$570 = 0, $$7 = 0, $$772 = 0, $$9 = 0, $$974 = 0, $$pre = 0;
 var $$pre$phiZ2D = 0, $$pre218 = 0, $$pre219 = 0, $$pre220 = 0, $$pre221 = 0, $$pre222 = 0, $$pre223 = 0, $$pre224 = 0, $$pre225 = 0, $$pre226 = 0, $$pre227 = 0, $$pre228 = 0, $$sroa$0180$1 = 0, $$sroa$0180$11186 = 0, $$sroa$0180$3 = 0, $$sroa$0180$5 = 0, $$sroa$0180$7 = 0, $$sroa$0180$9 = 0, $1 = 0, $10 = 0;
 var $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0;
 var $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0;
 var $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0;
 var $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0;
 var $173 = 0.0, $174 = 0.0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0;
 var $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0;
 var $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0;
 var $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0;
 var $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0;
 var $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0;
 var $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0;
 var $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0;
 var $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0;
 var $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0;
 var $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0;
 var $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0;
 var $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0;
 var $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0;
 var $425 = 0, $426 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i$i$i115 = 0, $scevgep5$i$i$i$i = 0, $scevgep5$i$i$i$i116 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(80|0);
 $1 = sp + 40|0;
 $2 = sp + 24|0;
 $3 = sp + 16|0;
 $4 = sp + 66|0;
 $5 = sp + 64|0;
 $6 = sp + 62|0;
 $7 = sp + 60|0;
 $8 = sp + 58|0;
 $9 = sp + 56|0;
 $10 = sp;
 $11 = (__Znwj(160)|0);
 __THREW__ = 0;
 invoke_vi(3360,($11|0));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $200 = ___cxa_find_matching_catch_2()|0;
  $201 = tempRet0;
  __ZdlPv($11);
  $$16 = $200;$$1681 = $201;
  ___resumeException($$16|0);
  // unreachable;
 }
 $14 = ((($11)) + 8|0);
 $15 = HEAP32[$14>>2]|0;HEAP32[$14>>2] = (($15+1)|0);
 __THREW__ = 0;
 $16 = (invoke_ii(3276,276)|0);
 $17 = __THREW__; __THREW__ = 0;
 $18 = $17&1;
 do {
  if ($18) {
   $202 = ___cxa_find_matching_catch_2()|0;
   $203 = tempRet0;
   $$15189 = $202;$$1580187 = $203;$$sroa$0180$11186 = $11;
  } else {
   __THREW__ = 0;
   invoke_vi(3485,($16|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if ($20) {
    $204 = ___cxa_find_matching_catch_2()|0;
    $205 = tempRet0;
    __ZdlPv($16);
    $$15189 = $204;$$1580187 = $205;$$sroa$0180$11186 = $11;
    break;
   }
   $21 = ((($16)) + 8|0);
   $22 = HEAP32[$21>>2]|0;HEAP32[$21>>2] = (($22+1)|0);
   $23 = HEAP32[$11>>2]|0;
   $24 = ((($23)) + 240|0);
   $25 = HEAP32[$24>>2]|0;
   __THREW__ = 0;
   (invoke_iii($25|0,($11|0),($16|0))|0);
   $26 = __THREW__; __THREW__ = 0;
   $27 = $26&1;
   L11: do {
    if ($27) {
     label = 41;
    } else {
     __THREW__ = 0;
     invoke_vii(3486,($16|0),0);
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      label = 41;
     } else {
      __THREW__ = 0;
      $30 = (invoke_ii(3276,48)|0);
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if ($32) {
       label = 41;
      } else {
       $33 = ((($30)) + 16|0);
       __THREW__ = 0;
       invoke_vi(3282,($33|0));
       $34 = __THREW__; __THREW__ = 0;
       $35 = $34&1;
       if ($35) {
        $208 = ___cxa_find_matching_catch_2()|0;
        $209 = tempRet0;
        __ZdlPv($30);
        $$13 = $208;$$1378 = $209;$$sroa$0180$9 = $11;
        break;
       }
       $36 = ((($30)) + 28|0);
       ;HEAP32[$36>>2]=0|0;HEAP32[$36+4>>2]=0|0;HEAP32[$36+8>>2]=0|0;
       $37 = ((($30)) + 40|0);
       HEAP32[$37>>2] = 2;
       $38 = ((($30)) + 44|0);
       HEAP32[$38>>2] = 0;
       $39 = ((($30)) + 12|0);
       HEAP32[$39>>2] = 0;
       HEAP32[$30>>2] = (40328);
       $40 = ((($30)) + 8|0);
       HEAP32[$40>>2] = (40484);
       HEAP32[$33>>2] = (40732);
       $41 = ((($30)) + 4|0);
       HEAP32[$41>>2] = $0;
       $42 = ($0|0)==(0|0);
       if ($42) {
        $$pre$phiZ2D = $30;$46 = (40328);
       } else {
        $43 = ((($0)) + 8|0);
        $44 = HEAP32[$43>>2]|0;HEAP32[$43>>2] = (($44+1)|0);
        $$pre = HEAP32[$30>>2]|0;
        $$pre$phiZ2D = $30;$46 = $$pre;
       }
       $45 = ((($46)) + -16|0);
       $47 = HEAP32[$45>>2]|0;
       $48 = (($30) + ($47)|0);
       $49 = ((($48)) + 8|0);
       $50 = HEAP32[$49>>2]|0;HEAP32[$49>>2] = (($50+1)|0);
       $51 = HEAP32[$$pre$phiZ2D>>2]|0;
       $52 = ((($51)) + -12|0);
       $53 = HEAP32[$52>>2]|0;
       $54 = (($30) + ($53)|0);
       __THREW__ = 0;
       invoke_vii(3487,($16|0),($54|0));
       $55 = __THREW__; __THREW__ = 0;
       $56 = $55&1;
       L22: do {
        if ($56) {
         label = 43;
        } else {
         __THREW__ = 0;
         $57 = (invoke_ii(3276,88)|0);
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if ($59) {
          label = 43;
         } else {
          __THREW__ = 0;
          invoke_vii(3435,($57|0),1);
          $60 = __THREW__; __THREW__ = 0;
          $61 = $60&1;
          if ($61) {
           $212 = ___cxa_find_matching_catch_2()|0;
           $213 = tempRet0;
           __ZdlPv($57);
           $$11 = $212;$$1176 = $213;$$sroa$0180$7 = $11;
           break;
          }
          $62 = ((($57)) + 12|0);
          ;HEAP32[$62>>2]=0|0;HEAP32[$62+4>>2]=0|0;HEAP32[$62+8>>2]=0|0;
          $63 = ((($57)) + 24|0);
          HEAP32[$63>>2] = 2;
          $64 = ((($57)) + 28|0);
          ;HEAP32[$64>>2]=0|0;HEAP32[$64+4>>2]=0|0;HEAP32[$64+8>>2]=0|0;HEAP32[$64+12>>2]=0|0;HEAP32[$64+16>>2]=0|0;HEAP32[$64+20>>2]=0|0;
          $65 = ((($57)) + 52|0);
          HEAP32[$65>>2] = 29;
          $66 = ((($57)) + 56|0);
          HEAP32[$66>>2] = 4;
          $67 = ((($57)) + 60|0);
          HEAP32[$67>>2] = 5126;
          $68 = ((($57)) + 64|0);
          HEAP32[$68>>2] = -1;
          $69 = ((($57)) + 68|0);
          HEAP8[$69>>0] = 0;
          $70 = ((($57)) + 69|0);
          HEAP8[$70>>0] = 0;
          $71 = ((($57)) + 72|0);
          $72 = ((($57)) + 76|0);
          HEAP32[$72>>2] = 0;
          $73 = ((($57)) + 80|0);
          HEAP32[$73>>2] = 0;
          $74 = ((($57)) + 84|0);
          HEAP32[$74>>2] = 0;
          HEAP32[$57>>2] = (38280);
          HEAP32[$71>>2] = (38504);
          $75 = ((($57)) + 8|0);
          $76 = HEAP32[$75>>2]|0;HEAP32[$75>>2] = (($76+1)|0);
          HEAPF32[$1>>2] = 1.0;
          $77 = ((($1)) + 4|0);
          HEAPF32[$77>>2] = 1.0;
          $78 = ((($1)) + 8|0);
          HEAPF32[$78>>2] = 1.0;
          $79 = ((($1)) + 12|0);
          HEAPF32[$79>>2] = 1.0;
          $80 = HEAP32[$73>>2]|0;
          $81 = HEAP32[$74>>2]|0;
          $82 = ($80|0)==($81|0);
          if ($82) {
           __THREW__ = 0;
           invoke_vii(3488,($72|0),($1|0));
           $85 = __THREW__; __THREW__ = 0;
           $86 = $85&1;
           if ($86) {
            $216 = ___cxa_find_matching_catch_2()|0;
            $217 = tempRet0;
            $$9 = $216;$$974 = $217;$$sroa$0180$5 = $11;
           } else {
            label = 17;
           }
          } else {
           ;HEAP32[$80>>2]=HEAP32[$1>>2]|0;HEAP32[$80+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$80+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$80+12>>2]=HEAP32[$1+12>>2]|0;
           $83 = HEAP32[$73>>2]|0;
           $84 = ((($83)) + 16|0);
           HEAP32[$73>>2] = $84;
           label = 17;
          }
          L32: do {
           if ((label|0) == 17) {
            __THREW__ = 0;
            invoke_viii(3489,($16|0),($57|0),1);
            $87 = __THREW__; __THREW__ = 0;
            $88 = $87&1;
            if (!($88)) {
             __THREW__ = 0;
             $89 = (invoke_ii(3276,88)|0);
             $90 = __THREW__; __THREW__ = 0;
             $91 = $90&1;
             if (!($91)) {
              __THREW__ = 0;
              invoke_vii(3435,($89|0),1);
              $92 = __THREW__; __THREW__ = 0;
              $93 = $92&1;
              if ($93) {
               $218 = ___cxa_find_matching_catch_2()|0;
               $219 = tempRet0;
               __ZdlPv($89);
               $$9 = $218;$$974 = $219;$$sroa$0180$5 = $11;
               break;
              }
              $94 = ((($89)) + 12|0);
              ;HEAP32[$94>>2]=0|0;HEAP32[$94+4>>2]=0|0;HEAP32[$94+8>>2]=0|0;
              $95 = ((($89)) + 24|0);
              HEAP32[$95>>2] = 2;
              $96 = ((($89)) + 28|0);
              ;HEAP32[$96>>2]=0|0;HEAP32[$96+4>>2]=0|0;HEAP32[$96+8>>2]=0|0;HEAP32[$96+12>>2]=0|0;HEAP32[$96+16>>2]=0|0;HEAP32[$96+20>>2]=0|0;
              $97 = ((($89)) + 52|0);
              HEAP32[$97>>2] = 28;
              $98 = ((($89)) + 56|0);
              HEAP32[$98>>2] = 3;
              $99 = ((($89)) + 60|0);
              HEAP32[$99>>2] = 5126;
              $100 = ((($89)) + 64|0);
              HEAP32[$100>>2] = -1;
              $101 = ((($89)) + 68|0);
              HEAP8[$101>>0] = 0;
              $102 = ((($89)) + 69|0);
              HEAP8[$102>>0] = 0;
              $103 = ((($89)) + 72|0);
              $104 = ((($89)) + 76|0);
              HEAP32[$104>>2] = 0;
              $105 = ((($89)) + 80|0);
              HEAP32[$105>>2] = 0;
              $106 = ((($89)) + 84|0);
              HEAP32[$106>>2] = 0;
              HEAP32[$89>>2] = (37800);
              HEAP32[$103>>2] = (38024);
              $107 = ((($89)) + 8|0);
              $108 = HEAP32[$107>>2]|0;HEAP32[$107>>2] = (($108+1)|0);
              __THREW__ = 0;
              invoke_vii(3490,($16|0),($89|0));
              $109 = __THREW__; __THREW__ = 0;
              $110 = $109&1;
              L40: do {
               if ($110) {
                label = 48;
               } else {
                __THREW__ = 0;
                $111 = (invoke_ii(3276,88)|0);
                $112 = __THREW__; __THREW__ = 0;
                $113 = $112&1;
                if ($113) {
                 label = 48;
                 break;
                }
                __THREW__ = 0;
                invoke_vii(3435,($111|0),1);
                $114 = __THREW__; __THREW__ = 0;
                $115 = $114&1;
                if ($115) {
                 $222 = ___cxa_find_matching_catch_2()|0;
                 $223 = tempRet0;
                 __ZdlPv($111);
                 $$7 = $222;$$772 = $223;$$sroa$0180$3 = $11;
                 break;
                }
                $116 = ((($111)) + 12|0);
                ;HEAP32[$116>>2]=0|0;HEAP32[$116+4>>2]=0|0;HEAP32[$116+8>>2]=0|0;
                $117 = ((($111)) + 24|0);
                HEAP32[$117>>2] = 2;
                $118 = ((($111)) + 28|0);
                ;HEAP32[$118>>2]=0|0;HEAP32[$118+4>>2]=0|0;HEAP32[$118+8>>2]=0|0;HEAP32[$118+12>>2]=0|0;HEAP32[$118+16>>2]=0|0;HEAP32[$118+20>>2]=0|0;
                $119 = ((($111)) + 52|0);
                HEAP32[$119>>2] = 27;
                $120 = ((($111)) + 56|0);
                HEAP32[$120>>2] = 2;
                $121 = ((($111)) + 60|0);
                HEAP32[$121>>2] = 5126;
                $122 = ((($111)) + 64|0);
                HEAP32[$122>>2] = -1;
                $123 = ((($111)) + 68|0);
                HEAP8[$123>>0] = 0;
                $124 = ((($111)) + 69|0);
                HEAP8[$124>>0] = 0;
                $125 = ((($111)) + 72|0);
                $126 = ((($111)) + 76|0);
                HEAP32[$126>>2] = 0;
                $127 = ((($111)) + 80|0);
                HEAP32[$127>>2] = 0;
                $128 = ((($111)) + 84|0);
                HEAP32[$128>>2] = 0;
                HEAP32[$111>>2] = (38040);
                HEAP32[$125>>2] = (38264);
                $129 = ((($111)) + 8|0);
                $130 = HEAP32[$129>>2]|0;HEAP32[$129>>2] = (($130+1)|0);
                __THREW__ = 0;
                invoke_viiii(3491,($16|0),0,($111|0),-1);
                $131 = __THREW__; __THREW__ = 0;
                $132 = $131&1;
                L46: do {
                 if ($132) {
                  $224 = ___cxa_find_matching_catch_2()|0;
                  $225 = tempRet0;
                  $$5 = $224;$$570 = $225;$$sroa$0180$1 = $11;
                 } else {
                  HEAPF32[$2>>2] = 0.0;
                  $133 = ((($2)) + 4|0);
                  HEAPF32[$133>>2] = 0.0;
                  $134 = ((($2)) + 8|0);
                  HEAPF32[$134>>2] = 0.0;
                  $135 = HEAP32[$105>>2]|0;
                  $136 = HEAP32[$104>>2]|0;
                  $137 = (($135) - ($136))|0;
                  $138 = (($137|0) / 12)&-1;
                  $139 = ($138>>>0)<(49);
                  $140 = $136;
                  $141 = $135;
                  do {
                   if ($139) {
                    $142 = (49 - ($138))|0;
                    __THREW__ = 0;
                    invoke_viii(3492,($104|0),($142|0),($2|0));
                    $143 = __THREW__; __THREW__ = 0;
                    $144 = $143&1;
                    if (!($144)) {
                     break;
                    }
                    $228 = ___cxa_find_matching_catch_2()|0;
                    $229 = tempRet0;
                    $$5 = $228;$$570 = $229;$$sroa$0180$1 = $11;
                    break L46;
                   } else {
                    $145 = ($137|0)==(588);
                    if ($145) {
                     break;
                    }
                    $146 = ((($140)) + 588|0);
                    $147 = ($141|0)==($146|0);
                    if ($147) {
                     break;
                    }
                    $scevgep$i$i$i$i = ((($141)) + -12|0);
                    $148 = $scevgep$i$i$i$i;
                    $149 = $146;
                    $150 = (($148) - ($149))|0;
                    $151 = (($150>>>0) / 12)&-1;
                    $152 = $151 ^ -1;
                    $scevgep5$i$i$i$i = (($141) + (($152*12)|0)|0);
                    HEAP32[$105>>2] = $scevgep5$i$i$i$i;
                   }
                  } while(0);
                  HEAPF32[$3>>2] = 0.0;
                  $153 = ((($3)) + 4|0);
                  HEAPF32[$153>>2] = 0.0;
                  $154 = HEAP32[$127>>2]|0;
                  $155 = HEAP32[$126>>2]|0;
                  $156 = (($154) - ($155))|0;
                  $157 = $156 >> 3;
                  $158 = ($157>>>0)<(49);
                  $159 = $155;
                  $160 = $154;
                  do {
                   if ($158) {
                    $161 = (49 - ($157))|0;
                    __THREW__ = 0;
                    invoke_viii(3493,($126|0),($161|0),($3|0));
                    $162 = __THREW__; __THREW__ = 0;
                    $163 = $162&1;
                    if ($163) {
                     $230 = ___cxa_find_matching_catch_2()|0;
                     $231 = tempRet0;
                     $$5 = $230;$$570 = $231;$$sroa$0180$1 = $11;
                     break L46;
                    } else {
                     $$pre218 = HEAP32[$126>>2]|0;
                     $176 = $$pre218;
                     break;
                    }
                   } else {
                    $164 = ($157|0)==(49);
                    if ($164) {
                     $176 = $159;
                     break;
                    }
                    $165 = ((($159)) + 392|0);
                    $166 = ($160|0)==($165|0);
                    if ($166) {
                     $176 = $159;
                     break;
                    }
                    $scevgep$i$i$i$i115 = ((($160)) + -8|0);
                    $167 = $scevgep$i$i$i$i115;
                    $168 = $165;
                    $169 = (($167) - ($168))|0;
                    $170 = $169 >>> 3;
                    $171 = $170 ^ -1;
                    $scevgep5$i$i$i$i116 = (($160) + ($171<<3)|0);
                    HEAP32[$127>>2] = $scevgep5$i$i$i$i116;
                    $176 = $159;
                   }
                  } while(0);
                  $$083217 = 0;
                  while(1) {
                   $172 = ($$083217*7)|0;
                   $173 = (+($$083217>>>0));
                   $174 = $173 / 6.0;
                   $175 = (($176) + ($172<<3)|0);
                   HEAPF32[$175>>2] = 0.0;
                   $177 = (((($176) + ($172<<3)|0)) + 4|0);
                   HEAPF32[$177>>2] = $174;
                   $178 = (($172) + 1)|0;
                   $179 = (($176) + ($178<<3)|0);
                   HEAPF32[$179>>2] = 0.1666666716337204;
                   $180 = (((($176) + ($178<<3)|0)) + 4|0);
                   HEAPF32[$180>>2] = $174;
                   $181 = (($172) + 2)|0;
                   $182 = (($176) + ($181<<3)|0);
                   HEAPF32[$182>>2] = 0.3333333432674408;
                   $183 = (((($176) + ($181<<3)|0)) + 4|0);
                   HEAPF32[$183>>2] = $174;
                   $184 = (($172) + 3)|0;
                   $185 = (($176) + ($184<<3)|0);
                   HEAPF32[$185>>2] = 0.5;
                   $186 = (((($176) + ($184<<3)|0)) + 4|0);
                   HEAPF32[$186>>2] = $174;
                   $187 = (($172) + 4)|0;
                   $188 = (($176) + ($187<<3)|0);
                   HEAPF32[$188>>2] = 0.66666668653488159;
                   $189 = (((($176) + ($187<<3)|0)) + 4|0);
                   HEAPF32[$189>>2] = $174;
                   $190 = (($172) + 5)|0;
                   $191 = (($176) + ($190<<3)|0);
                   HEAPF32[$191>>2] = 0.83333331346511841;
                   $192 = (((($176) + ($190<<3)|0)) + 4|0);
                   HEAPF32[$192>>2] = $174;
                   $193 = (($172) + 6)|0;
                   $194 = (($176) + ($193<<3)|0);
                   HEAPF32[$194>>2] = 1.0;
                   $195 = (((($176) + ($193<<3)|0)) + 4|0);
                   HEAPF32[$195>>2] = $174;
                   $196 = (($$083217) + 1)|0;
                   $exitcond = ($196|0)==(7);
                   if ($exitcond) {
                    break;
                   } else {
                    $$083217 = $196;
                   }
                  }
                  __THREW__ = 0;
                  $197 = (invoke_ii(3276,80)|0);
                  $198 = __THREW__; __THREW__ = 0;
                  $199 = $198&1;
                  if ($199) {
                   $226 = ___cxa_find_matching_catch_2()|0;
                   $227 = tempRet0;
                   $$5 = $226;$$570 = $227;$$sroa$0180$1 = $11;
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vii(3435,($197|0),1);
                  $232 = __THREW__; __THREW__ = 0;
                  $233 = $232&1;
                  if ($233) {
                   $252 = ___cxa_find_matching_catch_2()|0;
                   $253 = tempRet0;
                   __ZdlPv($197);
                   $$5 = $252;$$570 = $253;$$sroa$0180$1 = $11;
                   break;
                  }
                  $234 = ((($197)) + 12|0);
                  ;HEAP32[$234>>2]=0|0;HEAP32[$234+4>>2]=0|0;HEAP32[$234+8>>2]=0|0;
                  $235 = ((($197)) + 24|0);
                  HEAP32[$235>>2] = 2;
                  $236 = ((($197)) + 28|0);
                  ;HEAP32[$236>>2]=0|0;HEAP32[$236+4>>2]=0|0;HEAP32[$236+8>>2]=0|0;HEAP32[$236+12>>2]=0|0;HEAP32[$236+16>>2]=0|0;HEAP32[$236+20>>2]=0|0;
                  $237 = ((($197)) + 52|0);
                  HEAP32[$237>>2] = 4;
                  $238 = ((($197)) + 56|0);
                  HEAP32[$238>>2] = 0;
                  $239 = ((($197)) + 60|0);
                  HEAP32[$239>>2] = 4;
                  $240 = ((($197)) + 64|0);
                  $241 = ((($197)) + 68|0);
                  HEAP32[$241>>2] = 0;
                  $242 = ((($197)) + 72|0);
                  HEAP32[$242>>2] = 0;
                  $243 = ((($197)) + 76|0);
                  HEAP32[$243>>2] = 0;
                  HEAP32[$197>>2] = (64316);
                  HEAP32[$240>>2] = (64564);
                  $244 = ((($197)) + 8|0);
                  $245 = HEAP32[$244>>2]|0;HEAP32[$244>>2] = (($245+1)|0);
                  __THREW__ = 0;
                  (invoke_iii(3494,($16|0),($197|0))|0);
                  $246 = __THREW__; __THREW__ = 0;
                  $247 = $246&1;
                  do {
                   if ($247) {
                    label = 60;
                   } else {
                    $$064215 = 0;
                    L76: while(1) {
                     $248 = ($$064215*7)|0;
                     $$063214 = 0;
                     while(1) {
                      $258 = (($$063214) + ($248))|0;
                      $259 = (($258) + 7)|0;
                      $260 = $259&65535;
                      HEAP16[$4>>1] = $260;
                      $261 = HEAP32[$242>>2]|0;
                      $262 = HEAP32[$243>>2]|0;
                      $263 = ($261|0)==($262|0);
                      if ($263) {
                       __THREW__ = 0;
                       invoke_vii(3495,($241|0),($4|0));
                       $265 = __THREW__; __THREW__ = 0;
                       $266 = $265&1;
                       if ($266) {
                        label = 86;
                        break L76;
                       }
                       $$pre219 = HEAP32[$242>>2]|0;
                       $$pre220 = HEAP32[$243>>2]|0;
                       $268 = $$pre219;$270 = $$pre220;
                      } else {
                       HEAP16[$261>>1] = $260;
                       $264 = ((($261)) + 2|0);
                       HEAP32[$242>>2] = $264;
                       $268 = $264;$270 = $262;
                      }
                      $267 = $258&65535;
                      HEAP16[$5>>1] = $267;
                      $269 = ($268|0)==($270|0);
                      if ($269) {
                       __THREW__ = 0;
                       invoke_vii(3495,($241|0),($5|0));
                       $272 = __THREW__; __THREW__ = 0;
                       $273 = $272&1;
                       if ($273) {
                        label = 87;
                        break L76;
                       }
                       $$pre221 = HEAP32[$242>>2]|0;
                       $$pre222 = HEAP32[$243>>2]|0;
                       $276 = $$pre221;$278 = $$pre222;
                      } else {
                       HEAP16[$268>>1] = $267;
                       $271 = ((($268)) + 2|0);
                       HEAP32[$242>>2] = $271;
                       $276 = $271;$278 = $270;
                      }
                      $274 = (($258) + 1)|0;
                      $275 = $274&65535;
                      HEAP16[$6>>1] = $275;
                      $277 = ($276|0)==($278|0);
                      if ($277) {
                       __THREW__ = 0;
                       invoke_vii(3495,($241|0),($6|0));
                       $280 = __THREW__; __THREW__ = 0;
                       $281 = $280&1;
                       if ($281) {
                        label = 88;
                        break L76;
                       }
                       $$pre223 = HEAP32[$242>>2]|0;
                       $$pre224 = HEAP32[$243>>2]|0;
                       $282 = $$pre223;$284 = $$pre224;
                      } else {
                       HEAP16[$276>>1] = $275;
                       $279 = ((($276)) + 2|0);
                       HEAP32[$242>>2] = $279;
                       $282 = $279;$284 = $278;
                      }
                      HEAP16[$7>>1] = $260;
                      $283 = ($282|0)==($284|0);
                      if ($283) {
                       __THREW__ = 0;
                       invoke_vii(3495,($241|0),($7|0));
                       $286 = __THREW__; __THREW__ = 0;
                       $287 = $286&1;
                       if ($287) {
                        label = 89;
                        break L76;
                       }
                       $$pre225 = HEAP32[$242>>2]|0;
                       $$pre226 = HEAP32[$243>>2]|0;
                       $288 = $$pre225;$290 = $$pre226;
                      } else {
                       HEAP16[$282>>1] = $260;
                       $285 = ((($282)) + 2|0);
                       HEAP32[$242>>2] = $285;
                       $288 = $285;$290 = $284;
                      }
                      HEAP16[$8>>1] = $275;
                      $289 = ($288|0)==($290|0);
                      if ($289) {
                       __THREW__ = 0;
                       invoke_vii(3495,($241|0),($8|0));
                       $292 = __THREW__; __THREW__ = 0;
                       $293 = $292&1;
                       if ($293) {
                        label = 90;
                        break L76;
                       }
                       $$pre227 = HEAP32[$242>>2]|0;
                       $$pre228 = HEAP32[$243>>2]|0;
                       $296 = $$pre227;$298 = $$pre228;
                      } else {
                       HEAP16[$288>>1] = $275;
                       $291 = ((($288)) + 2|0);
                       HEAP32[$242>>2] = $291;
                       $296 = $291;$298 = $290;
                      }
                      $294 = (($258) + 8)|0;
                      $295 = $294&65535;
                      HEAP16[$9>>1] = $295;
                      $297 = ($296|0)==($298|0);
                      if ($297) {
                       __THREW__ = 0;
                       invoke_vii(3495,($241|0),($9|0));
                       $300 = __THREW__; __THREW__ = 0;
                       $301 = $300&1;
                       if ($301) {
                        label = 91;
                        break L76;
                       }
                      } else {
                       HEAP16[$296>>1] = $295;
                       $299 = ((($296)) + 2|0);
                       HEAP32[$242>>2] = $299;
                      }
                      $302 = (($$063214) + 1)|0;
                      $303 = ($302>>>0)<(6);
                      if ($303) {
                       $$063214 = $302;
                      } else {
                       break;
                      }
                     }
                     $256 = (($$064215) + 1)|0;
                     $257 = ($256>>>0)<(6);
                     if ($257) {
                      $$064215 = $256;
                     } else {
                      label = 58;
                      break;
                     }
                    }
                    if ((label|0) == 58) {
                     __THREW__ = 0;
                     $249 = (invoke_ii(3281,($16|0))|0);
                     $250 = __THREW__; __THREW__ = 0;
                     $251 = $250&1;
                     if ($251) {
                      label = 60;
                      break;
                     }
                     __THREW__ = 0;
                     invoke_viii(3365,($249|0),2896,0);
                     $316 = __THREW__; __THREW__ = 0;
                     $317 = $316&1;
                     if ($317) {
                      label = 60;
                      break;
                     }
                     __THREW__ = 0;
                     $318 = (invoke_ii(3281,($16|0))|0);
                     $319 = __THREW__; __THREW__ = 0;
                     $320 = $319&1;
                     if ($320) {
                      label = 60;
                      break;
                     }
                     ;HEAP32[$10>>2]=0|0;HEAP32[$10+4>>2]=0|0;HEAP32[$10+8>>2]=0|0;
                     $321 = ((($10)) + 11|0);
                     HEAP8[$321>>0] = 9;
                     dest=$10; src=116791; stop=dest+9|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                     $322 = ((($10)) + 9|0);
                     HEAP8[$322>>0] = 0;
                     __THREW__ = 0;
                     invoke_viiii(3496,($318|0),0,($10|0),1);
                     $323 = __THREW__; __THREW__ = 0;
                     $324 = $323&1;
                     if ($324) {
                      $346 = ___cxa_find_matching_catch_2()|0;
                      $347 = tempRet0;
                      $348 = HEAP8[$321>>0]|0;
                      $349 = ($348<<24>>24)<(0);
                      if ($349) {
                       $350 = HEAP32[$10>>2]|0;
                       __ZdlPv($350);
                      }
                      $$2 = $346;$$267 = $347;
                      break;
                     }
                     $325 = HEAP8[$321>>0]|0;
                     $326 = ($325<<24>>24)<(0);
                     if ($326) {
                      $327 = HEAP32[$10>>2]|0;
                      __ZdlPv($327);
                     }
                     __THREW__ = 0;
                     $328 = (invoke_ii(3281,($16|0))|0);
                     $329 = __THREW__; __THREW__ = 0;
                     $330 = $329&1;
                     if ($330) {
                      label = 60;
                      break;
                     }
                     __THREW__ = 0;
                     $331 = (invoke_ii(3276,64)|0);
                     $332 = __THREW__; __THREW__ = 0;
                     $333 = $332&1;
                     if ($333) {
                      label = 60;
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3497,($331|0));
                     $334 = __THREW__; __THREW__ = 0;
                     $335 = $334&1;
                     if ($335) {
                      $351 = ___cxa_find_matching_catch_2()|0;
                      $352 = tempRet0;
                      __ZdlPv($331);
                      $$2 = $351;$$267 = $352;
                      break;
                     }
                     __THREW__ = 0;
                     invoke_viii(3357,($328|0),($331|0),5);
                     $336 = __THREW__; __THREW__ = 0;
                     $337 = $336&1;
                     if ($337) {
                      label = 60;
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vii(3498,($30|0),($16|0));
                     $338 = __THREW__; __THREW__ = 0;
                     $339 = $338&1;
                     if ($339) {
                      label = 60;
                      break;
                     }
                     __THREW__ = 0;
                     (invoke_ii(3335,($11|0))|0);
                     $340 = __THREW__; __THREW__ = 0;
                     $341 = $340&1;
                     if ($341) {
                      label = 60;
                      break;
                     }
                     $342 = HEAP32[$244>>2]|0;HEAP32[$244>>2] = (($342-1)|0);
                     $343 = ($342|0)==(1);
                     do {
                      if ($343) {
                       __THREW__ = 0;
                       invoke_viii(3262,($197|0),1,1);
                       $344 = __THREW__; __THREW__ = 0;
                       $345 = $344&1;
                       if (!($345)) {
                        break;
                       }
                       $357 = ___cxa_find_matching_catch_2()|0;
                       $358 = tempRet0;
                       $$5 = $357;$$570 = $358;$$sroa$0180$1 = 0;
                       break L46;
                      }
                     } while(0);
                     $353 = HEAP32[$129>>2]|0;HEAP32[$129>>2] = (($353-1)|0);
                     $354 = ($353|0)==(1);
                     do {
                      if ($354) {
                       __THREW__ = 0;
                       invoke_viii(3262,($111|0),1,1);
                       $355 = __THREW__; __THREW__ = 0;
                       $356 = $355&1;
                       if (!($356)) {
                        break;
                       }
                       $367 = ___cxa_find_matching_catch_2()|0;
                       $368 = tempRet0;
                       $$7 = $367;$$772 = $368;$$sroa$0180$3 = 0;
                       break L40;
                      }
                     } while(0);
                     $363 = HEAP32[$107>>2]|0;HEAP32[$107>>2] = (($363-1)|0);
                     $364 = ($363|0)==(1);
                     do {
                      if ($364) {
                       __THREW__ = 0;
                       invoke_viii(3262,($89|0),1,1);
                       $365 = __THREW__; __THREW__ = 0;
                       $366 = $365&1;
                       if (!($366)) {
                        break;
                       }
                       $377 = ___cxa_find_matching_catch_2()|0;
                       $378 = tempRet0;
                       $$9 = $377;$$974 = $378;$$sroa$0180$5 = 0;
                       break L32;
                      }
                     } while(0);
                     $373 = HEAP32[$75>>2]|0;HEAP32[$75>>2] = (($373-1)|0);
                     $374 = ($373|0)==(1);
                     do {
                      if ($374) {
                       __THREW__ = 0;
                       invoke_viii(3262,($57|0),1,1);
                       $375 = __THREW__; __THREW__ = 0;
                       $376 = $375&1;
                       if (!($376)) {
                        break;
                       }
                       $392 = ___cxa_find_matching_catch_2()|0;
                       $393 = tempRet0;
                       $$11 = $392;$$1176 = $393;$$sroa$0180$7 = 0;
                       break L22;
                      }
                     } while(0);
                     $383 = HEAP32[$$pre$phiZ2D>>2]|0;
                     $384 = ((($383)) + -16|0);
                     $385 = HEAP32[$384>>2]|0;
                     $386 = (($30) + ($385)|0);
                     $387 = ((($386)) + 8|0);
                     $388 = HEAP32[$387>>2]|0;HEAP32[$387>>2] = (($388-1)|0);
                     $389 = ($388|0)==(1);
                     do {
                      if ($389) {
                       __THREW__ = 0;
                       invoke_viii(3262,($386|0),1,1);
                       $390 = __THREW__; __THREW__ = 0;
                       $391 = $390&1;
                       if (!($391)) {
                        break;
                       }
                       $402 = ___cxa_find_matching_catch_2()|0;
                       $403 = tempRet0;
                       $$13 = $402;$$1378 = $403;$$sroa$0180$9 = 0;
                       break L11;
                      }
                     } while(0);
                     $398 = HEAP32[$21>>2]|0;HEAP32[$21>>2] = (($398-1)|0);
                     $399 = ($398|0)==(1);
                     if (!($399)) {
                      STACKTOP = sp;return ($11|0);
                     }
                     __THREW__ = 0;
                     invoke_viii(3262,($16|0),1,1);
                     $400 = __THREW__; __THREW__ = 0;
                     $401 = $400&1;
                     if (!($401)) {
                      STACKTOP = sp;return ($11|0);
                     }
                     $413 = ___cxa_find_matching_catch_2()|0;
                     $414 = tempRet0;
                     $$16 = $413;$$1681 = $414;
                     ___resumeException($$16|0);
                     // unreachable;
                    }
                    else if ((label|0) == 86) {
                     $304 = ___cxa_find_matching_catch_2()|0;
                     $305 = tempRet0;
                     $$2 = $304;$$267 = $305;
                     break;
                    }
                    else if ((label|0) == 87) {
                     $306 = ___cxa_find_matching_catch_2()|0;
                     $307 = tempRet0;
                     $$2 = $306;$$267 = $307;
                     break;
                    }
                    else if ((label|0) == 88) {
                     $308 = ___cxa_find_matching_catch_2()|0;
                     $309 = tempRet0;
                     $$2 = $308;$$267 = $309;
                     break;
                    }
                    else if ((label|0) == 89) {
                     $310 = ___cxa_find_matching_catch_2()|0;
                     $311 = tempRet0;
                     $$2 = $310;$$267 = $311;
                     break;
                    }
                    else if ((label|0) == 90) {
                     $312 = ___cxa_find_matching_catch_2()|0;
                     $313 = tempRet0;
                     $$2 = $312;$$267 = $313;
                     break;
                    }
                    else if ((label|0) == 91) {
                     $314 = ___cxa_find_matching_catch_2()|0;
                     $315 = tempRet0;
                     $$2 = $314;$$267 = $315;
                     break;
                    }
                   }
                  } while(0);
                  if ((label|0) == 60) {
                   $254 = ___cxa_find_matching_catch_2()|0;
                   $255 = tempRet0;
                   $$2 = $254;$$267 = $255;
                  }
                  $359 = HEAP32[$244>>2]|0;HEAP32[$244>>2] = (($359-1)|0);
                  $360 = ($359|0)==(1);
                  if (!($360)) {
                   $$5 = $$2;$$570 = $$267;$$sroa$0180$1 = $11;
                   break;
                  }
                  __THREW__ = 0;
                  invoke_viii(3262,($197|0),1,1);
                  $361 = __THREW__; __THREW__ = 0;
                  $362 = $361&1;
                  if (!($362)) {
                   $$5 = $$2;$$570 = $$267;$$sroa$0180$1 = $11;
                   break;
                  }
                  $425 = ___cxa_find_matching_catch_3(0|0)|0;
                  $426 = tempRet0;
                  ___clang_call_terminate($425);
                  // unreachable;
                 }
                } while(0);
                $369 = HEAP32[$129>>2]|0;HEAP32[$129>>2] = (($369-1)|0);
                $370 = ($369|0)==(1);
                if (!($370)) {
                 $$7 = $$5;$$772 = $$570;$$sroa$0180$3 = $$sroa$0180$1;
                 break;
                }
                __THREW__ = 0;
                invoke_viii(3262,($111|0),1,1);
                $371 = __THREW__; __THREW__ = 0;
                $372 = $371&1;
                if (!($372)) {
                 $$7 = $$5;$$772 = $$570;$$sroa$0180$3 = $$sroa$0180$1;
                 break;
                }
                $425 = ___cxa_find_matching_catch_3(0|0)|0;
                $426 = tempRet0;
                ___clang_call_terminate($425);
                // unreachable;
               }
              } while(0);
              if ((label|0) == 48) {
               $220 = ___cxa_find_matching_catch_2()|0;
               $221 = tempRet0;
               $$7 = $220;$$772 = $221;$$sroa$0180$3 = $11;
              }
              $379 = HEAP32[$107>>2]|0;HEAP32[$107>>2] = (($379-1)|0);
              $380 = ($379|0)==(1);
              if (!($380)) {
               $$9 = $$7;$$974 = $$772;$$sroa$0180$5 = $$sroa$0180$3;
               break;
              }
              __THREW__ = 0;
              invoke_viii(3262,($89|0),1,1);
              $381 = __THREW__; __THREW__ = 0;
              $382 = $381&1;
              if (!($382)) {
               $$9 = $$7;$$974 = $$772;$$sroa$0180$5 = $$sroa$0180$3;
               break;
              }
              $425 = ___cxa_find_matching_catch_3(0|0)|0;
              $426 = tempRet0;
              ___clang_call_terminate($425);
              // unreachable;
             }
            }
            $214 = ___cxa_find_matching_catch_2()|0;
            $215 = tempRet0;
            $$9 = $214;$$974 = $215;$$sroa$0180$5 = $11;
           }
          } while(0);
          $394 = HEAP32[$75>>2]|0;HEAP32[$75>>2] = (($394-1)|0);
          $395 = ($394|0)==(1);
          if ($395) {
           __THREW__ = 0;
           invoke_viii(3262,($57|0),1,1);
           $396 = __THREW__; __THREW__ = 0;
           $397 = $396&1;
           if ($397) {
            $425 = ___cxa_find_matching_catch_3(0|0)|0;
            $426 = tempRet0;
            ___clang_call_terminate($425);
            // unreachable;
           } else {
            $$11 = $$9;$$1176 = $$974;$$sroa$0180$7 = $$sroa$0180$5;
           }
          } else {
           $$11 = $$9;$$1176 = $$974;$$sroa$0180$7 = $$sroa$0180$5;
          }
         }
        }
       } while(0);
       if ((label|0) == 43) {
        $210 = ___cxa_find_matching_catch_2()|0;
        $211 = tempRet0;
        $$11 = $210;$$1176 = $211;$$sroa$0180$7 = $11;
       }
       $404 = HEAP32[$$pre$phiZ2D>>2]|0;
       $405 = ((($404)) + -16|0);
       $406 = HEAP32[$405>>2]|0;
       $407 = (($30) + ($406)|0);
       $408 = ((($407)) + 8|0);
       $409 = HEAP32[$408>>2]|0;HEAP32[$408>>2] = (($409-1)|0);
       $410 = ($409|0)==(1);
       if ($410) {
        __THREW__ = 0;
        invoke_viii(3262,($407|0),1,1);
        $411 = __THREW__; __THREW__ = 0;
        $412 = $411&1;
        if ($412) {
         $425 = ___cxa_find_matching_catch_3(0|0)|0;
         $426 = tempRet0;
         ___clang_call_terminate($425);
         // unreachable;
        } else {
         $$13 = $$11;$$1378 = $$1176;$$sroa$0180$9 = $$sroa$0180$7;
        }
       } else {
        $$13 = $$11;$$1378 = $$1176;$$sroa$0180$9 = $$sroa$0180$7;
       }
      }
     }
    }
   } while(0);
   if ((label|0) == 41) {
    $206 = ___cxa_find_matching_catch_2()|0;
    $207 = tempRet0;
    $$13 = $206;$$1378 = $207;$$sroa$0180$9 = $11;
   }
   $415 = HEAP32[$21>>2]|0;HEAP32[$21>>2] = (($415-1)|0);
   $416 = ($415|0)==(1);
   if ($416) {
    __THREW__ = 0;
    invoke_viii(3262,($16|0),1,1);
    $417 = __THREW__; __THREW__ = 0;
    $418 = $417&1;
    if ($418) {
     $425 = ___cxa_find_matching_catch_3(0|0)|0;
     $426 = tempRet0;
     ___clang_call_terminate($425);
     // unreachable;
    }
   }
   $419 = ($$sroa$0180$9|0)==(0|0);
   if ($419) {
    $$16 = $$13;$$1681 = $$1378;
    ___resumeException($$16|0);
    // unreachable;
   } else {
    $$15189 = $$13;$$1580187 = $$1378;$$sroa$0180$11186 = $$sroa$0180$9;
   }
  }
 } while(0);
 $420 = ((($$sroa$0180$11186)) + 8|0);
 $421 = HEAP32[$420>>2]|0;HEAP32[$420>>2] = (($421-1)|0);
 $422 = ($421|0)==(1);
 if (!($422)) {
  $$16 = $$15189;$$1681 = $$1580187;
  ___resumeException($$16|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(3262,($$sroa$0180$11186|0),1,1);
 $423 = __THREW__; __THREW__ = 0;
 $424 = $423&1;
 if ($424) {
  $425 = ___cxa_find_matching_catch_3(0|0)|0;
  $426 = tempRet0;
  ___clang_call_terminate($425);
  // unreachable;
 } else {
  $$16 = $$15189;$$1681 = $$1580187;
  ___resumeException($$16|0);
  // unreachable;
 }
 return (0)|0;
}
function __ZN22KeystoneUpdateCallback6updateEPN3osg8GeometryE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$063 = 0, $$in = 0, $$sroa$055$0$$sroa_idx = 0, $$sroa$457$0$$sroa_idx58 = 0, $$sroa$5$0$$sroa_idx60 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0.0, $33 = 0.0, $34 = 0.0, $35 = 0.0, $36 = 0.0, $37 = 0.0, $38 = 0.0, $39 = 0.0, $4 = 0, $40 = 0.0, $41 = 0.0;
 var $42 = 0.0, $43 = 0.0, $44 = 0, $45 = 0, $46 = 0, $47 = 0.0, $48 = 0.0, $49 = 0, $5 = 0, $50 = 0.0, $51 = 0.0, $52 = 0.0, $53 = 0.0, $54 = 0.0, $55 = 0.0, $56 = 0.0, $57 = 0.0, $58 = 0.0, $59 = 0.0, $6 = 0;
 var $60 = 0.0, $61 = 0.0, $62 = 0.0, $63 = 0.0, $64 = 0.0, $65 = 0.0, $66 = 0.0, $67 = 0.0, $68 = 0.0, $69 = 0.0, $7 = 0, $70 = 0.0, $71 = 0.0, $72 = 0.0, $73 = 0.0, $74 = 0.0, $75 = 0.0, $76 = 0.0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $9 = 0, $phitmp = 0, $phitmp31 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $2 = sp + 36|0;
 $3 = sp + 24|0;
 $4 = sp + 12|0;
 $5 = sp;
 $6 = ($1|0)==(0|0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = ((($1)) + 228|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if ($9) {
  STACKTOP = sp;return;
 }
 $10 = (___dynamic_cast($8,23016,5496,0)|0);
 $phitmp = ($10|0)==(0|0);
 if ($phitmp) {
  STACKTOP = sp;return;
 }
 $11 = (__ZN3osg8Geometry16getTexCoordArrayEj($1,0)|0);
 $12 = ($11|0)==(0|0);
 if ($12) {
  STACKTOP = sp;return;
 }
 $13 = (___dynamic_cast($11,23016,5456,0)|0);
 $phitmp31 = ($13|0)==(0|0);
 if ($phitmp31) {
  STACKTOP = sp;return;
 }
 HEAPF32[$2>>2] = 0.0;
 $14 = ((($2)) + 4|0);
 HEAPF32[$14>>2] = 0.0;
 $15 = ((($2)) + 8|0);
 HEAPF32[$15>>2] = 0.0;
 HEAPF32[$3>>2] = 0.0;
 $16 = ((($3)) + 4|0);
 HEAPF32[$16>>2] = 0.0;
 $17 = ((($3)) + 8|0);
 HEAPF32[$17>>2] = 0.0;
 HEAPF32[$4>>2] = 0.0;
 $18 = ((($4)) + 4|0);
 HEAPF32[$18>>2] = 0.0;
 $19 = ((($4)) + 8|0);
 HEAPF32[$19>>2] = 0.0;
 HEAPF32[$5>>2] = 0.0;
 $20 = ((($5)) + 4|0);
 HEAPF32[$20>>2] = 0.0;
 $21 = ((($5)) + 8|0);
 HEAPF32[$21>>2] = 0.0;
 $22 = ((($0)) + 4|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (__ZN3osg15DisplaySettings8instanceEv()|0);
 $25 = HEAP32[$24>>2]|0;
 __ZNK9osgViewer8Keystone18compute3DPositionsEPN3osg15DisplaySettingsERNS1_5Vec3fES5_S5_S5_($23,$25,$2,$3,$4,$5);
 $26 = ((($10)) + 76|0);
 $27 = ((($10)) + 80|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = HEAP32[$26>>2]|0;
 $30 = ($28|0)==($29|0);
 if (!($30)) {
  $31 = ((($13)) + 76|0);
  $32 = +HEAPF32[$5>>2];
  $33 = +HEAPF32[$20>>2];
  $34 = +HEAPF32[$21>>2];
  $35 = +HEAPF32[$4>>2];
  $36 = +HEAPF32[$18>>2];
  $37 = +HEAPF32[$19>>2];
  $38 = +HEAPF32[$2>>2];
  $39 = +HEAPF32[$14>>2];
  $40 = +HEAPF32[$15>>2];
  $41 = +HEAPF32[$3>>2];
  $42 = +HEAPF32[$16>>2];
  $43 = +HEAPF32[$17>>2];
  $$063 = 0;$$in = $29;
  while(1) {
   $44 = $$in;
   $45 = HEAP32[$31>>2]|0;
   $46 = (($45) + ($$063<<3)|0);
   $47 = +HEAPF32[$46>>2];
   $48 = 1.0 - $47;
   $49 = (((($45) + ($$063<<3)|0)) + 4|0);
   $50 = +HEAPF32[$49>>2];
   $51 = 1.0 - $50;
   $52 = $48 * $51;
   $53 = $32 * $52;
   $54 = $33 * $52;
   $55 = $52 * $34;
   $56 = $47 * $51;
   $57 = $56 * $35;
   $58 = $56 * $36;
   $59 = $56 * $37;
   $60 = $53 + $57;
   $61 = $54 + $58;
   $62 = $55 + $59;
   $63 = $48 * $50;
   $64 = $63 * $38;
   $65 = $63 * $39;
   $66 = $63 * $40;
   $67 = $60 + $64;
   $68 = $61 + $65;
   $69 = $62 + $66;
   $70 = $47 * $50;
   $71 = $70 * $41;
   $72 = $70 * $42;
   $73 = $70 * $43;
   $74 = $67 + $71;
   $75 = $68 + $72;
   $76 = $69 + $73;
   $$sroa$055$0$$sroa_idx = (($44) + (($$063*12)|0)|0);
   HEAPF32[$$sroa$055$0$$sroa_idx>>2] = $74;
   $$sroa$457$0$$sroa_idx58 = (((($44) + (($$063*12)|0)|0)) + 4|0);
   HEAPF32[$$sroa$457$0$$sroa_idx58>>2] = $75;
   $$sroa$5$0$$sroa_idx60 = (((($44) + (($$063*12)|0)|0)) + 8|0);
   HEAPF32[$$sroa$5$0$$sroa_idx60>>2] = $76;
   $77 = (($$063) + 1)|0;
   $78 = HEAP32[$27>>2]|0;
   $79 = HEAP32[$26>>2]|0;
   $80 = (($78) - ($79))|0;
   $81 = (($80|0) / 12)&-1;
   $82 = ($77>>>0)<($81>>>0);
   if ($82) {
    $$063 = $77;$$in = $79;
   } else {
    break;
   }
  }
 }
 __ZN3osg4Node10dirtyBoundEv($1);
 STACKTOP = sp;return;
}
function __ZNK22KeystoneUpdateCallback9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(48)|0);
 $2 = ((($1)) + 16|0);
 __THREW__ = 0;
 invoke_vi(3282,($2|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $11 = ___cxa_find_matching_catch_2()|0;
  $12 = tempRet0;
  __ZdlPv($1);
  ___resumeException($11|0);
  // unreachable;
 } else {
  $5 = ((($1)) + 28|0);
  ;HEAP32[$5>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;
  $6 = ((($1)) + 40|0);
  HEAP32[$6>>2] = 2;
  $7 = ((($1)) + 44|0);
  HEAP32[$7>>2] = 0;
  $8 = ((($1)) + 12|0);
  HEAP32[$8>>2] = 0;
  HEAP32[$1>>2] = (40328);
  $9 = ((($1)) + 8|0);
  HEAP32[$9>>2] = (40484);
  HEAP32[$2>>2] = (40732);
  $10 = ((($1)) + 4|0);
  HEAP32[$10>>2] = 0;
  return ($2|0);
 }
 return (0)|0;
}
function __ZNK22KeystoneUpdateCallback5cloneERKN3osg6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(48)|0);
 $3 = ((($2)) + 16|0);
 __THREW__ = 0;
 invoke_vi(3282,($3|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $12 = ___cxa_find_matching_catch_2()|0;
  $13 = tempRet0;
  __ZdlPv($2);
  ___resumeException($12|0);
  // unreachable;
 } else {
  $6 = ((($2)) + 28|0);
  ;HEAP32[$6>>2]=0|0;HEAP32[$6+4>>2]=0|0;HEAP32[$6+8>>2]=0|0;
  $7 = ((($2)) + 40|0);
  HEAP32[$7>>2] = 2;
  $8 = ((($2)) + 44|0);
  HEAP32[$8>>2] = 0;
  $9 = ((($2)) + 12|0);
  HEAP32[$9>>2] = 0;
  HEAP32[$2>>2] = (40328);
  $10 = ((($2)) + 8|0);
  HEAP32[$10>>2] = (40484);
  HEAP32[$3>>2] = (40732);
  $11 = ((($2)) + 4|0);
  HEAP32[$11>>2] = 0;
  return ($3|0);
 }
 return (0)|0;
}
function __ZNK22KeystoneUpdateCallback12isSameKindAsEPKN3osg6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,8064,-1)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK22KeystoneUpdateCallback11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175113|0);
}
function __ZNK22KeystoneUpdateCallback9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (107931|0);
}
function __ZN3osg22DrawableUpdateCallback24asDrawableUpdateCallbackEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ($0|0);
}
function __ZNK3osg22DrawableUpdateCallback24asDrawableUpdateCallbackEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ($0|0);
}
function __ZN22KeystoneUpdateCallback6updateEPN3osg11NodeVisitorEPNS0_8DrawableE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + 140|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_ii[$5 & 8191]($2)|0);
 __ZN22KeystoneUpdateCallback6updateEPN3osg8GeometryE($0,$6);
 return;
}
function __ZN22KeystoneUpdateCallbackD1Ev($0) {
 $0 = $0|0;
 var $$0 = 0, $$02 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = ((40328));
 $1 = ((($0)) + 8|0);
 HEAP32[$1>>2] = ((40484));
 $2 = ((($0)) + 16|0);
 HEAP32[$2>>2] = ((40732));
 $3 = ((($0)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  label = 4;
 } else {
  $6 = ((($4)) + 8|0);
  $7 = HEAP32[$6>>2]|0;HEAP32[$6>>2] = (($7-1)|0);
  $8 = ($7|0)==(1);
  if ($8) {
   __THREW__ = 0;
   invoke_viii(3262,($4|0),1,1);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if ($10) {
    $24 = ___cxa_find_matching_catch_2()|0;
    $25 = tempRet0;
    HEAP32[$1>>2] = ((29984));
    $26 = ((($1)) + 8|0);
    HEAP32[$26>>2] = ((30232));
    $27 = ((($0)) + 12|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = ($28|0)==(0|0);
    if (!($29)) {
     $30 = HEAP32[$28>>2]|0;
     $31 = ((($30)) + -12|0);
     $32 = HEAP32[$31>>2]|0;
     $33 = (($28) + ($32)|0);
     $34 = ((($33)) + 8|0);
     $35 = HEAP32[$34>>2]|0;HEAP32[$34>>2] = (($35-1)|0);
     $36 = ($35|0)==(1);
     if ($36) {
      __THREW__ = 0;
      invoke_viii(3262,($33|0),1,1);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       $43 = ___cxa_find_matching_catch_3(0|0)|0;
       $44 = tempRet0;
       ___clang_call_terminate($43);
       // unreachable;
      }
     }
    }
    HEAP32[$27>>2] = 0;
    $$0 = $25;$$02 = $24;
   } else {
    label = 4;
   }
  } else {
   label = 4;
  }
 }
 do {
  if ((label|0) == 4) {
   HEAP32[$3>>2] = 0;
   HEAP32[$1>>2] = ((29984));
   $11 = ((($1)) + 8|0);
   HEAP32[$11>>2] = ((30232));
   $12 = ((($0)) + 12|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = ($13|0)==(0|0);
   if ($14) {
    HEAP32[$12>>2] = 0;
    __ZN3osg6ObjectD2Ev($2);
    return;
   }
   $15 = HEAP32[$13>>2]|0;
   $16 = ((($15)) + -12|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (($13) + ($17)|0);
   $19 = ((($18)) + 8|0);
   $20 = HEAP32[$19>>2]|0;HEAP32[$19>>2] = (($20-1)|0);
   $21 = ($20|0)==(1);
   if (!($21)) {
    HEAP32[$12>>2] = 0;
    __ZN3osg6ObjectD2Ev($2);
    return;
   }
   __THREW__ = 0;
   invoke_viii(3262,($18|0),1,1);
   $22 = __THREW__; __THREW__ = 0;
   $23 = $22&1;
   if ($23) {
    $39 = ___cxa_find_matching_catch_2()|0;
    $40 = tempRet0;
    $$0 = $40;$$02 = $39;
    break;
   } else {
    HEAP32[$12>>2] = 0;
    __ZN3osg6ObjectD2Ev($2);
    return;
   }
  }
 } while(0);
 __THREW__ = 0;
 invoke_vi(388,($2|0));
 $41 = __THREW__; __THREW__ = 0;
 $42 = $41&1;
 if ($42) {
  $43 = ___cxa_find_matching_catch_3(0|0)|0;
  $44 = tempRet0;
  ___clang_call_terminate($43);
  // unreachable;
 } else {
  ___resumeException($$02|0);
  // unreachable;
 }
}
function __ZN22KeystoneUpdateCallbackD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(609,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZTv0_n16_NK22KeystoneUpdateCallback9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(48)|0);
 $2 = ((($1)) + 16|0);
 __THREW__ = 0;
 invoke_vi(3282,($2|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch_2()|0;
  $6 = tempRet0;
  __ZdlPv($1);
  ___resumeException($5|0);
  // unreachable;
 } else {
  $7 = ((($1)) + 28|0);
  ;HEAP32[$7>>2]=0|0;HEAP32[$7+4>>2]=0|0;HEAP32[$7+8>>2]=0|0;
  $8 = ((($1)) + 40|0);
  HEAP32[$8>>2] = 2;
  $9 = ((($1)) + 44|0);
  HEAP32[$9>>2] = 0;
  $10 = ((($1)) + 12|0);
  HEAP32[$10>>2] = 0;
  HEAP32[$1>>2] = (40328);
  $11 = ((($1)) + 8|0);
  HEAP32[$11>>2] = (40484);
  HEAP32[$2>>2] = (40732);
  $12 = ((($1)) + 4|0);
  HEAP32[$12>>2] = 0;
  return ($2|0);
 }
 return (0)|0;
}
function __ZTv0_n20_NK22KeystoneUpdateCallback5cloneERKN3osg6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(48)|0);
 $3 = ((($2)) + 16|0);
 __THREW__ = 0;
 invoke_vi(3282,($3|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch_2()|0;
  $7 = tempRet0;
  __ZdlPv($2);
  ___resumeException($6|0);
  // unreachable;
 } else {
  $8 = ((($2)) + 28|0);
  ;HEAP32[$8>>2]=0|0;HEAP32[$8+4>>2]=0|0;HEAP32[$8+8>>2]=0|0;
  $9 = ((($2)) + 40|0);
  HEAP32[$9>>2] = 2;
  $10 = ((($2)) + 44|0);
  HEAP32[$10>>2] = 0;
  $11 = ((($2)) + 12|0);
  HEAP32[$11>>2] = 0;
  HEAP32[$2>>2] = (40328);
  $12 = ((($2)) + 8|0);
  HEAP32[$12>>2] = (40484);
  HEAP32[$3>>2] = (40732);
  $13 = ((($2)) + 4|0);
  HEAP32[$13>>2] = 0;
  return ($3|0);
 }
 return (0)|0;
}
function __ZTv0_n24_NK22KeystoneUpdateCallback12isSameKindAsEPKN3osg6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,8064,-1)|0);
 $phitmp$i = ($3|0)!=(0|0);
 $4 = $phitmp$i;
 return ($4|0);
}
function __ZTv0_n28_NK22KeystoneUpdateCallback11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175113|0);
}
function __ZTv0_n32_NK22KeystoneUpdateCallback9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (107931|0);
}
function __ZTv0_n76_N3osg22DrawableUpdateCallback24asDrawableUpdateCallbackEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 return ($4|0);
}
function __ZTv0_n80_NK3osg22DrawableUpdateCallback24asDrawableUpdateCallbackEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -80|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 return ($4|0);
}
function __ZTv0_n112_N22KeystoneUpdateCallbackD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -112|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __ZN22KeystoneUpdateCallbackD1Ev($4);
 return;
}
function __ZTv0_n112_N22KeystoneUpdateCallbackD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -112|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __THREW__ = 0;
 invoke_vi(609,($4|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $7 = ___cxa_find_matching_catch_2()|0;
  $8 = tempRet0;
  __ZdlPv($4);
  ___resumeException($7|0);
  // unreachable;
 } else {
  __ZdlPv($4);
  return;
 }
}
function __ZTv0_n16_N22KeystoneUpdateCallbackD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __ZN22KeystoneUpdateCallbackD1Ev($4);
 return;
}
function __ZTv0_n16_N22KeystoneUpdateCallbackD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __THREW__ = 0;
 invoke_vi(609,($4|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $7 = ___cxa_find_matching_catch_2()|0;
  $8 = tempRet0;
  __ZdlPv($4);
  ___resumeException($7|0);
  // unreachable;
 } else {
  __ZdlPv($4);
  return;
 }
}
function __ZTv0_n20_NK22KeystoneUpdateCallback9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(48)|0);
 $2 = ((($1)) + 16|0);
 __THREW__ = 0;
 invoke_vi(3282,($2|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch_2()|0;
  $6 = tempRet0;
  __ZdlPv($1);
  ___resumeException($5|0);
  // unreachable;
 } else {
  $7 = ((($1)) + 28|0);
  ;HEAP32[$7>>2]=0|0;HEAP32[$7+4>>2]=0|0;HEAP32[$7+8>>2]=0|0;
  $8 = ((($1)) + 40|0);
  HEAP32[$8>>2] = 2;
  $9 = ((($1)) + 44|0);
  HEAP32[$9>>2] = 0;
  $10 = ((($1)) + 12|0);
  HEAP32[$10>>2] = 0;
  HEAP32[$1>>2] = (40328);
  $11 = ((($1)) + 8|0);
  HEAP32[$11>>2] = (40484);
  HEAP32[$2>>2] = (40732);
  $12 = ((($1)) + 4|0);
  HEAP32[$12>>2] = 0;
  return ($2|0);
 }
 return (0)|0;
}
function __ZTv0_n24_NK22KeystoneUpdateCallback5cloneERKN3osg6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(48)|0);
 $3 = ((($2)) + 16|0);
 __THREW__ = 0;
 invoke_vi(3282,($3|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch_2()|0;
  $7 = tempRet0;
  __ZdlPv($2);
  ___resumeException($6|0);
  // unreachable;
 } else {
  $8 = ((($2)) + 28|0);
  ;HEAP32[$8>>2]=0|0;HEAP32[$8+4>>2]=0|0;HEAP32[$8+8>>2]=0|0;
  $9 = ((($2)) + 40|0);
  HEAP32[$9>>2] = 2;
  $10 = ((($2)) + 44|0);
  HEAP32[$10>>2] = 0;
  $11 = ((($2)) + 12|0);
  HEAP32[$11>>2] = 0;
  HEAP32[$2>>2] = (40328);
  $12 = ((($2)) + 8|0);
  HEAP32[$12>>2] = (40484);
  HEAP32[$3>>2] = (40732);
  $13 = ((($2)) + 4|0);
  HEAP32[$13>>2] = 0;
  return ($3|0);
 }
 return (0)|0;
}
function __ZTv0_n28_NK22KeystoneUpdateCallback12isSameKindAsEPKN3osg6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,8064,-1)|0);
 $phitmp$i = ($3|0)!=(0|0);
 $4 = $phitmp$i;
 return ($4|0);
}
function __ZTv0_n32_NK22KeystoneUpdateCallback11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175113|0);
}
function __ZTv0_n36_NK22KeystoneUpdateCallback9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (107931|0);
}
function __ZN9osgViewer8Keystone10createGridEv($0) {
 $0 = $0|0;
 var $$0299 = 0, $$048300 = 0, $$1 = 0, $$12 = 0, $$1261 = 0, $$13 = 0, $$1362 = 0, $$15 = 0, $$150 = 0, $$1564 = 0, $$17 = 0, $$1766 = 0, $$19 = 0, $$1968 = 0, $$21 = 0, $$2170 = 0, $$23289 = 0, $$2372287 = 0, $$24 = 0, $$2473 = 0;
 var $$3 = 0, $$352 = 0, $$7 = 0, $$756 = 0, $$cast = 0, $$pre = 0, $$pre$phiZ2D = 0, $$pre304 = 0, $$pre305 = 0, $$pre307 = 0, $$pre309 = 0, $$pre310 = 0, $$pre311 = 0, $$pre312 = 0, $$pre313 = 0, $$pre314 = 0, $$pre315 = 0, $$pre316 = 0, $$pre317 = 0, $$pre318 = 0;
 var $$pre319 = 0, $$pre320 = 0, $$pre321 = 0, $$pre322 = 0, $$pre323 = 0, $$pre324 = 0, $$pre325 = 0, $$sroa$0280$1 = 0, $$sroa$0280$3 = 0, $$sroa$0280$5 = 0, $$sroa$0280$7 = 0, $$sroa$0280$9286 = 0, $$sroa_raw_idx169 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0;
 var $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0;
 var $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0;
 var $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0.0, $192 = 0.0, $193 = 0.0, $194 = 0.0, $195 = 0;
 var $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0;
 var $213 = 0.0, $214 = 0.0, $215 = 0.0, $216 = 0.0, $217 = 0.0, $218 = 0.0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0;
 var $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0.0, $238 = 0.0, $239 = 0.0, $24 = 0, $240 = 0.0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0;
 var $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0;
 var $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0;
 var $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0;
 var $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0;
 var $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0.0;
 var $34 = 0, $340 = 0.0, $341 = 0.0, $342 = 0.0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0;
 var $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0.0, $366 = 0.0, $367 = 0.0, $368 = 0.0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0;
 var $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0.0, $392 = 0.0, $393 = 0.0;
 var $394 = 0.0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0;
 var $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0.0, $418 = 0.0, $419 = 0.0, $42 = 0, $420 = 0.0, $421 = 0, $422 = 0.0, $423 = 0.0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0;
 var $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0;
 var $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0.0;
 var $466 = 0.0, $467 = 0.0, $468 = 0.0, $469 = 0.0, $47 = 0, $470 = 0.0, $471 = 0.0, $472 = 0.0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0;
 var $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0.0, $494 = 0.0, $495 = 0.0, $496 = 0.0, $497 = 0, $498 = 0.0, $499 = 0.0, $5 = 0, $50 = 0, $500 = 0;
 var $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0;
 var $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0;
 var $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0.0, $544 = 0.0, $545 = 0.0, $546 = 0.0, $547 = 0.0, $548 = 0.0, $549 = 0.0, $55 = 0, $550 = 0.0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0;
 var $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0;
 var $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0;
 var $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0;
 var $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0;
 var $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0;
 var $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0;
 var $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0;
 var $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0;
 var $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0.0, $709 = 0.0, $71 = 0, $710 = 0.0, $711 = 0.0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0;
 var $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0.0, $73 = 0, $730 = 0.0, $731 = 0.0, $732 = 0.0, $733 = 0, $734 = 0, $735 = 0;
 var $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0.0, $751 = 0.0, $752 = 0.0, $753 = 0.0;
 var $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0.0;
 var $772 = 0.0, $773 = 0.0, $774 = 0.0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0;
 var $790 = 0, $791 = 0, $792 = 0.0, $793 = 0.0, $794 = 0.0, $795 = 0.0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0;
 var $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0.0, $814 = 0.0, $815 = 0.0, $816 = 0.0, $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = 0, $825 = 0;
 var $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = 0.0, $834 = 0.0, $835 = 0.0, $836 = 0.0, $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = 0, $841 = 0, $842 = 0, $843 = 0;
 var $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0, $850 = 0, $851 = 0, $852 = 0, $853 = 0, $854 = 0.0, $855 = 0.0, $856 = 0.0, $857 = 0.0, $858 = 0, $859 = 0, $86 = 0, $860 = 0, $861 = 0;
 var $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0, $869 = 0, $87 = 0, $870 = 0, $871 = 0, $872 = 0, $873 = 0, $874 = 0, $875 = 0.0, $876 = 0.0, $877 = 0.0, $878 = 0.0, $879 = 0, $88 = 0;
 var $880 = 0, $881 = 0, $882 = 0, $883 = 0, $884 = 0, $885 = 0, $886 = 0, $887 = 0, $888 = 0, $889 = 0, $89 = 0, $890 = 0, $891 = 0, $892 = 0, $893 = 0, $894 = 0, $895 = 0, $896 = 0.0, $897 = 0.0, $898 = 0.0;
 var $899 = 0.0, $9 = 0, $90 = 0, $900 = 0, $901 = 0, $902 = 0, $903 = 0, $904 = 0, $905 = 0, $906 = 0, $907 = 0, $908 = 0, $909 = 0, $91 = 0, $910 = 0, $911 = 0, $912 = 0, $913 = 0, $914 = 0, $915 = 0;
 var $916 = 0, $917 = 0.0, $918 = 0.0, $919 = 0.0, $92 = 0, $920 = 0.0, $921 = 0, $922 = 0, $923 = 0, $924 = 0, $925 = 0, $926 = 0, $927 = 0, $928 = 0, $929 = 0, $93 = 0, $930 = 0, $931 = 0, $932 = 0, $933 = 0;
 var $934 = 0, $935 = 0, $936 = 0, $937 = 0, $938 = 0.0, $939 = 0.0, $94 = 0, $940 = 0.0, $941 = 0.0, $942 = 0, $943 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $scevgep$i$i$i$i = 0, $scevgep5$i$i$i$i = 0, dest = 0, label = 0;
 var sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(96|0);
 $1 = sp + 64|0;
 $2 = sp + 56|0;
 $3 = sp + 48|0;
 $4 = sp + 40|0;
 $5 = sp + 32|0;
 $6 = sp + 24|0;
 $7 = sp + 16|0;
 $8 = sp + 8|0;
 $9 = sp;
 $10 = sp + 84|0;
 $11 = sp + 72|0;
 $12 = (__Znwj(160)|0);
 __THREW__ = 0;
 invoke_vi(3360,($12|0));
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 if ($14) {
  $292 = ___cxa_find_matching_catch_2()|0;
  $293 = tempRet0;
  __ZdlPv($12);
  $$24 = $292;$$2473 = $293;
  ___resumeException($$24|0);
  // unreachable;
 }
 $15 = ((($12)) + 8|0);
 $16 = HEAP32[$15>>2]|0;HEAP32[$15>>2] = (($16+1)|0);
 __THREW__ = 0;
 $17 = (invoke_ii(3276,276)|0);
 $18 = __THREW__; __THREW__ = 0;
 $19 = $18&1;
 do {
  if ($19) {
   $294 = ___cxa_find_matching_catch_2()|0;
   $295 = tempRet0;
   $$23289 = $294;$$2372287 = $295;$$sroa$0280$9286 = $12;
  } else {
   __THREW__ = 0;
   invoke_vi(3485,($17|0));
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if ($21) {
    $296 = ___cxa_find_matching_catch_2()|0;
    $297 = tempRet0;
    __ZdlPv($17);
    $$23289 = $296;$$2372287 = $297;$$sroa$0280$9286 = $12;
    break;
   }
   $22 = ((($17)) + 8|0);
   $23 = HEAP32[$22>>2]|0;HEAP32[$22>>2] = (($23+1)|0);
   $24 = HEAP32[$12>>2]|0;
   $25 = ((($24)) + 240|0);
   $26 = HEAP32[$25>>2]|0;
   __THREW__ = 0;
   (invoke_iii($26|0,($12|0),($17|0))|0);
   $27 = __THREW__; __THREW__ = 0;
   $28 = $27&1;
   L11: do {
    if ($28) {
     label = 54;
    } else {
     __THREW__ = 0;
     invoke_vii(3486,($17|0),0);
     $29 = __THREW__; __THREW__ = 0;
     $30 = $29&1;
     if ($30) {
      label = 54;
     } else {
      __THREW__ = 0;
      $31 = (invoke_ii(3276,48)|0);
      $32 = __THREW__; __THREW__ = 0;
      $33 = $32&1;
      if ($33) {
       label = 54;
      } else {
       $34 = ((($31)) + 16|0);
       __THREW__ = 0;
       invoke_vi(3282,($34|0));
       $35 = __THREW__; __THREW__ = 0;
       $36 = $35&1;
       if ($36) {
        $300 = ___cxa_find_matching_catch_2()|0;
        $301 = tempRet0;
        __ZdlPv($31);
        $$21 = $300;$$2170 = $301;$$sroa$0280$7 = $12;
        break;
       }
       $37 = ((($31)) + 28|0);
       ;HEAP32[$37>>2]=0|0;HEAP32[$37+4>>2]=0|0;HEAP32[$37+8>>2]=0|0;
       $38 = ((($31)) + 40|0);
       HEAP32[$38>>2] = 2;
       $39 = ((($31)) + 44|0);
       HEAP32[$39>>2] = 0;
       $40 = ((($31)) + 12|0);
       HEAP32[$40>>2] = 0;
       HEAP32[$31>>2] = (40328);
       $41 = ((($31)) + 8|0);
       HEAP32[$41>>2] = (40484);
       HEAP32[$34>>2] = (40732);
       $42 = ((($31)) + 4|0);
       HEAP32[$42>>2] = $0;
       $43 = ($0|0)==(0|0);
       if ($43) {
        $$pre$phiZ2D = $31;$47 = (40328);
       } else {
        $44 = ((($0)) + 8|0);
        $45 = HEAP32[$44>>2]|0;HEAP32[$44>>2] = (($45+1)|0);
        $$pre = HEAP32[$31>>2]|0;
        $$pre$phiZ2D = $31;$47 = $$pre;
       }
       $46 = ((($47)) + -16|0);
       $48 = HEAP32[$46>>2]|0;
       $49 = (($31) + ($48)|0);
       $50 = ((($49)) + 8|0);
       $51 = HEAP32[$50>>2]|0;HEAP32[$50>>2] = (($51+1)|0);
       $52 = HEAP32[$$pre$phiZ2D>>2]|0;
       $53 = ((($52)) + -12|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = (($31) + ($54)|0);
       __THREW__ = 0;
       invoke_vii(3487,($17|0),($55|0));
       $56 = __THREW__; __THREW__ = 0;
       $57 = $56&1;
       L22: do {
        if ($57) {
         label = 56;
        } else {
         __THREW__ = 0;
         $58 = (invoke_ii(3276,48)|0);
         $59 = __THREW__; __THREW__ = 0;
         $60 = $59&1;
         if ($60) {
          label = 56;
         } else {
          $61 = ((($58)) + 16|0);
          __THREW__ = 0;
          invoke_vi(3282,($61|0));
          $62 = __THREW__; __THREW__ = 0;
          $63 = $62&1;
          if ($63) {
           $304 = ___cxa_find_matching_catch_2()|0;
           $305 = tempRet0;
           __ZdlPv($58);
           $$19 = $304;$$1968 = $305;$$sroa$0280$5 = $12;
           break;
          }
          $64 = ((($58)) + 28|0);
          ;HEAP32[$64>>2]=0|0;HEAP32[$64+4>>2]=0|0;HEAP32[$64+8>>2]=0|0;
          $65 = ((($58)) + 40|0);
          HEAP32[$65>>2] = 2;
          $66 = ((($58)) + 44|0);
          HEAP32[$66>>2] = 0;
          $67 = ((($58)) + 12|0);
          HEAP32[$67>>2] = 0;
          HEAP32[$58>>2] = (40888);
          $68 = ((($58)) + 8|0);
          HEAP32[$68>>2] = (41044);
          HEAP32[$61>>2] = (41292);
          $69 = ((($58)) + 4|0);
          HEAP32[$69>>2] = $0;
          if ($43) {
           $73 = (40888);
          } else {
           $70 = ((($0)) + 8|0);
           $71 = HEAP32[$70>>2]|0;HEAP32[$70>>2] = (($71+1)|0);
           $$pre304 = HEAP32[$58>>2]|0;
           $73 = $$pre304;
          }
          $72 = ((($73)) + -12|0);
          $74 = HEAP32[$72>>2]|0;
          $75 = (($58) + ($74)|0);
          $76 = ((($17)) + 100|0);
          $77 = HEAP32[$76>>2]|0;
          $78 = ($77|0)==($75|0);
          if (!($78)) {
           HEAP32[$76>>2] = $75;
           $79 = HEAP32[$75>>2]|0;
           $80 = ((($79)) + -12|0);
           $81 = HEAP32[$80>>2]|0;
           $82 = (($75) + ($81)|0);
           $83 = ((($82)) + 8|0);
           $84 = HEAP32[$83>>2]|0;HEAP32[$83>>2] = (($84+1)|0);
           $85 = ($77|0)==(0|0);
           if (!($85)) {
            $86 = HEAP32[$77>>2]|0;
            $87 = ((($86)) + -12|0);
            $88 = HEAP32[$87>>2]|0;
            $89 = (($77) + ($88)|0);
            $90 = ((($89)) + 8|0);
            $91 = HEAP32[$90>>2]|0;HEAP32[$90>>2] = (($91-1)|0);
            $92 = ($91|0)==(1);
            if ($92) {
             __THREW__ = 0;
             invoke_viii(3262,($89|0),1,1);
             $93 = __THREW__; __THREW__ = 0;
             $94 = $93&1;
             if ($94) {
              label = 56;
              break;
             }
            }
           }
          }
          __THREW__ = 0;
          $95 = (invoke_ii(3276,88)|0);
          $96 = __THREW__; __THREW__ = 0;
          $97 = $96&1;
          if ($97) {
           label = 56;
          } else {
           __THREW__ = 0;
           invoke_vii(3435,($95|0),1);
           $98 = __THREW__; __THREW__ = 0;
           $99 = $98&1;
           if ($99) {
            $306 = ___cxa_find_matching_catch_2()|0;
            $307 = tempRet0;
            __ZdlPv($95);
            $$19 = $306;$$1968 = $307;$$sroa$0280$5 = $12;
            break;
           }
           $100 = ((($95)) + 12|0);
           ;HEAP32[$100>>2]=0|0;HEAP32[$100+4>>2]=0|0;HEAP32[$100+8>>2]=0|0;
           $101 = ((($95)) + 24|0);
           HEAP32[$101>>2] = 2;
           $102 = ((($95)) + 28|0);
           ;HEAP32[$102>>2]=0|0;HEAP32[$102+4>>2]=0|0;HEAP32[$102+8>>2]=0|0;HEAP32[$102+12>>2]=0|0;HEAP32[$102+16>>2]=0|0;HEAP32[$102+20>>2]=0|0;
           $103 = ((($95)) + 52|0);
           HEAP32[$103>>2] = 29;
           $104 = ((($95)) + 56|0);
           HEAP32[$104>>2] = 4;
           $105 = ((($95)) + 60|0);
           HEAP32[$105>>2] = 5126;
           $106 = ((($95)) + 64|0);
           HEAP32[$106>>2] = -1;
           $107 = ((($95)) + 68|0);
           HEAP8[$107>>0] = 0;
           $108 = ((($95)) + 69|0);
           HEAP8[$108>>0] = 0;
           $109 = ((($95)) + 72|0);
           $110 = ((($95)) + 76|0);
           HEAP32[$110>>2] = 0;
           $111 = ((($95)) + 80|0);
           HEAP32[$111>>2] = 0;
           $112 = ((($95)) + 84|0);
           HEAP32[$112>>2] = 0;
           HEAP32[$95>>2] = (38280);
           HEAP32[$109>>2] = (38504);
           $113 = ((($95)) + 8|0);
           $114 = HEAP32[$113>>2]|0;HEAP32[$113>>2] = (($114+1)|0);
           $115 = ((($0)) + 36|0);
           $116 = HEAP32[$111>>2]|0;
           $117 = HEAP32[$112>>2]|0;
           $118 = ($116|0)==($117|0);
           if ($118) {
            __THREW__ = 0;
            invoke_vii(3488,($110|0),($115|0));
            $121 = __THREW__; __THREW__ = 0;
            $122 = $121&1;
            if ($122) {
             label = 59;
            } else {
             label = 25;
            }
           } else {
            ;HEAP32[$116>>2]=HEAP32[$115>>2]|0;HEAP32[$116+4>>2]=HEAP32[$115+4>>2]|0;HEAP32[$116+8>>2]=HEAP32[$115+8>>2]|0;HEAP32[$116+12>>2]=HEAP32[$115+12>>2]|0;
            $119 = HEAP32[$111>>2]|0;
            $120 = ((($119)) + 16|0);
            HEAP32[$111>>2] = $120;
            label = 25;
           }
           L43: do {
            if ((label|0) == 25) {
             __THREW__ = 0;
             invoke_viii(3489,($17|0),($95|0),1);
             $123 = __THREW__; __THREW__ = 0;
             $124 = $123&1;
             if ($124) {
              label = 59;
              break;
             }
             __THREW__ = 0;
             $125 = (invoke_ii(3276,88)|0);
             $126 = __THREW__; __THREW__ = 0;
             $127 = $126&1;
             if ($127) {
              label = 59;
              break;
             }
             __THREW__ = 0;
             invoke_vii(3435,($125|0),1);
             $128 = __THREW__; __THREW__ = 0;
             $129 = $128&1;
             if ($129) {
              $310 = ___cxa_find_matching_catch_2()|0;
              $311 = tempRet0;
              __ZdlPv($125);
              $$17 = $310;$$1766 = $311;$$sroa$0280$3 = $12;
              break;
             }
             $130 = ((($125)) + 12|0);
             ;HEAP32[$130>>2]=0|0;HEAP32[$130+4>>2]=0|0;HEAP32[$130+8>>2]=0|0;
             $131 = ((($125)) + 24|0);
             HEAP32[$131>>2] = 2;
             $132 = ((($125)) + 28|0);
             ;HEAP32[$132>>2]=0|0;HEAP32[$132+4>>2]=0|0;HEAP32[$132+8>>2]=0|0;HEAP32[$132+12>>2]=0|0;HEAP32[$132+16>>2]=0|0;HEAP32[$132+20>>2]=0|0;
             $133 = ((($125)) + 52|0);
             HEAP32[$133>>2] = 28;
             $134 = ((($125)) + 56|0);
             HEAP32[$134>>2] = 3;
             $135 = ((($125)) + 60|0);
             HEAP32[$135>>2] = 5126;
             $136 = ((($125)) + 64|0);
             HEAP32[$136>>2] = -1;
             $137 = ((($125)) + 68|0);
             HEAP8[$137>>0] = 0;
             $138 = ((($125)) + 69|0);
             HEAP8[$138>>0] = 0;
             $139 = ((($125)) + 72|0);
             $140 = ((($125)) + 76|0);
             HEAP32[$140>>2] = 0;
             $141 = ((($125)) + 80|0);
             HEAP32[$141>>2] = 0;
             $142 = ((($125)) + 84|0);
             HEAP32[$142>>2] = 0;
             HEAP32[$125>>2] = (37800);
             HEAP32[$139>>2] = (38024);
             $143 = ((($125)) + 8|0);
             $144 = HEAP32[$143>>2]|0;HEAP32[$143>>2] = (($144+1)|0);
             __THREW__ = 0;
             invoke_vii(3490,($17|0),($125|0));
             $145 = __THREW__; __THREW__ = 0;
             $146 = $145&1;
             L50: do {
              if ($146) {
               label = 61;
              } else {
               __THREW__ = 0;
               $147 = (invoke_ii(3276,88)|0);
               $148 = __THREW__; __THREW__ = 0;
               $149 = $148&1;
               if ($149) {
                label = 61;
                break;
               }
               __THREW__ = 0;
               invoke_vii(3435,($147|0),1);
               $150 = __THREW__; __THREW__ = 0;
               $151 = $150&1;
               if ($151) {
                $314 = ___cxa_find_matching_catch_2()|0;
                $315 = tempRet0;
                __ZdlPv($147);
                $$15 = $314;$$1564 = $315;$$sroa$0280$1 = $12;
                break;
               }
               $152 = ((($147)) + 12|0);
               ;HEAP32[$152>>2]=0|0;HEAP32[$152+4>>2]=0|0;HEAP32[$152+8>>2]=0|0;
               $153 = ((($147)) + 24|0);
               HEAP32[$153>>2] = 2;
               $154 = ((($147)) + 28|0);
               ;HEAP32[$154>>2]=0|0;HEAP32[$154+4>>2]=0|0;HEAP32[$154+8>>2]=0|0;HEAP32[$154+12>>2]=0|0;HEAP32[$154+16>>2]=0|0;HEAP32[$154+20>>2]=0|0;
               $155 = ((($147)) + 52|0);
               HEAP32[$155>>2] = 27;
               $156 = ((($147)) + 56|0);
               HEAP32[$156>>2] = 2;
               $157 = ((($147)) + 60|0);
               HEAP32[$157>>2] = 5126;
               $158 = ((($147)) + 64|0);
               HEAP32[$158>>2] = -1;
               $159 = ((($147)) + 68|0);
               HEAP8[$159>>0] = 0;
               $160 = ((($147)) + 69|0);
               HEAP8[$160>>0] = 0;
               $161 = ((($147)) + 72|0);
               $162 = ((($147)) + 76|0);
               HEAP32[$162>>2] = 0;
               $163 = ((($147)) + 80|0);
               HEAP32[$163>>2] = 0;
               $164 = ((($147)) + 84|0);
               HEAP32[$164>>2] = 0;
               HEAP32[$147>>2] = (38040);
               HEAP32[$161>>2] = (38264);
               $165 = ((($147)) + 8|0);
               $166 = HEAP32[$165>>2]|0;HEAP32[$165>>2] = (($166+1)|0);
               __THREW__ = 0;
               invoke_viiii(3491,($17|0),0,($147|0),-1);
               $167 = __THREW__; __THREW__ = 0;
               $168 = $167&1;
               if ($168) {
                $316 = ___cxa_find_matching_catch_2()|0;
                $317 = tempRet0;
                $$13 = $316;$$1362 = $317;
               } else {
                HEAPF32[$1>>2] = 0.0;
                $169 = ((($1)) + 4|0);
                HEAPF32[$169>>2] = 0.0;
                $170 = HEAP32[$163>>2]|0;
                $171 = HEAP32[$162>>2]|0;
                $172 = (($170) - ($171))|0;
                $173 = $172 >> 3;
                $$cast = $170;
                $174 = HEAP32[$164>>2]|0;
                $175 = ($$cast|0)==($174|0);
                do {
                 if ($175) {
                  __THREW__ = 0;
                  invoke_vii(3499,($162|0),($1|0));
                  $189 = __THREW__; __THREW__ = 0;
                  $190 = $189&1;
                  if ($190) {
                   label = 65;
                   break;
                  }
                  $$pre305 = HEAP32[$163>>2]|0;
                  $197 = $$pre305;
                  label = 36;
                 } else {
                  $176 = $170;
                  $177 = $1;
                  $178 = $177;
                  $179 = HEAP32[$178>>2]|0;
                  $180 = (($177) + 4)|0;
                  $181 = $180;
                  $182 = HEAP32[$181>>2]|0;
                  $183 = $176;
                  $184 = $183;
                  HEAP32[$184>>2] = $179;
                  $185 = (($183) + 4)|0;
                  $186 = $185;
                  HEAP32[$186>>2] = $182;
                  $187 = HEAP32[$163>>2]|0;
                  $188 = ((($187)) + 8|0);
                  HEAP32[$163>>2] = $188;
                  $197 = $188;
                  label = 36;
                 }
                } while(0);
                L63: do {
                 if ((label|0) == 36) {
                  $191 = +HEAPF32[$1>>2];
                  $192 = $191 + 1.0;
                  $193 = +HEAPF32[$169>>2];
                  $194 = $193 + 0.0;
                  HEAPF32[$2>>2] = $192;
                  $195 = ((($2)) + 4|0);
                  HEAPF32[$195>>2] = $194;
                  $196 = HEAP32[$164>>2]|0;
                  $198 = ($197|0)==($196|0);
                  do {
                   if ($198) {
                    __THREW__ = 0;
                    invoke_vii(3499,($162|0),($2|0));
                    $211 = __THREW__; __THREW__ = 0;
                    $212 = $211&1;
                    if ($212) {
                     $322 = ___cxa_find_matching_catch_2()|0;
                     $323 = tempRet0;
                     $$12 = $322;$$1261 = $323;
                     break L63;
                    } else {
                     $$pre307 = HEAP32[$163>>2]|0;
                     $221 = $$pre307;
                     break;
                    }
                   } else {
                    $199 = $2;
                    $200 = $199;
                    $201 = HEAP32[$200>>2]|0;
                    $202 = (($199) + 4)|0;
                    $203 = $202;
                    $204 = HEAP32[$203>>2]|0;
                    $205 = $197;
                    $206 = $205;
                    HEAP32[$206>>2] = $201;
                    $207 = (($205) + 4)|0;
                    $208 = $207;
                    HEAP32[$208>>2] = $204;
                    $209 = HEAP32[$163>>2]|0;
                    $210 = ((($209)) + 8|0);
                    HEAP32[$163>>2] = $210;
                    $221 = $210;
                   }
                  } while(0);
                  $213 = +HEAPF32[$1>>2];
                  $214 = $213 + 1.0;
                  $215 = +HEAPF32[$169>>2];
                  $216 = $215 + 0.0;
                  $217 = $214 + 0.0;
                  $218 = $216 + 1.0;
                  HEAPF32[$3>>2] = $217;
                  $219 = ((($3)) + 4|0);
                  HEAPF32[$219>>2] = $218;
                  $220 = HEAP32[$164>>2]|0;
                  $222 = ($221|0)==($220|0);
                  do {
                   if ($222) {
                    __THREW__ = 0;
                    invoke_vii(3499,($162|0),($3|0));
                    $235 = __THREW__; __THREW__ = 0;
                    $236 = $235&1;
                    if ($236) {
                     $324 = ___cxa_find_matching_catch_2()|0;
                     $325 = tempRet0;
                     $$12 = $324;$$1261 = $325;
                     break L63;
                    } else {
                     $$pre309 = HEAP32[$163>>2]|0;
                     $243 = $$pre309;
                     break;
                    }
                   } else {
                    $223 = $3;
                    $224 = $223;
                    $225 = HEAP32[$224>>2]|0;
                    $226 = (($223) + 4)|0;
                    $227 = $226;
                    $228 = HEAP32[$227>>2]|0;
                    $229 = $221;
                    $230 = $229;
                    HEAP32[$230>>2] = $225;
                    $231 = (($229) + 4)|0;
                    $232 = $231;
                    HEAP32[$232>>2] = $228;
                    $233 = HEAP32[$163>>2]|0;
                    $234 = ((($233)) + 8|0);
                    HEAP32[$163>>2] = $234;
                    $243 = $234;
                   }
                  } while(0);
                  $237 = +HEAPF32[$1>>2];
                  $238 = $237 + 0.0;
                  $239 = +HEAPF32[$169>>2];
                  $240 = $239 + 1.0;
                  HEAPF32[$4>>2] = $238;
                  $241 = ((($4)) + 4|0);
                  HEAPF32[$241>>2] = $240;
                  $242 = HEAP32[$164>>2]|0;
                  $244 = ($243|0)==($242|0);
                  do {
                   if ($244) {
                    __THREW__ = 0;
                    invoke_vii(3499,($162|0),($4|0));
                    $257 = __THREW__; __THREW__ = 0;
                    $258 = $257&1;
                    if (!($258)) {
                     break;
                    }
                    $326 = ___cxa_find_matching_catch_2()|0;
                    $327 = tempRet0;
                    $$12 = $326;$$1261 = $327;
                    break L63;
                   } else {
                    $245 = $4;
                    $246 = $245;
                    $247 = HEAP32[$246>>2]|0;
                    $248 = (($245) + 4)|0;
                    $249 = $248;
                    $250 = HEAP32[$249>>2]|0;
                    $251 = $243;
                    $252 = $251;
                    HEAP32[$252>>2] = $247;
                    $253 = (($251) + 4)|0;
                    $254 = $253;
                    HEAP32[$254>>2] = $250;
                    $255 = HEAP32[$163>>2]|0;
                    $256 = ((($255)) + 8|0);
                    HEAP32[$163>>2] = $256;
                   }
                  } while(0);
                  __THREW__ = 0;
                  $259 = (invoke_ii(3276,72)|0);
                  $260 = __THREW__; __THREW__ = 0;
                  $261 = $260&1;
                  if ($261) {
                   label = 65;
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vii(3435,($259|0),1);
                  $262 = __THREW__; __THREW__ = 0;
                  $263 = $262&1;
                  if ($263) {
                   $328 = ___cxa_find_matching_catch_2()|0;
                   $329 = tempRet0;
                   __ZdlPv($259);
                   $$12 = $328;$$1261 = $329;
                   break;
                  }
                  $264 = ((($259)) + 12|0);
                  ;HEAP32[$264>>2]=0|0;HEAP32[$264+4>>2]=0|0;HEAP32[$264+8>>2]=0|0;
                  $265 = ((($259)) + 24|0);
                  HEAP32[$265>>2] = 2;
                  $266 = ((($259)) + 28|0);
                  ;HEAP32[$266>>2]=0|0;HEAP32[$266+4>>2]=0|0;HEAP32[$266+8>>2]=0|0;HEAP32[$266+12>>2]=0|0;HEAP32[$266+16>>2]=0|0;HEAP32[$266+20>>2]=0|0;
                  $267 = ((($259)) + 52|0);
                  HEAP32[$267>>2] = 1;
                  $268 = ((($259)) + 56|0);
                  HEAP32[$268>>2] = 0;
                  $269 = ((($259)) + 60|0);
                  HEAP32[$269>>2] = 2;
                  HEAP32[$259>>2] = (64844);
                  $270 = ((($259)) + 64|0);
                  HEAP32[$270>>2] = $173;
                  $271 = ((($259)) + 68|0);
                  HEAP32[$271>>2] = 4;
                  __THREW__ = 0;
                  (invoke_iii(3494,($17|0),($259|0))|0);
                  $272 = __THREW__; __THREW__ = 0;
                  $273 = $272&1;
                  if ($273) {
                   label = 65;
                   break;
                  }
                  $274 = HEAP32[$163>>2]|0;
                  $275 = HEAP32[$162>>2]|0;
                  $276 = (($274) - ($275))|0;
                  $277 = $276 >> 3;
                  $278 = $1;
                  $279 = $278;
                  $280 = HEAP32[$279>>2]|0;
                  $281 = (($278) + 4)|0;
                  $282 = $281;
                  $283 = HEAP32[$282>>2]|0;
                  $284 = $5;
                  $285 = $284;
                  HEAP32[$285>>2] = $280;
                  $286 = (($284) + 4)|0;
                  $287 = $286;
                  HEAP32[$287>>2] = $283;
                  $288 = ((($5)) + 4|0);
                  $289 = $274;
                  $290 = HEAP32[$164>>2]|0;
                  $291 = ($289|0)==($290|0);
                  do {
                   if ($291) {
                    __THREW__ = 0;
                    invoke_vii(3499,($162|0),($5|0));
                    $337 = __THREW__; __THREW__ = 0;
                    $338 = $337&1;
                    if ($338) {
                     label = 74;
                     break;
                    }
                    $$pre310 = HEAP32[$163>>2]|0;
                    $344 = $$pre310;
                    label = 73;
                   } else {
                    $330 = $274;
                    $331 = $330;
                    $332 = $331;
                    HEAP32[$332>>2] = $280;
                    $333 = (($331) + 4)|0;
                    $334 = $333;
                    HEAP32[$334>>2] = $283;
                    $335 = HEAP32[$163>>2]|0;
                    $336 = ((($335)) + 8|0);
                    HEAP32[$163>>2] = $336;
                    $344 = $336;
                    label = 73;
                   }
                  } while(0);
                  L93: do {
                   if ((label|0) == 73) {
                    $339 = +HEAPF32[$5>>2];
                    $340 = $339 + 0.1666666716337204;
                    HEAPF32[$5>>2] = $340;
                    $341 = +HEAPF32[$288>>2];
                    $342 = $341 + 0.1666666716337204;
                    HEAPF32[$288>>2] = $342;
                    $343 = HEAP32[$164>>2]|0;
                    $345 = ($344|0)==($343|0);
                    if ($345) {
                     __THREW__ = 0;
                     invoke_vii(3499,($162|0),($5|0));
                     $831 = __THREW__; __THREW__ = 0;
                     $832 = $831&1;
                     if ($832) {
                      label = 74;
                      break;
                     }
                     $$pre311 = HEAP32[$163>>2]|0;
                     $838 = $$pre311;
                    } else {
                     $819 = $5;
                     $820 = $819;
                     $821 = HEAP32[$820>>2]|0;
                     $822 = (($819) + 4)|0;
                     $823 = $822;
                     $824 = HEAP32[$823>>2]|0;
                     $825 = $344;
                     $826 = $825;
                     HEAP32[$826>>2] = $821;
                     $827 = (($825) + 4)|0;
                     $828 = $827;
                     HEAP32[$828>>2] = $824;
                     $829 = HEAP32[$163>>2]|0;
                     $830 = ((($829)) + 8|0);
                     HEAP32[$163>>2] = $830;
                     $838 = $830;
                    }
                    $833 = +HEAPF32[$5>>2];
                    $834 = $833 + 0.1666666716337204;
                    HEAPF32[$5>>2] = $834;
                    $835 = +HEAPF32[$288>>2];
                    $836 = $835 + 0.1666666716337204;
                    HEAPF32[$288>>2] = $836;
                    $837 = HEAP32[$164>>2]|0;
                    $839 = ($838|0)==($837|0);
                    if ($839) {
                     __THREW__ = 0;
                     invoke_vii(3499,($162|0),($5|0));
                     $852 = __THREW__; __THREW__ = 0;
                     $853 = $852&1;
                     if ($853) {
                      label = 74;
                      break;
                     }
                     $$pre312 = HEAP32[$163>>2]|0;
                     $859 = $$pre312;
                    } else {
                     $840 = $5;
                     $841 = $840;
                     $842 = HEAP32[$841>>2]|0;
                     $843 = (($840) + 4)|0;
                     $844 = $843;
                     $845 = HEAP32[$844>>2]|0;
                     $846 = $838;
                     $847 = $846;
                     HEAP32[$847>>2] = $842;
                     $848 = (($846) + 4)|0;
                     $849 = $848;
                     HEAP32[$849>>2] = $845;
                     $850 = HEAP32[$163>>2]|0;
                     $851 = ((($850)) + 8|0);
                     HEAP32[$163>>2] = $851;
                     $859 = $851;
                    }
                    $854 = +HEAPF32[$5>>2];
                    $855 = $854 + 0.1666666716337204;
                    HEAPF32[$5>>2] = $855;
                    $856 = +HEAPF32[$288>>2];
                    $857 = $856 + 0.1666666716337204;
                    HEAPF32[$288>>2] = $857;
                    $858 = HEAP32[$164>>2]|0;
                    $860 = ($859|0)==($858|0);
                    if ($860) {
                     __THREW__ = 0;
                     invoke_vii(3499,($162|0),($5|0));
                     $873 = __THREW__; __THREW__ = 0;
                     $874 = $873&1;
                     if ($874) {
                      label = 74;
                      break;
                     }
                     $$pre313 = HEAP32[$163>>2]|0;
                     $880 = $$pre313;
                    } else {
                     $861 = $5;
                     $862 = $861;
                     $863 = HEAP32[$862>>2]|0;
                     $864 = (($861) + 4)|0;
                     $865 = $864;
                     $866 = HEAP32[$865>>2]|0;
                     $867 = $859;
                     $868 = $867;
                     HEAP32[$868>>2] = $863;
                     $869 = (($867) + 4)|0;
                     $870 = $869;
                     HEAP32[$870>>2] = $866;
                     $871 = HEAP32[$163>>2]|0;
                     $872 = ((($871)) + 8|0);
                     HEAP32[$163>>2] = $872;
                     $880 = $872;
                    }
                    $875 = +HEAPF32[$5>>2];
                    $876 = $875 + 0.1666666716337204;
                    HEAPF32[$5>>2] = $876;
                    $877 = +HEAPF32[$288>>2];
                    $878 = $877 + 0.1666666716337204;
                    HEAPF32[$288>>2] = $878;
                    $879 = HEAP32[$164>>2]|0;
                    $881 = ($880|0)==($879|0);
                    if ($881) {
                     __THREW__ = 0;
                     invoke_vii(3499,($162|0),($5|0));
                     $894 = __THREW__; __THREW__ = 0;
                     $895 = $894&1;
                     if ($895) {
                      label = 74;
                      break;
                     }
                     $$pre314 = HEAP32[$163>>2]|0;
                     $901 = $$pre314;
                    } else {
                     $882 = $5;
                     $883 = $882;
                     $884 = HEAP32[$883>>2]|0;
                     $885 = (($882) + 4)|0;
                     $886 = $885;
                     $887 = HEAP32[$886>>2]|0;
                     $888 = $880;
                     $889 = $888;
                     HEAP32[$889>>2] = $884;
                     $890 = (($888) + 4)|0;
                     $891 = $890;
                     HEAP32[$891>>2] = $887;
                     $892 = HEAP32[$163>>2]|0;
                     $893 = ((($892)) + 8|0);
                     HEAP32[$163>>2] = $893;
                     $901 = $893;
                    }
                    $896 = +HEAPF32[$5>>2];
                    $897 = $896 + 0.1666666716337204;
                    HEAPF32[$5>>2] = $897;
                    $898 = +HEAPF32[$288>>2];
                    $899 = $898 + 0.1666666716337204;
                    HEAPF32[$288>>2] = $899;
                    $900 = HEAP32[$164>>2]|0;
                    $902 = ($901|0)==($900|0);
                    if ($902) {
                     __THREW__ = 0;
                     invoke_vii(3499,($162|0),($5|0));
                     $915 = __THREW__; __THREW__ = 0;
                     $916 = $915&1;
                     if ($916) {
                      label = 74;
                      break;
                     }
                     $$pre315 = HEAP32[$163>>2]|0;
                     $922 = $$pre315;
                    } else {
                     $903 = $5;
                     $904 = $903;
                     $905 = HEAP32[$904>>2]|0;
                     $906 = (($903) + 4)|0;
                     $907 = $906;
                     $908 = HEAP32[$907>>2]|0;
                     $909 = $901;
                     $910 = $909;
                     HEAP32[$910>>2] = $905;
                     $911 = (($909) + 4)|0;
                     $912 = $911;
                     HEAP32[$912>>2] = $908;
                     $913 = HEAP32[$163>>2]|0;
                     $914 = ((($913)) + 8|0);
                     HEAP32[$163>>2] = $914;
                     $922 = $914;
                    }
                    $917 = +HEAPF32[$5>>2];
                    $918 = $917 + 0.1666666716337204;
                    HEAPF32[$5>>2] = $918;
                    $919 = +HEAPF32[$288>>2];
                    $920 = $919 + 0.1666666716337204;
                    HEAPF32[$288>>2] = $920;
                    $921 = HEAP32[$164>>2]|0;
                    $923 = ($922|0)==($921|0);
                    if ($923) {
                     __THREW__ = 0;
                     invoke_vii(3499,($162|0),($5|0));
                     $936 = __THREW__; __THREW__ = 0;
                     $937 = $936&1;
                     if ($937) {
                      label = 74;
                      break;
                     }
                    } else {
                     $924 = $5;
                     $925 = $924;
                     $926 = HEAP32[$925>>2]|0;
                     $927 = (($924) + 4)|0;
                     $928 = $927;
                     $929 = HEAP32[$928>>2]|0;
                     $930 = $922;
                     $931 = $930;
                     HEAP32[$931>>2] = $926;
                     $932 = (($930) + 4)|0;
                     $933 = $932;
                     HEAP32[$933>>2] = $929;
                     $934 = HEAP32[$163>>2]|0;
                     $935 = ((($934)) + 8|0);
                     HEAP32[$163>>2] = $935;
                    }
                    $938 = +HEAPF32[$5>>2];
                    $939 = $938 + 0.1666666716337204;
                    HEAPF32[$5>>2] = $939;
                    $940 = +HEAPF32[$288>>2];
                    $941 = $940 + 0.1666666716337204;
                    HEAPF32[$288>>2] = $941;
                    __THREW__ = 0;
                    $348 = (invoke_ii(3276,72)|0);
                    $942 = __THREW__; __THREW__ = 0;
                    $943 = $942&1;
                    L124: do {
                     if (!($943)) {
                      __THREW__ = 0;
                      invoke_vii(3435,($348|0),1);
                      $349 = __THREW__; __THREW__ = 0;
                      $350 = $349&1;
                      if ($350) {
                       $374 = ___cxa_find_matching_catch_2()|0;
                       $375 = tempRet0;
                       __ZdlPv($348);
                       $$1 = $374;$$150 = $375;
                       break L93;
                      }
                      $351 = ((($348)) + 12|0);
                      ;HEAP32[$351>>2]=0|0;HEAP32[$351+4>>2]=0|0;HEAP32[$351+8>>2]=0|0;
                      $352 = ((($348)) + 24|0);
                      HEAP32[$352>>2] = 2;
                      $353 = ((($348)) + 28|0);
                      ;HEAP32[$353>>2]=0|0;HEAP32[$353+4>>2]=0|0;HEAP32[$353+8>>2]=0|0;HEAP32[$353+12>>2]=0|0;HEAP32[$353+16>>2]=0|0;HEAP32[$353+20>>2]=0|0;
                      $354 = ((($348)) + 52|0);
                      HEAP32[$354>>2] = 1;
                      $355 = ((($348)) + 56|0);
                      HEAP32[$355>>2] = 0;
                      $356 = ((($348)) + 60|0);
                      HEAP32[$356>>2] = 3;
                      HEAP32[$348>>2] = (64844);
                      $357 = ((($348)) + 64|0);
                      HEAP32[$357>>2] = $277;
                      $358 = ((($348)) + 68|0);
                      HEAP32[$358>>2] = 7;
                      __THREW__ = 0;
                      (invoke_iii(3494,($17|0),($348|0))|0);
                      $359 = __THREW__; __THREW__ = 0;
                      $360 = $359&1;
                      if ($360) {
                       break;
                      }
                      $361 = HEAP32[$163>>2]|0;
                      $362 = HEAP32[$162>>2]|0;
                      $363 = (($361) - ($362))|0;
                      $364 = $363 >> 3;
                      $365 = +HEAPF32[$1>>2];
                      $366 = $365 + 0.0;
                      $367 = +HEAPF32[$169>>2];
                      $368 = $367 + 1.0;
                      HEAPF32[$5>>2] = $366;
                      $$sroa_raw_idx169 = ((($5)) + 4|0);
                      HEAPF32[$$sroa_raw_idx169>>2] = $368;
                      $369 = $361;
                      $370 = HEAP32[$164>>2]|0;
                      $371 = ($369|0)==($370|0);
                      do {
                       if ($371) {
                        __THREW__ = 0;
                        invoke_vii(3499,($162|0),($5|0));
                        $389 = __THREW__; __THREW__ = 0;
                        $390 = $389&1;
                        if ($390) {
                         break;
                        }
                        $$pre316 = HEAP32[$163>>2]|0;
                        $396 = $$pre316;
                        label = 83;
                       } else {
                        $376 = $361;
                        $377 = $5;
                        $378 = $377;
                        $379 = HEAP32[$378>>2]|0;
                        $380 = (($377) + 4)|0;
                        $381 = $380;
                        $382 = HEAP32[$381>>2]|0;
                        $383 = $376;
                        $384 = $383;
                        HEAP32[$384>>2] = $379;
                        $385 = (($383) + 4)|0;
                        $386 = $385;
                        HEAP32[$386>>2] = $382;
                        $387 = HEAP32[$163>>2]|0;
                        $388 = ((($387)) + 8|0);
                        HEAP32[$163>>2] = $388;
                        $396 = $388;
                        label = 83;
                       }
                      } while(0);
                      do {
                       if ((label|0) == 83) {
                        $391 = +HEAPF32[$5>>2];
                        $392 = $391 + 0.1666666716337204;
                        HEAPF32[$5>>2] = $392;
                        $393 = +HEAPF32[$288>>2];
                        $394 = $393 + -0.1666666716337204;
                        HEAPF32[$288>>2] = $394;
                        $395 = HEAP32[$164>>2]|0;
                        $397 = ($396|0)==($395|0);
                        if ($397) {
                         __THREW__ = 0;
                         invoke_vii(3499,($162|0),($5|0));
                         $706 = __THREW__; __THREW__ = 0;
                         $707 = $706&1;
                         if ($707) {
                          break;
                         }
                         $$pre317 = HEAP32[$163>>2]|0;
                         $713 = $$pre317;
                        } else {
                         $694 = $5;
                         $695 = $694;
                         $696 = HEAP32[$695>>2]|0;
                         $697 = (($694) + 4)|0;
                         $698 = $697;
                         $699 = HEAP32[$698>>2]|0;
                         $700 = $396;
                         $701 = $700;
                         HEAP32[$701>>2] = $696;
                         $702 = (($700) + 4)|0;
                         $703 = $702;
                         HEAP32[$703>>2] = $699;
                         $704 = HEAP32[$163>>2]|0;
                         $705 = ((($704)) + 8|0);
                         HEAP32[$163>>2] = $705;
                         $713 = $705;
                        }
                        $708 = +HEAPF32[$5>>2];
                        $709 = $708 + 0.1666666716337204;
                        HEAPF32[$5>>2] = $709;
                        $710 = +HEAPF32[$288>>2];
                        $711 = $710 + -0.1666666716337204;
                        HEAPF32[$288>>2] = $711;
                        $712 = HEAP32[$164>>2]|0;
                        $714 = ($713|0)==($712|0);
                        if ($714) {
                         __THREW__ = 0;
                         invoke_vii(3499,($162|0),($5|0));
                         $727 = __THREW__; __THREW__ = 0;
                         $728 = $727&1;
                         if ($728) {
                          break;
                         }
                         $$pre318 = HEAP32[$163>>2]|0;
                         $734 = $$pre318;
                        } else {
                         $715 = $5;
                         $716 = $715;
                         $717 = HEAP32[$716>>2]|0;
                         $718 = (($715) + 4)|0;
                         $719 = $718;
                         $720 = HEAP32[$719>>2]|0;
                         $721 = $713;
                         $722 = $721;
                         HEAP32[$722>>2] = $717;
                         $723 = (($721) + 4)|0;
                         $724 = $723;
                         HEAP32[$724>>2] = $720;
                         $725 = HEAP32[$163>>2]|0;
                         $726 = ((($725)) + 8|0);
                         HEAP32[$163>>2] = $726;
                         $734 = $726;
                        }
                        $729 = +HEAPF32[$5>>2];
                        $730 = $729 + 0.1666666716337204;
                        HEAPF32[$5>>2] = $730;
                        $731 = +HEAPF32[$288>>2];
                        $732 = $731 + -0.1666666716337204;
                        HEAPF32[$288>>2] = $732;
                        $733 = HEAP32[$164>>2]|0;
                        $735 = ($734|0)==($733|0);
                        if ($735) {
                         __THREW__ = 0;
                         invoke_vii(3499,($162|0),($5|0));
                         $748 = __THREW__; __THREW__ = 0;
                         $749 = $748&1;
                         if ($749) {
                          break;
                         }
                         $$pre319 = HEAP32[$163>>2]|0;
                         $755 = $$pre319;
                        } else {
                         $736 = $5;
                         $737 = $736;
                         $738 = HEAP32[$737>>2]|0;
                         $739 = (($736) + 4)|0;
                         $740 = $739;
                         $741 = HEAP32[$740>>2]|0;
                         $742 = $734;
                         $743 = $742;
                         HEAP32[$743>>2] = $738;
                         $744 = (($742) + 4)|0;
                         $745 = $744;
                         HEAP32[$745>>2] = $741;
                         $746 = HEAP32[$163>>2]|0;
                         $747 = ((($746)) + 8|0);
                         HEAP32[$163>>2] = $747;
                         $755 = $747;
                        }
                        $750 = +HEAPF32[$5>>2];
                        $751 = $750 + 0.1666666716337204;
                        HEAPF32[$5>>2] = $751;
                        $752 = +HEAPF32[$288>>2];
                        $753 = $752 + -0.1666666716337204;
                        HEAPF32[$288>>2] = $753;
                        $754 = HEAP32[$164>>2]|0;
                        $756 = ($755|0)==($754|0);
                        if ($756) {
                         __THREW__ = 0;
                         invoke_vii(3499,($162|0),($5|0));
                         $769 = __THREW__; __THREW__ = 0;
                         $770 = $769&1;
                         if ($770) {
                          break;
                         }
                         $$pre320 = HEAP32[$163>>2]|0;
                         $776 = $$pre320;
                        } else {
                         $757 = $5;
                         $758 = $757;
                         $759 = HEAP32[$758>>2]|0;
                         $760 = (($757) + 4)|0;
                         $761 = $760;
                         $762 = HEAP32[$761>>2]|0;
                         $763 = $755;
                         $764 = $763;
                         HEAP32[$764>>2] = $759;
                         $765 = (($763) + 4)|0;
                         $766 = $765;
                         HEAP32[$766>>2] = $762;
                         $767 = HEAP32[$163>>2]|0;
                         $768 = ((($767)) + 8|0);
                         HEAP32[$163>>2] = $768;
                         $776 = $768;
                        }
                        $771 = +HEAPF32[$5>>2];
                        $772 = $771 + 0.1666666716337204;
                        HEAPF32[$5>>2] = $772;
                        $773 = +HEAPF32[$288>>2];
                        $774 = $773 + -0.1666666716337204;
                        HEAPF32[$288>>2] = $774;
                        $775 = HEAP32[$164>>2]|0;
                        $777 = ($776|0)==($775|0);
                        if ($777) {
                         __THREW__ = 0;
                         invoke_vii(3499,($162|0),($5|0));
                         $790 = __THREW__; __THREW__ = 0;
                         $791 = $790&1;
                         if ($791) {
                          break;
                         }
                         $$pre321 = HEAP32[$163>>2]|0;
                         $797 = $$pre321;
                        } else {
                         $778 = $5;
                         $779 = $778;
                         $780 = HEAP32[$779>>2]|0;
                         $781 = (($778) + 4)|0;
                         $782 = $781;
                         $783 = HEAP32[$782>>2]|0;
                         $784 = $776;
                         $785 = $784;
                         HEAP32[$785>>2] = $780;
                         $786 = (($784) + 4)|0;
                         $787 = $786;
                         HEAP32[$787>>2] = $783;
                         $788 = HEAP32[$163>>2]|0;
                         $789 = ((($788)) + 8|0);
                         HEAP32[$163>>2] = $789;
                         $797 = $789;
                        }
                        $792 = +HEAPF32[$5>>2];
                        $793 = $792 + 0.1666666716337204;
                        HEAPF32[$5>>2] = $793;
                        $794 = +HEAPF32[$288>>2];
                        $795 = $794 + -0.1666666716337204;
                        HEAPF32[$288>>2] = $795;
                        $796 = HEAP32[$164>>2]|0;
                        $798 = ($797|0)==($796|0);
                        if ($798) {
                         __THREW__ = 0;
                         invoke_vii(3499,($162|0),($5|0));
                         $811 = __THREW__; __THREW__ = 0;
                         $812 = $811&1;
                         if ($812) {
                          break;
                         }
                        } else {
                         $799 = $5;
                         $800 = $799;
                         $801 = HEAP32[$800>>2]|0;
                         $802 = (($799) + 4)|0;
                         $803 = $802;
                         $804 = HEAP32[$803>>2]|0;
                         $805 = $797;
                         $806 = $805;
                         HEAP32[$806>>2] = $801;
                         $807 = (($805) + 4)|0;
                         $808 = $807;
                         HEAP32[$808>>2] = $804;
                         $809 = HEAP32[$163>>2]|0;
                         $810 = ((($809)) + 8|0);
                         HEAP32[$163>>2] = $810;
                        }
                        $813 = +HEAPF32[$5>>2];
                        $814 = $813 + 0.1666666716337204;
                        HEAPF32[$5>>2] = $814;
                        $815 = +HEAPF32[$288>>2];
                        $816 = $815 + -0.1666666716337204;
                        HEAPF32[$288>>2] = $816;
                        __THREW__ = 0;
                        $400 = (invoke_ii(3276,72)|0);
                        $817 = __THREW__; __THREW__ = 0;
                        $818 = $817&1;
                        if ($818) {
                         break L124;
                        }
                        __THREW__ = 0;
                        invoke_vii(3435,($400|0),1);
                        $401 = __THREW__; __THREW__ = 0;
                        $402 = $401&1;
                        if ($402) {
                         $429 = ___cxa_find_matching_catch_2()|0;
                         $430 = tempRet0;
                         __ZdlPv($400);
                         $$1 = $429;$$150 = $430;
                         break L93;
                        }
                        $403 = ((($400)) + 12|0);
                        ;HEAP32[$403>>2]=0|0;HEAP32[$403+4>>2]=0|0;HEAP32[$403+8>>2]=0|0;
                        $404 = ((($400)) + 24|0);
                        HEAP32[$404>>2] = 2;
                        $405 = ((($400)) + 28|0);
                        ;HEAP32[$405>>2]=0|0;HEAP32[$405+4>>2]=0|0;HEAP32[$405+8>>2]=0|0;HEAP32[$405+12>>2]=0|0;HEAP32[$405+16>>2]=0|0;HEAP32[$405+20>>2]=0|0;
                        $406 = ((($400)) + 52|0);
                        HEAP32[$406>>2] = 1;
                        $407 = ((($400)) + 56|0);
                        HEAP32[$407>>2] = 0;
                        $408 = ((($400)) + 60|0);
                        HEAP32[$408>>2] = 3;
                        HEAP32[$400>>2] = (64844);
                        $409 = ((($400)) + 64|0);
                        HEAP32[$409>>2] = $364;
                        $410 = ((($400)) + 68|0);
                        HEAP32[$410>>2] = 7;
                        __THREW__ = 0;
                        (invoke_iii(3494,($17|0),($400|0))|0);
                        $411 = __THREW__; __THREW__ = 0;
                        $412 = $411&1;
                        if ($412) {
                         break L124;
                        }
                        $413 = HEAP32[$163>>2]|0;
                        $414 = HEAP32[$162>>2]|0;
                        $415 = (($413) - ($414))|0;
                        $416 = $415 >> 3;
                        $417 = +HEAPF32[$1>>2];
                        $418 = $417 + 0.1666666716337204;
                        $419 = +HEAPF32[$169>>2];
                        $420 = $419 + 0.0;
                        HEAPF32[$6>>2] = $418;
                        $421 = ((($6)) + 4|0);
                        HEAPF32[$421>>2] = $420;
                        $422 = $418 + 0.0;
                        $423 = $420 + 1.0;
                        HEAPF32[$7>>2] = $422;
                        $424 = ((($7)) + 4|0);
                        HEAPF32[$424>>2] = $423;
                        $425 = $413;
                        $$048300 = 0;$432 = $425;
                        while(1) {
                         $431 = HEAP32[$164>>2]|0;
                         $433 = ($432|0)==($431|0);
                         if ($433) {
                          __THREW__ = 0;
                          invoke_vii(3499,($162|0),($6|0));
                          $446 = __THREW__; __THREW__ = 0;
                          $447 = $446&1;
                          if ($447) {
                           label = 100;
                           break;
                          }
                          $$pre323 = HEAP32[$163>>2]|0;
                          $449 = $$pre323;
                         } else {
                          $434 = $6;
                          $435 = $434;
                          $436 = HEAP32[$435>>2]|0;
                          $437 = (($434) + 4)|0;
                          $438 = $437;
                          $439 = HEAP32[$438>>2]|0;
                          $440 = $432;
                          $441 = $440;
                          HEAP32[$441>>2] = $436;
                          $442 = (($440) + 4)|0;
                          $443 = $442;
                          HEAP32[$443>>2] = $439;
                          $444 = HEAP32[$163>>2]|0;
                          $445 = ((($444)) + 8|0);
                          HEAP32[$163>>2] = $445;
                          $449 = $445;
                         }
                         $448 = HEAP32[$164>>2]|0;
                         $450 = ($449|0)==($448|0);
                         if ($450) {
                          __THREW__ = 0;
                          invoke_vii(3499,($162|0),($7|0));
                          $463 = __THREW__; __THREW__ = 0;
                          $464 = $463&1;
                          if ($464) {
                           label = 100;
                           break;
                          }
                         } else {
                          $451 = $7;
                          $452 = $451;
                          $453 = HEAP32[$452>>2]|0;
                          $454 = (($451) + 4)|0;
                          $455 = $454;
                          $456 = HEAP32[$455>>2]|0;
                          $457 = $449;
                          $458 = $457;
                          HEAP32[$458>>2] = $453;
                          $459 = (($457) + 4)|0;
                          $460 = $459;
                          HEAP32[$460>>2] = $456;
                          $461 = HEAP32[$163>>2]|0;
                          $462 = ((($461)) + 8|0);
                          HEAP32[$163>>2] = $462;
                         }
                         $465 = +HEAPF32[$6>>2];
                         $466 = $465 + 0.1666666716337204;
                         HEAPF32[$6>>2] = $466;
                         $467 = +HEAPF32[$421>>2];
                         $468 = $467 + 0.0;
                         HEAPF32[$421>>2] = $468;
                         $469 = +HEAPF32[$7>>2];
                         $470 = $469 + 0.1666666716337204;
                         HEAPF32[$7>>2] = $470;
                         $471 = +HEAPF32[$424>>2];
                         $472 = $471 + 0.0;
                         HEAPF32[$424>>2] = $472;
                         $473 = (($$048300) + 1)|0;
                         $474 = ($473>>>0)<(5);
                         if (!($474)) {
                          label = 88;
                          break;
                         }
                         $$pre322 = HEAP32[$163>>2]|0;
                         $$048300 = $473;$432 = $$pre322;
                        }
                        L182: do {
                         if ((label|0) == 88) {
                          __THREW__ = 0;
                          $426 = (invoke_ii(3276,72)|0);
                          $427 = __THREW__; __THREW__ = 0;
                          $428 = $427&1;
                          do {
                           if (!($428)) {
                            __THREW__ = 0;
                            invoke_vii(3435,($426|0),1);
                            $477 = __THREW__; __THREW__ = 0;
                            $478 = $477&1;
                            if ($478) {
                             $507 = ___cxa_find_matching_catch_2()|0;
                             $508 = tempRet0;
                             __ZdlPv($426);
                             $$3 = $507;$$352 = $508;
                             break L182;
                            }
                            $479 = ((($426)) + 12|0);
                            ;HEAP32[$479>>2]=0|0;HEAP32[$479+4>>2]=0|0;HEAP32[$479+8>>2]=0|0;
                            $480 = ((($426)) + 24|0);
                            HEAP32[$480>>2] = 2;
                            $481 = ((($426)) + 28|0);
                            ;HEAP32[$481>>2]=0|0;HEAP32[$481+4>>2]=0|0;HEAP32[$481+8>>2]=0|0;HEAP32[$481+12>>2]=0|0;HEAP32[$481+16>>2]=0|0;HEAP32[$481+20>>2]=0|0;
                            $482 = ((($426)) + 52|0);
                            HEAP32[$482>>2] = 1;
                            $483 = ((($426)) + 56|0);
                            HEAP32[$483>>2] = 0;
                            $484 = ((($426)) + 60|0);
                            HEAP32[$484>>2] = 1;
                            HEAP32[$426>>2] = (64844);
                            $485 = ((($426)) + 64|0);
                            HEAP32[$485>>2] = $416;
                            $486 = ((($426)) + 68|0);
                            HEAP32[$486>>2] = 10;
                            __THREW__ = 0;
                            (invoke_iii(3494,($17|0),($426|0))|0);
                            $487 = __THREW__; __THREW__ = 0;
                            $488 = $487&1;
                            if ($488) {
                             break;
                            }
                            $489 = HEAP32[$163>>2]|0;
                            $490 = HEAP32[$162>>2]|0;
                            $491 = (($489) - ($490))|0;
                            $492 = $491 >> 3;
                            $493 = +HEAPF32[$1>>2];
                            $494 = $493 + 0.0;
                            $495 = +HEAPF32[$169>>2];
                            $496 = $495 + 0.1666666716337204;
                            HEAPF32[$8>>2] = $494;
                            $497 = ((($8)) + 4|0);
                            HEAPF32[$497>>2] = $496;
                            $498 = $494 + 1.0;
                            $499 = $496 + 0.0;
                            HEAPF32[$9>>2] = $498;
                            $500 = ((($9)) + 4|0);
                            HEAPF32[$500>>2] = $499;
                            $501 = $489;
                            $$0299 = 0;$510 = $501;
                            while(1) {
                             $509 = HEAP32[$164>>2]|0;
                             $511 = ($510|0)==($509|0);
                             if ($511) {
                              __THREW__ = 0;
                              invoke_vii(3499,($162|0),($8|0));
                              $524 = __THREW__; __THREW__ = 0;
                              $525 = $524&1;
                              if ($525) {
                               label = 117;
                               break;
                              }
                              $$pre325 = HEAP32[$163>>2]|0;
                              $527 = $$pre325;
                             } else {
                              $512 = $8;
                              $513 = $512;
                              $514 = HEAP32[$513>>2]|0;
                              $515 = (($512) + 4)|0;
                              $516 = $515;
                              $517 = HEAP32[$516>>2]|0;
                              $518 = $510;
                              $519 = $518;
                              HEAP32[$519>>2] = $514;
                              $520 = (($518) + 4)|0;
                              $521 = $520;
                              HEAP32[$521>>2] = $517;
                              $522 = HEAP32[$163>>2]|0;
                              $523 = ((($522)) + 8|0);
                              HEAP32[$163>>2] = $523;
                              $527 = $523;
                             }
                             $526 = HEAP32[$164>>2]|0;
                             $528 = ($527|0)==($526|0);
                             if ($528) {
                              __THREW__ = 0;
                              invoke_vii(3499,($162|0),($9|0));
                              $541 = __THREW__; __THREW__ = 0;
                              $542 = $541&1;
                              if ($542) {
                               label = 117;
                               break;
                              }
                             } else {
                              $529 = $9;
                              $530 = $529;
                              $531 = HEAP32[$530>>2]|0;
                              $532 = (($529) + 4)|0;
                              $533 = $532;
                              $534 = HEAP32[$533>>2]|0;
                              $535 = $527;
                              $536 = $535;
                              HEAP32[$536>>2] = $531;
                              $537 = (($535) + 4)|0;
                              $538 = $537;
                              HEAP32[$538>>2] = $534;
                              $539 = HEAP32[$163>>2]|0;
                              $540 = ((($539)) + 8|0);
                              HEAP32[$163>>2] = $540;
                             }
                             $543 = +HEAPF32[$8>>2];
                             $544 = $543 + 0.0;
                             HEAPF32[$8>>2] = $544;
                             $545 = +HEAPF32[$497>>2];
                             $546 = $545 + 0.1666666716337204;
                             HEAPF32[$497>>2] = $546;
                             $547 = +HEAPF32[$9>>2];
                             $548 = $547 + 0.0;
                             HEAPF32[$9>>2] = $548;
                             $549 = +HEAPF32[$500>>2];
                             $550 = $549 + 0.1666666716337204;
                             HEAPF32[$500>>2] = $550;
                             $551 = (($$0299) + 1)|0;
                             $552 = ($551>>>0)<(5);
                             if (!($552)) {
                              label = 104;
                              break;
                             }
                             $$pre324 = HEAP32[$163>>2]|0;
                             $$0299 = $551;$510 = $$pre324;
                            }
                            L202: do {
                             if ((label|0) == 104) {
                              __THREW__ = 0;
                              $502 = (invoke_ii(3276,72)|0);
                              $503 = __THREW__; __THREW__ = 0;
                              $504 = $503&1;
                              do {
                               if (!($504)) {
                                __THREW__ = 0;
                                invoke_vii(3435,($502|0),1);
                                $555 = __THREW__; __THREW__ = 0;
                                $556 = $555&1;
                                if ($556) {
                                 $621 = ___cxa_find_matching_catch_2()|0;
                                 $622 = tempRet0;
                                 __ZdlPv($502);
                                 $$7 = $621;$$756 = $622;
                                 break L202;
                                }
                                $557 = ((($502)) + 12|0);
                                ;HEAP32[$557>>2]=0|0;HEAP32[$557+4>>2]=0|0;HEAP32[$557+8>>2]=0|0;
                                $558 = ((($502)) + 24|0);
                                HEAP32[$558>>2] = 2;
                                $559 = ((($502)) + 28|0);
                                ;HEAP32[$559>>2]=0|0;HEAP32[$559+4>>2]=0|0;HEAP32[$559+8>>2]=0|0;HEAP32[$559+12>>2]=0|0;HEAP32[$559+16>>2]=0|0;HEAP32[$559+20>>2]=0|0;
                                $560 = ((($502)) + 52|0);
                                HEAP32[$560>>2] = 1;
                                $561 = ((($502)) + 56|0);
                                HEAP32[$561>>2] = 0;
                                $562 = ((($502)) + 60|0);
                                HEAP32[$562>>2] = 1;
                                HEAP32[$502>>2] = (64844);
                                $563 = ((($502)) + 64|0);
                                HEAP32[$563>>2] = $492;
                                $564 = ((($502)) + 68|0);
                                HEAP32[$564>>2] = 10;
                                __THREW__ = 0;
                                (invoke_iii(3494,($17|0),($502|0))|0);
                                $565 = __THREW__; __THREW__ = 0;
                                $566 = $565&1;
                                if ($566) {
                                 break;
                                }
                                $567 = HEAP32[$163>>2]|0;
                                $568 = HEAP32[$162>>2]|0;
                                $569 = (($567) - ($568))|0;
                                $570 = $569 >> 3;
                                HEAPF32[$10>>2] = 0.0;
                                $571 = ((($10)) + 4|0);
                                HEAPF32[$571>>2] = 0.0;
                                $572 = ((($10)) + 8|0);
                                HEAPF32[$572>>2] = 0.0;
                                $573 = HEAP32[$141>>2]|0;
                                $574 = HEAP32[$140>>2]|0;
                                $575 = (($573) - ($574))|0;
                                $576 = (($575|0) / 12)&-1;
                                $577 = ($570>>>0)>($576>>>0);
                                $578 = $574;
                                $579 = $573;
                                do {
                                 if ($577) {
                                  $580 = (($570) - ($576))|0;
                                  __THREW__ = 0;
                                  invoke_viii(3492,($140|0),($580|0),($10|0));
                                  $581 = __THREW__; __THREW__ = 0;
                                  $582 = $581&1;
                                  if (!($582)) {
                                   break;
                                  }
                                  $623 = ___cxa_find_matching_catch_2()|0;
                                  $624 = tempRet0;
                                  $$12 = $623;$$1261 = $624;
                                  break L63;
                                 } else {
                                  $583 = ($570>>>0)<($576>>>0);
                                  if (!($583)) {
                                   break;
                                  }
                                  $584 = (($578) + (($570*12)|0)|0);
                                  $585 = ($579|0)==($584|0);
                                  if ($585) {
                                   break;
                                  }
                                  $scevgep$i$i$i$i = ((($579)) + -12|0);
                                  $586 = $scevgep$i$i$i$i;
                                  $587 = $584;
                                  $588 = (($586) - ($587))|0;
                                  $589 = (($588>>>0) / 12)&-1;
                                  $590 = $589 ^ -1;
                                  $scevgep5$i$i$i$i = (($579) + (($590*12)|0)|0);
                                  HEAP32[$141>>2] = $scevgep5$i$i$i$i;
                                 }
                                } while(0);
                                __THREW__ = 0;
                                $591 = (invoke_ii(3281,($17|0))|0);
                                $592 = __THREW__; __THREW__ = 0;
                                $593 = $592&1;
                                do {
                                 if (!($593)) {
                                  __THREW__ = 0;
                                  invoke_viii(3365,($591|0),2896,0);
                                  $594 = __THREW__; __THREW__ = 0;
                                  $595 = $594&1;
                                  if ($595) {
                                   break;
                                  }
                                  __THREW__ = 0;
                                  $596 = (invoke_ii(3281,($17|0))|0);
                                  $597 = __THREW__; __THREW__ = 0;
                                  $598 = $597&1;
                                  if ($598) {
                                   break;
                                  }
                                  __THREW__ = 0;
                                  invoke_viii(3365,($596|0),2929,0);
                                  $599 = __THREW__; __THREW__ = 0;
                                  $600 = $599&1;
                                  if ($600) {
                                   break;
                                  }
                                  __THREW__ = 0;
                                  $601 = (invoke_ii(3281,($17|0))|0);
                                  $602 = __THREW__; __THREW__ = 0;
                                  $603 = $602&1;
                                  if ($603) {
                                   break;
                                  }
                                  ;HEAP32[$11>>2]=0|0;HEAP32[$11+4>>2]=0|0;HEAP32[$11+8>>2]=0|0;
                                  $604 = ((($11)) + 11|0);
                                  HEAP8[$604>>0] = 9;
                                  dest=$11; src=116791; stop=dest+9|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                                  $605 = ((($11)) + 9|0);
                                  HEAP8[$605>>0] = 0;
                                  __THREW__ = 0;
                                  invoke_viiii(3496,($601|0),1,($11|0),1);
                                  $606 = __THREW__; __THREW__ = 0;
                                  $607 = $606&1;
                                  if ($607) {
                                   $625 = ___cxa_find_matching_catch_2()|0;
                                   $626 = tempRet0;
                                   $627 = HEAP8[$604>>0]|0;
                                   $628 = ($627<<24>>24)<(0);
                                   if ($628) {
                                    $629 = HEAP32[$11>>2]|0;
                                    __ZdlPv($629);
                                   }
                                   $$12 = $625;$$1261 = $626;
                                   break L63;
                                  }
                                  $608 = HEAP8[$604>>0]|0;
                                  $609 = ($608<<24>>24)<(0);
                                  if ($609) {
                                   $610 = HEAP32[$11>>2]|0;
                                   __ZdlPv($610);
                                  }
                                  __THREW__ = 0;
                                  invoke_vii(3498,($31|0),($17|0));
                                  $611 = __THREW__; __THREW__ = 0;
                                  $612 = $611&1;
                                  if ($612) {
                                   break;
                                  }
                                  __THREW__ = 0;
                                  (invoke_ii(3335,($12|0))|0);
                                  $613 = __THREW__; __THREW__ = 0;
                                  $614 = $613&1;
                                  if ($614) {
                                   break;
                                  }
                                  $615 = HEAP32[$165>>2]|0;HEAP32[$165>>2] = (($615-1)|0);
                                  $616 = ($615|0)==(1);
                                  do {
                                   if ($616) {
                                    __THREW__ = 0;
                                    invoke_viii(3262,($147|0),1,1);
                                    $617 = __THREW__; __THREW__ = 0;
                                    $618 = $617&1;
                                    if (!($618)) {
                                     break;
                                    }
                                    $634 = ___cxa_find_matching_catch_2()|0;
                                    $635 = tempRet0;
                                    $$15 = $634;$$1564 = $635;$$sroa$0280$1 = 0;
                                    break L50;
                                   }
                                  } while(0);
                                  $630 = HEAP32[$143>>2]|0;HEAP32[$143>>2] = (($630-1)|0);
                                  $631 = ($630|0)==(1);
                                  do {
                                   if ($631) {
                                    __THREW__ = 0;
                                    invoke_viii(3262,($125|0),1,1);
                                    $632 = __THREW__; __THREW__ = 0;
                                    $633 = $632&1;
                                    if (!($633)) {
                                     break;
                                    }
                                    $644 = ___cxa_find_matching_catch_2()|0;
                                    $645 = tempRet0;
                                    $$17 = $644;$$1766 = $645;$$sroa$0280$3 = 0;
                                    break L43;
                                   }
                                  } while(0);
                                  $640 = HEAP32[$113>>2]|0;HEAP32[$113>>2] = (($640-1)|0);
                                  $641 = ($640|0)==(1);
                                  do {
                                   if ($641) {
                                    __THREW__ = 0;
                                    invoke_viii(3262,($95|0),1,1);
                                    $642 = __THREW__; __THREW__ = 0;
                                    $643 = $642&1;
                                    if (!($643)) {
                                     break;
                                    }
                                    $659 = ___cxa_find_matching_catch_2()|0;
                                    $660 = tempRet0;
                                    $$19 = $659;$$1968 = $660;$$sroa$0280$5 = 0;
                                    break L22;
                                   }
                                  } while(0);
                                  $650 = HEAP32[$$pre$phiZ2D>>2]|0;
                                  $651 = ((($650)) + -16|0);
                                  $652 = HEAP32[$651>>2]|0;
                                  $653 = (($31) + ($652)|0);
                                  $654 = ((($653)) + 8|0);
                                  $655 = HEAP32[$654>>2]|0;HEAP32[$654>>2] = (($655-1)|0);
                                  $656 = ($655|0)==(1);
                                  do {
                                   if ($656) {
                                    __THREW__ = 0;
                                    invoke_viii(3262,($653|0),1,1);
                                    $657 = __THREW__; __THREW__ = 0;
                                    $658 = $657&1;
                                    if (!($658)) {
                                     break;
                                    }
                                    $669 = ___cxa_find_matching_catch_2()|0;
                                    $670 = tempRet0;
                                    $$21 = $669;$$2170 = $670;$$sroa$0280$7 = 0;
                                    break L11;
                                   }
                                  } while(0);
                                  $665 = HEAP32[$22>>2]|0;HEAP32[$22>>2] = (($665-1)|0);
                                  $666 = ($665|0)==(1);
                                  if (!($666)) {
                                   STACKTOP = sp;return ($12|0);
                                  }
                                  __THREW__ = 0;
                                  invoke_viii(3262,($17|0),1,1);
                                  $667 = __THREW__; __THREW__ = 0;
                                  $668 = $667&1;
                                  if (!($668)) {
                                   STACKTOP = sp;return ($12|0);
                                  }
                                  $680 = ___cxa_find_matching_catch_2()|0;
                                  $681 = tempRet0;
                                  $$24 = $680;$$2473 = $681;
                                  ___resumeException($$24|0);
                                  // unreachable;
                                 }
                                } while(0);
                                $318 = ___cxa_find_matching_catch_2()|0;
                                $319 = tempRet0;
                                $$12 = $318;$$1261 = $319;
                                break L63;
                               }
                              } while(0);
                              $619 = ___cxa_find_matching_catch_2()|0;
                              $620 = tempRet0;
                              $$7 = $619;$$756 = $620;
                             }
                             else if ((label|0) == 117) {
                              $553 = ___cxa_find_matching_catch_2()|0;
                              $554 = tempRet0;
                              $$7 = $553;$$756 = $554;
                             }
                            } while(0);
                            $$12 = $$7;$$1261 = $$756;
                            break L63;
                           }
                          } while(0);
                          $505 = ___cxa_find_matching_catch_2()|0;
                          $506 = tempRet0;
                          $$3 = $505;$$352 = $506;
                         }
                         else if ((label|0) == 100) {
                          $475 = ___cxa_find_matching_catch_2()|0;
                          $476 = tempRet0;
                          $$3 = $475;$$352 = $476;
                         }
                        } while(0);
                        $$12 = $$3;$$1261 = $$352;
                        break L63;
                       }
                      } while(0);
                      $398 = ___cxa_find_matching_catch_2()|0;
                      $399 = tempRet0;
                      $$1 = $398;$$150 = $399;
                      break L93;
                     }
                    } while(0);
                    $372 = ___cxa_find_matching_catch_2()|0;
                    $373 = tempRet0;
                    $$1 = $372;$$150 = $373;
                   }
                  } while(0);
                  if ((label|0) == 74) {
                   $346 = ___cxa_find_matching_catch_2()|0;
                   $347 = tempRet0;
                   $$1 = $346;$$150 = $347;
                  }
                  $$12 = $$1;$$1261 = $$150;
                 }
                } while(0);
                if ((label|0) == 65) {
                 $320 = ___cxa_find_matching_catch_2()|0;
                 $321 = tempRet0;
                 $$12 = $320;$$1261 = $321;
                }
                $$13 = $$12;$$1362 = $$1261;
               }
               $636 = HEAP32[$165>>2]|0;HEAP32[$165>>2] = (($636-1)|0);
               $637 = ($636|0)==(1);
               if (!($637)) {
                $$15 = $$13;$$1564 = $$1362;$$sroa$0280$1 = $12;
                break;
               }
               __THREW__ = 0;
               invoke_viii(3262,($147|0),1,1);
               $638 = __THREW__; __THREW__ = 0;
               $639 = $638&1;
               if (!($639)) {
                $$15 = $$13;$$1564 = $$1362;$$sroa$0280$1 = $12;
                break;
               }
               $692 = ___cxa_find_matching_catch_3(0|0)|0;
               $693 = tempRet0;
               ___clang_call_terminate($692);
               // unreachable;
              }
             } while(0);
             if ((label|0) == 61) {
              $312 = ___cxa_find_matching_catch_2()|0;
              $313 = tempRet0;
              $$15 = $312;$$1564 = $313;$$sroa$0280$1 = $12;
             }
             $646 = HEAP32[$143>>2]|0;HEAP32[$143>>2] = (($646-1)|0);
             $647 = ($646|0)==(1);
             if (!($647)) {
              $$17 = $$15;$$1766 = $$1564;$$sroa$0280$3 = $$sroa$0280$1;
              break;
             }
             __THREW__ = 0;
             invoke_viii(3262,($125|0),1,1);
             $648 = __THREW__; __THREW__ = 0;
             $649 = $648&1;
             if (!($649)) {
              $$17 = $$15;$$1766 = $$1564;$$sroa$0280$3 = $$sroa$0280$1;
              break;
             }
             $692 = ___cxa_find_matching_catch_3(0|0)|0;
             $693 = tempRet0;
             ___clang_call_terminate($692);
             // unreachable;
            }
           } while(0);
           if ((label|0) == 59) {
            $308 = ___cxa_find_matching_catch_2()|0;
            $309 = tempRet0;
            $$17 = $308;$$1766 = $309;$$sroa$0280$3 = $12;
           }
           $661 = HEAP32[$113>>2]|0;HEAP32[$113>>2] = (($661-1)|0);
           $662 = ($661|0)==(1);
           if ($662) {
            __THREW__ = 0;
            invoke_viii(3262,($95|0),1,1);
            $663 = __THREW__; __THREW__ = 0;
            $664 = $663&1;
            if (!($664)) {
             $$19 = $$17;$$1968 = $$1766;$$sroa$0280$5 = $$sroa$0280$3;
             break;
            }
            $692 = ___cxa_find_matching_catch_3(0|0)|0;
            $693 = tempRet0;
            ___clang_call_terminate($692);
            // unreachable;
           } else {
            $$19 = $$17;$$1968 = $$1766;$$sroa$0280$5 = $$sroa$0280$3;
           }
          }
         }
        }
       } while(0);
       if ((label|0) == 56) {
        $302 = ___cxa_find_matching_catch_2()|0;
        $303 = tempRet0;
        $$19 = $302;$$1968 = $303;$$sroa$0280$5 = $12;
       }
       $671 = HEAP32[$$pre$phiZ2D>>2]|0;
       $672 = ((($671)) + -16|0);
       $673 = HEAP32[$672>>2]|0;
       $674 = (($31) + ($673)|0);
       $675 = ((($674)) + 8|0);
       $676 = HEAP32[$675>>2]|0;HEAP32[$675>>2] = (($676-1)|0);
       $677 = ($676|0)==(1);
       if ($677) {
        __THREW__ = 0;
        invoke_viii(3262,($674|0),1,1);
        $678 = __THREW__; __THREW__ = 0;
        $679 = $678&1;
        if ($679) {
         $692 = ___cxa_find_matching_catch_3(0|0)|0;
         $693 = tempRet0;
         ___clang_call_terminate($692);
         // unreachable;
        } else {
         $$21 = $$19;$$2170 = $$1968;$$sroa$0280$7 = $$sroa$0280$5;
        }
       } else {
        $$21 = $$19;$$2170 = $$1968;$$sroa$0280$7 = $$sroa$0280$5;
       }
      }
     }
    }
   } while(0);
   if ((label|0) == 54) {
    $298 = ___cxa_find_matching_catch_2()|0;
    $299 = tempRet0;
    $$21 = $298;$$2170 = $299;$$sroa$0280$7 = $12;
   }
   $682 = HEAP32[$22>>2]|0;HEAP32[$22>>2] = (($682-1)|0);
   $683 = ($682|0)==(1);
   if ($683) {
    __THREW__ = 0;
    invoke_viii(3262,($17|0),1,1);
    $684 = __THREW__; __THREW__ = 0;
    $685 = $684&1;
    if ($685) {
     $692 = ___cxa_find_matching_catch_3(0|0)|0;
     $693 = tempRet0;
     ___clang_call_terminate($692);
     // unreachable;
    }
   }
   $686 = ($$sroa$0280$7|0)==(0|0);
   if ($686) {
    $$24 = $$21;$$2473 = $$2170;
    ___resumeException($$24|0);
    // unreachable;
   } else {
    $$23289 = $$21;$$2372287 = $$2170;$$sroa$0280$9286 = $$sroa$0280$7;
   }
  }
 } while(0);
 $687 = ((($$sroa$0280$9286)) + 8|0);
 $688 = HEAP32[$687>>2]|0;HEAP32[$687>>2] = (($688-1)|0);
 $689 = ($688|0)==(1);
 if (!($689)) {
  $$24 = $$23289;$$2473 = $$2372287;
  ___resumeException($$24|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(3262,($$sroa$0280$9286|0),1,1);
 $690 = __THREW__; __THREW__ = 0;
 $691 = $690&1;
 if ($691) {
  $692 = ___cxa_find_matching_catch_3(0|0)|0;
  $693 = tempRet0;
  ___clang_call_terminate($692);
  // unreachable;
 } else {
  $$24 = $$23289;$$2473 = $$2372287;
  ___resumeException($$24|0);
  // unreachable;
 }
 return (0)|0;
}
function __ZNK20KeystoneCullCallback9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(48)|0);
 $2 = ((($1)) + 16|0);
 __THREW__ = 0;
 invoke_vi(3282,($2|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $11 = ___cxa_find_matching_catch_2()|0;
  $12 = tempRet0;
  __ZdlPv($1);
  ___resumeException($11|0);
  // unreachable;
 } else {
  $5 = ((($1)) + 28|0);
  ;HEAP32[$5>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;
  $6 = ((($1)) + 40|0);
  HEAP32[$6>>2] = 2;
  $7 = ((($1)) + 44|0);
  HEAP32[$7>>2] = 0;
  $8 = ((($1)) + 12|0);
  HEAP32[$8>>2] = 0;
  HEAP32[$1>>2] = (40888);
  $9 = ((($1)) + 8|0);
  HEAP32[$9>>2] = (41044);
  HEAP32[$2>>2] = (41292);
  $10 = ((($1)) + 4|0);
  HEAP32[$10>>2] = 0;
  return ($2|0);
 }
 return (0)|0;
}
function __ZNK20KeystoneCullCallback5cloneERKN3osg6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(48)|0);
 $3 = ((($2)) + 16|0);
 __THREW__ = 0;
 invoke_vi(3282,($3|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $12 = ___cxa_find_matching_catch_2()|0;
  $13 = tempRet0;
  __ZdlPv($2);
  ___resumeException($12|0);
  // unreachable;
 } else {
  $6 = ((($2)) + 28|0);
  ;HEAP32[$6>>2]=0|0;HEAP32[$6+4>>2]=0|0;HEAP32[$6+8>>2]=0|0;
  $7 = ((($2)) + 40|0);
  HEAP32[$7>>2] = 2;
  $8 = ((($2)) + 44|0);
  HEAP32[$8>>2] = 0;
  $9 = ((($2)) + 12|0);
  HEAP32[$9>>2] = 0;
  HEAP32[$2>>2] = (40888);
  $10 = ((($2)) + 8|0);
  HEAP32[$10>>2] = (41044);
  HEAP32[$3>>2] = (41292);
  $11 = ((($2)) + 4|0);
  HEAP32[$11>>2] = 0;
  return ($3|0);
 }
 return (0)|0;
}
function __ZNK20KeystoneCullCallback12isSameKindAsEPKN3osg6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,8080,-1)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK20KeystoneCullCallback11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175113|0);
}
function __ZNK20KeystoneCullCallback9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (107979|0);
}
function __ZN3osg20DrawableCullCallback22asDrawableCullCallbackEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ($0|0);
}
function __ZNK3osg20DrawableCullCallback22asDrawableCullCallbackEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ($0|0);
}
function __ZNK3osg20DrawableCullCallback4cullEPNS_11NodeVisitorEPNS_8DrawableEPNS_5StateE($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function __ZNK20KeystoneCullCallback4cullEPN3osg11NodeVisitorEPNS0_8DrawableEPNS0_10RenderInfoE($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $10 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ((($0)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $10 = 1;
  return ($10|0);
 }
 $7 = ((($5)) + 32|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = ($8<<24>>24)==(0);
 $10 = $9;
 return ($10|0);
}
function __ZN20KeystoneCullCallbackD1Ev($0) {
 $0 = $0|0;
 var $$0 = 0, $$02 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = ((40888));
 $1 = ((($0)) + 8|0);
 HEAP32[$1>>2] = ((41044));
 $2 = ((($0)) + 16|0);
 HEAP32[$2>>2] = ((41292));
 $3 = ((($0)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  label = 4;
 } else {
  $6 = ((($4)) + 8|0);
  $7 = HEAP32[$6>>2]|0;HEAP32[$6>>2] = (($7-1)|0);
  $8 = ($7|0)==(1);
  if ($8) {
   __THREW__ = 0;
   invoke_viii(3262,($4|0),1,1);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if ($10) {
    $24 = ___cxa_find_matching_catch_2()|0;
    $25 = tempRet0;
    HEAP32[$1>>2] = ((29984));
    $26 = ((($1)) + 8|0);
    HEAP32[$26>>2] = ((30232));
    $27 = ((($0)) + 12|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = ($28|0)==(0|0);
    if (!($29)) {
     $30 = HEAP32[$28>>2]|0;
     $31 = ((($30)) + -12|0);
     $32 = HEAP32[$31>>2]|0;
     $33 = (($28) + ($32)|0);
     $34 = ((($33)) + 8|0);
     $35 = HEAP32[$34>>2]|0;HEAP32[$34>>2] = (($35-1)|0);
     $36 = ($35|0)==(1);
     if ($36) {
      __THREW__ = 0;
      invoke_viii(3262,($33|0),1,1);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       $43 = ___cxa_find_matching_catch_3(0|0)|0;
       $44 = tempRet0;
       ___clang_call_terminate($43);
       // unreachable;
      }
     }
    }
    HEAP32[$27>>2] = 0;
    $$0 = $25;$$02 = $24;
   } else {
    label = 4;
   }
  } else {
   label = 4;
  }
 }
 do {
  if ((label|0) == 4) {
   HEAP32[$3>>2] = 0;
   HEAP32[$1>>2] = ((29984));
   $11 = ((($1)) + 8|0);
   HEAP32[$11>>2] = ((30232));
   $12 = ((($0)) + 12|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = ($13|0)==(0|0);
   if ($14) {
    HEAP32[$12>>2] = 0;
    __ZN3osg6ObjectD2Ev($2);
    return;
   }
   $15 = HEAP32[$13>>2]|0;
   $16 = ((($15)) + -12|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (($13) + ($17)|0);
   $19 = ((($18)) + 8|0);
   $20 = HEAP32[$19>>2]|0;HEAP32[$19>>2] = (($20-1)|0);
   $21 = ($20|0)==(1);
   if (!($21)) {
    HEAP32[$12>>2] = 0;
    __ZN3osg6ObjectD2Ev($2);
    return;
   }
   __THREW__ = 0;
   invoke_viii(3262,($18|0),1,1);
   $22 = __THREW__; __THREW__ = 0;
   $23 = $22&1;
   if ($23) {
    $39 = ___cxa_find_matching_catch_2()|0;
    $40 = tempRet0;
    $$0 = $40;$$02 = $39;
    break;
   } else {
    HEAP32[$12>>2] = 0;
    __ZN3osg6ObjectD2Ev($2);
    return;
   }
  }
 } while(0);
 __THREW__ = 0;
 invoke_vi(388,($2|0));
 $41 = __THREW__; __THREW__ = 0;
 $42 = $41&1;
 if ($42) {
  $43 = ___cxa_find_matching_catch_3(0|0)|0;
  $44 = tempRet0;
  ___clang_call_terminate($43);
  // unreachable;
 } else {
  ___resumeException($$02|0);
  // unreachable;
 }
}
function __ZN20KeystoneCullCallbackD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(637,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZTv0_n16_NK20KeystoneCullCallback9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(48)|0);
 $2 = ((($1)) + 16|0);
 __THREW__ = 0;
 invoke_vi(3282,($2|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch_2()|0;
  $6 = tempRet0;
  __ZdlPv($1);
  ___resumeException($5|0);
  // unreachable;
 } else {
  $7 = ((($1)) + 28|0);
  ;HEAP32[$7>>2]=0|0;HEAP32[$7+4>>2]=0|0;HEAP32[$7+8>>2]=0|0;
  $8 = ((($1)) + 40|0);
  HEAP32[$8>>2] = 2;
  $9 = ((($1)) + 44|0);
  HEAP32[$9>>2] = 0;
  $10 = ((($1)) + 12|0);
  HEAP32[$10>>2] = 0;
  HEAP32[$1>>2] = (40888);
  $11 = ((($1)) + 8|0);
  HEAP32[$11>>2] = (41044);
  HEAP32[$2>>2] = (41292);
  $12 = ((($1)) + 4|0);
  HEAP32[$12>>2] = 0;
  return ($2|0);
 }
 return (0)|0;
}
function __ZTv0_n20_NK20KeystoneCullCallback5cloneERKN3osg6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(48)|0);
 $3 = ((($2)) + 16|0);
 __THREW__ = 0;
 invoke_vi(3282,($3|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch_2()|0;
  $7 = tempRet0;
  __ZdlPv($2);
  ___resumeException($6|0);
  // unreachable;
 } else {
  $8 = ((($2)) + 28|0);
  ;HEAP32[$8>>2]=0|0;HEAP32[$8+4>>2]=0|0;HEAP32[$8+8>>2]=0|0;
  $9 = ((($2)) + 40|0);
  HEAP32[$9>>2] = 2;
  $10 = ((($2)) + 44|0);
  HEAP32[$10>>2] = 0;
  $11 = ((($2)) + 12|0);
  HEAP32[$11>>2] = 0;
  HEAP32[$2>>2] = (40888);
  $12 = ((($2)) + 8|0);
  HEAP32[$12>>2] = (41044);
  HEAP32[$3>>2] = (41292);
  $13 = ((($2)) + 4|0);
  HEAP32[$13>>2] = 0;
  return ($3|0);
 }
 return (0)|0;
}
function __ZTv0_n24_NK20KeystoneCullCallback12isSameKindAsEPKN3osg6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,8080,-1)|0);
 $phitmp$i = ($3|0)!=(0|0);
 $4 = $phitmp$i;
 return ($4|0);
}
function __ZTv0_n28_NK20KeystoneCullCallback11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175113|0);
}
function __ZTv0_n32_NK20KeystoneCullCallback9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (107979|0);
}
function __ZTv0_n92_N3osg20DrawableCullCallback22asDrawableCullCallbackEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -92|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 return ($4|0);
}
function __ZTv0_n96_NK3osg20DrawableCullCallback22asDrawableCullCallbackEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -96|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 return ($4|0);
}
function __ZTv0_n112_N20KeystoneCullCallbackD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -112|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __ZN20KeystoneCullCallbackD1Ev($4);
 return;
}
function __ZTv0_n112_N20KeystoneCullCallbackD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -112|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __THREW__ = 0;
 invoke_vi(637,($4|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $7 = ___cxa_find_matching_catch_2()|0;
  $8 = tempRet0;
  __ZdlPv($4);
  ___resumeException($7|0);
  // unreachable;
 } else {
  __ZdlPv($4);
  return;
 }
}
function __ZTv0_n16_N20KeystoneCullCallbackD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __ZN20KeystoneCullCallbackD1Ev($4);
 return;
}
function __ZTv0_n16_N20KeystoneCullCallbackD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __THREW__ = 0;
 invoke_vi(637,($4|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $7 = ___cxa_find_matching_catch_2()|0;
  $8 = tempRet0;
  __ZdlPv($4);
  ___resumeException($7|0);
  // unreachable;
 } else {
  __ZdlPv($4);
  return;
 }
}
function __ZTv0_n20_NK20KeystoneCullCallback9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(48)|0);
 $2 = ((($1)) + 16|0);
 __THREW__ = 0;
 invoke_vi(3282,($2|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch_2()|0;
  $6 = tempRet0;
  __ZdlPv($1);
  ___resumeException($5|0);
  // unreachable;
 } else {
  $7 = ((($1)) + 28|0);
  ;HEAP32[$7>>2]=0|0;HEAP32[$7+4>>2]=0|0;HEAP32[$7+8>>2]=0|0;
  $8 = ((($1)) + 40|0);
  HEAP32[$8>>2] = 2;
  $9 = ((($1)) + 44|0);
  HEAP32[$9>>2] = 0;
  $10 = ((($1)) + 12|0);
  HEAP32[$10>>2] = 0;
  HEAP32[$1>>2] = (40888);
  $11 = ((($1)) + 8|0);
  HEAP32[$11>>2] = (41044);
  HEAP32[$2>>2] = (41292);
  $12 = ((($1)) + 4|0);
  HEAP32[$12>>2] = 0;
  return ($2|0);
 }
 return (0)|0;
}
function __ZTv0_n24_NK20KeystoneCullCallback5cloneERKN3osg6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(48)|0);
 $3 = ((($2)) + 16|0);
 __THREW__ = 0;
 invoke_vi(3282,($3|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch_2()|0;
  $7 = tempRet0;
  __ZdlPv($2);
  ___resumeException($6|0);
  // unreachable;
 } else {
  $8 = ((($2)) + 28|0);
  ;HEAP32[$8>>2]=0|0;HEAP32[$8+4>>2]=0|0;HEAP32[$8+8>>2]=0|0;
  $9 = ((($2)) + 40|0);
  HEAP32[$9>>2] = 2;
  $10 = ((($2)) + 44|0);
  HEAP32[$10>>2] = 0;
  $11 = ((($2)) + 12|0);
  HEAP32[$11>>2] = 0;
  HEAP32[$2>>2] = (40888);
  $12 = ((($2)) + 8|0);
  HEAP32[$12>>2] = (41044);
  HEAP32[$3>>2] = (41292);
  $13 = ((($2)) + 4|0);
  HEAP32[$13>>2] = 0;
  return ($3|0);
 }
 return (0)|0;
}
function __ZTv0_n28_NK20KeystoneCullCallback12isSameKindAsEPKN3osg6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,8080,-1)|0);
 $phitmp$i = ($3|0)!=(0|0);
 $4 = $phitmp$i;
 return ($4|0);
}
function __ZTv0_n32_NK20KeystoneCullCallback11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175113|0);
}
function __ZTv0_n36_NK20KeystoneCullCallback9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (107979|0);
}
function __ZN9osgViewer15KeystoneHandlerC1EPNS_8KeystoneE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$04 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 116|0);
 __ZN3osg10ReferencedC2Ev($2);
 $3 = ((($0)) + 128|0);
 ;HEAP32[$3>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;
 $4 = ((($0)) + 140|0);
 HEAP32[$4>>2] = 2;
 $5 = ((($0)) + 144|0);
 HEAP32[$5>>2] = 0;
 $6 = ((($0)) + 108|0);
 $7 = ((($6)) + 8|0);
 $8 = ((($0)) + 112|0);
 HEAP32[$8>>2] = 0;
 HEAP32[$0>>2] = (39044);
 HEAP32[$6>>2] = (39296);
 HEAP32[$2>>2] = (39544);
 $9 = ((($0)) + 4|0);
 HEAP32[$9>>2] = (39140);
 $10 = ((($0)) + 8|0);
 HEAP32[$10>>2] = $1;
 $11 = ($1|0)==(0|0);
 if (!($11)) {
  $12 = ((($1)) + 8|0);
  $13 = HEAP32[$12>>2]|0;HEAP32[$12>>2] = (($13+1)|0);
 }
 $14 = ((($0)) + 16|0);
 $15 = ((($0)) + 32|0);
 ;HEAP32[$14>>2]=0|0;HEAP32[$14+4>>2]=0|0;HEAP32[$14+8>>2]=0|0;HEAP32[$14+12>>2]=0|0;
 HEAPF64[$15>>3] = 1.0;
 $16 = ((($0)) + 40|0);
 HEAPF64[$16>>3] = 1.0;
 $17 = ((($0)) + 48|0);
 HEAPF64[$17>>3] = 0.10000000000000001;
 $18 = ((($0)) + 56|0);
 HEAPF64[$18>>3] = 0.10000000000000001;
 $19 = ((($0)) + 64|0);
 HEAPF64[$19>>3] = 0.0050000000000000001;
 $20 = ((($0)) + 72|0);
 HEAPF64[$20>>3] = 0.0050000000000000001;
 $21 = ((($0)) + 80|0);
 $22 = ((($0)) + 96|0);
 $23 = ((($0)) + 104|0);
 ;HEAP32[$21>>2]=0|0;HEAP32[$21+4>>2]=0|0;HEAP32[$21+8>>2]=0|0;HEAP32[$21+12>>2]=0|0;HEAP32[$21+16>>2]=0|0;HEAP32[$21+20>>2]=0|0;HEAP32[$21+24>>2]=0|0;
 __THREW__ = 0;
 $24 = (invoke_ii(3276,120)|0);
 $25 = __THREW__; __THREW__ = 0;
 $26 = $25&1;
 do {
  if ($26) {
   label = 16;
  } else {
   __THREW__ = 0;
   invoke_vi(3282,($24|0));
   $27 = __THREW__; __THREW__ = 0;
   $28 = $27&1;
   if ($28) {
    $67 = ___cxa_find_matching_catch_2()|0;
    $68 = tempRet0;
    __ZdlPv($24);
    $$0 = $68;$$04 = $67;
    break;
   }
   $29 = ((($24)) + 12|0);
   ;HEAP32[$29>>2]=0|0;HEAP32[$29+4>>2]=0|0;HEAP32[$29+8>>2]=0|0;
   $30 = ((($24)) + 24|0);
   HEAP32[$30>>2] = 2;
   $31 = ((($24)) + 28|0);
   HEAP32[$31>>2] = 0;
   HEAP32[$24>>2] = (40172);
   $32 = ((($24)) + 32|0);
   HEAP8[$32>>0] = 0;
   $33 = ((($24)) + 36|0);
   HEAPF32[$33>>2] = 1.0;
   $34 = ((($24)) + 40|0);
   HEAPF32[$34>>2] = 1.0;
   $35 = ((($24)) + 44|0);
   HEAPF32[$35>>2] = 1.0;
   $36 = ((($24)) + 48|0);
   HEAPF32[$36>>2] = 1.0;
   $37 = ((($24)) + 56|0);
   HEAPF64[$37>>3] = -1.0;
   $38 = ((($24)) + 64|0);
   HEAPF64[$38>>3] = -1.0;
   $39 = ((($24)) + 72|0);
   HEAPF64[$39>>3] = 1.0;
   $40 = ((($24)) + 80|0);
   HEAPF64[$40>>3] = -1.0;
   $41 = ((($24)) + 88|0);
   HEAPF64[$41>>3] = -1.0;
   $42 = ((($24)) + 96|0);
   HEAPF64[$42>>3] = 1.0;
   $43 = ((($24)) + 104|0);
   HEAPF64[$43>>3] = 1.0;
   $44 = ((($24)) + 112|0);
   HEAPF64[$44>>3] = 1.0;
   $45 = HEAP32[$22>>2]|0;
   $46 = ($45|0)==($24|0);
   if (!($46)) {
    HEAP32[$22>>2] = $24;
    $47 = ((($24)) + 8|0);
    $48 = HEAP32[$47>>2]|0;HEAP32[$47>>2] = (($48+1)|0);
    $49 = ($45|0)==(0|0);
    if (!($49)) {
     $50 = ((($45)) + 8|0);
     $51 = HEAP32[$50>>2]|0;HEAP32[$50>>2] = (($51-1)|0);
     $52 = ($51|0)==(1);
     if ($52) {
      __THREW__ = 0;
      invoke_viii(3262,($45|0),1,1);
      $53 = __THREW__; __THREW__ = 0;
      $54 = $53&1;
      if ($54) {
       label = 16;
       break;
      }
     }
    }
   }
   $55 = HEAP32[$23>>2]|0;
   $56 = ($55|0)==($1|0);
   if ($56) {
    return;
   }
   HEAP32[$23>>2] = $1;
   if (!($11)) {
    $57 = ((($1)) + 8|0);
    $58 = HEAP32[$57>>2]|0;HEAP32[$57>>2] = (($58+1)|0);
   }
   $59 = ($55|0)==(0|0);
   if ($59) {
    return;
   }
   $60 = ((($55)) + 8|0);
   $61 = HEAP32[$60>>2]|0;HEAP32[$60>>2] = (($61-1)|0);
   $62 = ($61|0)==(1);
   if (!($62)) {
    return;
   }
   __THREW__ = 0;
   invoke_viii(3262,($55|0),1,1);
   $63 = __THREW__; __THREW__ = 0;
   $64 = $63&1;
   if ($64) {
    label = 16;
   } else {
    return;
   }
  }
 } while(0);
 if ((label|0) == 16) {
  $65 = ___cxa_find_matching_catch_2()|0;
  $66 = tempRet0;
  $$0 = $66;$$04 = $65;
 }
 $69 = HEAP32[$23>>2]|0;
 $70 = ($69|0)==(0|0);
 if (!($70)) {
  $71 = ((($69)) + 8|0);
  $72 = HEAP32[$71>>2]|0;HEAP32[$71>>2] = (($72-1)|0);
  $73 = ($72|0)==(1);
  if ($73) {
   __THREW__ = 0;
   invoke_viii(3262,($69|0),1,1);
   $74 = __THREW__; __THREW__ = 0;
   $75 = $74&1;
   if ($75) {
    $105 = ___cxa_find_matching_catch_3(0|0)|0;
    $106 = tempRet0;
    ___clang_call_terminate($105);
    // unreachable;
   }
  }
 }
 HEAP32[$23>>2] = 0;
 $76 = HEAP32[$22>>2]|0;
 $77 = ($76|0)==(0|0);
 if (!($77)) {
  $78 = ((($76)) + 8|0);
  $79 = HEAP32[$78>>2]|0;HEAP32[$78>>2] = (($79-1)|0);
  $80 = ($79|0)==(1);
  if ($80) {
   __THREW__ = 0;
   invoke_viii(3262,($76|0),1,1);
   $81 = __THREW__; __THREW__ = 0;
   $82 = $81&1;
   if ($82) {
    $105 = ___cxa_find_matching_catch_3(0|0)|0;
    $106 = tempRet0;
    ___clang_call_terminate($105);
    // unreachable;
   }
  }
 }
 HEAP32[$22>>2] = 0;
 $83 = HEAP32[$10>>2]|0;
 $84 = ($83|0)==(0|0);
 if (!($84)) {
  $85 = ((($83)) + 8|0);
  $86 = HEAP32[$85>>2]|0;HEAP32[$85>>2] = (($86-1)|0);
  $87 = ($86|0)==(1);
  if ($87) {
   __THREW__ = 0;
   invoke_viii(3262,($83|0),1,1);
   $88 = __THREW__; __THREW__ = 0;
   $89 = $88&1;
   if ($89) {
    $105 = ___cxa_find_matching_catch_3(0|0)|0;
    $106 = tempRet0;
    ___clang_call_terminate($105);
    // unreachable;
   }
  }
 }
 HEAP32[$10>>2] = 0;
 __THREW__ = 0;
 invoke_vii(3484,($0|0),((39688)|0));
 $90 = __THREW__; __THREW__ = 0;
 $91 = $90&1;
 if ($91) {
  $105 = ___cxa_find_matching_catch_3(0|0)|0;
  $106 = tempRet0;
  ___clang_call_terminate($105);
  // unreachable;
 }
 HEAP32[$6>>2] = ((29984));
 HEAP32[$7>>2] = ((30232));
 $92 = HEAP32[$8>>2]|0;
 $93 = ($92|0)==(0|0);
 if (!($93)) {
  $94 = HEAP32[$92>>2]|0;
  $95 = ((($94)) + -12|0);
  $96 = HEAP32[$95>>2]|0;
  $97 = (($92) + ($96)|0);
  $98 = ((($97)) + 8|0);
  $99 = HEAP32[$98>>2]|0;HEAP32[$98>>2] = (($99-1)|0);
  $100 = ($99|0)==(1);
  if ($100) {
   __THREW__ = 0;
   invoke_viii(3262,($97|0),1,1);
   $101 = __THREW__; __THREW__ = 0;
   $102 = $101&1;
   if ($102) {
    $105 = ___cxa_find_matching_catch_3(0|0)|0;
    $106 = tempRet0;
    ___clang_call_terminate($105);
    // unreachable;
   }
  }
 }
 HEAP32[$8>>2] = 0;
 __THREW__ = 0;
 invoke_vi(388,($2|0));
 $103 = __THREW__; __THREW__ = 0;
 $104 = $103&1;
 if ($104) {
  $105 = ___cxa_find_matching_catch_3(0|0)|0;
  $106 = tempRet0;
  ___clang_call_terminate($105);
  // unreachable;
 } else {
  ___resumeException($$04|0);
  // unreachable;
 }
}
function __ZN9osgViewer8Keystone17loadKeystoneFilesEPN3osg15DisplaySettingsE($0) {
 $0 = $0|0;
 var $$1 = 0, $$114 = 0, $$220$off0 = 0, $$3 = 0, $$316 = 0, $$4 = 0, $$4126 = 0, $$417 = 0, $$417125 = 0, $$41774 = 0, $$475 = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i31 = 0, $$sroa$0$4122 = 0, $$sroa$0$5124 = 0, $$sroa$066$0110 = 0, $1 = 0, $10 = 0, $100 = 0;
 var $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0;
 var $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0;
 var $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0;
 var $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0;
 var $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0;
 var $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0;
 var $21 = 0, $210 = 0, $211 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $1 = sp + 40|0;
 $2 = sp + 36|0;
 $3 = sp + 16|0;
 $4 = sp + 32|0;
 $5 = sp;
 $6 = sp + 28|0;
 $7 = ((($0)) + 172|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($0)) + 176|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8|0)==($10|0);
 if ($11) {
  $$220$off0 = 0;
  STACKTOP = sp;return ($$220$off0|0);
 }
 $12 = ((($5)) + 11|0);
 $13 = ((($5)) + 8|0);
 $14 = ((($0)) + 184|0);
 $15 = ((($0)) + 188|0);
 $16 = ((($0)) + 192|0);
 $17 = ((($3)) + 11|0);
 $18 = ((($3)) + 8|0);
 $$sroa$066$0110 = $8;
 L4: while(1) {
  $19 = (__ZN5osgDB8Registry8instanceEb(0)|0);
  $20 = ((($19)) + 160|0);
  $21 = HEAP32[$20>>2]|0;
  __ZN5osgDB17readRefObjectFileERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEPKNS_7OptionsE($2,$$sroa$066$0110,$21);
  $22 = HEAP32[$2>>2]|0;
  $23 = ($22|0)==(0|0);
  do {
   if ($23) {
    label = 33;
   } else {
    $24 = (___dynamic_cast($22,26112,4080,0)|0);
    $25 = ($24|0)==(0|0);
    if ($25) {
     $30 = $22;
     label = 8;
    } else {
     $26 = ((($24)) + 8|0);
     $27 = HEAP32[$26>>2]|0;HEAP32[$26>>2] = (($27+1)|0);
     $$pre$i$i = HEAP32[$2>>2]|0;
     $28 = ($$pre$i$i|0)==(0|0);
     if ($28) {
     } else {
      $30 = $$pre$i$i;
      label = 8;
     }
    }
    if ((label|0) == 8) {
     label = 0;
     $29 = ((($30)) + 8|0);
     $31 = HEAP32[$29>>2]|0;HEAP32[$29>>2] = (($31-1)|0);
     $32 = ($31|0)==(1);
     if ($32) {
      __ZNK3osg10Referenced24signalObserversAndDeleteEbb($30,1,1);
     }
     if ($25) {
      label = 33;
      break;
     }
    }
    ;HEAP32[$3>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;
    HEAP8[$17>>0] = 8;
    $33 = $3;
    $34 = $33;
    HEAP32[$34>>2] = 1701603686;
    $35 = (($33) + 4)|0;
    $36 = $35;
    HEAP32[$36>>2] = 1701667182;
    HEAP8[$18>>0] = 0;
    __THREW__ = 0;
    invoke_viii(3500,($24|0),($3|0),($$sroa$066$0110|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     label = 24;
     break L4;
    }
    $39 = HEAP8[$17>>0]|0;
    $40 = ($39<<24>>24)<(0);
    if ($40) {
     $41 = HEAP32[$3>>2]|0;
     __ZdlPv($41);
    }
    HEAP32[$4>>2] = $24;
    $42 = ((($24)) + 8|0);
    $43 = HEAP32[$42>>2]|0;HEAP32[$42>>2] = (($43+1)|0);
    $44 = HEAP32[$15>>2]|0;
    $45 = HEAP32[$16>>2]|0;
    $46 = ($44|0)==($45|0);
    if ($46) {
     __THREW__ = 0;
     invoke_vii(3475,($14|0),($4|0));
     $53 = __THREW__; __THREW__ = 0;
     $54 = $53&1;
     if ($54) {
      label = 28;
      break L4;
     }
    } else {
     $47 = HEAP32[$4>>2]|0;
     HEAP32[$44>>2] = $47;
     $48 = ($47|0)==(0|0);
     if ($48) {
      $52 = $44;
     } else {
      $49 = ((($47)) + 8|0);
      $50 = HEAP32[$49>>2]|0;HEAP32[$49>>2] = (($50+1)|0);
      $$pre$i31 = HEAP32[$15>>2]|0;
      $52 = $$pre$i31;
     }
     $51 = ((($52)) + 4|0);
     HEAP32[$15>>2] = $51;
    }
    $55 = HEAP32[$4>>2]|0;
    $56 = ($55|0)==(0|0);
    if (!($56)) {
     $57 = ((($55)) + 8|0);
     $58 = HEAP32[$57>>2]|0;HEAP32[$57>>2] = (($58-1)|0);
     $59 = ($58|0)==(1);
     if ($59) {
      __THREW__ = 0;
      invoke_viii(3262,($55|0),1,1);
      $60 = __THREW__; __THREW__ = 0;
      $61 = $60&1;
      if ($61) {
       label = 27;
       break L4;
      }
     }
    }
    $197 = ($24|0)==(0|0);
    if (!($197)) {
     $$sroa$0$4122 = $24;
     label = 72;
    }
   }
  } while(0);
  if ((label|0) == 33) {
   label = 0;
   __THREW__ = 0;
   $80 = (invoke_ii(3265,3)|0);
   $81 = __THREW__; __THREW__ = 0;
   $82 = $81&1;
   if ($82) {
    label = 22;
    break;
   }
   if ($80) {
    __THREW__ = 0;
    $83 = (invoke_ii(3266,3)|0);
    $84 = __THREW__; __THREW__ = 0;
    $85 = $84&1;
    if ($85) {
     label = 22;
     break;
    }
    __THREW__ = 0;
    $86 = (invoke_iiii(3267,($83|0),(108023|0),38)|0);
    $87 = __THREW__; __THREW__ = 0;
    $88 = $87&1;
    if ($88) {
     label = 22;
     break;
    }
    $89 = ((($$sroa$066$0110)) + 11|0);
    $90 = HEAP8[$89>>0]|0;
    $91 = ($90<<24>>24)<(0);
    $92 = HEAP32[$$sroa$066$0110>>2]|0;
    $93 = $91 ? $92 : $$sroa$066$0110;
    $94 = ((($$sroa$066$0110)) + 4|0);
    $95 = HEAP32[$94>>2]|0;
    $96 = $90&255;
    $97 = $91 ? $95 : $96;
    __THREW__ = 0;
    $98 = (invoke_iiii(3267,($86|0),($93|0),($97|0))|0);
    $99 = __THREW__; __THREW__ = 0;
    $100 = $99&1;
    if ($100) {
     label = 22;
     break;
    }
    $101 = HEAP32[$98>>2]|0;
    $102 = ((($101)) + -12|0);
    $103 = HEAP32[$102>>2]|0;
    $104 = (($98) + ($103)|0);
    __THREW__ = 0;
    invoke_vii(3257,($1|0),($104|0));
    $105 = __THREW__; __THREW__ = 0;
    $106 = $105&1;
    if ($106) {
     label = 22;
     break;
    }
    __THREW__ = 0;
    $107 = (invoke_iii(3255,($1|0),(215188|0))|0);
    $108 = __THREW__; __THREW__ = 0;
    $109 = $108&1;
    if ($109) {
     label = 41;
     break;
    }
    $110 = HEAP32[$107>>2]|0;
    $111 = ((($110)) + 28|0);
    $112 = HEAP32[$111>>2]|0;
    __THREW__ = 0;
    $113 = (invoke_iii($112|0,($107|0),10)|0);
    $114 = __THREW__; __THREW__ = 0;
    $115 = $114&1;
    if ($115) {
     label = 41;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3263,($1|0));
    $122 = __THREW__; __THREW__ = 0;
    $123 = $122&1;
    if ($123) {
     label = 22;
     break;
    }
    __THREW__ = 0;
    (invoke_iii(3268,($98|0),($113|0))|0);
    $124 = __THREW__; __THREW__ = 0;
    $125 = $124&1;
    if ($125) {
     label = 22;
     break;
    }
    __THREW__ = 0;
    (invoke_ii(3269,($98|0))|0);
    $126 = __THREW__; __THREW__ = 0;
    $127 = $126&1;
    if ($127) {
     label = 22;
     break;
    }
   }
   __THREW__ = 0;
   $128 = (invoke_ii(3276,120)|0);
   $129 = __THREW__; __THREW__ = 0;
   $130 = $129&1;
   if ($130) {
    label = 22;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3282,($128|0));
   $131 = __THREW__; __THREW__ = 0;
   $132 = $131&1;
   if ($132) {
    label = 61;
    break;
   }
   $133 = ((($128)) + 12|0);
   ;HEAP32[$133>>2]=0|0;HEAP32[$133+4>>2]=0|0;HEAP32[$133+8>>2]=0|0;
   $134 = ((($128)) + 24|0);
   HEAP32[$134>>2] = 2;
   $135 = ((($128)) + 28|0);
   HEAP32[$135>>2] = 0;
   HEAP32[$128>>2] = (40172);
   $136 = ((($128)) + 32|0);
   HEAP8[$136>>0] = 0;
   $137 = ((($128)) + 36|0);
   HEAPF32[$137>>2] = 1.0;
   $138 = ((($128)) + 40|0);
   HEAPF32[$138>>2] = 1.0;
   $139 = ((($128)) + 44|0);
   HEAPF32[$139>>2] = 1.0;
   $140 = ((($128)) + 48|0);
   HEAPF32[$140>>2] = 1.0;
   $141 = ((($128)) + 56|0);
   HEAPF64[$141>>3] = -1.0;
   $142 = ((($128)) + 64|0);
   HEAPF64[$142>>3] = -1.0;
   $143 = ((($128)) + 72|0);
   HEAPF64[$143>>3] = 1.0;
   $144 = ((($128)) + 80|0);
   HEAPF64[$144>>3] = -1.0;
   $145 = ((($128)) + 88|0);
   HEAPF64[$145>>3] = -1.0;
   $146 = ((($128)) + 96|0);
   HEAPF64[$146>>3] = 1.0;
   $147 = ((($128)) + 104|0);
   HEAPF64[$147>>3] = 1.0;
   $148 = ((($128)) + 112|0);
   HEAPF64[$148>>3] = 1.0;
   $149 = ((($128)) + 8|0);
   $150 = HEAP32[$149>>2]|0;HEAP32[$149>>2] = (($150+1)|0);
   ;HEAP32[$5>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;
   HEAP8[$12>>0] = 8;
   $151 = $5;
   $152 = $151;
   HEAP32[$152>>2] = 1701603686;
   $153 = (($151) + 4)|0;
   $154 = $153;
   HEAP32[$154>>2] = 1701667182;
   HEAP8[$13>>0] = 0;
   __THREW__ = 0;
   invoke_viii(3500,($128|0),($5|0),($$sroa$066$0110|0));
   $155 = __THREW__; __THREW__ = 0;
   $156 = $155&1;
   if ($156) {
    label = 62;
    break;
   }
   $157 = HEAP8[$12>>0]|0;
   $158 = ($157<<24>>24)<(0);
   if ($158) {
    $159 = HEAP32[$5>>2]|0;
    __ZdlPv($159);
   }
   HEAP32[$6>>2] = $128;
   $160 = HEAP32[$149>>2]|0;HEAP32[$149>>2] = (($160+1)|0);
   $161 = HEAP32[$15>>2]|0;
   $162 = HEAP32[$16>>2]|0;
   $163 = ($161|0)==($162|0);
   if ($163) {
    __THREW__ = 0;
    invoke_vii(3475,($14|0),($6|0));
    $170 = __THREW__; __THREW__ = 0;
    $171 = $170&1;
    if ($171) {
     label = 66;
     break;
    }
   } else {
    $164 = HEAP32[$6>>2]|0;
    HEAP32[$161>>2] = $164;
    $165 = ($164|0)==(0|0);
    if ($165) {
     $169 = $161;
    } else {
     $166 = ((($164)) + 8|0);
     $167 = HEAP32[$166>>2]|0;HEAP32[$166>>2] = (($167+1)|0);
     $$pre$i = HEAP32[$15>>2]|0;
     $169 = $$pre$i;
    }
    $168 = ((($169)) + 4|0);
    HEAP32[$15>>2] = $168;
   }
   $172 = HEAP32[$6>>2]|0;
   $173 = ($172|0)==(0|0);
   if (!($173)) {
    $174 = ((($172)) + 8|0);
    $175 = HEAP32[$174>>2]|0;HEAP32[$174>>2] = (($175-1)|0);
    $176 = ($175|0)==(1);
    if ($176) {
     __THREW__ = 0;
     invoke_viii(3262,($172|0),1,1);
     $177 = __THREW__; __THREW__ = 0;
     $178 = $177&1;
     if ($178) {
      label = 65;
      break;
     }
    }
   }
   $$sroa$0$4122 = $128;
   label = 72;
  }
  if ((label|0) == 72) {
   label = 0;
   $198 = ((($$sroa$0$4122)) + 8|0);
   $199 = HEAP32[$198>>2]|0;HEAP32[$198>>2] = (($199-1)|0);
   $200 = ($199|0)==(1);
   if ($200) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($$sroa$0$4122,1,1);
   }
  }
  $201 = ((($$sroa$066$0110)) + 12|0);
  $202 = HEAP32[$9>>2]|0;
  $203 = ($201|0)==($202|0);
  if ($203) {
   $$220$off0 = 1;
   label = 79;
   break;
  } else {
   $$sroa$066$0110 = $201;
  }
 }
 switch (label|0) {
  case 22: {
   $62 = ___cxa_find_matching_catch_2()|0;
   $63 = tempRet0;
   $eh$lpad$body$index2Z2D = $63;$eh$lpad$body$indexZ2D = $62;
   label = 23;
   break;
  }
  case 24: {
   $64 = ___cxa_find_matching_catch_2()|0;
   $65 = tempRet0;
   $66 = HEAP8[$17>>0]|0;
   $67 = ($66<<24>>24)<(0);
   if ($67) {
    $68 = HEAP32[$3>>2]|0;
    __ZdlPv($68);
   }
   $$4 = $65;$$417 = $64;
   label = 75;
   break;
  }
  case 27: {
   $69 = ___cxa_find_matching_catch_2()|0;
   $70 = tempRet0;
   $$1 = $70;$$114 = $69;
   label = 32;
   break;
  }
  case 28: {
   $71 = ___cxa_find_matching_catch_2()|0;
   $72 = tempRet0;
   $73 = HEAP32[$4>>2]|0;
   $74 = ($73|0)==(0|0);
   if (!($74)) {
    $75 = ((($73)) + 8|0);
    $76 = HEAP32[$75>>2]|0;HEAP32[$75>>2] = (($76-1)|0);
    $77 = ($76|0)==(1);
    if ($77) {
     __THREW__ = 0;
     invoke_viii(3262,($73|0),1,1);
     $78 = __THREW__; __THREW__ = 0;
     $79 = $78&1;
     if ($79) {
      $210 = ___cxa_find_matching_catch_3(0|0)|0;
      $211 = tempRet0;
      ___clang_call_terminate($210);
      // unreachable;
     }
    }
   }
   HEAP32[$4>>2] = 0;
   $$1 = $72;$$114 = $71;
   label = 32;
   break;
  }
  case 41: {
   $116 = ___cxa_find_matching_catch_2()|0;
   $117 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($1|0));
   $118 = __THREW__; __THREW__ = 0;
   $119 = $118&1;
   if ($119) {
    $120 = ___cxa_find_matching_catch_3(0|0)|0;
    $121 = tempRet0;
    ___clang_call_terminate($120);
    // unreachable;
   } else {
    $eh$lpad$body$index2Z2D = $117;$eh$lpad$body$indexZ2D = $116;
    label = 23;
    break;
   }
   break;
  }
  case 61: {
   $179 = ___cxa_find_matching_catch_2()|0;
   $180 = tempRet0;
   __ZdlPv($128);
   $$41774 = $179;$$475 = $180;
   ___resumeException($$41774|0);
   // unreachable;
   break;
  }
  case 62: {
   $181 = ___cxa_find_matching_catch_2()|0;
   $182 = tempRet0;
   $183 = HEAP8[$12>>0]|0;
   $184 = ($183<<24>>24)<(0);
   if ($184) {
    $185 = HEAP32[$5>>2]|0;
    __ZdlPv($185);
   }
   $$4126 = $182;$$417125 = $181;$$sroa$0$5124 = $128;
   break;
  }
  case 65: {
   $186 = ___cxa_find_matching_catch_2()|0;
   $187 = tempRet0;
   $$3 = $187;$$316 = $186;
   label = 70;
   break;
  }
  case 66: {
   $188 = ___cxa_find_matching_catch_2()|0;
   $189 = tempRet0;
   $190 = HEAP32[$6>>2]|0;
   $191 = ($190|0)==(0|0);
   if (!($191)) {
    $192 = ((($190)) + 8|0);
    $193 = HEAP32[$192>>2]|0;HEAP32[$192>>2] = (($193-1)|0);
    $194 = ($193|0)==(1);
    if ($194) {
     __THREW__ = 0;
     invoke_viii(3262,($190|0),1,1);
     $195 = __THREW__; __THREW__ = 0;
     $196 = $195&1;
     if ($196) {
      $210 = ___cxa_find_matching_catch_3(0|0)|0;
      $211 = tempRet0;
      ___clang_call_terminate($210);
      // unreachable;
     }
    }
   }
   HEAP32[$6>>2] = 0;
   $$3 = $189;$$316 = $188;
   label = 70;
   break;
  }
  case 79: {
   STACKTOP = sp;return ($$220$off0|0);
   break;
  }
 }
 if ((label|0) == 23) {
  $$41774 = $eh$lpad$body$indexZ2D;$$475 = $eh$lpad$body$index2Z2D;
  ___resumeException($$41774|0);
  // unreachable;
 }
 else if ((label|0) == 32) {
  $$4 = $$1;$$417 = $$114;
  label = 75;
 }
 else if ((label|0) == 70) {
  $$4126 = $$3;$$417125 = $$316;$$sroa$0$5124 = $128;
 }
 if ((label|0) == 75) {
  $204 = ($24|0)==(0|0);
  if ($204) {
   $$41774 = $$417;$$475 = $$4;
   ___resumeException($$41774|0);
   // unreachable;
  } else {
   $$4126 = $$4;$$417125 = $$417;$$sroa$0$5124 = $24;
  }
 }
 $205 = ((($$sroa$0$5124)) + 8|0);
 $206 = HEAP32[$205>>2]|0;HEAP32[$205>>2] = (($206-1)|0);
 $207 = ($206|0)==(1);
 if (!($207)) {
  $$41774 = $$417125;$$475 = $$4126;
  ___resumeException($$41774|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(3262,($$sroa$0$5124|0),1,1);
 $208 = __THREW__; __THREW__ = 0;
 $209 = $208&1;
 if ($209) {
  $210 = ___cxa_find_matching_catch_3(0|0)|0;
  $211 = tempRet0;
  ___clang_call_terminate($210);
  // unreachable;
 } else {
  $$41774 = $$417125;$$475 = $$4126;
  ___resumeException($$41774|0);
  // unreachable;
 }
 return (0)|0;
}
function __ZN3osg6Object12setUserValueINSt3__212basic_stringIcNS2_11char_traitsIcEENS2_9allocatorIcEEEEEEvRKS8_RKT_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$030 = 0, $$031 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = HEAP32[$0>>2]|0;
 $4 = ((($3)) + 104|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_ii[$5 & 8191]($0)|0);
 $7 = ($6|0)==(0|0);
 if ($7) {
  (__ZN3osg6Object28getOrCreateUserDataContainerEv($0)|0);
  $8 = ((($0)) + 28|0);
  $9 = HEAP32[$8>>2]|0;
  $$031 = $9;
 } else {
  $$031 = $6;
 }
 $10 = HEAP32[$$031>>2]|0;
 $11 = ((($10)) + 168|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (FUNCTION_TABLE_iiii[$12 & 8191]($$031,$1,0)|0);
 $14 = HEAP32[$$031>>2]|0;
 $15 = ((($14)) + 160|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (FUNCTION_TABLE_ii[$16 & 8191]($$031)|0);
 $18 = ($13>>>0)<($17>>>0);
 if (!($18)) {
  $39 = HEAP32[$$031>>2]|0;
  $40 = ((($39)) + 140|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = (__Znwj(44)|0);
  __THREW__ = 0;
  invoke_viii(3501,($42|0),($1|0),($2|0));
  $43 = __THREW__; __THREW__ = 0;
  $44 = $43&1;
  if ($44) {
   $45 = ___cxa_find_matching_catch_2()|0;
   $46 = tempRet0;
   __ZdlPv($42);
   $$0 = $46;$$030 = $45;
   ___resumeException($$030|0);
   // unreachable;
  } else {
   (FUNCTION_TABLE_iii[$41 & 8191]($$031,$42)|0);
   return;
  }
 }
 $19 = HEAP32[$$031>>2]|0;
 $20 = ((($19)) + 152|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (FUNCTION_TABLE_iii[$21 & 8191]($$031,$13)|0);
 $23 = ($22|0)==(0|0);
 if ($23) {
  ___cxa_bad_typeid();
  // unreachable;
 }
 $24 = HEAP32[$22>>2]|0;
 $25 = ((($24)) + -4|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ((($26)) + 4|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = ($28|0)==(107693|0);
 if ($29) {
  $30 = ((($22)) + 32|0);
  (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEaSERKS5_($30,$2)|0);
  return;
 }
 $31 = HEAP32[$$031>>2]|0;
 $32 = ((($31)) + 144|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = (__Znwj(44)|0);
 __THREW__ = 0;
 invoke_viii(3501,($34|0),($1|0),($2|0));
 $35 = __THREW__; __THREW__ = 0;
 $36 = $35&1;
 if ($36) {
  $37 = ___cxa_find_matching_catch_2()|0;
  $38 = tempRet0;
  __ZdlPv($34);
  $$0 = $38;$$030 = $37;
  ___resumeException($$030|0);
  // unreachable;
 } else {
  FUNCTION_TABLE_viii[$33 & 8191]($$031,$13,$34);
  return;
 }
}
function __ZN3osg19TemplateValueObjectINSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEEC2ERKS7_SA_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg10ReferencedC2Eb($0,1);
 $3 = ((($0)) + 12|0);
 ;HEAP32[$3>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;
 $4 = ((($0)) + 24|0);
 HEAP32[$4>>2] = 2;
 $5 = ((($0)) + 28|0);
 HEAP32[$5>>2] = 0;
 HEAP32[$0>>2] = (41440);
 __THREW__ = 0;
 (invoke_iii(3477,($3|0),($1|0))|0);
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if ($7) {
  $8 = ___cxa_find_matching_catch_2()|0;
  $9 = tempRet0;
  __THREW__ = 0;
  invoke_vi(388,($0|0));
  $10 = __THREW__; __THREW__ = 0;
  $11 = $10&1;
  if ($11) {
   $12 = ___cxa_find_matching_catch_3(0|0)|0;
   $13 = tempRet0;
   ___clang_call_terminate($12);
   // unreachable;
  } else {
   ___resumeException($8|0);
   // unreachable;
  }
 }
 HEAP32[$0>>2] = (41596);
 $14 = ((($0)) + 32|0);
 __THREW__ = 0;
 invoke_vii(3457,($14|0),($2|0));
 $15 = __THREW__; __THREW__ = 0;
 $16 = $15&1;
 if (!($16)) {
  return;
 }
 $17 = ___cxa_find_matching_catch_2()|0;
 $18 = tempRet0;
 __THREW__ = 0;
 invoke_vi(388,($0|0));
 $19 = __THREW__; __THREW__ = 0;
 $20 = $19&1;
 if ($20) {
  $21 = ___cxa_find_matching_catch_3(0|0)|0;
  $22 = tempRet0;
  ___clang_call_terminate($21);
  // unreachable;
 } else {
  ___resumeException($17|0);
  // unreachable;
 }
}
function __ZN3osg19TemplateValueObjectINSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (41596);
 $1 = ((($0)) + 32|0);
 $2 = ((($1)) + 11|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)<(0);
 if (!($4)) {
  __ZN3osg6ObjectD2Ev($0);
  return;
 }
 $5 = HEAP32[$1>>2]|0;
 __ZdlPv($5);
 __ZN3osg6ObjectD2Ev($0);
 return;
}
function __ZN3osg19TemplateValueObjectINSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEED0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (41596);
 $1 = ((($0)) + 32|0);
 $2 = ((($1)) + 11|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)<(0);
 if ($4) {
  $5 = HEAP32[$1>>2]|0;
  __ZdlPv($5);
 }
 __THREW__ = 0;
 invoke_vi(388,($0|0));
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if ($7) {
  $8 = ___cxa_find_matching_catch_2()|0;
  $9 = tempRet0;
  __ZdlPv($0);
  ___resumeException($8|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK3osg19TemplateValueObjectINSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEE9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(44)|0);
 __THREW__ = 0;
 invoke_vii(3435,($1|0),1);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $8 = ___cxa_find_matching_catch_2()|0;
  $9 = tempRet0;
  __ZdlPv($1);
  ___resumeException($8|0);
  // unreachable;
 } else {
  $4 = ((($1)) + 12|0);
  ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;
  $5 = ((($1)) + 24|0);
  HEAP32[$5>>2] = 2;
  $6 = ((($1)) + 28|0);
  HEAP32[$6>>2] = 0;
  HEAP32[$1>>2] = (41596);
  $7 = ((($1)) + 32|0);
  ;HEAP32[$7>>2]=0|0;HEAP32[$7+4>>2]=0|0;HEAP32[$7+8>>2]=0|0;
  return ($1|0);
 }
 return (0)|0;
}
function __ZNK3osg19TemplateValueObjectINSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEE5cloneERKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i = 0, $$04$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = (__Znwj(44)|0);
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 HEAP32[$2>>2] = (58136);
 $6 = ((($2)) + 4|0);
 HEAP32[$6>>2] = $5;
 __THREW__ = 0;
 invoke_viii(3468,($3|0),($0|0),($2|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $13 = ___cxa_find_matching_catch_2()|0;
  $14 = tempRet0;
  $$0$i = $14;$$04$i = $13;
  __ZdlPv($3);
  ___resumeException($$04$i|0);
  // unreachable;
 }
 HEAP32[$3>>2] = (41596);
 $9 = ((($3)) + 32|0);
 $10 = ((($0)) + 32|0);
 __THREW__ = 0;
 invoke_vii(3457,($9|0),($10|0));
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if (!($12)) {
  STACKTOP = sp;return ($3|0);
 }
 $15 = ___cxa_find_matching_catch_2()|0;
 $16 = tempRet0;
 __THREW__ = 0;
 invoke_vi(388,($3|0));
 $17 = __THREW__; __THREW__ = 0;
 $18 = $17&1;
 if ($18) {
  $19 = ___cxa_find_matching_catch_3(0|0)|0;
  $20 = tempRet0;
  ___clang_call_terminate($19);
  // unreachable;
 } else {
  $$0$i = $16;$$04$i = $15;
  __ZdlPv($3);
  ___resumeException($$04$i|0);
  // unreachable;
 }
 return (0)|0;
}
function __ZNK3osg19TemplateValueObjectINSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEE12isSameKindAsEPKNS_6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,8096,0)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK3osg19TemplateValueObjectINSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEE11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175113|0);
}
function __ZNK3osg19TemplateValueObjectINSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEE9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (108062|0);
}
function __ZNK3osg19TemplateValueObjectINSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEE3getERNS_11ValueObject15GetValueVisitorE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 44|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 32|0);
 FUNCTION_TABLE_vii[$4 & 8191]($1,$5);
 return 1;
}
function __ZN3osg19TemplateValueObjectINSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEE3setERNS_11ValueObject15SetValueVisitorE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 44|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 32|0);
 FUNCTION_TABLE_vii[$4 & 8191]($1,$5);
 return 1;
}
function __ZN3osg11ValueObjectD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(388,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK3osg11ValueObject9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(32)|0);
 __THREW__ = 0;
 invoke_vii(3435,($1|0),1);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $7 = ___cxa_find_matching_catch_2()|0;
  $8 = tempRet0;
  __ZdlPv($1);
  ___resumeException($7|0);
  // unreachable;
 } else {
  $4 = ((($1)) + 12|0);
  ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;
  $5 = ((($1)) + 24|0);
  HEAP32[$5>>2] = 2;
  $6 = ((($1)) + 28|0);
  HEAP32[$6>>2] = 0;
  HEAP32[$1>>2] = (41440);
  return ($1|0);
 }
 return (0)|0;
}
function __ZNK3osg11ValueObject5cloneERKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = (__Znwj(32)|0);
 HEAP32[$2>>2] = (58136);
 $4 = ((($2)) + 4|0);
 $5 = ((($1)) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 HEAP32[$4>>2] = $6;
 __THREW__ = 0;
 invoke_viii(3468,($3|0),($0|0),($2|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch_2()|0;
  $10 = tempRet0;
  __ZdlPv($3);
  ___resumeException($9|0);
  // unreachable;
 } else {
  HEAP32[$3>>2] = (41440);
  STACKTOP = sp;return ($3|0);
 }
 return (0)|0;
}
function __ZNK3osg11ValueObject12isSameKindAsEPKNS_6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,8112,0)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK3osg11ValueObject11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175113|0);
}
function __ZNK3osg11ValueObject9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (108100|0);
}
function __ZNK3osg11ValueObject3getERNS0_15GetValueVisitorE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function __ZN3osg11ValueObject3setERNS0_15SetValueVisitorE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function __ZN15EXTQuerySupportD2Ev($0) {
 $0 = $0|0;
 var $$023$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i = 0, $scevgep5$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (41752);
 $1 = ((($0)) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = ((($0)) + 32|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==($2|0);
  if (!($6)) {
   $scevgep$i$i$i = ((($5)) + -4|0);
   $7 = $scevgep$i$i$i;
   $8 = $2;
   $9 = (($7) - ($8))|0;
   $10 = $9 >>> 2;
   $11 = $10 ^ -1;
   $scevgep5$i$i$i = (($5) + ($11<<2)|0);
   HEAP32[$4>>2] = $scevgep5$i$i$i;
  }
  __ZdlPv($2);
 }
 $12 = ((($0)) + 16|0);
 $13 = ((($0)) + 24|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(0);
 if ($15) {
  __ZN3osg10ReferencedD2Ev($0);
  return;
 }
 $16 = ((($0)) + 20|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = HEAP32[$12>>2]|0;
 $19 = ((($18)) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = HEAP32[$17>>2]|0;
 $22 = ((($21)) + 4|0);
 HEAP32[$22>>2] = $20;
 $23 = HEAP32[$19>>2]|0;
 HEAP32[$23>>2] = $21;
 HEAP32[$13>>2] = 0;
 $24 = ($17|0)==($12|0);
 if ($24) {
  __ZN3osg10ReferencedD2Ev($0);
  return;
 } else {
  $$023$i$i = $17;
 }
 while(1) {
  $25 = ((($$023$i$i)) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  __ZdlPv($$023$i$i);
  $27 = ($26|0)==($12|0);
  if ($27) {
   break;
  } else {
   $$023$i$i = $26;
  }
 }
 __ZN3osg10ReferencedD2Ev($0);
 return;
}
function __ZN15EXTQuerySupportD0Ev($0) {
 $0 = $0|0;
 var $$023$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i = 0, $scevgep5$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (41752);
 $1 = ((($0)) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = ((($0)) + 32|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==($2|0);
  if (!($6)) {
   $scevgep$i$i$i$i = ((($5)) + -4|0);
   $7 = $scevgep$i$i$i$i;
   $8 = $2;
   $9 = (($7) - ($8))|0;
   $10 = $9 >>> 2;
   $11 = $10 ^ -1;
   $scevgep5$i$i$i$i = (($5) + ($11<<2)|0);
   HEAP32[$4>>2] = $scevgep5$i$i$i$i;
  }
  __ZdlPv($2);
 }
 $12 = ((($0)) + 16|0);
 $13 = ((($0)) + 24|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(0);
 if (!($15)) {
  $16 = ((($0)) + 20|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = HEAP32[$12>>2]|0;
  $19 = ((($18)) + 4|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = HEAP32[$17>>2]|0;
  $22 = ((($21)) + 4|0);
  HEAP32[$22>>2] = $20;
  $23 = HEAP32[$19>>2]|0;
  HEAP32[$23>>2] = $21;
  HEAP32[$13>>2] = 0;
  $24 = ($17|0)==($12|0);
  if (!($24)) {
   $$023$i$i$i = $17;
   while(1) {
    $25 = ((($$023$i$i$i)) + 4|0);
    $26 = HEAP32[$25>>2]|0;
    __ZdlPv($$023$i$i$i);
    $27 = ($26|0)==($12|0);
    if ($27) {
     break;
    } else {
     $$023$i$i$i = $26;
    }
   }
  }
 }
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $28 = __THREW__; __THREW__ = 0;
 $29 = $28&1;
 if ($29) {
  $30 = ___cxa_find_matching_catch_2()|0;
  $31 = tempRet0;
  __ZdlPv($0);
  ___resumeException($30|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZN15EXTQuerySupport10checkQueryEPN3osg5StatsEPNS0_5StateEy($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0 = 0, $$025 = 0, $$sink$i = 0.0, $$sink$i28 = 0.0, $$sroa$043$067 = 0, $$sroa$043$1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0.0, $43 = 0, $44 = 0, $45 = 0.0, $46 = 0.0, $47 = 0;
 var $48 = 0.0, $49 = 0.0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0.0, $74 = 0.0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0.0, $87 = 0, $88 = 0, $89 = 0.0, $9 = 0, $90 = 0.0, $91 = 0, $92 = 0.0, $93 = 0.0, $94 = 0.0, $95 = 0.0, $96 = 0.0, $97 = 0.0, $98 = 0, $99 = 0, dest = 0, label = 0, sp = 0;
 var src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(64|0);
 $5 = sp + 48|0;
 $6 = sp + 44|0;
 $7 = sp;
 $8 = sp + 32|0;
 $9 = sp + 20|0;
 $10 = sp + 8|0;
 $11 = ((($0)) + 20|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ((($0)) + 16|0);
 $14 = $12;
 $15 = ($14|0)==($13|0);
 L1: do {
  if (!($15)) {
   $16 = ((($0)) + 12|0);
   $17 = ((($0)) + 40|0);
   $18 = ((($8)) + 8|0);
   $19 = ((($8)) + 4|0);
   $20 = ((($8)) + 11|0);
   $21 = ((($9)) + 8|0);
   $22 = ((($9)) + 4|0);
   $23 = ((($9)) + 11|0);
   $24 = ((($10)) + 8|0);
   $25 = ((($10)) + 4|0);
   $26 = ((($10)) + 11|0);
   $27 = ((($0)) + 24|0);
   $28 = ((($0)) + 32|0);
   $29 = ((($0)) + 36|0);
   $30 = ((($0)) + 28|0);
   $$sroa$043$067 = $12;$124 = $14;
   while(1) {
    $51 = $$sroa$043$067;
    $52 = ((($51)) + 8|0);
    $53 = HEAP32[$52>>2]|0;
    HEAP32[$5>>2] = $53;
    HEAP32[$6>>2] = 0;
    $54 = HEAP32[$16>>2]|0;
    $55 = ((($54)) + 936|0);
    $56 = HEAP32[$55>>2]|0;
    FUNCTION_TABLE_viii[$56 & 8191]($53,34919,$6);
    $57 = HEAP32[$6>>2]|0;
    $58 = ($57|0)==(0);
    if ($58) {
     $152 = ((($124)) + 4|0);
     $153 = HEAP32[$152>>2]|0;
     $$sroa$043$1 = $153;
    } else {
     $59 = $7;
     $60 = $59;
     HEAP32[$60>>2] = 0;
     $61 = (($59) + 4)|0;
     $62 = $61;
     HEAP32[$62>>2] = 0;
     $63 = HEAP32[$16>>2]|0;
     $64 = ((($63)) + 944|0);
     $65 = HEAP32[$64>>2]|0;
     $66 = HEAP32[$5>>2]|0;
     FUNCTION_TABLE_viii[$65 & 8191]($66,34918,$7);
     $67 = $7;
     $68 = $67;
     $69 = HEAP32[$68>>2]|0;
     $70 = (($67) + 4)|0;
     $71 = $70;
     $72 = HEAP32[$71>>2]|0;
     $73 = (+($69>>>0)) + (4294967296.0*(+($72>>>0)));
     $74 = $73 * 1.0000000000000001E-9;
     $75 = (__ZN3osg5Timer8instanceEv()|0);
     $76 = (__ZN3osg5Timer8instanceEv()|0);
     $77 = (__ZNK3osg5Timer4tickEv($76)|0);
     $78 = tempRet0;
     $79 = ($78>>>0)>($4>>>0);
     $80 = ($77>>>0)>($3>>>0);
     $81 = ($78|0)==($4|0);
     $82 = $81 & $80;
     $83 = $79 | $82;
     if ($83) {
      $84 = (_i64Subtract(($77|0),($78|0),($3|0),($4|0))|0);
      $85 = tempRet0;
      $86 = (+($84>>>0)) + (4294967296.0*(+($85>>>0)));
      $$sink$i28 = $86;
     } else {
      $87 = (_i64Subtract(($3|0),($4|0),($77|0),($78|0))|0);
      $88 = tempRet0;
      $89 = (+($87>>>0)) + (4294967296.0*(+($88>>>0)));
      $90 = -$89;
      $$sink$i28 = $90;
     }
     $91 = ((($75)) + 8|0);
     $92 = +HEAPF64[$91>>3];
     $93 = $$sink$i28 * $92;
     $94 = +HEAPF64[$17>>3];
     $95 = $94 + $93;
     $96 = $95 * 0.5;
     $97 = $96 - $74;
     $98 = ((($51)) + 12|0);
     $99 = HEAP32[$98>>2]|0;
     $100 = (__Znwj(32)|0);
     HEAP32[$8>>2] = $100;
     HEAP32[$18>>2] = -2147483616;
     HEAP32[$19>>2] = 19;
     dest=$100; src=108145; stop=dest+19|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
     $101 = ((($100)) + 19|0);
     HEAP8[$101>>0] = 0;
     __THREW__ = 0;
     (invoke_iiiid(3392,($1|0),($99|0),($8|0),(+$97))|0);
     $102 = __THREW__; __THREW__ = 0;
     $103 = $102&1;
     if ($103) {
      label = 24;
      break;
     }
     $104 = HEAP8[$20>>0]|0;
     $105 = ($104<<24>>24)<(0);
     if ($105) {
      $106 = HEAP32[$8>>2]|0;
      __ZdlPv($106);
     }
     $107 = HEAP32[$98>>2]|0;
     $108 = (__Znwj(32)|0);
     HEAP32[$9>>2] = $108;
     HEAP32[$21>>2] = -2147483616;
     HEAP32[$22>>2] = 17;
     dest=$108; src=108165; stop=dest+17|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
     $109 = ((($108)) + 17|0);
     HEAP8[$109>>0] = 0;
     __THREW__ = 0;
     (invoke_iiiid(3392,($1|0),($107|0),($9|0),(+$96))|0);
     $110 = __THREW__; __THREW__ = 0;
     $111 = $110&1;
     if ($111) {
      label = 27;
      break;
     }
     $112 = HEAP8[$23>>0]|0;
     $113 = ($112<<24>>24)<(0);
     if ($113) {
      $114 = HEAP32[$9>>2]|0;
      __ZdlPv($114);
     }
     $115 = HEAP32[$98>>2]|0;
     $116 = (__Znwj(32)|0);
     HEAP32[$10>>2] = $116;
     HEAP32[$24>>2] = -2147483616;
     HEAP32[$25>>2] = 19;
     dest=$116; src=108183; stop=dest+19|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
     $117 = ((($116)) + 19|0);
     HEAP8[$117>>0] = 0;
     __THREW__ = 0;
     (invoke_iiiid(3392,($1|0),($115|0),($10|0),(+$74))|0);
     $118 = __THREW__; __THREW__ = 0;
     $119 = $118&1;
     if ($119) {
      label = 30;
      break;
     }
     $120 = HEAP8[$26>>0]|0;
     $121 = ($120<<24>>24)<(0);
     if ($121) {
      $122 = HEAP32[$10>>2]|0;
      __ZdlPv($122);
     }
     $123 = ((($124)) + 4|0);
     $125 = HEAP32[$123>>2]|0;
     $126 = HEAP32[$124>>2]|0;
     $127 = ((($126)) + 4|0);
     HEAP32[$127>>2] = $125;
     $128 = HEAP32[$123>>2]|0;
     HEAP32[$128>>2] = $126;
     $129 = HEAP32[$27>>2]|0;
     $130 = (($129) + -1)|0;
     HEAP32[$27>>2] = $130;
     $131 = $$sroa$043$067;
     __ZdlPv($131);
     $132 = HEAP32[$28>>2]|0;
     $133 = HEAP32[$29>>2]|0;
     $134 = ($132|0)==($133|0);
     if ($134) {
      __ZNSt3__26vectorIjNS_9allocatorIjEEE21__push_back_slow_pathIKjEEvRT_($30,$5);
     } else {
      $135 = HEAP32[$5>>2]|0;
      HEAP32[$132>>2] = $135;
      $136 = ((($132)) + 4|0);
      HEAP32[$28>>2] = $136;
     }
     $$sroa$043$1 = $125;
    }
    $154 = $$sroa$043$1;
    $155 = ($154|0)==($13|0);
    if ($155) {
     break L1;
    } else {
     $$sroa$043$067 = $$sroa$043$1;$124 = $154;
    }
   }
   if ((label|0) == 24) {
    $137 = ___cxa_find_matching_catch_2()|0;
    $138 = tempRet0;
    $139 = HEAP8[$20>>0]|0;
    $140 = ($139<<24>>24)<(0);
    if ($140) {
     $141 = HEAP32[$8>>2]|0;
     __ZdlPv($141);
    }
    $$0 = $137;$$025 = $138;
    ___resumeException($$0|0);
    // unreachable;
   }
   else if ((label|0) == 27) {
    $142 = ___cxa_find_matching_catch_2()|0;
    $143 = tempRet0;
    $144 = HEAP8[$23>>0]|0;
    $145 = ($144<<24>>24)<(0);
    if ($145) {
     $146 = HEAP32[$9>>2]|0;
     __ZdlPv($146);
    }
    $$0 = $142;$$025 = $143;
    ___resumeException($$0|0);
    // unreachable;
   }
   else if ((label|0) == 30) {
    $147 = ___cxa_find_matching_catch_2()|0;
    $148 = tempRet0;
    $149 = HEAP8[$26>>0]|0;
    $150 = ($149<<24>>24)<(0);
    if ($150) {
     $151 = HEAP32[$10>>2]|0;
     __ZdlPv($151);
    }
    $$0 = $147;$$025 = $148;
    ___resumeException($$0|0);
    // unreachable;
   }
  }
 } while(0);
 $31 = (__ZN3osg5Timer8instanceEv()|0);
 $32 = (__ZN3osg5Timer8instanceEv()|0);
 $33 = (__ZNK3osg5Timer4tickEv($32)|0);
 $34 = tempRet0;
 $35 = ($34>>>0)>($4>>>0);
 $36 = ($33>>>0)>($3>>>0);
 $37 = ($34|0)==($4|0);
 $38 = $37 & $36;
 $39 = $35 | $38;
 if ($39) {
  $40 = (_i64Subtract(($33|0),($34|0),($3|0),($4|0))|0);
  $41 = tempRet0;
  $42 = (+($40>>>0)) + (4294967296.0*(+($41>>>0)));
  $$sink$i = $42;
  $47 = ((($31)) + 8|0);
  $48 = +HEAPF64[$47>>3];
  $49 = $$sink$i * $48;
  $50 = ((($0)) + 40|0);
  HEAPF64[$50>>3] = $49;
  STACKTOP = sp;return;
 } else {
  $43 = (_i64Subtract(($3|0),($4|0),($33|0),($34|0))|0);
  $44 = tempRet0;
  $45 = (+($43>>>0)) + (4294967296.0*(+($44>>>0)));
  $46 = -$45;
  $$sink$i = $46;
  $47 = ((($31)) + 8|0);
  $48 = +HEAPF64[$47>>3];
  $49 = $$sink$i * $48;
  $50 = ((($0)) + 40|0);
  HEAPF64[$50>>3] = $49;
  STACKTOP = sp;return;
 }
}
function __ZN15EXTQuerySupport10beginQueryEjPN3osg5StateE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$i = 0, $$pre = 0, $$pre$phiZ2D = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = ((($0)) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($0)) + 32|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5|0)==($7|0);
 if ($8) {
  $9 = ((($0)) + 12|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ((($10)) + 904|0);
  $12 = HEAP32[$11>>2]|0;
  FUNCTION_TABLE_vii[$12 & 8191](1,$3);
  $13 = HEAP32[$3>>2]|0;
  $$0$i = $13;$$pre$phiZ2D = $9;
 } else {
  $14 = ((($7)) + -4|0);
  $15 = HEAP32[$14>>2]|0;
  HEAP32[$6>>2] = $14;
  $$pre = ((($0)) + 12|0);
  $$0$i = $15;$$pre$phiZ2D = $$pre;
 }
 $16 = HEAP32[$$pre$phiZ2D>>2]|0;
 $17 = ((($16)) + 908|0);
 $18 = HEAP32[$17>>2]|0;
 FUNCTION_TABLE_vii[$18 & 8191](35007,$$0$i);
 $19 = ((($0)) + 16|0);
 $20 = (__Znwj(16)|0);
 $21 = ((($20)) + 8|0);
 $22 = $21;
 $23 = $22;
 HEAP32[$23>>2] = $$0$i;
 $24 = (($22) + 4)|0;
 $25 = $24;
 HEAP32[$25>>2] = $1;
 $26 = ((($20)) + 4|0);
 HEAP32[$26>>2] = $19;
 $27 = HEAP32[$19>>2]|0;
 HEAP32[$20>>2] = $27;
 $28 = ((($27)) + 4|0);
 HEAP32[$28>>2] = $20;
 HEAP32[$19>>2] = $20;
 $29 = ((($0)) + 24|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($30) + 1)|0;
 HEAP32[$29>>2] = $31;
 STACKTOP = sp;return;
}
function __ZN15EXTQuerySupport8endQueryEPN3osg5StateE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + 912|0);
 $5 = HEAP32[$4>>2]|0;
 FUNCTION_TABLE_vi[$5 & 8191](35007);
 return;
}
function __ZN15EXTQuerySupport10initializeEPN3osg5StateEy($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$sink$i = 0.0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0.0, $19 = 0, $20 = 0, $21 = 0.0, $22 = 0.0, $23 = 0, $24 = 0.0, $25 = 0.0, $26 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ((($1)) + 784|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($0)) + 12|0);
 HEAP32[$6>>2] = $5;
 $7 = (__ZN3osg5Timer8instanceEv()|0);
 $8 = (__ZN3osg5Timer8instanceEv()|0);
 $9 = (__ZNK3osg5Timer4tickEv($8)|0);
 $10 = tempRet0;
 $11 = ($10>>>0)>($3>>>0);
 $12 = ($9>>>0)>($2>>>0);
 $13 = ($10|0)==($3|0);
 $14 = $13 & $12;
 $15 = $11 | $14;
 if ($15) {
  $16 = (_i64Subtract(($9|0),($10|0),($2|0),($3|0))|0);
  $17 = tempRet0;
  $18 = (+($16>>>0)) + (4294967296.0*(+($17>>>0)));
  $$sink$i = $18;
  $23 = ((($7)) + 8|0);
  $24 = +HEAPF64[$23>>3];
  $25 = $$sink$i * $24;
  $26 = ((($0)) + 40|0);
  HEAPF64[$26>>3] = $25;
  return;
 } else {
  $19 = (_i64Subtract(($2|0),($3|0),($9|0),($10|0))|0);
  $20 = tempRet0;
  $21 = (+($19>>>0)) + (4294967296.0*(+($20>>>0)));
  $22 = -$21;
  $$sink$i = $22;
  $23 = ((($7)) + 8|0);
  $24 = +HEAPF64[$23>>3];
  $25 = $$sink$i * $24;
  $26 = ((($0)) + 40|0);
  HEAPF64[$26>>3] = $25;
  return;
 }
}
function __ZN9osgViewer8Renderer7releaseEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $2 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
 do {
  if ($2) {
   $3 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
   $4 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($3,109343,19)|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = ((($5)) + -12|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = (($4) + ($7)|0);
   __ZNKSt3__28ios_base6getlocEv($1,$8);
   __THREW__ = 0;
   $9 = (invoke_iii(3255,($1|0),(215188|0))|0);
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    $12 = HEAP32[$9>>2]|0;
    $13 = ((($12)) + 28|0);
    $14 = HEAP32[$13>>2]|0;
    __THREW__ = 0;
    $15 = (invoke_iii($14|0,($9|0),10)|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if (!($17)) {
     __ZNSt3__26localeD2Ev($1);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($4,$15)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($4)|0);
     break;
    }
   }
   $18 = ___cxa_find_matching_catch_2()|0;
   $19 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($1|0));
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if ($21) {
    $22 = ___cxa_find_matching_catch_3(0|0)|0;
    $23 = tempRet0;
    ___clang_call_terminate($22);
    // unreachable;
   } else {
    ___resumeException($18|0);
    // unreachable;
   }
  }
 } while(0);
 $24 = ((($0)) + 28|0);
 HEAP8[$24>>0] = 1;
 $25 = ((($0)) + 40|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ((($26)) + 8|0);
 $28 = HEAP32[$27>>2]|0;
 (FUNCTION_TABLE_ii[$28 & 8191]($25)|0);
 $29 = ((($0)) + 72|0);
 HEAP8[$29>>0] = 1;
 $30 = ((($0)) + 52|0);
 __THREW__ = 0;
 (invoke_ii(2504,($30|0))|0);
 $31 = __THREW__; __THREW__ = 0;
 $32 = $31&1;
 if ($32) {
  $33 = ___cxa_find_matching_catch_2()|0;
  $34 = tempRet0;
  $35 = HEAP32[$25>>2]|0;
  $36 = ((($35)) + 12|0);
  $37 = HEAP32[$36>>2]|0;
  __THREW__ = 0;
  (invoke_ii($37|0,($25|0))|0);
  $38 = __THREW__; __THREW__ = 0;
  $39 = $38&1;
  if ($39) {
   $40 = ___cxa_find_matching_catch_3(0|0)|0;
   $41 = tempRet0;
   ___clang_call_terminate($40);
   // unreachable;
  } else {
   ___resumeException($33|0);
   // unreachable;
  }
 }
 $42 = HEAP32[$25>>2]|0;
 $43 = ((($42)) + 12|0);
 $44 = HEAP32[$43>>2]|0;
 (FUNCTION_TABLE_ii[$44 & 8191]($25)|0);
 $45 = ((($0)) + 76|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = ((($46)) + 8|0);
 $48 = HEAP32[$47>>2]|0;
 (FUNCTION_TABLE_ii[$48 & 8191]($45)|0);
 $49 = ((($0)) + 108|0);
 HEAP8[$49>>0] = 1;
 $50 = ((($0)) + 88|0);
 __THREW__ = 0;
 (invoke_ii(2504,($50|0))|0);
 $51 = __THREW__; __THREW__ = 0;
 $52 = $51&1;
 if (!($52)) {
  $62 = HEAP32[$45>>2]|0;
  $63 = ((($62)) + 12|0);
  $64 = HEAP32[$63>>2]|0;
  (FUNCTION_TABLE_ii[$64 & 8191]($45)|0);
  STACKTOP = sp;return;
 }
 $53 = ___cxa_find_matching_catch_2()|0;
 $54 = tempRet0;
 $55 = HEAP32[$45>>2]|0;
 $56 = ((($55)) + 12|0);
 $57 = HEAP32[$56>>2]|0;
 __THREW__ = 0;
 (invoke_ii($57|0,($45|0))|0);
 $58 = __THREW__; __THREW__ = 0;
 $59 = $58&1;
 if ($59) {
  $60 = ___cxa_find_matching_catch_3(0|0)|0;
  $61 = tempRet0;
  ___clang_call_terminate($60);
  // unreachable;
 } else {
  ___resumeException($53|0);
  // unreachable;
 }
}
function __ZN9osgViewer8RendererclEPN3osg6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = (___dynamic_cast($1,26112,24816,0)|0);
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = HEAP32[$0>>2]|0;
   $6 = ((($5)) + 16|0);
   $7 = HEAP32[$6>>2]|0;
   FUNCTION_TABLE_vii[$7 & 8191]($0,$3);
  }
 }
 $8 = HEAP32[$1>>2]|0;
 $9 = ((($8)) + 72|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (FUNCTION_TABLE_ii[$10 & 8191]($1)|0);
 $12 = ($11|0)==(0|0);
 if ($12) {
  return;
 }
 $13 = HEAP32[$0>>2]|0;
 $14 = ((($13)) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 FUNCTION_TABLE_vi[$15 & 8191]($0);
 return;
}
function __ZN9osgViewer8RendererD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vii(3502,($0|0),(41864|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  $3 = ((($0)) + 128|0);
  __ZN3osg10ReferencedD2Ev($3);
  return;
 }
 $4 = ___cxa_find_matching_catch_2()|0;
 $5 = tempRet0;
 $6 = ((($0)) + 128|0);
 __THREW__ = 0;
 invoke_vi(712,($6|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch_3(0|0)|0;
  $10 = tempRet0;
  ___clang_call_terminate($9);
  // unreachable;
 } else {
  ___resumeException($4|0);
  // unreachable;
 }
}
function __ZN9osgViewer8RendererD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vii(3502,($0|0),(41864|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $6 = ___cxa_find_matching_catch_2()|0;
  $7 = tempRet0;
  $8 = ((($0)) + 128|0);
  __THREW__ = 0;
  invoke_vi(712,($8|0));
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if ($10) {
   $11 = ___cxa_find_matching_catch_3(0|0)|0;
   $12 = tempRet0;
   ___clang_call_terminate($11);
   // unreachable;
  } else {
   $eh$lpad$body$index2Z2D = $7;$eh$lpad$body$indexZ2D = $6;
   __ZdlPv($0);
   ___resumeException($eh$lpad$body$indexZ2D|0);
   // unreachable;
  }
 }
 $3 = ((($0)) + 128|0);
 __THREW__ = 0;
 invoke_vi(712,($3|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  __ZdlPv($0);
  return;
 }
 $13 = ___cxa_find_matching_catch_2()|0;
 $14 = tempRet0;
 $eh$lpad$body$index2Z2D = $14;$eh$lpad$body$indexZ2D = $13;
 __ZdlPv($0);
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
}
function __ZN9osgViewer8RendererclEPN3osg15GraphicsContextE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 29|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 $5 = HEAP32[$0>>2]|0;
 if ($4) {
  $8 = ((($5)) + 24|0);
  $9 = HEAP32[$8>>2]|0;
  FUNCTION_TABLE_vi[$9 & 8191]($0);
  return;
 } else {
  $6 = ((($5)) + 28|0);
  $7 = HEAP32[$6>>2]|0;
  FUNCTION_TABLE_vi[$7 & 8191]($0);
  return;
 }
}
function __ZN9osgViewer8Renderer4cullEv($0) {
 $0 = $0|0;
 var $$064 = 0, $$065 = 0, $$sink$i = 0.0, $$sink$i84 = 0.0, $$sink$i91 = 0.0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0.0, $192 = 0, $193 = 0, $194 = 0.0, $195 = 0.0, $196 = 0, $197 = 0.0, $198 = 0.0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0;
 var $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0;
 var $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0.0, $227 = 0, $228 = 0, $229 = 0.0, $23 = 0, $230 = 0.0, $231 = 0, $232 = 0.0, $233 = 0.0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0;
 var $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0.0, $255 = 0, $256 = 0;
 var $257 = 0.0, $258 = 0.0, $259 = 0, $26 = 0, $260 = 0.0, $261 = 0.0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0;
 var $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0;
 var $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0;
 var $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0;
 var $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0;
 var $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0;
 var $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, $eh$lpad$body105$index7Z2D = 0, $eh$lpad$body105$indexZ2D = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(80|0);
 $1 = sp + 72|0;
 $2 = sp + 68|0;
 $3 = sp + 64|0;
 $4 = sp + 60|0;
 $5 = sp + 48|0;
 $6 = sp + 36|0;
 $7 = sp + 24|0;
 $8 = sp + 12|0;
 $9 = sp;
 $10 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(5)|0);
 do {
  if ($10) {
   $11 = (__ZN3osg6notifyENS_14NotifySeverityE(5)|0);
   $12 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($11,109302,6)|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = ((($13)) + -12|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (($12) + ($15)|0);
   __ZNKSt3__28ios_base6getlocEv($4,$16);
   __THREW__ = 0;
   $17 = (invoke_iii(3255,($4|0),(215188|0))|0);
   $18 = __THREW__; __THREW__ = 0;
   $19 = $18&1;
   if (!($19)) {
    $20 = HEAP32[$17>>2]|0;
    $21 = ((($20)) + 28|0);
    $22 = HEAP32[$21>>2]|0;
    __THREW__ = 0;
    $23 = (invoke_iii($22|0,($17|0),10)|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     __ZNSt3__26localeD2Ev($4);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($12,$23)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($12)|0);
     break;
    }
   }
   $26 = ___cxa_find_matching_catch_2()|0;
   $27 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($4|0));
   $28 = __THREW__; __THREW__ = 0;
   $29 = $28&1;
   if ($29) {
    $30 = ___cxa_find_matching_catch_3(0|0)|0;
    $31 = tempRet0;
    ___clang_call_terminate($30);
    // unreachable;
   } else {
    ___resumeException($26|0);
    // unreachable;
   }
  }
 } while(0);
 $32 = ((($0)) + 28|0);
 $33 = HEAP8[$32>>0]|0;
 $34 = ($33<<24>>24)==(0);
 if (!($34)) {
  STACKTOP = sp;return;
 }
 $35 = ((($0)) + 29|0);
 $36 = HEAP8[$35>>0]|0;
 $37 = ($36<<24>>24)==(0);
 if (!($37)) {
  STACKTOP = sp;return;
 }
 $38 = ((($0)) + 40|0);
 $39 = (__ZN9osgViewer8Renderer15ThreadSafeQueue9takeFrontEv($38)|0);
 $40 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(5)|0);
 do {
  if ($40) {
   $41 = (__ZN3osg6notifyENS_14NotifySeverityE(5)|0);
   $42 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($41,109309,21)|0);
   $43 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEPKv($42,$39)|0);
   $44 = HEAP32[$43>>2]|0;
   $45 = ((($44)) + -12|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = (($43) + ($46)|0);
   __ZNKSt3__28ios_base6getlocEv($3,$47);
   __THREW__ = 0;
   $48 = (invoke_iii(3255,($3|0),(215188|0))|0);
   $49 = __THREW__; __THREW__ = 0;
   $50 = $49&1;
   if (!($50)) {
    $51 = HEAP32[$48>>2]|0;
    $52 = ((($51)) + 28|0);
    $53 = HEAP32[$52>>2]|0;
    __THREW__ = 0;
    $54 = (invoke_iii($53|0,($48|0),10)|0);
    $55 = __THREW__; __THREW__ = 0;
    $56 = $55&1;
    if (!($56)) {
     __ZNSt3__26localeD2Ev($3);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($43,$54)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($43)|0);
     break;
    }
   }
   $57 = ___cxa_find_matching_catch_2()|0;
   $58 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($3|0));
   $59 = __THREW__; __THREW__ = 0;
   $60 = $59&1;
   if ($60) {
    $61 = ___cxa_find_matching_catch_3(0|0)|0;
    $62 = tempRet0;
    ___clang_call_terminate($61);
    // unreachable;
   } else {
    ___resumeException($57|0);
    // unreachable;
   }
  }
 } while(0);
 $63 = ($39|0)==(0|0);
 do {
  if (!($63)) {
   $64 = HEAP32[$0>>2]|0;
   $65 = ((($64)) + 40|0);
   $66 = HEAP32[$65>>2]|0;
   FUNCTION_TABLE_vii[$66 & 8191]($0,$39);
   $67 = ((($39)) + 204|0);
   $68 = ((($39)) + 208|0);
   $69 = HEAP32[$68>>2]|0;
   $70 = ((($69)) + 220|0);
   $71 = HEAP32[$70>>2]|0;
   $72 = ($71|0)==(0|0);
   if (!($72)) {
    $73 = (___dynamic_cast($71,27072,3928,0)|0);
    $74 = ($73|0)==(0|0);
    if (!($74)) {
     $75 = ((($73)) + 120|0);
     $76 = HEAP32[$75>>2]|0;
     $77 = ((($73)) + 124|0);
     $78 = HEAP32[$77>>2]|0;
     $79 = ((($39)) + 232|0);
     HEAP32[$79>>2] = $76;
     $80 = ((($39)) + 236|0);
     HEAP32[$80>>2] = $78;
    }
   }
   $81 = ((($69)) + 224|0);
   $82 = HEAP32[$81>>2]|0;
   $83 = ((($39)) + 200|0);
   $84 = HEAP32[$83>>2]|0;
   $85 = ($84|0)==(0|0);
   if ($85) {
    $199 = 0;
   } else {
    $86 = ((($84)) + 12|0);
    $87 = HEAP32[$86>>2]|0;
    $199 = $87;
   }
   $88 = (__ZN3osg5Timer8instanceEv()|0);
   $89 = (__ZNK3osg5Timer4tickEv($88)|0);
   $90 = tempRet0;
   $91 = HEAP32[$39>>2]|0;
   $92 = ((($91)) + 164|0);
   $93 = HEAP32[$92>>2]|0;
   $94 = HEAP32[$67>>2]|0;
   $95 = ($94|0)==(0|0);
   if ($95) {
    $101 = 0;
   } else {
    $96 = ((($94)) + 24|0);
    $97 = HEAP32[$96>>2]|0;
    $98 = ($97|0)==(0|0);
    if ($98) {
     $101 = 0;
    } else {
     $99 = HEAP32[$68>>2]|0;
     $101 = $99;
    }
   }
   $100 = ((($101)) + 144|0);
   FUNCTION_TABLE_vii[$93 & 8191]($39,$100);
   $102 = HEAP32[$39>>2]|0;
   $103 = ((($102)) + 180|0);
   $104 = HEAP32[$103>>2]|0;
   FUNCTION_TABLE_vi[$104 & 8191]($39);
   $105 = (__ZN3osg5Timer8instanceEv()|0);
   $106 = (__ZNK3osg5Timer4tickEv($105)|0);
   $107 = tempRet0;
   $108 = ($82|0)==(0|0);
   L40: do {
    if (!($108)) {
     ;HEAP32[$5>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;
     $109 = ((($5)) + 11|0);
     HEAP8[$109>>0] = 9;
     dest=$5; src=108349; stop=dest+9|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
     $110 = ((($5)) + 9|0);
     HEAP8[$110>>0] = 0;
     $111 = ((($82)) + 24|0);
     $112 = HEAP32[$111>>2]|0;
     $113 = ((($112)) + 8|0);
     $114 = HEAP32[$113>>2]|0;
     __THREW__ = 0;
     (invoke_ii($114|0,($111|0))|0);
     $115 = __THREW__; __THREW__ = 0;
     $116 = $115&1;
     do {
      if ($116) {
       label = 44;
      } else {
       $117 = ((($82)) + 68|0);
       __THREW__ = 0;
       $118 = (invoke_iii(3391,($117|0),($5|0))|0);
       $119 = __THREW__; __THREW__ = 0;
       $120 = $119&1;
       if ($120) {
        $131 = ___cxa_find_matching_catch_2()|0;
        $132 = tempRet0;
        $133 = HEAP32[$111>>2]|0;
        $134 = ((($133)) + 12|0);
        $135 = HEAP32[$134>>2]|0;
        __THREW__ = 0;
        (invoke_ii($135|0,($111|0))|0);
        $136 = __THREW__; __THREW__ = 0;
        $137 = $136&1;
        if (!($137)) {
         $eh$lpad$body$index2Z2D = $132;$eh$lpad$body$indexZ2D = $131;
         break;
        }
        $138 = ___cxa_find_matching_catch_3(0|0)|0;
        $139 = tempRet0;
        ___clang_call_terminate($138);
        // unreachable;
       }
       $121 = ((($82)) + 72|0);
       $122 = ($118|0)==($121|0);
       if ($122) {
        $377 = 0;
       } else {
        $123 = ((($118)) + 28|0);
        $124 = HEAP8[$123>>0]|0;
        $125 = ($124<<24>>24)!=(0);
        $377 = $125;
       }
       $126 = HEAP32[$111>>2]|0;
       $127 = ((($126)) + 12|0);
       $128 = HEAP32[$127>>2]|0;
       __THREW__ = 0;
       (invoke_ii($128|0,($111|0))|0);
       $129 = __THREW__; __THREW__ = 0;
       $130 = $129&1;
       if ($130) {
        label = 44;
       } else {
        $140 = HEAP8[$109>>0]|0;
        $141 = ($140<<24>>24)<(0);
        if ($141) {
         $142 = HEAP32[$5>>2]|0;
         __ZdlPv($142);
        }
        L55: do {
         if ($377) {
          $143 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(5)|0);
          L57: do {
           if ($143) {
            $144 = (__ZN3osg6notifyENS_14NotifySeverityE(5)|0);
            $145 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($144,108359,26)|0);
            $146 = HEAP32[$145>>2]|0;
            $147 = ((($146)) + -12|0);
            $148 = HEAP32[$147>>2]|0;
            $149 = (($145) + ($148)|0);
            __ZNKSt3__28ios_base6getlocEv($2,$149);
            __THREW__ = 0;
            $150 = (invoke_iii(3255,($2|0),(215188|0))|0);
            $151 = __THREW__; __THREW__ = 0;
            $152 = $151&1;
            do {
             if (!($152)) {
              $153 = HEAP32[$150>>2]|0;
              $154 = ((($153)) + 28|0);
              $155 = HEAP32[$154>>2]|0;
              __THREW__ = 0;
              $156 = (invoke_iii($155|0,($150|0),10)|0);
              $157 = __THREW__; __THREW__ = 0;
              $158 = $157&1;
              if ($158) {
               break;
              }
              __ZNSt3__26localeD2Ev($2);
              (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($145,$156)|0);
              (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($145)|0);
              break L57;
             }
            } while(0);
            $159 = ___cxa_find_matching_catch_2()|0;
            $160 = tempRet0;
            __THREW__ = 0;
            invoke_vi(3263,($2|0));
            $161 = __THREW__; __THREW__ = 0;
            $162 = $161&1;
            if ($162) {
             $163 = ___cxa_find_matching_catch_3(0|0)|0;
             $164 = tempRet0;
             ___clang_call_terminate($163);
             // unreachable;
            } else {
             ___resumeException($159|0);
             // unreachable;
            }
           }
          } while(0);
          $170 = (__Znwj(32)|0);
          HEAP32[$6>>2] = $170;
          $171 = ((($6)) + 8|0);
          HEAP32[$171>>2] = -2147483616;
          $172 = ((($6)) + 4|0);
          HEAP32[$172>>2] = 25;
          dest=$170; src=108386; stop=dest+25|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
          $173 = ((($170)) + 25|0);
          HEAP8[$173>>0] = 0;
          __THREW__ = 0;
          $174 = (invoke_i(3384)|0);
          $175 = __THREW__; __THREW__ = 0;
          $176 = $175&1;
          do {
           if (!($176)) {
            $177 = ((($0)) + 120|0);
            $178 = $177;
            $179 = $178;
            $180 = HEAP32[$179>>2]|0;
            $181 = (($178) + 4)|0;
            $182 = $181;
            $183 = HEAP32[$182>>2]|0;
            $184 = ($90>>>0)>($183>>>0);
            $185 = ($89>>>0)>($180>>>0);
            $186 = ($90|0)==($183|0);
            $187 = $186 & $185;
            $188 = $184 | $187;
            if ($188) {
             $189 = (_i64Subtract(($89|0),($90|0),($180|0),($183|0))|0);
             $190 = tempRet0;
             $191 = (+($189>>>0)) + (4294967296.0*(+($190>>>0)));
             $$sink$i = $191;
            } else {
             $192 = (_i64Subtract(($180|0),($183|0),($89|0),($90|0))|0);
             $193 = tempRet0;
             $194 = (+($192>>>0)) + (4294967296.0*(+($193>>>0)));
             $195 = -$194;
             $$sink$i = $195;
            }
            $196 = ((($174)) + 8|0);
            $197 = +HEAPF64[$196>>3];
            $198 = $$sink$i * $197;
            __THREW__ = 0;
            (invoke_iiiid(3392,($82|0),($199|0),($6|0),(+$198))|0);
            $200 = __THREW__; __THREW__ = 0;
            $201 = $200&1;
            if ($201) {
             break;
            }
            $202 = ((($6)) + 11|0);
            $203 = HEAP8[$202>>0]|0;
            $204 = ($203<<24>>24)<(0);
            if ($204) {
             $205 = HEAP32[$6>>2]|0;
             __ZdlPv($205);
            }
            $206 = (__Znwj(32)|0);
            HEAP32[$7>>2] = $206;
            $207 = ((($7)) + 8|0);
            HEAP32[$207>>2] = -2147483616;
            $208 = ((($7)) + 4|0);
            HEAP32[$208>>2] = 23;
            dest=$206; src=108412; stop=dest+23|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
            $209 = ((($206)) + 23|0);
            HEAP8[$209>>0] = 0;
            __THREW__ = 0;
            $210 = (invoke_i(3384)|0);
            $211 = __THREW__; __THREW__ = 0;
            $212 = $211&1;
            do {
             if (!($212)) {
              $213 = $177;
              $214 = $213;
              $215 = HEAP32[$214>>2]|0;
              $216 = (($213) + 4)|0;
              $217 = $216;
              $218 = HEAP32[$217>>2]|0;
              $219 = ($107>>>0)>($218>>>0);
              $220 = ($106>>>0)>($215>>>0);
              $221 = ($107|0)==($218|0);
              $222 = $221 & $220;
              $223 = $219 | $222;
              if ($223) {
               $224 = (_i64Subtract(($106|0),($107|0),($215|0),($218|0))|0);
               $225 = tempRet0;
               $226 = (+($224>>>0)) + (4294967296.0*(+($225>>>0)));
               $$sink$i84 = $226;
              } else {
               $227 = (_i64Subtract(($215|0),($218|0),($106|0),($107|0))|0);
               $228 = tempRet0;
               $229 = (+($227>>>0)) + (4294967296.0*(+($228>>>0)));
               $230 = -$229;
               $$sink$i84 = $230;
              }
              $231 = ((($210)) + 8|0);
              $232 = +HEAPF64[$231>>3];
              $233 = $$sink$i84 * $232;
              __THREW__ = 0;
              (invoke_iiiid(3392,($82|0),($199|0),($7|0),(+$233))|0);
              $234 = __THREW__; __THREW__ = 0;
              $235 = $234&1;
              if ($235) {
               break;
              }
              $236 = ((($7)) + 11|0);
              $237 = HEAP8[$236>>0]|0;
              $238 = ($237<<24>>24)<(0);
              if ($238) {
               $239 = HEAP32[$7>>2]|0;
               __ZdlPv($239);
              }
              $240 = (__Znwj(32)|0);
              HEAP32[$8>>2] = $240;
              $241 = ((($8)) + 8|0);
              HEAP32[$241>>2] = -2147483616;
              $242 = ((($8)) + 4|0);
              HEAP32[$242>>2] = 25;
              dest=$240; src=108436; stop=dest+25|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
              $243 = ((($240)) + 25|0);
              HEAP8[$243>>0] = 0;
              __THREW__ = 0;
              $244 = (invoke_i(3384)|0);
              $245 = __THREW__; __THREW__ = 0;
              $246 = $245&1;
              do {
               if (!($246)) {
                $247 = ($107>>>0)>($90>>>0);
                $248 = ($106>>>0)>($89>>>0);
                $249 = ($107|0)==($90|0);
                $250 = $249 & $248;
                $251 = $247 | $250;
                if ($251) {
                 $252 = (_i64Subtract(($106|0),($107|0),($89|0),($90|0))|0);
                 $253 = tempRet0;
                 $254 = (+($252>>>0)) + (4294967296.0*(+($253>>>0)));
                 $$sink$i91 = $254;
                } else {
                 $255 = (_i64Subtract(($89|0),($90|0),($106|0),($107|0))|0);
                 $256 = tempRet0;
                 $257 = (+($255>>>0)) + (4294967296.0*(+($256>>>0)));
                 $258 = -$257;
                 $$sink$i91 = $258;
                }
                $259 = ((($244)) + 8|0);
                $260 = +HEAPF64[$259>>3];
                $261 = $$sink$i91 * $260;
                __THREW__ = 0;
                (invoke_iiiid(3392,($82|0),($199|0),($8|0),(+$261))|0);
                $262 = __THREW__; __THREW__ = 0;
                $263 = $262&1;
                if ($263) {
                 break;
                }
                $264 = ((($8)) + 11|0);
                $265 = HEAP8[$264>>0]|0;
                $266 = ($265<<24>>24)<(0);
                if ($266) {
                 $267 = HEAP32[$8>>2]|0;
                 __ZdlPv($267);
                }
                break L55;
               }
              } while(0);
              $280 = ___cxa_find_matching_catch_2()|0;
              $281 = tempRet0;
              $282 = ((($8)) + 11|0);
              $283 = HEAP8[$282>>0]|0;
              $284 = ($283<<24>>24)<(0);
              if ($284) {
               $285 = HEAP32[$8>>2]|0;
               __ZdlPv($285);
              }
              $$064 = $281;$$065 = $280;
              ___resumeException($$065|0);
              // unreachable;
             }
            } while(0);
            $274 = ___cxa_find_matching_catch_2()|0;
            $275 = tempRet0;
            $276 = ((($7)) + 11|0);
            $277 = HEAP8[$276>>0]|0;
            $278 = ($277<<24>>24)<(0);
            if ($278) {
             $279 = HEAP32[$7>>2]|0;
             __ZdlPv($279);
            }
            $$064 = $275;$$065 = $274;
            ___resumeException($$065|0);
            // unreachable;
           }
          } while(0);
          $268 = ___cxa_find_matching_catch_2()|0;
          $269 = tempRet0;
          $270 = ((($6)) + 11|0);
          $271 = HEAP8[$270>>0]|0;
          $272 = ($271<<24>>24)<(0);
          if ($272) {
           $273 = HEAP32[$6>>2]|0;
           __ZdlPv($273);
          }
          $$064 = $269;$$065 = $268;
          ___resumeException($$065|0);
          // unreachable;
         }
        } while(0);
        ;HEAP32[$9>>2]=0|0;HEAP32[$9+4>>2]=0|0;HEAP32[$9+8>>2]=0|0;
        $286 = ((($9)) + 11|0);
        HEAP8[$286>>0] = 5;
        ;HEAP8[$9>>0]=HEAP8[108343>>0]|0;HEAP8[$9+1>>0]=HEAP8[108343+1>>0]|0;HEAP8[$9+2>>0]=HEAP8[108343+2>>0]|0;HEAP8[$9+3>>0]=HEAP8[108343+3>>0]|0;HEAP8[$9+4>>0]=HEAP8[108343+4>>0]|0;
        $287 = ((($9)) + 5|0);
        HEAP8[$287>>0] = 0;
        $288 = HEAP32[$111>>2]|0;
        $289 = ((($288)) + 8|0);
        $290 = HEAP32[$289>>2]|0;
        __THREW__ = 0;
        (invoke_ii($290|0,($111|0))|0);
        $291 = __THREW__; __THREW__ = 0;
        $292 = $291&1;
        do {
         if ($292) {
          label = 90;
         } else {
          __THREW__ = 0;
          $293 = (invoke_iii(3391,($117|0),($9|0))|0);
          $294 = __THREW__; __THREW__ = 0;
          $295 = $294&1;
          if ($295) {
           $305 = ___cxa_find_matching_catch_2()|0;
           $306 = tempRet0;
           $307 = HEAP32[$111>>2]|0;
           $308 = ((($307)) + 12|0);
           $309 = HEAP32[$308>>2]|0;
           __THREW__ = 0;
           (invoke_ii($309|0,($111|0))|0);
           $310 = __THREW__; __THREW__ = 0;
           $311 = $310&1;
           if (!($311)) {
            $eh$lpad$body105$index7Z2D = $306;$eh$lpad$body105$indexZ2D = $305;
            break;
           }
           $312 = ___cxa_find_matching_catch_3(0|0)|0;
           $313 = tempRet0;
           ___clang_call_terminate($312);
           // unreachable;
          }
          $296 = ($293|0)==($121|0);
          if ($296) {
           $378 = 0;
          } else {
           $297 = ((($293)) + 28|0);
           $298 = HEAP8[$297>>0]|0;
           $299 = ($298<<24>>24)!=(0);
           $378 = $299;
          }
          $300 = HEAP32[$111>>2]|0;
          $301 = ((($300)) + 12|0);
          $302 = HEAP32[$301>>2]|0;
          __THREW__ = 0;
          (invoke_ii($302|0,($111|0))|0);
          $303 = __THREW__; __THREW__ = 0;
          $304 = $303&1;
          if ($304) {
           label = 90;
           break;
          }
          $314 = HEAP8[$286>>0]|0;
          $315 = ($314<<24>>24)<(0);
          if ($315) {
           $316 = HEAP32[$9>>2]|0;
           __ZdlPv($316);
          }
          if (!($378)) {
           break L40;
          }
          __ZL21collectSceneViewStatsjPN7osgUtil9SceneViewEPN3osg5StatsE($199,$39,$82);
          break L40;
         }
        } while(0);
        if ((label|0) == 90) {
         $317 = ___cxa_find_matching_catch_2()|0;
         $318 = tempRet0;
         $eh$lpad$body105$index7Z2D = $318;$eh$lpad$body105$indexZ2D = $317;
        }
        $319 = HEAP8[$286>>0]|0;
        $320 = ($319<<24>>24)<(0);
        if ($320) {
         $321 = HEAP32[$9>>2]|0;
         __ZdlPv($321);
        }
        $$064 = $eh$lpad$body105$index7Z2D;$$065 = $eh$lpad$body105$indexZ2D;
        ___resumeException($$065|0);
        // unreachable;
       }
      }
     } while(0);
     if ((label|0) == 44) {
      $165 = ___cxa_find_matching_catch_2()|0;
      $166 = tempRet0;
      $eh$lpad$body$index2Z2D = $166;$eh$lpad$body$indexZ2D = $165;
     }
     $167 = HEAP8[$109>>0]|0;
     $168 = ($167<<24>>24)<(0);
     if ($168) {
      $169 = HEAP32[$5>>2]|0;
      __ZdlPv($169);
     }
     $$064 = $eh$lpad$body$index2Z2D;$$065 = $eh$lpad$body$indexZ2D;
     ___resumeException($$065|0);
     // unreachable;
    }
   } while(0);
   $322 = ((($0)) + 76|0);
   $323 = HEAP32[$322>>2]|0;
   $324 = ((($323)) + 8|0);
   $325 = HEAP32[$324>>2]|0;
   (FUNCTION_TABLE_ii[$325 & 8191]($322)|0);
   $326 = ((($0)) + 96|0);
   __THREW__ = 0;
   $327 = (invoke_ii(3276,12)|0);
   $328 = __THREW__; __THREW__ = 0;
   $329 = $328&1;
   if (!($329)) {
    $330 = $39;
    $331 = ((($327)) + 8|0);
    HEAP32[$331>>2] = $330;
    $332 = ((($327)) + 4|0);
    HEAP32[$332>>2] = $326;
    $333 = HEAP32[$326>>2]|0;
    HEAP32[$327>>2] = $333;
    $334 = ((($333)) + 4|0);
    HEAP32[$334>>2] = $327;
    HEAP32[$326>>2] = $327;
    $335 = ((($0)) + 104|0);
    $336 = HEAP32[$335>>2]|0;
    $337 = (($336) + 1)|0;
    HEAP32[$335>>2] = $337;
    $338 = ((($0)) + 108|0);
    HEAP8[$338>>0] = 1;
    $339 = ((($0)) + 88|0);
    __THREW__ = 0;
    (invoke_ii(2504,($339|0))|0);
    $340 = __THREW__; __THREW__ = 0;
    $341 = $340&1;
    if (!($341)) {
     $351 = HEAP32[$322>>2]|0;
     $352 = ((($351)) + 12|0);
     $353 = HEAP32[$352>>2]|0;
     (FUNCTION_TABLE_ii[$353 & 8191]($322)|0);
     break;
    }
   }
   $342 = ___cxa_find_matching_catch_2()|0;
   $343 = tempRet0;
   $344 = HEAP32[$322>>2]|0;
   $345 = ((($344)) + 12|0);
   $346 = HEAP32[$345>>2]|0;
   __THREW__ = 0;
   (invoke_ii($346|0,($322|0))|0);
   $347 = __THREW__; __THREW__ = 0;
   $348 = $347&1;
   if ($348) {
    $349 = ___cxa_find_matching_catch_3(0|0)|0;
    $350 = tempRet0;
    ___clang_call_terminate($349);
    // unreachable;
   } else {
    ___resumeException($342|0);
    // unreachable;
   }
  }
 } while(0);
 $354 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(5)|0);
 if (!($354)) {
  STACKTOP = sp;return;
 }
 $355 = (__ZN3osg6notifyENS_14NotifySeverityE(5)|0);
 $356 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($355,109331,11)|0);
 $357 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEPKv($356,$0)|0);
 $358 = HEAP32[$357>>2]|0;
 $359 = ((($358)) + -12|0);
 $360 = HEAP32[$359>>2]|0;
 $361 = (($357) + ($360)|0);
 __ZNKSt3__28ios_base6getlocEv($1,$361);
 __THREW__ = 0;
 $362 = (invoke_iii(3255,($1|0),(215188|0))|0);
 $363 = __THREW__; __THREW__ = 0;
 $364 = $363&1;
 if (!($364)) {
  $365 = HEAP32[$362>>2]|0;
  $366 = ((($365)) + 28|0);
  $367 = HEAP32[$366>>2]|0;
  __THREW__ = 0;
  $368 = (invoke_iii($367|0,($362|0),10)|0);
  $369 = __THREW__; __THREW__ = 0;
  $370 = $369&1;
  if (!($370)) {
   __ZNSt3__26localeD2Ev($1);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($357,$368)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($357)|0);
   STACKTOP = sp;return;
  }
 }
 $371 = ___cxa_find_matching_catch_2()|0;
 $372 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($1|0));
 $373 = __THREW__; __THREW__ = 0;
 $374 = $373&1;
 if ($374) {
  $375 = ___cxa_find_matching_catch_3(0|0)|0;
  $376 = tempRet0;
  ___clang_call_terminate($375);
  // unreachable;
 } else {
  ___resumeException($371|0);
  // unreachable;
 }
}
function __ZN9osgViewer8Renderer4drawEv($0) {
 $0 = $0|0;
 var $$2 = 0, $$275 = 0, $$sink$i = 0.0, $$sink$i107 = 0.0, $$sink$i114 = 0.0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0;
 var $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0;
 var $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0;
 var $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0;
 var $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0;
 var $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0;
 var $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0;
 var $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0;
 var $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0;
 var $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0.0, $359 = 0, $36 = 0, $360 = 0, $361 = 0.0, $362 = 0.0, $363 = 0, $364 = 0.0;
 var $365 = 0.0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0;
 var $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0.0, $393 = 0, $394 = 0, $395 = 0.0, $396 = 0.0, $397 = 0, $398 = 0.0, $399 = 0.0, $4 = 0, $40 = 0;
 var $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0;
 var $419 = 0, $42 = 0, $420 = 0.0, $421 = 0, $422 = 0, $423 = 0.0, $424 = 0.0, $425 = 0, $426 = 0.0, $427 = 0.0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0;
 var $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0;
 var $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0;
 var $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, $eh$lpad$body95$index7Z2D = 0, $eh$lpad$body95$indexZ2D = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(80|0);
 $1 = sp + 76|0;
 $2 = sp + 72|0;
 $3 = sp + 68|0;
 $4 = sp + 64|0;
 $5 = sp + 60|0;
 $6 = sp + 48|0;
 $7 = sp + 36|0;
 $8 = sp + 24|0;
 $9 = sp + 12|0;
 $10 = sp;
 $11 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(5)|0);
 do {
  if ($11) {
   $12 = (__ZN3osg6notifyENS_14NotifySeverityE(5)|0);
   $13 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($12,109138,7)|0);
   $14 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEPKv($13,$0)|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = ((($15)) + -12|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (($14) + ($17)|0);
   __ZNKSt3__28ios_base6getlocEv($5,$18);
   __THREW__ = 0;
   $19 = (invoke_iii(3255,($5|0),(215188|0))|0);
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if (!($21)) {
    $22 = HEAP32[$19>>2]|0;
    $23 = ((($22)) + 28|0);
    $24 = HEAP32[$23>>2]|0;
    __THREW__ = 0;
    $25 = (invoke_iii($24|0,($19|0),10)|0);
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if (!($27)) {
     __ZNSt3__26localeD2Ev($5);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($14,$25)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($14)|0);
     break;
    }
   }
   $28 = ___cxa_find_matching_catch_2()|0;
   $29 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($5|0));
   $30 = __THREW__; __THREW__ = 0;
   $31 = $30&1;
   if ($31) {
    $32 = ___cxa_find_matching_catch_3(0|0)|0;
    $33 = tempRet0;
    ___clang_call_terminate($32);
    // unreachable;
   } else {
    ___resumeException($28|0);
    // unreachable;
   }
  }
 } while(0);
 $34 = ((($0)) + 76|0);
 $35 = (__ZN9osgViewer8Renderer15ThreadSafeQueue9takeFrontEv($34)|0);
 $36 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(5)|0);
 do {
  if ($36) {
   $37 = (__ZN3osg6notifyENS_14NotifySeverityE(5)|0);
   $38 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($37,109146,21)|0);
   $39 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEPKv($38,$35)|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = ((($40)) + -12|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = (($39) + ($42)|0);
   __ZNKSt3__28ios_base6getlocEv($4,$43);
   __THREW__ = 0;
   $44 = (invoke_iii(3255,($4|0),(215188|0))|0);
   $45 = __THREW__; __THREW__ = 0;
   $46 = $45&1;
   if (!($46)) {
    $47 = HEAP32[$44>>2]|0;
    $48 = ((($47)) + 28|0);
    $49 = HEAP32[$48>>2]|0;
    __THREW__ = 0;
    $50 = (invoke_iii($49|0,($44|0),10)|0);
    $51 = __THREW__; __THREW__ = 0;
    $52 = $51&1;
    if (!($52)) {
     __ZNSt3__26localeD2Ev($4);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($39,$50)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($39)|0);
     break;
    }
   }
   $53 = ___cxa_find_matching_catch_2()|0;
   $54 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($4|0));
   $55 = __THREW__; __THREW__ = 0;
   $56 = $55&1;
   if ($56) {
    $57 = ___cxa_find_matching_catch_3(0|0)|0;
    $58 = tempRet0;
    ___clang_call_terminate($57);
    // unreachable;
   } else {
    ___resumeException($53|0);
    // unreachable;
   }
  }
 } while(0);
 $59 = ($35|0)==(0|0);
 do {
  if (!($59)) {
   $60 = ((($0)) + 28|0);
   $61 = HEAP8[$60>>0]|0;
   $62 = ($61<<24>>24)==(0);
   if ($62) {
    __ZN7osgUtil9SceneView35collateReferencesToDependentCamerasEv($35);
    $63 = ((($0)) + 30|0);
    $64 = HEAP8[$63>>0]|0;
    $65 = ($64<<24>>24)==(0);
    if (!($65)) {
     $66 = HEAP32[$0>>2]|0;
     $67 = ((($66)) + 32|0);
     $68 = HEAP32[$67>>2]|0;
     FUNCTION_TABLE_vi[$68 & 8191]($0);
    }
    $69 = HEAP8[$60>>0]|0;
    $70 = ($69<<24>>24)==(0);
    if (!($70)) {
     $71 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
     if (!($71)) {
      STACKTOP = sp;return;
     }
     $72 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
     $73 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($72,109168,40)|0);
     $74 = HEAP32[$73>>2]|0;
     $75 = ((($74)) + -12|0);
     $76 = HEAP32[$75>>2]|0;
     $77 = (($73) + ($76)|0);
     __ZNKSt3__28ios_base6getlocEv($3,$77);
     __THREW__ = 0;
     $78 = (invoke_iii(3255,($3|0),(215188|0))|0);
     $79 = __THREW__; __THREW__ = 0;
     $80 = $79&1;
     if (!($80)) {
      $81 = HEAP32[$78>>2]|0;
      $82 = ((($81)) + 28|0);
      $83 = HEAP32[$82>>2]|0;
      __THREW__ = 0;
      $84 = (invoke_iii($83|0,($78|0),10)|0);
      $85 = __THREW__; __THREW__ = 0;
      $86 = $85&1;
      if (!($86)) {
       __ZNSt3__26localeD2Ev($3);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($73,$84)|0);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($73)|0);
       STACKTOP = sp;return;
      }
     }
     $87 = ___cxa_find_matching_catch_2()|0;
     $88 = tempRet0;
     __THREW__ = 0;
     invoke_vi(3263,($3|0));
     $89 = __THREW__; __THREW__ = 0;
     $90 = $89&1;
     if ($90) {
      $91 = ___cxa_find_matching_catch_3(0|0)|0;
      $92 = tempRet0;
      ___clang_call_terminate($91);
      // unreachable;
     } else {
      ___resumeException($87|0);
      // unreachable;
     }
    }
    $93 = ((($0)) + 29|0);
    $94 = HEAP8[$93>>0]|0;
    $95 = ($94<<24>>24)==(0);
    if (!($95)) {
     $96 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
     if (!($96)) {
      STACKTOP = sp;return;
     }
     $97 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
     $98 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($97,109209,80)|0);
     $99 = HEAP32[$98>>2]|0;
     $100 = ((($99)) + -12|0);
     $101 = HEAP32[$100>>2]|0;
     $102 = (($98) + ($101)|0);
     __ZNKSt3__28ios_base6getlocEv($2,$102);
     __THREW__ = 0;
     $103 = (invoke_iii(3255,($2|0),(215188|0))|0);
     $104 = __THREW__; __THREW__ = 0;
     $105 = $104&1;
     if (!($105)) {
      $106 = HEAP32[$103>>2]|0;
      $107 = ((($106)) + 28|0);
      $108 = HEAP32[$107>>2]|0;
      __THREW__ = 0;
      $109 = (invoke_iii($108|0,($103|0),10)|0);
      $110 = __THREW__; __THREW__ = 0;
      $111 = $110&1;
      if (!($111)) {
       __ZNSt3__26localeD2Ev($2);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($98,$109)|0);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($98)|0);
       STACKTOP = sp;return;
      }
     }
     $112 = ___cxa_find_matching_catch_2()|0;
     $113 = tempRet0;
     __THREW__ = 0;
     invoke_vi(3263,($2|0));
     $114 = __THREW__; __THREW__ = 0;
     $115 = $114&1;
     if ($115) {
      $116 = ___cxa_find_matching_catch_3(0|0)|0;
      $117 = tempRet0;
      ___clang_call_terminate($116);
      // unreachable;
     } else {
      ___resumeException($112|0);
      // unreachable;
     }
    }
    $118 = ((($35)) + 208|0);
    $119 = HEAP32[$118>>2]|0;
    $120 = ((($119)) + 224|0);
    $121 = HEAP32[$120>>2]|0;
    $122 = ((($35)) + 100|0);
    $123 = HEAP32[$122>>2]|0;
    $124 = ((($35)) + 200|0);
    $125 = HEAP32[$124>>2]|0;
    $126 = ((($125)) + 12|0);
    $127 = HEAP32[$126>>2]|0;
    $128 = ((($0)) + 112|0);
    $129 = HEAP8[$128>>0]|0;
    $130 = ($129<<24>>24)==(0);
    if ($130) {
     __ZN9osgViewer8Renderer10initializeEPN3osg5StateE($0,$123);
    }
    $131 = ((($35)) + 284|0);
    $132 = HEAP32[$131>>2]|0;
    $133 = ((($123)) + 788|0);
    $134 = HEAP32[$133>>2]|0;
    $135 = ($134|0)==($132|0);
    if (!($135)) {
     HEAP32[$133>>2] = $132;
    }
    $136 = ($132|0)==(0);
    if ($136) {
     $137 = ((($123)) + 792|0);
     $138 = HEAP32[$137>>2]|0;
     $139 = ($138|0)==(0|0);
     if (!($139)) {
      $140 = HEAP32[$138>>2]|0;
      $141 = ((($140)) + 12|0);
      $142 = HEAP32[$141>>2]|0;
      FUNCTION_TABLE_vii[$142 & 8191]($138,$123);
     }
    }
    $143 = ($121|0)!=(0|0);
    L65: do {
     if ($143) {
      $144 = ((($0)) + 116|0);
      $145 = HEAP32[$144>>2]|0;
      $146 = ($145|0)==(0|0);
      if ($146) {
       $482 = 0;
      } else {
       $147 = ((($6)) + 4|0);
       $148 = $147;
       $149 = $148;
       HEAP32[$149>>2] = 0;
       $150 = (($148) + 4)|0;
       $151 = $150;
       HEAP32[$151>>2] = 0;
       $152 = ((($6)) + 11|0);
       HEAP8[$152>>0] = 3;
       ;HEAP8[$6>>0]=HEAP8[108339>>0]|0;HEAP8[$6+1>>0]=HEAP8[108339+1>>0]|0;HEAP8[$6+2>>0]=HEAP8[108339+2>>0]|0;
       $153 = ((($6)) + 3|0);
       HEAP8[$153>>0] = 0;
       $154 = ((($121)) + 24|0);
       $155 = HEAP32[$154>>2]|0;
       $156 = ((($155)) + 8|0);
       $157 = HEAP32[$156>>2]|0;
       __THREW__ = 0;
       (invoke_ii($157|0,($154|0))|0);
       $158 = __THREW__; __THREW__ = 0;
       $159 = $158&1;
       do {
        if ($159) {
         label = 55;
        } else {
         $160 = ((($121)) + 68|0);
         __THREW__ = 0;
         $161 = (invoke_iii(3391,($160|0),($6|0))|0);
         $162 = __THREW__; __THREW__ = 0;
         $163 = $162&1;
         if ($163) {
          $174 = ___cxa_find_matching_catch_2()|0;
          $175 = tempRet0;
          $176 = HEAP32[$154>>2]|0;
          $177 = ((($176)) + 12|0);
          $178 = HEAP32[$177>>2]|0;
          __THREW__ = 0;
          (invoke_ii($178|0,($154|0))|0);
          $179 = __THREW__; __THREW__ = 0;
          $180 = $179&1;
          if (!($180)) {
           $eh$lpad$body$index2Z2D = $175;$eh$lpad$body$indexZ2D = $174;
           break;
          }
          $181 = ___cxa_find_matching_catch_3(0|0)|0;
          $182 = tempRet0;
          ___clang_call_terminate($181);
          // unreachable;
         }
         $164 = ((($121)) + 72|0);
         $165 = ($161|0)==($164|0);
         if ($165) {
          $483 = 0;
         } else {
          $166 = ((($161)) + 28|0);
          $167 = HEAP8[$166>>0]|0;
          $168 = ($167<<24>>24)!=(0);
          $483 = $168;
         }
         $169 = HEAP32[$154>>2]|0;
         $170 = ((($169)) + 12|0);
         $171 = HEAP32[$170>>2]|0;
         __THREW__ = 0;
         (invoke_ii($171|0,($154|0))|0);
         $172 = __THREW__; __THREW__ = 0;
         $173 = $172&1;
         if ($173) {
          label = 55;
         } else {
          $183 = HEAP8[$152>>0]|0;
          $184 = ($183<<24>>24)<(0);
          if ($184) {
           $185 = HEAP32[$6>>2]|0;
           __ZdlPv($185);
          }
          if (!($483)) {
           $482 = 0;
           break L65;
          }
          $186 = HEAP32[$144>>2]|0;
          $187 = HEAP32[$186>>2]|0;
          $188 = ((($187)) + 12|0);
          $189 = HEAP32[$188>>2]|0;
          $190 = ((($0)) + 120|0);
          $191 = $190;
          $192 = $191;
          $193 = HEAP32[$192>>2]|0;
          $194 = (($191) + 4)|0;
          $195 = $194;
          $196 = HEAP32[$195>>2]|0;
          FUNCTION_TABLE_viiiii[$189 & 8191]($186,$121,$123,$193,$196);
          $197 = HEAP32[$144>>2]|0;
          $198 = HEAP32[$197>>2]|0;
          $199 = ((($198)) + 12|0);
          $200 = HEAP32[$199>>2]|0;
          $201 = $190;
          $202 = $201;
          $203 = HEAP32[$202>>2]|0;
          $204 = (($201) + 4)|0;
          $205 = $204;
          $206 = HEAP32[$205>>2]|0;
          FUNCTION_TABLE_viiiii[$200 & 8191]($197,$121,$123,$203,$206);
          $207 = HEAP32[$144>>2]|0;
          $208 = HEAP32[$207>>2]|0;
          $209 = ((($208)) + 16|0);
          $210 = HEAP32[$209>>2]|0;
          FUNCTION_TABLE_viii[$210 & 8191]($207,$127,$123);
          $482 = 1;
          break L65;
         }
        }
       } while(0);
       if ((label|0) == 55) {
        $211 = ___cxa_find_matching_catch_2()|0;
        $212 = tempRet0;
        $eh$lpad$body$index2Z2D = $212;$eh$lpad$body$indexZ2D = $211;
       }
       $213 = HEAP8[$152>>0]|0;
       $214 = ($213<<24>>24)<(0);
       if ($214) {
        $215 = HEAP32[$6>>2]|0;
        __ZdlPv($215);
       }
       $$2 = $eh$lpad$body$index2Z2D;$$275 = $eh$lpad$body$indexZ2D;
       ___resumeException($$275|0);
       // unreachable;
      }
     } else {
      $482 = 0;
     }
    } while(0);
    $216 = ((($0)) + 31|0);
    $217 = HEAP8[$216>>0]|0;
    $218 = ($217<<24>>24)==(0);
    do {
     if ($218) {
      $244 = (__ZN3osg5Timer8instanceEv()|0);
      $245 = (__ZNK3osg5Timer4tickEv($244)|0);
      $246 = tempRet0;
      $247 = HEAP32[$35>>2]|0;
      $248 = ((($247)) + 184|0);
      $249 = HEAP32[$248>>2]|0;
      FUNCTION_TABLE_vi[$249 & 8191]($35);
      $349 = $246;$351 = $245;
     } else {
      $219 = HEAP32[51948]|0;
      $220 = ((($219)) + 8|0);
      $221 = HEAP32[$220>>2]|0;
      (FUNCTION_TABLE_ii[$221 & 8191](207792)|0);
      __THREW__ = 0;
      $222 = (invoke_i(3384)|0);
      $223 = __THREW__; __THREW__ = 0;
      $224 = $223&1;
      if (!($224)) {
       __THREW__ = 0;
       $225 = (invoke_ii(3385,($222|0))|0);
       $226 = tempRet0;
       $227 = __THREW__; __THREW__ = 0;
       $228 = $227&1;
       if (!($228)) {
        $229 = HEAP32[$35>>2]|0;
        $230 = ((($229)) + 184|0);
        $231 = HEAP32[$230>>2]|0;
        __THREW__ = 0;
        invoke_vi($231|0,($35|0));
        $232 = __THREW__; __THREW__ = 0;
        $233 = $232&1;
        if (!($233)) {
         $234 = HEAP32[51948]|0;
         $235 = ((($234)) + 12|0);
         $236 = HEAP32[$235>>2]|0;
         (FUNCTION_TABLE_ii[$236 & 8191](207792)|0);
         $349 = $226;$351 = $225;
         break;
        }
       }
      }
      $237 = ___cxa_find_matching_catch_2()|0;
      $238 = tempRet0;
      $239 = HEAP32[51948]|0;
      $240 = ((($239)) + 12|0);
      $241 = HEAP32[$240>>2]|0;
      __THREW__ = 0;
      (invoke_ii($241|0,(207792|0))|0);
      $242 = __THREW__; __THREW__ = 0;
      $243 = $242&1;
      if ($243) {
       $480 = ___cxa_find_matching_catch_3(0|0)|0;
       $481 = tempRet0;
       ___clang_call_terminate($480);
       // unreachable;
      }
      $$2 = $238;$$275 = $237;
      ___resumeException($$275|0);
      // unreachable;
     }
    } while(0);
    $250 = ((($0)) + 40|0);
    $251 = HEAP32[$250>>2]|0;
    $252 = ((($251)) + 8|0);
    $253 = HEAP32[$252>>2]|0;
    (FUNCTION_TABLE_ii[$253 & 8191]($250)|0);
    $254 = ((($0)) + 60|0);
    __THREW__ = 0;
    $255 = (invoke_ii(3276,12)|0);
    $256 = __THREW__; __THREW__ = 0;
    $257 = $256&1;
    if (!($257)) {
     $258 = $35;
     $259 = ((($255)) + 8|0);
     HEAP32[$259>>2] = $258;
     $260 = ((($255)) + 4|0);
     HEAP32[$260>>2] = $254;
     $261 = HEAP32[$254>>2]|0;
     HEAP32[$255>>2] = $261;
     $262 = ((($261)) + 4|0);
     HEAP32[$262>>2] = $255;
     HEAP32[$254>>2] = $255;
     $263 = ((($0)) + 68|0);
     $264 = HEAP32[$263>>2]|0;
     $265 = (($264) + 1)|0;
     HEAP32[$263>>2] = $265;
     $266 = ((($0)) + 72|0);
     HEAP8[$266>>0] = 1;
     $267 = ((($0)) + 52|0);
     __THREW__ = 0;
     (invoke_ii(2504,($267|0))|0);
     $268 = __THREW__; __THREW__ = 0;
     $269 = $268&1;
     if (!($269)) {
      $279 = HEAP32[$250>>2]|0;
      $280 = ((($279)) + 12|0);
      $281 = HEAP32[$280>>2]|0;
      (FUNCTION_TABLE_ii[$281 & 8191]($250)|0);
      if ($482) {
       $282 = ((($0)) + 116|0);
       $283 = HEAP32[$282>>2]|0;
       $284 = HEAP32[$283>>2]|0;
       $285 = ((($284)) + 20|0);
       $286 = HEAP32[$285>>2]|0;
       FUNCTION_TABLE_vii[$286 & 8191]($283,$123);
       $287 = HEAP32[$282>>2]|0;
       $288 = HEAP32[$287>>2]|0;
       $289 = ((($288)) + 12|0);
       $290 = HEAP32[$289>>2]|0;
       $291 = ((($0)) + 120|0);
       $292 = $291;
       $293 = $292;
       $294 = HEAP32[$293>>2]|0;
       $295 = (($292) + 4)|0;
       $296 = $295;
       $297 = HEAP32[$296>>2]|0;
       FUNCTION_TABLE_viiiii[$290 & 8191]($287,$121,$123,$294,$297);
      }
      $298 = (__ZN3osg5Timer8instanceEv()|0);
      $299 = (__ZNK3osg5Timer4tickEv($298)|0);
      $300 = tempRet0;
      L109: do {
       if ($143) {
        ;HEAP32[$7>>2]=0|0;HEAP32[$7+4>>2]=0|0;HEAP32[$7+8>>2]=0|0;
        $301 = ((($7)) + 11|0);
        HEAP8[$301>>0] = 9;
        dest=$7; src=108349; stop=dest+9|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
        $302 = ((($7)) + 9|0);
        HEAP8[$302>>0] = 0;
        $303 = ((($121)) + 24|0);
        $304 = HEAP32[$303>>2]|0;
        $305 = ((($304)) + 8|0);
        $306 = HEAP32[$305>>2]|0;
        __THREW__ = 0;
        (invoke_ii($306|0,($303|0))|0);
        $307 = __THREW__; __THREW__ = 0;
        $308 = $307&1;
        do {
         if ($308) {
          label = 107;
         } else {
          $309 = ((($121)) + 68|0);
          __THREW__ = 0;
          $310 = (invoke_iii(3391,($309|0),($7|0))|0);
          $311 = __THREW__; __THREW__ = 0;
          $312 = $311&1;
          if ($312) {
           $323 = ___cxa_find_matching_catch_2()|0;
           $324 = tempRet0;
           $325 = HEAP32[$303>>2]|0;
           $326 = ((($325)) + 12|0);
           $327 = HEAP32[$326>>2]|0;
           __THREW__ = 0;
           (invoke_ii($327|0,($303|0))|0);
           $328 = __THREW__; __THREW__ = 0;
           $329 = $328&1;
           if (!($329)) {
            $eh$lpad$body95$index7Z2D = $324;$eh$lpad$body95$indexZ2D = $323;
            break;
           }
           $330 = ___cxa_find_matching_catch_3(0|0)|0;
           $331 = tempRet0;
           ___clang_call_terminate($330);
           // unreachable;
          }
          $313 = ((($121)) + 72|0);
          $314 = ($310|0)==($313|0);
          if ($314) {
           $484 = 0;
          } else {
           $315 = ((($310)) + 28|0);
           $316 = HEAP8[$315>>0]|0;
           $317 = ($316<<24>>24)!=(0);
           $484 = $317;
          }
          $318 = HEAP32[$303>>2]|0;
          $319 = ((($318)) + 12|0);
          $320 = HEAP32[$319>>2]|0;
          __THREW__ = 0;
          (invoke_ii($320|0,($303|0))|0);
          $321 = __THREW__; __THREW__ = 0;
          $322 = $321&1;
          if ($322) {
           label = 107;
           break;
          }
          $332 = HEAP8[$301>>0]|0;
          $333 = ($332<<24>>24)<(0);
          if ($333) {
           $334 = HEAP32[$7>>2]|0;
           __ZdlPv($334);
          }
          if (!($484)) {
           break L109;
          }
          $335 = (__Znwj(32)|0);
          HEAP32[$8>>2] = $335;
          $336 = ((($8)) + 8|0);
          HEAP32[$336>>2] = -2147483616;
          $337 = ((($8)) + 4|0);
          HEAP32[$337>>2] = 25;
          dest=$335; src=108462; stop=dest+25|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
          $338 = ((($335)) + 25|0);
          HEAP8[$338>>0] = 0;
          __THREW__ = 0;
          $339 = (invoke_i(3384)|0);
          $340 = __THREW__; __THREW__ = 0;
          $341 = $340&1;
          do {
           if (!($341)) {
            $342 = ((($0)) + 120|0);
            $343 = $342;
            $344 = $343;
            $345 = HEAP32[$344>>2]|0;
            $346 = (($343) + 4)|0;
            $347 = $346;
            $348 = HEAP32[$347>>2]|0;
            $350 = ($349>>>0)>($348>>>0);
            $352 = ($351>>>0)>($345>>>0);
            $353 = ($349|0)==($348|0);
            $354 = $353 & $352;
            $355 = $350 | $354;
            if ($355) {
             $356 = (_i64Subtract(($351|0),($349|0),($345|0),($348|0))|0);
             $357 = tempRet0;
             $358 = (+($356>>>0)) + (4294967296.0*(+($357>>>0)));
             $$sink$i = $358;
            } else {
             $359 = (_i64Subtract(($345|0),($348|0),($351|0),($349|0))|0);
             $360 = tempRet0;
             $361 = (+($359>>>0)) + (4294967296.0*(+($360>>>0)));
             $362 = -$361;
             $$sink$i = $362;
            }
            $363 = ((($339)) + 8|0);
            $364 = +HEAPF64[$363>>3];
            $365 = $$sink$i * $364;
            __THREW__ = 0;
            (invoke_iiiid(3392,($121|0),($127|0),($8|0),(+$365))|0);
            $366 = __THREW__; __THREW__ = 0;
            $367 = $366&1;
            if ($367) {
             break;
            }
            $368 = ((($8)) + 11|0);
            $369 = HEAP8[$368>>0]|0;
            $370 = ($369<<24>>24)<(0);
            if ($370) {
             $371 = HEAP32[$8>>2]|0;
             __ZdlPv($371);
            }
            $372 = (__Znwj(32)|0);
            HEAP32[$9>>2] = $372;
            $373 = ((($9)) + 8|0);
            HEAP32[$373>>2] = -2147483616;
            $374 = ((($9)) + 4|0);
            HEAP32[$374>>2] = 23;
            dest=$372; src=108488; stop=dest+23|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
            $375 = ((($372)) + 23|0);
            HEAP8[$375>>0] = 0;
            __THREW__ = 0;
            $376 = (invoke_i(3384)|0);
            $377 = __THREW__; __THREW__ = 0;
            $378 = $377&1;
            do {
             if (!($378)) {
              $379 = $342;
              $380 = $379;
              $381 = HEAP32[$380>>2]|0;
              $382 = (($379) + 4)|0;
              $383 = $382;
              $384 = HEAP32[$383>>2]|0;
              $385 = ($300>>>0)>($384>>>0);
              $386 = ($299>>>0)>($381>>>0);
              $387 = ($300|0)==($384|0);
              $388 = $387 & $386;
              $389 = $385 | $388;
              if ($389) {
               $390 = (_i64Subtract(($299|0),($300|0),($381|0),($384|0))|0);
               $391 = tempRet0;
               $392 = (+($390>>>0)) + (4294967296.0*(+($391>>>0)));
               $$sink$i107 = $392;
              } else {
               $393 = (_i64Subtract(($381|0),($384|0),($299|0),($300|0))|0);
               $394 = tempRet0;
               $395 = (+($393>>>0)) + (4294967296.0*(+($394>>>0)));
               $396 = -$395;
               $$sink$i107 = $396;
              }
              $397 = ((($376)) + 8|0);
              $398 = +HEAPF64[$397>>3];
              $399 = $$sink$i107 * $398;
              __THREW__ = 0;
              (invoke_iiiid(3392,($121|0),($127|0),($9|0),(+$399))|0);
              $400 = __THREW__; __THREW__ = 0;
              $401 = $400&1;
              if ($401) {
               break;
              }
              $402 = ((($9)) + 11|0);
              $403 = HEAP8[$402>>0]|0;
              $404 = ($403<<24>>24)<(0);
              if ($404) {
               $405 = HEAP32[$9>>2]|0;
               __ZdlPv($405);
              }
              $406 = (__Znwj(32)|0);
              HEAP32[$10>>2] = $406;
              $407 = ((($10)) + 8|0);
              HEAP32[$407>>2] = -2147483616;
              $408 = ((($10)) + 4|0);
              HEAP32[$408>>2] = 25;
              dest=$406; src=108512; stop=dest+25|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
              $409 = ((($406)) + 25|0);
              HEAP8[$409>>0] = 0;
              __THREW__ = 0;
              $410 = (invoke_i(3384)|0);
              $411 = __THREW__; __THREW__ = 0;
              $412 = $411&1;
              do {
               if (!($412)) {
                $413 = ($300>>>0)>($349>>>0);
                $414 = ($299>>>0)>($351>>>0);
                $415 = ($300|0)==($349|0);
                $416 = $415 & $414;
                $417 = $413 | $416;
                if ($417) {
                 $418 = (_i64Subtract(($299|0),($300|0),($351|0),($349|0))|0);
                 $419 = tempRet0;
                 $420 = (+($418>>>0)) + (4294967296.0*(+($419>>>0)));
                 $$sink$i114 = $420;
                } else {
                 $421 = (_i64Subtract(($351|0),($349|0),($299|0),($300|0))|0);
                 $422 = tempRet0;
                 $423 = (+($421>>>0)) + (4294967296.0*(+($422>>>0)));
                 $424 = -$423;
                 $$sink$i114 = $424;
                }
                $425 = ((($410)) + 8|0);
                $426 = +HEAPF64[$425>>3];
                $427 = $$sink$i114 * $426;
                __THREW__ = 0;
                (invoke_iiiid(3392,($121|0),($127|0),($10|0),(+$427))|0);
                $428 = __THREW__; __THREW__ = 0;
                $429 = $428&1;
                if ($429) {
                 break;
                }
                $430 = ((($10)) + 11|0);
                $431 = HEAP8[$430>>0]|0;
                $432 = ($431<<24>>24)<(0);
                if ($432) {
                 $433 = HEAP32[$10>>2]|0;
                 __ZdlPv($433);
                }
                break L109;
               }
              } while(0);
              $451 = ___cxa_find_matching_catch_2()|0;
              $452 = tempRet0;
              $453 = ((($10)) + 11|0);
              $454 = HEAP8[$453>>0]|0;
              $455 = ($454<<24>>24)<(0);
              if ($455) {
               $456 = HEAP32[$10>>2]|0;
               __ZdlPv($456);
              }
              $$2 = $452;$$275 = $451;
              ___resumeException($$275|0);
              // unreachable;
             }
            } while(0);
            $445 = ___cxa_find_matching_catch_2()|0;
            $446 = tempRet0;
            $447 = ((($9)) + 11|0);
            $448 = HEAP8[$447>>0]|0;
            $449 = ($448<<24>>24)<(0);
            if ($449) {
             $450 = HEAP32[$9>>2]|0;
             __ZdlPv($450);
            }
            $$2 = $446;$$275 = $445;
            ___resumeException($$275|0);
            // unreachable;
           }
          } while(0);
          $439 = ___cxa_find_matching_catch_2()|0;
          $440 = tempRet0;
          $441 = ((($8)) + 11|0);
          $442 = HEAP8[$441>>0]|0;
          $443 = ($442<<24>>24)<(0);
          if ($443) {
           $444 = HEAP32[$8>>2]|0;
           __ZdlPv($444);
          }
          $$2 = $440;$$275 = $439;
          ___resumeException($$275|0);
          // unreachable;
         }
        } while(0);
        if ((label|0) == 107) {
         $434 = ___cxa_find_matching_catch_2()|0;
         $435 = tempRet0;
         $eh$lpad$body95$index7Z2D = $435;$eh$lpad$body95$indexZ2D = $434;
        }
        $436 = HEAP8[$301>>0]|0;
        $437 = ($436<<24>>24)<(0);
        if ($437) {
         $438 = HEAP32[$7>>2]|0;
         __ZdlPv($438);
        }
        $$2 = $eh$lpad$body95$index7Z2D;$$275 = $eh$lpad$body95$indexZ2D;
        ___resumeException($$275|0);
        // unreachable;
       }
      } while(0);
      __ZN7osgUtil9SceneView33clearReferencesToDependentCamerasEv($35);
      break;
     }
    }
    $270 = ___cxa_find_matching_catch_2()|0;
    $271 = tempRet0;
    $272 = HEAP32[$250>>2]|0;
    $273 = ((($272)) + 12|0);
    $274 = HEAP32[$273>>2]|0;
    __THREW__ = 0;
    (invoke_ii($274|0,($250|0))|0);
    $275 = __THREW__; __THREW__ = 0;
    $276 = $275&1;
    if ($276) {
     $277 = ___cxa_find_matching_catch_3(0|0)|0;
     $278 = tempRet0;
     ___clang_call_terminate($277);
     // unreachable;
    } else {
     ___resumeException($270|0);
     // unreachable;
    }
   }
  }
 } while(0);
 $457 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(5)|0);
 if (!($457)) {
  STACKTOP = sp;return;
 }
 $458 = (__ZN3osg6notifyENS_14NotifySeverityE(5)|0);
 $459 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($458,109290,11)|0);
 $460 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEPKv($459,$0)|0);
 $461 = HEAP32[$460>>2]|0;
 $462 = ((($461)) + -12|0);
 $463 = HEAP32[$462>>2]|0;
 $464 = (($460) + ($463)|0);
 __ZNKSt3__28ios_base6getlocEv($1,$464);
 __THREW__ = 0;
 $465 = (invoke_iii(3255,($1|0),(215188|0))|0);
 $466 = __THREW__; __THREW__ = 0;
 $467 = $466&1;
 if (!($467)) {
  $468 = HEAP32[$465>>2]|0;
  $469 = ((($468)) + 28|0);
  $470 = HEAP32[$469>>2]|0;
  __THREW__ = 0;
  $471 = (invoke_iii($470|0,($465|0),10)|0);
  $472 = __THREW__; __THREW__ = 0;
  $473 = $472&1;
  if (!($473)) {
   __ZNSt3__26localeD2Ev($1);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($460,$471)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($460)|0);
   STACKTOP = sp;return;
  }
 }
 $474 = ___cxa_find_matching_catch_2()|0;
 $475 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($1|0));
 $476 = __THREW__; __THREW__ = 0;
 $477 = $476&1;
 if ($477) {
  $478 = ___cxa_find_matching_catch_3(0|0)|0;
  $479 = tempRet0;
  ___clang_call_terminate($478);
  // unreachable;
 } else {
  ___resumeException($474|0);
  // unreachable;
 }
}
function __ZN9osgViewer8Renderer9cull_drawEv($0) {
 $0 = $0|0;
 var $$3 = 0, $$3111 = 0, $$sink$i = 0.0, $$sink$i153 = 0.0, $$sink$i160 = 0.0, $$sink$i167 = 0.0, $$sink$i174 = 0.0, $$sink$i181 = 0.0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0;
 var $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0;
 var $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0;
 var $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0;
 var $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0;
 var $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0;
 var $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0;
 var $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0;
 var $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0;
 var $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0;
 var $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0;
 var $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0.0, $35 = 0, $350 = 0, $351 = 0, $352 = 0.0, $353 = 0.0, $354 = 0, $355 = 0.0, $356 = 0.0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0;
 var $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0;
 var $380 = 0, $381 = 0, $382 = 0, $383 = 0.0, $384 = 0, $385 = 0, $386 = 0.0, $387 = 0.0, $388 = 0, $389 = 0.0, $39 = 0, $390 = 0.0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0;
 var $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0.0, $412 = 0, $413 = 0, $414 = 0.0, $415 = 0.0;
 var $416 = 0, $417 = 0.0, $418 = 0.0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0;
 var $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0.0, $448 = 0, $449 = 0, $45 = 0, $450 = 0.0, $451 = 0.0;
 var $452 = 0, $453 = 0.0, $454 = 0.0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0;
 var $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0.0, $482 = 0, $483 = 0, $484 = 0.0, $485 = 0.0, $486 = 0, $487 = 0.0, $488 = 0.0;
 var $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0;
 var $506 = 0, $507 = 0, $508 = 0, $509 = 0.0, $51 = 0, $510 = 0, $511 = 0, $512 = 0.0, $513 = 0.0, $514 = 0, $515 = 0.0, $516 = 0.0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0;
 var $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0;
 var $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0;
 var $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0;
 var $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, $eh$lpad$body126$index7Z2D = 0, $eh$lpad$body126$indexZ2D = 0, $eh$lpad$body139$index12Z2D = 0;
 var $eh$lpad$body139$indexZ2D = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(128|0);
 $1 = sp + 116|0;
 $2 = sp + 112|0;
 $3 = sp + 108|0;
 $4 = sp + 96|0;
 $5 = sp + 84|0;
 $6 = sp + 72|0;
 $7 = sp + 60|0;
 $8 = sp + 48|0;
 $9 = sp + 36|0;
 $10 = sp + 24|0;
 $11 = sp + 12|0;
 $12 = sp;
 $13 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(5)|0);
 do {
  if ($13) {
   $14 = (__ZN3osg6notifyENS_14NotifySeverityE(5)|0);
   $15 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($14,108326,12)|0);
   $16 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEPKv($15,$0)|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = ((($17)) + -12|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($16) + ($19)|0);
   __ZNKSt3__28ios_base6getlocEv($3,$20);
   __THREW__ = 0;
   $21 = (invoke_iii(3255,($3|0),(215188|0))|0);
   $22 = __THREW__; __THREW__ = 0;
   $23 = $22&1;
   if (!($23)) {
    $24 = HEAP32[$21>>2]|0;
    $25 = ((($24)) + 28|0);
    $26 = HEAP32[$25>>2]|0;
    __THREW__ = 0;
    $27 = (invoke_iii($26|0,($21|0),10)|0);
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if (!($29)) {
     __ZNSt3__26localeD2Ev($3);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($16,$27)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($16)|0);
     break;
    }
   }
   $30 = ___cxa_find_matching_catch_2()|0;
   $31 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($3|0));
   $32 = __THREW__; __THREW__ = 0;
   $33 = $32&1;
   if ($33) {
    $34 = ___cxa_find_matching_catch_3(0|0)|0;
    $35 = tempRet0;
    ___clang_call_terminate($34);
    // unreachable;
   } else {
    ___resumeException($30|0);
    // unreachable;
   }
  }
 } while(0);
 $36 = ((($0)) + 32|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = ($37|0)==(0|0);
 if ($38) {
  STACKTOP = sp;return;
 }
 $39 = ((($0)) + 28|0);
 $40 = HEAP8[$39>>0]|0;
 $41 = ($40<<24>>24)==(0);
 if (!($41)) {
  STACKTOP = sp;return;
 }
 $42 = HEAP32[$0>>2]|0;
 $43 = ((($42)) + 40|0);
 $44 = HEAP32[$43>>2]|0;
 FUNCTION_TABLE_vii[$44 & 8191]($0,$37);
 $45 = ((($0)) + 30|0);
 $46 = HEAP8[$45>>0]|0;
 $47 = ($46<<24>>24)==(0);
 if (!($47)) {
  $48 = HEAP32[$0>>2]|0;
  $49 = ((($48)) + 32|0);
  $50 = HEAP32[$49>>2]|0;
  FUNCTION_TABLE_vi[$50 & 8191]($0);
 }
 $51 = ((($0)) + 24|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = ((($52)) + 220|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = ($54|0)==(0|0);
 if (!($55)) {
  $56 = (___dynamic_cast($54,27072,3928,0)|0);
  $57 = ($56|0)==(0|0);
  if (!($57)) {
   $58 = ((($56)) + 120|0);
   $59 = HEAP32[$58>>2]|0;
   $60 = ((($56)) + 124|0);
   $61 = HEAP32[$60>>2]|0;
   $62 = ((($37)) + 232|0);
   HEAP32[$62>>2] = $59;
   $63 = ((($37)) + 236|0);
   HEAP32[$63>>2] = $61;
  }
 }
 $64 = ((($37)) + 204|0);
 $65 = ((($37)) + 208|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = ((($66)) + 224|0);
 $68 = HEAP32[$67>>2]|0;
 $69 = ((($37)) + 100|0);
 $70 = HEAP32[$69>>2]|0;
 $71 = ((($37)) + 200|0);
 $72 = HEAP32[$71>>2]|0;
 $73 = ($72|0)==(0|0);
 if ($73) {
  $192 = 0;
 } else {
  $74 = ((($72)) + 12|0);
  $75 = HEAP32[$74>>2]|0;
  $192 = $75;
 }
 $76 = ((($0)) + 112|0);
 $77 = HEAP8[$76>>0]|0;
 $78 = ($77<<24>>24)==(0);
 if ($78) {
  __ZN9osgViewer8Renderer10initializeEPN3osg5StateE($0,$70);
 }
 $79 = ($68|0)!=(0|0);
 L30: do {
  if ($79) {
   $80 = ((($0)) + 116|0);
   $81 = HEAP32[$80>>2]|0;
   $82 = ($81|0)==(0|0);
   if ($82) {
    $584 = 0;
   } else {
    $83 = ((($4)) + 4|0);
    $84 = $83;
    $85 = $84;
    HEAP32[$85>>2] = 0;
    $86 = (($84) + 4)|0;
    $87 = $86;
    HEAP32[$87>>2] = 0;
    $88 = ((($4)) + 11|0);
    HEAP8[$88>>0] = 3;
    ;HEAP8[$4>>0]=HEAP8[108339>>0]|0;HEAP8[$4+1>>0]=HEAP8[108339+1>>0]|0;HEAP8[$4+2>>0]=HEAP8[108339+2>>0]|0;
    $89 = ((($4)) + 3|0);
    HEAP8[$89>>0] = 0;
    $90 = ((($68)) + 24|0);
    $91 = HEAP32[$90>>2]|0;
    $92 = ((($91)) + 8|0);
    $93 = HEAP32[$92>>2]|0;
    __THREW__ = 0;
    (invoke_ii($93|0,($90|0))|0);
    $94 = __THREW__; __THREW__ = 0;
    $95 = $94&1;
    do {
     if ($95) {
      label = 32;
     } else {
      $96 = ((($68)) + 68|0);
      __THREW__ = 0;
      $97 = (invoke_iii(3391,($96|0),($4|0))|0);
      $98 = __THREW__; __THREW__ = 0;
      $99 = $98&1;
      if ($99) {
       $110 = ___cxa_find_matching_catch_2()|0;
       $111 = tempRet0;
       $112 = HEAP32[$90>>2]|0;
       $113 = ((($112)) + 12|0);
       $114 = HEAP32[$113>>2]|0;
       __THREW__ = 0;
       (invoke_ii($114|0,($90|0))|0);
       $115 = __THREW__; __THREW__ = 0;
       $116 = $115&1;
       if (!($116)) {
        $eh$lpad$body$index2Z2D = $111;$eh$lpad$body$indexZ2D = $110;
        break;
       }
       $117 = ___cxa_find_matching_catch_3(0|0)|0;
       $118 = tempRet0;
       ___clang_call_terminate($117);
       // unreachable;
      }
      $100 = ((($68)) + 72|0);
      $101 = ($97|0)==($100|0);
      if ($101) {
       $585 = 0;
      } else {
       $102 = ((($97)) + 28|0);
       $103 = HEAP8[$102>>0]|0;
       $104 = ($103<<24>>24)!=(0);
       $585 = $104;
      }
      $105 = HEAP32[$90>>2]|0;
      $106 = ((($105)) + 12|0);
      $107 = HEAP32[$106>>2]|0;
      __THREW__ = 0;
      (invoke_ii($107|0,($90|0))|0);
      $108 = __THREW__; __THREW__ = 0;
      $109 = $108&1;
      if ($109) {
       label = 32;
      } else {
       $119 = HEAP8[$88>>0]|0;
       $120 = ($119<<24>>24)<(0);
       if ($120) {
        $121 = HEAP32[$4>>2]|0;
        __ZdlPv($121);
       }
       if (!($585)) {
        $584 = 0;
        break L30;
       }
       $122 = HEAP32[$80>>2]|0;
       $123 = HEAP32[$122>>2]|0;
       $124 = ((($123)) + 12|0);
       $125 = HEAP32[$124>>2]|0;
       $126 = ((($0)) + 120|0);
       $127 = $126;
       $128 = $127;
       $129 = HEAP32[$128>>2]|0;
       $130 = (($127) + 4)|0;
       $131 = $130;
       $132 = HEAP32[$131>>2]|0;
       FUNCTION_TABLE_viiiii[$125 & 8191]($122,$68,$70,$129,$132);
       $584 = 1;
       break L30;
      }
     }
    } while(0);
    if ((label|0) == 32) {
     $133 = ___cxa_find_matching_catch_2()|0;
     $134 = tempRet0;
     $eh$lpad$body$index2Z2D = $134;$eh$lpad$body$indexZ2D = $133;
    }
    $135 = HEAP8[$88>>0]|0;
    $136 = ($135<<24>>24)<(0);
    if ($136) {
     $137 = HEAP32[$4>>2]|0;
     __ZdlPv($137);
    }
    $$3 = $eh$lpad$body$index2Z2D;$$3111 = $eh$lpad$body$indexZ2D;
    ___resumeException($$3111|0);
    // unreachable;
   }
  } else {
   $584 = 0;
  }
 } while(0);
 $138 = (__ZN3osg5Timer8instanceEv()|0);
 $139 = (__ZNK3osg5Timer4tickEv($138)|0);
 $140 = tempRet0;
 $141 = HEAP32[$37>>2]|0;
 $142 = ((($141)) + 164|0);
 $143 = HEAP32[$142>>2]|0;
 $144 = HEAP32[$64>>2]|0;
 $145 = ($144|0)==(0|0);
 if ($145) {
  $151 = 0;
 } else {
  $146 = ((($144)) + 24|0);
  $147 = HEAP32[$146>>2]|0;
  $148 = ($147|0)==(0|0);
  if ($148) {
   $151 = 0;
  } else {
   $149 = HEAP32[$65>>2]|0;
   $151 = $149;
  }
 }
 $150 = ((($151)) + 144|0);
 FUNCTION_TABLE_vii[$143 & 8191]($37,$150);
 $152 = HEAP32[$37>>2]|0;
 $153 = ((($152)) + 180|0);
 $154 = HEAP32[$153>>2]|0;
 FUNCTION_TABLE_vi[$154 & 8191]($37);
 $155 = (__ZN3osg5Timer8instanceEv()|0);
 $156 = (__ZNK3osg5Timer4tickEv($155)|0);
 $157 = tempRet0;
 L59: do {
  if ($79) {
   ;HEAP32[$5>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;
   $158 = ((($5)) + 11|0);
   HEAP8[$158>>0] = 5;
   ;HEAP8[$5>>0]=HEAP8[108343>>0]|0;HEAP8[$5+1>>0]=HEAP8[108343+1>>0]|0;HEAP8[$5+2>>0]=HEAP8[108343+2>>0]|0;HEAP8[$5+3>>0]=HEAP8[108343+3>>0]|0;HEAP8[$5+4>>0]=HEAP8[108343+4>>0]|0;
   $159 = ((($5)) + 5|0);
   HEAP8[$159>>0] = 0;
   $160 = ((($68)) + 24|0);
   $161 = HEAP32[$160>>2]|0;
   $162 = ((($161)) + 8|0);
   $163 = HEAP32[$162>>2]|0;
   __THREW__ = 0;
   (invoke_ii($163|0,($160|0))|0);
   $164 = __THREW__; __THREW__ = 0;
   $165 = $164&1;
   do {
    if ($165) {
     label = 51;
    } else {
     $166 = ((($68)) + 68|0);
     __THREW__ = 0;
     $167 = (invoke_iii(3391,($166|0),($5|0))|0);
     $168 = __THREW__; __THREW__ = 0;
     $169 = $168&1;
     if ($169) {
      $180 = ___cxa_find_matching_catch_2()|0;
      $181 = tempRet0;
      $182 = HEAP32[$160>>2]|0;
      $183 = ((($182)) + 12|0);
      $184 = HEAP32[$183>>2]|0;
      __THREW__ = 0;
      (invoke_ii($184|0,($160|0))|0);
      $185 = __THREW__; __THREW__ = 0;
      $186 = $185&1;
      if (!($186)) {
       $eh$lpad$body126$index7Z2D = $181;$eh$lpad$body126$indexZ2D = $180;
       break;
      }
      $187 = ___cxa_find_matching_catch_3(0|0)|0;
      $188 = tempRet0;
      ___clang_call_terminate($187);
      // unreachable;
     }
     $170 = ((($68)) + 72|0);
     $171 = ($167|0)==($170|0);
     if ($171) {
      $586 = 0;
     } else {
      $172 = ((($167)) + 28|0);
      $173 = HEAP8[$172>>0]|0;
      $174 = ($173<<24>>24)!=(0);
      $586 = $174;
     }
     $175 = HEAP32[$160>>2]|0;
     $176 = ((($175)) + 12|0);
     $177 = HEAP32[$176>>2]|0;
     __THREW__ = 0;
     (invoke_ii($177|0,($160|0))|0);
     $178 = __THREW__; __THREW__ = 0;
     $179 = $178&1;
     if ($179) {
      label = 51;
     } else {
      $189 = HEAP8[$158>>0]|0;
      $190 = ($189<<24>>24)<(0);
      if ($190) {
       $191 = HEAP32[$5>>2]|0;
       __ZdlPv($191);
      }
      if (!($586)) {
       break L59;
      }
      __ZL21collectSceneViewStatsjPN7osgUtil9SceneViewEPN3osg5StatsE($192,$37,$68);
      break L59;
     }
    }
   } while(0);
   if ((label|0) == 51) {
    $193 = ___cxa_find_matching_catch_2()|0;
    $194 = tempRet0;
    $eh$lpad$body126$index7Z2D = $194;$eh$lpad$body126$indexZ2D = $193;
   }
   $195 = HEAP8[$158>>0]|0;
   $196 = ($195<<24>>24)<(0);
   if ($196) {
    $197 = HEAP32[$5>>2]|0;
    __ZdlPv($197);
   }
   $$3 = $eh$lpad$body126$index7Z2D;$$3111 = $eh$lpad$body126$indexZ2D;
   ___resumeException($$3111|0);
   // unreachable;
  }
 } while(0);
 if ($584) {
  $198 = ((($0)) + 116|0);
  $199 = HEAP32[$198>>2]|0;
  $200 = HEAP32[$199>>2]|0;
  $201 = ((($200)) + 12|0);
  $202 = HEAP32[$201>>2]|0;
  $203 = ((($0)) + 120|0);
  $204 = $203;
  $205 = $204;
  $206 = HEAP32[$205>>2]|0;
  $207 = (($204) + 4)|0;
  $208 = $207;
  $209 = HEAP32[$208>>2]|0;
  FUNCTION_TABLE_viiiii[$202 & 8191]($199,$68,$70,$206,$209);
  $210 = HEAP32[$198>>2]|0;
  $211 = HEAP32[$210>>2]|0;
  $212 = ((($211)) + 16|0);
  $213 = HEAP32[$212>>2]|0;
  FUNCTION_TABLE_viii[$213 & 8191]($210,$192,$70);
 }
 $214 = ((($0)) + 31|0);
 $215 = HEAP8[$214>>0]|0;
 $216 = ($215<<24>>24)==(0);
 do {
  if ($216) {
   $242 = (__ZN3osg5Timer8instanceEv()|0);
   $243 = (__ZNK3osg5Timer4tickEv($242)|0);
   $244 = tempRet0;
   $245 = HEAP32[$37>>2]|0;
   $246 = ((($245)) + 184|0);
   $247 = HEAP32[$246>>2]|0;
   FUNCTION_TABLE_vi[$247 & 8191]($37);
   $438 = $244;$440 = $243;
  } else {
   $217 = HEAP32[51948]|0;
   $218 = ((($217)) + 8|0);
   $219 = HEAP32[$218>>2]|0;
   (FUNCTION_TABLE_ii[$219 & 8191](207792)|0);
   __THREW__ = 0;
   $220 = (invoke_i(3384)|0);
   $221 = __THREW__; __THREW__ = 0;
   $222 = $221&1;
   if (!($222)) {
    __THREW__ = 0;
    $223 = (invoke_ii(3385,($220|0))|0);
    $224 = tempRet0;
    $225 = __THREW__; __THREW__ = 0;
    $226 = $225&1;
    if (!($226)) {
     $227 = HEAP32[$37>>2]|0;
     $228 = ((($227)) + 184|0);
     $229 = HEAP32[$228>>2]|0;
     __THREW__ = 0;
     invoke_vi($229|0,($37|0));
     $230 = __THREW__; __THREW__ = 0;
     $231 = $230&1;
     if (!($231)) {
      $232 = HEAP32[51948]|0;
      $233 = ((($232)) + 12|0);
      $234 = HEAP32[$233>>2]|0;
      (FUNCTION_TABLE_ii[$234 & 8191](207792)|0);
      $438 = $224;$440 = $223;
      break;
     }
    }
   }
   $235 = ___cxa_find_matching_catch_2()|0;
   $236 = tempRet0;
   $237 = HEAP32[51948]|0;
   $238 = ((($237)) + 12|0);
   $239 = HEAP32[$238>>2]|0;
   __THREW__ = 0;
   (invoke_ii($239|0,(207792|0))|0);
   $240 = __THREW__; __THREW__ = 0;
   $241 = $240&1;
   if ($241) {
    $582 = ___cxa_find_matching_catch_3(0|0)|0;
    $583 = tempRet0;
    ___clang_call_terminate($582);
    // unreachable;
   }
   $$3 = $236;$$3111 = $235;
   ___resumeException($$3111|0);
   // unreachable;
  }
 } while(0);
 if ($584) {
  $248 = ((($0)) + 116|0);
  $249 = HEAP32[$248>>2]|0;
  $250 = HEAP32[$249>>2]|0;
  $251 = ((($250)) + 20|0);
  $252 = HEAP32[$251>>2]|0;
  FUNCTION_TABLE_vii[$252 & 8191]($249,$70);
  $253 = HEAP32[$248>>2]|0;
  $254 = HEAP32[$253>>2]|0;
  $255 = ((($254)) + 12|0);
  $256 = HEAP32[$255>>2]|0;
  $257 = ((($0)) + 120|0);
  $258 = $257;
  $259 = $258;
  $260 = HEAP32[$259>>2]|0;
  $261 = (($258) + 4)|0;
  $262 = $261;
  $263 = HEAP32[$262>>2]|0;
  FUNCTION_TABLE_viiiii[$256 & 8191]($253,$68,$70,$260,$263);
 }
 $264 = (__ZN3osg5Timer8instanceEv()|0);
 $265 = (__ZNK3osg5Timer4tickEv($264)|0);
 $266 = tempRet0;
 L102: do {
  if ($79) {
   ;HEAP32[$6>>2]=0|0;HEAP32[$6+4>>2]=0|0;HEAP32[$6+8>>2]=0|0;
   $267 = ((($6)) + 11|0);
   HEAP8[$267>>0] = 9;
   dest=$6; src=108349; stop=dest+9|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
   $268 = ((($6)) + 9|0);
   HEAP8[$268>>0] = 0;
   $269 = ((($68)) + 24|0);
   $270 = HEAP32[$269>>2]|0;
   $271 = ((($270)) + 8|0);
   $272 = HEAP32[$271>>2]|0;
   __THREW__ = 0;
   (invoke_ii($272|0,($269|0))|0);
   $273 = __THREW__; __THREW__ = 0;
   $274 = $273&1;
   do {
    if ($274) {
     label = 85;
    } else {
     $275 = ((($68)) + 68|0);
     __THREW__ = 0;
     $276 = (invoke_iii(3391,($275|0),($6|0))|0);
     $277 = __THREW__; __THREW__ = 0;
     $278 = $277&1;
     if ($278) {
      $289 = ___cxa_find_matching_catch_2()|0;
      $290 = tempRet0;
      $291 = HEAP32[$269>>2]|0;
      $292 = ((($291)) + 12|0);
      $293 = HEAP32[$292>>2]|0;
      __THREW__ = 0;
      (invoke_ii($293|0,($269|0))|0);
      $294 = __THREW__; __THREW__ = 0;
      $295 = $294&1;
      if (!($295)) {
       $eh$lpad$body139$index12Z2D = $290;$eh$lpad$body139$indexZ2D = $289;
       break;
      }
      $296 = ___cxa_find_matching_catch_3(0|0)|0;
      $297 = tempRet0;
      ___clang_call_terminate($296);
      // unreachable;
     }
     $279 = ((($68)) + 72|0);
     $280 = ($276|0)==($279|0);
     if ($280) {
      $587 = 0;
     } else {
      $281 = ((($276)) + 28|0);
      $282 = HEAP8[$281>>0]|0;
      $283 = ($282<<24>>24)!=(0);
      $587 = $283;
     }
     $284 = HEAP32[$269>>2]|0;
     $285 = ((($284)) + 12|0);
     $286 = HEAP32[$285>>2]|0;
     __THREW__ = 0;
     (invoke_ii($286|0,($269|0))|0);
     $287 = __THREW__; __THREW__ = 0;
     $288 = $287&1;
     if ($288) {
      label = 85;
     } else {
      $298 = HEAP8[$267>>0]|0;
      $299 = ($298<<24>>24)<(0);
      if ($299) {
       $300 = HEAP32[$6>>2]|0;
       __ZdlPv($300);
      }
      if (!($587)) {
       break L102;
      }
      $301 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(5)|0);
      L118: do {
       if ($301) {
        $302 = (__ZN3osg6notifyENS_14NotifySeverityE(5)|0);
        $303 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($302,108359,26)|0);
        $304 = HEAP32[$303>>2]|0;
        $305 = ((($304)) + -12|0);
        $306 = HEAP32[$305>>2]|0;
        $307 = (($303) + ($306)|0);
        __ZNKSt3__28ios_base6getlocEv($1,$307);
        __THREW__ = 0;
        $308 = (invoke_iii(3255,($1|0),(215188|0))|0);
        $309 = __THREW__; __THREW__ = 0;
        $310 = $309&1;
        do {
         if (!($310)) {
          $311 = HEAP32[$308>>2]|0;
          $312 = ((($311)) + 28|0);
          $313 = HEAP32[$312>>2]|0;
          __THREW__ = 0;
          $314 = (invoke_iii($313|0,($308|0),10)|0);
          $315 = __THREW__; __THREW__ = 0;
          $316 = $315&1;
          if ($316) {
           break;
          }
          __ZNSt3__26localeD2Ev($1);
          (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($303,$314)|0);
          (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($303)|0);
          break L118;
         }
        } while(0);
        $317 = ___cxa_find_matching_catch_2()|0;
        $318 = tempRet0;
        __THREW__ = 0;
        invoke_vi(3263,($1|0));
        $319 = __THREW__; __THREW__ = 0;
        $320 = $319&1;
        if ($320) {
         $321 = ___cxa_find_matching_catch_3(0|0)|0;
         $322 = tempRet0;
         ___clang_call_terminate($321);
         // unreachable;
        } else {
         ___resumeException($317|0);
         // unreachable;
        }
       }
      } while(0);
      $328 = (__Znwj(32)|0);
      HEAP32[$7>>2] = $328;
      $329 = ((($7)) + 8|0);
      HEAP32[$329>>2] = -2147483616;
      $330 = ((($7)) + 4|0);
      HEAP32[$330>>2] = 25;
      dest=$328; src=108386; stop=dest+25|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
      $331 = ((($328)) + 25|0);
      HEAP8[$331>>0] = 0;
      __THREW__ = 0;
      $332 = (invoke_i(3384)|0);
      $333 = __THREW__; __THREW__ = 0;
      $334 = $333&1;
      do {
       if (!($334)) {
        $335 = ((($0)) + 120|0);
        $336 = $335;
        $337 = $336;
        $338 = HEAP32[$337>>2]|0;
        $339 = (($336) + 4)|0;
        $340 = $339;
        $341 = HEAP32[$340>>2]|0;
        $342 = ($140>>>0)>($341>>>0);
        $343 = ($139>>>0)>($338>>>0);
        $344 = ($140|0)==($341|0);
        $345 = $344 & $343;
        $346 = $342 | $345;
        if ($346) {
         $347 = (_i64Subtract(($139|0),($140|0),($338|0),($341|0))|0);
         $348 = tempRet0;
         $349 = (+($347>>>0)) + (4294967296.0*(+($348>>>0)));
         $$sink$i = $349;
        } else {
         $350 = (_i64Subtract(($338|0),($341|0),($139|0),($140|0))|0);
         $351 = tempRet0;
         $352 = (+($350>>>0)) + (4294967296.0*(+($351>>>0)));
         $353 = -$352;
         $$sink$i = $353;
        }
        $354 = ((($332)) + 8|0);
        $355 = +HEAPF64[$354>>3];
        $356 = $$sink$i * $355;
        __THREW__ = 0;
        (invoke_iiiid(3392,($68|0),($192|0),($7|0),(+$356))|0);
        $357 = __THREW__; __THREW__ = 0;
        $358 = $357&1;
        if ($358) {
         break;
        }
        $359 = ((($7)) + 11|0);
        $360 = HEAP8[$359>>0]|0;
        $361 = ($360<<24>>24)<(0);
        if ($361) {
         $362 = HEAP32[$7>>2]|0;
         __ZdlPv($362);
        }
        $363 = (__Znwj(32)|0);
        HEAP32[$8>>2] = $363;
        $364 = ((($8)) + 8|0);
        HEAP32[$364>>2] = -2147483616;
        $365 = ((($8)) + 4|0);
        HEAP32[$365>>2] = 23;
        dest=$363; src=108412; stop=dest+23|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
        $366 = ((($363)) + 23|0);
        HEAP8[$366>>0] = 0;
        __THREW__ = 0;
        $367 = (invoke_i(3384)|0);
        $368 = __THREW__; __THREW__ = 0;
        $369 = $368&1;
        do {
         if (!($369)) {
          $370 = $335;
          $371 = $370;
          $372 = HEAP32[$371>>2]|0;
          $373 = (($370) + 4)|0;
          $374 = $373;
          $375 = HEAP32[$374>>2]|0;
          $376 = ($157>>>0)>($375>>>0);
          $377 = ($156>>>0)>($372>>>0);
          $378 = ($157|0)==($375|0);
          $379 = $378 & $377;
          $380 = $376 | $379;
          if ($380) {
           $381 = (_i64Subtract(($156|0),($157|0),($372|0),($375|0))|0);
           $382 = tempRet0;
           $383 = (+($381>>>0)) + (4294967296.0*(+($382>>>0)));
           $$sink$i153 = $383;
          } else {
           $384 = (_i64Subtract(($372|0),($375|0),($156|0),($157|0))|0);
           $385 = tempRet0;
           $386 = (+($384>>>0)) + (4294967296.0*(+($385>>>0)));
           $387 = -$386;
           $$sink$i153 = $387;
          }
          $388 = ((($367)) + 8|0);
          $389 = +HEAPF64[$388>>3];
          $390 = $$sink$i153 * $389;
          __THREW__ = 0;
          (invoke_iiiid(3392,($68|0),($192|0),($8|0),(+$390))|0);
          $391 = __THREW__; __THREW__ = 0;
          $392 = $391&1;
          if ($392) {
           break;
          }
          $393 = ((($8)) + 11|0);
          $394 = HEAP8[$393>>0]|0;
          $395 = ($394<<24>>24)<(0);
          if ($395) {
           $396 = HEAP32[$8>>2]|0;
           __ZdlPv($396);
          }
          $397 = (__Znwj(32)|0);
          HEAP32[$9>>2] = $397;
          $398 = ((($9)) + 8|0);
          HEAP32[$398>>2] = -2147483616;
          $399 = ((($9)) + 4|0);
          HEAP32[$399>>2] = 25;
          dest=$397; src=108436; stop=dest+25|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
          $400 = ((($397)) + 25|0);
          HEAP8[$400>>0] = 0;
          __THREW__ = 0;
          $401 = (invoke_i(3384)|0);
          $402 = __THREW__; __THREW__ = 0;
          $403 = $402&1;
          do {
           if (!($403)) {
            $404 = ($157>>>0)>($140>>>0);
            $405 = ($156>>>0)>($139>>>0);
            $406 = ($157|0)==($140|0);
            $407 = $406 & $405;
            $408 = $404 | $407;
            if ($408) {
             $409 = (_i64Subtract(($156|0),($157|0),($139|0),($140|0))|0);
             $410 = tempRet0;
             $411 = (+($409>>>0)) + (4294967296.0*(+($410>>>0)));
             $$sink$i160 = $411;
            } else {
             $412 = (_i64Subtract(($139|0),($140|0),($156|0),($157|0))|0);
             $413 = tempRet0;
             $414 = (+($412>>>0)) + (4294967296.0*(+($413>>>0)));
             $415 = -$414;
             $$sink$i160 = $415;
            }
            $416 = ((($401)) + 8|0);
            $417 = +HEAPF64[$416>>3];
            $418 = $$sink$i160 * $417;
            __THREW__ = 0;
            (invoke_iiiid(3392,($68|0),($192|0),($9|0),(+$418))|0);
            $419 = __THREW__; __THREW__ = 0;
            $420 = $419&1;
            if ($420) {
             break;
            }
            $421 = ((($9)) + 11|0);
            $422 = HEAP8[$421>>0]|0;
            $423 = ($422<<24>>24)<(0);
            if ($423) {
             $424 = HEAP32[$9>>2]|0;
             __ZdlPv($424);
            }
            $425 = (__Znwj(32)|0);
            HEAP32[$10>>2] = $425;
            $426 = ((($10)) + 8|0);
            HEAP32[$426>>2] = -2147483616;
            $427 = ((($10)) + 4|0);
            HEAP32[$427>>2] = 25;
            dest=$425; src=108462; stop=dest+25|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
            $428 = ((($425)) + 25|0);
            HEAP8[$428>>0] = 0;
            __THREW__ = 0;
            $429 = (invoke_i(3384)|0);
            $430 = __THREW__; __THREW__ = 0;
            $431 = $430&1;
            do {
             if (!($431)) {
              $432 = $335;
              $433 = $432;
              $434 = HEAP32[$433>>2]|0;
              $435 = (($432) + 4)|0;
              $436 = $435;
              $437 = HEAP32[$436>>2]|0;
              $439 = ($438>>>0)>($437>>>0);
              $441 = ($440>>>0)>($434>>>0);
              $442 = ($438|0)==($437|0);
              $443 = $442 & $441;
              $444 = $439 | $443;
              if ($444) {
               $445 = (_i64Subtract(($440|0),($438|0),($434|0),($437|0))|0);
               $446 = tempRet0;
               $447 = (+($445>>>0)) + (4294967296.0*(+($446>>>0)));
               $$sink$i167 = $447;
              } else {
               $448 = (_i64Subtract(($434|0),($437|0),($440|0),($438|0))|0);
               $449 = tempRet0;
               $450 = (+($448>>>0)) + (4294967296.0*(+($449>>>0)));
               $451 = -$450;
               $$sink$i167 = $451;
              }
              $452 = ((($429)) + 8|0);
              $453 = +HEAPF64[$452>>3];
              $454 = $$sink$i167 * $453;
              __THREW__ = 0;
              (invoke_iiiid(3392,($68|0),($192|0),($10|0),(+$454))|0);
              $455 = __THREW__; __THREW__ = 0;
              $456 = $455&1;
              if ($456) {
               break;
              }
              $457 = ((($10)) + 11|0);
              $458 = HEAP8[$457>>0]|0;
              $459 = ($458<<24>>24)<(0);
              if ($459) {
               $460 = HEAP32[$10>>2]|0;
               __ZdlPv($460);
              }
              $461 = (__Znwj(32)|0);
              HEAP32[$11>>2] = $461;
              $462 = ((($11)) + 8|0);
              HEAP32[$462>>2] = -2147483616;
              $463 = ((($11)) + 4|0);
              HEAP32[$463>>2] = 23;
              dest=$461; src=108488; stop=dest+23|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
              $464 = ((($461)) + 23|0);
              HEAP8[$464>>0] = 0;
              __THREW__ = 0;
              $465 = (invoke_i(3384)|0);
              $466 = __THREW__; __THREW__ = 0;
              $467 = $466&1;
              do {
               if (!($467)) {
                $468 = $335;
                $469 = $468;
                $470 = HEAP32[$469>>2]|0;
                $471 = (($468) + 4)|0;
                $472 = $471;
                $473 = HEAP32[$472>>2]|0;
                $474 = ($266>>>0)>($473>>>0);
                $475 = ($265>>>0)>($470>>>0);
                $476 = ($266|0)==($473|0);
                $477 = $476 & $475;
                $478 = $474 | $477;
                if ($478) {
                 $479 = (_i64Subtract(($265|0),($266|0),($470|0),($473|0))|0);
                 $480 = tempRet0;
                 $481 = (+($479>>>0)) + (4294967296.0*(+($480>>>0)));
                 $$sink$i174 = $481;
                } else {
                 $482 = (_i64Subtract(($470|0),($473|0),($265|0),($266|0))|0);
                 $483 = tempRet0;
                 $484 = (+($482>>>0)) + (4294967296.0*(+($483>>>0)));
                 $485 = -$484;
                 $$sink$i174 = $485;
                }
                $486 = ((($465)) + 8|0);
                $487 = +HEAPF64[$486>>3];
                $488 = $$sink$i174 * $487;
                __THREW__ = 0;
                (invoke_iiiid(3392,($68|0),($192|0),($11|0),(+$488))|0);
                $489 = __THREW__; __THREW__ = 0;
                $490 = $489&1;
                if ($490) {
                 break;
                }
                $491 = ((($11)) + 11|0);
                $492 = HEAP8[$491>>0]|0;
                $493 = ($492<<24>>24)<(0);
                if ($493) {
                 $494 = HEAP32[$11>>2]|0;
                 __ZdlPv($494);
                }
                $495 = (__Znwj(32)|0);
                HEAP32[$12>>2] = $495;
                $496 = ((($12)) + 8|0);
                HEAP32[$496>>2] = -2147483616;
                $497 = ((($12)) + 4|0);
                HEAP32[$497>>2] = 25;
                dest=$495; src=108512; stop=dest+25|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                $498 = ((($495)) + 25|0);
                HEAP8[$498>>0] = 0;
                __THREW__ = 0;
                $499 = (invoke_i(3384)|0);
                $500 = __THREW__; __THREW__ = 0;
                $501 = $500&1;
                do {
                 if (!($501)) {
                  $502 = ($266>>>0)>($438>>>0);
                  $503 = ($265>>>0)>($440>>>0);
                  $504 = ($266|0)==($438|0);
                  $505 = $504 & $503;
                  $506 = $502 | $505;
                  if ($506) {
                   $507 = (_i64Subtract(($265|0),($266|0),($440|0),($438|0))|0);
                   $508 = tempRet0;
                   $509 = (+($507>>>0)) + (4294967296.0*(+($508>>>0)));
                   $$sink$i181 = $509;
                  } else {
                   $510 = (_i64Subtract(($440|0),($438|0),($265|0),($266|0))|0);
                   $511 = tempRet0;
                   $512 = (+($510>>>0)) + (4294967296.0*(+($511>>>0)));
                   $513 = -$512;
                   $$sink$i181 = $513;
                  }
                  $514 = ((($499)) + 8|0);
                  $515 = +HEAPF64[$514>>3];
                  $516 = $$sink$i181 * $515;
                  __THREW__ = 0;
                  (invoke_iiiid(3392,($68|0),($192|0),($12|0),(+$516))|0);
                  $517 = __THREW__; __THREW__ = 0;
                  $518 = $517&1;
                  if ($518) {
                   break;
                  }
                  $519 = ((($12)) + 11|0);
                  $520 = HEAP8[$519>>0]|0;
                  $521 = ($520<<24>>24)<(0);
                  if ($521) {
                   $522 = HEAP32[$12>>2]|0;
                   __ZdlPv($522);
                  }
                  break L102;
                 }
                } while(0);
                $553 = ___cxa_find_matching_catch_2()|0;
                $554 = tempRet0;
                $555 = ((($12)) + 11|0);
                $556 = HEAP8[$555>>0]|0;
                $557 = ($556<<24>>24)<(0);
                if ($557) {
                 $558 = HEAP32[$12>>2]|0;
                 __ZdlPv($558);
                }
                $$3 = $554;$$3111 = $553;
                ___resumeException($$3111|0);
                // unreachable;
               }
              } while(0);
              $547 = ___cxa_find_matching_catch_2()|0;
              $548 = tempRet0;
              $549 = ((($11)) + 11|0);
              $550 = HEAP8[$549>>0]|0;
              $551 = ($550<<24>>24)<(0);
              if ($551) {
               $552 = HEAP32[$11>>2]|0;
               __ZdlPv($552);
              }
              $$3 = $548;$$3111 = $547;
              ___resumeException($$3111|0);
              // unreachable;
             }
            } while(0);
            $541 = ___cxa_find_matching_catch_2()|0;
            $542 = tempRet0;
            $543 = ((($10)) + 11|0);
            $544 = HEAP8[$543>>0]|0;
            $545 = ($544<<24>>24)<(0);
            if ($545) {
             $546 = HEAP32[$10>>2]|0;
             __ZdlPv($546);
            }
            $$3 = $542;$$3111 = $541;
            ___resumeException($$3111|0);
            // unreachable;
           }
          } while(0);
          $535 = ___cxa_find_matching_catch_2()|0;
          $536 = tempRet0;
          $537 = ((($9)) + 11|0);
          $538 = HEAP8[$537>>0]|0;
          $539 = ($538<<24>>24)<(0);
          if ($539) {
           $540 = HEAP32[$9>>2]|0;
           __ZdlPv($540);
          }
          $$3 = $536;$$3111 = $535;
          ___resumeException($$3111|0);
          // unreachable;
         }
        } while(0);
        $529 = ___cxa_find_matching_catch_2()|0;
        $530 = tempRet0;
        $531 = ((($8)) + 11|0);
        $532 = HEAP8[$531>>0]|0;
        $533 = ($532<<24>>24)<(0);
        if ($533) {
         $534 = HEAP32[$8>>2]|0;
         __ZdlPv($534);
        }
        $$3 = $530;$$3111 = $529;
        ___resumeException($$3111|0);
        // unreachable;
       }
      } while(0);
      $523 = ___cxa_find_matching_catch_2()|0;
      $524 = tempRet0;
      $525 = ((($7)) + 11|0);
      $526 = HEAP8[$525>>0]|0;
      $527 = ($526<<24>>24)<(0);
      if ($527) {
       $528 = HEAP32[$7>>2]|0;
       __ZdlPv($528);
      }
      $$3 = $524;$$3111 = $523;
      ___resumeException($$3111|0);
      // unreachable;
     }
    }
   } while(0);
   if ((label|0) == 85) {
    $323 = ___cxa_find_matching_catch_2()|0;
    $324 = tempRet0;
    $eh$lpad$body139$index12Z2D = $324;$eh$lpad$body139$indexZ2D = $323;
   }
   $325 = HEAP8[$267>>0]|0;
   $326 = ($325<<24>>24)<(0);
   if ($326) {
    $327 = HEAP32[$6>>2]|0;
    __ZdlPv($327);
   }
   $$3 = $eh$lpad$body139$index12Z2D;$$3111 = $eh$lpad$body139$indexZ2D;
   ___resumeException($$3111|0);
   // unreachable;
  }
 } while(0);
 $559 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(5)|0);
 if (!($559)) {
  STACKTOP = sp;return;
 }
 $560 = (__ZN3osg6notifyENS_14NotifySeverityE(5)|0);
 $561 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($560,108538,16)|0);
 $562 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEPKv($561,$0)|0);
 $563 = HEAP32[$562>>2]|0;
 $564 = ((($563)) + -12|0);
 $565 = HEAP32[$564>>2]|0;
 $566 = (($562) + ($565)|0);
 __ZNKSt3__28ios_base6getlocEv($2,$566);
 __THREW__ = 0;
 $567 = (invoke_iii(3255,($2|0),(215188|0))|0);
 $568 = __THREW__; __THREW__ = 0;
 $569 = $568&1;
 if (!($569)) {
  $570 = HEAP32[$567>>2]|0;
  $571 = ((($570)) + 28|0);
  $572 = HEAP32[$571>>2]|0;
  __THREW__ = 0;
  $573 = (invoke_iii($572|0,($567|0),10)|0);
  $574 = __THREW__; __THREW__ = 0;
  $575 = $574&1;
  if (!($575)) {
   __ZNSt3__26localeD2Ev($2);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($562,$573)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($562)|0);
   STACKTOP = sp;return;
  }
 }
 $576 = ___cxa_find_matching_catch_2()|0;
 $577 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($2|0));
 $578 = __THREW__; __THREW__ = 0;
 $579 = $578&1;
 if ($579) {
  $580 = ___cxa_find_matching_catch_3(0|0)|0;
  $581 = tempRet0;
  ___clang_call_terminate($580);
  // unreachable;
 } else {
  ___resumeException($576|0);
  // unreachable;
 }
}
function __ZN9osgViewer8Renderer7compileEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $100 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(160|0);
 $1 = sp + 156|0;
 $2 = sp;
 $3 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(5)|0);
 do {
  if ($3) {
   $4 = (__ZN3osg6notifyENS_14NotifySeverityE(5)|0);
   $5 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($4,108257,19)|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ((($6)) + -12|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($5) + ($8)|0);
   __ZNKSt3__28ios_base6getlocEv($1,$9);
   __THREW__ = 0;
   $10 = (invoke_iii(3255,($1|0),(215188|0))|0);
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if (!($12)) {
    $13 = HEAP32[$10>>2]|0;
    $14 = ((($13)) + 28|0);
    $15 = HEAP32[$14>>2]|0;
    __THREW__ = 0;
    $16 = (invoke_iii($15|0,($10|0),10)|0);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if (!($18)) {
     __ZNSt3__26localeD2Ev($1);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($5,$16)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($5)|0);
     break;
    }
   }
   $19 = ___cxa_find_matching_catch_2()|0;
   $20 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($1|0));
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if ($22) {
    $23 = ___cxa_find_matching_catch_3(0|0)|0;
    $24 = tempRet0;
    ___clang_call_terminate($23);
    // unreachable;
   } else {
    ___resumeException($19|0);
    // unreachable;
   }
  }
 } while(0);
 $25 = ((($0)) + 30|0);
 HEAP8[$25>>0] = 0;
 $26 = ((($0)) + 32|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  STACKTOP = sp;return;
 }
 $29 = ((($0)) + 28|0);
 $30 = HEAP8[$29>>0]|0;
 $31 = ($30<<24>>24)==(0);
 if (!($31)) {
  STACKTOP = sp;return;
 }
 $32 = ((($27)) + 100|0);
 $33 = HEAP32[$32>>2]|0;
 (__ZNK3osg5State13checkGLErrorsEPKcS2_($33,108277,0)|0);
 $34 = ((($27)) + 208|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 $37 = ((($36)) + 224|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (FUNCTION_TABLE_ii[$38 & 8191]($35)|0);
 $40 = ($39|0)==(0);
 do {
  if (!($40)) {
   $41 = HEAP32[$34>>2]|0;
   $42 = ((($41)) + 124|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = HEAP32[$43>>2]|0;
   $45 = ($44|0)==(0|0);
   if (!($45)) {
    __ZN7osgUtil16GLObjectsVisitorC1Ej($2,268);
    $46 = HEAP32[$32>>2]|0;
    $47 = ((($2)) + 60|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = ($48|0)==($46|0);
    if ($49) {
     label = 18;
    } else {
     HEAP32[$47>>2] = $46;
     $50 = ($46|0)==(0|0);
     if (!($50)) {
      $51 = ((($46)) + 8|0);
      $52 = HEAP32[$51>>2]|0;HEAP32[$51>>2] = (($52+1)|0);
     }
     $53 = ($48|0)==(0|0);
     if ($53) {
      label = 18;
     } else {
      $54 = ((($48)) + 8|0);
      $55 = HEAP32[$54>>2]|0;HEAP32[$54>>2] = (($55-1)|0);
      $56 = ($55|0)==(1);
      if ($56) {
       __THREW__ = 0;
       invoke_viii(3262,($48|0),1,1);
       $57 = __THREW__; __THREW__ = 0;
       $58 = $57&1;
       if (!($58)) {
        label = 18;
       }
      } else {
       label = 18;
      }
     }
    }
    if ((label|0) == 18) {
     $59 = HEAP32[$34>>2]|0;
     $60 = HEAP32[$59>>2]|0;
     $61 = ((($60)) + 224|0);
     $62 = HEAP32[$61>>2]|0;
     __THREW__ = 0;
     (invoke_ii($62|0,($59|0))|0);
     $63 = __THREW__; __THREW__ = 0;
     $64 = $63&1;
     if (!($64)) {
      $65 = HEAP32[$34>>2]|0;
      $66 = ((($65)) + 124|0);
      $67 = HEAP32[$66>>2]|0;
      $68 = HEAP32[$67>>2]|0;
      $69 = HEAP32[$68>>2]|0;
      $70 = ((($69)) + 188|0);
      $71 = HEAP32[$70>>2]|0;
      __THREW__ = 0;
      invoke_vii($71|0,($68|0),($2|0));
      $72 = __THREW__; __THREW__ = 0;
      $73 = $72&1;
      if (!($73)) {
       __THREW__ = 0;
       invoke_vii(3503,($2|0),(47052|0));
       $74 = __THREW__; __THREW__ = 0;
       $75 = $74&1;
       if (!($75)) {
        $83 = ((($2)) + 124|0);
        __ZN3osg6ObjectD2Ev($83);
        break;
       }
       $76 = ___cxa_find_matching_catch_2()|0;
       $77 = tempRet0;
       $78 = ((($2)) + 124|0);
       __THREW__ = 0;
       invoke_vi(388,($78|0));
       $79 = __THREW__; __THREW__ = 0;
       $80 = $79&1;
       if ($80) {
        $81 = ___cxa_find_matching_catch_3(0|0)|0;
        $82 = tempRet0;
        ___clang_call_terminate($81);
        // unreachable;
       } else {
        ___resumeException($76|0);
        // unreachable;
       }
      }
     }
    }
    $84 = ___cxa_find_matching_catch_2()|0;
    $85 = tempRet0;
    __THREW__ = 0;
    invoke_vii(3503,($2|0),(47052|0));
    $86 = __THREW__; __THREW__ = 0;
    $87 = $86&1;
    if ($87) {
     $91 = ___cxa_find_matching_catch_3(0|0)|0;
     $92 = tempRet0;
     $93 = ((($2)) + 124|0);
     __THREW__ = 0;
     invoke_vi(388,($93|0));
     $94 = __THREW__; __THREW__ = 0;
     $95 = $94&1;
     if ($95) {
      $96 = ___cxa_find_matching_catch_3(0|0)|0;
      $97 = tempRet0;
      ___clang_call_terminate($96);
      // unreachable;
     } else {
      $eh$lpad$body$indexZ2D = $91;
      ___clang_call_terminate($eh$lpad$body$indexZ2D);
      // unreachable;
     }
    }
    $88 = ((($2)) + 124|0);
    __THREW__ = 0;
    invoke_vi(388,($88|0));
    $89 = __THREW__; __THREW__ = 0;
    $90 = $89&1;
    if (!($90)) {
     ___resumeException($84|0);
     // unreachable;
    }
    $99 = ___cxa_find_matching_catch_3(0|0)|0;
    $100 = tempRet0;
    $eh$lpad$body$indexZ2D = $99;
    ___clang_call_terminate($eh$lpad$body$indexZ2D);
    // unreachable;
   }
  }
 } while(0);
 $98 = HEAP32[$32>>2]|0;
 (__ZNK3osg5State13checkGLErrorsEPKcS2_($98,108302,0)|0);
 STACKTOP = sp;return;
}
function __ZN9osgViewer8Renderer5resetEv($0) {
 $0 = $0|0;
 var $$023$i$i$i = 0, $$023$i$i$i3 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 40|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 (FUNCTION_TABLE_ii[$4 & 8191]($1)|0);
 $5 = ((($0)) + 60|0);
 $6 = ((($0)) + 68|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0);
 if (!($8)) {
  $9 = ((($0)) + 64|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = HEAP32[$5>>2]|0;
  $12 = ((($11)) + 4|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = HEAP32[$10>>2]|0;
  $15 = ((($14)) + 4|0);
  HEAP32[$15>>2] = $13;
  $16 = HEAP32[$12>>2]|0;
  HEAP32[$16>>2] = $14;
  HEAP32[$6>>2] = 0;
  $17 = ($10|0)==($5|0);
  if (!($17)) {
   $$023$i$i$i = $10;
   while(1) {
    $18 = ((($$023$i$i$i)) + 4|0);
    $19 = HEAP32[$18>>2]|0;
    __ZdlPv($$023$i$i$i);
    $20 = ($19|0)==($5|0);
    if ($20) {
     break;
    } else {
     $$023$i$i$i = $19;
    }
   }
  }
 }
 $21 = ((($0)) + 72|0);
 HEAP8[$21>>0] = 0;
 $22 = HEAP32[$1>>2]|0;
 $23 = ((($22)) + 12|0);
 $24 = HEAP32[$23>>2]|0;
 (FUNCTION_TABLE_ii[$24 & 8191]($1)|0);
 $25 = ((($0)) + 32|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = HEAP32[$1>>2]|0;
 $28 = ((($27)) + 8|0);
 $29 = HEAP32[$28>>2]|0;
 (FUNCTION_TABLE_ii[$29 & 8191]($1)|0);
 __THREW__ = 0;
 $30 = (invoke_ii(3276,12)|0);
 $31 = __THREW__; __THREW__ = 0;
 $32 = $31&1;
 if (!($32)) {
  $33 = ((($30)) + 8|0);
  HEAP32[$33>>2] = $26;
  $34 = ((($30)) + 4|0);
  HEAP32[$34>>2] = $5;
  $35 = HEAP32[$5>>2]|0;
  HEAP32[$30>>2] = $35;
  $36 = ((($35)) + 4|0);
  HEAP32[$36>>2] = $30;
  HEAP32[$5>>2] = $30;
  $37 = HEAP32[$6>>2]|0;
  $38 = (($37) + 1)|0;
  HEAP32[$6>>2] = $38;
  HEAP8[$21>>0] = 1;
  $39 = ((($0)) + 52|0);
  __THREW__ = 0;
  (invoke_ii(2504,($39|0))|0);
  $40 = __THREW__; __THREW__ = 0;
  $41 = $40&1;
  if (!($41)) {
   $51 = HEAP32[$1>>2]|0;
   $52 = ((($51)) + 12|0);
   $53 = HEAP32[$52>>2]|0;
   (FUNCTION_TABLE_ii[$53 & 8191]($1)|0);
   $54 = ((($0)) + 36|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = HEAP32[$1>>2]|0;
   $57 = ((($56)) + 8|0);
   $58 = HEAP32[$57>>2]|0;
   (FUNCTION_TABLE_ii[$58 & 8191]($1)|0);
   __THREW__ = 0;
   $59 = (invoke_ii(3276,12)|0);
   $60 = __THREW__; __THREW__ = 0;
   $61 = $60&1;
   if (!($61)) {
    $62 = ((($59)) + 8|0);
    HEAP32[$62>>2] = $55;
    $63 = ((($59)) + 4|0);
    HEAP32[$63>>2] = $5;
    $64 = HEAP32[$5>>2]|0;
    HEAP32[$59>>2] = $64;
    $65 = ((($64)) + 4|0);
    HEAP32[$65>>2] = $59;
    HEAP32[$5>>2] = $59;
    $66 = HEAP32[$6>>2]|0;
    $67 = (($66) + 1)|0;
    HEAP32[$6>>2] = $67;
    HEAP8[$21>>0] = 1;
    __THREW__ = 0;
    (invoke_ii(2504,($39|0))|0);
    $68 = __THREW__; __THREW__ = 0;
    $69 = $68&1;
    if (!($69)) {
     $79 = HEAP32[$1>>2]|0;
     $80 = ((($79)) + 12|0);
     $81 = HEAP32[$80>>2]|0;
     (FUNCTION_TABLE_ii[$81 & 8191]($1)|0);
     $82 = ((($0)) + 76|0);
     $83 = HEAP32[$82>>2]|0;
     $84 = ((($83)) + 8|0);
     $85 = HEAP32[$84>>2]|0;
     (FUNCTION_TABLE_ii[$85 & 8191]($82)|0);
     $86 = ((($0)) + 96|0);
     $87 = ((($0)) + 104|0);
     $88 = HEAP32[$87>>2]|0;
     $89 = ($88|0)==(0);
     if ($89) {
      $102 = ((($0)) + 108|0);
      HEAP8[$102>>0] = 0;
      $103 = HEAP32[$82>>2]|0;
      $104 = ((($103)) + 12|0);
      $105 = HEAP32[$104>>2]|0;
      (FUNCTION_TABLE_ii[$105 & 8191]($82)|0);
      return;
     }
     $90 = ((($0)) + 100|0);
     $91 = HEAP32[$90>>2]|0;
     $92 = HEAP32[$86>>2]|0;
     $93 = ((($92)) + 4|0);
     $94 = HEAP32[$93>>2]|0;
     $95 = HEAP32[$91>>2]|0;
     $96 = ((($95)) + 4|0);
     HEAP32[$96>>2] = $94;
     $97 = HEAP32[$93>>2]|0;
     HEAP32[$97>>2] = $95;
     HEAP32[$87>>2] = 0;
     $98 = ($91|0)==($86|0);
     if ($98) {
      $102 = ((($0)) + 108|0);
      HEAP8[$102>>0] = 0;
      $103 = HEAP32[$82>>2]|0;
      $104 = ((($103)) + 12|0);
      $105 = HEAP32[$104>>2]|0;
      (FUNCTION_TABLE_ii[$105 & 8191]($82)|0);
      return;
     } else {
      $$023$i$i$i3 = $91;
     }
     while(1) {
      $99 = ((($$023$i$i$i3)) + 4|0);
      $100 = HEAP32[$99>>2]|0;
      __ZdlPv($$023$i$i$i3);
      $101 = ($100|0)==($86|0);
      if ($101) {
       break;
      } else {
       $$023$i$i$i3 = $100;
      }
     }
     $102 = ((($0)) + 108|0);
     HEAP8[$102>>0] = 0;
     $103 = HEAP32[$82>>2]|0;
     $104 = ((($103)) + 12|0);
     $105 = HEAP32[$104>>2]|0;
     (FUNCTION_TABLE_ii[$105 & 8191]($82)|0);
     return;
    }
   }
   $70 = ___cxa_find_matching_catch_2()|0;
   $71 = tempRet0;
   $72 = HEAP32[$1>>2]|0;
   $73 = ((($72)) + 12|0);
   $74 = HEAP32[$73>>2]|0;
   __THREW__ = 0;
   (invoke_ii($74|0,($1|0))|0);
   $75 = __THREW__; __THREW__ = 0;
   $76 = $75&1;
   if ($76) {
    $77 = ___cxa_find_matching_catch_3(0|0)|0;
    $78 = tempRet0;
    ___clang_call_terminate($77);
    // unreachable;
   } else {
    ___resumeException($70|0);
    // unreachable;
   }
  }
 }
 $42 = ___cxa_find_matching_catch_2()|0;
 $43 = tempRet0;
 $44 = HEAP32[$1>>2]|0;
 $45 = ((($44)) + 12|0);
 $46 = HEAP32[$45>>2]|0;
 __THREW__ = 0;
 (invoke_ii($46|0,($1|0))|0);
 $47 = __THREW__; __THREW__ = 0;
 $48 = $47&1;
 if ($48) {
  $49 = ___cxa_find_matching_catch_3(0|0)|0;
  $50 = tempRet0;
  ___clang_call_terminate($49);
  // unreachable;
 } else {
  ___resumeException($42|0);
  // unreachable;
 }
}
function __ZN9osgViewer8Renderer15updateSceneViewEPN7osgUtil9SceneViewE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$ = 0, $$0 = 0, $$077 = 0, $$ph81 = 0, $$pre$phi93Z2D = 0, $$sink = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $187 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + 220|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $9 = ((($0)) + 20|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10|0)==(0|0);
  if ($11) {
   $16 = 0;
  } else {
   $12 = ((($10)) + 24|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = ($13|0)==(0|0);
   $$ = $14 ? 0 : $3;
   $16 = $$;
  }
 } else {
  $7 = ((($5)) + 16|0);
  $8 = HEAP32[$7>>2]|0;
  $16 = $8;
 }
 $15 = ($3|0)==($16|0);
 if ($15) {
  $21 = (__ZN3osg4Node19getOrCreateStateSetEv($3)|0);
  $$0 = $21;$$077 = 0;
 } else {
  $17 = (__ZN3osg4Node19getOrCreateStateSetEv($16)|0);
  $18 = HEAP32[$2>>2]|0;
  $19 = ((($18)) + 120|0);
  $20 = HEAP32[$19>>2]|0;
  $$0 = $17;$$077 = $20;
 }
 $22 = ((($1)) + 216|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)==($$0|0);
 if (!($24)) {
  HEAP32[$22>>2] = $$0;
  $25 = ($$0|0)==(0|0);
  if (!($25)) {
   $26 = ((($$0)) + 8|0);
   $27 = HEAP32[$26>>2]|0;HEAP32[$26>>2] = (($27+1)|0);
  }
  $28 = ($23|0)==(0|0);
  if (!($28)) {
   $29 = ((($23)) + 8|0);
   $30 = HEAP32[$29>>2]|0;HEAP32[$29>>2] = (($30-1)|0);
   $31 = ($30|0)==(1);
   if ($31) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($23,1,1);
   }
  }
 }
 $32 = ((($1)) + 228|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ($33|0)==($$077|0);
 if (!($34)) {
  HEAP32[$32>>2] = $$077;
  $35 = ($$077|0)==(0|0);
  if (!($35)) {
   $36 = ((($$077)) + 8|0);
   $37 = HEAP32[$36>>2]|0;HEAP32[$36>>2] = (($37+1)|0);
  }
  $38 = ($33|0)==(0|0);
  if (!($38)) {
   $39 = ((($33)) + 8|0);
   $40 = HEAP32[$39>>2]|0;HEAP32[$39>>2] = (($40-1)|0);
   $41 = ($40|0)==(1);
   if ($41) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($33,1,1);
   }
  }
 }
 $42 = HEAP32[$2>>2]|0;
 $43 = ((($42)) + 624|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = ($44|0)==(0|0);
 if ($45) {
  $51 = 0;
 } else {
  $46 = ((($44)) + 48|0);
  $47 = HEAP32[$46>>2]|0;
  $51 = $47;
 }
 $48 = ((($1)) + 100|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = ($49|0)==($51|0);
 if (!($50)) {
  HEAP32[$48>>2] = $51;
  $52 = ($51|0)==(0|0);
  if (!($52)) {
   $53 = ((($51)) + 8|0);
   $54 = HEAP32[$53>>2]|0;HEAP32[$53>>2] = (($54+1)|0);
  }
  $55 = ($49|0)==(0|0);
  if (!($55)) {
   $56 = ((($49)) + 8|0);
   $57 = HEAP32[$56>>2]|0;HEAP32[$56>>2] = (($57-1)|0);
   $58 = ($57|0)==(1);
   if ($58) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($49,1,1);
   }
  }
 }
 $59 = HEAP32[$2>>2]|0;
 $60 = ((($59)) + 220|0);
 $61 = HEAP32[$60>>2]|0;
 $62 = ($61|0)==(0|0);
 if ($62) {
  label = 42;
 } else {
  $63 = (___dynamic_cast($61,27072,3928,0)|0);
  $64 = ($63|0)==(0|0);
  if ($64) {
   label = 42;
  } else {
   $65 = ((($63)) + 40|0);
   $66 = HEAP32[$65>>2]|0;
   $67 = ($66|0)==(0|0);
   if ($67) {
    $$sink = 1;
   } else {
    $68 = ((($66)) + 24|0);
    $69 = HEAP32[$68>>2]|0;
    $70 = ($69|0)==(0|0);
    if ($70) {
     $$sink = 1;
    } else {
     $71 = ((($63)) + 44|0);
     $72 = HEAP32[$71>>2]|0;
     $73 = ($72|0)==(0|0);
     if ($73) {
      $$ph81 = 1;
     } else {
      $74 = ((($72)) + 88|0);
      $75 = HEAP32[$74>>2]|0;
      $phitmp = ($75|0)==(0|0);
      $$ph81 = $phitmp;
     }
     $76 = $$ph81&1;
     $$sink = $76;
    }
   }
   $77 = ((($1)) + 245|0);
   HEAP8[$77>>0] = $$sink;
   $78 = (__ZN9osgViewer4View16getDatabasePagerEv($63)|0);
   $79 = ((($1)) + 148|0);
   $80 = HEAP32[$79>>2]|0;
   $81 = ((($80)) + 40|0);
   $82 = HEAP32[$81>>2]|0;
   $83 = ($82|0)==($78|0);
   if (!($83)) {
    HEAP32[$81>>2] = $78;
    $84 = ($78|0)==(0|0);
    if (!($84)) {
     $85 = ((($78)) + 8|0);
     $86 = HEAP32[$85>>2]|0;HEAP32[$85>>2] = (($86+1)|0);
    }
    $87 = ($82|0)==(0|0);
    if (!($87)) {
     $88 = ((($82)) + 8|0);
     $89 = HEAP32[$88>>2]|0;HEAP32[$88>>2] = (($89-1)|0);
     $90 = ($89|0)==(1);
     if ($90) {
      __ZNK3osg10Referenced24signalObserversAndDeleteEbb($82,1,1);
     }
    }
   }
   $91 = (__ZN9osgViewer4View13getImagePagerEv($63)|0);
   $$pre$phi93Z2D = $79;$105 = $91;$114 = $63;$187 = 1;
  }
 }
 if ((label|0) == 42) {
  $92 = ((($1)) + 245|0);
  HEAP8[$92>>0] = 1;
  $93 = ((($1)) + 148|0);
  $94 = HEAP32[$93>>2]|0;
  $95 = ((($94)) + 40|0);
  $96 = HEAP32[$95>>2]|0;
  $97 = ($96|0)==(0|0);
  if ($97) {
   $$pre$phi93Z2D = $93;$105 = 0;$114 = 0;$187 = 0;
  } else {
   HEAP32[$95>>2] = 0;
   $98 = ((($96)) + 8|0);
   $99 = HEAP32[$98>>2]|0;HEAP32[$98>>2] = (($99-1)|0);
   $100 = ($99|0)==(1);
   if ($100) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($96,1,1);
    $$pre$phi93Z2D = $93;$105 = 0;$114 = 0;$187 = 0;
   } else {
    $$pre$phi93Z2D = $93;$105 = 0;$114 = 0;$187 = 0;
   }
  }
 }
 $101 = HEAP32[$$pre$phi93Z2D>>2]|0;
 $102 = ((($101)) + 44|0);
 $103 = HEAP32[$102>>2]|0;
 $104 = ($103|0)==($105|0);
 if (!($104)) {
  HEAP32[$102>>2] = $105;
  $106 = ($105|0)==(0|0);
  if (!($106)) {
   $107 = ((($105)) + 8|0);
   $108 = HEAP32[$107>>2]|0;HEAP32[$107>>2] = (($108+1)|0);
  }
  $109 = ($103|0)==(0|0);
  if (!($109)) {
   $110 = ((($103)) + 8|0);
   $111 = HEAP32[$110>>2]|0;HEAP32[$110>>2] = (($111-1)|0);
   $112 = ($111|0)==(1);
   if ($112) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($103,1,1);
   }
  }
 }
 if ($187) {
  $113 = ((($114)) + 32|0);
  $115 = HEAP32[$113>>2]|0;
  $116 = ($115|0)==(0|0);
  if ($116) {
   label = 54;
  } else {
   $117 = ((($1)) + 200|0);
   $118 = HEAP32[$117>>2]|0;
   (__ZN3osg10FrameStampaSERKS0_($118,$115)|0);
  }
 } else {
  label = 54;
 }
 if ((label|0) == 54) {
  $119 = ((($51)) + 160|0);
  $120 = HEAP32[$119>>2]|0;
  $121 = ($120|0)==(0|0);
  if (!($121)) {
   $122 = ((($1)) + 200|0);
   $123 = HEAP32[$122>>2]|0;
   (__ZN3osg10FrameStampaSERKS0_($123,$120)|0);
  }
 }
 $124 = HEAP32[$2>>2]|0;
 $125 = ((($124)) + 232|0);
 $126 = HEAP32[$125>>2]|0;
 $127 = ($126|0)==(0|0);
 do {
  if ($127) {
   if ($187) {
    $128 = ((($114)) + 116|0);
    $129 = HEAP32[$128>>2]|0;
    $130 = ($129|0)==(0|0);
    if (!($130)) {
     $135 = $129;
     label = 60;
     break;
    }
   }
   $131 = (__ZN3osg15DisplaySettings8instanceEv()|0);
   $132 = HEAP32[$131>>2]|0;
   $133 = ($132|0)==(0|0);
   if (!($133)) {
    $135 = $132;
    label = 60;
   }
  } else {
   $135 = $126;
   label = 60;
  }
 } while(0);
 if ((label|0) == 60) {
  $134 = ((($135)) + 94|0);
  $136 = HEAP8[$134>>0]|0;
  $137 = ($136<<24>>24)==(0);
  if (!($137)) {
   $138 = ((($1)) + 224|0);
   $139 = HEAP32[$138>>2]|0;
   $140 = ($139|0)==($135|0);
   if (!($140)) {
    HEAP32[$138>>2] = $135;
    $141 = ((($135)) + 8|0);
    $142 = HEAP32[$141>>2]|0;HEAP32[$141>>2] = (($142+1)|0);
    $143 = ($139|0)==(0|0);
    if (!($143)) {
     $144 = ((($139)) + 8|0);
     $145 = HEAP32[$144>>2]|0;HEAP32[$144>>2] = (($145-1)|0);
     $146 = ($145|0)==(1);
     if ($146) {
      __ZNK3osg10Referenced24signalObserversAndDeleteEbb($139,1,1);
     }
    }
   }
  }
 }
 if ($187) {
  $147 = ((($114)) + 48|0);
  $148 = $147;
  $149 = $148;
  $150 = HEAP32[$149>>2]|0;
  $151 = (($148) + 4)|0;
  $152 = $151;
  $153 = HEAP32[$152>>2]|0;
  $154 = ((($0)) + 120|0);
  $155 = $154;
  $156 = $155;
  HEAP32[$156>>2] = $150;
  $157 = (($155) + 4)|0;
  $158 = $157;
  HEAP32[$158>>2] = $153;
  $159 = ($51|0)==(0|0);
  if ($159) {
   return;
  }
  $160 = ((($51)) + 864|0);
  $161 = $160;
  $162 = $161;
  HEAP32[$162>>2] = $150;
  $163 = (($161) + 4)|0;
  $164 = $163;
  HEAP32[$164>>2] = $153;
  return;
 }
 if ($45) {
  return;
 }
 $165 = (___dynamic_cast($44,24816,3888,0)|0);
 $166 = ($165|0)==(0|0);
 if ($166) {
  return;
 }
 $167 = ((($165)) + 136|0);
 $168 = HEAP32[$167>>2]|0;
 $169 = ((($168)) + 24|0);
 $170 = $169;
 $171 = $170;
 $172 = HEAP32[$171>>2]|0;
 $173 = (($170) + 4)|0;
 $174 = $173;
 $175 = HEAP32[$174>>2]|0;
 $176 = ((($0)) + 120|0);
 $177 = $176;
 $178 = $177;
 HEAP32[$178>>2] = $172;
 $179 = (($177) + 4)|0;
 $180 = $179;
 HEAP32[$180>>2] = $175;
 $181 = ($51|0)==(0|0);
 if ($181) {
  return;
 }
 $182 = ((($51)) + 864|0);
 $183 = $182;
 $184 = $183;
 HEAP32[$184>>2] = $172;
 $185 = (($183) + 4)|0;
 $186 = $185;
 HEAP32[$186>>2] = $175;
 return;
}
function __ZTv0_n16_N9osgViewer8RendererD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __THREW__ = 0;
 invoke_vii(3502,($4|0),(41864|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if (!($6)) {
  $14 = ((($4)) + 128|0);
  __ZN3osg10ReferencedD2Ev($14);
  return;
 }
 $7 = ___cxa_find_matching_catch_2()|0;
 $8 = tempRet0;
 $9 = ((($4)) + 128|0);
 __THREW__ = 0;
 invoke_vi(712,($9|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if ($11) {
  $12 = ___cxa_find_matching_catch_3(0|0)|0;
  $13 = tempRet0;
  ___clang_call_terminate($12);
  // unreachable;
 } else {
  ___resumeException($7|0);
  // unreachable;
 }
}
function __ZTv0_n16_N9osgViewer8RendererD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$i$index2Z2D = 0, $eh$lpad$body$i$indexZ2D = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __THREW__ = 0;
 invoke_vii(3502,($4|0),(41864|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $10 = ___cxa_find_matching_catch_2()|0;
  $11 = tempRet0;
  $12 = ((($4)) + 128|0);
  __THREW__ = 0;
  invoke_vi(712,($12|0));
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if ($14) {
   $15 = ___cxa_find_matching_catch_3(0|0)|0;
   $16 = tempRet0;
   ___clang_call_terminate($15);
   // unreachable;
  } else {
   $eh$lpad$body$i$index2Z2D = $11;$eh$lpad$body$i$indexZ2D = $10;
   __ZdlPv($4);
   ___resumeException($eh$lpad$body$i$indexZ2D|0);
   // unreachable;
  }
 }
 $7 = ((($4)) + 128|0);
 __THREW__ = 0;
 invoke_vi(712,($7|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if (!($9)) {
  __ZdlPv($4);
  return;
 }
 $17 = ___cxa_find_matching_catch_2()|0;
 $18 = tempRet0;
 $eh$lpad$body$i$index2Z2D = $18;$eh$lpad$body$i$indexZ2D = $17;
 __ZdlPv($4);
 ___resumeException($eh$lpad$body$i$indexZ2D|0);
 // unreachable;
}
function __ZN9osgViewer8RendererD2Ev($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$023$i$i$i = 0, $$023$i$i$i17 = 0, $$023$i$i$i26 = 0, $$023$i$i$i33 = 0, $$03 = 0, $$1 = 0, $$14 = 0, $$2 = 0, $$25 = 0, $$3 = 0, $$36 = 0, $$4 = 0, $$47 = 0, $$cast = 0, $$cast$i$i = 0, $$cast$i$i46 = 0, $$lcssa = 0, $10 = 0, $100 = 0;
 var $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0;
 var $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0;
 var $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0;
 var $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0;
 var $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0;
 var $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0;
 var $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0;
 var $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0;
 var $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0;
 var $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, $eh$lpad$body16$index7Z2D = 0, $eh$lpad$body16$indexZ2D = 0, $eh$lpad$body22$index12Z2D = 0, $eh$lpad$body22$indexZ2D = 0;
 var $eh$lpad$body31$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $3;
 $4 = ((($1)) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $$cast = $3;
 $6 = ((($$cast)) + -12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($0) + ($7)|0);
 HEAP32[$8>>2] = $5;
 __THREW__ = 0;
 $9 = (invoke_ii(3265,5)|0);
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 L1: do {
  if ($11) {
   label = 15;
  } else {
   do {
    if ($9) {
     __THREW__ = 0;
     $12 = (invoke_ii(3266,5)|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      label = 15;
      break L1;
     }
     __THREW__ = 0;
     $15 = (invoke_iiii(3267,($12|0),(108221|0),18)|0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      label = 15;
      break L1;
     }
     __THREW__ = 0;
     $18 = (invoke_iii(3275,($15|0),($0|0))|0);
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      label = 15;
      break L1;
     }
     $21 = HEAP32[$18>>2]|0;
     $22 = ((($21)) + -12|0);
     $23 = HEAP32[$22>>2]|0;
     $24 = (($18) + ($23)|0);
     __THREW__ = 0;
     invoke_vii(3257,($2|0),($24|0));
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if ($26) {
      label = 15;
      break L1;
     }
     __THREW__ = 0;
     $27 = (invoke_iii(3255,($2|0),(215188|0))|0);
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if (!($29)) {
      $30 = HEAP32[$27>>2]|0;
      $31 = ((($30)) + 28|0);
      $32 = HEAP32[$31>>2]|0;
      __THREW__ = 0;
      $33 = (invoke_iii($32|0,($27|0),10)|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if (!($35)) {
       __THREW__ = 0;
       invoke_vi(3263,($2|0));
       $42 = __THREW__; __THREW__ = 0;
       $43 = $42&1;
       if ($43) {
        label = 15;
        break L1;
       }
       __THREW__ = 0;
       (invoke_iii(3268,($18|0),($33|0))|0);
       $44 = __THREW__; __THREW__ = 0;
       $45 = $44&1;
       if ($45) {
        label = 15;
        break L1;
       }
       __THREW__ = 0;
       (invoke_ii(3269,($18|0))|0);
       $46 = __THREW__; __THREW__ = 0;
       $47 = $46&1;
       if ($47) {
        label = 15;
        break L1;
       } else {
        break;
       }
      }
     }
     $36 = ___cxa_find_matching_catch_2()|0;
     $37 = tempRet0;
     __THREW__ = 0;
     invoke_vi(3263,($2|0));
     $38 = __THREW__; __THREW__ = 0;
     $39 = $38&1;
     if ($39) {
      $40 = ___cxa_find_matching_catch_3(0|0)|0;
      $41 = tempRet0;
      ___clang_call_terminate($40);
      // unreachable;
     } else {
      $eh$lpad$body$index2Z2D = $37;$eh$lpad$body$indexZ2D = $36;
      label = 16;
      break L1;
     }
    }
   } while(0);
   $58 = ((($0)) + 116|0);
   $59 = HEAP32[$58>>2]|0;
   $60 = ($59|0)==(0|0);
   if (!($60)) {
    $61 = ((($59)) + 8|0);
    $62 = HEAP32[$61>>2]|0;HEAP32[$61>>2] = (($62-1)|0);
    $63 = ($62|0)==(1);
    if ($63) {
     __THREW__ = 0;
     invoke_viii(3262,($59|0),1,1);
     $64 = __THREW__; __THREW__ = 0;
     $65 = $64&1;
     if ($65) {
      $153 = ___cxa_find_matching_catch_2()|0;
      $154 = tempRet0;
      $$0 = $154;$$03 = $153;
      label = 49;
      break;
     }
    }
   }
   HEAP32[$58>>2] = 0;
   $66 = ((($0)) + 76|0);
   $67 = ((($0)) + 96|0);
   $68 = ((($0)) + 104|0);
   $69 = HEAP32[$68>>2]|0;
   $70 = ($69|0)==(0);
   if (!($70)) {
    $71 = ((($0)) + 100|0);
    $72 = HEAP32[$71>>2]|0;
    $73 = HEAP32[$67>>2]|0;
    $74 = ((($73)) + 4|0);
    $75 = HEAP32[$74>>2]|0;
    $76 = HEAP32[$72>>2]|0;
    $77 = ((($76)) + 4|0);
    HEAP32[$77>>2] = $75;
    $78 = HEAP32[$74>>2]|0;
    HEAP32[$78>>2] = $76;
    HEAP32[$68>>2] = 0;
    $79 = ($72|0)==($67|0);
    if (!($79)) {
     $$023$i$i$i = $72;
     while(1) {
      $80 = ((($$023$i$i$i)) + 4|0);
      $81 = HEAP32[$80>>2]|0;
      __ZdlPv($$023$i$i$i);
      $82 = ($81|0)==($67|0);
      if ($82) {
       break;
      } else {
       $$023$i$i$i = $81;
      }
     }
    }
   }
   $83 = ((($0)) + 88|0);
   __THREW__ = 0;
   invoke_vi(2499,($83|0));
   $84 = __THREW__; __THREW__ = 0;
   $85 = $84&1;
   do {
    if ($85) {
     $88 = ___cxa_find_matching_catch_2()|0;
     $89 = tempRet0;
     __THREW__ = 0;
     invoke_vi(707,($66|0));
     $90 = __THREW__; __THREW__ = 0;
     $91 = $90&1;
     if ($91) {
      $92 = ___cxa_find_matching_catch_3(0|0)|0;
      $93 = tempRet0;
      ___clang_call_terminate($92);
      // unreachable;
     } else {
      $eh$lpad$body16$index7Z2D = $89;$eh$lpad$body16$indexZ2D = $88;
     }
    } else {
     __THREW__ = 0;
     invoke_vi(707,($66|0));
     $86 = __THREW__; __THREW__ = 0;
     $87 = $86&1;
     if ($87) {
      $155 = ___cxa_find_matching_catch_2()|0;
      $156 = tempRet0;
      $eh$lpad$body16$index7Z2D = $156;$eh$lpad$body16$indexZ2D = $155;
      break;
     }
     $94 = ((($0)) + 40|0);
     $95 = ((($0)) + 60|0);
     $96 = ((($0)) + 68|0);
     $97 = HEAP32[$96>>2]|0;
     $98 = ($97|0)==(0);
     if (!($98)) {
      $99 = ((($0)) + 64|0);
      $100 = HEAP32[$99>>2]|0;
      $101 = HEAP32[$95>>2]|0;
      $102 = ((($101)) + 4|0);
      $103 = HEAP32[$102>>2]|0;
      $104 = HEAP32[$100>>2]|0;
      $105 = ((($104)) + 4|0);
      HEAP32[$105>>2] = $103;
      $106 = HEAP32[$102>>2]|0;
      HEAP32[$106>>2] = $104;
      HEAP32[$96>>2] = 0;
      $107 = ($100|0)==($95|0);
      if (!($107)) {
       $$023$i$i$i17 = $100;
       while(1) {
        $108 = ((($$023$i$i$i17)) + 4|0);
        $109 = HEAP32[$108>>2]|0;
        __ZdlPv($$023$i$i$i17);
        $110 = ($109|0)==($95|0);
        if ($110) {
         break;
        } else {
         $$023$i$i$i17 = $109;
        }
       }
      }
     }
     $111 = ((($0)) + 52|0);
     __THREW__ = 0;
     invoke_vi(2499,($111|0));
     $112 = __THREW__; __THREW__ = 0;
     $113 = $112&1;
     do {
      if ($113) {
       $116 = ___cxa_find_matching_catch_2()|0;
       $117 = tempRet0;
       __THREW__ = 0;
       invoke_vi(707,($94|0));
       $118 = __THREW__; __THREW__ = 0;
       $119 = $118&1;
       if ($119) {
        $120 = ___cxa_find_matching_catch_3(0|0)|0;
        $121 = tempRet0;
        ___clang_call_terminate($120);
        // unreachable;
       } else {
        $eh$lpad$body22$index12Z2D = $117;$eh$lpad$body22$indexZ2D = $116;
       }
      } else {
       __THREW__ = 0;
       invoke_vi(707,($94|0));
       $114 = __THREW__; __THREW__ = 0;
       $115 = $114&1;
       if ($115) {
        $185 = ___cxa_find_matching_catch_2()|0;
        $186 = tempRet0;
        $eh$lpad$body22$index12Z2D = $186;$eh$lpad$body22$indexZ2D = $185;
        break;
       }
       $122 = ((($0)) + 32|0);
       $123 = ((($0)) + 36|0);
       $124 = HEAP32[$123>>2]|0;
       $125 = ($124|0)==(0|0);
       if ($125) {
        label = 40;
       } else {
        $126 = ((($124)) + 8|0);
        $127 = HEAP32[$126>>2]|0;HEAP32[$126>>2] = (($127-1)|0);
        $128 = ($127|0)==(1);
        if ($128) {
         __THREW__ = 0;
         invoke_viii(3262,($124|0),1,1);
         $129 = __THREW__; __THREW__ = 0;
         $130 = $129&1;
         if ($130) {
          $$lcssa = $123;
         } else {
          label = 40;
         }
        } else {
         label = 40;
        }
       }
       do {
        if ((label|0) == 40) {
         HEAP32[$123>>2] = 0;
         $131 = ((($0)) + 32|0);
         $132 = HEAP32[$131>>2]|0;
         $133 = ($132|0)==(0|0);
         if (!($133)) {
          $267 = ((($132)) + 8|0);
          $268 = HEAP32[$267>>2]|0;HEAP32[$267>>2] = (($268-1)|0);
          $269 = ($268|0)==(1);
          if ($269) {
           __THREW__ = 0;
           invoke_viii(3262,($132|0),1,1);
           $270 = __THREW__; __THREW__ = 0;
           $271 = $270&1;
           if ($271) {
            $$lcssa = $131;
            break;
           }
          }
         }
         HEAP32[$131>>2] = 0;
         $140 = ((($0)) + 20|0);
         $135 = HEAP32[$140>>2]|0;
         $272 = ($135|0)==(0|0);
         if (!($272)) {
          $134 = ((($135)) + 8|0);
          $136 = HEAP32[$134>>2]|0;HEAP32[$134>>2] = (($136-1)|0);
          $137 = ($136|0)==(1);
          if ($137) {
           __THREW__ = 0;
           invoke_viii(3262,($135|0),1,1);
           $138 = __THREW__; __THREW__ = 0;
           $139 = $138&1;
           if ($139) {
            $239 = ___cxa_find_matching_catch_2()|0;
            $240 = tempRet0;
            $$4 = $240;$$47 = $239;
            break L1;
           }
          }
         }
         HEAP32[$140>>2] = 0;
         $141 = ((($1)) + 8|0);
         $142 = HEAP32[$141>>2]|0;
         HEAP32[$0>>2] = $142;
         $143 = ((($1)) + 12|0);
         $144 = HEAP32[$143>>2]|0;
         $$cast$i$i = $142;
         $145 = ((($$cast$i$i)) + -12|0);
         $146 = HEAP32[$145>>2]|0;
         $147 = (($0) + ($146)|0);
         HEAP32[$147>>2] = $144;
         $148 = ((($0)) + 4|0);
         $149 = ((($148)) + 11|0);
         $150 = HEAP8[$149>>0]|0;
         $151 = ($150<<24>>24)<(0);
         if (!($151)) {
          STACKTOP = sp;return;
         }
         $152 = HEAP32[$148>>2]|0;
         __ZdlPv($152);
         STACKTOP = sp;return;
        }
       } while(0);
       $215 = ___cxa_find_matching_catch_2()|0;
       $216 = tempRet0;
       $217 = ($122|0)==($$lcssa|0);
       if ($217) {
        $$3 = $216;$$36 = $215;
        label = 75;
        break L1;
       } else {
        $219 = $$lcssa;
       }
       while(1) {
        $218 = ((($219)) + -4|0);
        $220 = HEAP32[$218>>2]|0;
        $221 = ($220|0)==(0|0);
        if (!($221)) {
         $222 = ((($220)) + 8|0);
         $223 = HEAP32[$222>>2]|0;HEAP32[$222>>2] = (($223-1)|0);
         $224 = ($223|0)==(1);
         if ($224) {
          __THREW__ = 0;
          invoke_viii(3262,($220|0),1,1);
          $225 = __THREW__; __THREW__ = 0;
          $226 = $225&1;
          if ($226) {
           break;
          }
         }
        }
        HEAP32[$218>>2] = 0;
        $227 = ($218|0)==($122|0);
        if ($227) {
         $$3 = $216;$$36 = $215;
         label = 75;
         break L1;
        } else {
         $219 = $218;
        }
       }
       $261 = ___cxa_find_matching_catch_3(0|0)|0;
       $262 = tempRet0;
       $eh$lpad$body31$indexZ2D = $261;
       ___clang_call_terminate($eh$lpad$body31$indexZ2D);
       // unreachable;
      }
     } while(0);
     $$2 = $eh$lpad$body22$index12Z2D;$$25 = $eh$lpad$body22$indexZ2D;
     label = 70;
     break L1;
    }
   } while(0);
   $$1 = $eh$lpad$body16$index7Z2D;$$14 = $eh$lpad$body16$indexZ2D;
   label = 58;
  }
 } while(0);
 if ((label|0) == 15) {
  $48 = ___cxa_find_matching_catch_2()|0;
  $49 = tempRet0;
  $eh$lpad$body$index2Z2D = $49;$eh$lpad$body$indexZ2D = $48;
  label = 16;
 }
 do {
  if ((label|0) == 16) {
   $50 = ((($0)) + 116|0);
   $51 = HEAP32[$50>>2]|0;
   $52 = ($51|0)==(0|0);
   if (!($52)) {
    $53 = ((($51)) + 8|0);
    $54 = HEAP32[$53>>2]|0;HEAP32[$53>>2] = (($54-1)|0);
    $55 = ($54|0)==(1);
    if ($55) {
     __THREW__ = 0;
     invoke_viii(3262,($51|0),1,1);
     $56 = __THREW__; __THREW__ = 0;
     $57 = $56&1;
     if ($57) {
      label = 84;
      break;
     }
    }
   }
   HEAP32[$50>>2] = 0;
   $$0 = $eh$lpad$body$index2Z2D;$$03 = $eh$lpad$body$indexZ2D;
   label = 49;
  }
 } while(0);
 do {
  if ((label|0) == 49) {
   $157 = ((($0)) + 76|0);
   $158 = ((($0)) + 96|0);
   $159 = ((($0)) + 104|0);
   $160 = HEAP32[$159>>2]|0;
   $161 = ($160|0)==(0);
   if (!($161)) {
    $162 = ((($0)) + 100|0);
    $163 = HEAP32[$162>>2]|0;
    $164 = HEAP32[$158>>2]|0;
    $165 = ((($164)) + 4|0);
    $166 = HEAP32[$165>>2]|0;
    $167 = HEAP32[$163>>2]|0;
    $168 = ((($167)) + 4|0);
    HEAP32[$168>>2] = $166;
    $169 = HEAP32[$165>>2]|0;
    HEAP32[$169>>2] = $167;
    HEAP32[$159>>2] = 0;
    $170 = ($163|0)==($158|0);
    if (!($170)) {
     $$023$i$i$i26 = $163;
     while(1) {
      $171 = ((($$023$i$i$i26)) + 4|0);
      $172 = HEAP32[$171>>2]|0;
      __ZdlPv($$023$i$i$i26);
      $173 = ($172|0)==($158|0);
      if ($173) {
       break;
      } else {
       $$023$i$i$i26 = $172;
      }
     }
    }
   }
   $174 = ((($0)) + 88|0);
   __THREW__ = 0;
   invoke_vi(2499,($174|0));
   $175 = __THREW__; __THREW__ = 0;
   $176 = $175&1;
   if (!($176)) {
    __THREW__ = 0;
    invoke_vi(707,($157|0));
    $177 = __THREW__; __THREW__ = 0;
    $178 = $177&1;
    if ($178) {
     label = 84;
     break;
    } else {
     $$1 = $$0;$$14 = $$03;
     label = 58;
     break;
    }
   }
   $179 = ___cxa_find_matching_catch_3(0|0)|0;
   $180 = tempRet0;
   __THREW__ = 0;
   invoke_vi(707,($157|0));
   $181 = __THREW__; __THREW__ = 0;
   $182 = $181&1;
   if ($182) {
    $183 = ___cxa_find_matching_catch_3(0|0)|0;
    $184 = tempRet0;
    ___clang_call_terminate($183);
    // unreachable;
   } else {
    $eh$lpad$body31$indexZ2D = $179;
    ___clang_call_terminate($eh$lpad$body31$indexZ2D);
    // unreachable;
   }
  }
 } while(0);
 do {
  if ((label|0) == 58) {
   $187 = ((($0)) + 40|0);
   $188 = ((($0)) + 60|0);
   $189 = ((($0)) + 68|0);
   $190 = HEAP32[$189>>2]|0;
   $191 = ($190|0)==(0);
   if (!($191)) {
    $192 = ((($0)) + 64|0);
    $193 = HEAP32[$192>>2]|0;
    $194 = HEAP32[$188>>2]|0;
    $195 = ((($194)) + 4|0);
    $196 = HEAP32[$195>>2]|0;
    $197 = HEAP32[$193>>2]|0;
    $198 = ((($197)) + 4|0);
    HEAP32[$198>>2] = $196;
    $199 = HEAP32[$195>>2]|0;
    HEAP32[$199>>2] = $197;
    HEAP32[$189>>2] = 0;
    $200 = ($193|0)==($188|0);
    if (!($200)) {
     $$023$i$i$i33 = $193;
     while(1) {
      $201 = ((($$023$i$i$i33)) + 4|0);
      $202 = HEAP32[$201>>2]|0;
      __ZdlPv($$023$i$i$i33);
      $203 = ($202|0)==($188|0);
      if ($203) {
       break;
      } else {
       $$023$i$i$i33 = $202;
      }
     }
    }
   }
   $204 = ((($0)) + 52|0);
   __THREW__ = 0;
   invoke_vi(2499,($204|0));
   $205 = __THREW__; __THREW__ = 0;
   $206 = $205&1;
   if (!($206)) {
    __THREW__ = 0;
    invoke_vi(707,($187|0));
    $207 = __THREW__; __THREW__ = 0;
    $208 = $207&1;
    if ($208) {
     label = 84;
     break;
    } else {
     $$2 = $$1;$$25 = $$14;
     label = 70;
     break;
    }
   }
   $209 = ___cxa_find_matching_catch_3(0|0)|0;
   $210 = tempRet0;
   __THREW__ = 0;
   invoke_vi(707,($187|0));
   $211 = __THREW__; __THREW__ = 0;
   $212 = $211&1;
   if ($212) {
    $213 = ___cxa_find_matching_catch_3(0|0)|0;
    $214 = tempRet0;
    ___clang_call_terminate($213);
    // unreachable;
   } else {
    $eh$lpad$body31$indexZ2D = $209;
    ___clang_call_terminate($eh$lpad$body31$indexZ2D);
    // unreachable;
   }
  }
 } while(0);
 L111: do {
  if ((label|0) == 70) {
   $228 = ((($0)) + 36|0);
   $229 = HEAP32[$228>>2]|0;
   $230 = ($229|0)==(0|0);
   if ($230) {
    label = 73;
   } else {
    $231 = ((($229)) + 8|0);
    $232 = HEAP32[$231>>2]|0;HEAP32[$231>>2] = (($232-1)|0);
    $233 = ($232|0)==(1);
    if ($233) {
     __THREW__ = 0;
     invoke_viii(3262,($229|0),1,1);
     $234 = __THREW__; __THREW__ = 0;
     $235 = $234&1;
     if (!($235)) {
      label = 73;
     }
    } else {
     label = 73;
    }
   }
   do {
    if ((label|0) == 73) {
     HEAP32[$228>>2] = 0;
     $236 = ((($0)) + 32|0);
     $237 = HEAP32[$236>>2]|0;
     $238 = ($237|0)==(0|0);
     if (!($238)) {
      $273 = ((($237)) + 8|0);
      $274 = HEAP32[$273>>2]|0;HEAP32[$273>>2] = (($274-1)|0);
      $275 = ($274|0)==(1);
      if ($275) {
       __THREW__ = 0;
       invoke_viii(3262,($237|0),1,1);
       $276 = __THREW__; __THREW__ = 0;
       $277 = $276&1;
       if ($277) {
        break;
       }
      }
     }
     HEAP32[$236>>2] = 0;
     $$3 = $$2;$$36 = $$25;
     label = 75;
     break L111;
    }
   } while(0);
   $263 = ___cxa_find_matching_catch_3(0|0)|0;
   $264 = tempRet0;
   $eh$lpad$body31$indexZ2D = $263;
   ___clang_call_terminate($eh$lpad$body31$indexZ2D);
   // unreachable;
  }
 } while(0);
 do {
  if ((label|0) == 75) {
   $241 = ((($0)) + 20|0);
   $242 = HEAP32[$241>>2]|0;
   $243 = ($242|0)==(0|0);
   if (!($243)) {
    $244 = ((($242)) + 8|0);
    $245 = HEAP32[$244>>2]|0;HEAP32[$244>>2] = (($245-1)|0);
    $246 = ($245|0)==(1);
    if ($246) {
     __THREW__ = 0;
     invoke_viii(3262,($242|0),1,1);
     $247 = __THREW__; __THREW__ = 0;
     $248 = $247&1;
     if ($248) {
      label = 84;
      break;
     }
    }
   }
   HEAP32[$241>>2] = 0;
   $$4 = $$3;$$47 = $$36;
  }
 } while(0);
 if ((label|0) == 84) {
  $265 = ___cxa_find_matching_catch_3(0|0)|0;
  $266 = tempRet0;
  $eh$lpad$body31$indexZ2D = $265;
  ___clang_call_terminate($eh$lpad$body31$indexZ2D);
  // unreachable;
 }
 $249 = ((($1)) + 8|0);
 $250 = HEAP32[$249>>2]|0;
 HEAP32[$0>>2] = $250;
 $251 = ((($1)) + 12|0);
 $252 = HEAP32[$251>>2]|0;
 $$cast$i$i46 = $250;
 $253 = ((($$cast$i$i46)) + -12|0);
 $254 = HEAP32[$253>>2]|0;
 $255 = (($0) + ($254)|0);
 HEAP32[$255>>2] = $252;
 $256 = ((($0)) + 4|0);
 $257 = ((($256)) + 11|0);
 $258 = HEAP8[$257>>0]|0;
 $259 = ($258<<24>>24)<(0);
 if (!($259)) {
  ___resumeException($$47|0);
  // unreachable;
 }
 $260 = HEAP32[$256>>2]|0;
 __ZdlPv($260);
 ___resumeException($$47|0);
 // unreachable;
}
function __ZN3osg9Operation7releaseEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN3osg9OperationD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = ((2636));
 $1 = ((($0)) + 20|0);
 HEAP32[$1>>2] = ((2668));
 $2 = ((($0)) + 4|0);
 $3 = ((($2)) + 11|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)<(0);
 if (!($5)) {
  __ZN3osg10ReferencedD2Ev($1);
  return;
 }
 $6 = HEAP32[$2>>2]|0;
 __ZdlPv($6);
 __ZN3osg10ReferencedD2Ev($1);
 return;
}
function __ZN3osg9OperationD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = ((2636));
 $1 = ((($0)) + 20|0);
 HEAP32[$1>>2] = ((2668));
 $2 = ((($0)) + 4|0);
 $3 = ((($2)) + 11|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)<(0);
 if ($5) {
  $6 = HEAP32[$2>>2]|0;
  __ZdlPv($6);
 }
 __THREW__ = 0;
 invoke_vi(712,($1|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch_2()|0;
  $10 = tempRet0;
  __ZdlPv($0);
  ___resumeException($9|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZTv0_n16_N3osg9OperationD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 HEAP32[$4>>2] = ((2636));
 $5 = ((($4)) + 20|0);
 HEAP32[$5>>2] = ((2668));
 $6 = ((($4)) + 4|0);
 $7 = ((($6)) + 11|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = ($8<<24>>24)<(0);
 if (!($9)) {
  __ZN3osg10ReferencedD2Ev($5);
  return;
 }
 $10 = HEAP32[$6>>2]|0;
 __ZdlPv($10);
 __ZN3osg10ReferencedD2Ev($5);
 return;
}
function __ZTv0_n16_N3osg9OperationD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 HEAP32[$4>>2] = ((2636));
 $5 = ((($4)) + 20|0);
 HEAP32[$5>>2] = ((2668));
 $6 = ((($4)) + 4|0);
 $7 = ((($6)) + 11|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = ($8<<24>>24)<(0);
 if ($9) {
  $10 = HEAP32[$6>>2]|0;
  __ZdlPv($10);
 }
 __THREW__ = 0;
 invoke_vi(712,($5|0));
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if ($12) {
  $13 = ___cxa_find_matching_catch_2()|0;
  $14 = tempRet0;
  __ZdlPv($4);
  ___resumeException($13|0);
  // unreachable;
 } else {
  __ZdlPv($4);
  return;
 }
}
function __ZN3osg17GraphicsOperationD1Ev($0) {
 $0 = $0|0;
 var $$cast$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[(60828)>>2]|0;
 HEAP32[$0>>2] = $1;
 $2 = HEAP32[(60832)>>2]|0;
 $$cast$i$i = $1;
 $3 = ((($$cast$i$i)) + -12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($0) + ($4)|0);
 HEAP32[$5>>2] = $2;
 $6 = ((($0)) + 4|0);
 $7 = ((($6)) + 11|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = ($8<<24>>24)<(0);
 if (!($9)) {
  $11 = ((($0)) + 20|0);
  __ZN3osg10ReferencedD2Ev($11);
  return;
 }
 $10 = HEAP32[$6>>2]|0;
 __ZdlPv($10);
 $11 = ((($0)) + 20|0);
 __ZN3osg10ReferencedD2Ev($11);
 return;
}
function __ZN3osg17GraphicsOperationD0Ev($0) {
 $0 = $0|0;
 var $$cast$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[(60828)>>2]|0;
 HEAP32[$0>>2] = $1;
 $2 = HEAP32[(60832)>>2]|0;
 $$cast$i$i$i = $1;
 $3 = ((($$cast$i$i$i)) + -12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($0) + ($4)|0);
 HEAP32[$5>>2] = $2;
 $6 = ((($0)) + 4|0);
 $7 = ((($6)) + 11|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = ($8<<24>>24)<(0);
 if ($9) {
  $10 = HEAP32[$6>>2]|0;
  __ZdlPv($10);
 }
 $11 = ((($0)) + 20|0);
 __THREW__ = 0;
 invoke_vi(712,($11|0));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $14 = ___cxa_find_matching_catch_2()|0;
  $15 = tempRet0;
  __ZdlPv($0);
  ___resumeException($14|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZTv0_n16_N3osg17GraphicsOperationD1Ev($0) {
 $0 = $0|0;
 var $$cast$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 $5 = HEAP32[(60828)>>2]|0;
 HEAP32[$4>>2] = $5;
 $6 = HEAP32[(60832)>>2]|0;
 $$cast$i$i$i = $5;
 $7 = ((($$cast$i$i$i)) + -12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($4) + ($8)|0);
 HEAP32[$9>>2] = $6;
 $10 = ((($4)) + 4|0);
 $11 = ((($10)) + 11|0);
 $12 = HEAP8[$11>>0]|0;
 $13 = ($12<<24>>24)<(0);
 if (!($13)) {
  $15 = ((($4)) + 20|0);
  __ZN3osg10ReferencedD2Ev($15);
  return;
 }
 $14 = HEAP32[$10>>2]|0;
 __ZdlPv($14);
 $15 = ((($4)) + 20|0);
 __ZN3osg10ReferencedD2Ev($15);
 return;
}
function __ZTv0_n16_N3osg17GraphicsOperationD0Ev($0) {
 $0 = $0|0;
 var $$cast$i$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 $5 = HEAP32[(60828)>>2]|0;
 HEAP32[$4>>2] = $5;
 $6 = HEAP32[(60832)>>2]|0;
 $$cast$i$i$i$i = $5;
 $7 = ((($$cast$i$i$i$i)) + -12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($4) + ($8)|0);
 HEAP32[$9>>2] = $6;
 $10 = ((($4)) + 4|0);
 $11 = ((($10)) + 11|0);
 $12 = HEAP8[$11>>0]|0;
 $13 = ($12<<24>>24)<(0);
 if ($13) {
  $14 = HEAP32[$10>>2]|0;
  __ZdlPv($14);
 }
 $15 = ((($4)) + 20|0);
 __THREW__ = 0;
 invoke_vi(712,($15|0));
 $16 = __THREW__; __THREW__ = 0;
 $17 = $16&1;
 if ($17) {
  $18 = ___cxa_find_matching_catch_2()|0;
  $19 = tempRet0;
  __ZdlPv($4);
  ___resumeException($18|0);
  // unreachable;
 } else {
  __ZdlPv($4);
  return;
 }
}
function __ZN7osgUtil16GLObjectsVisitorD2Ev($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$2 = 0, $$25 = 0, $$cast = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $2;
 $3 = ((($1)) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $$cast = $2;
 $5 = ((($$cast)) + -12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($0) + ($6)|0);
 HEAP32[$7>>2] = $4;
 $8 = ((($0)) + 120|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if ($10) {
  label = 4;
 } else {
  $11 = ((($9)) + 8|0);
  $12 = HEAP32[$11>>2]|0;HEAP32[$11>>2] = (($12-1)|0);
  $13 = ($12|0)==(1);
  if ($13) {
   __THREW__ = 0;
   invoke_viii(3262,($9|0),1,1);
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if ($15) {
    $28 = ___cxa_find_matching_catch_2()|0;
    $29 = tempRet0;
    $30 = ((($0)) + 108|0);
    $31 = ((($0)) + 112|0);
    $32 = HEAP32[$31>>2]|0;
    __ZNSt3__26__treeIPN3osg8StateSetENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($30,$32);
    $33 = ((($0)) + 96|0);
    $34 = ((($0)) + 100|0);
    $35 = HEAP32[$34>>2]|0;
    __ZNSt3__26__treeIPN3osg8DrawableENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($33,$35);
    $36 = ((($0)) + 60|0);
    __THREW__ = 0;
    invoke_vi(3504,($36|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     $42 = ___cxa_find_matching_catch_3(0|0)|0;
     $43 = tempRet0;
     ___clang_call_terminate($42);
     // unreachable;
    } else {
     $$2 = $29;$$25 = $28;
    }
   } else {
    label = 4;
   }
  } else {
   label = 4;
  }
 }
 do {
  if ((label|0) == 4) {
   HEAP32[$8>>2] = 0;
   $16 = ((($0)) + 108|0);
   $17 = ((($0)) + 112|0);
   $18 = HEAP32[$17>>2]|0;
   __ZNSt3__26__treeIPN3osg8StateSetENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($16,$18);
   $19 = ((($0)) + 96|0);
   $20 = ((($0)) + 100|0);
   $21 = HEAP32[$20>>2]|0;
   __ZNSt3__26__treeIPN3osg8DrawableENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($19,$21);
   $22 = ((($0)) + 60|0);
   __THREW__ = 0;
   invoke_vi(3504,($22|0));
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if ($24) {
    $26 = ___cxa_find_matching_catch_2()|0;
    $27 = tempRet0;
    $$2 = $27;$$25 = $26;
    break;
   } else {
    $25 = ((($1)) + 4|0);
    __ZN3osg11NodeVisitorD2Ev($0,$25);
    return;
   }
  }
 } while(0);
 $39 = ((($1)) + 4|0);
 __THREW__ = 0;
 invoke_vii(3284,($0|0),($39|0));
 $40 = __THREW__; __THREW__ = 0;
 $41 = $40&1;
 if ($41) {
  $42 = ___cxa_find_matching_catch_3(0|0)|0;
  $43 = tempRet0;
  ___clang_call_terminate($42);
  // unreachable;
 } else {
  ___resumeException($$25|0);
  // unreachable;
 }
}
function __ZN3osg10RenderInfoD2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i12 = 0, $scevgep$i$i$i4 = 0, $scevgep$i$i$i7 = 0, $scevgep5$i$i$i = 0, $scevgep5$i$i$i13 = 0, $scevgep5$i$i$i5 = 0, $scevgep5$i$i$i8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 32|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = ((($2)) + 8|0);
  $5 = HEAP32[$4>>2]|0;HEAP32[$4>>2] = (($5-1)|0);
  $6 = ($5|0)==(1);
  if ($6) {
   __THREW__ = 0;
   invoke_viii(3262,($2|0),1,1);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $36 = ___cxa_find_matching_catch_2()|0;
    $37 = tempRet0;
    $38 = ((($0)) + 20|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = ($39|0)==(0|0);
    if (!($40)) {
     $41 = ((($0)) + 24|0);
     $42 = HEAP32[$41>>2]|0;
     $43 = ($42|0)==($39|0);
     if (!($43)) {
      $scevgep$i$i$i7 = ((($42)) + -4|0);
      $44 = $scevgep$i$i$i7;
      $45 = $39;
      $46 = (($44) - ($45))|0;
      $47 = $46 >>> 2;
      $48 = $47 ^ -1;
      $scevgep5$i$i$i8 = (($42) + ($48<<2)|0);
      HEAP32[$41>>2] = $scevgep5$i$i$i8;
     }
     __ZdlPv($39);
    }
    $49 = ((($0)) + 8|0);
    $50 = HEAP32[$49>>2]|0;
    $51 = ($50|0)==(0|0);
    if (!($51)) {
     $52 = ((($0)) + 12|0);
     $53 = HEAP32[$52>>2]|0;
     $54 = ($53|0)==($50|0);
     if (!($54)) {
      $scevgep$i$i$i12 = ((($53)) + -4|0);
      $55 = $scevgep$i$i$i12;
      $56 = $50;
      $57 = (($55) - ($56))|0;
      $58 = $57 >>> 2;
      $59 = $58 ^ -1;
      $scevgep5$i$i$i13 = (($53) + ($59<<2)|0);
      HEAP32[$52>>2] = $scevgep5$i$i$i13;
     }
     __ZdlPv($50);
    }
    $60 = HEAP32[$0>>2]|0;
    $61 = ($60|0)==(0|0);
    if ($61) {
     HEAP32[$0>>2] = 0;
     ___resumeException($36|0);
     // unreachable;
    }
    $62 = ((($60)) + 8|0);
    $63 = HEAP32[$62>>2]|0;HEAP32[$62>>2] = (($63-1)|0);
    $64 = ($63|0)==(1);
    if (!($64)) {
     HEAP32[$0>>2] = 0;
     ___resumeException($36|0);
     // unreachable;
    }
    __THREW__ = 0;
    invoke_viii(3262,($60|0),1,1);
    $65 = __THREW__; __THREW__ = 0;
    $66 = $65&1;
    if ($66) {
     $67 = ___cxa_find_matching_catch_3(0|0)|0;
     $68 = tempRet0;
     ___clang_call_terminate($67);
     // unreachable;
    } else {
     HEAP32[$0>>2] = 0;
     ___resumeException($36|0);
     // unreachable;
    }
   }
  }
 }
 HEAP32[$1>>2] = 0;
 $9 = ((($0)) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if (!($11)) {
  $12 = ((($0)) + 24|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($13|0)==($10|0);
  if (!($14)) {
   $scevgep$i$i$i = ((($13)) + -4|0);
   $15 = $scevgep$i$i$i;
   $16 = $10;
   $17 = (($15) - ($16))|0;
   $18 = $17 >>> 2;
   $19 = $18 ^ -1;
   $scevgep5$i$i$i = (($13) + ($19<<2)|0);
   HEAP32[$12>>2] = $scevgep5$i$i$i;
  }
  __ZdlPv($10);
 }
 $20 = ((($0)) + 8|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0|0);
 if (!($22)) {
  $23 = ((($0)) + 12|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = ($24|0)==($21|0);
  if (!($25)) {
   $scevgep$i$i$i4 = ((($24)) + -4|0);
   $26 = $scevgep$i$i$i4;
   $27 = $21;
   $28 = (($26) - ($27))|0;
   $29 = $28 >>> 2;
   $30 = $29 ^ -1;
   $scevgep5$i$i$i5 = (($24) + ($30<<2)|0);
   HEAP32[$23>>2] = $scevgep5$i$i$i5;
  }
  __ZdlPv($21);
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)==(0|0);
 if ($32) {
  HEAP32[$0>>2] = 0;
  return;
 }
 $33 = ((($31)) + 8|0);
 $34 = HEAP32[$33>>2]|0;HEAP32[$33>>2] = (($34-1)|0);
 $35 = ($34|0)==(1);
 if (!($35)) {
  HEAP32[$0>>2] = 0;
  return;
 }
 __ZNK3osg10Referenced24signalObserversAndDeleteEbb($31,1,1);
 HEAP32[$0>>2] = 0;
 return;
}
function __ZN9osgViewer8Renderer10initializeEPN3osg5StateE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$09 = 0, $$pre = 0, $$pre$phiZ2D = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 112|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if (!($4)) {
  return;
 }
 HEAP8[$2>>0] = 1;
 $5 = ((($1)) + 784|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($6)) + 806|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = ($8<<24>>24)==(0);
 if ($9) {
  label = 10;
 } else {
  $10 = ((($1)) + 888|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($11|0)>(0);
  if ($12) {
   $13 = (__Znwj(40)|0);
   dest=$13; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
   __THREW__ = 0;
   invoke_vi(3282,($13|0));
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if ($15) {
    $29 = ___cxa_find_matching_catch_2()|0;
    $30 = tempRet0;
    __ZdlPv($13);
    $$0 = $30;$$09 = $29;
    ___resumeException($$09|0);
    // unreachable;
   }
   $16 = ((($13)) + 12|0);
   HEAP32[$16>>2] = 0;
   HEAP32[$13>>2] = (41896);
   $17 = ((($13)) + 16|0);
   HEAP32[$17>>2] = $17;
   $18 = ((($13)) + 20|0);
   HEAP32[$18>>2] = $17;
   $19 = ((($13)) + 24|0);
   ;HEAP32[$19>>2]=0|0;HEAP32[$19+4>>2]=0|0;HEAP32[$19+8>>2]=0|0;HEAP32[$19+12>>2]=0|0;
   $20 = ((($0)) + 116|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = ($21|0)==($13|0);
   if ($22) {
    $$pre$phiZ2D = $20;
   } else {
    HEAP32[$20>>2] = $13;
    $23 = ((($13)) + 8|0);
    $24 = HEAP32[$23>>2]|0;HEAP32[$23>>2] = (($24+1)|0);
    $25 = ($21|0)==(0|0);
    if ($25) {
     $$pre$phiZ2D = $20;
    } else {
     $26 = ((($21)) + 8|0);
     $27 = HEAP32[$26>>2]|0;HEAP32[$26>>2] = (($27-1)|0);
     $28 = ($27|0)==(1);
     if ($28) {
      __ZNK3osg10Referenced24signalObserversAndDeleteEbb($21,1,1);
      $$pre$phiZ2D = $20;
     } else {
      $$pre$phiZ2D = $20;
     }
    }
   }
  } else {
   label = 10;
  }
 }
 do {
  if ((label|0) == 10) {
   $31 = ((($6)) + 805|0);
   $32 = HEAP8[$31>>0]|0;
   $33 = ($32<<24>>24)==(0);
   if ($33) {
    $$pre = ((($0)) + 116|0);
    $$pre$phiZ2D = $$pre;
    break;
   }
   $34 = (__Znwj(48)|0);
   __THREW__ = 0;
   invoke_vi(3282,($34|0));
   $35 = __THREW__; __THREW__ = 0;
   $36 = $35&1;
   if ($36) {
    $50 = ___cxa_find_matching_catch_2()|0;
    $51 = tempRet0;
    __ZdlPv($34);
    $$0 = $51;$$09 = $50;
    ___resumeException($$09|0);
    // unreachable;
   }
   $37 = ((($34)) + 12|0);
   HEAP32[$37>>2] = 0;
   HEAP32[$34>>2] = (41752);
   $38 = ((($34)) + 16|0);
   HEAP32[$38>>2] = $38;
   $39 = ((($34)) + 20|0);
   HEAP32[$39>>2] = $38;
   $40 = ((($34)) + 24|0);
   ;HEAP32[$40>>2]=0|0;HEAP32[$40+4>>2]=0|0;HEAP32[$40+8>>2]=0|0;HEAP32[$40+12>>2]=0|0;HEAP32[$40+16>>2]=0|0;HEAP32[$40+20>>2]=0|0;
   $41 = ((($0)) + 116|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = ($42|0)==($34|0);
   if ($43) {
    $$pre$phiZ2D = $41;
   } else {
    HEAP32[$41>>2] = $34;
    $44 = ((($34)) + 8|0);
    $45 = HEAP32[$44>>2]|0;HEAP32[$44>>2] = (($45+1)|0);
    $46 = ($42|0)==(0|0);
    if ($46) {
     $$pre$phiZ2D = $41;
    } else {
     $47 = ((($42)) + 8|0);
     $48 = HEAP32[$47>>2]|0;HEAP32[$47>>2] = (($48-1)|0);
     $49 = ($48|0)==(1);
     if ($49) {
      __ZNK3osg10Referenced24signalObserversAndDeleteEbb($42,1,1);
      $$pre$phiZ2D = $41;
     } else {
      $$pre$phiZ2D = $41;
     }
    }
   }
  }
 } while(0);
 $52 = HEAP32[$$pre$phiZ2D>>2]|0;
 $53 = ($52|0)==(0|0);
 if ($53) {
  return;
 }
 $54 = HEAP32[$52>>2]|0;
 $55 = ((($54)) + 24|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = ((($0)) + 120|0);
 $58 = $57;
 $59 = $58;
 $60 = HEAP32[$59>>2]|0;
 $61 = (($58) + 4)|0;
 $62 = $61;
 $63 = HEAP32[$62>>2]|0;
 FUNCTION_TABLE_viiii[$56 & 8191]($52,$1,$60,$63);
 return;
}
function __ZL21collectSceneViewStatsjPN7osgUtil9SceneViewEPN3osg5StatsE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$0$i$i$i$i = 0, $$0$i$i181 = 0, $$0$i$i205 = 0, $$0$i$i229 = 0, $$0$i$i253 = 0, $$0$i$i277 = 0, $$0$i$i301 = 0, $$0$i$i325 = 0, $$0$i$i349 = 0, $$0$i$i373 = 0, $$0$ph$i$i178 = 0, $$0$ph$i$i202 = 0, $$0$ph$i$i226 = 0, $$0$ph$i$i250 = 0, $$0$ph$i$i274 = 0, $$0$ph$i$i298 = 0, $$0$ph$i$i322 = 0, $$0$ph$i$i346 = 0, $$0$ph$i$i370 = 0;
 var $$014$i = 0, $$014$i190 = 0, $$014$i214 = 0, $$014$i238 = 0, $$014$i262 = 0, $$014$i286 = 0, $$014$i310 = 0, $$014$i334 = 0, $$014$i358 = 0, $$014$i382 = 0, $$024$i$i180 = 0, $$024$i$i204 = 0, $$024$i$i228 = 0, $$024$i$i252 = 0, $$024$i$i276 = 0, $$024$i$i300 = 0, $$024$i$i324 = 0, $$024$i$i348 = 0, $$024$i$i372 = 0, $$024$i$i538 = 0;
 var $$025$i$i183 = 0, $$025$i$i207 = 0, $$025$i$i231 = 0, $$025$i$i255 = 0, $$025$i$i279 = 0, $$025$i$i303 = 0, $$025$i$i327 = 0, $$025$i$i351 = 0, $$025$i$i375 = 0, $$025$i47$i = 0, $$025$i47$i185 = 0, $$025$i47$i209 = 0, $$025$i47$i233 = 0, $$025$i47$i257 = 0, $$025$i47$i281 = 0, $$025$i47$i305 = 0, $$025$i47$i329 = 0, $$025$i47$i353 = 0, $$025$i47$i377 = 0, $$034$i182 = 0;
 var $$034$i206 = 0, $$034$i230 = 0, $$034$i254 = 0, $$034$i278 = 0, $$034$i302 = 0, $$034$i326 = 0, $$034$i350 = 0, $$034$i374 = 0, $$03446$i = 0, $$03446$i186 = 0, $$03446$i210 = 0, $$03446$i234 = 0, $$03446$i258 = 0, $$03446$i282 = 0, $$03446$i306 = 0, $$03446$i330 = 0, $$03446$i354 = 0, $$03446$i378 = 0, $$064 = 0, $$088$lcssa = 0;
 var $$088542 = 0, $$1 = 0, $$10 = 0, $$1074 = 0, $$11 = 0, $$1175 = 0, $$12 = 0, $$1276 = 0, $$13 = 0, $$1377 = 0, $$14 = 0, $$1478 = 0, $$15 = 0, $$1579 = 0, $$16 = 0, $$165 = 0, $$1680 = 0, $$17 = 0, $$1781 = 0, $$18 = 0;
 var $$1882 = 0, $$19 = 0, $$1983 = 0, $$2 = 0, $$20 = 0, $$2084 = 0, $$23 = 0, $$2387 = 0, $$266 = 0, $$3 = 0, $$367 = 0, $$4 = 0, $$468 = 0, $$5 = 0, $$569 = 0, $$6 = 0, $$670 = 0, $$7 = 0, $$771 = 0, $$8 = 0;
 var $$872 = 0, $$in$i$i177 = 0, $$in$i$i201 = 0, $$in$i$i225 = 0, $$in$i$i249 = 0, $$in$i$i273 = 0, $$in$i$i297 = 0, $$in$i$i321 = 0, $$in$i$i345 = 0, $$in$i$i369 = 0, $$lcssa535 = 0, $$pre$i$i = 0, $$pre$i$i188 = 0, $$pre$i$i212 = 0, $$pre$i$i236 = 0, $$pre$i$i260 = 0, $$pre$i$i284 = 0, $$pre$i$i308 = 0, $$pre$i$i332 = 0, $$pre$i$i356 = 0;
 var $$pre$i$i380 = 0, $$sroa$0447$0$be = 0, $$sroa$0447$0541 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0.0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0.0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0.0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0.0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0.0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0;
 var $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0;
 var $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0;
 var $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0;
 var $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0;
 var $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0.0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0;
 var $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0;
 var $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0.0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0;
 var $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0.0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0;
 var $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0;
 var $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0.0, $401 = 0, $402 = 0, $403 = 0;
 var $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0;
 var $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0;
 var $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0.0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0;
 var $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0;
 var $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0.0, $490 = 0, $491 = 0, $492 = 0.0, $493 = 0, $494 = 0;
 var $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0;
 var $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0;
 var $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0.0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0;
 var $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0;
 var $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0.0;
 var $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0;
 var $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0;
 var $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0.0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0;
 var $639 = 0, $64 = 0.0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0;
 var $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0;
 var $675 = 0, $676 = 0.0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0;
 var $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0;
 var $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0.0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0;
 var $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0;
 var $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0;
 var $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0;
 var $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0.0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = 0;
 var $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0;
 var $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = 0, $834 = 0, $835 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0.0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, dest = 0, label = 0, sp = 0, src = 0;
 var stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 336|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(336|0);
 $3 = sp + 240|0;
 $4 = sp + 228|0;
 $5 = sp + 216|0;
 $6 = sp + 204|0;
 $7 = sp + 192|0;
 $8 = sp + 180|0;
 $9 = sp + 168|0;
 $10 = sp + 156|0;
 $11 = sp + 144|0;
 $12 = sp + 132|0;
 $13 = sp + 120|0;
 $14 = sp + 108|0;
 $15 = sp + 96|0;
 $16 = sp + 84|0;
 $17 = sp + 72|0;
 $18 = sp + 60|0;
 $19 = sp + 48|0;
 $20 = sp + 36|0;
 $21 = sp + 24|0;
 $22 = sp + 12|0;
 $23 = sp;
 __ZN7osgUtil10StatisticsC2Ev($3);
 __THREW__ = 0;
 (invoke_iii(3505,($1|0),($3|0))|0);
 $24 = __THREW__; __THREW__ = 0;
 $25 = $24&1;
 L1: do {
  if ($25) {
   $174 = ___cxa_find_matching_catch_2()|0;
   $175 = tempRet0;
   $$23 = $174;$$2387 = $175;
  } else {
   ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;
   __THREW__ = 0;
   $26 = (invoke_ii(3276,32)|0);
   $27 = __THREW__; __THREW__ = 0;
   $28 = $27&1;
   do {
    if ($28) {
     $176 = ___cxa_find_matching_catch_2()|0;
     $177 = tempRet0;
     $$0 = $176;$$064 = $177;
    } else {
     HEAP32[$4>>2] = $26;
     $29 = ((($4)) + 8|0);
     HEAP32[$29>>2] = -2147483616;
     $30 = ((($4)) + 4|0);
     HEAP32[$30>>2] = 20;
     dest=$26; src=108555; stop=dest+20|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
     $31 = ((($26)) + 20|0);
     HEAP8[$31>>0] = 0;
     $32 = ((($3)) + 48|0);
     $33 = HEAP32[$32>>2]|0;
     $34 = (+($33>>>0));
     __THREW__ = 0;
     (invoke_iiiid(3392,($2|0),($0|0),($4|0),(+$34))|0);
     $35 = __THREW__; __THREW__ = 0;
     $36 = $35&1;
     if ($36) {
      $178 = ___cxa_find_matching_catch_2()|0;
      $179 = tempRet0;
      $180 = ((($4)) + 11|0);
      $181 = HEAP8[$180>>0]|0;
      $182 = ($181<<24>>24)<(0);
      if (!($182)) {
       $$0 = $178;$$064 = $179;
       break;
      }
      $183 = HEAP32[$4>>2]|0;
      __ZdlPv($183);
      $$0 = $178;$$064 = $179;
      break;
     }
     $37 = ((($4)) + 11|0);
     $38 = HEAP8[$37>>0]|0;
     $39 = ($38<<24>>24)<(0);
     if ($39) {
      $40 = HEAP32[$4>>2]|0;
      __ZdlPv($40);
     }
     ;HEAP32[$5>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;
     __THREW__ = 0;
     $41 = (invoke_ii(3276,32)|0);
     $42 = __THREW__; __THREW__ = 0;
     $43 = $42&1;
     do {
      if ($43) {
       $184 = ___cxa_find_matching_catch_2()|0;
       $185 = tempRet0;
       $$1 = $184;$$165 = $185;
      } else {
       HEAP32[$5>>2] = $41;
       $44 = ((($5)) + 8|0);
       HEAP32[$44>>2] = -2147483616;
       $45 = ((($5)) + 4|0);
       HEAP32[$45>>2] = 27;
       dest=$41; src=108576; stop=dest+27|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
       $46 = ((($41)) + 27|0);
       HEAP8[$46>>0] = 0;
       $47 = ((($3)) + 4|0);
       $48 = HEAP32[$47>>2]|0;
       $49 = (+($48|0));
       __THREW__ = 0;
       (invoke_iiiid(3392,($2|0),($0|0),($5|0),(+$49))|0);
       $50 = __THREW__; __THREW__ = 0;
       $51 = $50&1;
       if ($51) {
        $186 = ___cxa_find_matching_catch_2()|0;
        $187 = tempRet0;
        $188 = ((($5)) + 11|0);
        $189 = HEAP8[$188>>0]|0;
        $190 = ($189<<24>>24)<(0);
        if (!($190)) {
         $$1 = $186;$$165 = $187;
         break;
        }
        $191 = HEAP32[$5>>2]|0;
        __ZdlPv($191);
        $$1 = $186;$$165 = $187;
        break;
       }
       $52 = ((($5)) + 11|0);
       $53 = HEAP8[$52>>0]|0;
       $54 = ($53<<24>>24)<(0);
       if ($54) {
        $55 = HEAP32[$5>>2]|0;
        __ZdlPv($55);
       }
       ;HEAP32[$6>>2]=0|0;HEAP32[$6+4>>2]=0|0;HEAP32[$6+8>>2]=0|0;
       __THREW__ = 0;
       $56 = (invoke_ii(3276,48)|0);
       $57 = __THREW__; __THREW__ = 0;
       $58 = $57&1;
       do {
        if ($58) {
         $192 = ___cxa_find_matching_catch_2()|0;
         $193 = tempRet0;
         $$2 = $192;$$266 = $193;
        } else {
         HEAP32[$6>>2] = $56;
         $59 = ((($6)) + 8|0);
         HEAP32[$59>>2] = -2147483600;
         $60 = ((($6)) + 4|0);
         HEAP32[$60>>2] = 32;
         dest=$56; src=108604; stop=dest+32|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
         $61 = ((($56)) + 32|0);
         HEAP8[$61>>0] = 0;
         $62 = ((($3)) + 20|0);
         $63 = HEAP32[$62>>2]|0;
         $64 = (+($63|0));
         __THREW__ = 0;
         (invoke_iiiid(3392,($2|0),($0|0),($6|0),(+$64))|0);
         $65 = __THREW__; __THREW__ = 0;
         $66 = $65&1;
         if ($66) {
          $194 = ___cxa_find_matching_catch_2()|0;
          $195 = tempRet0;
          $196 = ((($6)) + 11|0);
          $197 = HEAP8[$196>>0]|0;
          $198 = ($197<<24>>24)<(0);
          if (!($198)) {
           $$2 = $194;$$266 = $195;
           break;
          }
          $199 = HEAP32[$6>>2]|0;
          __ZdlPv($199);
          $$2 = $194;$$266 = $195;
          break;
         }
         $67 = ((($6)) + 11|0);
         $68 = HEAP8[$67>>0]|0;
         $69 = ($68<<24>>24)<(0);
         if ($69) {
          $70 = HEAP32[$6>>2]|0;
          __ZdlPv($70);
         }
         ;HEAP32[$7>>2]=0|0;HEAP32[$7+4>>2]=0|0;HEAP32[$7+8>>2]=0|0;
         __THREW__ = 0;
         $71 = (invoke_ii(3276,32)|0);
         $72 = __THREW__; __THREW__ = 0;
         $73 = $72&1;
         do {
          if ($73) {
           $200 = ___cxa_find_matching_catch_2()|0;
           $201 = tempRet0;
           $$3 = $200;$$367 = $201;
          } else {
           HEAP32[$7>>2] = $71;
           $74 = ((($7)) + 8|0);
           HEAP32[$74>>2] = -2147483616;
           $75 = ((($7)) + 4|0);
           HEAP32[$75>>2] = 24;
           dest=$71; src=108637; stop=dest+24|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
           $76 = ((($71)) + 24|0);
           HEAP8[$76>>0] = 0;
           $77 = ((($3)) + 24|0);
           $78 = HEAP32[$77>>2]|0;
           $79 = (+($78|0));
           __THREW__ = 0;
           (invoke_iiiid(3392,($2|0),($0|0),($7|0),(+$79))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if ($81) {
            $202 = ___cxa_find_matching_catch_2()|0;
            $203 = tempRet0;
            $204 = ((($7)) + 11|0);
            $205 = HEAP8[$204>>0]|0;
            $206 = ($205<<24>>24)<(0);
            if (!($206)) {
             $$3 = $202;$$367 = $203;
             break;
            }
            $207 = HEAP32[$7>>2]|0;
            __ZdlPv($207);
            $$3 = $202;$$367 = $203;
            break;
           }
           $82 = ((($7)) + 11|0);
           $83 = HEAP8[$82>>0]|0;
           $84 = ($83<<24>>24)<(0);
           if ($84) {
            $85 = HEAP32[$7>>2]|0;
            __ZdlPv($85);
           }
           ;HEAP32[$8>>2]=0|0;HEAP32[$8+4>>2]=0|0;HEAP32[$8+8>>2]=0|0;
           __THREW__ = 0;
           $86 = (invoke_ii(3276,32)|0);
           $87 = __THREW__; __THREW__ = 0;
           $88 = $87&1;
           do {
            if ($88) {
             $208 = ___cxa_find_matching_catch_2()|0;
             $209 = tempRet0;
             $$4 = $208;$$468 = $209;
            } else {
             HEAP32[$8>>2] = $86;
             $89 = ((($8)) + 8|0);
             HEAP32[$89>>2] = -2147483616;
             $90 = ((($8)) + 4|0);
             HEAP32[$90>>2] = 29;
             dest=$86; src=108662; stop=dest+29|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
             $91 = ((($86)) + 29|0);
             HEAP8[$91>>0] = 0;
             $92 = ((($3)) + 12|0);
             $93 = HEAP32[$92>>2]|0;
             $94 = (+($93|0));
             __THREW__ = 0;
             (invoke_iiiid(3392,($2|0),($0|0),($8|0),(+$94))|0);
             $95 = __THREW__; __THREW__ = 0;
             $96 = $95&1;
             if ($96) {
              $210 = ___cxa_find_matching_catch_2()|0;
              $211 = tempRet0;
              $212 = ((($8)) + 11|0);
              $213 = HEAP8[$212>>0]|0;
              $214 = ($213<<24>>24)<(0);
              if (!($214)) {
               $$4 = $210;$$468 = $211;
               break;
              }
              $215 = HEAP32[$8>>2]|0;
              __ZdlPv($215);
              $$4 = $210;$$468 = $211;
              break;
             }
             $97 = ((($8)) + 11|0);
             $98 = HEAP8[$97>>0]|0;
             $99 = ($98<<24>>24)<(0);
             if ($99) {
              $100 = HEAP32[$8>>2]|0;
              __ZdlPv($100);
             }
             ;HEAP32[$9>>2]=0|0;HEAP32[$9+4>>2]=0|0;HEAP32[$9+8>>2]=0|0;
             __THREW__ = 0;
             $101 = (invoke_ii(3276,16)|0);
             $102 = __THREW__; __THREW__ = 0;
             $103 = $102&1;
             do {
              if ($103) {
               $216 = ___cxa_find_matching_catch_2()|0;
               $217 = tempRet0;
               $$5 = $216;$$569 = $217;
              } else {
               HEAP32[$9>>2] = $101;
               $104 = ((($9)) + 8|0);
               HEAP32[$104>>2] = -2147483632;
               $105 = ((($9)) + 4|0);
               HEAP32[$105>>2] = 13;
               dest=$101; src=108692; stop=dest+13|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
               $106 = ((($101)) + 13|0);
               HEAP8[$106>>0] = 0;
               $107 = ((($3)) + 28|0);
               $108 = HEAP32[$107>>2]|0;
               $109 = (+($108|0));
               __THREW__ = 0;
               (invoke_iiiid(3392,($2|0),($0|0),($9|0),(+$109))|0);
               $110 = __THREW__; __THREW__ = 0;
               $111 = $110&1;
               if ($111) {
                $218 = ___cxa_find_matching_catch_2()|0;
                $219 = tempRet0;
                $220 = ((($9)) + 11|0);
                $221 = HEAP8[$220>>0]|0;
                $222 = ($221<<24>>24)<(0);
                if (!($222)) {
                 $$5 = $218;$$569 = $219;
                 break;
                }
                $223 = HEAP32[$9>>2]|0;
                __ZdlPv($223);
                $$5 = $218;$$569 = $219;
                break;
               }
               $112 = ((($9)) + 11|0);
               $113 = HEAP8[$112>>0]|0;
               $114 = ($113<<24>>24)<(0);
               if ($114) {
                $115 = HEAP32[$9>>2]|0;
                __ZdlPv($115);
               }
               ;HEAP32[$10>>2]=0|0;HEAP32[$10+4>>2]=0|0;HEAP32[$10+8>>2]=0|0;
               __THREW__ = 0;
               $116 = (invoke_ii(3276,32)|0);
               $117 = __THREW__; __THREW__ = 0;
               $118 = $117&1;
               do {
                if ($118) {
                 $224 = ___cxa_find_matching_catch_2()|0;
                 $225 = tempRet0;
                 $$6 = $224;$$670 = $225;
                } else {
                 HEAP32[$10>>2] = $116;
                 $119 = ((($10)) + 8|0);
                 HEAP32[$119>>2] = -2147483616;
                 $120 = ((($10)) + 4|0);
                 HEAP32[$120>>2] = 21;
                 dest=$116; src=108706; stop=dest+21|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                 $121 = ((($116)) + 21|0);
                 HEAP8[$121>>0] = 0;
                 $122 = ((($3)) + 16|0);
                 $123 = HEAP32[$122>>2]|0;
                 $124 = (+($123|0));
                 __THREW__ = 0;
                 (invoke_iiiid(3392,($2|0),($0|0),($10|0),(+$124))|0);
                 $125 = __THREW__; __THREW__ = 0;
                 $126 = $125&1;
                 if ($126) {
                  $226 = ___cxa_find_matching_catch_2()|0;
                  $227 = tempRet0;
                  $228 = ((($10)) + 11|0);
                  $229 = HEAP8[$228>>0]|0;
                  $230 = ($229<<24>>24)<(0);
                  if (!($230)) {
                   $$6 = $226;$$670 = $227;
                   break;
                  }
                  $231 = HEAP32[$10>>2]|0;
                  __ZdlPv($231);
                  $$6 = $226;$$670 = $227;
                  break;
                 }
                 $127 = ((($10)) + 11|0);
                 $128 = HEAP8[$127>>0]|0;
                 $129 = ($128<<24>>24)<(0);
                 if ($129) {
                  $130 = HEAP32[$10>>2]|0;
                  __ZdlPv($130);
                 }
                 ;HEAP32[$11>>2]=0|0;HEAP32[$11+4>>2]=0|0;HEAP32[$11+8>>2]=0|0;
                 __THREW__ = 0;
                 $131 = (invoke_ii(3276,32)|0);
                 $132 = __THREW__; __THREW__ = 0;
                 $133 = $132&1;
                 do {
                  if ($133) {
                   $232 = ___cxa_find_matching_catch_2()|0;
                   $233 = tempRet0;
                   $$7 = $232;$$771 = $233;
                  } else {
                   HEAP32[$11>>2] = $131;
                   $134 = ((($11)) + 8|0);
                   HEAP32[$134>>2] = -2147483616;
                   $135 = ((($11)) + 4|0);
                   HEAP32[$135>>2] = 27;
                   dest=$131; src=108728; stop=dest+27|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                   $136 = ((($131)) + 27|0);
                   HEAP8[$136>>0] = 0;
                   $137 = ((($3)) + 40|0);
                   $138 = HEAP32[$137>>2]|0;
                   $139 = (+($138|0));
                   __THREW__ = 0;
                   (invoke_iiiid(3392,($2|0),($0|0),($11|0),(+$139))|0);
                   $140 = __THREW__; __THREW__ = 0;
                   $141 = $140&1;
                   if ($141) {
                    $234 = ___cxa_find_matching_catch_2()|0;
                    $235 = tempRet0;
                    $236 = ((($11)) + 11|0);
                    $237 = HEAP8[$236>>0]|0;
                    $238 = ($237<<24>>24)<(0);
                    if (!($238)) {
                     $$7 = $234;$$771 = $235;
                     break;
                    }
                    $239 = HEAP32[$11>>2]|0;
                    __ZdlPv($239);
                    $$7 = $234;$$771 = $235;
                    break;
                   }
                   $142 = ((($11)) + 11|0);
                   $143 = HEAP8[$142>>0]|0;
                   $144 = ($143<<24>>24)<(0);
                   if ($144) {
                    $145 = HEAP32[$11>>2]|0;
                    __ZdlPv($145);
                   }
                   ;HEAP32[$12>>2]=0|0;HEAP32[$12+4>>2]=0|0;HEAP32[$12+8>>2]=0|0;
                   __THREW__ = 0;
                   $146 = (invoke_ii(3276,32)|0);
                   $147 = __THREW__; __THREW__ = 0;
                   $148 = $147&1;
                   do {
                    if ($148) {
                     $240 = ___cxa_find_matching_catch_2()|0;
                     $241 = tempRet0;
                     $$8 = $240;$$872 = $241;
                    } else {
                     HEAP32[$12>>2] = $146;
                     $149 = ((($12)) + 8|0);
                     HEAP32[$149>>2] = -2147483616;
                     $150 = ((($12)) + 4|0);
                     HEAP32[$150>>2] = 24;
                     dest=$146; src=108756; stop=dest+24|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                     $151 = ((($146)) + 24|0);
                     HEAP8[$151>>0] = 0;
                     $152 = ((($3)) + 44|0);
                     $153 = HEAP32[$152>>2]|0;
                     $154 = (+($153|0));
                     __THREW__ = 0;
                     (invoke_iiiid(3392,($2|0),($0|0),($12|0),(+$154))|0);
                     $155 = __THREW__; __THREW__ = 0;
                     $156 = $155&1;
                     if ($156) {
                      $242 = ___cxa_find_matching_catch_2()|0;
                      $243 = tempRet0;
                      $244 = ((($12)) + 11|0);
                      $245 = HEAP8[$244>>0]|0;
                      $246 = ($245<<24>>24)<(0);
                      if (!($246)) {
                       $$8 = $242;$$872 = $243;
                       break;
                      }
                      $247 = HEAP32[$12>>2]|0;
                      __ZdlPv($247);
                      $$8 = $242;$$872 = $243;
                      break;
                     }
                     $157 = ((($12)) + 11|0);
                     $158 = HEAP8[$157>>0]|0;
                     $159 = ($158<<24>>24)<(0);
                     if ($159) {
                      $160 = HEAP32[$12>>2]|0;
                      __ZdlPv($160);
                     }
                     $161 = ((($3)) + 52|0);
                     $162 = HEAP32[$161>>2]|0;
                     $163 = ((($3)) + 56|0);
                     $164 = ($162|0)==($163|0);
                     if ($164) {
                      $$088$lcssa = 0;
                     } else {
                      $$088542 = 0;$$sroa$0447$0541 = $162;
                      while(1) {
                       $248 = ((($$sroa$0447$0541)) + 20|0);
                       $249 = HEAP32[$248>>2]|0;
                       $250 = (($249) + ($$088542))|0;
                       $251 = ((($$sroa$0447$0541)) + 4|0);
                       $252 = HEAP32[$251>>2]|0;
                       $253 = ($252|0)==(0|0);
                       do {
                        if ($253) {
                         $254 = ((($$sroa$0447$0541)) + 8|0);
                         $255 = HEAP32[$254>>2]|0;
                         $256 = HEAP32[$255>>2]|0;
                         $257 = ($256|0)==($$sroa$0447$0541|0);
                         if ($257) {
                          $$sroa$0447$0$be = $255;
                          break;
                         } else {
                          $262 = $254;
                         }
                         while(1) {
                          $261 = HEAP32[$262>>2]|0;
                          $263 = ((($261)) + 8|0);
                          $264 = HEAP32[$263>>2]|0;
                          $265 = HEAP32[$264>>2]|0;
                          $266 = ($265|0)==($261|0);
                          if ($266) {
                           $$sroa$0447$0$be = $264;
                           break;
                          } else {
                           $262 = $263;
                          }
                         }
                        } else {
                         $$0$i$i$i$i = $252;
                         while(1) {
                          $259 = HEAP32[$$0$i$i$i$i>>2]|0;
                          $260 = ($259|0)==(0|0);
                          if ($260) {
                           break;
                          } else {
                           $$0$i$i$i$i = $259;
                          }
                         }
                         $$sroa$0447$0$be = $$0$i$i$i$i;
                        }
                       } while(0);
                       $258 = ($$sroa$0447$0$be|0)==($163|0);
                       if ($258) {
                        $$088$lcssa = $250;
                        break;
                       } else {
                        $$088542 = $250;$$sroa$0447$0541 = $$sroa$0447$0$be;
                       }
                      }
                     }
                     ;HEAP32[$13>>2]=0|0;HEAP32[$13+4>>2]=0|0;HEAP32[$13+8>>2]=0|0;
                     __THREW__ = 0;
                     $165 = (invoke_ii(3276,32)|0);
                     $166 = __THREW__; __THREW__ = 0;
                     $167 = $166&1;
                     do {
                      if ($167) {
                       $733 = ___cxa_find_matching_catch_2()|0;
                       $734 = tempRet0;
                       $$10 = $733;$$1074 = $734;
                      } else {
                       HEAP32[$13>>2] = $165;
                       $168 = ((($13)) + 8|0);
                       HEAP32[$168>>2] = -2147483616;
                       $169 = ((($13)) + 4|0);
                       HEAP32[$169>>2] = 31;
                       dest=$165; src=108781; stop=dest+31|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                       $170 = ((($165)) + 31|0);
                       HEAP8[$170>>0] = 0;
                       $171 = (+($$088$lcssa>>>0));
                       __THREW__ = 0;
                       (invoke_iiiid(3392,($2|0),($0|0),($13|0),(+$171))|0);
                       $172 = __THREW__; __THREW__ = 0;
                       $173 = $172&1;
                       if ($173) {
                        $735 = ___cxa_find_matching_catch_2()|0;
                        $736 = tempRet0;
                        $737 = ((($13)) + 11|0);
                        $738 = HEAP8[$737>>0]|0;
                        $739 = ($738<<24>>24)<(0);
                        if (!($739)) {
                         $$10 = $735;$$1074 = $736;
                         break;
                        }
                        $740 = HEAP32[$13>>2]|0;
                        __ZdlPv($740);
                        $$10 = $735;$$1074 = $736;
                        break;
                       }
                       $267 = ((($13)) + 11|0);
                       $268 = HEAP8[$267>>0]|0;
                       $269 = ($268<<24>>24)<(0);
                       if ($269) {
                        $270 = HEAP32[$13>>2]|0;
                        __ZdlPv($270);
                       }
                       $271 = ((($3)) + 68|0);
                       ;HEAP32[$14>>2]=0|0;HEAP32[$14+4>>2]=0|0;HEAP32[$14+8>>2]=0|0;
                       __THREW__ = 0;
                       $272 = (invoke_ii(3276,32)|0);
                       $273 = __THREW__; __THREW__ = 0;
                       $274 = $273&1;
                       do {
                        if ($274) {
                         $741 = ___cxa_find_matching_catch_2()|0;
                         $742 = tempRet0;
                         $$11 = $741;$$1175 = $742;
                        } else {
                         HEAP32[$14>>2] = $272;
                         $275 = ((($14)) + 8|0);
                         HEAP32[$275>>2] = -2147483616;
                         $276 = ((($14)) + 4|0);
                         HEAP32[$276>>2] = 27;
                         dest=$272; src=108813; stop=dest+27|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                         $277 = ((($272)) + 27|0);
                         HEAP8[$277>>0] = 0;
                         $278 = ((($3)) + 72|0);
                         $279 = HEAP32[$278>>2]|0;
                         $280 = ($279|0)==(0|0);
                         L119: do {
                          if ($280) {
                           $$025$i47$i = $278;$$03446$i = $278;
                           label = 94;
                          } else {
                           $281 = ((($279)) + 16|0);
                           $282 = HEAP32[$281>>2]|0;
                           $283 = ($282|0)==(0);
                           L122: do {
                            if ($283) {
                             $$lcssa535 = $279;
                            } else {
                             $$024$i$i538 = $279;
                             while(1) {
                              $285 = HEAP32[$$024$i$i538>>2]|0;
                              $288 = ($285|0)==(0|0);
                              if ($288) {
                               break;
                              }
                              $284 = ((($285)) + 16|0);
                              $286 = HEAP32[$284>>2]|0;
                              $287 = ($286|0)==(0);
                              if ($287) {
                               $$lcssa535 = $285;
                               break L122;
                              } else {
                               $$024$i$i538 = $285;
                              }
                             }
                             $$025$i47$i = $$024$i$i538;$$03446$i = $$024$i$i538;
                             label = 94;
                             break L119;
                            }
                           } while(0);
                           $$014$i = $$lcssa535;
                           label = 98;
                          }
                         } while(0);
                         do {
                          if ((label|0) == 94) {
                           __THREW__ = 0;
                           $289 = (invoke_ii(3276,24)|0);
                           $290 = __THREW__; __THREW__ = 0;
                           $291 = $290&1;
                           if ($291) {
                            break;
                           }
                           $292 = ((($289)) + 16|0);
                           HEAP32[$292>>2] = 0;
                           $293 = ((($289)) + 20|0);
                           HEAP32[$293>>2] = 0;
                           HEAP32[$289>>2] = 0;
                           $294 = ((($289)) + 4|0);
                           HEAP32[$294>>2] = 0;
                           $295 = ((($289)) + 8|0);
                           HEAP32[$295>>2] = $$03446$i;
                           HEAP32[$$025$i47$i>>2] = $289;
                           $296 = HEAP32[$271>>2]|0;
                           $297 = HEAP32[$296>>2]|0;
                           $298 = ($297|0)==(0|0);
                           if ($298) {
                            $302 = $289;
                           } else {
                            $299 = $297;
                            HEAP32[$271>>2] = $299;
                            $$pre$i$i = HEAP32[$$025$i47$i>>2]|0;
                            $302 = $$pre$i$i;
                           }
                           $300 = ((($3)) + 72|0);
                           $301 = HEAP32[$300>>2]|0;
                           __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($301,$302);
                           $303 = ((($3)) + 76|0);
                           $304 = HEAP32[$303>>2]|0;
                           $305 = (($304) + 1)|0;
                           HEAP32[$303>>2] = $305;
                           $$014$i = $289;
                           label = 98;
                          }
                         } while(0);
                         do {
                          if ((label|0) == 98) {
                           $306 = ((($$014$i)) + 20|0);
                           $307 = HEAP32[$306>>2]|0;
                           $308 = (+($307>>>0));
                           __THREW__ = 0;
                           (invoke_iiiid(3392,($2|0),($0|0),($14|0),(+$308))|0);
                           $309 = __THREW__; __THREW__ = 0;
                           $310 = $309&1;
                           if ($310) {
                            break;
                           }
                           $311 = ((($14)) + 11|0);
                           $312 = HEAP8[$311>>0]|0;
                           $313 = ($312<<24>>24)<(0);
                           if ($313) {
                            $314 = HEAP32[$14>>2]|0;
                            __ZdlPv($314);
                           }
                           ;HEAP32[$15>>2]=0|0;HEAP32[$15+4>>2]=0|0;HEAP32[$15+8>>2]=0|0;
                           __THREW__ = 0;
                           $315 = (invoke_ii(3276,32)|0);
                           $316 = __THREW__; __THREW__ = 0;
                           $317 = $316&1;
                           do {
                            if ($317) {
                             $749 = ___cxa_find_matching_catch_2()|0;
                             $750 = tempRet0;
                             $$12 = $749;$$1276 = $750;
                            } else {
                             HEAP32[$15>>2] = $315;
                             $318 = ((($15)) + 8|0);
                             HEAP32[$318>>2] = -2147483616;
                             $319 = ((($15)) + 4|0);
                             HEAP32[$319>>2] = 26;
                             dest=$315; src=108841; stop=dest+26|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                             $320 = ((($315)) + 26|0);
                             HEAP8[$320>>0] = 0;
                             $321 = HEAP32[$278>>2]|0;
                             $322 = ($321|0)==(0|0);
                             do {
                              if ($322) {
                               $$025$i$i183 = $278;$$034$i182 = $278;$333 = $321;
                               label = 113;
                              } else {
                               $323 = ((($3)) + 72|0);
                               $$0$i$i181 = $323;$$024$i$i180 = $321;$827 = $321;
                               while(1) {
                                $324 = ((($$024$i$i180)) + 16|0);
                                $325 = HEAP32[$324>>2]|0;
                                $326 = ($325>>>0)>(1);
                                if ($326) {
                                 $327 = HEAP32[$$024$i$i180>>2]|0;
                                 $328 = ($327|0)==(0|0);
                                 if ($328) {
                                  label = 107;
                                  break;
                                 } else {
                                  $$0$ph$i$i178 = $$024$i$i180;$$in$i$i177 = $327;
                                 }
                                } else {
                                 $329 = ($325|0)==(0);
                                 if (!($329)) {
                                  label = 111;
                                  break;
                                 }
                                 $330 = ((($$024$i$i180)) + 4|0);
                                 $331 = HEAP32[$330>>2]|0;
                                 $332 = ($331|0)==(0|0);
                                 if ($332) {
                                  label = 110;
                                  break;
                                 } else {
                                  $$0$ph$i$i178 = $330;$$in$i$i177 = $331;
                                 }
                                }
                                $$0$i$i181 = $$0$ph$i$i178;$$024$i$i180 = $$in$i$i177;$827 = $$in$i$i177;
                               }
                               if ((label|0) == 107) {
                                $$025$i47$i185 = $$024$i$i180;$$03446$i186 = $$024$i$i180;
                                label = 114;
                                break;
                               }
                               else if ((label|0) == 110) {
                                $$025$i47$i185 = $330;$$03446$i186 = $$024$i$i180;
                                label = 114;
                                break;
                               }
                               else if ((label|0) == 111) {
                                $$025$i$i183 = $$0$i$i181;$$034$i182 = $$024$i$i180;$333 = $827;
                                label = 113;
                                break;
                               }
                              }
                             } while(0);
                             if ((label|0) == 113) {
                              $334 = ($333|0)==(0|0);
                              if ($334) {
                               $$025$i47$i185 = $$025$i$i183;$$03446$i186 = $$034$i182;
                               label = 114;
                              } else {
                               $$014$i190 = $333;
                               label = 118;
                              }
                             }
                             do {
                              if ((label|0) == 114) {
                               __THREW__ = 0;
                               $335 = (invoke_ii(3276,24)|0);
                               $336 = __THREW__; __THREW__ = 0;
                               $337 = $336&1;
                               if ($337) {
                                break;
                               }
                               $338 = ((($335)) + 16|0);
                               HEAP32[$338>>2] = 1;
                               $339 = ((($335)) + 20|0);
                               HEAP32[$339>>2] = 0;
                               HEAP32[$335>>2] = 0;
                               $340 = ((($335)) + 4|0);
                               HEAP32[$340>>2] = 0;
                               $341 = ((($335)) + 8|0);
                               HEAP32[$341>>2] = $$03446$i186;
                               HEAP32[$$025$i47$i185>>2] = $335;
                               $342 = HEAP32[$271>>2]|0;
                               $343 = HEAP32[$342>>2]|0;
                               $344 = ($343|0)==(0|0);
                               if ($344) {
                                $348 = $335;
                               } else {
                                $345 = $343;
                                HEAP32[$271>>2] = $345;
                                $$pre$i$i188 = HEAP32[$$025$i47$i185>>2]|0;
                                $348 = $$pre$i$i188;
                               }
                               $346 = ((($3)) + 72|0);
                               $347 = HEAP32[$346>>2]|0;
                               __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($347,$348);
                               $349 = ((($3)) + 76|0);
                               $350 = HEAP32[$349>>2]|0;
                               $351 = (($350) + 1)|0;
                               HEAP32[$349>>2] = $351;
                               $$014$i190 = $335;
                               label = 118;
                              }
                             } while(0);
                             do {
                              if ((label|0) == 118) {
                               $352 = ((($$014$i190)) + 20|0);
                               $353 = HEAP32[$352>>2]|0;
                               $354 = (+($353>>>0));
                               __THREW__ = 0;
                               (invoke_iiiid(3392,($2|0),($0|0),($15|0),(+$354))|0);
                               $355 = __THREW__; __THREW__ = 0;
                               $356 = $355&1;
                               if ($356) {
                                break;
                               }
                               $357 = ((($15)) + 11|0);
                               $358 = HEAP8[$357>>0]|0;
                               $359 = ($358<<24>>24)<(0);
                               if ($359) {
                                $360 = HEAP32[$15>>2]|0;
                                __ZdlPv($360);
                               }
                               ;HEAP32[$16>>2]=0|0;HEAP32[$16+4>>2]=0|0;HEAP32[$16+8>>2]=0|0;
                               __THREW__ = 0;
                               $361 = (invoke_ii(3276,32)|0);
                               $362 = __THREW__; __THREW__ = 0;
                               $363 = $362&1;
                               do {
                                if ($363) {
                                 $757 = ___cxa_find_matching_catch_2()|0;
                                 $758 = tempRet0;
                                 $$13 = $757;$$1377 = $758;
                                } else {
                                 HEAP32[$16>>2] = $361;
                                 $364 = ((($16)) + 8|0);
                                 HEAP32[$364>>2] = -2147483616;
                                 $365 = ((($16)) + 4|0);
                                 HEAP32[$365>>2] = 31;
                                 dest=$361; src=108868; stop=dest+31|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                                 $366 = ((($361)) + 31|0);
                                 HEAP8[$366>>0] = 0;
                                 $367 = HEAP32[$278>>2]|0;
                                 $368 = ($367|0)==(0|0);
                                 do {
                                  if ($368) {
                                   $$025$i$i207 = $278;$$034$i206 = $278;$379 = $367;
                                   label = 133;
                                  } else {
                                   $369 = ((($3)) + 72|0);
                                   $$0$i$i205 = $369;$$024$i$i204 = $367;$828 = $367;
                                   while(1) {
                                    $370 = ((($$024$i$i204)) + 16|0);
                                    $371 = HEAP32[$370>>2]|0;
                                    $372 = ($371>>>0)>(3);
                                    if ($372) {
                                     $373 = HEAP32[$$024$i$i204>>2]|0;
                                     $374 = ($373|0)==(0|0);
                                     if ($374) {
                                      label = 127;
                                      break;
                                     } else {
                                      $$0$ph$i$i202 = $$024$i$i204;$$in$i$i201 = $373;
                                     }
                                    } else {
                                     $375 = ($371|0)==(3);
                                     if ($375) {
                                      label = 131;
                                      break;
                                     }
                                     $376 = ((($$024$i$i204)) + 4|0);
                                     $377 = HEAP32[$376>>2]|0;
                                     $378 = ($377|0)==(0|0);
                                     if ($378) {
                                      label = 130;
                                      break;
                                     } else {
                                      $$0$ph$i$i202 = $376;$$in$i$i201 = $377;
                                     }
                                    }
                                    $$0$i$i205 = $$0$ph$i$i202;$$024$i$i204 = $$in$i$i201;$828 = $$in$i$i201;
                                   }
                                   if ((label|0) == 127) {
                                    $$025$i47$i209 = $$024$i$i204;$$03446$i210 = $$024$i$i204;
                                    label = 134;
                                    break;
                                   }
                                   else if ((label|0) == 130) {
                                    $$025$i47$i209 = $376;$$03446$i210 = $$024$i$i204;
                                    label = 134;
                                    break;
                                   }
                                   else if ((label|0) == 131) {
                                    $$025$i$i207 = $$0$i$i205;$$034$i206 = $$024$i$i204;$379 = $828;
                                    label = 133;
                                    break;
                                   }
                                  }
                                 } while(0);
                                 if ((label|0) == 133) {
                                  $380 = ($379|0)==(0|0);
                                  if ($380) {
                                   $$025$i47$i209 = $$025$i$i207;$$03446$i210 = $$034$i206;
                                   label = 134;
                                  } else {
                                   $$014$i214 = $379;
                                   label = 138;
                                  }
                                 }
                                 do {
                                  if ((label|0) == 134) {
                                   __THREW__ = 0;
                                   $381 = (invoke_ii(3276,24)|0);
                                   $382 = __THREW__; __THREW__ = 0;
                                   $383 = $382&1;
                                   if ($383) {
                                    break;
                                   }
                                   $384 = ((($381)) + 16|0);
                                   HEAP32[$384>>2] = 3;
                                   $385 = ((($381)) + 20|0);
                                   HEAP32[$385>>2] = 0;
                                   HEAP32[$381>>2] = 0;
                                   $386 = ((($381)) + 4|0);
                                   HEAP32[$386>>2] = 0;
                                   $387 = ((($381)) + 8|0);
                                   HEAP32[$387>>2] = $$03446$i210;
                                   HEAP32[$$025$i47$i209>>2] = $381;
                                   $388 = HEAP32[$271>>2]|0;
                                   $389 = HEAP32[$388>>2]|0;
                                   $390 = ($389|0)==(0|0);
                                   if ($390) {
                                    $394 = $381;
                                   } else {
                                    $391 = $389;
                                    HEAP32[$271>>2] = $391;
                                    $$pre$i$i212 = HEAP32[$$025$i47$i209>>2]|0;
                                    $394 = $$pre$i$i212;
                                   }
                                   $392 = ((($3)) + 72|0);
                                   $393 = HEAP32[$392>>2]|0;
                                   __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($393,$394);
                                   $395 = ((($3)) + 76|0);
                                   $396 = HEAP32[$395>>2]|0;
                                   $397 = (($396) + 1)|0;
                                   HEAP32[$395>>2] = $397;
                                   $$014$i214 = $381;
                                   label = 138;
                                  }
                                 } while(0);
                                 do {
                                  if ((label|0) == 138) {
                                   $398 = ((($$014$i214)) + 20|0);
                                   $399 = HEAP32[$398>>2]|0;
                                   $400 = (+($399>>>0));
                                   __THREW__ = 0;
                                   (invoke_iiiid(3392,($2|0),($0|0),($16|0),(+$400))|0);
                                   $401 = __THREW__; __THREW__ = 0;
                                   $402 = $401&1;
                                   if ($402) {
                                    break;
                                   }
                                   $403 = ((($16)) + 11|0);
                                   $404 = HEAP8[$403>>0]|0;
                                   $405 = ($404<<24>>24)<(0);
                                   if ($405) {
                                    $406 = HEAP32[$16>>2]|0;
                                    __ZdlPv($406);
                                   }
                                   ;HEAP32[$17>>2]=0|0;HEAP32[$17+4>>2]=0|0;HEAP32[$17+8>>2]=0|0;
                                   __THREW__ = 0;
                                   $407 = (invoke_ii(3276,32)|0);
                                   $408 = __THREW__; __THREW__ = 0;
                                   $409 = $408&1;
                                   do {
                                    if ($409) {
                                     $765 = ___cxa_find_matching_catch_2()|0;
                                     $766 = tempRet0;
                                     $$14 = $765;$$1478 = $766;
                                    } else {
                                     HEAP32[$17>>2] = $407;
                                     $410 = ((($17)) + 8|0);
                                     HEAP32[$410>>2] = -2147483616;
                                     $411 = ((($17)) + 4|0);
                                     HEAP32[$411>>2] = 30;
                                     dest=$407; src=108900; stop=dest+30|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                                     $412 = ((($407)) + 30|0);
                                     HEAP8[$412>>0] = 0;
                                     $413 = HEAP32[$278>>2]|0;
                                     $414 = ($413|0)==(0|0);
                                     do {
                                      if ($414) {
                                       $$025$i$i231 = $278;$$034$i230 = $278;$425 = $413;
                                       label = 153;
                                      } else {
                                       $415 = ((($3)) + 72|0);
                                       $$0$i$i229 = $415;$$024$i$i228 = $413;$829 = $413;
                                       while(1) {
                                        $416 = ((($$024$i$i228)) + 16|0);
                                        $417 = HEAP32[$416>>2]|0;
                                        $418 = ($417>>>0)>(2);
                                        if ($418) {
                                         $419 = HEAP32[$$024$i$i228>>2]|0;
                                         $420 = ($419|0)==(0|0);
                                         if ($420) {
                                          label = 147;
                                          break;
                                         } else {
                                          $$0$ph$i$i226 = $$024$i$i228;$$in$i$i225 = $419;
                                         }
                                        } else {
                                         $421 = ($417|0)==(2);
                                         if ($421) {
                                          label = 151;
                                          break;
                                         }
                                         $422 = ((($$024$i$i228)) + 4|0);
                                         $423 = HEAP32[$422>>2]|0;
                                         $424 = ($423|0)==(0|0);
                                         if ($424) {
                                          label = 150;
                                          break;
                                         } else {
                                          $$0$ph$i$i226 = $422;$$in$i$i225 = $423;
                                         }
                                        }
                                        $$0$i$i229 = $$0$ph$i$i226;$$024$i$i228 = $$in$i$i225;$829 = $$in$i$i225;
                                       }
                                       if ((label|0) == 147) {
                                        $$025$i47$i233 = $$024$i$i228;$$03446$i234 = $$024$i$i228;
                                        label = 154;
                                        break;
                                       }
                                       else if ((label|0) == 150) {
                                        $$025$i47$i233 = $422;$$03446$i234 = $$024$i$i228;
                                        label = 154;
                                        break;
                                       }
                                       else if ((label|0) == 151) {
                                        $$025$i$i231 = $$0$i$i229;$$034$i230 = $$024$i$i228;$425 = $829;
                                        label = 153;
                                        break;
                                       }
                                      }
                                     } while(0);
                                     if ((label|0) == 153) {
                                      $426 = ($425|0)==(0|0);
                                      if ($426) {
                                       $$025$i47$i233 = $$025$i$i231;$$03446$i234 = $$034$i230;
                                       label = 154;
                                      } else {
                                       $$014$i238 = $425;
                                       label = 158;
                                      }
                                     }
                                     do {
                                      if ((label|0) == 154) {
                                       __THREW__ = 0;
                                       $427 = (invoke_ii(3276,24)|0);
                                       $428 = __THREW__; __THREW__ = 0;
                                       $429 = $428&1;
                                       if ($429) {
                                        break;
                                       }
                                       $430 = ((($427)) + 16|0);
                                       HEAP32[$430>>2] = 2;
                                       $431 = ((($427)) + 20|0);
                                       HEAP32[$431>>2] = 0;
                                       HEAP32[$427>>2] = 0;
                                       $432 = ((($427)) + 4|0);
                                       HEAP32[$432>>2] = 0;
                                       $433 = ((($427)) + 8|0);
                                       HEAP32[$433>>2] = $$03446$i234;
                                       HEAP32[$$025$i47$i233>>2] = $427;
                                       $434 = HEAP32[$271>>2]|0;
                                       $435 = HEAP32[$434>>2]|0;
                                       $436 = ($435|0)==(0|0);
                                       if ($436) {
                                        $440 = $427;
                                       } else {
                                        $437 = $435;
                                        HEAP32[$271>>2] = $437;
                                        $$pre$i$i236 = HEAP32[$$025$i47$i233>>2]|0;
                                        $440 = $$pre$i$i236;
                                       }
                                       $438 = ((($3)) + 72|0);
                                       $439 = HEAP32[$438>>2]|0;
                                       __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($439,$440);
                                       $441 = ((($3)) + 76|0);
                                       $442 = HEAP32[$441>>2]|0;
                                       $443 = (($442) + 1)|0;
                                       HEAP32[$441>>2] = $443;
                                       $$014$i238 = $427;
                                       label = 158;
                                      }
                                     } while(0);
                                     do {
                                      if ((label|0) == 158) {
                                       $444 = ((($$014$i238)) + 20|0);
                                       $445 = HEAP32[$444>>2]|0;
                                       $446 = (+($445>>>0));
                                       __THREW__ = 0;
                                       (invoke_iiiid(3392,($2|0),($0|0),($17|0),(+$446))|0);
                                       $447 = __THREW__; __THREW__ = 0;
                                       $448 = $447&1;
                                       if ($448) {
                                        break;
                                       }
                                       $449 = ((($17)) + 11|0);
                                       $450 = HEAP8[$449>>0]|0;
                                       $451 = ($450<<24>>24)<(0);
                                       if ($451) {
                                        $452 = HEAP32[$17>>2]|0;
                                        __ZdlPv($452);
                                       }
                                       ;HEAP32[$18>>2]=0|0;HEAP32[$18+4>>2]=0|0;HEAP32[$18+8>>2]=0|0;
                                       __THREW__ = 0;
                                       $453 = (invoke_ii(3276,32)|0);
                                       $454 = __THREW__; __THREW__ = 0;
                                       $455 = $454&1;
                                       do {
                                        if ($455) {
                                         $773 = ___cxa_find_matching_catch_2()|0;
                                         $774 = tempRet0;
                                         $$15 = $773;$$1579 = $774;
                                        } else {
                                         HEAP32[$18>>2] = $453;
                                         $456 = ((($18)) + 8|0);
                                         HEAP32[$456>>2] = -2147483616;
                                         $457 = ((($18)) + 4|0);
                                         HEAP32[$457>>2] = 30;
                                         dest=$453; src=108931; stop=dest+30|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                                         $458 = ((($453)) + 30|0);
                                         HEAP8[$458>>0] = 0;
                                         $459 = HEAP32[$278>>2]|0;
                                         $460 = ($459|0)==(0|0);
                                         do {
                                          if ($460) {
                                           $$025$i$i255 = $278;$$034$i254 = $278;$471 = $459;
                                           label = 173;
                                          } else {
                                           $461 = ((($3)) + 72|0);
                                           $$0$i$i253 = $461;$$024$i$i252 = $459;$830 = $459;
                                           while(1) {
                                            $462 = ((($$024$i$i252)) + 16|0);
                                            $463 = HEAP32[$462>>2]|0;
                                            $464 = ($463>>>0)>(4);
                                            if ($464) {
                                             $465 = HEAP32[$$024$i$i252>>2]|0;
                                             $466 = ($465|0)==(0|0);
                                             if ($466) {
                                              label = 167;
                                              break;
                                             } else {
                                              $$0$ph$i$i250 = $$024$i$i252;$$in$i$i249 = $465;
                                             }
                                            } else {
                                             $467 = ($463|0)==(4);
                                             if ($467) {
                                              label = 171;
                                              break;
                                             }
                                             $468 = ((($$024$i$i252)) + 4|0);
                                             $469 = HEAP32[$468>>2]|0;
                                             $470 = ($469|0)==(0|0);
                                             if ($470) {
                                              label = 170;
                                              break;
                                             } else {
                                              $$0$ph$i$i250 = $468;$$in$i$i249 = $469;
                                             }
                                            }
                                            $$0$i$i253 = $$0$ph$i$i250;$$024$i$i252 = $$in$i$i249;$830 = $$in$i$i249;
                                           }
                                           if ((label|0) == 167) {
                                            $$025$i47$i257 = $$024$i$i252;$$03446$i258 = $$024$i$i252;
                                            label = 174;
                                            break;
                                           }
                                           else if ((label|0) == 170) {
                                            $$025$i47$i257 = $468;$$03446$i258 = $$024$i$i252;
                                            label = 174;
                                            break;
                                           }
                                           else if ((label|0) == 171) {
                                            $$025$i$i255 = $$0$i$i253;$$034$i254 = $$024$i$i252;$471 = $830;
                                            label = 173;
                                            break;
                                           }
                                          }
                                         } while(0);
                                         if ((label|0) == 173) {
                                          $472 = ($471|0)==(0|0);
                                          if ($472) {
                                           $$025$i47$i257 = $$025$i$i255;$$03446$i258 = $$034$i254;
                                           label = 174;
                                          } else {
                                           $$014$i262 = $471;
                                           label = 178;
                                          }
                                         }
                                         do {
                                          if ((label|0) == 174) {
                                           __THREW__ = 0;
                                           $473 = (invoke_ii(3276,24)|0);
                                           $474 = __THREW__; __THREW__ = 0;
                                           $475 = $474&1;
                                           if ($475) {
                                            break;
                                           }
                                           $476 = ((($473)) + 16|0);
                                           HEAP32[$476>>2] = 4;
                                           $477 = ((($473)) + 20|0);
                                           HEAP32[$477>>2] = 0;
                                           HEAP32[$473>>2] = 0;
                                           $478 = ((($473)) + 4|0);
                                           HEAP32[$478>>2] = 0;
                                           $479 = ((($473)) + 8|0);
                                           HEAP32[$479>>2] = $$03446$i258;
                                           HEAP32[$$025$i47$i257>>2] = $473;
                                           $480 = HEAP32[$271>>2]|0;
                                           $481 = HEAP32[$480>>2]|0;
                                           $482 = ($481|0)==(0|0);
                                           if ($482) {
                                            $486 = $473;
                                           } else {
                                            $483 = $481;
                                            HEAP32[$271>>2] = $483;
                                            $$pre$i$i260 = HEAP32[$$025$i47$i257>>2]|0;
                                            $486 = $$pre$i$i260;
                                           }
                                           $484 = ((($3)) + 72|0);
                                           $485 = HEAP32[$484>>2]|0;
                                           __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($485,$486);
                                           $487 = ((($3)) + 76|0);
                                           $488 = HEAP32[$487>>2]|0;
                                           $489 = (($488) + 1)|0;
                                           HEAP32[$487>>2] = $489;
                                           $$014$i262 = $473;
                                           label = 178;
                                          }
                                         } while(0);
                                         do {
                                          if ((label|0) == 178) {
                                           $490 = ((($$014$i262)) + 20|0);
                                           $491 = HEAP32[$490>>2]|0;
                                           $492 = (+($491>>>0));
                                           __THREW__ = 0;
                                           (invoke_iiiid(3392,($2|0),($0|0),($18|0),(+$492))|0);
                                           $493 = __THREW__; __THREW__ = 0;
                                           $494 = $493&1;
                                           if ($494) {
                                            break;
                                           }
                                           $495 = ((($18)) + 11|0);
                                           $496 = HEAP8[$495>>0]|0;
                                           $497 = ($496<<24>>24)<(0);
                                           if ($497) {
                                            $498 = HEAP32[$18>>2]|0;
                                            __ZdlPv($498);
                                           }
                                           ;HEAP32[$19>>2]=0|0;HEAP32[$19+4>>2]=0|0;HEAP32[$19+8>>2]=0|0;
                                           __THREW__ = 0;
                                           $499 = (invoke_ii(3276,48)|0);
                                           $500 = __THREW__; __THREW__ = 0;
                                           $501 = $500&1;
                                           do {
                                            if ($501) {
                                             $781 = ___cxa_find_matching_catch_2()|0;
                                             $782 = tempRet0;
                                             $$16 = $781;$$1680 = $782;
                                            } else {
                                             HEAP32[$19>>2] = $499;
                                             $502 = ((($19)) + 8|0);
                                             HEAP32[$502>>2] = -2147483600;
                                             $503 = ((($19)) + 4|0);
                                             HEAP32[$503>>2] = 35;
                                             dest=$499; src=108962; stop=dest+35|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                                             $504 = ((($499)) + 35|0);
                                             HEAP8[$504>>0] = 0;
                                             $505 = HEAP32[$278>>2]|0;
                                             $506 = ($505|0)==(0|0);
                                             do {
                                              if ($506) {
                                               $$025$i$i279 = $278;$$034$i278 = $278;$517 = $505;
                                               label = 193;
                                              } else {
                                               $507 = ((($3)) + 72|0);
                                               $$0$i$i277 = $507;$$024$i$i276 = $505;$831 = $505;
                                               while(1) {
                                                $508 = ((($$024$i$i276)) + 16|0);
                                                $509 = HEAP32[$508>>2]|0;
                                                $510 = ($509>>>0)>(5);
                                                if ($510) {
                                                 $511 = HEAP32[$$024$i$i276>>2]|0;
                                                 $512 = ($511|0)==(0|0);
                                                 if ($512) {
                                                  label = 187;
                                                  break;
                                                 } else {
                                                  $$0$ph$i$i274 = $$024$i$i276;$$in$i$i273 = $511;
                                                 }
                                                } else {
                                                 $513 = ($509|0)==(5);
                                                 if ($513) {
                                                  label = 191;
                                                  break;
                                                 }
                                                 $514 = ((($$024$i$i276)) + 4|0);
                                                 $515 = HEAP32[$514>>2]|0;
                                                 $516 = ($515|0)==(0|0);
                                                 if ($516) {
                                                  label = 190;
                                                  break;
                                                 } else {
                                                  $$0$ph$i$i274 = $514;$$in$i$i273 = $515;
                                                 }
                                                }
                                                $$0$i$i277 = $$0$ph$i$i274;$$024$i$i276 = $$in$i$i273;$831 = $$in$i$i273;
                                               }
                                               if ((label|0) == 187) {
                                                $$025$i47$i281 = $$024$i$i276;$$03446$i282 = $$024$i$i276;
                                                label = 194;
                                                break;
                                               }
                                               else if ((label|0) == 190) {
                                                $$025$i47$i281 = $514;$$03446$i282 = $$024$i$i276;
                                                label = 194;
                                                break;
                                               }
                                               else if ((label|0) == 191) {
                                                $$025$i$i279 = $$0$i$i277;$$034$i278 = $$024$i$i276;$517 = $831;
                                                label = 193;
                                                break;
                                               }
                                              }
                                             } while(0);
                                             if ((label|0) == 193) {
                                              $518 = ($517|0)==(0|0);
                                              if ($518) {
                                               $$025$i47$i281 = $$025$i$i279;$$03446$i282 = $$034$i278;
                                               label = 194;
                                              } else {
                                               $$014$i286 = $517;
                                               label = 198;
                                              }
                                             }
                                             do {
                                              if ((label|0) == 194) {
                                               __THREW__ = 0;
                                               $519 = (invoke_ii(3276,24)|0);
                                               $520 = __THREW__; __THREW__ = 0;
                                               $521 = $520&1;
                                               if ($521) {
                                                break;
                                               }
                                               $522 = ((($519)) + 16|0);
                                               HEAP32[$522>>2] = 5;
                                               $523 = ((($519)) + 20|0);
                                               HEAP32[$523>>2] = 0;
                                               HEAP32[$519>>2] = 0;
                                               $524 = ((($519)) + 4|0);
                                               HEAP32[$524>>2] = 0;
                                               $525 = ((($519)) + 8|0);
                                               HEAP32[$525>>2] = $$03446$i282;
                                               HEAP32[$$025$i47$i281>>2] = $519;
                                               $526 = HEAP32[$271>>2]|0;
                                               $527 = HEAP32[$526>>2]|0;
                                               $528 = ($527|0)==(0|0);
                                               if ($528) {
                                                $532 = $519;
                                               } else {
                                                $529 = $527;
                                                HEAP32[$271>>2] = $529;
                                                $$pre$i$i284 = HEAP32[$$025$i47$i281>>2]|0;
                                                $532 = $$pre$i$i284;
                                               }
                                               $530 = ((($3)) + 72|0);
                                               $531 = HEAP32[$530>>2]|0;
                                               __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($531,$532);
                                               $533 = ((($3)) + 76|0);
                                               $534 = HEAP32[$533>>2]|0;
                                               $535 = (($534) + 1)|0;
                                               HEAP32[$533>>2] = $535;
                                               $$014$i286 = $519;
                                               label = 198;
                                              }
                                             } while(0);
                                             do {
                                              if ((label|0) == 198) {
                                               $536 = ((($$014$i286)) + 20|0);
                                               $537 = HEAP32[$536>>2]|0;
                                               $538 = (+($537>>>0));
                                               __THREW__ = 0;
                                               (invoke_iiiid(3392,($2|0),($0|0),($19|0),(+$538))|0);
                                               $539 = __THREW__; __THREW__ = 0;
                                               $540 = $539&1;
                                               if ($540) {
                                                break;
                                               }
                                               $541 = ((($19)) + 11|0);
                                               $542 = HEAP8[$541>>0]|0;
                                               $543 = ($542<<24>>24)<(0);
                                               if ($543) {
                                                $544 = HEAP32[$19>>2]|0;
                                                __ZdlPv($544);
                                               }
                                               ;HEAP32[$20>>2]=0|0;HEAP32[$20+4>>2]=0|0;HEAP32[$20+8>>2]=0|0;
                                               __THREW__ = 0;
                                               $545 = (invoke_ii(3276,48)|0);
                                               $546 = __THREW__; __THREW__ = 0;
                                               $547 = $546&1;
                                               do {
                                                if ($547) {
                                                 $789 = ___cxa_find_matching_catch_2()|0;
                                                 $790 = tempRet0;
                                                 $$17 = $789;$$1781 = $790;
                                                } else {
                                                 HEAP32[$20>>2] = $545;
                                                 $548 = ((($20)) + 8|0);
                                                 HEAP32[$548>>2] = -2147483600;
                                                 $549 = ((($20)) + 4|0);
                                                 HEAP32[$549>>2] = 33;
                                                 dest=$545; src=108998; stop=dest+33|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                                                 $550 = ((($545)) + 33|0);
                                                 HEAP8[$550>>0] = 0;
                                                 $551 = HEAP32[$278>>2]|0;
                                                 $552 = ($551|0)==(0|0);
                                                 do {
                                                  if ($552) {
                                                   $$025$i$i303 = $278;$$034$i302 = $278;$563 = $551;
                                                   label = 213;
                                                  } else {
                                                   $553 = ((($3)) + 72|0);
                                                   $$0$i$i301 = $553;$$024$i$i300 = $551;$832 = $551;
                                                   while(1) {
                                                    $554 = ((($$024$i$i300)) + 16|0);
                                                    $555 = HEAP32[$554>>2]|0;
                                                    $556 = ($555>>>0)>(6);
                                                    if ($556) {
                                                     $557 = HEAP32[$$024$i$i300>>2]|0;
                                                     $558 = ($557|0)==(0|0);
                                                     if ($558) {
                                                      label = 207;
                                                      break;
                                                     } else {
                                                      $$0$ph$i$i298 = $$024$i$i300;$$in$i$i297 = $557;
                                                     }
                                                    } else {
                                                     $559 = ($555|0)==(6);
                                                     if ($559) {
                                                      label = 211;
                                                      break;
                                                     }
                                                     $560 = ((($$024$i$i300)) + 4|0);
                                                     $561 = HEAP32[$560>>2]|0;
                                                     $562 = ($561|0)==(0|0);
                                                     if ($562) {
                                                      label = 210;
                                                      break;
                                                     } else {
                                                      $$0$ph$i$i298 = $560;$$in$i$i297 = $561;
                                                     }
                                                    }
                                                    $$0$i$i301 = $$0$ph$i$i298;$$024$i$i300 = $$in$i$i297;$832 = $$in$i$i297;
                                                   }
                                                   if ((label|0) == 207) {
                                                    $$025$i47$i305 = $$024$i$i300;$$03446$i306 = $$024$i$i300;
                                                    label = 214;
                                                    break;
                                                   }
                                                   else if ((label|0) == 210) {
                                                    $$025$i47$i305 = $560;$$03446$i306 = $$024$i$i300;
                                                    label = 214;
                                                    break;
                                                   }
                                                   else if ((label|0) == 211) {
                                                    $$025$i$i303 = $$0$i$i301;$$034$i302 = $$024$i$i300;$563 = $832;
                                                    label = 213;
                                                    break;
                                                   }
                                                  }
                                                 } while(0);
                                                 if ((label|0) == 213) {
                                                  $564 = ($563|0)==(0|0);
                                                  if ($564) {
                                                   $$025$i47$i305 = $$025$i$i303;$$03446$i306 = $$034$i302;
                                                   label = 214;
                                                  } else {
                                                   $$014$i310 = $563;
                                                   label = 218;
                                                  }
                                                 }
                                                 do {
                                                  if ((label|0) == 214) {
                                                   __THREW__ = 0;
                                                   $565 = (invoke_ii(3276,24)|0);
                                                   $566 = __THREW__; __THREW__ = 0;
                                                   $567 = $566&1;
                                                   if ($567) {
                                                    break;
                                                   }
                                                   $568 = ((($565)) + 16|0);
                                                   HEAP32[$568>>2] = 6;
                                                   $569 = ((($565)) + 20|0);
                                                   HEAP32[$569>>2] = 0;
                                                   HEAP32[$565>>2] = 0;
                                                   $570 = ((($565)) + 4|0);
                                                   HEAP32[$570>>2] = 0;
                                                   $571 = ((($565)) + 8|0);
                                                   HEAP32[$571>>2] = $$03446$i306;
                                                   HEAP32[$$025$i47$i305>>2] = $565;
                                                   $572 = HEAP32[$271>>2]|0;
                                                   $573 = HEAP32[$572>>2]|0;
                                                   $574 = ($573|0)==(0|0);
                                                   if ($574) {
                                                    $578 = $565;
                                                   } else {
                                                    $575 = $573;
                                                    HEAP32[$271>>2] = $575;
                                                    $$pre$i$i308 = HEAP32[$$025$i47$i305>>2]|0;
                                                    $578 = $$pre$i$i308;
                                                   }
                                                   $576 = ((($3)) + 72|0);
                                                   $577 = HEAP32[$576>>2]|0;
                                                   __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($577,$578);
                                                   $579 = ((($3)) + 76|0);
                                                   $580 = HEAP32[$579>>2]|0;
                                                   $581 = (($580) + 1)|0;
                                                   HEAP32[$579>>2] = $581;
                                                   $$014$i310 = $565;
                                                   label = 218;
                                                  }
                                                 } while(0);
                                                 do {
                                                  if ((label|0) == 218) {
                                                   $582 = ((($$014$i310)) + 20|0);
                                                   $583 = HEAP32[$582>>2]|0;
                                                   $584 = (+($583>>>0));
                                                   __THREW__ = 0;
                                                   (invoke_iiiid(3392,($2|0),($0|0),($20|0),(+$584))|0);
                                                   $585 = __THREW__; __THREW__ = 0;
                                                   $586 = $585&1;
                                                   if ($586) {
                                                    break;
                                                   }
                                                   $587 = ((($20)) + 11|0);
                                                   $588 = HEAP8[$587>>0]|0;
                                                   $589 = ($588<<24>>24)<(0);
                                                   if ($589) {
                                                    $590 = HEAP32[$20>>2]|0;
                                                    __ZdlPv($590);
                                                   }
                                                   ;HEAP32[$21>>2]=0|0;HEAP32[$21+4>>2]=0|0;HEAP32[$21+8>>2]=0|0;
                                                   __THREW__ = 0;
                                                   $591 = (invoke_ii(3276,32)|0);
                                                   $592 = __THREW__; __THREW__ = 0;
                                                   $593 = $592&1;
                                                   do {
                                                    if ($593) {
                                                     $797 = ___cxa_find_matching_catch_2()|0;
                                                     $798 = tempRet0;
                                                     $$18 = $797;$$1882 = $798;
                                                    } else {
                                                     HEAP32[$21>>2] = $591;
                                                     $594 = ((($21)) + 8|0);
                                                     HEAP32[$594>>2] = -2147483616;
                                                     $595 = ((($21)) + 4|0);
                                                     HEAP32[$595>>2] = 26;
                                                     dest=$591; src=109032; stop=dest+26|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                                                     $596 = ((($591)) + 26|0);
                                                     HEAP8[$596>>0] = 0;
                                                     $597 = HEAP32[$278>>2]|0;
                                                     $598 = ($597|0)==(0|0);
                                                     do {
                                                      if ($598) {
                                                       $$025$i$i327 = $278;$$034$i326 = $278;$609 = $597;
                                                       label = 233;
                                                      } else {
                                                       $599 = ((($3)) + 72|0);
                                                       $$0$i$i325 = $599;$$024$i$i324 = $597;$833 = $597;
                                                       while(1) {
                                                        $600 = ((($$024$i$i324)) + 16|0);
                                                        $601 = HEAP32[$600>>2]|0;
                                                        $602 = ($601>>>0)>(7);
                                                        if ($602) {
                                                         $603 = HEAP32[$$024$i$i324>>2]|0;
                                                         $604 = ($603|0)==(0|0);
                                                         if ($604) {
                                                          label = 227;
                                                          break;
                                                         } else {
                                                          $$0$ph$i$i322 = $$024$i$i324;$$in$i$i321 = $603;
                                                         }
                                                        } else {
                                                         $605 = ($601|0)==(7);
                                                         if ($605) {
                                                          label = 231;
                                                          break;
                                                         }
                                                         $606 = ((($$024$i$i324)) + 4|0);
                                                         $607 = HEAP32[$606>>2]|0;
                                                         $608 = ($607|0)==(0|0);
                                                         if ($608) {
                                                          label = 230;
                                                          break;
                                                         } else {
                                                          $$0$ph$i$i322 = $606;$$in$i$i321 = $607;
                                                         }
                                                        }
                                                        $$0$i$i325 = $$0$ph$i$i322;$$024$i$i324 = $$in$i$i321;$833 = $$in$i$i321;
                                                       }
                                                       if ((label|0) == 227) {
                                                        $$025$i47$i329 = $$024$i$i324;$$03446$i330 = $$024$i$i324;
                                                        label = 234;
                                                        break;
                                                       }
                                                       else if ((label|0) == 230) {
                                                        $$025$i47$i329 = $606;$$03446$i330 = $$024$i$i324;
                                                        label = 234;
                                                        break;
                                                       }
                                                       else if ((label|0) == 231) {
                                                        $$025$i$i327 = $$0$i$i325;$$034$i326 = $$024$i$i324;$609 = $833;
                                                        label = 233;
                                                        break;
                                                       }
                                                      }
                                                     } while(0);
                                                     if ((label|0) == 233) {
                                                      $610 = ($609|0)==(0|0);
                                                      if ($610) {
                                                       $$025$i47$i329 = $$025$i$i327;$$03446$i330 = $$034$i326;
                                                       label = 234;
                                                      } else {
                                                       $$014$i334 = $609;
                                                       label = 238;
                                                      }
                                                     }
                                                     do {
                                                      if ((label|0) == 234) {
                                                       __THREW__ = 0;
                                                       $611 = (invoke_ii(3276,24)|0);
                                                       $612 = __THREW__; __THREW__ = 0;
                                                       $613 = $612&1;
                                                       if ($613) {
                                                        break;
                                                       }
                                                       $614 = ((($611)) + 16|0);
                                                       HEAP32[$614>>2] = 7;
                                                       $615 = ((($611)) + 20|0);
                                                       HEAP32[$615>>2] = 0;
                                                       HEAP32[$611>>2] = 0;
                                                       $616 = ((($611)) + 4|0);
                                                       HEAP32[$616>>2] = 0;
                                                       $617 = ((($611)) + 8|0);
                                                       HEAP32[$617>>2] = $$03446$i330;
                                                       HEAP32[$$025$i47$i329>>2] = $611;
                                                       $618 = HEAP32[$271>>2]|0;
                                                       $619 = HEAP32[$618>>2]|0;
                                                       $620 = ($619|0)==(0|0);
                                                       if ($620) {
                                                        $624 = $611;
                                                       } else {
                                                        $621 = $619;
                                                        HEAP32[$271>>2] = $621;
                                                        $$pre$i$i332 = HEAP32[$$025$i47$i329>>2]|0;
                                                        $624 = $$pre$i$i332;
                                                       }
                                                       $622 = ((($3)) + 72|0);
                                                       $623 = HEAP32[$622>>2]|0;
                                                       __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($623,$624);
                                                       $625 = ((($3)) + 76|0);
                                                       $626 = HEAP32[$625>>2]|0;
                                                       $627 = (($626) + 1)|0;
                                                       HEAP32[$625>>2] = $627;
                                                       $$014$i334 = $611;
                                                       label = 238;
                                                      }
                                                     } while(0);
                                                     do {
                                                      if ((label|0) == 238) {
                                                       $628 = ((($$014$i334)) + 20|0);
                                                       $629 = HEAP32[$628>>2]|0;
                                                       $630 = (+($629>>>0));
                                                       __THREW__ = 0;
                                                       (invoke_iiiid(3392,($2|0),($0|0),($21|0),(+$630))|0);
                                                       $631 = __THREW__; __THREW__ = 0;
                                                       $632 = $631&1;
                                                       if ($632) {
                                                        break;
                                                       }
                                                       $633 = ((($21)) + 11|0);
                                                       $634 = HEAP8[$633>>0]|0;
                                                       $635 = ($634<<24>>24)<(0);
                                                       if ($635) {
                                                        $636 = HEAP32[$21>>2]|0;
                                                        __ZdlPv($636);
                                                       }
                                                       ;HEAP32[$22>>2]=0|0;HEAP32[$22+4>>2]=0|0;HEAP32[$22+8>>2]=0|0;
                                                       __THREW__ = 0;
                                                       $637 = (invoke_ii(3276,32)|0);
                                                       $638 = __THREW__; __THREW__ = 0;
                                                       $639 = $638&1;
                                                       do {
                                                        if ($639) {
                                                         $805 = ___cxa_find_matching_catch_2()|0;
                                                         $806 = tempRet0;
                                                         $$19 = $805;$$1983 = $806;
                                                        } else {
                                                         HEAP32[$22>>2] = $637;
                                                         $640 = ((($22)) + 8|0);
                                                         HEAP32[$640>>2] = -2147483616;
                                                         $641 = ((($22)) + 4|0);
                                                         HEAP32[$641>>2] = 31;
                                                         dest=$637; src=109059; stop=dest+31|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                                                         $642 = ((($637)) + 31|0);
                                                         HEAP8[$642>>0] = 0;
                                                         $643 = HEAP32[$278>>2]|0;
                                                         $644 = ($643|0)==(0|0);
                                                         do {
                                                          if ($644) {
                                                           $$025$i$i351 = $278;$$034$i350 = $278;$655 = $643;
                                                           label = 253;
                                                          } else {
                                                           $645 = ((($3)) + 72|0);
                                                           $$0$i$i349 = $645;$$024$i$i348 = $643;$834 = $643;
                                                           while(1) {
                                                            $646 = ((($$024$i$i348)) + 16|0);
                                                            $647 = HEAP32[$646>>2]|0;
                                                            $648 = ($647>>>0)>(8);
                                                            if ($648) {
                                                             $649 = HEAP32[$$024$i$i348>>2]|0;
                                                             $650 = ($649|0)==(0|0);
                                                             if ($650) {
                                                              label = 247;
                                                              break;
                                                             } else {
                                                              $$0$ph$i$i346 = $$024$i$i348;$$in$i$i345 = $649;
                                                             }
                                                            } else {
                                                             $651 = ($647|0)==(8);
                                                             if ($651) {
                                                              label = 251;
                                                              break;
                                                             }
                                                             $652 = ((($$024$i$i348)) + 4|0);
                                                             $653 = HEAP32[$652>>2]|0;
                                                             $654 = ($653|0)==(0|0);
                                                             if ($654) {
                                                              label = 250;
                                                              break;
                                                             } else {
                                                              $$0$ph$i$i346 = $652;$$in$i$i345 = $653;
                                                             }
                                                            }
                                                            $$0$i$i349 = $$0$ph$i$i346;$$024$i$i348 = $$in$i$i345;$834 = $$in$i$i345;
                                                           }
                                                           if ((label|0) == 247) {
                                                            $$025$i47$i353 = $$024$i$i348;$$03446$i354 = $$024$i$i348;
                                                            label = 254;
                                                            break;
                                                           }
                                                           else if ((label|0) == 250) {
                                                            $$025$i47$i353 = $652;$$03446$i354 = $$024$i$i348;
                                                            label = 254;
                                                            break;
                                                           }
                                                           else if ((label|0) == 251) {
                                                            $$025$i$i351 = $$0$i$i349;$$034$i350 = $$024$i$i348;$655 = $834;
                                                            label = 253;
                                                            break;
                                                           }
                                                          }
                                                         } while(0);
                                                         if ((label|0) == 253) {
                                                          $656 = ($655|0)==(0|0);
                                                          if ($656) {
                                                           $$025$i47$i353 = $$025$i$i351;$$03446$i354 = $$034$i350;
                                                           label = 254;
                                                          } else {
                                                           $$014$i358 = $655;
                                                           label = 258;
                                                          }
                                                         }
                                                         do {
                                                          if ((label|0) == 254) {
                                                           __THREW__ = 0;
                                                           $657 = (invoke_ii(3276,24)|0);
                                                           $658 = __THREW__; __THREW__ = 0;
                                                           $659 = $658&1;
                                                           if ($659) {
                                                            break;
                                                           }
                                                           $660 = ((($657)) + 16|0);
                                                           HEAP32[$660>>2] = 8;
                                                           $661 = ((($657)) + 20|0);
                                                           HEAP32[$661>>2] = 0;
                                                           HEAP32[$657>>2] = 0;
                                                           $662 = ((($657)) + 4|0);
                                                           HEAP32[$662>>2] = 0;
                                                           $663 = ((($657)) + 8|0);
                                                           HEAP32[$663>>2] = $$03446$i354;
                                                           HEAP32[$$025$i47$i353>>2] = $657;
                                                           $664 = HEAP32[$271>>2]|0;
                                                           $665 = HEAP32[$664>>2]|0;
                                                           $666 = ($665|0)==(0|0);
                                                           if ($666) {
                                                            $670 = $657;
                                                           } else {
                                                            $667 = $665;
                                                            HEAP32[$271>>2] = $667;
                                                            $$pre$i$i356 = HEAP32[$$025$i47$i353>>2]|0;
                                                            $670 = $$pre$i$i356;
                                                           }
                                                           $668 = ((($3)) + 72|0);
                                                           $669 = HEAP32[$668>>2]|0;
                                                           __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($669,$670);
                                                           $671 = ((($3)) + 76|0);
                                                           $672 = HEAP32[$671>>2]|0;
                                                           $673 = (($672) + 1)|0;
                                                           HEAP32[$671>>2] = $673;
                                                           $$014$i358 = $657;
                                                           label = 258;
                                                          }
                                                         } while(0);
                                                         do {
                                                          if ((label|0) == 258) {
                                                           $674 = ((($$014$i358)) + 20|0);
                                                           $675 = HEAP32[$674>>2]|0;
                                                           $676 = (+($675>>>0));
                                                           __THREW__ = 0;
                                                           (invoke_iiiid(3392,($2|0),($0|0),($22|0),(+$676))|0);
                                                           $677 = __THREW__; __THREW__ = 0;
                                                           $678 = $677&1;
                                                           if ($678) {
                                                            break;
                                                           }
                                                           $679 = ((($22)) + 11|0);
                                                           $680 = HEAP8[$679>>0]|0;
                                                           $681 = ($680<<24>>24)<(0);
                                                           if ($681) {
                                                            $682 = HEAP32[$22>>2]|0;
                                                            __ZdlPv($682);
                                                           }
                                                           ;HEAP32[$23>>2]=0|0;HEAP32[$23+4>>2]=0|0;HEAP32[$23+8>>2]=0|0;
                                                           __THREW__ = 0;
                                                           $683 = (invoke_ii(3276,32)|0);
                                                           $684 = __THREW__; __THREW__ = 0;
                                                           $685 = $684&1;
                                                           do {
                                                            if ($685) {
                                                             $813 = ___cxa_find_matching_catch_2()|0;
                                                             $814 = tempRet0;
                                                             $$20 = $813;$$2084 = $814;
                                                            } else {
                                                             HEAP32[$23>>2] = $683;
                                                             $686 = ((($23)) + 8|0);
                                                             HEAP32[$686>>2] = -2147483616;
                                                             $687 = ((($23)) + 4|0);
                                                             HEAP32[$687>>2] = 28;
                                                             dest=$683; src=109091; stop=dest+28|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                                                             $688 = ((($683)) + 28|0);
                                                             HEAP8[$688>>0] = 0;
                                                             $689 = HEAP32[$278>>2]|0;
                                                             $690 = ($689|0)==(0|0);
                                                             do {
                                                              if ($690) {
                                                               $$025$i$i375 = $278;$$034$i374 = $278;$701 = $689;
                                                               label = 273;
                                                              } else {
                                                               $691 = ((($3)) + 72|0);
                                                               $$0$i$i373 = $691;$$024$i$i372 = $689;$835 = $689;
                                                               while(1) {
                                                                $692 = ((($$024$i$i372)) + 16|0);
                                                                $693 = HEAP32[$692>>2]|0;
                                                                $694 = ($693>>>0)>(9);
                                                                if ($694) {
                                                                 $695 = HEAP32[$$024$i$i372>>2]|0;
                                                                 $696 = ($695|0)==(0|0);
                                                                 if ($696) {
                                                                  label = 267;
                                                                  break;
                                                                 } else {
                                                                  $$0$ph$i$i370 = $$024$i$i372;$$in$i$i369 = $695;
                                                                 }
                                                                } else {
                                                                 $697 = ($693|0)==(9);
                                                                 if ($697) {
                                                                  label = 271;
                                                                  break;
                                                                 }
                                                                 $698 = ((($$024$i$i372)) + 4|0);
                                                                 $699 = HEAP32[$698>>2]|0;
                                                                 $700 = ($699|0)==(0|0);
                                                                 if ($700) {
                                                                  label = 270;
                                                                  break;
                                                                 } else {
                                                                  $$0$ph$i$i370 = $698;$$in$i$i369 = $699;
                                                                 }
                                                                }
                                                                $$0$i$i373 = $$0$ph$i$i370;$$024$i$i372 = $$in$i$i369;$835 = $$in$i$i369;
                                                               }
                                                               if ((label|0) == 267) {
                                                                $$025$i47$i377 = $$024$i$i372;$$03446$i378 = $$024$i$i372;
                                                                label = 274;
                                                                break;
                                                               }
                                                               else if ((label|0) == 270) {
                                                                $$025$i47$i377 = $698;$$03446$i378 = $$024$i$i372;
                                                                label = 274;
                                                                break;
                                                               }
                                                               else if ((label|0) == 271) {
                                                                $$025$i$i375 = $$0$i$i373;$$034$i374 = $$024$i$i372;$701 = $835;
                                                                label = 273;
                                                                break;
                                                               }
                                                              }
                                                             } while(0);
                                                             if ((label|0) == 273) {
                                                              $702 = ($701|0)==(0|0);
                                                              if ($702) {
                                                               $$025$i47$i377 = $$025$i$i375;$$03446$i378 = $$034$i374;
                                                               label = 274;
                                                              } else {
                                                               $$014$i382 = $701;
                                                               label = 278;
                                                              }
                                                             }
                                                             do {
                                                              if ((label|0) == 274) {
                                                               __THREW__ = 0;
                                                               $703 = (invoke_ii(3276,24)|0);
                                                               $704 = __THREW__; __THREW__ = 0;
                                                               $705 = $704&1;
                                                               if ($705) {
                                                                break;
                                                               }
                                                               $706 = ((($703)) + 16|0);
                                                               HEAP32[$706>>2] = 9;
                                                               $707 = ((($703)) + 20|0);
                                                               HEAP32[$707>>2] = 0;
                                                               HEAP32[$703>>2] = 0;
                                                               $708 = ((($703)) + 4|0);
                                                               HEAP32[$708>>2] = 0;
                                                               $709 = ((($703)) + 8|0);
                                                               HEAP32[$709>>2] = $$03446$i378;
                                                               HEAP32[$$025$i47$i377>>2] = $703;
                                                               $710 = HEAP32[$271>>2]|0;
                                                               $711 = HEAP32[$710>>2]|0;
                                                               $712 = ($711|0)==(0|0);
                                                               if ($712) {
                                                                $716 = $703;
                                                               } else {
                                                                $713 = $711;
                                                                HEAP32[$271>>2] = $713;
                                                                $$pre$i$i380 = HEAP32[$$025$i47$i377>>2]|0;
                                                                $716 = $$pre$i$i380;
                                                               }
                                                               $714 = ((($3)) + 72|0);
                                                               $715 = HEAP32[$714>>2]|0;
                                                               __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($715,$716);
                                                               $717 = ((($3)) + 76|0);
                                                               $718 = HEAP32[$717>>2]|0;
                                                               $719 = (($718) + 1)|0;
                                                               HEAP32[$717>>2] = $719;
                                                               $$014$i382 = $703;
                                                               label = 278;
                                                              }
                                                             } while(0);
                                                             do {
                                                              if ((label|0) == 278) {
                                                               $720 = ((($$014$i382)) + 20|0);
                                                               $721 = HEAP32[$720>>2]|0;
                                                               $722 = (+($721>>>0));
                                                               __THREW__ = 0;
                                                               (invoke_iiiid(3392,($2|0),($0|0),($23|0),(+$722))|0);
                                                               $723 = __THREW__; __THREW__ = 0;
                                                               $724 = $723&1;
                                                               if ($724) {
                                                                break;
                                                               }
                                                               $725 = ((($23)) + 11|0);
                                                               $726 = HEAP8[$725>>0]|0;
                                                               $727 = ($726<<24>>24)<(0);
                                                               if (!($727)) {
                                                                HEAP32[$3>>2] = (50252);
                                                                $729 = ((($3)) + 68|0);
                                                                $730 = HEAP32[$278>>2]|0;
                                                                __ZNSt3__26__treeINS_12__value_typeIjjEENS_19__map_value_compareIjS2_NS_4lessIjEELb1EEENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($729,$730);
                                                                $731 = ((($3)) + 52|0);
                                                                $732 = HEAP32[$163>>2]|0;
                                                                __ZNSt3__26__treeINS_12__value_typeIjNS_4pairIjjEEEENS_19__map_value_compareIjS4_NS_4lessIjEELb1EEENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($731,$732);
                                                                STACKTOP = sp;return;
                                                               }
                                                               $728 = HEAP32[$23>>2]|0;
                                                               __ZdlPv($728);
                                                               HEAP32[$3>>2] = (50252);
                                                               $729 = ((($3)) + 68|0);
                                                               $730 = HEAP32[$278>>2]|0;
                                                               __ZNSt3__26__treeINS_12__value_typeIjjEENS_19__map_value_compareIjS2_NS_4lessIjEELb1EEENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($729,$730);
                                                               $731 = ((($3)) + 52|0);
                                                               $732 = HEAP32[$163>>2]|0;
                                                               __ZNSt3__26__treeINS_12__value_typeIjNS_4pairIjjEEEENS_19__map_value_compareIjS4_NS_4lessIjEELb1EEENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($731,$732);
                                                               STACKTOP = sp;return;
                                                              }
                                                             } while(0);
                                                             $815 = ___cxa_find_matching_catch_2()|0;
                                                             $816 = tempRet0;
                                                             $817 = ((($23)) + 11|0);
                                                             $818 = HEAP8[$817>>0]|0;
                                                             $819 = ($818<<24>>24)<(0);
                                                             if (!($819)) {
                                                              $$20 = $815;$$2084 = $816;
                                                              break;
                                                             }
                                                             $820 = HEAP32[$23>>2]|0;
                                                             __ZdlPv($820);
                                                             $$20 = $815;$$2084 = $816;
                                                            }
                                                           } while(0);
                                                           $$23 = $$20;$$2387 = $$2084;
                                                           break L1;
                                                          }
                                                         } while(0);
                                                         $807 = ___cxa_find_matching_catch_2()|0;
                                                         $808 = tempRet0;
                                                         $809 = ((($22)) + 11|0);
                                                         $810 = HEAP8[$809>>0]|0;
                                                         $811 = ($810<<24>>24)<(0);
                                                         if (!($811)) {
                                                          $$19 = $807;$$1983 = $808;
                                                          break;
                                                         }
                                                         $812 = HEAP32[$22>>2]|0;
                                                         __ZdlPv($812);
                                                         $$19 = $807;$$1983 = $808;
                                                        }
                                                       } while(0);
                                                       $$23 = $$19;$$2387 = $$1983;
                                                       break L1;
                                                      }
                                                     } while(0);
                                                     $799 = ___cxa_find_matching_catch_2()|0;
                                                     $800 = tempRet0;
                                                     $801 = ((($21)) + 11|0);
                                                     $802 = HEAP8[$801>>0]|0;
                                                     $803 = ($802<<24>>24)<(0);
                                                     if (!($803)) {
                                                      $$18 = $799;$$1882 = $800;
                                                      break;
                                                     }
                                                     $804 = HEAP32[$21>>2]|0;
                                                     __ZdlPv($804);
                                                     $$18 = $799;$$1882 = $800;
                                                    }
                                                   } while(0);
                                                   $$23 = $$18;$$2387 = $$1882;
                                                   break L1;
                                                  }
                                                 } while(0);
                                                 $791 = ___cxa_find_matching_catch_2()|0;
                                                 $792 = tempRet0;
                                                 $793 = ((($20)) + 11|0);
                                                 $794 = HEAP8[$793>>0]|0;
                                                 $795 = ($794<<24>>24)<(0);
                                                 if (!($795)) {
                                                  $$17 = $791;$$1781 = $792;
                                                  break;
                                                 }
                                                 $796 = HEAP32[$20>>2]|0;
                                                 __ZdlPv($796);
                                                 $$17 = $791;$$1781 = $792;
                                                }
                                               } while(0);
                                               $$23 = $$17;$$2387 = $$1781;
                                               break L1;
                                              }
                                             } while(0);
                                             $783 = ___cxa_find_matching_catch_2()|0;
                                             $784 = tempRet0;
                                             $785 = ((($19)) + 11|0);
                                             $786 = HEAP8[$785>>0]|0;
                                             $787 = ($786<<24>>24)<(0);
                                             if (!($787)) {
                                              $$16 = $783;$$1680 = $784;
                                              break;
                                             }
                                             $788 = HEAP32[$19>>2]|0;
                                             __ZdlPv($788);
                                             $$16 = $783;$$1680 = $784;
                                            }
                                           } while(0);
                                           $$23 = $$16;$$2387 = $$1680;
                                           break L1;
                                          }
                                         } while(0);
                                         $775 = ___cxa_find_matching_catch_2()|0;
                                         $776 = tempRet0;
                                         $777 = ((($18)) + 11|0);
                                         $778 = HEAP8[$777>>0]|0;
                                         $779 = ($778<<24>>24)<(0);
                                         if (!($779)) {
                                          $$15 = $775;$$1579 = $776;
                                          break;
                                         }
                                         $780 = HEAP32[$18>>2]|0;
                                         __ZdlPv($780);
                                         $$15 = $775;$$1579 = $776;
                                        }
                                       } while(0);
                                       $$23 = $$15;$$2387 = $$1579;
                                       break L1;
                                      }
                                     } while(0);
                                     $767 = ___cxa_find_matching_catch_2()|0;
                                     $768 = tempRet0;
                                     $769 = ((($17)) + 11|0);
                                     $770 = HEAP8[$769>>0]|0;
                                     $771 = ($770<<24>>24)<(0);
                                     if (!($771)) {
                                      $$14 = $767;$$1478 = $768;
                                      break;
                                     }
                                     $772 = HEAP32[$17>>2]|0;
                                     __ZdlPv($772);
                                     $$14 = $767;$$1478 = $768;
                                    }
                                   } while(0);
                                   $$23 = $$14;$$2387 = $$1478;
                                   break L1;
                                  }
                                 } while(0);
                                 $759 = ___cxa_find_matching_catch_2()|0;
                                 $760 = tempRet0;
                                 $761 = ((($16)) + 11|0);
                                 $762 = HEAP8[$761>>0]|0;
                                 $763 = ($762<<24>>24)<(0);
                                 if (!($763)) {
                                  $$13 = $759;$$1377 = $760;
                                  break;
                                 }
                                 $764 = HEAP32[$16>>2]|0;
                                 __ZdlPv($764);
                                 $$13 = $759;$$1377 = $760;
                                }
                               } while(0);
                               $$23 = $$13;$$2387 = $$1377;
                               break L1;
                              }
                             } while(0);
                             $751 = ___cxa_find_matching_catch_2()|0;
                             $752 = tempRet0;
                             $753 = ((($15)) + 11|0);
                             $754 = HEAP8[$753>>0]|0;
                             $755 = ($754<<24>>24)<(0);
                             if (!($755)) {
                              $$12 = $751;$$1276 = $752;
                              break;
                             }
                             $756 = HEAP32[$15>>2]|0;
                             __ZdlPv($756);
                             $$12 = $751;$$1276 = $752;
                            }
                           } while(0);
                           $$23 = $$12;$$2387 = $$1276;
                           break L1;
                          }
                         } while(0);
                         $743 = ___cxa_find_matching_catch_2()|0;
                         $744 = tempRet0;
                         $745 = ((($14)) + 11|0);
                         $746 = HEAP8[$745>>0]|0;
                         $747 = ($746<<24>>24)<(0);
                         if (!($747)) {
                          $$11 = $743;$$1175 = $744;
                          break;
                         }
                         $748 = HEAP32[$14>>2]|0;
                         __ZdlPv($748);
                         $$11 = $743;$$1175 = $744;
                        }
                       } while(0);
                       $$23 = $$11;$$2387 = $$1175;
                       break L1;
                      }
                     } while(0);
                     $$23 = $$10;$$2387 = $$1074;
                     break L1;
                    }
                   } while(0);
                   $$23 = $$8;$$2387 = $$872;
                   break L1;
                  }
                 } while(0);
                 $$23 = $$7;$$2387 = $$771;
                 break L1;
                }
               } while(0);
               $$23 = $$6;$$2387 = $$670;
               break L1;
              }
             } while(0);
             $$23 = $$5;$$2387 = $$569;
             break L1;
            }
           } while(0);
           $$23 = $$4;$$2387 = $$468;
           break L1;
          }
         } while(0);
         $$23 = $$3;$$2387 = $$367;
         break L1;
        }
       } while(0);
       $$23 = $$2;$$2387 = $$266;
       break L1;
      }
     } while(0);
     $$23 = $$1;$$2387 = $$165;
     break L1;
    }
   } while(0);
   $$23 = $$0;$$2387 = $$064;
  }
 } while(0);
 HEAP32[$3>>2] = (50252);
 $821 = ((($3)) + 68|0);
 $822 = ((($3)) + 72|0);
 $823 = HEAP32[$822>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIjjEENS_19__map_value_compareIjS2_NS_4lessIjEELb1EEENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($821,$823);
 $824 = ((($3)) + 52|0);
 $825 = ((($3)) + 56|0);
 $826 = HEAP32[$825>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIjNS_4pairIjjEEEENS_19__map_value_compareIjS4_NS_4lessIjEELb1EEENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($824,$826);
 ___resumeException($$23|0);
 // unreachable;
}
function __ZN15ARBQuerySupportD2Ev($0) {
 $0 = $0|0;
 var $$023$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i = 0, $scevgep5$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (41896);
 $1 = ((($0)) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = ((($0)) + 32|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==($2|0);
  if (!($6)) {
   $scevgep$i$i$i = ((($5)) + -8|0);
   $7 = $scevgep$i$i$i;
   $8 = $2;
   $9 = (($7) - ($8))|0;
   $10 = $9 >>> 3;
   $11 = $10 ^ -1;
   $scevgep5$i$i$i = (($5) + ($11<<3)|0);
   HEAP32[$4>>2] = $scevgep5$i$i$i;
  }
  __ZdlPv($2);
 }
 $12 = ((($0)) + 16|0);
 $13 = ((($0)) + 24|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(0);
 if ($15) {
  __ZN3osg10ReferencedD2Ev($0);
  return;
 }
 $16 = ((($0)) + 20|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = HEAP32[$12>>2]|0;
 $19 = ((($18)) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = HEAP32[$17>>2]|0;
 $22 = ((($21)) + 4|0);
 HEAP32[$22>>2] = $20;
 $23 = HEAP32[$19>>2]|0;
 HEAP32[$23>>2] = $21;
 HEAP32[$13>>2] = 0;
 $24 = ($17|0)==($12|0);
 if ($24) {
  __ZN3osg10ReferencedD2Ev($0);
  return;
 } else {
  $$023$i$i = $17;
 }
 while(1) {
  $25 = ((($$023$i$i)) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  __ZdlPv($$023$i$i);
  $27 = ($26|0)==($12|0);
  if ($27) {
   break;
  } else {
   $$023$i$i = $26;
  }
 }
 __ZN3osg10ReferencedD2Ev($0);
 return;
}
function __ZN15ARBQuerySupportD0Ev($0) {
 $0 = $0|0;
 var $$023$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i = 0, $scevgep5$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (41896);
 $1 = ((($0)) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = ((($0)) + 32|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==($2|0);
  if (!($6)) {
   $scevgep$i$i$i$i = ((($5)) + -8|0);
   $7 = $scevgep$i$i$i$i;
   $8 = $2;
   $9 = (($7) - ($8))|0;
   $10 = $9 >>> 3;
   $11 = $10 ^ -1;
   $scevgep5$i$i$i$i = (($5) + ($11<<3)|0);
   HEAP32[$4>>2] = $scevgep5$i$i$i$i;
  }
  __ZdlPv($2);
 }
 $12 = ((($0)) + 16|0);
 $13 = ((($0)) + 24|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(0);
 if (!($15)) {
  $16 = ((($0)) + 20|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = HEAP32[$12>>2]|0;
  $19 = ((($18)) + 4|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = HEAP32[$17>>2]|0;
  $22 = ((($21)) + 4|0);
  HEAP32[$22>>2] = $20;
  $23 = HEAP32[$19>>2]|0;
  HEAP32[$23>>2] = $21;
  HEAP32[$13>>2] = 0;
  $24 = ($17|0)==($12|0);
  if (!($24)) {
   $$023$i$i$i = $17;
   while(1) {
    $25 = ((($$023$i$i$i)) + 4|0);
    $26 = HEAP32[$25>>2]|0;
    __ZdlPv($$023$i$i$i);
    $27 = ($26|0)==($12|0);
    if ($27) {
     break;
    } else {
     $$023$i$i$i = $26;
    }
   }
  }
 }
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $28 = __THREW__; __THREW__ = 0;
 $29 = $28&1;
 if ($29) {
  $30 = ___cxa_find_matching_catch_2()|0;
  $31 = tempRet0;
  __ZdlPv($0);
  ___resumeException($30|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZN15ARBQuerySupport10checkQueryEPN3osg5StatsEPNS0_5StateEy($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$073 = 0, $$074 = 0, $$075 = 0.0, $$076 = 0.0, $$sink$i$i = 0.0, $$sroa$092$0120 = 0, $$sroa$092$1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0.0;
 var $184 = 0.0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0;
 var $202 = 0, $203 = 0, $204 = 0, $205 = 0.0, $206 = 0, $207 = 0, $208 = 0.0, $209 = 0.0, $21 = 0, $210 = 0, $211 = 0.0, $212 = 0.0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0;
 var $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0.0, $229 = 0.0, $23 = 0, $230 = 0.0, $231 = 0, $232 = 0, $233 = 0.0, $234 = 0.0, $235 = 0.0, $236 = 0, $237 = 0, $238 = 0;
 var $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0.0, $25 = 0, $250 = 0.0, $251 = 0.0, $252 = 0, $253 = 0, $254 = 0.0, $255 = 0.0, $256 = 0.0;
 var $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0;
 var $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0;
 var $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0;
 var $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(64|0);
 $5 = sp + 60|0;
 $6 = sp + 16|0;
 $7 = sp + 8|0;
 $8 = sp;
 $9 = sp + 48|0;
 $10 = sp + 36|0;
 $11 = sp + 24|0;
 $12 = ((($0)) + 20|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($0)) + 16|0);
 $15 = $13;
 $16 = ($15|0)==($14|0);
 if ($16) {
  STACKTOP = sp;return;
 }
 $17 = ((($0)) + 12|0);
 $18 = ((($6)) + 4|0);
 $19 = ((($2)) + 880|0);
 $20 = ((($2)) + 888|0);
 $21 = ((($2)) + 864|0);
 $22 = ((($2)) + 872|0);
 $23 = ((($9)) + 8|0);
 $24 = ((($9)) + 4|0);
 $25 = ((($9)) + 11|0);
 $26 = ((($10)) + 8|0);
 $27 = ((($10)) + 4|0);
 $28 = ((($10)) + 11|0);
 $29 = ((($11)) + 8|0);
 $30 = ((($11)) + 4|0);
 $31 = ((($11)) + 11|0);
 $32 = ((($0)) + 24|0);
 $33 = ((($0)) + 32|0);
 $34 = ((($0)) + 36|0);
 $35 = ((($0)) + 28|0);
 $$sroa$092$0120 = $13;$283 = $15;
 while(1) {
  HEAP32[$5>>2] = 0;
  $36 = HEAP32[$17>>2]|0;
  $37 = ((($36)) + 936|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = $$sroa$092$0120;
  $40 = ((($39)) + 12|0);
  $41 = HEAP32[$40>>2]|0;
  FUNCTION_TABLE_viii[$38 & 8191]($41,34919,$5);
  $42 = HEAP32[$5>>2]|0;
  $43 = ($42|0)==(0);
  if ($43) {
   $321 = ((($283)) + 4|0);
   $322 = HEAP32[$321>>2]|0;
   $$sroa$092$1 = $322;
  } else {
   $44 = ((($39)) + 8|0);
   $45 = $44;
   $46 = $45;
   $47 = HEAP32[$46>>2]|0;
   $48 = (($45) + 4)|0;
   $49 = $48;
   $50 = HEAP32[$49>>2]|0;
   $51 = $6;
   $52 = $51;
   HEAP32[$52>>2] = $47;
   $53 = (($51) + 4)|0;
   $54 = $53;
   HEAP32[$54>>2] = $50;
   $55 = $7;
   $56 = $55;
   HEAP32[$56>>2] = 0;
   $57 = (($55) + 4)|0;
   $58 = $57;
   HEAP32[$58>>2] = 0;
   $59 = $8;
   $60 = $59;
   HEAP32[$60>>2] = 0;
   $61 = (($59) + 4)|0;
   $62 = $61;
   HEAP32[$62>>2] = 0;
   $63 = HEAP32[$17>>2]|0;
   $64 = ((($63)) + 944|0);
   $65 = HEAP32[$64>>2]|0;
   FUNCTION_TABLE_viii[$65 & 8191]($47,34918,$7);
   $66 = HEAP32[$17>>2]|0;
   $67 = ((($66)) + 944|0);
   $68 = HEAP32[$67>>2]|0;
   $69 = HEAP32[$18>>2]|0;
   FUNCTION_TABLE_viii[$68 & 8191]($69,34918,$8);
   $70 = $19;
   $71 = $70;
   $72 = HEAP32[$71>>2]|0;
   $73 = (($70) + 4)|0;
   $74 = $73;
   $75 = HEAP32[$74>>2]|0;
   $76 = HEAP32[$20>>2]|0;
   $77 = ($76|0)<(64);
   do {
    if ($77) {
     $90 = (($76) + -1)|0;
     $91 = (_bitshift64Shl(1,0,($90|0))|0);
     $92 = tempRet0;
     $93 = $7;
     $94 = $93;
     $95 = HEAP32[$94>>2]|0;
     $96 = (($93) + 4)|0;
     $97 = $96;
     $98 = HEAP32[$97>>2]|0;
     $99 = (_bitshift64Lshr(($95|0),($98|0),($90|0))|0);
     $100 = tempRet0;
     $101 = $8;
     $102 = $101;
     $103 = HEAP32[$102>>2]|0;
     $104 = (($101) + 4)|0;
     $105 = $104;
     $106 = HEAP32[$105>>2]|0;
     $107 = (_bitshift64Lshr(($103|0),($106|0),($90|0))|0);
     $108 = tempRet0;
     $109 = (_bitshift64Lshr(($72|0),($75|0),($90|0))|0);
     $110 = tempRet0;
     $111 = (_i64Add(($109|0),($110|0),-1,-1)|0);
     $112 = tempRet0;
     $113 = (_i64Add(($111|0),($112|0),($99|0),($100|0))|0);
     $114 = tempRet0;
     $115 = (_i64Add(($113|0),($114|0),($107|0),($108|0))|0);
     $116 = tempRet0;
     $117 = ($116>>>0)<(0);
     $118 = ($115>>>0)<(2);
     $119 = ($116|0)==(0);
     $120 = $119 & $118;
     $121 = $117 | $120;
     if ($121) {
      $122 = (_bitshift64Shl(1,0,($76|0))|0);
      $123 = tempRet0;
      $124 = ($98>>>0)>($106>>>0);
      $125 = ($95>>>0)>($103>>>0);
      $126 = ($98|0)==($106|0);
      $127 = $126 & $125;
      $128 = $124 | $127;
      if ($128) {
       $129 = (_i64Add(($103|0),($106|0),($122|0),($123|0))|0);
       $130 = tempRet0;
       $131 = $8;
       $132 = $131;
       HEAP32[$132>>2] = $129;
       $133 = (($131) + 4)|0;
       $134 = $133;
       HEAP32[$134>>2] = $130;
       $177 = $129;$178 = $130;$179 = $95;$180 = $98;$220 = $75;$222 = $72;
       break;
      }
      $135 = ($98>>>0)>($75>>>0);
      $136 = ($95>>>0)>($72>>>0);
      $137 = ($98|0)==($75|0);
      $138 = $137 & $136;
      $139 = $135 | $138;
      if ($139) {
       $140 = (_i64Subtract(($95|0),($98|0),($72|0),($75|0))|0);
       $141 = tempRet0;
       $142 = (_bitshift64Lshr(($91|0),($92|0),1)|0);
       $143 = tempRet0;
       $144 = ($141>>>0)>($143>>>0);
       $145 = ($140>>>0)>($142>>>0);
       $146 = ($141|0)==($143|0);
       $147 = $146 & $145;
       $148 = $144 | $147;
       if ($148) {
        $149 = (_i64Add(($122|0),($123|0),($72|0),($75|0))|0);
        $150 = tempRet0;
        $177 = $103;$178 = $106;$179 = $95;$180 = $98;$220 = $150;$222 = $149;
        break;
       }
      }
      $151 = ($75>>>0)>($106>>>0);
      $152 = ($72>>>0)>($103>>>0);
      $153 = ($75|0)==($106|0);
      $154 = $153 & $152;
      $155 = $151 | $154;
      if ($155) {
       $156 = (_i64Subtract(($72|0),($75|0),($103|0),($106|0))|0);
       $157 = tempRet0;
       $158 = (_bitshift64Lshr(($91|0),($92|0),1)|0);
       $159 = tempRet0;
       $160 = ($157>>>0)>($159>>>0);
       $161 = ($156>>>0)>($158>>>0);
       $162 = ($157|0)==($159|0);
       $163 = $162 & $161;
       $164 = $160 | $163;
       if ($164) {
        $165 = (_i64Add(($103|0),($106|0),($122|0),($123|0))|0);
        $166 = tempRet0;
        $167 = (_i64Add(($95|0),($98|0),($122|0),($123|0))|0);
        $168 = tempRet0;
        $169 = $7;
        $170 = $169;
        HEAP32[$170>>2] = $167;
        $171 = (($169) + 4)|0;
        $172 = $171;
        HEAP32[$172>>2] = $168;
        $173 = $8;
        $174 = $173;
        HEAP32[$174>>2] = $165;
        $175 = (($173) + 4)|0;
        $176 = $175;
        HEAP32[$176>>2] = $166;
        $177 = $165;$178 = $166;$179 = $167;$180 = $168;$220 = $75;$222 = $72;
       } else {
        $177 = $103;$178 = $106;$179 = $95;$180 = $98;$220 = $75;$222 = $72;
       }
      } else {
       $177 = $103;$178 = $106;$179 = $95;$180 = $98;$220 = $75;$222 = $72;
      }
     } else {
      $177 = $103;$178 = $106;$179 = $95;$180 = $98;$220 = $75;$222 = $72;
     }
    } else {
     $78 = $8;
     $79 = $78;
     $80 = HEAP32[$79>>2]|0;
     $81 = (($78) + 4)|0;
     $82 = $81;
     $83 = HEAP32[$82>>2]|0;
     $84 = $7;
     $85 = $84;
     $86 = HEAP32[$85>>2]|0;
     $87 = (($84) + 4)|0;
     $88 = $87;
     $89 = HEAP32[$88>>2]|0;
     $177 = $80;$178 = $83;$179 = $86;$180 = $89;$220 = $75;$222 = $72;
    }
   } while(0);
   $181 = (_i64Subtract(($177|0),($178|0),($179|0),($180|0))|0);
   $182 = tempRet0;
   $183 = (+($181>>>0)) + (4294967296.0*(+($182>>>0)));
   $184 = $183 * 1.0000000000000001E-9;
   $185 = (__ZN3osg5Timer8instanceEv()|0);
   $186 = $21;
   $187 = $186;
   $188 = HEAP32[$187>>2]|0;
   $189 = (($186) + 4)|0;
   $190 = $189;
   $191 = HEAP32[$190>>2]|0;
   $192 = $22;
   $193 = $192;
   $194 = HEAP32[$193>>2]|0;
   $195 = (($192) + 4)|0;
   $196 = $195;
   $197 = HEAP32[$196>>2]|0;
   $198 = ($197>>>0)>($191>>>0);
   $199 = ($194>>>0)>($188>>>0);
   $200 = ($197|0)==($191|0);
   $201 = $200 & $199;
   $202 = $198 | $201;
   if ($202) {
    $203 = (_i64Subtract(($194|0),($197|0),($188|0),($191|0))|0);
    $204 = tempRet0;
    $205 = (+($203>>>0)) + (4294967296.0*(+($204>>>0)));
    $$sink$i$i = $205;
   } else {
    $206 = (_i64Subtract(($188|0),($191|0),($194|0),($197|0))|0);
    $207 = tempRet0;
    $208 = (+($206>>>0)) + (4294967296.0*(+($207>>>0)));
    $209 = -$208;
    $$sink$i$i = $209;
   }
   $210 = ((($185)) + 8|0);
   $211 = +HEAPF64[$210>>3];
   $212 = $$sink$i$i * $211;
   $213 = $7;
   $214 = $213;
   $215 = HEAP32[$214>>2]|0;
   $216 = (($213) + 4)|0;
   $217 = $216;
   $218 = HEAP32[$217>>2]|0;
   $219 = ($218>>>0)>($220>>>0);
   $221 = ($215>>>0)>($222>>>0);
   $223 = ($218|0)==($220|0);
   $224 = $223 & $221;
   $225 = $219 | $224;
   if ($225) {
    $226 = (_i64Subtract(($215|0),($218|0),($222|0),($220|0))|0);
    $227 = tempRet0;
    $228 = (+($226>>>0)) + (4294967296.0*(+($227>>>0)));
    $229 = $228 * 1.0000000000000001E-9;
    $230 = $212 + $229;
    $$076 = $230;
   } else {
    $231 = (_i64Subtract(($222|0),($220|0),($215|0),($218|0))|0);
    $232 = tempRet0;
    $233 = (+($231>>>0)) + (4294967296.0*(+($232>>>0)));
    $234 = $233 * 1.0000000000000001E-9;
    $235 = $212 - $234;
    $$076 = $235;
   }
   $236 = $8;
   $237 = $236;
   $238 = HEAP32[$237>>2]|0;
   $239 = (($236) + 4)|0;
   $240 = $239;
   $241 = HEAP32[$240>>2]|0;
   $242 = ($241>>>0)>($220>>>0);
   $243 = ($238>>>0)>($222>>>0);
   $244 = ($241|0)==($220|0);
   $245 = $244 & $243;
   $246 = $242 | $245;
   if ($246) {
    $247 = (_i64Subtract(($238|0),($241|0),($222|0),($220|0))|0);
    $248 = tempRet0;
    $249 = (+($247>>>0)) + (4294967296.0*(+($248>>>0)));
    $250 = $249 * 1.0000000000000001E-9;
    $251 = $212 + $250;
    $$075 = $251;
   } else {
    $252 = (_i64Subtract(($222|0),($220|0),($238|0),($241|0))|0);
    $253 = tempRet0;
    $254 = (+($252>>>0)) + (4294967296.0*(+($253>>>0)));
    $255 = $254 * 1.0000000000000001E-9;
    $256 = $212 - $255;
    $$075 = $256;
   }
   $257 = ((($39)) + 16|0);
   $258 = HEAP32[$257>>2]|0;
   $259 = (__Znwj(32)|0);
   HEAP32[$9>>2] = $259;
   HEAP32[$23>>2] = -2147483616;
   HEAP32[$24>>2] = 19;
   dest=$259; src=108145; stop=dest+19|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
   $260 = ((($259)) + 19|0);
   HEAP8[$260>>0] = 0;
   __THREW__ = 0;
   (invoke_iiiid(3392,($1|0),($258|0),($9|0),(+$$076))|0);
   $261 = __THREW__; __THREW__ = 0;
   $262 = $261&1;
   if ($262) {
    label = 38;
    break;
   }
   $263 = HEAP8[$25>>0]|0;
   $264 = ($263<<24>>24)<(0);
   if ($264) {
    $265 = HEAP32[$9>>2]|0;
    __ZdlPv($265);
   }
   $266 = HEAP32[$257>>2]|0;
   $267 = (__Znwj(32)|0);
   HEAP32[$10>>2] = $267;
   HEAP32[$26>>2] = -2147483616;
   HEAP32[$27>>2] = 17;
   dest=$267; src=108165; stop=dest+17|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
   $268 = ((($267)) + 17|0);
   HEAP8[$268>>0] = 0;
   __THREW__ = 0;
   (invoke_iiiid(3392,($1|0),($266|0),($10|0),(+$$075))|0);
   $269 = __THREW__; __THREW__ = 0;
   $270 = $269&1;
   if ($270) {
    label = 41;
    break;
   }
   $271 = HEAP8[$28>>0]|0;
   $272 = ($271<<24>>24)<(0);
   if ($272) {
    $273 = HEAP32[$10>>2]|0;
    __ZdlPv($273);
   }
   $274 = HEAP32[$257>>2]|0;
   $275 = (__Znwj(32)|0);
   HEAP32[$11>>2] = $275;
   HEAP32[$29>>2] = -2147483616;
   HEAP32[$30>>2] = 19;
   dest=$275; src=108183; stop=dest+19|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
   $276 = ((($275)) + 19|0);
   HEAP8[$276>>0] = 0;
   __THREW__ = 0;
   (invoke_iiiid(3392,($1|0),($274|0),($11|0),(+$184))|0);
   $277 = __THREW__; __THREW__ = 0;
   $278 = $277&1;
   if ($278) {
    label = 44;
    break;
   }
   $279 = HEAP8[$31>>0]|0;
   $280 = ($279<<24>>24)<(0);
   if ($280) {
    $281 = HEAP32[$11>>2]|0;
    __ZdlPv($281);
   }
   $282 = ((($283)) + 4|0);
   $284 = HEAP32[$282>>2]|0;
   $285 = HEAP32[$283>>2]|0;
   $286 = ((($285)) + 4|0);
   HEAP32[$286>>2] = $284;
   $287 = HEAP32[$282>>2]|0;
   HEAP32[$287>>2] = $285;
   $288 = HEAP32[$32>>2]|0;
   $289 = (($288) + -1)|0;
   HEAP32[$32>>2] = $289;
   $290 = $$sroa$092$0120;
   __ZdlPv($290);
   $291 = HEAP32[$33>>2]|0;
   $292 = HEAP32[$34>>2]|0;
   $293 = ($291|0)==($292|0);
   if ($293) {
    __ZNSt3__26vectorINS_4pairIjjEENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($35,$6);
   } else {
    $294 = $6;
    $295 = $294;
    $296 = HEAP32[$295>>2]|0;
    $297 = (($294) + 4)|0;
    $298 = $297;
    $299 = HEAP32[$298>>2]|0;
    $300 = $291;
    $301 = $300;
    HEAP32[$301>>2] = $296;
    $302 = (($300) + 4)|0;
    $303 = $302;
    HEAP32[$303>>2] = $299;
    $304 = HEAP32[$33>>2]|0;
    $305 = ((($304)) + 8|0);
    HEAP32[$33>>2] = $305;
   }
   $$sroa$092$1 = $284;
  }
  $323 = $$sroa$092$1;
  $324 = ($323|0)==($14|0);
  if ($324) {
   label = 3;
   break;
  } else {
   $$sroa$092$0120 = $$sroa$092$1;$283 = $323;
  }
 }
 if ((label|0) == 3) {
  STACKTOP = sp;return;
 }
 else if ((label|0) == 38) {
  $306 = ___cxa_find_matching_catch_2()|0;
  $307 = tempRet0;
  $308 = HEAP8[$25>>0]|0;
  $309 = ($308<<24>>24)<(0);
  if ($309) {
   $310 = HEAP32[$9>>2]|0;
   __ZdlPv($310);
  }
  $$073 = $307;$$074 = $306;
  ___resumeException($$074|0);
  // unreachable;
 }
 else if ((label|0) == 41) {
  $311 = ___cxa_find_matching_catch_2()|0;
  $312 = tempRet0;
  $313 = HEAP8[$28>>0]|0;
  $314 = ($313<<24>>24)<(0);
  if ($314) {
   $315 = HEAP32[$10>>2]|0;
   __ZdlPv($315);
  }
  $$073 = $312;$$074 = $311;
  ___resumeException($$074|0);
  // unreachable;
 }
 else if ((label|0) == 44) {
  $316 = ___cxa_find_matching_catch_2()|0;
  $317 = tempRet0;
  $318 = HEAP8[$31>>0]|0;
  $319 = ($318<<24>>24)<(0);
  if ($319) {
   $320 = HEAP32[$11>>2]|0;
   __ZdlPv($320);
  }
  $$073 = $317;$$074 = $316;
  ___resumeException($$074|0);
  // unreachable;
 }
}
function __ZN15ARBQuerySupport10beginQueryEjPN3osg5StateE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$pre = 0, $$pre$phiZ2D = 0, $$pre3 = 0, $$sroa$0$0$$sroa_idx = 0, $$sroa$4$0$$sroa_idx = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep5$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 HEAP32[$3>>2] = 0;
 $4 = ((($3)) + 4|0);
 HEAP32[$4>>2] = 0;
 $5 = ((($0)) + 28|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($0)) + 32|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6|0)==($8|0);
 if ($9) {
  $10 = ((($0)) + 12|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ((($11)) + 904|0);
  $13 = HEAP32[$12>>2]|0;
  FUNCTION_TABLE_vii[$13 & 8191](1,$3);
  $14 = HEAP32[$10>>2]|0;
  $15 = ((($14)) + 904|0);
  $16 = HEAP32[$15>>2]|0;
  FUNCTION_TABLE_vii[$16 & 8191](1,$4);
  $$pre = HEAP32[$3>>2]|0;
  $$pre$phiZ2D = $10;$24 = $$pre;
 } else {
  $17 = ((($8)) + -8|0);
  $18 = HEAP32[$17>>2]|0;
  HEAP32[$3>>2] = $18;
  $19 = ((($8)) + -4|0);
  $20 = HEAP32[$19>>2]|0;
  HEAP32[$4>>2] = $20;
  $scevgep5$i$i$i = ((($8)) + -8|0);
  HEAP32[$7>>2] = $scevgep5$i$i$i;
  $$pre3 = ((($0)) + 12|0);
  $$pre$phiZ2D = $$pre3;$24 = $18;
 }
 $21 = HEAP32[$$pre$phiZ2D>>2]|0;
 $22 = ((($21)) + 924|0);
 $23 = HEAP32[$22>>2]|0;
 FUNCTION_TABLE_vii[$23 & 8191]($24,36392);
 $25 = ((($0)) + 16|0);
 $26 = $3;
 $27 = $26;
 $28 = HEAP32[$27>>2]|0;
 $29 = (($26) + 4)|0;
 $30 = $29;
 $31 = HEAP32[$30>>2]|0;
 $32 = (__Znwj(20)|0);
 $$sroa$0$0$$sroa_idx = ((($32)) + 8|0);
 $33 = $$sroa$0$0$$sroa_idx;
 $34 = $33;
 HEAP32[$34>>2] = $28;
 $35 = (($33) + 4)|0;
 $36 = $35;
 HEAP32[$36>>2] = $31;
 $$sroa$4$0$$sroa_idx = ((($32)) + 16|0);
 HEAP32[$$sroa$4$0$$sroa_idx>>2] = $1;
 $37 = ((($32)) + 4|0);
 HEAP32[$37>>2] = $25;
 $38 = HEAP32[$25>>2]|0;
 HEAP32[$32>>2] = $38;
 $39 = ((($38)) + 4|0);
 HEAP32[$39>>2] = $32;
 HEAP32[$25>>2] = $32;
 $40 = ((($0)) + 24|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = (($41) + 1)|0;
 HEAP32[$40>>2] = $42;
 STACKTOP = sp;return;
}
function __ZN15ARBQuerySupport8endQueryEPN3osg5StateE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + 924|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($0)) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($7)) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 FUNCTION_TABLE_vii[$5 & 8191]($9,36392);
 return;
}
function __ZN15ARBQuerySupport10initializeEPN3osg5StateEy($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ((($1)) + 784|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($0)) + 12|0);
 HEAP32[$6>>2] = $5;
 return;
}
function __ZNSt3__26vectorINS_4pairIjjEENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 3;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(536870911);
 if ($8) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $9 = ((($0)) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) - ($4))|0;
 $12 = $11 >> 3;
 $13 = ($12>>>0)<(268435455);
 $14 = $11 >> 2;
 $15 = ($14>>>0)<($7>>>0);
 $$sroa$speculated$i = $15 ? $7 : $14;
 $$sroa$speculated$$i = $13 ? $$sroa$speculated$i : 536870911;
 $16 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($16) {
   $26 = 0;
  } else {
   $17 = ($$sroa$speculated$$i>>>0)>(536870911);
   if (!($17)) {
    $23 = $$sroa$speculated$$i << 3;
    $24 = (__Znwj($23)|0);
    $26 = $24;
    break;
   }
   $18 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($18|0),(204840|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if ($20) {
    $21 = ___cxa_find_matching_catch_2()|0;
    $22 = tempRet0;
    ___cxa_free_exception(($18|0));
    ___resumeException($21|0);
    // unreachable;
   } else {
    HEAP32[$18>>2] = (99824);
    ___cxa_throw(($18|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $25 = (($26) + ($6<<3)|0);
 $27 = (($26) + ($$sroa$speculated$$i<<3)|0);
 $28 = $27;
 $29 = $1;
 $30 = $29;
 $31 = HEAP32[$30>>2]|0;
 $32 = (($29) + 4)|0;
 $33 = $32;
 $34 = HEAP32[$33>>2]|0;
 $35 = $25;
 $36 = $35;
 HEAP32[$36>>2] = $31;
 $37 = (($35) + 4)|0;
 $38 = $37;
 HEAP32[$38>>2] = $34;
 $39 = ((($25)) + 8|0);
 $40 = $39;
 $41 = (0 - ($6))|0;
 $42 = (($25) + ($41<<3)|0);
 $43 = $42;
 $44 = ($5|0)>(0);
 if ($44) {
  $45 = $4;
  _memcpy(($42|0),($45|0),($5|0))|0;
 }
 HEAP32[$0>>2] = $43;
 HEAP32[$2>>2] = $40;
 HEAP32[$9>>2] = $28;
 $46 = ($4|0)==(0);
 if ($46) {
  return;
 }
 $47 = $4;
 __ZdlPv($47);
 return;
}
function __ZN9osgViewer8Renderer15ThreadSafeQueue9takeFrontEv($0) {
 $0 = $0|0;
 var $$07 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 (FUNCTION_TABLE_ii[$3 & 8191]($0)|0);
 $4 = ((($0)) + 32|0);
 $5 = ((($0)) + 12|0);
 while(1) {
  $6 = HEAP8[$4>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if (!($7)) {
   break;
  }
  __THREW__ = 0;
  (invoke_iii(2501,($5|0),($0|0))|0);
  $23 = __THREW__; __THREW__ = 0;
  $24 = $23&1;
  if ($24) {
   label = 8;
   break;
  }
 }
 if ((label|0) == 8) {
  $28 = ___cxa_find_matching_catch_2()|0;
  $29 = tempRet0;
  $30 = HEAP32[$0>>2]|0;
  $31 = ((($30)) + 12|0);
  $32 = HEAP32[$31>>2]|0;
  __THREW__ = 0;
  (invoke_ii($32|0,($0|0))|0);
  $33 = __THREW__; __THREW__ = 0;
  $34 = $33&1;
  if ($34) {
   $35 = ___cxa_find_matching_catch_3(0|0)|0;
   $36 = tempRet0;
   ___clang_call_terminate($35);
   // unreachable;
  } else {
   ___resumeException($28|0);
   // unreachable;
  }
 }
 $8 = ((($0)) + 28|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0);
 if ($10) {
  $$07 = 0;
 } else {
  $11 = ((($0)) + 24|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ((($12)) + 8|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = ((($12)) + 4|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = HEAP32[$12>>2]|0;
  $18 = ((($17)) + 4|0);
  HEAP32[$18>>2] = $16;
  $19 = HEAP32[$15>>2]|0;
  HEAP32[$19>>2] = $17;
  $20 = (($9) + -1)|0;
  HEAP32[$8>>2] = $20;
  __ZdlPv($12);
  $21 = HEAP32[$8>>2]|0;
  $22 = ($21|0)==(0);
  if ($22) {
   HEAP8[$4>>0] = 0;
   $$07 = $14;
  } else {
   $$07 = $14;
  }
 }
 $25 = HEAP32[$0>>2]|0;
 $26 = ((($25)) + 12|0);
 $27 = HEAP32[$26>>2]|0;
 (FUNCTION_TABLE_ii[$27 & 8191]($0)|0);
 return ($$07|0);
}
function __GLOBAL__sub_I_Renderer_cpp() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF32[51951] = 1.0;
 HEAPF32[(207808)>>2] = 0.0;
 HEAPF32[(207812)>>2] = 0.0;
 HEAPF32[51954] = 0.0;
 HEAPF32[(207820)>>2] = 1.0;
 HEAPF32[(207824)>>2] = 0.0;
 HEAPF32[51957] = 0.0;
 HEAPF32[(207832)>>2] = 0.0;
 HEAPF32[(207836)>>2] = 1.0;
 __ZN11OpenThreads5MutexC2ENS0_9MutexTypeE(207792,1);
 HEAP32[51948] = (41932);
 (___cxa_atexit((707|0),(207792|0),(___dso_handle|0))|0);
 return;
}
function __ZN11OpenThreads14ReentrantMutexD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(707,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZN3osg12observer_ptrINS_6CameraEEC2EPS1_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$ = 0, $$pr = 0, $$pr6 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = 0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   label = 9;
  } else {
   __THREW__ = 0;
   $3 = (invoke_ii(3325,($1|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $$pr = HEAP32[$0>>2]|0;
    $6 = ($$pr|0)==($3|0);
    if ($6) {
     $16 = $3;
     break;
    }
    HEAP32[$0>>2] = $3;
    $7 = ($3|0)==(0|0);
    if (!($7)) {
     $8 = ((($3)) + 8|0);
     $9 = HEAP32[$8>>2]|0;HEAP32[$8>>2] = (($9+1)|0);
    }
    $10 = ($$pr|0)==(0|0);
    if ($10) {
     label = 9;
     break;
    }
    $11 = ((($$pr)) + 8|0);
    $12 = HEAP32[$11>>2]|0;HEAP32[$11>>2] = (($12-1)|0);
    $13 = ($12|0)==(1);
    if (!($13)) {
     label = 9;
     break;
    }
    __THREW__ = 0;
    invoke_viii(3262,($$pr|0),1,1);
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if (!($15)) {
     label = 9;
     break;
    }
   }
   $23 = ___cxa_find_matching_catch_2()|0;
   $24 = tempRet0;
   $25 = HEAP32[$0>>2]|0;
   $26 = ($25|0)==(0|0);
   if ($26) {
    HEAP32[$0>>2] = 0;
    ___resumeException($23|0);
    // unreachable;
   }
   $27 = ((($25)) + 8|0);
   $28 = HEAP32[$27>>2]|0;HEAP32[$27>>2] = (($28-1)|0);
   $29 = ($28|0)==(1);
   if (!($29)) {
    HEAP32[$0>>2] = 0;
    ___resumeException($23|0);
    // unreachable;
   }
   __THREW__ = 0;
   invoke_viii(3262,($25|0),1,1);
   $30 = __THREW__; __THREW__ = 0;
   $31 = $30&1;
   if ($31) {
    $32 = ___cxa_find_matching_catch_3(0|0)|0;
    $33 = tempRet0;
    ___clang_call_terminate($32);
    // unreachable;
   } else {
    HEAP32[$0>>2] = 0;
    ___resumeException($23|0);
    // unreachable;
   }
  }
 } while(0);
 if ((label|0) == 9) {
  $$pr6 = HEAP32[$0>>2]|0;
  $16 = $$pr6;
 }
 $17 = ($16|0)==(0|0);
 if ($17) {
  $22 = 0;
  $21 = ((($0)) + 4|0);
  HEAP32[$21>>2] = $22;
  return;
 }
 $18 = ((($16)) + 24|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)!=(0|0);
 $$ = $20 ? $1 : 0;
 $22 = $$;
 $21 = ((($0)) + 4|0);
 HEAP32[$21>>2] = $22;
 return;
}
function __ZN7osgUtil11CullVisitor10IdentifierD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZN9osgViewer8RendererC1EPN3osg6CameraE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$023$i$i$i = 0, $$023$i$i$i97 = 0, $$068 = 0, $$069 = 0, $$10 = 0, $$1064 = 0, $$11 = 0, $$1165 = 0, $$12 = 0, $$1266 = 0, $$13 = 0, $$1367 = 0, $$2 = 0, $$256 = 0, $$9 = 0, $$963 = 0, $$ph178 = 0, $$pre = 0, $10 = 0;
 var $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0;
 var $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0;
 var $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0;
 var $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0;
 var $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0;
 var $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0;
 var $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0;
 var $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0;
 var $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0;
 var $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0;
 var $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0;
 var $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0;
 var $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0;
 var $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0;
 var $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0;
 var $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0;
 var $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0;
 var $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0;
 var $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0;
 var $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0;
 var $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0;
 var $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0;
 var $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0;
 var $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0;
 var $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0;
 var $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0;
 var $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0;
 var $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0;
 var $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0;
 var $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0;
 var $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0;
 var $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0;
 var $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0;
 var $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0;
 var $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0;
 var $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0;
 var $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0;
 var $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0;
 var $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0;
 var $803 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, $eh$lpad$body117$index19Z2D = 0, $eh$lpad$body117$indexZ2D = 0, $eh$lpad$body75$index7Z2D = 0, $eh$lpad$body75$indexZ2D = 0, $eh$lpad$body81$index12Z2D = 0, $eh$lpad$body81$indexZ2D = 0, $eh$lpad$body96$indexZ2D = 0, $switch$select = 0, $switch$select182 = 0, $switch$selectcmp = 0, $switch$selectcmp181 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $2 = sp + 16|0;
 $3 = sp + 12|0;
 $4 = sp;
 $5 = ((($0)) + 128|0);
 __ZN3osg10ReferencedC2Eb($5,1);
 ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;
 $6 = ((($4)) + 11|0);
 HEAP8[$6>>0] = 8;
 $7 = $4;
 $8 = $7;
 HEAP32[$8>>2] = 1684956498;
 $9 = (($7) + 4)|0;
 $10 = $9;
 HEAP32[$10>>2] = 1919251045;
 $11 = ((($4)) + 8|0);
 HEAP8[$11>>0] = 0;
 HEAP32[$0>>2] = ((8252));
 HEAP32[$5>>2] = ((8284));
 $12 = ((($0)) + 4|0);
 __THREW__ = 0;
 invoke_vii(3457,($12|0),($4|0));
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 L1: do {
  if ($14) {
   $105 = ___cxa_find_matching_catch_2()|0;
   $106 = tempRet0;
   $107 = HEAP8[$6>>0]|0;
   $108 = ($107<<24>>24)<(0);
   if ($108) {
    $109 = HEAP32[$4>>2]|0;
    __ZdlPv($109);
   }
   $$13 = $105;$$1367 = $106;
   label = 260;
  } else {
   $15 = ((($0)) + 16|0);
   HEAP8[$15>>0] = 1;
   HEAP32[$0>>2] = ((8188));
   HEAP32[$5>>2] = ((8224));
   $16 = HEAP8[$6>>0]|0;
   $17 = ($16<<24>>24)<(0);
   if ($17) {
    $18 = HEAP32[$4>>2]|0;
    __ZdlPv($18);
   }
   HEAP32[$0>>2] = (41792);
   HEAP32[$5>>2] = (41852);
   $19 = ((($0)) + 20|0);
   __THREW__ = 0;
   invoke_vii(3506,($19|0),($1|0));
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   L10: do {
    if ($21) {
     $110 = ___cxa_find_matching_catch_2()|0;
     $111 = tempRet0;
     $$12 = $110;$$1266 = $111;
    } else {
     $22 = ((($0)) + 28|0);
     HEAP8[$22>>0] = 0;
     $23 = ((($0)) + 29|0);
     HEAP8[$23>>0] = 1;
     $24 = ((($0)) + 30|0);
     HEAP8[$24>>0] = 1;
     $25 = ((($0)) + 31|0);
     $26 = ((($0)) + 32|0);
     $27 = ((($0)) + 40|0);
     dest=$25; stop=dest+9|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
     __THREW__ = 0;
     invoke_vii(3507,($27|0),0);
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     do {
      if ($29) {
       $112 = ___cxa_find_matching_catch_2()|0;
       $113 = tempRet0;
       $eh$lpad$body$index2Z2D = $113;$eh$lpad$body$indexZ2D = $112;
       label = 32;
      } else {
       $30 = ((($0)) + 52|0);
       __THREW__ = 0;
       invoke_vi(3508,($30|0));
       $31 = __THREW__; __THREW__ = 0;
       $32 = $31&1;
       if ($32) {
        $33 = ___cxa_find_matching_catch_2()|0;
        $34 = tempRet0;
        __THREW__ = 0;
        invoke_vi(707,($27|0));
        $35 = __THREW__; __THREW__ = 0;
        $36 = $35&1;
        if (!($36)) {
         $eh$lpad$body$index2Z2D = $34;$eh$lpad$body$indexZ2D = $33;
         label = 32;
         break;
        }
        $37 = ___cxa_find_matching_catch_3(0|0)|0;
        $38 = tempRet0;
        ___clang_call_terminate($37);
        // unreachable;
       }
       $39 = ((($0)) + 60|0);
       HEAP32[$39>>2] = $39;
       $40 = ((($0)) + 64|0);
       HEAP32[$40>>2] = $39;
       $41 = ((($0)) + 68|0);
       HEAP32[$41>>2] = 0;
       $42 = ((($0)) + 72|0);
       HEAP8[$42>>0] = 0;
       $43 = ((($0)) + 76|0);
       __THREW__ = 0;
       invoke_vii(3507,($43|0),0);
       $44 = __THREW__; __THREW__ = 0;
       $45 = $44&1;
       do {
        if ($45) {
         $114 = ___cxa_find_matching_catch_2()|0;
         $115 = tempRet0;
         $eh$lpad$body75$index7Z2D = $115;$eh$lpad$body75$indexZ2D = $114;
         label = 34;
        } else {
         $46 = ((($0)) + 88|0);
         __THREW__ = 0;
         invoke_vi(3508,($46|0));
         $47 = __THREW__; __THREW__ = 0;
         $48 = $47&1;
         if ($48) {
          $49 = ___cxa_find_matching_catch_2()|0;
          $50 = tempRet0;
          __THREW__ = 0;
          invoke_vi(707,($43|0));
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if (!($52)) {
           $eh$lpad$body75$index7Z2D = $50;$eh$lpad$body75$indexZ2D = $49;
           label = 34;
           break;
          }
          $53 = ___cxa_find_matching_catch_3(0|0)|0;
          $54 = tempRet0;
          ___clang_call_terminate($53);
          // unreachable;
         }
         $55 = ((($0)) + 96|0);
         HEAP32[$55>>2] = $55;
         $56 = ((($0)) + 100|0);
         HEAP32[$56>>2] = $55;
         $57 = ((($0)) + 104|0);
         HEAP32[$57>>2] = 0;
         $58 = ((($0)) + 108|0);
         HEAP8[$58>>0] = 0;
         $59 = ((($0)) + 112|0);
         HEAP8[$59>>0] = 0;
         $60 = ((($0)) + 116|0);
         HEAP32[$60>>2] = 0;
         $61 = ((($0)) + 120|0);
         $62 = $61;
         $63 = $62;
         HEAP32[$63>>2] = 0;
         $64 = (($62) + 4)|0;
         $65 = $64;
         HEAP32[$65>>2] = 0;
         __THREW__ = 0;
         $66 = (invoke_ii(3265,5)|0);
         $67 = __THREW__; __THREW__ = 0;
         $68 = $67&1;
         L27: do {
          if ($68) {
           label = 35;
          } else {
           L29: do {
            if ($66) {
             __THREW__ = 0;
             $69 = (invoke_ii(3266,5)|0);
             $70 = __THREW__; __THREW__ = 0;
             $71 = $70&1;
             if ($71) {
              label = 35;
              break L27;
             }
             __THREW__ = 0;
             $72 = (invoke_iiii(3267,($69|0),(109417|0),17)|0);
             $73 = __THREW__; __THREW__ = 0;
             $74 = $73&1;
             if ($74) {
              label = 35;
              break L27;
             }
             __THREW__ = 0;
             $75 = (invoke_iii(3275,($72|0),($0|0))|0);
             $76 = __THREW__; __THREW__ = 0;
             $77 = $76&1;
             if ($77) {
              label = 35;
              break L27;
             }
             $78 = HEAP32[$75>>2]|0;
             $79 = ((($78)) + -12|0);
             $80 = HEAP32[$79>>2]|0;
             $81 = (($75) + ($80)|0);
             __THREW__ = 0;
             invoke_vii(3257,($3|0),($81|0));
             $82 = __THREW__; __THREW__ = 0;
             $83 = $82&1;
             if ($83) {
              label = 35;
              break L27;
             }
             __THREW__ = 0;
             $84 = (invoke_iii(3255,($3|0),(215188|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             do {
              if (!($86)) {
               $87 = HEAP32[$84>>2]|0;
               $88 = ((($87)) + 28|0);
               $89 = HEAP32[$88>>2]|0;
               __THREW__ = 0;
               $90 = (invoke_iii($89|0,($84|0),10)|0);
               $91 = __THREW__; __THREW__ = 0;
               $92 = $91&1;
               if ($92) {
                break;
               }
               __THREW__ = 0;
               invoke_vi(3263,($3|0));
               $99 = __THREW__; __THREW__ = 0;
               $100 = $99&1;
               if ($100) {
                label = 35;
                break L27;
               }
               __THREW__ = 0;
               (invoke_iii(3268,($75|0),($90|0))|0);
               $101 = __THREW__; __THREW__ = 0;
               $102 = $101&1;
               if ($102) {
                label = 35;
                break L27;
               }
               __THREW__ = 0;
               (invoke_ii(3269,($75|0))|0);
               $103 = __THREW__; __THREW__ = 0;
               $104 = $103&1;
               if ($104) {
                label = 35;
                break L27;
               } else {
                break L29;
               }
              }
             } while(0);
             $93 = ___cxa_find_matching_catch_2()|0;
             $94 = tempRet0;
             __THREW__ = 0;
             invoke_vi(3263,($3|0));
             $95 = __THREW__; __THREW__ = 0;
             $96 = $95&1;
             if ($96) {
              $97 = ___cxa_find_matching_catch_3(0|0)|0;
              $98 = tempRet0;
              ___clang_call_terminate($97);
              // unreachable;
             } else {
              $eh$lpad$body81$index12Z2D = $94;$eh$lpad$body81$indexZ2D = $93;
              label = 36;
              break L27;
             }
            }
           } while(0);
           __THREW__ = 0;
           $118 = (invoke_ii(3276,296)|0);
           $119 = __THREW__; __THREW__ = 0;
           $120 = $119&1;
           if ($120) {
            label = 35;
           } else {
            __THREW__ = 0;
            invoke_vii(3509,($118|0),(0|0));
            $121 = __THREW__; __THREW__ = 0;
            $122 = $121&1;
            if ($122) {
             $198 = ___cxa_find_matching_catch_2()|0;
             $199 = tempRet0;
             __ZdlPv($118);
             $$9 = $198;$$963 = $199;
             break;
            }
            $123 = HEAP32[$26>>2]|0;
            $124 = ($123|0)==($118|0);
            if (!($124)) {
             HEAP32[$26>>2] = $118;
             $125 = ((($118)) + 8|0);
             $126 = HEAP32[$125>>2]|0;HEAP32[$125>>2] = (($126+1)|0);
             $127 = ($123|0)==(0|0);
             if (!($127)) {
              $128 = ((($123)) + 8|0);
              $129 = HEAP32[$128>>2]|0;HEAP32[$128>>2] = (($129-1)|0);
              $130 = ($129|0)==(1);
              if ($130) {
               __THREW__ = 0;
               invoke_viii(3262,($123|0),1,1);
               $131 = __THREW__; __THREW__ = 0;
               $132 = $131&1;
               if ($132) {
                label = 35;
                break;
               }
              }
             }
            }
            __THREW__ = 0;
            $133 = (invoke_ii(3276,296)|0);
            $134 = __THREW__; __THREW__ = 0;
            $135 = $134&1;
            if ($135) {
             label = 35;
            } else {
             __THREW__ = 0;
             invoke_vii(3509,($133|0),(0|0));
             $136 = __THREW__; __THREW__ = 0;
             $137 = $136&1;
             if ($137) {
              $200 = ___cxa_find_matching_catch_2()|0;
              $201 = tempRet0;
              __ZdlPv($133);
              $$9 = $200;$$963 = $201;
              break;
             }
             $138 = ((($0)) + 36|0);
             $139 = HEAP32[$138>>2]|0;
             $140 = ($139|0)==($133|0);
             do {
              if (!($140)) {
               HEAP32[$138>>2] = $133;
               $141 = ((($133)) + 8|0);
               $142 = HEAP32[$141>>2]|0;HEAP32[$141>>2] = (($142+1)|0);
               $143 = ($139|0)==(0|0);
               if ($143) {
                break;
               }
               $144 = ((($139)) + 8|0);
               $145 = HEAP32[$144>>2]|0;HEAP32[$144>>2] = (($145-1)|0);
               $146 = ($145|0)==(1);
               if (!($146)) {
                break;
               }
               __THREW__ = 0;
               invoke_viii(3262,($139|0),1,1);
               $147 = __THREW__; __THREW__ = 0;
               $148 = $147&1;
               if ($148) {
                label = 35;
                break L27;
               }
              }
             } while(0);
             $149 = HEAP32[$26>>2]|0;
             __THREW__ = 0;
             $150 = (invoke_ii(3276,72)|0);
             $151 = __THREW__; __THREW__ = 0;
             $152 = $151&1;
             if ($152) {
              label = 35;
              break;
             }
             __THREW__ = 0;
             invoke_vi(3298,($150|0));
             $153 = __THREW__; __THREW__ = 0;
             $154 = $153&1;
             if ($154) {
              $202 = ___cxa_find_matching_catch_2()|0;
              $203 = tempRet0;
              __ZdlPv($150);
              $$9 = $202;$$963 = $203;
              break;
             }
             $155 = ((($149)) + 200|0);
             $156 = HEAP32[$155>>2]|0;
             $157 = ($156|0)==($150|0);
             do {
              if (!($157)) {
               HEAP32[$155>>2] = $150;
               $158 = ((($150)) + 8|0);
               $159 = HEAP32[$158>>2]|0;HEAP32[$158>>2] = (($159+1)|0);
               $160 = ($156|0)==(0|0);
               if ($160) {
                break;
               }
               $161 = ((($156)) + 8|0);
               $162 = HEAP32[$161>>2]|0;HEAP32[$161>>2] = (($162-1)|0);
               $163 = ($162|0)==(1);
               if (!($163)) {
                break;
               }
               __THREW__ = 0;
               invoke_viii(3262,($156|0),1,1);
               $164 = __THREW__; __THREW__ = 0;
               $165 = $164&1;
               if ($165) {
                label = 35;
                break L27;
               }
              }
             } while(0);
             $166 = HEAP32[$138>>2]|0;
             __THREW__ = 0;
             $167 = (invoke_ii(3276,72)|0);
             $168 = __THREW__; __THREW__ = 0;
             $169 = $168&1;
             if ($169) {
              label = 35;
              break;
             }
             __THREW__ = 0;
             invoke_vi(3298,($167|0));
             $170 = __THREW__; __THREW__ = 0;
             $171 = $170&1;
             if ($171) {
              $204 = ___cxa_find_matching_catch_2()|0;
              $205 = tempRet0;
              __ZdlPv($167);
              $$9 = $204;$$963 = $205;
              break;
             }
             $172 = ((($166)) + 200|0);
             $173 = HEAP32[$172>>2]|0;
             $174 = ($173|0)==($167|0);
             do {
              if (!($174)) {
               HEAP32[$172>>2] = $167;
               $175 = ((($167)) + 8|0);
               $176 = HEAP32[$175>>2]|0;HEAP32[$175>>2] = (($176+1)|0);
               $177 = ($173|0)==(0|0);
               if ($177) {
                break;
               }
               $178 = ((($173)) + 8|0);
               $179 = HEAP32[$178>>2]|0;HEAP32[$178>>2] = (($179-1)|0);
               $180 = ($179|0)==(1);
               if (!($180)) {
                break;
               }
               __THREW__ = 0;
               invoke_viii(3262,($173|0),1,1);
               $181 = __THREW__; __THREW__ = 0;
               $182 = $181&1;
               if ($182) {
                label = 35;
                break L27;
               }
              }
             } while(0);
             $183 = ((($0)) + 24|0);
             $184 = HEAP32[$183>>2]|0;
             $185 = ((($184)) + 220|0);
             $186 = HEAP32[$185>>2]|0;
             $187 = ($186|0)==(0|0);
             if ($187) {
              $191 = $1;
             } else {
              $188 = ((($186)) + 16|0);
              $189 = HEAP32[$188>>2]|0;
              $191 = $189;
             }
             $190 = ($184|0)==($191|0);
             do {
              if ($190) {
               __THREW__ = 0;
               $208 = (invoke_ii(3281,($184|0))|0);
               $209 = __THREW__; __THREW__ = 0;
               $210 = $209&1;
               if ($210) {
                label = 70;
                break;
               }
               $$pre = HEAP32[$183>>2]|0;
               $$068 = $208;$$069 = 0;$212 = $$pre;
              } else {
               __THREW__ = 0;
               $192 = (invoke_ii(3281,($191|0))|0);
               $193 = __THREW__; __THREW__ = 0;
               $194 = $193&1;
               if ($194) {
                label = 70;
                break;
               }
               $195 = HEAP32[$183>>2]|0;
               $196 = ((($195)) + 120|0);
               $197 = HEAP32[$196>>2]|0;
               $$068 = $192;$$069 = $197;$212 = $195;
              }
             } while(0);
             if ((label|0) == 70) {
              $206 = ___cxa_find_matching_catch_2()|0;
              $207 = tempRet0;
              $$9 = $206;$$963 = $207;
              break;
             }
             $211 = ((($212)) + 220|0);
             $213 = HEAP32[$211>>2]|0;
             $214 = ($213|0)==(0|0);
             do {
              if ($214) {
               $228 = 0;$234 = 0;$801 = 0;
              } else {
               $215 = (___dynamic_cast($213,27072,3928,0)|0);
               $216 = ($215|0)==(0|0);
               if ($216) {
                $228 = 0;$234 = 0;$801 = 0;
                break;
               }
               $217 = ((($215)) + 40|0);
               $218 = HEAP32[$217>>2]|0;
               $219 = ($218|0)==(0|0);
               if ($219) {
                $228 = 0;$234 = $215;$801 = 1;
                break;
               }
               $220 = ((($218)) + 24|0);
               $221 = HEAP32[$220>>2]|0;
               $222 = ($221|0)==(0|0);
               if ($222) {
                $228 = 0;$234 = $215;$801 = 1;
                break;
               }
               $223 = ((($215)) + 44|0);
               $224 = HEAP32[$223>>2]|0;
               $225 = ($224|0)==(0|0);
               if ($225) {
                $228 = 0;$234 = $215;$801 = 1;
                break;
               }
               $226 = ((($224)) + 88|0);
               $227 = HEAP32[$226>>2]|0;
               $228 = $227;$234 = $215;$801 = 1;
              }
             } while(0);
             $229 = ($228|0)==(0|0);
             $230 = ((($212)) + 232|0);
             $231 = HEAP32[$230>>2]|0;
             $232 = ($231|0)==(0|0);
             do {
              if ($232) {
               if ($801) {
                $233 = ((($234)) + 116|0);
                $235 = HEAP32[$233>>2]|0;
                $236 = ($235|0)==(0|0);
                if (!($236)) {
                 $$ph178 = $235;
                 label = 83;
                 break;
                }
               }
               __THREW__ = 0;
               $237 = (invoke_i(3285)|0);
               $238 = __THREW__; __THREW__ = 0;
               $239 = $238&1;
               if ($239) {
                $251 = ___cxa_find_matching_catch_2()|0;
                $252 = tempRet0;
                $$9 = $251;$$963 = $252;
                break L27;
               } else {
                $241 = HEAP32[$237>>2]|0;
                $242 = ($241|0)==(0|0);
                if ($242) {
                 $248 = 0;$323 = 0;$803 = 0;
                 break;
                } else {
                 $244 = $241;$802 = 1;
                 label = 85;
                 break;
                }
               }
              } else {
               $$ph178 = $231;
               label = 83;
              }
             } while(0);
             if ((label|0) == 83) {
              $240 = ($$ph178|0)!=(0|0);
              $244 = $$ph178;$802 = $240;
              label = 85;
             }
             if ((label|0) == 85) {
              $243 = ((($244)) + 93|0);
              $245 = HEAP8[$243>>0]|0;
              $246 = ($245<<24>>24)!=(0);
              $248 = $246;$323 = $244;$803 = $802;
             }
             $247 = $248&1;
             HEAP8[$25>>0] = $247;
             if ($801) {
              $249 = ((($234)) + 8|0);
              $250 = HEAP32[$249>>2]|0;
              $switch$selectcmp = ($250|0)==(2);
              $switch$select = $switch$selectcmp ? 2 : 1;
              $switch$selectcmp181 = ($250|0)==(0);
              $switch$select182 = $switch$selectcmp181 ? 0 : $switch$select;
              $$0 = $switch$select182;
             } else {
              $$0 = 1;
             }
             $255 = HEAP32[$26>>2]|0;
             $256 = $229&1;
             $257 = ((($255)) + 245|0);
             HEAP8[$257>>0] = $256;
             $258 = ((($255)) + 216|0);
             $259 = HEAP32[$258>>2]|0;
             $260 = ($259|0)==($$068|0);
             do {
              if ($260) {
               label = 97;
              } else {
               HEAP32[$258>>2] = $$068;
               $261 = ($$068|0)==(0|0);
               if (!($261)) {
                $262 = ((($$068)) + 8|0);
                $263 = HEAP32[$262>>2]|0;HEAP32[$262>>2] = (($263+1)|0);
               }
               $264 = ($259|0)==(0|0);
               if ($264) {
                label = 97;
                break;
               }
               $265 = ((($259)) + 8|0);
               $266 = HEAP32[$265>>2]|0;HEAP32[$265>>2] = (($266-1)|0);
               $267 = ($266|0)==(1);
               if (!($267)) {
                label = 97;
                break;
               }
               __THREW__ = 0;
               invoke_viii(3262,($259|0),1,1);
               $268 = __THREW__; __THREW__ = 0;
               $269 = $268&1;
               if ($269) {
                label = 89;
               } else {
                label = 97;
               }
              }
             } while(0);
             L122: do {
              if ((label|0) == 97) {
               $270 = HEAP32[$26>>2]|0;
               $271 = ((($270)) + 228|0);
               $272 = HEAP32[$271>>2]|0;
               $273 = ($272|0)==($$069|0);
               do {
                if (!($273)) {
                 HEAP32[$271>>2] = $$069;
                 $274 = ($$069|0)==(0|0);
                 if (!($274)) {
                  $275 = ((($$069)) + 8|0);
                  $276 = HEAP32[$275>>2]|0;HEAP32[$275>>2] = (($276+1)|0);
                 }
                 $277 = ($272|0)==(0|0);
                 if ($277) {
                  break;
                 }
                 $278 = ((($272)) + 8|0);
                 $279 = HEAP32[$278>>2]|0;HEAP32[$278>>2] = (($279-1)|0);
                 $280 = ($279|0)==(1);
                 if (!($280)) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_viii(3262,($272|0),1,1);
                 $281 = __THREW__; __THREW__ = 0;
                 $282 = $281&1;
                 if ($282) {
                  label = 89;
                  break L122;
                 }
                }
               } while(0);
               $283 = HEAP32[$138>>2]|0;
               $284 = ((($283)) + 245|0);
               HEAP8[$284>>0] = $256;
               $285 = ((($283)) + 216|0);
               $286 = HEAP32[$285>>2]|0;
               $287 = ($286|0)==($$068|0);
               do {
                if (!($287)) {
                 HEAP32[$285>>2] = $$068;
                 $288 = ($$068|0)==(0|0);
                 if (!($288)) {
                  $289 = ((($$068)) + 8|0);
                  $290 = HEAP32[$289>>2]|0;HEAP32[$289>>2] = (($290+1)|0);
                 }
                 $291 = ($286|0)==(0|0);
                 if ($291) {
                  break;
                 }
                 $292 = ((($286)) + 8|0);
                 $293 = HEAP32[$292>>2]|0;HEAP32[$292>>2] = (($293-1)|0);
                 $294 = ($293|0)==(1);
                 if (!($294)) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_viii(3262,($286|0),1,1);
                 $295 = __THREW__; __THREW__ = 0;
                 $296 = $295&1;
                 if ($296) {
                  label = 89;
                  break L122;
                 }
                }
               } while(0);
               $297 = HEAP32[$138>>2]|0;
               $298 = ((($297)) + 228|0);
               $299 = HEAP32[$298>>2]|0;
               $300 = ($299|0)==($$069|0);
               do {
                if (!($300)) {
                 HEAP32[$298>>2] = $$069;
                 $301 = ($$069|0)==(0|0);
                 if (!($301)) {
                  $302 = ((($$069)) + 8|0);
                  $303 = HEAP32[$302>>2]|0;HEAP32[$302>>2] = (($303+1)|0);
                 }
                 $304 = ($299|0)==(0|0);
                 if ($304) {
                  break;
                 }
                 $305 = ((($299)) + 8|0);
                 $306 = HEAP32[$305>>2]|0;HEAP32[$305>>2] = (($306-1)|0);
                 $307 = ($306|0)==(1);
                 if (!($307)) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_viii(3262,($299|0),1,1);
                 $308 = __THREW__; __THREW__ = 0;
                 $309 = $308&1;
                 if ($309) {
                  label = 89;
                  break L122;
                 }
                }
               } while(0);
               $310 = HEAP32[$26>>2]|0;
               $311 = HEAP32[$310>>2]|0;
               $312 = ((($311)) + 144|0);
               $313 = HEAP32[$312>>2]|0;
               __THREW__ = 0;
               invoke_vii($313|0,($310|0),($$0|0));
               $314 = __THREW__; __THREW__ = 0;
               $315 = $314&1;
               if ($315) {
                label = 89;
                break;
               }
               $316 = HEAP32[$138>>2]|0;
               $317 = HEAP32[$316>>2]|0;
               $318 = ((($317)) + 144|0);
               $319 = HEAP32[$318>>2]|0;
               __THREW__ = 0;
               invoke_vii($319|0,($316|0),($$0|0));
               $320 = __THREW__; __THREW__ = 0;
               $321 = $320&1;
               if ($321) {
                label = 89;
                break;
               }
               do {
                if ($803) {
                 $322 = ((($323)) + 94|0);
                 $324 = HEAP8[$322>>0]|0;
                 $325 = ($324<<24>>24)==(0);
                 if ($325) {
                  label = 129;
                  break;
                 }
                 $326 = HEAP32[$26>>2]|0;
                 $327 = ((($326)) + 224|0);
                 $328 = HEAP32[$327>>2]|0;
                 $329 = ($328|0)==($323|0);
                 do {
                  if (!($329)) {
                   HEAP32[$327>>2] = $323;
                   $330 = ((($323)) + 8|0);
                   $331 = HEAP32[$330>>2]|0;HEAP32[$330>>2] = (($331+1)|0);
                   $332 = ($328|0)==(0|0);
                   if ($332) {
                    break;
                   }
                   $333 = ((($328)) + 8|0);
                   $334 = HEAP32[$333>>2]|0;HEAP32[$333>>2] = (($334-1)|0);
                   $335 = ($334|0)==(1);
                   if (!($335)) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(3262,($328|0),1,1);
                   $336 = __THREW__; __THREW__ = 0;
                   $337 = $336&1;
                   if ($337) {
                    label = 89;
                    break L122;
                   }
                  }
                 } while(0);
                 $338 = HEAP32[$138>>2]|0;
                 $339 = ((($338)) + 224|0);
                 $340 = HEAP32[$339>>2]|0;
                 $341 = ($340|0)==($323|0);
                 if ($341) {
                  break;
                 }
                 HEAP32[$339>>2] = $323;
                 $342 = ($323|0)==(0|0);
                 if (!($342)) {
                  $343 = ((($323)) + 8|0);
                  $344 = HEAP32[$343>>2]|0;HEAP32[$343>>2] = (($344+1)|0);
                 }
                 $345 = ($340|0)==(0|0);
                 if ($345) {
                  break;
                 }
                 $346 = ((($340)) + 8|0);
                 $347 = HEAP32[$346>>2]|0;HEAP32[$346>>2] = (($347-1)|0);
                 $348 = ($347|0)==(1);
                 if (!($348)) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_viii(3262,($340|0),1,1);
                 $349 = __THREW__; __THREW__ = 0;
                 $350 = $349&1;
                 if ($350) {
                  label = 89;
                  break L122;
                 }
                } else {
                 label = 129;
                }
               } while(0);
               if ((label|0) == 129) {
                $351 = HEAP32[$26>>2]|0;
                $352 = ((($351)) + 288|0);
                HEAP8[$352>>0] = 0;
                $353 = HEAP32[$138>>2]|0;
                $354 = ((($353)) + 288|0);
                HEAP8[$354>>0] = 0;
               }
               $355 = HEAP32[$26>>2]|0;
               $356 = HEAP32[$19>>2]|0;
               $357 = ($356|0)==(0|0);
               do {
                if ($357) {
                 $362 = 0;
                } else {
                 $358 = ((($356)) + 24|0);
                 $359 = HEAP32[$358>>2]|0;
                 $360 = ($359|0)==(0|0);
                 if ($360) {
                  $362 = 0;
                  break;
                 }
                 $361 = HEAP32[$183>>2]|0;
                 $362 = $361;
                }
               } while(0);
               __THREW__ = 0;
               invoke_viii(3510,($355|0),($362|0),0);
               $363 = __THREW__; __THREW__ = 0;
               $364 = $363&1;
               if ($364) {
                label = 89;
                break;
               }
               $365 = HEAP32[$138>>2]|0;
               $366 = HEAP32[$19>>2]|0;
               $367 = ($366|0)==(0|0);
               do {
                if ($367) {
                 $372 = 0;
                } else {
                 $368 = ((($366)) + 24|0);
                 $369 = HEAP32[$368>>2]|0;
                 $370 = ($369|0)==(0|0);
                 if ($370) {
                  $372 = 0;
                  break;
                 }
                 $371 = HEAP32[$183>>2]|0;
                 $372 = $371;
                }
               } while(0);
               __THREW__ = 0;
               invoke_viii(3510,($365|0),($372|0),0);
               $373 = __THREW__; __THREW__ = 0;
               $374 = $373&1;
               if ($374) {
                label = 89;
                break;
               }
               __THREW__ = 0;
               $375 = (invoke_ii(3276,12)|0);
               $376 = __THREW__; __THREW__ = 0;
               $377 = $376&1;
               if ($377) {
                label = 89;
                break;
               }
               __THREW__ = 0;
               invoke_vi(3282,($375|0));
               $378 = __THREW__; __THREW__ = 0;
               $379 = $378&1;
               if ($379) {
                $693 = ___cxa_find_matching_catch_2()|0;
                $694 = tempRet0;
                __ZdlPv($375);
                $$9 = $693;$$963 = $694;
                break L27;
               }
               HEAP32[$375>>2] = (41960);
               $380 = ((($375)) + 8|0);
               $381 = HEAP32[$380>>2]|0;HEAP32[$380>>2] = (($381+1)|0);
               __THREW__ = 0;
               $382 = (invoke_ii(3276,12)|0);
               $383 = __THREW__; __THREW__ = 0;
               $384 = $383&1;
               L181: do {
                if ($384) {
                 $695 = ___cxa_find_matching_catch_2()|0;
                 $696 = tempRet0;
                 $$2 = $695;$$256 = $696;
                } else {
                 __THREW__ = 0;
                 invoke_vi(3282,($382|0));
                 $385 = __THREW__; __THREW__ = 0;
                 $386 = $385&1;
                 if ($386) {
                  $697 = ___cxa_find_matching_catch_2()|0;
                  $698 = tempRet0;
                  __ZdlPv($382);
                  $$2 = $697;$$256 = $698;
                  break;
                 }
                 HEAP32[$382>>2] = (41960);
                 $387 = ((($382)) + 8|0);
                 $388 = HEAP32[$387>>2]|0;HEAP32[$387>>2] = (($388+1)|0);
                 $389 = HEAP32[$26>>2]|0;
                 $390 = ((($389)) + 148|0);
                 $391 = HEAP32[$390>>2]|0;
                 $392 = ((($391)) + 504|0);
                 $393 = HEAP32[$392>>2]|0;
                 $394 = ($393|0)==($375|0);
                 do {
                  if ($394) {
                   label = 146;
                  } else {
                   HEAP32[$392>>2] = $375;
                   $395 = HEAP32[$380>>2]|0;HEAP32[$380>>2] = (($395+1)|0);
                   $396 = ($393|0)==(0|0);
                   if ($396) {
                    label = 146;
                    break;
                   }
                   $397 = ((($393)) + 8|0);
                   $398 = HEAP32[$397>>2]|0;HEAP32[$397>>2] = (($398-1)|0);
                   $399 = ($398|0)==(1);
                   if (!($399)) {
                    label = 146;
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(3262,($393|0),1,1);
                   $400 = __THREW__; __THREW__ = 0;
                   $401 = $400&1;
                   if (!($401)) {
                    label = 146;
                   }
                  }
                 } while(0);
                 L191: do {
                  if ((label|0) == 146) {
                   $402 = HEAP32[$26>>2]|0;
                   $403 = ((($402)) + 148|0);
                   $404 = HEAP32[$403>>2]|0;
                   $405 = HEAP32[$404>>2]|0;
                   $406 = ((($405)) + 200|0);
                   $407 = HEAP32[$406>>2]|0;
                   __THREW__ = 0;
                   $408 = (invoke_ii($407|0,($404|0))|0);
                   $409 = __THREW__; __THREW__ = 0;
                   $410 = $409&1;
                   if ($410) {
                    break;
                   }
                   $411 = ((($402)) + 164|0);
                   $412 = HEAP32[$411>>2]|0;
                   $413 = ($412|0)==($408|0);
                   do {
                    if (!($413)) {
                     HEAP32[$411>>2] = $408;
                     $414 = ($408|0)==(0|0);
                     if (!($414)) {
                      $415 = HEAP32[$408>>2]|0;
                      $416 = ((($415)) + -12|0);
                      $417 = HEAP32[$416>>2]|0;
                      $418 = (($408) + ($417)|0);
                      $419 = ((($418)) + 8|0);
                      $420 = HEAP32[$419>>2]|0;HEAP32[$419>>2] = (($420+1)|0);
                     }
                     $421 = ($412|0)==(0|0);
                     if ($421) {
                      break;
                     }
                     $422 = HEAP32[$412>>2]|0;
                     $423 = ((($422)) + -12|0);
                     $424 = HEAP32[$423>>2]|0;
                     $425 = (($412) + ($424)|0);
                     $426 = ((($425)) + 8|0);
                     $427 = HEAP32[$426>>2]|0;HEAP32[$426>>2] = (($427-1)|0);
                     $428 = ($427|0)==(1);
                     if (!($428)) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_viii(3262,($425|0),1,1);
                     $429 = __THREW__; __THREW__ = 0;
                     $430 = $429&1;
                     if ($430) {
                      break L191;
                     }
                    }
                   } while(0);
                   $431 = HEAP32[$26>>2]|0;
                   $432 = ((($431)) + 164|0);
                   $433 = HEAP32[$432>>2]|0;
                   $434 = ((($433)) + 504|0);
                   $435 = HEAP32[$434>>2]|0;
                   $436 = ($435|0)==($375|0);
                   do {
                    if (!($436)) {
                     HEAP32[$434>>2] = $375;
                     $437 = HEAP32[$380>>2]|0;HEAP32[$380>>2] = (($437+1)|0);
                     $438 = ($435|0)==(0|0);
                     if ($438) {
                      break;
                     }
                     $439 = ((($435)) + 8|0);
                     $440 = HEAP32[$439>>2]|0;HEAP32[$439>>2] = (($440-1)|0);
                     $441 = ($440|0)==(1);
                     if (!($441)) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_viii(3262,($435|0),1,1);
                     $442 = __THREW__; __THREW__ = 0;
                     $443 = $442&1;
                     if ($443) {
                      break L191;
                     }
                    }
                   } while(0);
                   $444 = HEAP32[$26>>2]|0;
                   $445 = ((($444)) + 148|0);
                   $446 = HEAP32[$445>>2]|0;
                   $447 = HEAP32[$446>>2]|0;
                   $448 = ((($447)) + 200|0);
                   $449 = HEAP32[$448>>2]|0;
                   __THREW__ = 0;
                   $450 = (invoke_ii($449|0,($446|0))|0);
                   $451 = __THREW__; __THREW__ = 0;
                   $452 = $451&1;
                   if ($452) {
                    break;
                   }
                   $453 = ((($444)) + 180|0);
                   $454 = HEAP32[$453>>2]|0;
                   $455 = ($454|0)==($450|0);
                   do {
                    if (!($455)) {
                     HEAP32[$453>>2] = $450;
                     $456 = ($450|0)==(0|0);
                     if (!($456)) {
                      $457 = HEAP32[$450>>2]|0;
                      $458 = ((($457)) + -12|0);
                      $459 = HEAP32[$458>>2]|0;
                      $460 = (($450) + ($459)|0);
                      $461 = ((($460)) + 8|0);
                      $462 = HEAP32[$461>>2]|0;HEAP32[$461>>2] = (($462+1)|0);
                     }
                     $463 = ($454|0)==(0|0);
                     if ($463) {
                      break;
                     }
                     $464 = HEAP32[$454>>2]|0;
                     $465 = ((($464)) + -12|0);
                     $466 = HEAP32[$465>>2]|0;
                     $467 = (($454) + ($466)|0);
                     $468 = ((($467)) + 8|0);
                     $469 = HEAP32[$468>>2]|0;HEAP32[$468>>2] = (($469-1)|0);
                     $470 = ($469|0)==(1);
                     if (!($470)) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_viii(3262,($467|0),1,1);
                     $471 = __THREW__; __THREW__ = 0;
                     $472 = $471&1;
                     if ($472) {
                      break L191;
                     }
                    }
                   } while(0);
                   $473 = HEAP32[$26>>2]|0;
                   $474 = ((($473)) + 180|0);
                   $475 = HEAP32[$474>>2]|0;
                   $476 = ((($475)) + 504|0);
                   $477 = HEAP32[$476>>2]|0;
                   $478 = ($477|0)==($382|0);
                   do {
                    if (!($478)) {
                     HEAP32[$476>>2] = $382;
                     $479 = HEAP32[$387>>2]|0;HEAP32[$387>>2] = (($479+1)|0);
                     $480 = ($477|0)==(0|0);
                     if ($480) {
                      break;
                     }
                     $481 = ((($477)) + 8|0);
                     $482 = HEAP32[$481>>2]|0;HEAP32[$481>>2] = (($482-1)|0);
                     $483 = ($482|0)==(1);
                     if (!($483)) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_viii(3262,($477|0),1,1);
                     $484 = __THREW__; __THREW__ = 0;
                     $485 = $484&1;
                     if ($485) {
                      break L191;
                     }
                    }
                   } while(0);
                   $486 = HEAP32[$138>>2]|0;
                   $487 = ((($486)) + 148|0);
                   $488 = HEAP32[$487>>2]|0;
                   $489 = ((($488)) + 504|0);
                   $490 = HEAP32[$489>>2]|0;
                   $491 = ($490|0)==($375|0);
                   do {
                    if (!($491)) {
                     HEAP32[$489>>2] = $375;
                     $492 = HEAP32[$380>>2]|0;HEAP32[$380>>2] = (($492+1)|0);
                     $493 = ($490|0)==(0|0);
                     if ($493) {
                      break;
                     }
                     $494 = ((($490)) + 8|0);
                     $495 = HEAP32[$494>>2]|0;HEAP32[$494>>2] = (($495-1)|0);
                     $496 = ($495|0)==(1);
                     if (!($496)) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_viii(3262,($490|0),1,1);
                     $497 = __THREW__; __THREW__ = 0;
                     $498 = $497&1;
                     if ($498) {
                      break L191;
                     }
                    }
                   } while(0);
                   $499 = HEAP32[$138>>2]|0;
                   $500 = ((($499)) + 148|0);
                   $501 = HEAP32[$500>>2]|0;
                   $502 = HEAP32[$501>>2]|0;
                   $503 = ((($502)) + 200|0);
                   $504 = HEAP32[$503>>2]|0;
                   __THREW__ = 0;
                   $505 = (invoke_ii($504|0,($501|0))|0);
                   $506 = __THREW__; __THREW__ = 0;
                   $507 = $506&1;
                   if ($507) {
                    break;
                   }
                   $508 = ((($499)) + 164|0);
                   $509 = HEAP32[$508>>2]|0;
                   $510 = ($509|0)==($505|0);
                   do {
                    if (!($510)) {
                     HEAP32[$508>>2] = $505;
                     $511 = ($505|0)==(0|0);
                     if (!($511)) {
                      $512 = HEAP32[$505>>2]|0;
                      $513 = ((($512)) + -12|0);
                      $514 = HEAP32[$513>>2]|0;
                      $515 = (($505) + ($514)|0);
                      $516 = ((($515)) + 8|0);
                      $517 = HEAP32[$516>>2]|0;HEAP32[$516>>2] = (($517+1)|0);
                     }
                     $518 = ($509|0)==(0|0);
                     if ($518) {
                      break;
                     }
                     $519 = HEAP32[$509>>2]|0;
                     $520 = ((($519)) + -12|0);
                     $521 = HEAP32[$520>>2]|0;
                     $522 = (($509) + ($521)|0);
                     $523 = ((($522)) + 8|0);
                     $524 = HEAP32[$523>>2]|0;HEAP32[$523>>2] = (($524-1)|0);
                     $525 = ($524|0)==(1);
                     if (!($525)) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_viii(3262,($522|0),1,1);
                     $526 = __THREW__; __THREW__ = 0;
                     $527 = $526&1;
                     if ($527) {
                      break L191;
                     }
                    }
                   } while(0);
                   $528 = HEAP32[$138>>2]|0;
                   $529 = ((($528)) + 164|0);
                   $530 = HEAP32[$529>>2]|0;
                   $531 = ((($530)) + 504|0);
                   $532 = HEAP32[$531>>2]|0;
                   $533 = ($532|0)==($375|0);
                   do {
                    if (!($533)) {
                     HEAP32[$531>>2] = $375;
                     $534 = HEAP32[$380>>2]|0;HEAP32[$380>>2] = (($534+1)|0);
                     $535 = ($532|0)==(0|0);
                     if ($535) {
                      break;
                     }
                     $536 = ((($532)) + 8|0);
                     $537 = HEAP32[$536>>2]|0;HEAP32[$536>>2] = (($537-1)|0);
                     $538 = ($537|0)==(1);
                     if (!($538)) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_viii(3262,($532|0),1,1);
                     $539 = __THREW__; __THREW__ = 0;
                     $540 = $539&1;
                     if ($540) {
                      break L191;
                     }
                    }
                   } while(0);
                   $541 = HEAP32[$138>>2]|0;
                   $542 = ((($541)) + 148|0);
                   $543 = HEAP32[$542>>2]|0;
                   $544 = HEAP32[$543>>2]|0;
                   $545 = ((($544)) + 200|0);
                   $546 = HEAP32[$545>>2]|0;
                   __THREW__ = 0;
                   $547 = (invoke_ii($546|0,($543|0))|0);
                   $548 = __THREW__; __THREW__ = 0;
                   $549 = $548&1;
                   if ($549) {
                    break;
                   }
                   $550 = ((($541)) + 180|0);
                   $551 = HEAP32[$550>>2]|0;
                   $552 = ($551|0)==($547|0);
                   do {
                    if (!($552)) {
                     HEAP32[$550>>2] = $547;
                     $553 = ($547|0)==(0|0);
                     if (!($553)) {
                      $554 = HEAP32[$547>>2]|0;
                      $555 = ((($554)) + -12|0);
                      $556 = HEAP32[$555>>2]|0;
                      $557 = (($547) + ($556)|0);
                      $558 = ((($557)) + 8|0);
                      $559 = HEAP32[$558>>2]|0;HEAP32[$558>>2] = (($559+1)|0);
                     }
                     $560 = ($551|0)==(0|0);
                     if ($560) {
                      break;
                     }
                     $561 = HEAP32[$551>>2]|0;
                     $562 = ((($561)) + -12|0);
                     $563 = HEAP32[$562>>2]|0;
                     $564 = (($551) + ($563)|0);
                     $565 = ((($564)) + 8|0);
                     $566 = HEAP32[$565>>2]|0;HEAP32[$565>>2] = (($566-1)|0);
                     $567 = ($566|0)==(1);
                     if (!($567)) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_viii(3262,($564|0),1,1);
                     $568 = __THREW__; __THREW__ = 0;
                     $569 = $568&1;
                     if ($569) {
                      break L191;
                     }
                    }
                   } while(0);
                   $570 = HEAP32[$138>>2]|0;
                   $571 = ((($570)) + 180|0);
                   $572 = HEAP32[$571>>2]|0;
                   $573 = ((($572)) + 504|0);
                   $574 = HEAP32[$573>>2]|0;
                   $575 = ($574|0)==($382|0);
                   do {
                    if (!($575)) {
                     HEAP32[$573>>2] = $382;
                     $576 = HEAP32[$387>>2]|0;HEAP32[$387>>2] = (($576+1)|0);
                     $577 = ($574|0)==(0|0);
                     if ($577) {
                      break;
                     }
                     $578 = ((($574)) + 8|0);
                     $579 = HEAP32[$578>>2]|0;HEAP32[$578>>2] = (($579-1)|0);
                     $580 = ($579|0)==(1);
                     if (!($580)) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_viii(3262,($574|0),1,1);
                     $581 = __THREW__; __THREW__ = 0;
                     $582 = $581&1;
                     if ($582) {
                      break L191;
                     }
                    }
                   } while(0);
                   $583 = HEAP32[$387>>2]|0;HEAP32[$387>>2] = (($583-1)|0);
                   $584 = ($583|0)==(1);
                   do {
                    if ($584) {
                     __THREW__ = 0;
                     invoke_viii(3262,($382|0),1,1);
                     $585 = __THREW__; __THREW__ = 0;
                     $586 = $585&1;
                     if (!($586)) {
                      break;
                     }
                     $705 = ___cxa_find_matching_catch_2()|0;
                     $706 = tempRet0;
                     $$2 = $705;$$256 = $706;
                     break L181;
                    }
                   } while(0);
                   $587 = HEAP32[$380>>2]|0;HEAP32[$380>>2] = (($587-1)|0);
                   $588 = ($587|0)==(1);
                   do {
                    if ($588) {
                     __THREW__ = 0;
                     invoke_viii(3262,($375|0),1,1);
                     $589 = __THREW__; __THREW__ = 0;
                     $590 = $589&1;
                     if (!($590)) {
                      break;
                     }
                     $707 = ___cxa_find_matching_catch_2()|0;
                     $708 = tempRet0;
                     $$9 = $707;$$963 = $708;
                     break L27;
                    }
                   } while(0);
                   $591 = HEAP32[$26>>2]|0;
                   $592 = HEAP32[$27>>2]|0;
                   $593 = ((($592)) + 8|0);
                   $594 = HEAP32[$593>>2]|0;
                   __THREW__ = 0;
                   (invoke_ii($594|0,($27|0))|0);
                   $595 = __THREW__; __THREW__ = 0;
                   $596 = $595&1;
                   if ($596) {
                    label = 89;
                    break L122;
                   }
                   __THREW__ = 0;
                   $597 = (invoke_ii(3276,12)|0);
                   $598 = __THREW__; __THREW__ = 0;
                   $599 = $598&1;
                   do {
                    if (!($599)) {
                     $600 = ((($597)) + 8|0);
                     HEAP32[$600>>2] = $591;
                     $601 = ((($597)) + 4|0);
                     HEAP32[$601>>2] = $39;
                     $602 = HEAP32[$39>>2]|0;
                     HEAP32[$597>>2] = $602;
                     $603 = ((($602)) + 4|0);
                     HEAP32[$603>>2] = $597;
                     HEAP32[$39>>2] = $597;
                     $604 = HEAP32[$41>>2]|0;
                     $605 = (($604) + 1)|0;
                     HEAP32[$41>>2] = $605;
                     HEAP8[$42>>0] = 1;
                     __THREW__ = 0;
                     (invoke_ii(2504,($30|0))|0);
                     $606 = __THREW__; __THREW__ = 0;
                     $607 = $606&1;
                     if ($607) {
                      break;
                     }
                     $608 = HEAP32[$27>>2]|0;
                     $609 = ((($608)) + 12|0);
                     $610 = HEAP32[$609>>2]|0;
                     __THREW__ = 0;
                     (invoke_ii($610|0,($27|0))|0);
                     $611 = __THREW__; __THREW__ = 0;
                     $612 = $611&1;
                     if ($612) {
                      label = 89;
                      break L122;
                     }
                     $622 = HEAP32[$138>>2]|0;
                     $623 = HEAP32[$27>>2]|0;
                     $624 = ((($623)) + 8|0);
                     $625 = HEAP32[$624>>2]|0;
                     __THREW__ = 0;
                     (invoke_ii($625|0,($27|0))|0);
                     $626 = __THREW__; __THREW__ = 0;
                     $627 = $626&1;
                     if ($627) {
                      label = 89;
                      break L122;
                     }
                     __THREW__ = 0;
                     $628 = (invoke_ii(3276,12)|0);
                     $629 = __THREW__; __THREW__ = 0;
                     $630 = $629&1;
                     do {
                      if (!($630)) {
                       $631 = ((($628)) + 8|0);
                       HEAP32[$631>>2] = $622;
                       $632 = ((($628)) + 4|0);
                       HEAP32[$632>>2] = $39;
                       $633 = HEAP32[$39>>2]|0;
                       HEAP32[$628>>2] = $633;
                       $634 = ((($633)) + 4|0);
                       HEAP32[$634>>2] = $628;
                       HEAP32[$39>>2] = $628;
                       $635 = HEAP32[$41>>2]|0;
                       $636 = (($635) + 1)|0;
                       HEAP32[$41>>2] = $636;
                       HEAP8[$42>>0] = 1;
                       __THREW__ = 0;
                       (invoke_ii(2504,($30|0))|0);
                       $637 = __THREW__; __THREW__ = 0;
                       $638 = $637&1;
                       if ($638) {
                        break;
                       }
                       $639 = HEAP32[$27>>2]|0;
                       $640 = ((($639)) + 12|0);
                       $641 = HEAP32[$640>>2]|0;
                       __THREW__ = 0;
                       (invoke_ii($641|0,($27|0))|0);
                       $642 = __THREW__; __THREW__ = 0;
                       $643 = $642&1;
                       if ($643) {
                        label = 89;
                        break L122;
                       }
                       __THREW__ = 0;
                       $653 = (invoke_ii(3265,5)|0);
                       $654 = __THREW__; __THREW__ = 0;
                       $655 = $654&1;
                       if ($655) {
                        label = 89;
                        break L122;
                       }
                       if (!($653)) {
                        STACKTOP = sp;return;
                       }
                       __THREW__ = 0;
                       $656 = (invoke_ii(3266,5)|0);
                       $657 = __THREW__; __THREW__ = 0;
                       $658 = $657&1;
                       if ($658) {
                        label = 89;
                        break L122;
                       }
                       __THREW__ = 0;
                       $659 = (invoke_iiii(3267,($656|0),(109435|0),23)|0);
                       $660 = __THREW__; __THREW__ = 0;
                       $661 = $660&1;
                       if ($661) {
                        label = 89;
                        break L122;
                       }
                       $662 = HEAP32[$41>>2]|0;
                       __THREW__ = 0;
                       $663 = (invoke_iii(3417,($659|0),($662|0))|0);
                       $664 = __THREW__; __THREW__ = 0;
                       $665 = $664&1;
                       if ($665) {
                        label = 89;
                        break L122;
                       }
                       $666 = HEAP32[$663>>2]|0;
                       $667 = ((($666)) + -12|0);
                       $668 = HEAP32[$667>>2]|0;
                       $669 = (($663) + ($668)|0);
                       __THREW__ = 0;
                       invoke_vii(3257,($2|0),($669|0));
                       $670 = __THREW__; __THREW__ = 0;
                       $671 = $670&1;
                       if ($671) {
                        label = 89;
                        break L122;
                       }
                       __THREW__ = 0;
                       $672 = (invoke_iii(3255,($2|0),(215188|0))|0);
                       $673 = __THREW__; __THREW__ = 0;
                       $674 = $673&1;
                       do {
                        if (!($674)) {
                         $675 = HEAP32[$672>>2]|0;
                         $676 = ((($675)) + 28|0);
                         $677 = HEAP32[$676>>2]|0;
                         __THREW__ = 0;
                         $678 = (invoke_iii($677|0,($672|0),10)|0);
                         $679 = __THREW__; __THREW__ = 0;
                         $680 = $679&1;
                         if ($680) {
                          break;
                         }
                         __THREW__ = 0;
                         invoke_vi(3263,($2|0));
                         $687 = __THREW__; __THREW__ = 0;
                         $688 = $687&1;
                         if ($688) {
                          label = 89;
                          break L122;
                         }
                         __THREW__ = 0;
                         (invoke_iii(3268,($663|0),($678|0))|0);
                         $689 = __THREW__; __THREW__ = 0;
                         $690 = $689&1;
                         if ($690) {
                          label = 89;
                          break L122;
                         }
                         __THREW__ = 0;
                         (invoke_ii(3269,($663|0))|0);
                         $691 = __THREW__; __THREW__ = 0;
                         $692 = $691&1;
                         if ($692) {
                          label = 89;
                          break L122;
                         }
                         STACKTOP = sp;return;
                        }
                       } while(0);
                       $681 = ___cxa_find_matching_catch_2()|0;
                       $682 = tempRet0;
                       __THREW__ = 0;
                       invoke_vi(3263,($2|0));
                       $683 = __THREW__; __THREW__ = 0;
                       $684 = $683&1;
                       if ($684) {
                        $685 = ___cxa_find_matching_catch_3(0|0)|0;
                        $686 = tempRet0;
                        ___clang_call_terminate($685);
                        // unreachable;
                       } else {
                        $eh$lpad$body117$index19Z2D = $682;$eh$lpad$body117$indexZ2D = $681;
                        break L122;
                       }
                      }
                     } while(0);
                     $644 = ___cxa_find_matching_catch_2()|0;
                     $645 = tempRet0;
                     $646 = HEAP32[$27>>2]|0;
                     $647 = ((($646)) + 12|0);
                     $648 = HEAP32[$647>>2]|0;
                     __THREW__ = 0;
                     (invoke_ii($648|0,($27|0))|0);
                     $649 = __THREW__; __THREW__ = 0;
                     $650 = $649&1;
                     if (!($650)) {
                      $eh$lpad$body117$index19Z2D = $645;$eh$lpad$body117$indexZ2D = $644;
                      break L122;
                     }
                     $651 = ___cxa_find_matching_catch_3(0|0)|0;
                     $652 = tempRet0;
                     ___clang_call_terminate($651);
                     // unreachable;
                    }
                   } while(0);
                   $613 = ___cxa_find_matching_catch_2()|0;
                   $614 = tempRet0;
                   $615 = HEAP32[$27>>2]|0;
                   $616 = ((($615)) + 12|0);
                   $617 = HEAP32[$616>>2]|0;
                   __THREW__ = 0;
                   (invoke_ii($617|0,($27|0))|0);
                   $618 = __THREW__; __THREW__ = 0;
                   $619 = $618&1;
                   if (!($619)) {
                    $eh$lpad$body117$index19Z2D = $614;$eh$lpad$body117$indexZ2D = $613;
                    break L122;
                   }
                   $620 = ___cxa_find_matching_catch_3(0|0)|0;
                   $621 = tempRet0;
                   ___clang_call_terminate($620);
                   // unreachable;
                  }
                 } while(0);
                 $699 = ___cxa_find_matching_catch_2()|0;
                 $700 = tempRet0;
                 $701 = HEAP32[$387>>2]|0;HEAP32[$387>>2] = (($701-1)|0);
                 $702 = ($701|0)==(1);
                 if (!($702)) {
                  $$2 = $699;$$256 = $700;
                  break;
                 }
                 __THREW__ = 0;
                 invoke_viii(3262,($382|0),1,1);
                 $703 = __THREW__; __THREW__ = 0;
                 $704 = $703&1;
                 if ($704) {
                  break L1;
                 } else {
                  $$2 = $699;$$256 = $700;
                 }
                }
               } while(0);
               $709 = HEAP32[$380>>2]|0;HEAP32[$380>>2] = (($709-1)|0);
               $710 = ($709|0)==(1);
               if (!($710)) {
                $$9 = $$2;$$963 = $$256;
                break L27;
               }
               __THREW__ = 0;
               invoke_viii(3262,($375|0),1,1);
               $711 = __THREW__; __THREW__ = 0;
               $712 = $711&1;
               if ($712) {
                break L1;
               } else {
                $$9 = $$2;$$963 = $$256;
                break L27;
               }
              }
             } while(0);
             if ((label|0) == 89) {
              $253 = ___cxa_find_matching_catch_2()|0;
              $254 = tempRet0;
              $eh$lpad$body117$index19Z2D = $254;$eh$lpad$body117$indexZ2D = $253;
             }
             $$9 = $eh$lpad$body117$indexZ2D;$$963 = $eh$lpad$body117$index19Z2D;
            }
           }
          }
         } while(0);
         if ((label|0) == 35) {
          $116 = ___cxa_find_matching_catch_2()|0;
          $117 = tempRet0;
          $eh$lpad$body81$index12Z2D = $117;$eh$lpad$body81$indexZ2D = $116;
          label = 36;
         }
         if ((label|0) == 36) {
          $$9 = $eh$lpad$body81$indexZ2D;$$963 = $eh$lpad$body81$index12Z2D;
         }
         $713 = HEAP32[$60>>2]|0;
         $714 = ($713|0)==(0|0);
         if (!($714)) {
          $715 = ((($713)) + 8|0);
          $716 = HEAP32[$715>>2]|0;HEAP32[$715>>2] = (($716-1)|0);
          $717 = ($716|0)==(1);
          if ($717) {
           __THREW__ = 0;
           invoke_viii(3262,($713|0),1,1);
           $718 = __THREW__; __THREW__ = 0;
           $719 = $718&1;
           if ($719) {
            break L1;
           }
          }
         }
         HEAP32[$60>>2] = 0;
         $720 = ((($0)) + 96|0);
         $721 = HEAP32[$57>>2]|0;
         $722 = ($721|0)==(0);
         if (!($722)) {
          $723 = HEAP32[$56>>2]|0;
          $724 = HEAP32[$720>>2]|0;
          $725 = ((($724)) + 4|0);
          $726 = HEAP32[$725>>2]|0;
          $727 = HEAP32[$723>>2]|0;
          $728 = ((($727)) + 4|0);
          HEAP32[$728>>2] = $726;
          $729 = HEAP32[$725>>2]|0;
          HEAP32[$729>>2] = $727;
          HEAP32[$57>>2] = 0;
          $730 = ($723|0)==($720|0);
          if (!($730)) {
           $$023$i$i$i97 = $723;
           while(1) {
            $731 = ((($$023$i$i$i97)) + 4|0);
            $732 = HEAP32[$731>>2]|0;
            __ZdlPv($$023$i$i$i97);
            $733 = ($732|0)==($720|0);
            if ($733) {
             break;
            } else {
             $$023$i$i$i97 = $732;
            }
           }
          }
         }
         __THREW__ = 0;
         invoke_vi(2499,($46|0));
         $734 = __THREW__; __THREW__ = 0;
         $735 = $734&1;
         if (!($735)) {
          __THREW__ = 0;
          invoke_vi(707,($43|0));
          $736 = __THREW__; __THREW__ = 0;
          $737 = $736&1;
          if ($737) {
           break L1;
          } else {
           $$10 = $$9;$$1064 = $$963;
           break;
          }
         }
         $738 = ___cxa_find_matching_catch_3(0|0)|0;
         $739 = tempRet0;
         __THREW__ = 0;
         invoke_vi(707,($43|0));
         $740 = __THREW__; __THREW__ = 0;
         $741 = $740&1;
         if ($741) {
          $742 = ___cxa_find_matching_catch_3(0|0)|0;
          $743 = tempRet0;
          ___clang_call_terminate($742);
          // unreachable;
         } else {
          $eh$lpad$body96$indexZ2D = $738;
          ___clang_call_terminate($eh$lpad$body96$indexZ2D);
          // unreachable;
         }
        }
       } while(0);
       if ((label|0) == 34) {
        $$10 = $eh$lpad$body75$indexZ2D;$$1064 = $eh$lpad$body75$index7Z2D;
       }
       $744 = ((($0)) + 60|0);
       $745 = HEAP32[$41>>2]|0;
       $746 = ($745|0)==(0);
       if (!($746)) {
        $747 = HEAP32[$40>>2]|0;
        $748 = HEAP32[$744>>2]|0;
        $749 = ((($748)) + 4|0);
        $750 = HEAP32[$749>>2]|0;
        $751 = HEAP32[$747>>2]|0;
        $752 = ((($751)) + 4|0);
        HEAP32[$752>>2] = $750;
        $753 = HEAP32[$749>>2]|0;
        HEAP32[$753>>2] = $751;
        HEAP32[$41>>2] = 0;
        $754 = ($747|0)==($744|0);
        if (!($754)) {
         $$023$i$i$i = $747;
         while(1) {
          $755 = ((($$023$i$i$i)) + 4|0);
          $756 = HEAP32[$755>>2]|0;
          __ZdlPv($$023$i$i$i);
          $757 = ($756|0)==($744|0);
          if ($757) {
           break;
          } else {
           $$023$i$i$i = $756;
          }
         }
        }
       }
       __THREW__ = 0;
       invoke_vi(2499,($30|0));
       $758 = __THREW__; __THREW__ = 0;
       $759 = $758&1;
       if (!($759)) {
        __THREW__ = 0;
        invoke_vi(707,($27|0));
        $760 = __THREW__; __THREW__ = 0;
        $761 = $760&1;
        if ($761) {
         break L1;
        } else {
         $$11 = $$10;$$1165 = $$1064;
         break;
        }
       }
       $762 = ___cxa_find_matching_catch_3(0|0)|0;
       $763 = tempRet0;
       __THREW__ = 0;
       invoke_vi(707,($27|0));
       $764 = __THREW__; __THREW__ = 0;
       $765 = $764&1;
       if ($765) {
        $766 = ___cxa_find_matching_catch_3(0|0)|0;
        $767 = tempRet0;
        ___clang_call_terminate($766);
        // unreachable;
       } else {
        $eh$lpad$body96$indexZ2D = $762;
        ___clang_call_terminate($eh$lpad$body96$indexZ2D);
        // unreachable;
       }
      }
     } while(0);
     if ((label|0) == 32) {
      $$11 = $eh$lpad$body$indexZ2D;$$1165 = $eh$lpad$body$index2Z2D;
     }
     $768 = ((($0)) + 36|0);
     $769 = HEAP32[$768>>2]|0;
     $770 = ($769|0)==(0|0);
     if ($770) {
      label = 254;
     } else {
      $771 = ((($769)) + 8|0);
      $772 = HEAP32[$771>>2]|0;HEAP32[$771>>2] = (($772-1)|0);
      $773 = ($772|0)==(1);
      if ($773) {
       __THREW__ = 0;
       invoke_viii(3262,($769|0),1,1);
       $774 = __THREW__; __THREW__ = 0;
       $775 = $774&1;
       if (!($775)) {
        label = 254;
       }
      } else {
       label = 254;
      }
     }
     do {
      if ((label|0) == 254) {
       HEAP32[$768>>2] = 0;
       $776 = ((($0)) + 32|0);
       $777 = HEAP32[$776>>2]|0;
       $778 = ($777|0)==(0|0);
       if (!($778)) {
        $795 = ((($777)) + 8|0);
        $796 = HEAP32[$795>>2]|0;HEAP32[$795>>2] = (($796-1)|0);
        $797 = ($796|0)==(1);
        if ($797) {
         __THREW__ = 0;
         invoke_viii(3262,($777|0),1,1);
         $798 = __THREW__; __THREW__ = 0;
         $799 = $798&1;
         if ($799) {
          break;
         }
        }
       }
       HEAP32[$776>>2] = 0;
       $780 = HEAP32[$19>>2]|0;
       $800 = ($780|0)==(0|0);
       if (!($800)) {
        $779 = ((($780)) + 8|0);
        $781 = HEAP32[$779>>2]|0;HEAP32[$779>>2] = (($781-1)|0);
        $782 = ($781|0)==(1);
        if ($782) {
         __THREW__ = 0;
         invoke_viii(3262,($780|0),1,1);
         $783 = __THREW__; __THREW__ = 0;
         $784 = $783&1;
         if ($784) {
          break L1;
         }
        }
       }
       HEAP32[$19>>2] = 0;
       $$12 = $$11;$$1266 = $$1165;
       break L10;
      }
     } while(0);
     $791 = ___cxa_find_matching_catch_3(0|0)|0;
     $792 = tempRet0;
     $eh$lpad$body96$indexZ2D = $791;
     ___clang_call_terminate($eh$lpad$body96$indexZ2D);
     // unreachable;
    }
   } while(0);
   HEAP32[$0>>2] = ((8252));
   HEAP32[$5>>2] = ((8284));
   $785 = ((($12)) + 11|0);
   $786 = HEAP8[$785>>0]|0;
   $787 = ($786<<24>>24)<(0);
   if ($787) {
    $788 = HEAP32[$12>>2]|0;
    __ZdlPv($788);
    $$13 = $$12;$$1367 = $$1266;
    label = 260;
   } else {
    $$13 = $$12;$$1367 = $$1266;
    label = 260;
   }
  }
 } while(0);
 if ((label|0) == 260) {
  __THREW__ = 0;
  invoke_vi(712,($5|0));
  $789 = __THREW__; __THREW__ = 0;
  $790 = $789&1;
  if (!($790)) {
   ___resumeException($$13|0);
   // unreachable;
  }
 }
 $793 = ___cxa_find_matching_catch_3(0|0)|0;
 $794 = tempRet0;
 $eh$lpad$body96$indexZ2D = $793;
 ___clang_call_terminate($eh$lpad$body96$indexZ2D);
 // unreachable;
}
function __ZN9osgViewer8Renderer25setGraphicsThreadDoesCullEb($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 29|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = $3&255;
 $5 = $1&1;
 $6 = ($4|0)==($5|0);
 if ($6) {
  return;
 }
 $7 = $1&1;
 HEAP8[$2>>0] = $7;
 return;
}
function __ZN9osgViewer5SceneD2Ev($0) {
 $0 = $0|0;
 var $$0 = 0, $$02 = 0, $$1 = 0, $$13 = 0, $$2 = 0, $$24 = 0, $$pre$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (41980);
 $1 = HEAP8[205992]|0;
 $2 = ($1<<24>>24)==(0);
 do {
  if ($2) {
   $3 = (___cxa_guard_acquire(205992)|0);
   $4 = ($3|0)==(0);
   if ($4) {
    label = 15;
   } else {
    HEAP32[51960] = 0;
    HEAP32[(207844)>>2] = 0;
    HEAP32[(207848)>>2] = 0;
    __THREW__ = 0;
    invoke_vii(3507,((207852)|0),0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     (___cxa_atexit((3511|0),(207840|0),(___dso_handle|0))|0);
     label = 15;
     break;
    }
    $7 = ___cxa_find_matching_catch_2()|0;
    $8 = tempRet0;
    $9 = HEAP32[51960]|0;
    $10 = ($9|0)==(0|0);
    if (!($10)) {
     $11 = HEAP32[(207844)>>2]|0;
     $12 = ($11|0)==($9|0);
     do {
      if ($12) {
       $26 = $9;
      } else {
       $14 = $11;
       while(1) {
        $13 = ((($14)) + -8|0);
        HEAP32[(207844)>>2] = $13;
        $15 = HEAP32[$13>>2]|0;
        $16 = ($15|0)==(0|0);
        if (!($16)) {
         $17 = ((($15)) + 8|0);
         $18 = HEAP32[$17>>2]|0;HEAP32[$17>>2] = (($18-1)|0);
         $19 = ($18|0)==(1);
         if ($19) {
          __THREW__ = 0;
          invoke_viii(3262,($15|0),1,1);
          $20 = __THREW__; __THREW__ = 0;
          $21 = $20&1;
          if ($21) {
           label = 10;
           break;
          }
         }
        }
        HEAP32[$13>>2] = 0;
        $22 = HEAP32[(207844)>>2]|0;
        $23 = ($22|0)==($9|0);
        if ($23) {
         label = 11;
         break;
        } else {
         $14 = $22;
        }
       }
       if ((label|0) == 10) {
        $24 = ___cxa_find_matching_catch_2()|0;
        $25 = tempRet0;
        ___cxa_call_unexpected(($24|0));
        // unreachable;
       }
       else if ((label|0) == 11) {
        $$pre$i = HEAP32[51960]|0;
        $26 = $$pre$i;
        break;
       }
      }
     } while(0);
     __ZdlPv($26);
    }
    $eh$lpad$body$index2Z2D = $8;$eh$lpad$body$indexZ2D = $7;
    label = 27;
   }
  } else {
   label = 15;
  }
 } while(0);
 do {
  if ((label|0) == 15) {
   __THREW__ = 0;
   invoke_vii(3512,(207840|0),($0|0));
   $27 = __THREW__; __THREW__ = 0;
   $28 = $27&1;
   if ($28) {
    $53 = ___cxa_find_matching_catch_2()|0;
    $54 = tempRet0;
    $eh$lpad$body$index2Z2D = $54;$eh$lpad$body$indexZ2D = $53;
    label = 27;
    break;
   }
   $29 = ((($0)) + 20|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = ($30|0)==(0|0);
   if (!($31)) {
    $32 = ((($30)) + 8|0);
    $33 = HEAP32[$32>>2]|0;HEAP32[$32>>2] = (($33-1)|0);
    $34 = ($33|0)==(1);
    if ($34) {
     __THREW__ = 0;
     invoke_viii(3262,($30|0),1,1);
     $35 = __THREW__; __THREW__ = 0;
     $36 = $35&1;
     if ($36) {
      $63 = ___cxa_find_matching_catch_2()|0;
      $64 = tempRet0;
      $$0 = $64;$$02 = $63;
      label = 33;
      break;
     }
    }
   }
   HEAP32[$29>>2] = 0;
   $37 = ((($0)) + 16|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = ($38|0)==(0|0);
   if (!($39)) {
    $40 = ((($38)) + 8|0);
    $41 = HEAP32[$40>>2]|0;HEAP32[$40>>2] = (($41-1)|0);
    $42 = ($41|0)==(1);
    if ($42) {
     __THREW__ = 0;
     invoke_viii(3262,($38|0),1,1);
     $43 = __THREW__; __THREW__ = 0;
     $44 = $43&1;
     if ($44) {
      $65 = ___cxa_find_matching_catch_2()|0;
      $66 = tempRet0;
      $$1 = $66;$$13 = $65;
      label = 38;
      break;
     }
    }
   }
   HEAP32[$37>>2] = 0;
   $45 = ((($0)) + 12|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = ($46|0)==(0|0);
   if ($47) {
    HEAP32[$45>>2] = 0;
    __ZN3osg10ReferencedD2Ev($0);
    return;
   }
   $48 = ((($46)) + 8|0);
   $49 = HEAP32[$48>>2]|0;HEAP32[$48>>2] = (($49-1)|0);
   $50 = ($49|0)==(1);
   if (!($50)) {
    HEAP32[$45>>2] = 0;
    __ZN3osg10ReferencedD2Ev($0);
    return;
   }
   __THREW__ = 0;
   invoke_viii(3262,($46|0),1,1);
   $51 = __THREW__; __THREW__ = 0;
   $52 = $51&1;
   if ($52) {
    $75 = ___cxa_find_matching_catch_2()|0;
    $76 = tempRet0;
    $$2 = $76;$$24 = $75;
    break;
   } else {
    HEAP32[$45>>2] = 0;
    __ZN3osg10ReferencedD2Ev($0);
    return;
   }
  }
 } while(0);
 if ((label|0) == 27) {
  $55 = ((($0)) + 20|0);
  $56 = HEAP32[$55>>2]|0;
  $57 = ($56|0)==(0|0);
  if (!($57)) {
   $58 = ((($56)) + 8|0);
   $59 = HEAP32[$58>>2]|0;HEAP32[$58>>2] = (($59-1)|0);
   $60 = ($59|0)==(1);
   if ($60) {
    __THREW__ = 0;
    invoke_viii(3262,($56|0),1,1);
    $61 = __THREW__; __THREW__ = 0;
    $62 = $61&1;
    if ($62) {
     $87 = ___cxa_find_matching_catch_3(0|0)|0;
     $88 = tempRet0;
     ___clang_call_terminate($87);
     // unreachable;
    }
   }
  }
  HEAP32[$55>>2] = 0;
  $$0 = $eh$lpad$body$index2Z2D;$$02 = $eh$lpad$body$indexZ2D;
  label = 33;
 }
 if ((label|0) == 33) {
  $67 = ((($0)) + 16|0);
  $68 = HEAP32[$67>>2]|0;
  $69 = ($68|0)==(0|0);
  if (!($69)) {
   $70 = ((($68)) + 8|0);
   $71 = HEAP32[$70>>2]|0;HEAP32[$70>>2] = (($71-1)|0);
   $72 = ($71|0)==(1);
   if ($72) {
    __THREW__ = 0;
    invoke_viii(3262,($68|0),1,1);
    $73 = __THREW__; __THREW__ = 0;
    $74 = $73&1;
    if ($74) {
     $87 = ___cxa_find_matching_catch_3(0|0)|0;
     $88 = tempRet0;
     ___clang_call_terminate($87);
     // unreachable;
    }
   }
  }
  HEAP32[$67>>2] = 0;
  $$1 = $$0;$$13 = $$02;
  label = 38;
 }
 if ((label|0) == 38) {
  $77 = ((($0)) + 12|0);
  $78 = HEAP32[$77>>2]|0;
  $79 = ($78|0)==(0|0);
  if (!($79)) {
   $80 = ((($78)) + 8|0);
   $81 = HEAP32[$80>>2]|0;HEAP32[$80>>2] = (($81-1)|0);
   $82 = ($81|0)==(1);
   if ($82) {
    __THREW__ = 0;
    invoke_viii(3262,($78|0),1,1);
    $83 = __THREW__; __THREW__ = 0;
    $84 = $83&1;
    if ($84) {
     $87 = ___cxa_find_matching_catch_3(0|0)|0;
     $88 = tempRet0;
     ___clang_call_terminate($87);
     // unreachable;
    }
   }
  }
  HEAP32[$77>>2] = 0;
  $$2 = $$1;$$24 = $$13;
 }
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $85 = __THREW__; __THREW__ = 0;
 $86 = $85&1;
 if ($86) {
  $87 = ___cxa_find_matching_catch_3(0|0)|0;
  $88 = tempRet0;
  ___clang_call_terminate($87);
  // unreachable;
 } else {
  ___resumeException($$24|0);
  // unreachable;
 }
}
function __ZN9osgViewer5SceneD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(714,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK9osgViewer5Scene9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (109495|0);
}
function __ZNK9osgViewer5Scene24requiresUpdateSceneGraphEv($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (__ZNK5osgDB13DatabasePager24requiresUpdateSceneGraphEv($2)|0);
 if ($3) {
  $$0 = 1;
  return ($$0|0);
 }
 $4 = ((($0)) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($6)) + 24|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (FUNCTION_TABLE_ii[$8 & 8191]($5)|0);
 if ($9) {
  $$0 = 1;
  return ($$0|0);
 }
 $10 = ((($0)) + 12|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0|0);
 if (!($12)) {
  $13 = ((($11)) + 84|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = ($14|0)==(0|0);
  if (!($15)) {
   $$0 = 1;
   return ($$0|0);
  }
  $16 = ((($11)) + 88|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = ($17|0)==(0);
  if (!($18)) {
   $$0 = 1;
   return ($$0|0);
  }
 }
 $$0 = 0;
 return ($$0|0);
}
function __ZN9osgViewer5Scene16updateSceneGraphERN3osg11NodeVisitorE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  return;
 }
 $5 = ((($0)) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if (!($7)) {
  $8 = HEAP32[$6>>2]|0;
  $9 = ((($8)) + 56|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ((($1)) + 12|0);
  $12 = HEAP32[$11>>2]|0;
  FUNCTION_TABLE_vii[$10 & 8191]($6,$12);
 }
 $13 = ((($0)) + 20|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(0|0);
 if (!($15)) {
  $16 = HEAP32[$14>>2]|0;
  $17 = ((($16)) + 28|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = ((($1)) + 12|0);
  $20 = HEAP32[$19>>2]|0;
  FUNCTION_TABLE_vii[$18 & 8191]($14,$20);
 }
 $21 = HEAP32[$2>>2]|0;
 $22 = ($21|0)==(0|0);
 if ($22) {
  return;
 }
 $23 = HEAP32[$13>>2]|0;
 $24 = ((($1)) + 44|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)==($23|0);
 if (!($26)) {
  HEAP32[$24>>2] = $23;
  $27 = ($23|0)==(0|0);
  if (!($27)) {
   $28 = ((($23)) + 8|0);
   $29 = HEAP32[$28>>2]|0;HEAP32[$28>>2] = (($29+1)|0);
  }
  $30 = ($25|0)==(0|0);
  if (!($30)) {
   $31 = ((($25)) + 8|0);
   $32 = HEAP32[$31>>2]|0;HEAP32[$31>>2] = (($32-1)|0);
   $33 = ($32|0)==(1);
   if ($33) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($25,1,1);
   }
  }
 }
 $34 = HEAP32[$2>>2]|0;
 $35 = HEAP32[$34>>2]|0;
 $36 = ((($35)) + 188|0);
 $37 = HEAP32[$36>>2]|0;
 FUNCTION_TABLE_vii[$37 & 8191]($34,$1);
 return;
}
function __ZNK9osgViewer5Scene14requiresRedrawEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (__ZNK5osgDB13DatabasePager14requiresRedrawEv($2)|0);
 return ($3|0);
}
function __ZN9osgViewer14SceneSingletonD2Ev($0) {
 $0 = $0|0;
 var $$pre$i = 0, $$pre$i5 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 12|0);
 __THREW__ = 0;
 invoke_vi(707,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $23 = ___cxa_find_matching_catch_2()|0;
  $24 = tempRet0;
  $25 = HEAP32[$0>>2]|0;
  $26 = ($25|0)==(0|0);
  if ($26) {
   ___resumeException($23|0);
   // unreachable;
  }
  $27 = ((($0)) + 4|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = ($28|0)==($25|0);
  do {
   if ($29) {
    $43 = $25;
   } else {
    $31 = $28;
    while(1) {
     $30 = ((($31)) + -8|0);
     HEAP32[$27>>2] = $30;
     $32 = HEAP32[$30>>2]|0;
     $33 = ($32|0)==(0|0);
     if (!($33)) {
      $34 = ((($32)) + 8|0);
      $35 = HEAP32[$34>>2]|0;HEAP32[$34>>2] = (($35-1)|0);
      $36 = ($35|0)==(1);
      if ($36) {
       __THREW__ = 0;
       invoke_viii(3262,($32|0),1,1);
       $37 = __THREW__; __THREW__ = 0;
       $38 = $37&1;
       if ($38) {
        label = 18;
        break;
       }
      }
     }
     HEAP32[$30>>2] = 0;
     $39 = HEAP32[$27>>2]|0;
     $40 = ($39|0)==($25|0);
     if ($40) {
      label = 19;
      break;
     } else {
      $31 = $39;
     }
    }
    if ((label|0) == 18) {
     $41 = ___cxa_find_matching_catch_2()|0;
     $42 = tempRet0;
     ___cxa_call_unexpected(($41|0));
     // unreachable;
    }
    else if ((label|0) == 19) {
     $$pre$i5 = HEAP32[$0>>2]|0;
     $43 = $$pre$i5;
     break;
    }
   }
  } while(0);
  __ZdlPv($43);
  ___resumeException($23|0);
  // unreachable;
 } else {
  $4 = HEAP32[$0>>2]|0;
  $5 = ($4|0)==(0|0);
  if ($5) {
   return;
  }
  $6 = ((($0)) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)==($4|0);
  do {
   if ($8) {
    $22 = $4;
   } else {
    $10 = $7;
    while(1) {
     $9 = ((($10)) + -8|0);
     HEAP32[$6>>2] = $9;
     $11 = HEAP32[$9>>2]|0;
     $12 = ($11|0)==(0|0);
     if (!($12)) {
      $13 = ((($11)) + 8|0);
      $14 = HEAP32[$13>>2]|0;HEAP32[$13>>2] = (($14-1)|0);
      $15 = ($14|0)==(1);
      if ($15) {
       __THREW__ = 0;
       invoke_viii(3262,($11|0),1,1);
       $16 = __THREW__; __THREW__ = 0;
       $17 = $16&1;
       if ($17) {
        label = 8;
        break;
       }
      }
     }
     HEAP32[$9>>2] = 0;
     $18 = HEAP32[$6>>2]|0;
     $19 = ($18|0)==($4|0);
     if ($19) {
      label = 9;
      break;
     } else {
      $10 = $18;
     }
    }
    if ((label|0) == 8) {
     $20 = ___cxa_find_matching_catch_2()|0;
     $21 = tempRet0;
     ___cxa_call_unexpected(($20|0));
     // unreachable;
    }
    else if ((label|0) == 9) {
     $$pre$i = HEAP32[$0>>2]|0;
     $22 = $$pre$i;
     break;
    }
   }
  } while(0);
  __ZdlPv($22);
  return;
 }
}
function __ZN9osgViewer14SceneSingleton6removeEPNS_5SceneE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$lcssa$i$i10$i = 0, $$010$i$i$i = 0, $$078$i$i$i = 0, $$pre = 0, $$pre$i = 0, $$sink = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 (FUNCTION_TABLE_ii[$5 & 8191]($2)|0);
 $6 = HEAP32[$0>>2]|0;
 $7 = ((($0)) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $$sink = $6;
 while(1) {
  $9 = ($$sink|0)==($8|0);
  if ($9) {
   label = 24;
   break;
  }
  $10 = HEAP32[$$sink>>2]|0;
  $11 = ($10|0)==(0|0);
  if ($11) {
   $17 = 0;
  } else {
   $12 = ((($10)) + 24|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = ($13|0)==(0|0);
   if ($14) {
    $17 = 0;
   } else {
    $15 = ((($$sink)) + 4|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = $16;
   }
  }
  $18 = ($17|0)==($1|0);
  $19 = ((($$sink)) + 8|0);
  if ($18) {
   break;
  } else {
   $$sink = $19;
  }
 }
 if ((label|0) == 24) {
  $60 = HEAP32[$2>>2]|0;
  $61 = ((($60)) + 12|0);
  $62 = HEAP32[$61>>2]|0;
  (FUNCTION_TABLE_ii[$62 & 8191]($2)|0);
  return;
 }
 $20 = ($19|0)==($8|0);
 do {
  if ($20) {
   $$0$lcssa$i$i10$i = $$sink;$65 = $8;
  } else {
   $$010$i$i$i = $$sink;$$078$i$i$i = $19;$22 = $10;
   while(1) {
    $21 = HEAP32[$$078$i$i$i>>2]|0;
    $23 = ($22|0)==($21|0);
    if (!($23)) {
     HEAP32[$$010$i$i$i>>2] = $21;
     $24 = ($21|0)==(0|0);
     if (!($24)) {
      $25 = ((($21)) + 8|0);
      $26 = HEAP32[$25>>2]|0;HEAP32[$25>>2] = (($26+1)|0);
     }
     $27 = ($22|0)==(0|0);
     if (!($27)) {
      $28 = ((($22)) + 8|0);
      $29 = HEAP32[$28>>2]|0;HEAP32[$28>>2] = (($29-1)|0);
      $30 = ($29|0)==(1);
      if ($30) {
       __THREW__ = 0;
       invoke_viii(3262,($22|0),1,1);
       $31 = __THREW__; __THREW__ = 0;
       $32 = $31&1;
       if ($32) {
        break;
       }
      }
     }
    }
    $33 = ((($$078$i$i$i)) + 4|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = ((($$010$i$i$i)) + 4|0);
    HEAP32[$35>>2] = $34;
    $36 = ((($$078$i$i$i)) + 8|0);
    $37 = ((($$010$i$i$i)) + 8|0);
    $38 = ($36|0)==($8|0);
    if ($38) {
     label = 16;
     break;
    }
    $$pre = HEAP32[$37>>2]|0;
    $$010$i$i$i = $37;$$078$i$i$i = $36;$22 = $$pre;
   }
   if ((label|0) == 16) {
    $$pre$i = HEAP32[$7>>2]|0;
    $39 = ($$pre$i|0)==($37|0);
    if (!($39)) {
     $$0$lcssa$i$i10$i = $37;$65 = $$pre$i;
     break;
    }
    $60 = HEAP32[$2>>2]|0;
    $61 = ((($60)) + 12|0);
    $62 = HEAP32[$61>>2]|0;
    (FUNCTION_TABLE_ii[$62 & 8191]($2)|0);
    return;
   }
   $53 = ___cxa_find_matching_catch_2()|0;
   $54 = tempRet0;
   $55 = HEAP32[$2>>2]|0;
   $56 = ((($55)) + 12|0);
   $57 = HEAP32[$56>>2]|0;
   __THREW__ = 0;
   (invoke_ii($57|0,($2|0))|0);
   $58 = __THREW__; __THREW__ = 0;
   $59 = $58&1;
   if ($59) {
    $63 = ___cxa_find_matching_catch_3(0|0)|0;
    $64 = tempRet0;
    ___clang_call_terminate($63);
    // unreachable;
   } else {
    ___resumeException($53|0);
    // unreachable;
   }
  }
 } while(0);
 $41 = $65;
 while(1) {
  $40 = ((($41)) + -8|0);
  HEAP32[$7>>2] = $40;
  $42 = HEAP32[$40>>2]|0;
  $43 = ($42|0)==(0|0);
  if (!($43)) {
   $44 = ((($42)) + 8|0);
   $45 = HEAP32[$44>>2]|0;HEAP32[$44>>2] = (($45-1)|0);
   $46 = ($45|0)==(1);
   if ($46) {
    __THREW__ = 0;
    invoke_viii(3262,($42|0),1,1);
    $47 = __THREW__; __THREW__ = 0;
    $48 = $47&1;
    if ($48) {
     label = 22;
     break;
    }
   }
  }
  HEAP32[$40>>2] = 0;
  $49 = HEAP32[$7>>2]|0;
  $50 = ($49|0)==($$0$lcssa$i$i10$i|0);
  if ($50) {
   label = 24;
   break;
  } else {
   $41 = $49;
  }
 }
 if ((label|0) == 22) {
  $51 = ___cxa_find_matching_catch_2()|0;
  $52 = tempRet0;
  ___cxa_call_unexpected(($51|0));
  // unreachable;
 }
 else if ((label|0) == 24) {
  $60 = HEAP32[$2>>2]|0;
  $61 = ((($60)) + 12|0);
  $62 = HEAP32[$61>>2]|0;
  (FUNCTION_TABLE_ii[$62 & 8191]($2)|0);
  return;
 }
}
function __GLOBAL__sub_I_Scene_cpp() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF32[51966] = 1.0;
 HEAPF32[(207868)>>2] = 0.0;
 HEAPF32[(207872)>>2] = 0.0;
 HEAPF32[51969] = 0.0;
 HEAPF32[(207880)>>2] = 1.0;
 HEAPF32[(207884)>>2] = 0.0;
 HEAPF32[51972] = 0.0;
 HEAPF32[(207892)>>2] = 0.0;
 HEAPF32[(207896)>>2] = 1.0;
 __ZN9osgViewer19SceneSingletonProxyC2Ev(217116);
 return;
}
function __ZN9osgViewer19SceneSingletonProxyC2Ev($0) {
 $0 = $0|0;
 var $$pre$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP8[205992]|0;
 $2 = ($1<<24>>24)==(0);
 if (!($2)) {
  return;
 }
 $3 = (___cxa_guard_acquire(205992)|0);
 $4 = ($3|0)==(0);
 if ($4) {
  return;
 }
 HEAP32[51960] = 0;
 HEAP32[(207844)>>2] = 0;
 HEAP32[(207848)>>2] = 0;
 __THREW__ = 0;
 invoke_vii(3507,((207852)|0),0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if (!($6)) {
  (___cxa_atexit((3511|0),(207840|0),(___dso_handle|0))|0);
  return;
 }
 $7 = ___cxa_find_matching_catch_2()|0;
 $8 = tempRet0;
 $9 = HEAP32[51960]|0;
 $10 = ($9|0)==(0|0);
 if ($10) {
  ___resumeException($7|0);
  // unreachable;
 }
 $11 = HEAP32[(207844)>>2]|0;
 $12 = ($11|0)==($9|0);
 do {
  if ($12) {
   $26 = $9;
  } else {
   $14 = $11;
   while(1) {
    $13 = ((($14)) + -8|0);
    HEAP32[(207844)>>2] = $13;
    $15 = HEAP32[$13>>2]|0;
    $16 = ($15|0)==(0|0);
    if (!($16)) {
     $17 = ((($15)) + 8|0);
     $18 = HEAP32[$17>>2]|0;HEAP32[$17>>2] = (($18-1)|0);
     $19 = ($18|0)==(1);
     if ($19) {
      __THREW__ = 0;
      invoke_viii(3262,($15|0),1,1);
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if ($21) {
       label = 10;
       break;
      }
     }
    }
    HEAP32[$13>>2] = 0;
    $22 = HEAP32[(207844)>>2]|0;
    $23 = ($22|0)==($9|0);
    if ($23) {
     label = 11;
     break;
    } else {
     $14 = $22;
    }
   }
   if ((label|0) == 10) {
    $24 = ___cxa_find_matching_catch_2()|0;
    $25 = tempRet0;
    ___cxa_call_unexpected(($24|0));
    // unreachable;
   }
   else if ((label|0) == 11) {
    $$pre$i = HEAP32[51960]|0;
    $26 = $$pre$i;
    break;
   }
  }
 } while(0);
 __ZdlPv($26);
 ___resumeException($7|0);
 // unreachable;
}
function __ZN9osgViewer5SceneC2Ev($0) {
 $0 = $0|0;
 var $$0 = 0, $$02 = 0, $$pre$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg10ReferencedC2Eb($0,1);
 HEAP32[$0>>2] = (41980);
 $1 = ((($0)) + 12|0);
 HEAP32[$1>>2] = 0;
 $2 = ((($0)) + 16|0);
 HEAP32[$2>>2] = 0;
 $3 = ((($0)) + 20|0);
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 $4 = (invoke_i(3513)|0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 L1: do {
  if ($6) {
   label = 30;
  } else {
   $7 = HEAP32[$2>>2]|0;
   $8 = ($7|0)==($4|0);
   if (!($8)) {
    HEAP32[$2>>2] = $4;
    $9 = ($4|0)==(0|0);
    if (!($9)) {
     $10 = ((($4)) + 8|0);
     $11 = HEAP32[$10>>2]|0;HEAP32[$10>>2] = (($11+1)|0);
    }
    $12 = ($7|0)==(0|0);
    if (!($12)) {
     $13 = ((($7)) + 8|0);
     $14 = HEAP32[$13>>2]|0;HEAP32[$13>>2] = (($14-1)|0);
     $15 = ($14|0)==(1);
     if ($15) {
      __THREW__ = 0;
      invoke_viii(3262,($7|0),1,1);
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if ($17) {
       label = 30;
       break;
      }
     }
    }
   }
   __THREW__ = 0;
   $18 = (invoke_ii(3276,72)|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if ($20) {
    label = 30;
   } else {
    __THREW__ = 0;
    invoke_vi(3514,($18|0));
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if ($22) {
     $63 = ___cxa_find_matching_catch_2()|0;
     $64 = tempRet0;
     __ZdlPv($18);
     $$0 = $64;$$02 = $63;
     break;
    }
    $23 = HEAP32[$3>>2]|0;
    $24 = ($23|0)==($18|0);
    if (!($24)) {
     HEAP32[$3>>2] = $18;
     $25 = ((($18)) + 8|0);
     $26 = HEAP32[$25>>2]|0;HEAP32[$25>>2] = (($26+1)|0);
     $27 = ($23|0)==(0|0);
     if (!($27)) {
      $28 = ((($23)) + 8|0);
      $29 = HEAP32[$28>>2]|0;HEAP32[$28>>2] = (($29-1)|0);
      $30 = ($29|0)==(1);
      if ($30) {
       __THREW__ = 0;
       invoke_viii(3262,($23|0),1,1);
       $31 = __THREW__; __THREW__ = 0;
       $32 = $31&1;
       if ($32) {
        label = 30;
        break;
       }
      }
     }
    }
    $33 = HEAP8[205992]|0;
    $34 = ($33<<24>>24)==(0);
    do {
     if ($34) {
      $35 = (___cxa_guard_acquire(205992)|0);
      $36 = ($35|0)==(0);
      if (!($36)) {
       HEAP32[51960] = 0;
       HEAP32[(207844)>>2] = 0;
       HEAP32[(207848)>>2] = 0;
       __THREW__ = 0;
       invoke_vii(3507,((207852)|0),0);
       $37 = __THREW__; __THREW__ = 0;
       $38 = $37&1;
       if (!($38)) {
        (___cxa_atexit((3511|0),(207840|0),(___dso_handle|0))|0);
        break;
       }
       $39 = ___cxa_find_matching_catch_2()|0;
       $40 = tempRet0;
       $41 = HEAP32[51960]|0;
       $42 = ($41|0)==(0|0);
       if (!($42)) {
        $43 = HEAP32[(207844)>>2]|0;
        $44 = ($43|0)==($41|0);
        do {
         if ($44) {
          $58 = $41;
         } else {
          $46 = $43;
          while(1) {
           $45 = ((($46)) + -8|0);
           HEAP32[(207844)>>2] = $45;
           $47 = HEAP32[$45>>2]|0;
           $48 = ($47|0)==(0|0);
           if (!($48)) {
            $49 = ((($47)) + 8|0);
            $50 = HEAP32[$49>>2]|0;HEAP32[$49>>2] = (($50-1)|0);
            $51 = ($50|0)==(1);
            if ($51) {
             __THREW__ = 0;
             invoke_viii(3262,($47|0),1,1);
             $52 = __THREW__; __THREW__ = 0;
             $53 = $52&1;
             if ($53) {
              label = 23;
              break;
             }
            }
           }
           HEAP32[$45>>2] = 0;
           $54 = HEAP32[(207844)>>2]|0;
           $55 = ($54|0)==($41|0);
           if ($55) {
            label = 24;
            break;
           } else {
            $46 = $54;
           }
          }
          if ((label|0) == 23) {
           $56 = ___cxa_find_matching_catch_2()|0;
           $57 = tempRet0;
           ___cxa_call_unexpected(($56|0));
           // unreachable;
          }
          else if ((label|0) == 24) {
           $$pre$i = HEAP32[51960]|0;
           $58 = $$pre$i;
           break;
          }
         }
        } while(0);
        __ZdlPv($58);
       }
       $eh$lpad$body$index2Z2D = $40;$eh$lpad$body$indexZ2D = $39;
       label = 31;
       break L1;
      }
     }
    } while(0);
    __THREW__ = 0;
    invoke_vii(3515,(207840|0),($0|0));
    $59 = __THREW__; __THREW__ = 0;
    $60 = $59&1;
    if ($60) {
     label = 30;
    } else {
     return;
    }
   }
  }
 } while(0);
 if ((label|0) == 30) {
  $61 = ___cxa_find_matching_catch_2()|0;
  $62 = tempRet0;
  $eh$lpad$body$index2Z2D = $62;$eh$lpad$body$indexZ2D = $61;
  label = 31;
 }
 if ((label|0) == 31) {
  $$0 = $eh$lpad$body$index2Z2D;$$02 = $eh$lpad$body$indexZ2D;
 }
 $65 = HEAP32[$3>>2]|0;
 $66 = ($65|0)==(0|0);
 if (!($66)) {
  $67 = ((($65)) + 8|0);
  $68 = HEAP32[$67>>2]|0;HEAP32[$67>>2] = (($68-1)|0);
  $69 = ($68|0)==(1);
  if ($69) {
   __THREW__ = 0;
   invoke_viii(3262,($65|0),1,1);
   $70 = __THREW__; __THREW__ = 0;
   $71 = $70&1;
   if ($71) {
    $88 = ___cxa_find_matching_catch_3(0|0)|0;
    $89 = tempRet0;
    ___clang_call_terminate($88);
    // unreachable;
   }
  }
 }
 HEAP32[$3>>2] = 0;
 $72 = HEAP32[$2>>2]|0;
 $73 = ($72|0)==(0|0);
 if (!($73)) {
  $74 = ((($72)) + 8|0);
  $75 = HEAP32[$74>>2]|0;HEAP32[$74>>2] = (($75-1)|0);
  $76 = ($75|0)==(1);
  if ($76) {
   __THREW__ = 0;
   invoke_viii(3262,($72|0),1,1);
   $77 = __THREW__; __THREW__ = 0;
   $78 = $77&1;
   if ($78) {
    $88 = ___cxa_find_matching_catch_3(0|0)|0;
    $89 = tempRet0;
    ___clang_call_terminate($88);
    // unreachable;
   }
  }
 }
 HEAP32[$2>>2] = 0;
 $79 = HEAP32[$1>>2]|0;
 $80 = ($79|0)==(0|0);
 if (!($80)) {
  $81 = ((($79)) + 8|0);
  $82 = HEAP32[$81>>2]|0;HEAP32[$81>>2] = (($82-1)|0);
  $83 = ($82|0)==(1);
  if ($83) {
   __THREW__ = 0;
   invoke_viii(3262,($79|0),1,1);
   $84 = __THREW__; __THREW__ = 0;
   $85 = $84&1;
   if ($85) {
    $88 = ___cxa_find_matching_catch_3(0|0)|0;
    $89 = tempRet0;
    ___clang_call_terminate($88);
    // unreachable;
   }
  }
 }
 HEAP32[$1>>2] = 0;
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $86 = __THREW__; __THREW__ = 0;
 $87 = $86&1;
 if ($87) {
  $88 = ___cxa_find_matching_catch_3(0|0)|0;
  $89 = tempRet0;
  ___clang_call_terminate($88);
  // unreachable;
 } else {
  ___resumeException($$02|0);
  // unreachable;
 }
}
function __ZN9osgViewer14SceneSingleton3addEPNS_5SceneE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$03 = 0, $$pre$i = 0, $$pre$phiZ2D = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = ((($0)) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($4)) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 (FUNCTION_TABLE_ii[$6 & 8191]($3)|0);
 __THREW__ = 0;
 invoke_vii(3516,($2|0),($1|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 L1: do {
  if ($8) {
   label = 12;
  } else {
   $9 = ((($0)) + 4|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ((($0)) + 8|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = ($10|0)==($12|0);
   do {
    if ($13) {
     __THREW__ = 0;
     invoke_vii(3517,($0|0),($2|0));
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if (!($24)) {
      $$pre$phiZ2D = $2;
      break;
     }
     $37 = ___cxa_find_matching_catch_2()|0;
     $38 = tempRet0;
     $39 = HEAP32[$2>>2]|0;
     $40 = ($39|0)==(0|0);
     if (!($40)) {
      $41 = ((($39)) + 8|0);
      $42 = HEAP32[$41>>2]|0;HEAP32[$41>>2] = (($42-1)|0);
      $43 = ($42|0)==(1);
      if ($43) {
       __THREW__ = 0;
       invoke_viii(3262,($39|0),1,1);
       $44 = __THREW__; __THREW__ = 0;
       $45 = $44&1;
       if ($45) {
        $51 = ___cxa_find_matching_catch_3(0|0)|0;
        $52 = tempRet0;
        ___clang_call_terminate($51);
        // unreachable;
       }
      }
     }
     HEAP32[$2>>2] = 0;
     $$0 = $38;$$03 = $37;
     break L1;
    } else {
     $14 = HEAP32[$2>>2]|0;
     HEAP32[$10>>2] = $14;
     $15 = ($14|0)==(0|0);
     if ($15) {
      $22 = $10;
     } else {
      $16 = ((($14)) + 8|0);
      $17 = HEAP32[$16>>2]|0;HEAP32[$16>>2] = (($17+1)|0);
      $$pre$i = HEAP32[$9>>2]|0;
      $22 = $$pre$i;
     }
     $18 = ((($10)) + 4|0);
     $19 = ((($2)) + 4|0);
     $20 = HEAP32[$19>>2]|0;
     HEAP32[$18>>2] = $20;
     $21 = ((($22)) + 8|0);
     HEAP32[$9>>2] = $21;
     $$pre$phiZ2D = $2;
    }
   } while(0);
   $25 = HEAP32[$$pre$phiZ2D>>2]|0;
   $26 = ($25|0)==(0|0);
   if ($26) {
    HEAP32[$$pre$phiZ2D>>2] = 0;
    $32 = HEAP32[$3>>2]|0;
    $33 = ((($32)) + 12|0);
    $34 = HEAP32[$33>>2]|0;
    (FUNCTION_TABLE_ii[$34 & 8191]($3)|0);
    STACKTOP = sp;return;
   }
   $27 = ((($25)) + 8|0);
   $28 = HEAP32[$27>>2]|0;HEAP32[$27>>2] = (($28-1)|0);
   $29 = ($28|0)==(1);
   if (!($29)) {
    HEAP32[$$pre$phiZ2D>>2] = 0;
    $32 = HEAP32[$3>>2]|0;
    $33 = ((($32)) + 12|0);
    $34 = HEAP32[$33>>2]|0;
    (FUNCTION_TABLE_ii[$34 & 8191]($3)|0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   invoke_viii(3262,($25|0),1,1);
   $30 = __THREW__; __THREW__ = 0;
   $31 = $30&1;
   if ($31) {
    label = 12;
   } else {
    HEAP32[$$pre$phiZ2D>>2] = 0;
    $32 = HEAP32[$3>>2]|0;
    $33 = ((($32)) + 12|0);
    $34 = HEAP32[$33>>2]|0;
    (FUNCTION_TABLE_ii[$34 & 8191]($3)|0);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 12) {
  $35 = ___cxa_find_matching_catch_2()|0;
  $36 = tempRet0;
  $$0 = $36;$$03 = $35;
 }
 $46 = HEAP32[$3>>2]|0;
 $47 = ((($46)) + 12|0);
 $48 = HEAP32[$47>>2]|0;
 __THREW__ = 0;
 (invoke_ii($48|0,($3|0))|0);
 $49 = __THREW__; __THREW__ = 0;
 $50 = $49&1;
 if ($50) {
  $51 = ___cxa_find_matching_catch_3(0|0)|0;
  $52 = tempRet0;
  ___clang_call_terminate($51);
  // unreachable;
 } else {
  ___resumeException($$03|0);
  // unreachable;
 }
}
function __ZN3osg12observer_ptrIN9osgViewer5SceneEEC2EPS2_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$ = 0, $$pr = 0, $$pr6 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = 0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   label = 9;
  } else {
   __THREW__ = 0;
   $3 = (invoke_ii(3325,($1|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $$pr = HEAP32[$0>>2]|0;
    $6 = ($$pr|0)==($3|0);
    if ($6) {
     $16 = $3;
     break;
    }
    HEAP32[$0>>2] = $3;
    $7 = ($3|0)==(0|0);
    if (!($7)) {
     $8 = ((($3)) + 8|0);
     $9 = HEAP32[$8>>2]|0;HEAP32[$8>>2] = (($9+1)|0);
    }
    $10 = ($$pr|0)==(0|0);
    if ($10) {
     label = 9;
     break;
    }
    $11 = ((($$pr)) + 8|0);
    $12 = HEAP32[$11>>2]|0;HEAP32[$11>>2] = (($12-1)|0);
    $13 = ($12|0)==(1);
    if (!($13)) {
     label = 9;
     break;
    }
    __THREW__ = 0;
    invoke_viii(3262,($$pr|0),1,1);
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if (!($15)) {
     label = 9;
     break;
    }
   }
   $23 = ___cxa_find_matching_catch_2()|0;
   $24 = tempRet0;
   $25 = HEAP32[$0>>2]|0;
   $26 = ($25|0)==(0|0);
   if ($26) {
    HEAP32[$0>>2] = 0;
    ___resumeException($23|0);
    // unreachable;
   }
   $27 = ((($25)) + 8|0);
   $28 = HEAP32[$27>>2]|0;HEAP32[$27>>2] = (($28-1)|0);
   $29 = ($28|0)==(1);
   if (!($29)) {
    HEAP32[$0>>2] = 0;
    ___resumeException($23|0);
    // unreachable;
   }
   __THREW__ = 0;
   invoke_viii(3262,($25|0),1,1);
   $30 = __THREW__; __THREW__ = 0;
   $31 = $30&1;
   if ($31) {
    $32 = ___cxa_find_matching_catch_3(0|0)|0;
    $33 = tempRet0;
    ___clang_call_terminate($32);
    // unreachable;
   } else {
    HEAP32[$0>>2] = 0;
    ___resumeException($23|0);
    // unreachable;
   }
  }
 } while(0);
 if ((label|0) == 9) {
  $$pr6 = HEAP32[$0>>2]|0;
  $16 = $$pr6;
 }
 $17 = ($16|0)==(0|0);
 if ($17) {
  $22 = 0;
  $21 = ((($0)) + 4|0);
  HEAP32[$21>>2] = $22;
  return;
 }
 $18 = ((($16)) + 24|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)!=(0|0);
 $$ = $20 ? $1 : 0;
 $22 = $$;
 $21 = ((($0)) + 4|0);
 HEAP32[$21>>2] = $22;
 return;
}
function __ZNSt3__26vectorIN3osg12observer_ptrIN9osgViewer5SceneEEENS_9allocatorIS5_EEE21__push_back_slow_pathIKS5_EEvRT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$06$i$i = 0, $$pre = 0, $$pre$i = 0, $$pre38 = 0, $$pre39 = 0, $$sroa$7$0 = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 3;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(536870911);
 $9 = $4;
 $10 = $3;
 if ($8) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $11 = ((($0)) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) - ($4))|0;
 $14 = $13 >> 3;
 $15 = ($14>>>0)<(268435455);
 $16 = $13 >> 2;
 $17 = ($16>>>0)<($7>>>0);
 $$sroa$speculated$i = $17 ? $7 : $16;
 $$sroa$speculated$$i = $15 ? $$sroa$speculated$i : 536870911;
 $18 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($18) {
   $28 = 0;
  } else {
   $19 = ($$sroa$speculated$$i>>>0)>(536870911);
   if (!($19)) {
    $25 = $$sroa$speculated$$i << 3;
    $26 = (__Znwj($25)|0);
    $28 = $26;
    break;
   }
   $20 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($20|0),(204840|0));
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if ($22) {
    $23 = ___cxa_find_matching_catch_2()|0;
    $24 = tempRet0;
    ___cxa_free_exception(($20|0));
    ___resumeException($23|0);
    // unreachable;
   } else {
    HEAP32[$20>>2] = (99824);
    ___cxa_throw(($20|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $27 = (($28) + ($6<<3)|0);
 $29 = $27;
 $30 = (($28) + ($$sroa$speculated$$i<<3)|0);
 $31 = $30;
 $32 = HEAP32[$1>>2]|0;
 HEAP32[$27>>2] = $32;
 $33 = ($32|0)==(0|0);
 if ($33) {
  $41 = $10;$43 = $9;
 } else {
  $34 = ((($32)) + 8|0);
  $35 = HEAP32[$34>>2]|0;HEAP32[$34>>2] = (($35+1)|0);
  $$pre = HEAP32[$0>>2]|0;
  $$pre38 = HEAP32[$2>>2]|0;
  $41 = $$pre38;$43 = $$pre;
 }
 $36 = (((($28) + ($6<<3)|0)) + 4|0);
 $37 = ((($1)) + 4|0);
 $38 = HEAP32[$37>>2]|0;
 HEAP32[$36>>2] = $38;
 $39 = ((($27)) + 8|0);
 $40 = $39;
 $42 = ($41|0)==($43|0);
 if ($42) {
  $44 = $41;
  $59 = $29;$60 = $44;$62 = $41;
 } else {
  $$06$i$i = $41;$$sroa$7$0 = $29;$47 = $27;
  while(1) {
   $45 = ((($$06$i$i)) + -8|0);
   $46 = ((($47)) + -8|0);
   $48 = HEAP32[$45>>2]|0;
   HEAP32[$46>>2] = $48;
   $49 = ($48|0)==(0|0);
   if (!($49)) {
    $50 = ((($48)) + 8|0);
    $51 = HEAP32[$50>>2]|0;HEAP32[$50>>2] = (($51+1)|0);
   }
   $52 = ((($47)) + -4|0);
   $53 = ((($$06$i$i)) + -4|0);
   $54 = HEAP32[$53>>2]|0;
   HEAP32[$52>>2] = $54;
   $55 = $$sroa$7$0;
   $56 = ((($55)) + -8|0);
   $57 = $56;
   $58 = ($45|0)==($43|0);
   if ($58) {
    break;
   } else {
    $$06$i$i = $45;$$sroa$7$0 = $57;$47 = $56;
   }
  }
  $$pre$i = HEAP32[$0>>2]|0;
  $$pre39 = HEAP32[$2>>2]|0;
  $59 = $57;$60 = $$pre$i;$62 = $$pre39;
 }
 HEAP32[$0>>2] = $59;
 HEAP32[$2>>2] = $40;
 HEAP32[$11>>2] = $31;
 $61 = $60;
 $63 = ($62|0)==($61|0);
 L25: do {
  if (!($63)) {
   $65 = $62;
   while(1) {
    $64 = ((($65)) + -8|0);
    $66 = HEAP32[$64>>2]|0;
    $67 = ($66|0)==(0|0);
    if (!($67)) {
     $68 = ((($66)) + 8|0);
     $69 = HEAP32[$68>>2]|0;HEAP32[$68>>2] = (($69-1)|0);
     $70 = ($69|0)==(1);
     if ($70) {
      __THREW__ = 0;
      invoke_viii(3262,($66|0),1,1);
      $71 = __THREW__; __THREW__ = 0;
      $72 = $71&1;
      if ($72) {
       break;
      }
     }
    }
    HEAP32[$64>>2] = 0;
    $73 = ($64|0)==($61|0);
    if ($73) {
     break L25;
    } else {
     $65 = $64;
    }
   }
   $74 = ___cxa_find_matching_catch_2()|0;
   $75 = tempRet0;
   ___cxa_call_unexpected(($74|0));
   // unreachable;
  }
 } while(0);
 $76 = ($60|0)==(0);
 if ($76) {
  return;
 }
 $77 = $60;
 __ZdlPv($77);
 return;
}
function __ZN9osgViewer5Scene16setDatabasePagerEPN5osgDB13DatabasePagerE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==($1|0);
 if ($4) {
  return;
 }
 HEAP32[$2>>2] = $1;
 $5 = ($1|0)==(0|0);
 if (!($5)) {
  $6 = ((($1)) + 8|0);
  $7 = HEAP32[$6>>2]|0;HEAP32[$6>>2] = (($7+1)|0);
 }
 $8 = ($3|0)==(0|0);
 if ($8) {
  return;
 }
 $9 = ((($3)) + 8|0);
 $10 = HEAP32[$9>>2]|0;HEAP32[$9>>2] = (($10-1)|0);
 $11 = ($10|0)==(1);
 if (!($11)) {
  return;
 }
 __ZNK3osg10Referenced24signalObserversAndDeleteEbb($3,1,1);
 return;
}
function __ZN9osgViewer5Scene12setSceneDataEPN3osg4NodeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==($1|0);
 if ($4) {
  return;
 }
 HEAP32[$2>>2] = $1;
 $5 = ($1|0)==(0|0);
 if (!($5)) {
  $6 = ((($1)) + 8|0);
  $7 = HEAP32[$6>>2]|0;HEAP32[$6>>2] = (($7+1)|0);
 }
 $8 = ($3|0)==(0|0);
 if ($8) {
  return;
 }
 $9 = ((($3)) + 8|0);
 $10 = HEAP32[$9>>2]|0;HEAP32[$9>>2] = (($10-1)|0);
 $11 = ($10|0)==(1);
 if (!($11)) {
  return;
 }
 __ZNK3osg10Referenced24signalObserversAndDeleteEbb($3,1,1);
 return;
}
function __ZN9osgViewer5Scene12getSceneDataEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 return ($2|0);
}
function __ZN9osgViewer5Scene8getSceneEPN3osg4NodeE($0) {
 $0 = $0|0;
 var $$113$i = 0, $$pre$i = 0, $$sroa$015$024$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP8[205992]|0;
 $2 = ($1<<24>>24)==(0);
 do {
  if ($2) {
   $3 = (___cxa_guard_acquire(205992)|0);
   $4 = ($3|0)==(0);
   if (!($4)) {
    HEAP32[51960] = 0;
    HEAP32[(207844)>>2] = 0;
    HEAP32[(207848)>>2] = 0;
    __THREW__ = 0;
    invoke_vii(3507,((207852)|0),0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     (___cxa_atexit((3511|0),(207840|0),(___dso_handle|0))|0);
     break;
    }
    $7 = ___cxa_find_matching_catch_2()|0;
    $8 = tempRet0;
    $9 = HEAP32[51960]|0;
    $10 = ($9|0)==(0|0);
    if ($10) {
     ___resumeException($7|0);
     // unreachable;
    }
    $11 = HEAP32[(207844)>>2]|0;
    $12 = ($11|0)==($9|0);
    do {
     if ($12) {
      $26 = $9;
     } else {
      $14 = $11;
      while(1) {
       $13 = ((($14)) + -8|0);
       HEAP32[(207844)>>2] = $13;
       $15 = HEAP32[$13>>2]|0;
       $16 = ($15|0)==(0|0);
       if (!($16)) {
        $17 = ((($15)) + 8|0);
        $18 = HEAP32[$17>>2]|0;HEAP32[$17>>2] = (($18-1)|0);
        $19 = ($18|0)==(1);
        if ($19) {
         __THREW__ = 0;
         invoke_viii(3262,($15|0),1,1);
         $20 = __THREW__; __THREW__ = 0;
         $21 = $20&1;
         if ($21) {
          label = 10;
          break;
         }
        }
       }
       HEAP32[$13>>2] = 0;
       $22 = HEAP32[(207844)>>2]|0;
       $23 = ($22|0)==($9|0);
       if ($23) {
        label = 11;
        break;
       } else {
        $14 = $22;
       }
      }
      if ((label|0) == 10) {
       $24 = ___cxa_find_matching_catch_2()|0;
       $25 = tempRet0;
       ___cxa_call_unexpected(($24|0));
       // unreachable;
      }
      else if ((label|0) == 11) {
       $$pre$i = HEAP32[51960]|0;
       $26 = $$pre$i;
       break;
      }
     }
    } while(0);
    __ZdlPv($26);
    ___resumeException($7|0);
    // unreachable;
   }
  }
 } while(0);
 $27 = HEAP32[(207852)>>2]|0;
 $28 = ((($27)) + 8|0);
 $29 = HEAP32[$28>>2]|0;
 (FUNCTION_TABLE_ii[$29 & 8191]((207852))|0);
 $30 = HEAP32[51960]|0;
 $31 = HEAP32[(207844)>>2]|0;
 $32 = ($30|0)==($31|0);
 if ($32) {
  $$113$i = 0;
  $46 = HEAP32[(207852)>>2]|0;
  $47 = ((($46)) + 12|0);
  $48 = HEAP32[$47>>2]|0;
  (FUNCTION_TABLE_ii[$48 & 8191]((207852))|0);
  return ($$113$i|0);
 } else {
  $$sroa$015$024$i = $30;
 }
 while(1) {
  $33 = HEAP32[$$sroa$015$024$i>>2]|0;
  $34 = ($33|0)==(0|0);
  if (!($34)) {
   $35 = ((($33)) + 24|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = ($36|0)==(0|0);
   if (!($37)) {
    $38 = ((($$sroa$015$024$i)) + 4|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = ($39|0)==(0|0);
    if (!($40)) {
     $41 = ((($39)) + 12|0);
     $42 = HEAP32[$41>>2]|0;
     $43 = ($42|0)==($0|0);
     if ($43) {
      $$113$i = $39;
      label = 21;
      break;
     }
    }
   }
  }
  $44 = ((($$sroa$015$024$i)) + 8|0);
  $45 = ($44|0)==($31|0);
  if ($45) {
   $$113$i = 0;
   label = 21;
   break;
  } else {
   $$sroa$015$024$i = $44;
  }
 }
 if ((label|0) == 21) {
  $46 = HEAP32[(207852)>>2]|0;
  $47 = ((($46)) + 12|0);
  $48 = HEAP32[$47>>2]|0;
  (FUNCTION_TABLE_ii[$48 & 8191]((207852))|0);
  return ($$113$i|0);
 }
 return (0)|0;
}
function __ZN5osgGA12EventHandlerclEPN3osg4NodeEPNS1_11NodeVisitorE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$sroa$014$0 = 0, $$sroa$014$019 = 0, $$sroa$014$020 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + 52|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_ii[$5 & 8191]($2)|0);
 $7 = ($6|0)==(0|0);
 if (!($7)) {
  $8 = ((($6)) + 56|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($9|0)==(0|0);
  if (!($10)) {
   $11 = ((($6)) + 76|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = ($12|0)==(0);
   if (!($13)) {
    $14 = ((($6)) + 72|0);
    $$sroa$014$019 = HEAP32[$14>>2]|0;
    $15 = ((($6)) + 68|0);
    $16 = $$sroa$014$019;
    $17 = ($16|0)==($15|0);
    if (!($17)) {
     $$sroa$014$020 = $$sroa$014$019;$25 = $16;
     while(1) {
      $18 = HEAP32[$0>>2]|0;
      $19 = ((($18)) + 64|0);
      $20 = HEAP32[$19>>2]|0;
      $21 = $$sroa$014$020;
      $22 = ((($21)) + 8|0);
      $23 = HEAP32[$22>>2]|0;
      (FUNCTION_TABLE_iiiii[$20 & 8191]($0,$23,$1,$2)|0);
      $24 = ((($25)) + 4|0);
      $$sroa$014$0 = HEAP32[$24>>2]|0;
      $26 = $$sroa$014$0;
      $27 = ($26|0)==($15|0);
      if ($27) {
       break;
      } else {
       $$sroa$014$020 = $$sroa$014$0;$25 = $26;
      }
     }
    }
   }
  }
 }
 $28 = ((($1)) + 96|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ($29|0)==(0);
 $31 = HEAP32[$0>>2]|0;
 $32 = ((($31)) + -12|0);
 $33 = HEAP32[$32>>2]|0;
 if ($30) {
  $34 = (($0) + ($33)|0);
  $35 = ((($34)) + 4|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = ($36|0)==(0|0);
  if ($37) {
   return;
  }
 }
 $38 = (($0) + ($33)|0);
 $39 = ($2|0)==(0|0);
 if ($39) {
  $44 = 0;
 } else {
  $40 = HEAP32[$2>>2]|0;
  $41 = ((($40)) + -12|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = (($2) + ($42)|0);
  $44 = $43;
 }
 (__ZN3osg8Callback8traverseEPNS_6ObjectES2_($38,$1,$44)|0);
 return;
}
function __ZN5osgGA12EventHandler5eventEPN3osg11NodeVisitorEPNS1_8DrawableE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$sroa$011$0 = 0, $$sroa$011$016 = 0, $$sroa$011$017 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = HEAP32[$1>>2]|0;
 $4 = ((($3)) + 52|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_ii[$5 & 8191]($1)|0);
 $7 = ($6|0)==(0|0);
 if ($7) {
  return;
 }
 $8 = ((($6)) + 56|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if ($10) {
  return;
 }
 $11 = ((($6)) + 76|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0);
 if ($13) {
  return;
 }
 $14 = ((($6)) + 72|0);
 $$sroa$011$016 = HEAP32[$14>>2]|0;
 $15 = ((($6)) + 68|0);
 $16 = $$sroa$011$016;
 $17 = ($16|0)==($15|0);
 if ($17) {
  return;
 }
 $$sroa$011$017 = $$sroa$011$016;$25 = $16;
 while(1) {
  $18 = HEAP32[$0>>2]|0;
  $19 = ((($18)) + 64|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = $$sroa$011$017;
  $22 = ((($21)) + 8|0);
  $23 = HEAP32[$22>>2]|0;
  (FUNCTION_TABLE_iiiii[$20 & 8191]($0,$23,$2,$1)|0);
  $24 = ((($25)) + 4|0);
  $$sroa$011$0 = HEAP32[$24>>2]|0;
  $26 = $$sroa$011$0;
  $27 = ($26|0)==($15|0);
  if ($27) {
   break;
  } else {
   $$sroa$011$017 = $$sroa$011$0;$25 = $26;
  }
 }
 return;
}
function __ZN5osgGA12EventHandler6handleEPNS_5EventEPN3osg6ObjectEPNS3_11NodeVisitorE($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $4 = sp;
 $5 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
 if (!($5)) {
  STACKTOP = sp;return 0;
 }
 $6 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
 $7 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($6,109520,13)|0);
 $8 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEPKv($7,$1)|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($9)) + -12|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($8) + ($11)|0);
 __ZNKSt3__28ios_base6getlocEv($4,$12);
 __THREW__ = 0;
 $13 = (invoke_iii(3255,($4|0),(215188|0))|0);
 $14 = __THREW__; __THREW__ = 0;
 $15 = $14&1;
 if (!($15)) {
  $16 = HEAP32[$13>>2]|0;
  $17 = ((($16)) + 28|0);
  $18 = HEAP32[$17>>2]|0;
  __THREW__ = 0;
  $19 = (invoke_iii($18|0,($13|0),10)|0);
  $20 = __THREW__; __THREW__ = 0;
  $21 = $20&1;
  if (!($21)) {
   __ZNSt3__26localeD2Ev($4);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($8,$19)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($8)|0);
   STACKTOP = sp;return 0;
  }
 }
 $22 = ___cxa_find_matching_catch_2()|0;
 $23 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($4|0));
 $24 = __THREW__; __THREW__ = 0;
 $25 = $24&1;
 if ($25) {
  $26 = ___cxa_find_matching_catch_3(0|0)|0;
  $27 = tempRet0;
  ___clang_call_terminate($26);
  // unreachable;
 } else {
  ___resumeException($22|0);
  // unreachable;
 }
 return (0)|0;
}
function __ZThn4_N5osgGA12EventHandler5eventEPN3osg11NodeVisitorEPNS1_8DrawableE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$sroa$011$0$i = 0, $$sroa$011$016$i = 0, $$sroa$011$017$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + -4|0);
 $4 = HEAP32[$1>>2]|0;
 $5 = ((($4)) + 52|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_ii[$6 & 8191]($1)|0);
 $8 = ($7|0)==(0|0);
 if ($8) {
  return;
 }
 $9 = ((($7)) + 56|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  return;
 }
 $12 = ((($7)) + 76|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0);
 if ($14) {
  return;
 }
 $15 = ((($7)) + 72|0);
 $$sroa$011$016$i = HEAP32[$15>>2]|0;
 $16 = ((($7)) + 68|0);
 $17 = $$sroa$011$016$i;
 $18 = ($17|0)==($16|0);
 if ($18) {
  return;
 }
 $$sroa$011$017$i = $$sroa$011$016$i;$26 = $17;
 while(1) {
  $19 = HEAP32[$3>>2]|0;
  $20 = ((($19)) + 64|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = $$sroa$011$017$i;
  $23 = ((($22)) + 8|0);
  $24 = HEAP32[$23>>2]|0;
  (FUNCTION_TABLE_iiiii[$21 & 8191]($3,$24,$2,$1)|0);
  $25 = ((($26)) + 4|0);
  $$sroa$011$0$i = HEAP32[$25>>2]|0;
  $27 = $$sroa$011$0$i;
  $28 = ($27|0)==($16|0);
  if ($28) {
   break;
  } else {
   $$sroa$011$017$i = $$sroa$011$0$i;$26 = $27;
  }
 }
 return;
}
function __ZN5osgGA10EventQueueD2Ev($0) {
 $0 = $0|0;
 var $$023$i$i = 0, $$1 = 0, $$13 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (42064);
 $1 = ((($0)) + 44|0);
 $2 = ((($0)) + 52|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 L1: do {
  if (!($4)) {
   $5 = ((($0)) + 48|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = HEAP32[$1>>2]|0;
   $8 = ((($7)) + 4|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = HEAP32[$6>>2]|0;
   $11 = ((($10)) + 4|0);
   HEAP32[$11>>2] = $9;
   $12 = HEAP32[$8>>2]|0;
   HEAP32[$12>>2] = $10;
   HEAP32[$2>>2] = 0;
   $13 = ($6|0)==($1|0);
   if (!($13)) {
    $$023$i$i = $6;
    while(1) {
     $14 = ((($$023$i$i)) + 4|0);
     $15 = HEAP32[$14>>2]|0;
     $16 = ((($$023$i$i)) + 8|0);
     $17 = HEAP32[$16>>2]|0;
     $18 = ($17|0)==(0|0);
     if (!($18)) {
      $19 = ((($17)) + 8|0);
      $20 = HEAP32[$19>>2]|0;HEAP32[$19>>2] = (($20-1)|0);
      $21 = ($20|0)==(1);
      if ($21) {
       __THREW__ = 0;
       invoke_viii(3262,($17|0),1,1);
       $22 = __THREW__; __THREW__ = 0;
       $23 = $22&1;
       if ($23) {
        break;
       }
      }
     }
     __ZdlPv($$023$i$i);
     $24 = ($15|0)==($1|0);
     if ($24) {
      break L1;
     } else {
      $$023$i$i = $15;
     }
    }
    $25 = ___cxa_find_matching_catch_2()|0;
    $26 = tempRet0;
    ___cxa_call_unexpected(($25|0));
    // unreachable;
   }
  }
 } while(0);
 $27 = ((($0)) + 32|0);
 __THREW__ = 0;
 invoke_vi(707,($27|0));
 $28 = __THREW__; __THREW__ = 0;
 $29 = $28&1;
 do {
  if ($29) {
   $38 = ___cxa_find_matching_catch_2()|0;
   $39 = tempRet0;
   $40 = ((($0)) + 12|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = ($41|0)==(0|0);
   if (!($42)) {
    $43 = ((($41)) + 8|0);
    $44 = HEAP32[$43>>2]|0;HEAP32[$43>>2] = (($44-1)|0);
    $45 = ($44|0)==(1);
    if ($45) {
     __THREW__ = 0;
     invoke_viii(3262,($41|0),1,1);
     $46 = __THREW__; __THREW__ = 0;
     $47 = $46&1;
     if ($47) {
      $52 = ___cxa_find_matching_catch_3(0|0)|0;
      $53 = tempRet0;
      ___clang_call_terminate($52);
      // unreachable;
     }
    }
   }
   HEAP32[$40>>2] = 0;
   $$1 = $39;$$13 = $38;
  } else {
   $30 = ((($0)) + 12|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = ($31|0)==(0|0);
   if ($32) {
    HEAP32[$30>>2] = 0;
    __ZN3osg10ReferencedD2Ev($0);
    return;
   }
   $33 = ((($31)) + 8|0);
   $34 = HEAP32[$33>>2]|0;HEAP32[$33>>2] = (($34-1)|0);
   $35 = ($34|0)==(1);
   if (!($35)) {
    HEAP32[$30>>2] = 0;
    __ZN3osg10ReferencedD2Ev($0);
    return;
   }
   __THREW__ = 0;
   invoke_viii(3262,($31|0),1,1);
   $36 = __THREW__; __THREW__ = 0;
   $37 = $36&1;
   if ($37) {
    $48 = ___cxa_find_matching_catch_2()|0;
    $49 = tempRet0;
    $$1 = $49;$$13 = $48;
    break;
   } else {
    HEAP32[$30>>2] = 0;
    __ZN3osg10ReferencedD2Ev($0);
    return;
   }
  }
 } while(0);
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $50 = __THREW__; __THREW__ = 0;
 $51 = $50&1;
 if ($51) {
  $52 = ___cxa_find_matching_catch_3(0|0)|0;
  $53 = tempRet0;
  ___clang_call_terminate($52);
  // unreachable;
 } else {
  ___resumeException($$13|0);
  // unreachable;
 }
}
function __ZN5osgGA10EventQueueD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(720,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZN5osgGA10EventQueueC2ENS_15GUIEventAdapter17MouseYOrientationE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$023$i$i = 0, $$03 = 0, $$2 = 0, $$25 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg10ReferencedC2Ev($0);
 HEAP32[$0>>2] = (42064);
 $2 = ((($0)) + 12|0);
 HEAP32[$2>>2] = 0;
 $3 = ((($0)) + 32|0);
 __THREW__ = 0;
 invoke_vii(3507,($3|0),0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $42 = ___cxa_find_matching_catch_2()|0;
  $43 = tempRet0;
  $$2 = $43;$$25 = $42;
 } else {
  $6 = ((($0)) + 44|0);
  HEAP32[$6>>2] = $6;
  $7 = ((($0)) + 48|0);
  HEAP32[$7>>2] = $6;
  $8 = ((($0)) + 52|0);
  HEAP32[$8>>2] = 0;
  $9 = ((($0)) + 16|0);
  HEAP8[$9>>0] = 0;
  __THREW__ = 0;
  $10 = (invoke_i(3384)|0);
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  do {
   if ($12) {
    label = 11;
   } else {
    $13 = $10;
    $14 = $13;
    $15 = HEAP32[$14>>2]|0;
    $16 = (($13) + 4)|0;
    $17 = $16;
    $18 = HEAP32[$17>>2]|0;
    $19 = ((($0)) + 24|0);
    $20 = $19;
    $21 = $20;
    HEAP32[$21>>2] = $15;
    $22 = (($20) + 4)|0;
    $23 = $22;
    HEAP32[$23>>2] = $18;
    __THREW__ = 0;
    $24 = (invoke_ii(3276,176)|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if ($26) {
     label = 11;
    } else {
     __THREW__ = 0;
     invoke_vi(3518,($24|0));
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     if ($28) {
      $46 = ___cxa_find_matching_catch_2()|0;
      $47 = tempRet0;
      __ZdlPv($24);
      $$0 = $47;$$03 = $46;
      break;
     }
     $29 = HEAP32[$2>>2]|0;
     $30 = ($29|0)==($24|0);
     if ($30) {
      $39 = HEAP32[$2>>2]|0;
      $40 = ((($39)) + 120|0);
      HEAP32[$40>>2] = $1;
      $41 = ((($0)) + 56|0);
      HEAP8[$41>>0] = 1;
      return;
     }
     HEAP32[$2>>2] = $24;
     $31 = ((($24)) + 8|0);
     $32 = HEAP32[$31>>2]|0;HEAP32[$31>>2] = (($32+1)|0);
     $33 = ($29|0)==(0|0);
     if ($33) {
      $39 = HEAP32[$2>>2]|0;
      $40 = ((($39)) + 120|0);
      HEAP32[$40>>2] = $1;
      $41 = ((($0)) + 56|0);
      HEAP8[$41>>0] = 1;
      return;
     }
     $34 = ((($29)) + 8|0);
     $35 = HEAP32[$34>>2]|0;HEAP32[$34>>2] = (($35-1)|0);
     $36 = ($35|0)==(1);
     if (!($36)) {
      $39 = HEAP32[$2>>2]|0;
      $40 = ((($39)) + 120|0);
      HEAP32[$40>>2] = $1;
      $41 = ((($0)) + 56|0);
      HEAP8[$41>>0] = 1;
      return;
     }
     __THREW__ = 0;
     invoke_viii(3262,($29|0),1,1);
     $37 = __THREW__; __THREW__ = 0;
     $38 = $37&1;
     if ($38) {
      label = 11;
     } else {
      $39 = HEAP32[$2>>2]|0;
      $40 = ((($39)) + 120|0);
      HEAP32[$40>>2] = $1;
      $41 = ((($0)) + 56|0);
      HEAP8[$41>>0] = 1;
      return;
     }
    }
   }
  } while(0);
  if ((label|0) == 11) {
   $44 = ___cxa_find_matching_catch_2()|0;
   $45 = tempRet0;
   $$0 = $45;$$03 = $44;
  }
  $48 = HEAP32[$8>>2]|0;
  $49 = ($48|0)==(0);
  L23: do {
   if (!($49)) {
    $50 = HEAP32[$7>>2]|0;
    $51 = HEAP32[$6>>2]|0;
    $52 = ((($51)) + 4|0);
    $53 = HEAP32[$52>>2]|0;
    $54 = HEAP32[$50>>2]|0;
    $55 = ((($54)) + 4|0);
    HEAP32[$55>>2] = $53;
    $56 = HEAP32[$52>>2]|0;
    HEAP32[$56>>2] = $54;
    HEAP32[$8>>2] = 0;
    $57 = ($50|0)==($6|0);
    if (!($57)) {
     $$023$i$i = $50;
     while(1) {
      $58 = ((($$023$i$i)) + 4|0);
      $59 = HEAP32[$58>>2]|0;
      $60 = ((($$023$i$i)) + 8|0);
      $61 = HEAP32[$60>>2]|0;
      $62 = ($61|0)==(0|0);
      if (!($62)) {
       $63 = ((($61)) + 8|0);
       $64 = HEAP32[$63>>2]|0;HEAP32[$63>>2] = (($64-1)|0);
       $65 = ($64|0)==(1);
       if ($65) {
        __THREW__ = 0;
        invoke_viii(3262,($61|0),1,1);
        $66 = __THREW__; __THREW__ = 0;
        $67 = $66&1;
        if ($67) {
         break;
        }
       }
      }
      __ZdlPv($$023$i$i);
      $68 = ($59|0)==($6|0);
      if ($68) {
       break L23;
      } else {
       $$023$i$i = $59;
      }
     }
     $69 = ___cxa_find_matching_catch_2()|0;
     $70 = tempRet0;
     ___cxa_call_unexpected(($69|0));
     // unreachable;
    }
   }
  } while(0);
  __THREW__ = 0;
  invoke_vi(707,($3|0));
  $71 = __THREW__; __THREW__ = 0;
  $72 = $71&1;
  if ($72) {
   $82 = ___cxa_find_matching_catch_3(0|0)|0;
   $83 = tempRet0;
   ___clang_call_terminate($82);
   // unreachable;
  } else {
   $$2 = $$0;$$25 = $$03;
  }
 }
 $73 = HEAP32[$2>>2]|0;
 $74 = ($73|0)==(0|0);
 if (!($74)) {
  $75 = ((($73)) + 8|0);
  $76 = HEAP32[$75>>2]|0;HEAP32[$75>>2] = (($76-1)|0);
  $77 = ($76|0)==(1);
  if ($77) {
   __THREW__ = 0;
   invoke_viii(3262,($73|0),1,1);
   $78 = __THREW__; __THREW__ = 0;
   $79 = $78&1;
   if ($79) {
    $82 = ___cxa_find_matching_catch_3(0|0)|0;
    $83 = tempRet0;
    ___clang_call_terminate($82);
    // unreachable;
   }
  }
 }
 HEAP32[$2>>2] = 0;
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $80 = __THREW__; __THREW__ = 0;
 $81 = $80&1;
 if ($81) {
  $82 = ___cxa_find_matching_catch_3(0|0)|0;
  $83 = tempRet0;
  ___clang_call_terminate($82);
  // unreachable;
 } else {
  ___resumeException($$25|0);
  // unreachable;
 }
}
function __ZN5osgGA10EventQueue5clearEv($0) {
 $0 = $0|0;
 var $$023$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 32|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 (FUNCTION_TABLE_ii[$4 & 8191]($1)|0);
 $5 = ((($0)) + 44|0);
 $6 = ((($0)) + 52|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0);
 L1: do {
  if (!($8)) {
   $9 = ((($0)) + 48|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = HEAP32[$5>>2]|0;
   $12 = ((($11)) + 4|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = HEAP32[$10>>2]|0;
   $15 = ((($14)) + 4|0);
   HEAP32[$15>>2] = $13;
   $16 = HEAP32[$12>>2]|0;
   HEAP32[$16>>2] = $14;
   HEAP32[$6>>2] = 0;
   $17 = ($10|0)==($5|0);
   if (!($17)) {
    $$023$i$i = $10;
    while(1) {
     $18 = ((($$023$i$i)) + 4|0);
     $19 = HEAP32[$18>>2]|0;
     $20 = ((($$023$i$i)) + 8|0);
     $21 = HEAP32[$20>>2]|0;
     $22 = ($21|0)==(0|0);
     if (!($22)) {
      $23 = ((($21)) + 8|0);
      $24 = HEAP32[$23>>2]|0;HEAP32[$23>>2] = (($24-1)|0);
      $25 = ($24|0)==(1);
      if ($25) {
       __THREW__ = 0;
       invoke_viii(3262,($21|0),1,1);
       $26 = __THREW__; __THREW__ = 0;
       $27 = $26&1;
       if ($27) {
        break;
       }
      }
     }
     __ZdlPv($$023$i$i);
     $28 = ($19|0)==($5|0);
     if ($28) {
      break L1;
     } else {
      $$023$i$i = $19;
     }
    }
    $29 = ___cxa_find_matching_catch_2()|0;
    $30 = tempRet0;
    ___cxa_call_unexpected(($29|0));
    // unreachable;
   }
  }
 } while(0);
 $31 = HEAP32[$1>>2]|0;
 $32 = ((($31)) + 12|0);
 $33 = HEAP32[$32>>2]|0;
 (FUNCTION_TABLE_ii[$33 & 8191]($1)|0);
 return;
}
function __ZN5osgGA10EventQueue8addEventEPNS_5EventE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$03 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 32|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 (FUNCTION_TABLE_ii[$5 & 8191]($2)|0);
 $6 = ($1|0)==(0|0);
 if (!($6)) {
  $7 = ((($1)) + 8|0);
  $8 = HEAP32[$7>>2]|0;HEAP32[$7>>2] = (($8+1)|0);
 }
 $9 = ((($0)) + 44|0);
 __THREW__ = 0;
 $10 = (invoke_ii(3276,12)|0);
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 do {
  if ($12) {
   $32 = ___cxa_find_matching_catch_2()|0;
   $33 = tempRet0;
   if ($6) {
    $$0 = $33;$$03 = $32;
   } else {
    $34 = ((($1)) + 8|0);
    $35 = HEAP32[$34>>2]|0;HEAP32[$34>>2] = (($35-1)|0);
    $36 = ($35|0)==(1);
    if ($36) {
     __THREW__ = 0;
     invoke_viii(3262,($1|0),1,1);
     $37 = __THREW__; __THREW__ = 0;
     $38 = $37&1;
     if ($38) {
      $44 = ___cxa_find_matching_catch_3(0|0)|0;
      $45 = tempRet0;
      ___clang_call_terminate($44);
      // unreachable;
     } else {
      $$0 = $33;$$03 = $32;
     }
    } else {
     $$0 = $33;$$03 = $32;
    }
   }
  } else {
   $13 = ((($10)) + 8|0);
   HEAP32[$13>>2] = $1;
   if (!($6)) {
    $14 = ((($1)) + 8|0);
    $15 = HEAP32[$14>>2]|0;HEAP32[$14>>2] = (($15+1)|0);
   }
   $16 = ((($10)) + 4|0);
   HEAP32[$16>>2] = $9;
   $17 = HEAP32[$9>>2]|0;
   HEAP32[$10>>2] = $17;
   $18 = ((($17)) + 4|0);
   HEAP32[$18>>2] = $10;
   HEAP32[$9>>2] = $10;
   $19 = ((($0)) + 52|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($20) + 1)|0;
   HEAP32[$19>>2] = $21;
   if ($6) {
    $27 = HEAP32[$2>>2]|0;
    $28 = ((($27)) + 12|0);
    $29 = HEAP32[$28>>2]|0;
    (FUNCTION_TABLE_ii[$29 & 8191]($2)|0);
    return;
   }
   $22 = ((($1)) + 8|0);
   $23 = HEAP32[$22>>2]|0;HEAP32[$22>>2] = (($23-1)|0);
   $24 = ($23|0)==(1);
   if (!($24)) {
    $27 = HEAP32[$2>>2]|0;
    $28 = ((($27)) + 12|0);
    $29 = HEAP32[$28>>2]|0;
    (FUNCTION_TABLE_ii[$29 & 8191]($2)|0);
    return;
   }
   __THREW__ = 0;
   invoke_viii(3262,($1|0),1,1);
   $25 = __THREW__; __THREW__ = 0;
   $26 = $25&1;
   if ($26) {
    $30 = ___cxa_find_matching_catch_2()|0;
    $31 = tempRet0;
    $$0 = $31;$$03 = $30;
    break;
   } else {
    $27 = HEAP32[$2>>2]|0;
    $28 = ((($27)) + 12|0);
    $29 = HEAP32[$28>>2]|0;
    (FUNCTION_TABLE_ii[$29 & 8191]($2)|0);
    return;
   }
  }
 } while(0);
 $39 = HEAP32[$2>>2]|0;
 $40 = ((($39)) + 12|0);
 $41 = HEAP32[$40>>2]|0;
 __THREW__ = 0;
 (invoke_ii($41|0,($2|0))|0);
 $42 = __THREW__; __THREW__ = 0;
 $43 = $42&1;
 if ($43) {
  $44 = ___cxa_find_matching_catch_3(0|0)|0;
  $45 = tempRet0;
  ___clang_call_terminate($44);
  // unreachable;
 } else {
  ___resumeException($$03|0);
  // unreachable;
 }
}
function __ZN5osgGA10EventQueue10takeEventsERNSt3__24listIN3osg7ref_ptrINS_5EventEEENS1_9allocatorIS6_EEEEd($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = +$2;
 var $$013102 = 0.0, $$1 = 0, $$114 = 0.0, $$pre = 0, $$sroa$063$0 = 0, $$sroa$063$0105 = 0, $$sroa$454$0101 = 0, $$sroa$484$0108 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0.0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0.0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0.0, $99 = 0, $eh$lpad$body$sink98$index4Z2D = 0, $eh$lpad$body$sink98$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = ((($0)) + 32|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($5)) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 (FUNCTION_TABLE_ii[$7 & 8191]($4)|0);
 $8 = ((($0)) + 52|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0);
 if ($10) {
  $$1 = 0;
  $153 = HEAP32[$4>>2]|0;
  $154 = ((($153)) + 12|0);
  $155 = HEAP32[$154>>2]|0;
  (FUNCTION_TABLE_ii[$155 & 8191]($4)|0);
  STACKTOP = sp;return ($$1|0);
 }
 $11 = ((($0)) + 44|0);
 $12 = ((($0)) + 48|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($11|0)==($13|0);
 $15 = $13;
 if ($14) {
  $$1 = 0;
  $153 = HEAP32[$4>>2]|0;
  $154 = ((($153)) + 12|0);
  $155 = HEAP32[$154>>2]|0;
  (FUNCTION_TABLE_ii[$155 & 8191]($4)|0);
  STACKTOP = sp;return ($$1|0);
 }
 $16 = $11;
 $$sroa$484$0108 = $16;$28 = $11;
 while(1) {
  $17 = $$sroa$484$0108;
  $18 = HEAP32[$17>>2]|0;
  $19 = ((($18)) + 8|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = ((($20)) + 40|0);
  $22 = +HEAPF64[$21>>3];
  $23 = $22 > $2;
  if (!($23)) {
   break;
  }
  $24 = $$sroa$484$0108;
  $25 = HEAP32[$24>>2]|0;
  $26 = $25;
  $27 = ($26|0)==($13|0);
  if ($27) {
   $$1 = 0;
   label = 43;
   break;
  } else {
   $$sroa$484$0108 = $25;$28 = $26;
  }
 }
 if ((label|0) == 43) {
  $153 = HEAP32[$4>>2]|0;
  $154 = ((($153)) + 12|0);
  $155 = HEAP32[$154>>2]|0;
  (FUNCTION_TABLE_ii[$155 & 8191]($4)|0);
  STACKTOP = sp;return ($$1|0);
 }
 $29 = ($28|0)==($13|0);
 if ($29) {
  $$1 = 0;
  $153 = HEAP32[$4>>2]|0;
  $154 = ((($153)) + 12|0);
  $155 = HEAP32[$154>>2]|0;
  (FUNCTION_TABLE_ii[$155 & 8191]($4)|0);
  STACKTOP = sp;return ($$1|0);
 }
 $30 = ((($1)) + 8|0);
 $$sroa$063$0105 = $15;$51 = $13;
 while(1) {
  __THREW__ = 0;
  $35 = (invoke_ii(3276,12)|0);
  $36 = __THREW__; __THREW__ = 0;
  $37 = $36&1;
  if ($37) {
   label = 14;
   break;
  }
  $38 = $$sroa$063$0105;
  $39 = ((($35)) + 8|0);
  $40 = ((($38)) + 8|0);
  $41 = HEAP32[$40>>2]|0;
  HEAP32[$39>>2] = $41;
  $42 = ($41|0)==(0|0);
  if (!($42)) {
   $43 = ((($41)) + 8|0);
   $44 = HEAP32[$43>>2]|0;HEAP32[$43>>2] = (($44+1)|0);
  }
  $45 = ((($35)) + 4|0);
  HEAP32[$45>>2] = $1;
  $46 = HEAP32[$1>>2]|0;
  HEAP32[$35>>2] = $46;
  $47 = ((($46)) + 4|0);
  HEAP32[$47>>2] = $35;
  HEAP32[$1>>2] = $35;
  $48 = HEAP32[$30>>2]|0;
  $49 = (($48) + 1)|0;
  HEAP32[$30>>2] = $49;
  $50 = ((($51)) + 4|0);
  $$sroa$063$0 = HEAP32[$50>>2]|0;
  $52 = $$sroa$063$0;
  $53 = ($52|0)==($28|0);
  if ($53) {
   label = 8;
   break;
  } else {
   $$sroa$063$0105 = $$sroa$063$0;$51 = $52;
  }
 }
 L22: do {
  if ((label|0) == 8) {
   $31 = ((($1)) + 4|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ($1|0)==($32|0);
   L25: do {
    if (!($33)) {
     $34 = $1;
     $$013102 = $2;$$sroa$454$0101 = $34;$158 = $32;
     while(1) {
      $78 = $$sroa$454$0101;
      $79 = HEAP32[$78>>2]|0;
      $80 = ((($79)) + 8|0);
      $81 = HEAP32[$80>>2]|0;
      $82 = ((($81)) + 40|0);
      $83 = +HEAPF64[$82>>3];
      $84 = $83 > $$013102;
      if ($84) {
       __THREW__ = 0;
       $85 = (invoke_ii(3265,4)|0);
       $86 = __THREW__; __THREW__ = 0;
       $87 = $86&1;
       if ($87) {
        label = 38;
        break;
       }
       if ($85) {
        __THREW__ = 0;
        $88 = (invoke_ii(3266,4)|0);
        $89 = __THREW__; __THREW__ = 0;
        $90 = $89&1;
        if ($90) {
         label = 38;
         break;
        }
        __THREW__ = 0;
        $91 = (invoke_iiii(3267,($88|0),(109578|0),22)|0);
        $92 = __THREW__; __THREW__ = 0;
        $93 = $92&1;
        if ($93) {
         label = 38;
         break;
        }
        $94 = HEAP32[$78>>2]|0;
        $95 = ((($94)) + 8|0);
        $96 = HEAP32[$95>>2]|0;
        $97 = ((($96)) + 40|0);
        $98 = +HEAPF64[$97>>3];
        __THREW__ = 0;
        $99 = (invoke_iid(3519,($91|0),(+$98))|0);
        $100 = __THREW__; __THREW__ = 0;
        $101 = $100&1;
        if ($101) {
         label = 38;
         break;
        }
        __THREW__ = 0;
        $102 = (invoke_iiii(3267,($99|0),(175041|0),4)|0);
        $103 = __THREW__; __THREW__ = 0;
        $104 = $103&1;
        if ($104) {
         label = 38;
         break;
        }
        __THREW__ = 0;
        $105 = (invoke_iid(3519,($102|0),(+$$013102))|0);
        $106 = __THREW__; __THREW__ = 0;
        $107 = $106&1;
        if ($107) {
         label = 38;
         break;
        }
        $108 = HEAP32[$105>>2]|0;
        $109 = ((($108)) + -12|0);
        $110 = HEAP32[$109>>2]|0;
        $111 = (($105) + ($110)|0);
        __THREW__ = 0;
        invoke_vii(3257,($3|0),($111|0));
        $112 = __THREW__; __THREW__ = 0;
        $113 = $112&1;
        if ($113) {
         label = 38;
         break;
        }
        __THREW__ = 0;
        $114 = (invoke_iii(3255,($3|0),(215188|0))|0);
        $115 = __THREW__; __THREW__ = 0;
        $116 = $115&1;
        if ($116) {
         break;
        }
        $117 = HEAP32[$114>>2]|0;
        $118 = ((($117)) + 28|0);
        $119 = HEAP32[$118>>2]|0;
        __THREW__ = 0;
        $120 = (invoke_iii($119|0,($114|0),10)|0);
        $121 = __THREW__; __THREW__ = 0;
        $122 = $121&1;
        if ($122) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3263,($3|0));
        $123 = __THREW__; __THREW__ = 0;
        $124 = $123&1;
        if ($124) {
         label = 38;
         break;
        }
        __THREW__ = 0;
        (invoke_iii(3268,($105|0),($120|0))|0);
        $131 = __THREW__; __THREW__ = 0;
        $132 = $131&1;
        if ($132) {
         label = 38;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(3269,($105|0))|0);
        $133 = __THREW__; __THREW__ = 0;
        $134 = $133&1;
        if ($134) {
         label = 38;
         break;
        }
       }
       $137 = HEAP32[$78>>2]|0;
       $138 = ((($137)) + 8|0);
       $139 = HEAP32[$138>>2]|0;
       $140 = ((($139)) + 40|0);
       HEAPF64[$140>>3] = $$013102;
       $$pre = HEAP32[$31>>2]|0;
       $$114 = $$013102;$145 = $$pre;
      } else {
       $$114 = $83;$145 = $158;
      }
      $141 = $$sroa$454$0101;
      $142 = HEAP32[$141>>2]|0;
      $143 = $142;
      $144 = ($143|0)==($145|0);
      if ($144) {
       break L25;
      } else {
       $$013102 = $$114;$$sroa$454$0101 = $142;$158 = $145;
      }
     }
     if ((label|0) == 38) {
      $135 = ___cxa_find_matching_catch_2()|0;
      $136 = tempRet0;
      $eh$lpad$body$sink98$index4Z2D = $136;$eh$lpad$body$sink98$indexZ2D = $135;
      break L22;
     }
     $125 = ___cxa_find_matching_catch_2()|0;
     $126 = tempRet0;
     __THREW__ = 0;
     invoke_vi(3263,($3|0));
     $127 = __THREW__; __THREW__ = 0;
     $128 = $127&1;
     if ($128) {
      $129 = ___cxa_find_matching_catch_3(0|0)|0;
      $130 = tempRet0;
      ___clang_call_terminate($129);
      // unreachable;
     } else {
      $eh$lpad$body$sink98$index4Z2D = $126;$eh$lpad$body$sink98$indexZ2D = $125;
      break L22;
     }
    }
   } while(0);
   $56 = HEAP32[$12>>2]|0;
   $57 = ($56|0)==($28|0);
   if ($57) {
    $$1 = 1;
    $153 = HEAP32[$4>>2]|0;
    $154 = ((($153)) + 12|0);
    $155 = HEAP32[$154>>2]|0;
    (FUNCTION_TABLE_ii[$155 & 8191]($4)|0);
    STACKTOP = sp;return ($$1|0);
   }
   $58 = HEAP32[$28>>2]|0;
   $59 = ((($58)) + 4|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = HEAP32[$56>>2]|0;
   $62 = ((($61)) + 4|0);
   HEAP32[$62>>2] = $60;
   $63 = HEAP32[$59>>2]|0;
   HEAP32[$63>>2] = $61;
   $65 = $56;
   while(1) {
    $64 = ((($65)) + 4|0);
    $66 = HEAP32[$64>>2]|0;
    $67 = HEAP32[$8>>2]|0;
    $68 = (($67) + -1)|0;
    HEAP32[$8>>2] = $68;
    $69 = ((($65)) + 8|0);
    $70 = HEAP32[$69>>2]|0;
    $71 = ($70|0)==(0|0);
    if (!($71)) {
     $72 = ((($70)) + 8|0);
     $73 = HEAP32[$72>>2]|0;HEAP32[$72>>2] = (($73-1)|0);
     $74 = ($73|0)==(1);
     if ($74) {
      __THREW__ = 0;
      invoke_viii(3262,($70|0),1,1);
      $75 = __THREW__; __THREW__ = 0;
      $76 = $75&1;
      if ($76) {
       label = 41;
       break;
      }
     }
    }
    __ZdlPv($65);
    $77 = ($66|0)==($28|0);
    if ($77) {
     $$1 = 1;
     label = 43;
     break;
    } else {
     $65 = $66;
    }
   }
   if ((label|0) == 41) {
    $146 = ___cxa_find_matching_catch_2()|0;
    $147 = tempRet0;
    $eh$lpad$body$sink98$index4Z2D = $147;$eh$lpad$body$sink98$indexZ2D = $146;
    break;
   }
   else if ((label|0) == 43) {
    $153 = HEAP32[$4>>2]|0;
    $154 = ((($153)) + 12|0);
    $155 = HEAP32[$154>>2]|0;
    (FUNCTION_TABLE_ii[$155 & 8191]($4)|0);
    STACKTOP = sp;return ($$1|0);
   }
  }
  else if ((label|0) == 14) {
   $54 = ___cxa_find_matching_catch_2()|0;
   $55 = tempRet0;
   $eh$lpad$body$sink98$index4Z2D = $55;$eh$lpad$body$sink98$indexZ2D = $54;
  }
 } while(0);
 $148 = HEAP32[$4>>2]|0;
 $149 = ((($148)) + 12|0);
 $150 = HEAP32[$149>>2]|0;
 __THREW__ = 0;
 (invoke_ii($150|0,($4|0))|0);
 $151 = __THREW__; __THREW__ = 0;
 $152 = $151&1;
 if ($152) {
  $156 = ___cxa_find_matching_catch_3(0|0)|0;
  $157 = tempRet0;
  ___clang_call_terminate($156);
  // unreachable;
 } else {
  ___resumeException($eh$lpad$body$sink98$indexZ2D|0);
  // unreachable;
 }
 return (0)|0;
}
function __ZN5osgGA10EventQueue11mouseWarpedEff($0,$1,$2) {
 $0 = $0|0;
 $1 = +$1;
 $2 = +$2;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($4)) + 104|0);
 HEAPF32[$5>>2] = $1;
 $6 = ((($4)) + 108|0);
 HEAPF32[$6>>2] = $2;
 return;
}
function __ZN5osgGA10EventQueue11mouseMotionEffd($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = +$1;
 $2 = +$2;
 $3 = +$3;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $4 = sp;
 $5 = ((($0)) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($6)) + 104|0);
 HEAPF32[$7>>2] = $1;
 $8 = ((($6)) + 108|0);
 HEAPF32[$8>>2] = $2;
 $9 = (__Znwj(176)|0);
 HEAP32[$4>>2] = (58136);
 $10 = ((($4)) + 4|0);
 HEAP32[$10>>2] = 0;
 __THREW__ = 0;
 invoke_viii(3520,($9|0),($6|0),($4|0));
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if ($12) {
  $19 = ___cxa_find_matching_catch_2()|0;
  $20 = tempRet0;
  __ZdlPv($9);
  ___resumeException($19|0);
  // unreachable;
 } else {
  $13 = ((($9)) + 112|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = ($14|0)!=(0);
  $16 = $15 ? 8 : 16;
  $17 = ((($9)) + 48|0);
  HEAP32[$17>>2] = $16;
  $18 = ((($9)) + 40|0);
  HEAPF64[$18>>3] = $3;
  __ZN5osgGA10EventQueue8addEventEPNS_5EventE($0,$9);
  STACKTOP = sp;return ($9|0);
 }
 return (0)|0;
}
function __ZN5osgGA10EventQueue16mouseButtonPressEffjd($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = +$1;
 $2 = +$2;
 $3 = $3|0;
 $4 = +$4;
 var $$sink18 = 0, $$sink20 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $5 = sp;
 $6 = ((($0)) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($7)) + 104|0);
 HEAPF32[$8>>2] = $1;
 $9 = ((($7)) + 108|0);
 HEAPF32[$9>>2] = $2;
 switch ($3|0) {
 case 1:  {
  $$sink18 = 1;
  label = 4;
  break;
 }
 case 2:  {
  $$sink18 = 2;
  label = 4;
  break;
 }
 case 3:  {
  $$sink18 = 4;
  label = 4;
  break;
 }
 default: {
 }
 }
 if ((label|0) == 4) {
  $10 = ((($7)) + 112|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = $11 | $$sink18;
  HEAP32[$10>>2] = $12;
 }
 $13 = (__Znwj(176)|0);
 HEAP32[$5>>2] = (58136);
 $14 = ((($5)) + 4|0);
 HEAP32[$14>>2] = 0;
 __THREW__ = 0;
 invoke_viii(3520,($13|0),($7|0),($5|0));
 $15 = __THREW__; __THREW__ = 0;
 $16 = $15&1;
 if ($16) {
  $19 = ___cxa_find_matching_catch_2()|0;
  $20 = tempRet0;
  __ZdlPv($13);
  ___resumeException($19|0);
  // unreachable;
 }
 $17 = ((($13)) + 48|0);
 HEAP32[$17>>2] = 1;
 $18 = ((($13)) + 40|0);
 HEAPF64[$18>>3] = $4;
 switch ($3|0) {
 case 1:  {
  $$sink20 = 1;
  break;
 }
 case 2:  {
  $$sink20 = 2;
  break;
 }
 case 3:  {
  $$sink20 = 4;
  break;
 }
 default: {
  __ZN5osgGA10EventQueue8addEventEPNS_5EventE($0,$13);
  STACKTOP = sp;return ($13|0);
 }
 }
 $21 = ((($13)) + 84|0);
 HEAP32[$21>>2] = $$sink20;
 __ZN5osgGA10EventQueue8addEventEPNS_5EventE($0,$13);
 STACKTOP = sp;return ($13|0);
}
function __ZN5osgGA10EventQueue18mouseButtonReleaseEffjd($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = +$1;
 $2 = +$2;
 $3 = $3|0;
 $4 = +$4;
 var $$sink18 = 0, $$sink20 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $5 = sp;
 $6 = ((($0)) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($7)) + 104|0);
 HEAPF32[$8>>2] = $1;
 $9 = ((($7)) + 108|0);
 HEAPF32[$9>>2] = $2;
 switch ($3|0) {
 case 1:  {
  $$sink18 = -2;
  label = 4;
  break;
 }
 case 2:  {
  $$sink18 = -3;
  label = 4;
  break;
 }
 case 3:  {
  $$sink18 = -5;
  label = 4;
  break;
 }
 default: {
 }
 }
 if ((label|0) == 4) {
  $10 = ((($7)) + 112|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = $11 & $$sink18;
  HEAP32[$10>>2] = $12;
 }
 $13 = (__Znwj(176)|0);
 HEAP32[$5>>2] = (58136);
 $14 = ((($5)) + 4|0);
 HEAP32[$14>>2] = 0;
 __THREW__ = 0;
 invoke_viii(3520,($13|0),($7|0),($5|0));
 $15 = __THREW__; __THREW__ = 0;
 $16 = $15&1;
 if ($16) {
  $19 = ___cxa_find_matching_catch_2()|0;
  $20 = tempRet0;
  __ZdlPv($13);
  ___resumeException($19|0);
  // unreachable;
 }
 $17 = ((($13)) + 48|0);
 HEAP32[$17>>2] = 2;
 $18 = ((($13)) + 40|0);
 HEAPF64[$18>>3] = $4;
 switch ($3|0) {
 case 1:  {
  $$sink20 = 1;
  break;
 }
 case 2:  {
  $$sink20 = 2;
  break;
 }
 case 3:  {
  $$sink20 = 4;
  break;
 }
 default: {
  __ZN5osgGA10EventQueue8addEventEPNS_5EventE($0,$13);
  STACKTOP = sp;return ($13|0);
 }
 }
 $21 = ((($13)) + 84|0);
 HEAP32[$21>>2] = $$sink20;
 __ZN5osgGA10EventQueue8addEventEPNS_5EventE($0,$13);
 STACKTOP = sp;return ($13|0);
}
function __ZN5osgGA10EventQueue5frameEd($0,$1) {
 $0 = $0|0;
 $1 = +$1;
 var $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = (__Znwj(176)|0);
 $4 = ((($0)) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 HEAP32[$2>>2] = (58136);
 $6 = ((($2)) + 4|0);
 HEAP32[$6>>2] = 0;
 __THREW__ = 0;
 invoke_viii(3520,($3|0),($5|0),($2|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $11 = ___cxa_find_matching_catch_2()|0;
  $12 = tempRet0;
  __ZdlPv($3);
  ___resumeException($11|0);
  // unreachable;
 } else {
  $9 = ((($3)) + 48|0);
  HEAP32[$9>>2] = 128;
  $10 = ((($3)) + 40|0);
  HEAPF64[$10>>3] = $1;
  __ZN5osgGA10EventQueue8addEventEPNS_5EventE($0,$3);
  STACKTOP = sp;return ($3|0);
 }
 return (0)|0;
}
function __ZN5osgGA10EventQueue11createEventEv($0) {
 $0 = $0|0;
 var $$0 = 0, $$04 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $2 = ((($0)) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = (__Znwj(176)|0);
 if ($4) {
  __THREW__ = 0;
  invoke_vi(3518,($5|0));
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if (!($12)) {
   STACKTOP = sp;return ($5|0);
  }
  $13 = ___cxa_find_matching_catch_2()|0;
  $14 = tempRet0;
  __ZdlPv($5);
  $$0 = $14;$$04 = $13;
  ___resumeException($$04|0);
  // unreachable;
 }
 HEAP32[$1>>2] = (58136);
 $6 = ((($1)) + 4|0);
 HEAP32[$6>>2] = 0;
 __THREW__ = 0;
 invoke_viii(3520,($5|0),($3|0),($1|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch_2()|0;
  $10 = tempRet0;
  __ZdlPv($5);
  $$0 = $10;$$04 = $9;
  ___resumeException($$04|0);
  // unreachable;
 } else {
  STACKTOP = sp;return ($5|0);
 }
 return (0)|0;
}
function __ZN5osgGA12EventVisitorD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vii(3521,($0|0),(42572|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  $3 = ((($0)) + 80|0);
  __ZN3osg6ObjectD2Ev($3);
  return;
 }
 $4 = ___cxa_find_matching_catch_2()|0;
 $5 = tempRet0;
 $6 = ((($0)) + 80|0);
 __THREW__ = 0;
 invoke_vi(388,($6|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch_3(0|0)|0;
  $10 = tempRet0;
  ___clang_call_terminate($9);
  // unreachable;
 } else {
  ___resumeException($4|0);
  // unreachable;
 }
}
function __ZN5osgGA12EventVisitorD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vii(3521,($0|0),(42572|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $6 = ___cxa_find_matching_catch_2()|0;
  $7 = tempRet0;
  $8 = ((($0)) + 80|0);
  __THREW__ = 0;
  invoke_vi(388,($8|0));
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if ($10) {
   $11 = ___cxa_find_matching_catch_3(0|0)|0;
   $12 = tempRet0;
   ___clang_call_terminate($11);
   // unreachable;
  } else {
   $eh$lpad$body$index2Z2D = $7;$eh$lpad$body$indexZ2D = $6;
   __ZdlPv($0);
   ___resumeException($eh$lpad$body$indexZ2D|0);
   // unreachable;
  }
 }
 $3 = ((($0)) + 80|0);
 __THREW__ = 0;
 invoke_vi(388,($3|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  __ZdlPv($0);
  return;
 }
 $13 = ___cxa_find_matching_catch_2()|0;
 $14 = tempRet0;
 $eh$lpad$body$index2Z2D = $14;$eh$lpad$body$indexZ2D = $13;
 __ZdlPv($0);
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
}
function __ZNK5osgGA12EventVisitor11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (109961|0);
}
function __ZNK5osgGA12EventVisitor9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (109601|0);
}
function __ZN5osgGA12EventVisitor14asEventVisitorEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ($0|0);
}
function __ZNK5osgGA12EventVisitor14asEventVisitorEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ($0|0);
}
function __ZN5osgGA12EventVisitor5resetEv($0) {
 $0 = $0|0;
 var $$023$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 68|0);
 $2 = ((($0)) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  $27 = ((($0)) + 64|0);
  HEAP8[$27>>0] = 0;
  return;
 }
 $5 = ((($0)) + 72|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$1>>2]|0;
 $8 = ((($7)) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$6>>2]|0;
 $11 = ((($10)) + 4|0);
 HEAP32[$11>>2] = $9;
 $12 = HEAP32[$8>>2]|0;
 HEAP32[$12>>2] = $10;
 HEAP32[$2>>2] = 0;
 $13 = ($6|0)==($1|0);
 if ($13) {
  $27 = ((($0)) + 64|0);
  HEAP8[$27>>0] = 0;
  return;
 } else {
  $$023$i$i = $6;
 }
 while(1) {
  $14 = ((($$023$i$i)) + 4|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = ((($$023$i$i)) + 8|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = ($17|0)==(0|0);
  if (!($18)) {
   $19 = ((($17)) + 8|0);
   $20 = HEAP32[$19>>2]|0;HEAP32[$19>>2] = (($20-1)|0);
   $21 = ($20|0)==(1);
   if ($21) {
    __THREW__ = 0;
    invoke_viii(3262,($17|0),1,1);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     label = 7;
     break;
    }
   }
  }
  __ZdlPv($$023$i$i);
  $24 = ($15|0)==($1|0);
  if ($24) {
   label = 8;
   break;
  } else {
   $$023$i$i = $15;
  }
 }
 if ((label|0) == 7) {
  $25 = ___cxa_find_matching_catch_2()|0;
  $26 = tempRet0;
  ___cxa_call_unexpected(($25|0));
  // unreachable;
 }
 else if ((label|0) == 8) {
  $27 = ((($0)) + 64|0);
  HEAP8[$27>>0] = 0;
  return;
 }
}
function __ZN5osgGA12EventVisitor5applyERN3osg8DrawableE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 92|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 do {
  if (!($4)) {
   $5 = HEAP32[$3>>2]|0;
   $6 = ((($5)) + 84|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = (FUNCTION_TABLE_ii[$7 & 8191]($3)|0);
   $9 = ($8|0)==(0|0);
   if (!($9)) {
    $10 = HEAP32[$3>>2]|0;
    $11 = ((($10)) + 92|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = HEAP32[$0>>2]|0;
    $14 = ((($13)) + -12|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = (($0) + ($15)|0);
    (FUNCTION_TABLE_iiii[$12 & 8191]($3,$1,$16)|0);
    break;
   }
   $17 = HEAP32[$3>>2]|0;
   $18 = ((($17)) + 68|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (FUNCTION_TABLE_ii[$19 & 8191]($3)|0);
   $21 = HEAP32[$3>>2]|0;
   $22 = ((($21)) + 36|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = (FUNCTION_TABLE_ii[$23 & 8191]($3)|0);
   $25 = HEAP32[$3>>2]|0;
   $26 = ((($25)) + 28|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = (FUNCTION_TABLE_ii[$27 & 8191]($3)|0);
   $29 = ($20|0)!=(0|0);
   if ($29) {
    $30 = HEAP32[$20>>2]|0;
    $31 = ((($30)) + 32|0);
    $32 = HEAP32[$31>>2]|0;
    FUNCTION_TABLE_viii[$32 & 8191]($20,$0,$1);
   }
   $33 = ($24|0)!=(0|0);
   if ($33) {
    $34 = HEAP32[$24>>2]|0;
    $35 = ((($34)) + 32|0);
    $36 = HEAP32[$35>>2]|0;
    FUNCTION_TABLE_viii[$36 & 8191]($24,$1,$0);
   }
   $37 = ($28|0)==(0|0);
   if (!($37)) {
    $38 = HEAP32[$28>>2]|0;
    $39 = ((($38)) + 28|0);
    $40 = HEAP32[$39>>2]|0;
    $41 = HEAP32[$0>>2]|0;
    $42 = ((($41)) + -12|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = (($0) + ($43)|0);
    (FUNCTION_TABLE_iiii[$40 & 8191]($28,$1,$44)|0);
    break;
   }
   $or$cond = $29 | $33;
   if (!($or$cond)) {
    $45 = HEAP32[$3>>2]|0;
    $46 = ((($45)) + 92|0);
    $47 = HEAP32[$46>>2]|0;
    $48 = HEAP32[$0>>2]|0;
    $49 = ((($48)) + -12|0);
    $50 = HEAP32[$49>>2]|0;
    $51 = (($0) + ($50)|0);
    (FUNCTION_TABLE_iiii[$47 & 8191]($3,$1,$51)|0);
   }
  }
 } while(0);
 $52 = ((($1)) + 120|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = ($53|0)==(0|0);
 if ($54) {
  return;
 }
 $55 = ((($53)) + 152|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = ($56|0)==(0|0);
 if ($57) {
  $58 = ((($53)) + 156|0);
  $59 = HEAP32[$58>>2]|0;
  $60 = ($59|0)==(0);
  if ($60) {
   return;
  }
 }
 __ZN3osg8StateSet17runEventCallbacksEPNS_11NodeVisitorE($53,$0);
 return;
}
function __ZN5osgGA12EventVisitor5applyERN3osg4NodeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 120|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 do {
  if (!($4)) {
   $5 = ((($3)) + 152|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($6|0)==(0|0);
   if ($7) {
    $8 = ((($3)) + 156|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = ($9|0)==(0);
    if ($10) {
     break;
    }
   }
   __ZN3osg8StateSet17runEventCallbacksEPNS_11NodeVisitorE($3,$0);
  }
 } while(0);
 $11 = ((($1)) + 92|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0|0);
 if (!($13)) {
  $14 = HEAP32[$12>>2]|0;
  $15 = ((($14)) + 92|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = HEAP32[$0>>2]|0;
  $18 = ((($17)) + -12|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = (($0) + ($19)|0);
  (FUNCTION_TABLE_iiii[$16 & 8191]($12,$1,$20)|0);
  return;
 }
 $21 = ((($1)) + 96|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  return;
 }
 $24 = ((($0)) + 16|0);
 $25 = HEAP32[$24>>2]|0;
 switch ($25|0) {
 case 1:  {
  $26 = HEAP32[$1>>2]|0;
  $27 = ((($26)) + 192|0);
  $28 = HEAP32[$27>>2]|0;
  FUNCTION_TABLE_vii[$28 & 8191]($1,$0);
  return;
  break;
 }
 case 0:  {
  return;
  break;
 }
 default: {
  $29 = HEAP32[$1>>2]|0;
  $30 = ((($29)) + 196|0);
  $31 = HEAP32[$30>>2]|0;
  FUNCTION_TABLE_vii[$31 & 8191]($1,$0);
  return;
 }
 }
}
function __ZN5osgGA12EventVisitor5applyERN3osg5GeodeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 120|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 do {
  if (!($4)) {
   $5 = ((($3)) + 152|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($6|0)==(0|0);
   if ($7) {
    $8 = ((($3)) + 156|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = ($9|0)==(0);
    if ($10) {
     break;
    }
   }
   __ZN3osg8StateSet17runEventCallbacksEPNS_11NodeVisitorE($3,$0);
  }
 } while(0);
 $11 = ((($1)) + 92|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0|0);
 if (!($13)) {
  $14 = HEAP32[$12>>2]|0;
  $15 = ((($14)) + 92|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = HEAP32[$0>>2]|0;
  $18 = ((($17)) + -12|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = (($0) + ($19)|0);
  (FUNCTION_TABLE_iiii[$16 & 8191]($12,$1,$20)|0);
  return;
 }
 $21 = ((($1)) + 96|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  return;
 }
 $24 = ((($0)) + 16|0);
 $25 = HEAP32[$24>>2]|0;
 switch ($25|0) {
 case 1:  {
  $26 = HEAP32[$1>>2]|0;
  $27 = ((($26)) + 192|0);
  $28 = HEAP32[$27>>2]|0;
  FUNCTION_TABLE_vii[$28 & 8191]($1,$0);
  return;
  break;
 }
 case 0:  {
  return;
  break;
 }
 default: {
  $29 = HEAP32[$1>>2]|0;
  $30 = ((($29)) + 196|0);
  $31 = HEAP32[$30>>2]|0;
  FUNCTION_TABLE_vii[$31 & 8191]($1,$0);
  return;
 }
 }
}
function __ZN5osgGA12EventVisitor5applyERN3osg9BillboardE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 120|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 do {
  if (!($4)) {
   $5 = ((($3)) + 152|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($6|0)==(0|0);
   if ($7) {
    $8 = ((($3)) + 156|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = ($9|0)==(0);
    if ($10) {
     break;
    }
   }
   __ZN3osg8StateSet17runEventCallbacksEPNS_11NodeVisitorE($3,$0);
  }
 } while(0);
 $11 = ((($1)) + 92|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0|0);
 if (!($13)) {
  $14 = HEAP32[$12>>2]|0;
  $15 = ((($14)) + 92|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = HEAP32[$0>>2]|0;
  $18 = ((($17)) + -12|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = (($0) + ($19)|0);
  (FUNCTION_TABLE_iiii[$16 & 8191]($12,$1,$20)|0);
  return;
 }
 $21 = ((($1)) + 96|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  return;
 }
 $24 = ((($0)) + 16|0);
 $25 = HEAP32[$24>>2]|0;
 switch ($25|0) {
 case 1:  {
  $26 = HEAP32[$1>>2]|0;
  $27 = ((($26)) + 192|0);
  $28 = HEAP32[$27>>2]|0;
  FUNCTION_TABLE_vii[$28 & 8191]($1,$0);
  return;
  break;
 }
 case 0:  {
  return;
  break;
 }
 default: {
  $29 = HEAP32[$1>>2]|0;
  $30 = ((($29)) + 196|0);
  $31 = HEAP32[$30>>2]|0;
  FUNCTION_TABLE_vii[$31 & 8191]($1,$0);
  return;
 }
 }
}
function __ZN5osgGA12EventVisitor5applyERN3osg5GroupE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 120|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 do {
  if (!($4)) {
   $5 = ((($3)) + 152|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($6|0)==(0|0);
   if ($7) {
    $8 = ((($3)) + 156|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = ($9|0)==(0);
    if ($10) {
     break;
    }
   }
   __ZN3osg8StateSet17runEventCallbacksEPNS_11NodeVisitorE($3,$0);
  }
 } while(0);
 $11 = ((($1)) + 92|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0|0);
 if (!($13)) {
  $14 = HEAP32[$12>>2]|0;
  $15 = ((($14)) + 92|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = HEAP32[$0>>2]|0;
  $18 = ((($17)) + -12|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = (($0) + ($19)|0);
  (FUNCTION_TABLE_iiii[$16 & 8191]($12,$1,$20)|0);
  return;
 }
 $21 = ((($1)) + 96|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  return;
 }
 $24 = ((($0)) + 16|0);
 $25 = HEAP32[$24>>2]|0;
 switch ($25|0) {
 case 1:  {
  $26 = HEAP32[$1>>2]|0;
  $27 = ((($26)) + 192|0);
  $28 = HEAP32[$27>>2]|0;
  FUNCTION_TABLE_vii[$28 & 8191]($1,$0);
  return;
  break;
 }
 case 0:  {
  return;
  break;
 }
 default: {
  $29 = HEAP32[$1>>2]|0;
  $30 = ((($29)) + 196|0);
  $31 = HEAP32[$30>>2]|0;
  FUNCTION_TABLE_vii[$31 & 8191]($1,$0);
  return;
 }
 }
}
function __ZN5osgGA12EventVisitor5applyERN3osg10ProjectionE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 120|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 do {
  if (!($4)) {
   $5 = ((($3)) + 152|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($6|0)==(0|0);
   if ($7) {
    $8 = ((($3)) + 156|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = ($9|0)==(0);
    if ($10) {
     break;
    }
   }
   __ZN3osg8StateSet17runEventCallbacksEPNS_11NodeVisitorE($3,$0);
  }
 } while(0);
 $11 = ((($1)) + 92|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0|0);
 if (!($13)) {
  $14 = HEAP32[$12>>2]|0;
  $15 = ((($14)) + 92|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = HEAP32[$0>>2]|0;
  $18 = ((($17)) + -12|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = (($0) + ($19)|0);
  (FUNCTION_TABLE_iiii[$16 & 8191]($12,$1,$20)|0);
  return;
 }
 $21 = ((($1)) + 96|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  return;
 }
 $24 = ((($0)) + 16|0);
 $25 = HEAP32[$24>>2]|0;
 switch ($25|0) {
 case 1:  {
  $26 = HEAP32[$1>>2]|0;
  $27 = ((($26)) + 192|0);
  $28 = HEAP32[$27>>2]|0;
  FUNCTION_TABLE_vii[$28 & 8191]($1,$0);
  return;
  break;
 }
 case 0:  {
  return;
  break;
 }
 default: {
  $29 = HEAP32[$1>>2]|0;
  $30 = ((($29)) + 196|0);
  $31 = HEAP32[$30>>2]|0;
  FUNCTION_TABLE_vii[$31 & 8191]($1,$0);
  return;
 }
 }
}
function __ZN5osgGA12EventVisitor5applyERN3osg11LightSourceE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 120|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 do {
  if (!($4)) {
   $5 = ((($3)) + 152|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($6|0)==(0|0);
   if ($7) {
    $8 = ((($3)) + 156|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = ($9|0)==(0);
    if ($10) {
     break;
    }
   }
   __ZN3osg8StateSet17runEventCallbacksEPNS_11NodeVisitorE($3,$0);
  }
 } while(0);
 $11 = ((($1)) + 92|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0|0);
 if (!($13)) {
  $14 = HEAP32[$12>>2]|0;
  $15 = ((($14)) + 92|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = HEAP32[$0>>2]|0;
  $18 = ((($17)) + -12|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = (($0) + ($19)|0);
  (FUNCTION_TABLE_iiii[$16 & 8191]($12,$1,$20)|0);
  return;
 }
 $21 = ((($1)) + 96|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  return;
 }
 $24 = ((($0)) + 16|0);
 $25 = HEAP32[$24>>2]|0;
 switch ($25|0) {
 case 1:  {
  $26 = HEAP32[$1>>2]|0;
  $27 = ((($26)) + 192|0);
  $28 = HEAP32[$27>>2]|0;
  FUNCTION_TABLE_vii[$28 & 8191]($1,$0);
  return;
  break;
 }
 case 0:  {
  return;
  break;
 }
 default: {
  $29 = HEAP32[$1>>2]|0;
  $30 = ((($29)) + 196|0);
  $31 = HEAP32[$30>>2]|0;
  FUNCTION_TABLE_vii[$31 & 8191]($1,$0);
  return;
 }
 }
}
function __ZN5osgGA12EventVisitor5applyERN3osg9TransformE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 120|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 do {
  if (!($4)) {
   $5 = ((($3)) + 152|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($6|0)==(0|0);
   if ($7) {
    $8 = ((($3)) + 156|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = ($9|0)==(0);
    if ($10) {
     break;
    }
   }
   __ZN3osg8StateSet17runEventCallbacksEPNS_11NodeVisitorE($3,$0);
  }
 } while(0);
 $11 = ((($1)) + 92|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0|0);
 if (!($13)) {
  $14 = HEAP32[$12>>2]|0;
  $15 = ((($14)) + 92|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = HEAP32[$0>>2]|0;
  $18 = ((($17)) + -12|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = (($0) + ($19)|0);
  (FUNCTION_TABLE_iiii[$16 & 8191]($12,$1,$20)|0);
  return;
 }
 $21 = ((($1)) + 96|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  return;
 }
 $24 = ((($0)) + 16|0);
 $25 = HEAP32[$24>>2]|0;
 switch ($25|0) {
 case 1:  {
  $26 = HEAP32[$1>>2]|0;
  $27 = ((($26)) + 192|0);
  $28 = HEAP32[$27>>2]|0;
  FUNCTION_TABLE_vii[$28 & 8191]($1,$0);
  return;
  break;
 }
 case 0:  {
  return;
  break;
 }
 default: {
  $29 = HEAP32[$1>>2]|0;
  $30 = ((($29)) + 196|0);
  $31 = HEAP32[$30>>2]|0;
  FUNCTION_TABLE_vii[$31 & 8191]($1,$0);
  return;
 }
 }
}
function __ZN5osgGA12EventVisitor5applyERN3osg6SwitchE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 120|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 do {
  if (!($4)) {
   $5 = ((($3)) + 152|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($6|0)==(0|0);
   if ($7) {
    $8 = ((($3)) + 156|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = ($9|0)==(0);
    if ($10) {
     break;
    }
   }
   __ZN3osg8StateSet17runEventCallbacksEPNS_11NodeVisitorE($3,$0);
  }
 } while(0);
 $11 = ((($1)) + 92|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0|0);
 if (!($13)) {
  $14 = HEAP32[$12>>2]|0;
  $15 = ((($14)) + 92|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = HEAP32[$0>>2]|0;
  $18 = ((($17)) + -12|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = (($0) + ($19)|0);
  (FUNCTION_TABLE_iiii[$16 & 8191]($12,$1,$20)|0);
  return;
 }
 $21 = ((($1)) + 96|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  return;
 }
 $24 = ((($0)) + 16|0);
 $25 = HEAP32[$24>>2]|0;
 switch ($25|0) {
 case 1:  {
  $26 = HEAP32[$1>>2]|0;
  $27 = ((($26)) + 192|0);
  $28 = HEAP32[$27>>2]|0;
  FUNCTION_TABLE_vii[$28 & 8191]($1,$0);
  return;
  break;
 }
 case 0:  {
  return;
  break;
 }
 default: {
  $29 = HEAP32[$1>>2]|0;
  $30 = ((($29)) + 196|0);
  $31 = HEAP32[$30>>2]|0;
  FUNCTION_TABLE_vii[$31 & 8191]($1,$0);
  return;
 }
 }
}
function __ZN5osgGA12EventVisitor5applyERN3osg3LODE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 120|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 do {
  if (!($4)) {
   $5 = ((($3)) + 152|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($6|0)==(0|0);
   if ($7) {
    $8 = ((($3)) + 156|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = ($9|0)==(0);
    if ($10) {
     break;
    }
   }
   __ZN3osg8StateSet17runEventCallbacksEPNS_11NodeVisitorE($3,$0);
  }
 } while(0);
 $11 = ((($1)) + 92|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0|0);
 if (!($13)) {
  $14 = HEAP32[$12>>2]|0;
  $15 = ((($14)) + 92|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = HEAP32[$0>>2]|0;
  $18 = ((($17)) + -12|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = (($0) + ($19)|0);
  (FUNCTION_TABLE_iiii[$16 & 8191]($12,$1,$20)|0);
  return;
 }
 $21 = ((($1)) + 96|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  return;
 }
 $24 = ((($0)) + 16|0);
 $25 = HEAP32[$24>>2]|0;
 switch ($25|0) {
 case 1:  {
  $26 = HEAP32[$1>>2]|0;
  $27 = ((($26)) + 192|0);
  $28 = HEAP32[$27>>2]|0;
  FUNCTION_TABLE_vii[$28 & 8191]($1,$0);
  return;
  break;
 }
 case 0:  {
  return;
  break;
 }
 default: {
  $29 = HEAP32[$1>>2]|0;
  $30 = ((($29)) + 196|0);
  $31 = HEAP32[$30>>2]|0;
  FUNCTION_TABLE_vii[$31 & 8191]($1,$0);
  return;
 }
 }
}
function __ZN5osgGA12EventVisitor5applyERN3osg12OccluderNodeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 120|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 do {
  if (!($4)) {
   $5 = ((($3)) + 152|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($6|0)==(0|0);
   if ($7) {
    $8 = ((($3)) + 156|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = ($9|0)==(0);
    if ($10) {
     break;
    }
   }
   __ZN3osg8StateSet17runEventCallbacksEPNS_11NodeVisitorE($3,$0);
  }
 } while(0);
 $11 = ((($1)) + 92|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0|0);
 if (!($13)) {
  $14 = HEAP32[$12>>2]|0;
  $15 = ((($14)) + 92|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = HEAP32[$0>>2]|0;
  $18 = ((($17)) + -12|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = (($0) + ($19)|0);
  (FUNCTION_TABLE_iiii[$16 & 8191]($12,$1,$20)|0);
  return;
 }
 $21 = ((($1)) + 96|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  return;
 }
 $24 = ((($0)) + 16|0);
 $25 = HEAP32[$24>>2]|0;
 switch ($25|0) {
 case 1:  {
  $26 = HEAP32[$1>>2]|0;
  $27 = ((($26)) + 192|0);
  $28 = HEAP32[$27>>2]|0;
  FUNCTION_TABLE_vii[$28 & 8191]($1,$0);
  return;
  break;
 }
 case 0:  {
  return;
  break;
 }
 default: {
  $29 = HEAP32[$1>>2]|0;
  $30 = ((($29)) + 196|0);
  $31 = HEAP32[$30>>2]|0;
  FUNCTION_TABLE_vii[$31 & 8191]($1,$0);
  return;
 }
 }
}
function __ZTv0_n16_N5osgGA12EventVisitorD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __THREW__ = 0;
 invoke_vii(3521,($4|0),(42572|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if (!($6)) {
  $14 = ((($4)) + 80|0);
  __ZN3osg6ObjectD2Ev($14);
  return;
 }
 $7 = ___cxa_find_matching_catch_2()|0;
 $8 = tempRet0;
 $9 = ((($4)) + 80|0);
 __THREW__ = 0;
 invoke_vi(388,($9|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if ($11) {
  $12 = ___cxa_find_matching_catch_3(0|0)|0;
  $13 = tempRet0;
  ___clang_call_terminate($12);
  // unreachable;
 } else {
  ___resumeException($7|0);
  // unreachable;
 }
}
function __ZTv0_n16_N5osgGA12EventVisitorD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$i$index2Z2D = 0, $eh$lpad$body$i$indexZ2D = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __THREW__ = 0;
 invoke_vii(3521,($4|0),(42572|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $10 = ___cxa_find_matching_catch_2()|0;
  $11 = tempRet0;
  $12 = ((($4)) + 80|0);
  __THREW__ = 0;
  invoke_vi(388,($12|0));
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if ($14) {
   $15 = ___cxa_find_matching_catch_3(0|0)|0;
   $16 = tempRet0;
   ___clang_call_terminate($15);
   // unreachable;
  } else {
   $eh$lpad$body$i$index2Z2D = $11;$eh$lpad$body$i$indexZ2D = $10;
   __ZdlPv($4);
   ___resumeException($eh$lpad$body$i$indexZ2D|0);
   // unreachable;
  }
 }
 $7 = ((($4)) + 80|0);
 __THREW__ = 0;
 invoke_vi(388,($7|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if (!($9)) {
  __ZdlPv($4);
  return;
 }
 $17 = ___cxa_find_matching_catch_2()|0;
 $18 = tempRet0;
 $eh$lpad$body$i$index2Z2D = $18;$eh$lpad$body$i$indexZ2D = $17;
 __ZdlPv($4);
 ___resumeException($eh$lpad$body$i$indexZ2D|0);
 // unreachable;
}
function __ZTv0_n32_NK5osgGA12EventVisitor11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (109961|0);
}
function __ZTv0_n36_NK5osgGA12EventVisitor9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (109601|0);
}
function __ZN5osgGA12EventVisitorD2Ev($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$023$i$i = 0, $$cast = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $2;
 $3 = ((($1)) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $$cast = $2;
 $5 = ((($$cast)) + -12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($0) + ($6)|0);
 HEAP32[$7>>2] = $4;
 $8 = ((($0)) + 68|0);
 $9 = ((($0)) + 76|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0);
 L1: do {
  if (!($11)) {
   $12 = ((($0)) + 72|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = HEAP32[$8>>2]|0;
   $15 = ((($14)) + 4|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = HEAP32[$13>>2]|0;
   $18 = ((($17)) + 4|0);
   HEAP32[$18>>2] = $16;
   $19 = HEAP32[$15>>2]|0;
   HEAP32[$19>>2] = $17;
   HEAP32[$9>>2] = 0;
   $20 = ($13|0)==($8|0);
   if (!($20)) {
    $$023$i$i = $13;
    while(1) {
     $21 = ((($$023$i$i)) + 4|0);
     $22 = HEAP32[$21>>2]|0;
     $23 = ((($$023$i$i)) + 8|0);
     $24 = HEAP32[$23>>2]|0;
     $25 = ($24|0)==(0|0);
     if (!($25)) {
      $26 = ((($24)) + 8|0);
      $27 = HEAP32[$26>>2]|0;HEAP32[$26>>2] = (($27-1)|0);
      $28 = ($27|0)==(1);
      if ($28) {
       __THREW__ = 0;
       invoke_viii(3262,($24|0),1,1);
       $29 = __THREW__; __THREW__ = 0;
       $30 = $29&1;
       if ($30) {
        break;
       }
      }
     }
     __ZdlPv($$023$i$i);
     $31 = ($22|0)==($8|0);
     if ($31) {
      break L1;
     } else {
      $$023$i$i = $22;
     }
    }
    $32 = ___cxa_find_matching_catch_2()|0;
    $33 = tempRet0;
    ___cxa_call_unexpected(($32|0));
    // unreachable;
   }
  }
 } while(0);
 $34 = ((($0)) + 60|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = ($35|0)==(0|0);
 if ($36) {
  HEAP32[$34>>2] = 0;
  $42 = ((($1)) + 4|0);
  __ZN3osg11NodeVisitorD2Ev($0,$42);
  return;
 }
 $37 = ((($35)) + 8|0);
 $38 = HEAP32[$37>>2]|0;HEAP32[$37>>2] = (($38-1)|0);
 $39 = ($38|0)==(1);
 if (!($39)) {
  HEAP32[$34>>2] = 0;
  $42 = ((($1)) + 4|0);
  __ZN3osg11NodeVisitorD2Ev($0,$42);
  return;
 }
 __THREW__ = 0;
 invoke_viii(3262,($35|0),1,1);
 $40 = __THREW__; __THREW__ = 0;
 $41 = $40&1;
 if (!($41)) {
  HEAP32[$34>>2] = 0;
  $42 = ((($1)) + 4|0);
  __ZN3osg11NodeVisitorD2Ev($0,$42);
  return;
 }
 $43 = ___cxa_find_matching_catch_2()|0;
 $44 = tempRet0;
 $45 = ((($1)) + 4|0);
 __THREW__ = 0;
 invoke_vii(3284,($0|0),($45|0));
 $46 = __THREW__; __THREW__ = 0;
 $47 = $46&1;
 if ($47) {
  $48 = ___cxa_find_matching_catch_3(0|0)|0;
  $49 = tempRet0;
  ___clang_call_terminate($48);
  // unreachable;
 } else {
  ___resumeException($43|0);
  // unreachable;
 }
}
function __ZN5osgGA12EventVisitorC1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 80|0);
 __ZN3osg10ReferencedC2Ev($1);
 HEAP32[$1>>2] = (63412);
 $2 = ((($0)) + 92|0);
 ;HEAP32[$2>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;
 $3 = ((($0)) + 104|0);
 HEAP32[$3>>2] = 2;
 $4 = ((($0)) + 108|0);
 HEAP32[$4>>2] = 0;
 __THREW__ = 0;
 invoke_viiii(3522,($0|0),((42576)|0),2,3);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if (!($6)) {
  HEAP32[$0>>2] = (42088);
  HEAP32[$1>>2] = (42432);
  $7 = ((($0)) + 56|0);
  HEAP32[$7>>2] = 0;
  $8 = ((($0)) + 60|0);
  HEAP32[$8>>2] = 0;
  $9 = ((($0)) + 64|0);
  HEAP8[$9>>0] = 0;
  $10 = ((($0)) + 68|0);
  HEAP32[$10>>2] = $10;
  $11 = ((($0)) + 72|0);
  HEAP32[$11>>2] = $10;
  $12 = ((($0)) + 76|0);
  HEAP32[$12>>2] = 0;
  return;
 }
 $13 = ___cxa_find_matching_catch_2()|0;
 $14 = tempRet0;
 __THREW__ = 0;
 invoke_vi(388,($1|0));
 $15 = __THREW__; __THREW__ = 0;
 $16 = $15&1;
 if ($16) {
  $17 = ___cxa_find_matching_catch_3(0|0)|0;
  $18 = tempRet0;
  ___clang_call_terminate($17);
  // unreachable;
 } else {
  ___resumeException($13|0);
  // unreachable;
 }
}
function __ZN5osgGA12EventVisitor8addEventEPNS_5EventE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 68|0);
 $3 = ($1|0)==(0|0);
 if (!($3)) {
  $4 = ((($1)) + 8|0);
  $5 = HEAP32[$4>>2]|0;HEAP32[$4>>2] = (($5+1)|0);
 }
 __THREW__ = 0;
 $6 = (invoke_ii(3276,12)|0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $21 = ___cxa_find_matching_catch_2()|0;
  $22 = tempRet0;
  if ($3) {
   ___resumeException($21|0);
   // unreachable;
  }
  $23 = ((($1)) + 8|0);
  $24 = HEAP32[$23>>2]|0;HEAP32[$23>>2] = (($24-1)|0);
  $25 = ($24|0)==(1);
  if (!($25)) {
   ___resumeException($21|0);
   // unreachable;
  }
  __THREW__ = 0;
  invoke_viii(3262,($1|0),1,1);
  $26 = __THREW__; __THREW__ = 0;
  $27 = $26&1;
  if ($27) {
   $28 = ___cxa_find_matching_catch_3(0|0)|0;
   $29 = tempRet0;
   ___clang_call_terminate($28);
   // unreachable;
  } else {
   ___resumeException($21|0);
   // unreachable;
  }
 }
 $9 = ((($6)) + 8|0);
 HEAP32[$9>>2] = $1;
 if (!($3)) {
  $10 = ((($1)) + 8|0);
  $11 = HEAP32[$10>>2]|0;HEAP32[$10>>2] = (($11+1)|0);
 }
 $12 = ((($6)) + 4|0);
 HEAP32[$12>>2] = $2;
 $13 = HEAP32[$2>>2]|0;
 HEAP32[$6>>2] = $13;
 $14 = ((($13)) + 4|0);
 HEAP32[$14>>2] = $6;
 HEAP32[$2>>2] = $6;
 $15 = ((($0)) + 76|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + 1)|0;
 HEAP32[$15>>2] = $17;
 if ($3) {
  return;
 }
 $18 = ((($1)) + 8|0);
 $19 = HEAP32[$18>>2]|0;HEAP32[$18>>2] = (($19-1)|0);
 $20 = ($19|0)==(1);
 if (!($20)) {
  return;
 }
 __ZNK3osg10Referenced24signalObserversAndDeleteEbb($1,1,1);
 return;
}
function __ZN5osgGA15GUIEventAdapterD2Ev($0) {
 $0 = $0|0;
 var $$1 = 0, $$13 = 0, $$pre$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (42596);
 $1 = ((($0)) + 160|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = ((($0)) + 164|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==($2|0);
  do {
   if ($6) {
    $20 = $2;
   } else {
    $8 = $5;
    while(1) {
     $7 = ((($8)) + -4|0);
     HEAP32[$4>>2] = $7;
     $9 = HEAP32[$7>>2]|0;
     $10 = ($9|0)==(0|0);
     if (!($10)) {
      $11 = ((($9)) + 8|0);
      $12 = HEAP32[$11>>2]|0;HEAP32[$11>>2] = (($12-1)|0);
      $13 = ($12|0)==(1);
      if ($13) {
       __THREW__ = 0;
       invoke_viii(3262,($9|0),1,1);
       $14 = __THREW__; __THREW__ = 0;
       $15 = $14&1;
       if ($15) {
        label = 7;
        break;
       }
      }
     }
     HEAP32[$7>>2] = 0;
     $16 = HEAP32[$4>>2]|0;
     $17 = ($16|0)==($2|0);
     if ($17) {
      label = 8;
      break;
     } else {
      $8 = $16;
     }
    }
    if ((label|0) == 7) {
     $18 = ___cxa_find_matching_catch_2()|0;
     $19 = tempRet0;
     ___cxa_call_unexpected(($18|0));
     // unreachable;
    }
    else if ((label|0) == 8) {
     $$pre$i = HEAP32[$1>>2]|0;
     $20 = $$pre$i;
     break;
    }
   }
  } while(0);
  __ZdlPv($20);
 }
 $21 = ((($0)) + 156|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0|0);
 if ($23) {
  label = 13;
 } else {
  $24 = ((($22)) + 8|0);
  $25 = HEAP32[$24>>2]|0;HEAP32[$24>>2] = (($25-1)|0);
  $26 = ($25|0)==(1);
  if ($26) {
   __THREW__ = 0;
   invoke_viii(3262,($22|0),1,1);
   $27 = __THREW__; __THREW__ = 0;
   $28 = $27&1;
   if ($28) {
    $39 = ___cxa_find_matching_catch_2()|0;
    $40 = tempRet0;
    $41 = ((($0)) + 52|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = ($42|0)==(0|0);
    if (!($43)) {
     $44 = ((($42)) + 8|0);
     $45 = HEAP32[$44>>2]|0;HEAP32[$44>>2] = (($45-1)|0);
     $46 = ($45|0)==(1);
     if ($46) {
      __THREW__ = 0;
      invoke_viii(3262,($42|0),1,1);
      $47 = __THREW__; __THREW__ = 0;
      $48 = $47&1;
      if ($48) {
       $51 = ___cxa_find_matching_catch_3(0|0)|0;
       $52 = tempRet0;
       ___clang_call_terminate($51);
       // unreachable;
      }
     }
    }
    HEAP32[$41>>2] = 0;
    $$1 = $40;$$13 = $39;
   } else {
    label = 13;
   }
  } else {
   label = 13;
  }
 }
 do {
  if ((label|0) == 13) {
   HEAP32[$21>>2] = 0;
   $29 = ((($0)) + 52|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = ($30|0)==(0|0);
   if ($31) {
    HEAP32[$29>>2] = 0;
    __ZN3osg6ObjectD2Ev($0);
    return;
   }
   $32 = ((($30)) + 8|0);
   $33 = HEAP32[$32>>2]|0;HEAP32[$32>>2] = (($33-1)|0);
   $34 = ($33|0)==(1);
   if (!($34)) {
    HEAP32[$29>>2] = 0;
    __ZN3osg6ObjectD2Ev($0);
    return;
   }
   __THREW__ = 0;
   invoke_viii(3262,($30|0),1,1);
   $35 = __THREW__; __THREW__ = 0;
   $36 = $35&1;
   if ($36) {
    $37 = ___cxa_find_matching_catch_2()|0;
    $38 = tempRet0;
    $$1 = $38;$$13 = $37;
    break;
   } else {
    HEAP32[$29>>2] = 0;
    __ZN3osg6ObjectD2Ev($0);
    return;
   }
  }
 } while(0);
 __THREW__ = 0;
 invoke_vi(388,($0|0));
 $49 = __THREW__; __THREW__ = 0;
 $50 = $49&1;
 if ($50) {
  $51 = ___cxa_find_matching_catch_3(0|0)|0;
  $52 = tempRet0;
  ___clang_call_terminate($51);
  // unreachable;
 } else {
  ___resumeException($$13|0);
  // unreachable;
 }
}
function __ZN5osgGA15GUIEventAdapterD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(754,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK5osgGA15GUIEventAdapter9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0;
 var sp = 0, stop = 0;
 sp = STACKTOP;
 $1 = (__Znwj(176)|0);
 __THREW__ = 0;
 invoke_vi(3523,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $17 = ___cxa_find_matching_catch_2()|0;
  $18 = tempRet0;
  __ZdlPv($1);
  ___resumeException($17|0);
  // unreachable;
 } else {
  HEAP32[$1>>2] = (42596);
  $4 = ((($1)) + 48|0);
  $5 = ((($1)) + 68|0);
  ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;HEAP32[$4+12>>2]=0|0;HEAP32[$4+16>>2]=0|0;
  HEAP32[$5>>2] = 1280;
  $6 = ((($1)) + 72|0);
  HEAP32[$6>>2] = 1024;
  $7 = ((($1)) + 76|0);
  HEAP32[$7>>2] = 0;
  $8 = ((($1)) + 80|0);
  HEAP32[$8>>2] = 0;
  $9 = ((($1)) + 84|0);
  HEAP32[$9>>2] = 0;
  $10 = ((($1)) + 88|0);
  HEAPF32[$10>>2] = -1.0;
  $11 = ((($1)) + 92|0);
  HEAPF32[$11>>2] = 1.0;
  $12 = ((($1)) + 96|0);
  HEAPF32[$12>>2] = -1.0;
  $13 = ((($1)) + 100|0);
  HEAPF32[$13>>2] = 1.0;
  $14 = ((($1)) + 104|0);
  $15 = ((($1)) + 120|0);
  ;HEAP32[$14>>2]=0|0;HEAP32[$14+4>>2]=0|0;HEAP32[$14+8>>2]=0|0;HEAP32[$14+12>>2]=0|0;
  HEAP32[$15>>2] = 1;
  $16 = ((($1)) + 124|0);
  dest=$16; stop=dest+48|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
  return ($1|0);
 }
 return (0)|0;
}
function __ZNK5osgGA15GUIEventAdapter5cloneERKN3osg6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(176)|0);
 __THREW__ = 0;
 invoke_viii(3520,($2|0),($0|0),($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch_2()|0;
  $6 = tempRet0;
  __ZdlPv($2);
  ___resumeException($5|0);
  // unreachable;
 } else {
  return ($2|0);
 }
 return (0)|0;
}
function __ZNK5osgGA15GUIEventAdapter12isSameKindAsEPKN3osg6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,8944,0)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK5osgGA15GUIEventAdapter11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (109961|0);
}
function __ZNK5osgGA15GUIEventAdapter9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (109637|0);
}
function __ZN5osgGA15GUIEventAdapter17asGUIEventAdapterEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ($0|0);
}
function __ZNK5osgGA15GUIEventAdapter17asGUIEventAdapterEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ($0|0);
}
function __ZNK5osgGA15GUIEventAdapter12getEventTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 48|0);
 $2 = HEAP32[$1>>2]|0;
 return ($2|0);
}
function __ZNK5osgGA15GUIEventAdapter6getKeyEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 76|0);
 $2 = HEAP32[$1>>2]|0;
 return ($2|0);
}
function __ZN5osgGA15GUIEventAdapterC2ERKS0_RKN3osg6CopyOpE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$pre$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0;
 var $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0;
 var $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5osgGA5EventC2ERKS0_RKN3osg6CopyOpE($0,$1,$2);
 HEAP32[$0>>2] = (42596);
 $3 = ((($0)) + 48|0);
 $4 = ((($1)) + 48|0);
 $5 = HEAP32[$4>>2]|0;
 HEAP32[$3>>2] = $5;
 $6 = ((($0)) + 52|0);
 $7 = ((($1)) + 52|0);
 $8 = HEAP32[$7>>2]|0;
 HEAP32[$6>>2] = $8;
 $9 = ($8|0)==(0|0);
 if (!($9)) {
  $10 = ((($8)) + 8|0);
  $11 = HEAP32[$10>>2]|0;HEAP32[$10>>2] = (($11+1)|0);
 }
 $12 = ((($0)) + 56|0);
 $13 = ((($1)) + 56|0);
 $14 = HEAP32[$13>>2]|0;
 HEAP32[$12>>2] = $14;
 $15 = ((($0)) + 60|0);
 $16 = ((($1)) + 60|0);
 $17 = HEAP32[$16>>2]|0;
 HEAP32[$15>>2] = $17;
 $18 = ((($0)) + 64|0);
 $19 = ((($1)) + 64|0);
 $20 = HEAP32[$19>>2]|0;
 HEAP32[$18>>2] = $20;
 $21 = ((($0)) + 68|0);
 $22 = ((($1)) + 68|0);
 $23 = HEAP32[$22>>2]|0;
 HEAP32[$21>>2] = $23;
 $24 = ((($0)) + 72|0);
 $25 = ((($1)) + 72|0);
 $26 = HEAP32[$25>>2]|0;
 HEAP32[$24>>2] = $26;
 $27 = ((($0)) + 76|0);
 $28 = ((($1)) + 76|0);
 $29 = HEAP32[$28>>2]|0;
 HEAP32[$27>>2] = $29;
 $30 = ((($0)) + 80|0);
 $31 = ((($1)) + 80|0);
 $32 = HEAP32[$31>>2]|0;
 HEAP32[$30>>2] = $32;
 $33 = ((($0)) + 84|0);
 $34 = ((($1)) + 84|0);
 $35 = HEAP32[$34>>2]|0;
 HEAP32[$33>>2] = $35;
 $36 = ((($0)) + 88|0);
 $37 = ((($1)) + 88|0);
 $38 = HEAP32[$37>>2]|0;
 HEAP32[$36>>2] = $38;
 $39 = ((($0)) + 92|0);
 $40 = ((($1)) + 92|0);
 $41 = HEAP32[$40>>2]|0;
 HEAP32[$39>>2] = $41;
 $42 = ((($0)) + 96|0);
 $43 = ((($1)) + 96|0);
 $44 = HEAP32[$43>>2]|0;
 HEAP32[$42>>2] = $44;
 $45 = ((($0)) + 100|0);
 $46 = ((($1)) + 100|0);
 $47 = HEAP32[$46>>2]|0;
 HEAP32[$45>>2] = $47;
 $48 = ((($0)) + 104|0);
 $49 = ((($1)) + 104|0);
 $50 = HEAP32[$49>>2]|0;
 HEAP32[$48>>2] = $50;
 $51 = ((($0)) + 108|0);
 $52 = ((($1)) + 108|0);
 $53 = HEAP32[$52>>2]|0;
 HEAP32[$51>>2] = $53;
 $54 = ((($0)) + 112|0);
 $55 = ((($1)) + 112|0);
 $56 = HEAP32[$55>>2]|0;
 HEAP32[$54>>2] = $56;
 $57 = ((($0)) + 116|0);
 $58 = ((($1)) + 116|0);
 $59 = HEAP32[$58>>2]|0;
 HEAP32[$57>>2] = $59;
 $60 = ((($0)) + 120|0);
 $61 = ((($1)) + 120|0);
 $62 = HEAP32[$61>>2]|0;
 HEAP32[$60>>2] = $62;
 $63 = ((($0)) + 124|0);
 $64 = ((($1)) + 124|0);
 $65 = HEAP32[$64>>2]|0;
 HEAP32[$63>>2] = $65;
 $66 = ((($0)) + 128|0);
 $67 = ((($1)) + 128|0);
 $68 = HEAP32[$67>>2]|0;
 HEAP32[$66>>2] = $68;
 $69 = ((($0)) + 132|0);
 $70 = ((($1)) + 132|0);
 $71 = HEAP32[$70>>2]|0;
 HEAP32[$69>>2] = $71;
 $72 = ((($0)) + 136|0);
 $73 = ((($1)) + 136|0);
 $74 = HEAP32[$73>>2]|0;
 HEAP32[$72>>2] = $74;
 $75 = ((($0)) + 140|0);
 $76 = ((($1)) + 140|0);
 $77 = HEAP32[$76>>2]|0;
 HEAP32[$75>>2] = $77;
 $78 = ((($0)) + 144|0);
 $79 = ((($1)) + 144|0);
 $80 = HEAP32[$79>>2]|0;
 HEAP32[$78>>2] = $80;
 $81 = ((($0)) + 148|0);
 $82 = ((($1)) + 148|0);
 $83 = HEAP32[$82>>2]|0;
 HEAP32[$81>>2] = $83;
 $84 = ((($0)) + 152|0);
 $85 = ((($1)) + 152|0);
 $86 = HEAP32[$85>>2]|0;
 HEAP32[$84>>2] = $86;
 $87 = ((($0)) + 156|0);
 $88 = ((($0)) + 160|0);
 $89 = ((($0)) + 164|0);
 $90 = ((($1)) + 156|0);
 ;HEAP32[$87>>2]=0|0;HEAP32[$87+4>>2]=0|0;HEAP32[$87+8>>2]=0|0;HEAP32[$87+12>>2]=0|0;
 $91 = HEAP32[$90>>2]|0;
 $92 = ($91|0)==(0|0);
 if ($92) {
  return;
 }
 __THREW__ = 0;
 $93 = (invoke_iii(3524,($91|0),($2|0))|0);
 $94 = __THREW__; __THREW__ = 0;
 $95 = $94&1;
 if (!($95)) {
  $96 = HEAP32[$87>>2]|0;
  $97 = ($96|0)==($93|0);
  if ($97) {
   return;
  }
  HEAP32[$87>>2] = $93;
  $98 = ($93|0)==(0|0);
  if (!($98)) {
   $99 = ((($93)) + 8|0);
   $100 = HEAP32[$99>>2]|0;HEAP32[$99>>2] = (($100+1)|0);
  }
  $101 = ($96|0)==(0|0);
  if ($101) {
   return;
  }
  $102 = ((($96)) + 8|0);
  $103 = HEAP32[$102>>2]|0;HEAP32[$102>>2] = (($103-1)|0);
  $104 = ($103|0)==(1);
  if (!($104)) {
   return;
  }
  __THREW__ = 0;
  invoke_viii(3262,($96|0),1,1);
  $105 = __THREW__; __THREW__ = 0;
  $106 = $105&1;
  if (!($106)) {
   return;
  }
 }
 $107 = ___cxa_find_matching_catch_2()|0;
 $108 = tempRet0;
 $109 = HEAP32[$88>>2]|0;
 $110 = ($109|0)==(0|0);
 if (!($110)) {
  $111 = HEAP32[$89>>2]|0;
  $112 = ($111|0)==($109|0);
  do {
   if ($112) {
    $126 = $109;
   } else {
    $114 = $111;
    while(1) {
     $113 = ((($114)) + -4|0);
     HEAP32[$89>>2] = $113;
     $115 = HEAP32[$113>>2]|0;
     $116 = ($115|0)==(0|0);
     if (!($116)) {
      $117 = ((($115)) + 8|0);
      $118 = HEAP32[$117>>2]|0;HEAP32[$117>>2] = (($118-1)|0);
      $119 = ($118|0)==(1);
      if ($119) {
       __THREW__ = 0;
       invoke_viii(3262,($115|0),1,1);
       $120 = __THREW__; __THREW__ = 0;
       $121 = $120&1;
       if ($121) {
        label = 18;
        break;
       }
      }
     }
     HEAP32[$113>>2] = 0;
     $122 = HEAP32[$89>>2]|0;
     $123 = ($122|0)==($109|0);
     if ($123) {
      label = 19;
      break;
     } else {
      $114 = $122;
     }
    }
    if ((label|0) == 18) {
     $124 = ___cxa_find_matching_catch_2()|0;
     $125 = tempRet0;
     ___cxa_call_unexpected(($124|0));
     // unreachable;
    }
    else if ((label|0) == 19) {
     $$pre$i = HEAP32[$88>>2]|0;
     $126 = $$pre$i;
     break;
    }
   }
  } while(0);
  __ZdlPv($126);
 }
 $127 = HEAP32[$87>>2]|0;
 $128 = ($127|0)==(0|0);
 if (!($128)) {
  $129 = ((($127)) + 8|0);
  $130 = HEAP32[$129>>2]|0;HEAP32[$129>>2] = (($130-1)|0);
  $131 = ($130|0)==(1);
  if ($131) {
   __THREW__ = 0;
   invoke_viii(3262,($127|0),1,1);
   $132 = __THREW__; __THREW__ = 0;
   $133 = $132&1;
   if ($133) {
    $143 = ___cxa_find_matching_catch_3(0|0)|0;
    $144 = tempRet0;
    ___clang_call_terminate($143);
    // unreachable;
   }
  }
 }
 HEAP32[$87>>2] = 0;
 $134 = HEAP32[$6>>2]|0;
 $135 = ($134|0)==(0|0);
 if (!($135)) {
  $136 = ((($134)) + 8|0);
  $137 = HEAP32[$136>>2]|0;HEAP32[$136>>2] = (($137-1)|0);
  $138 = ($137|0)==(1);
  if ($138) {
   __THREW__ = 0;
   invoke_viii(3262,($134|0),1,1);
   $139 = __THREW__; __THREW__ = 0;
   $140 = $139&1;
   if ($140) {
    $143 = ___cxa_find_matching_catch_3(0|0)|0;
    $144 = tempRet0;
    ___clang_call_terminate($143);
    // unreachable;
   }
  }
 }
 HEAP32[$6>>2] = 0;
 __THREW__ = 0;
 invoke_vi(388,($0|0));
 $141 = __THREW__; __THREW__ = 0;
 $142 = $141&1;
 if ($142) {
  $143 = ___cxa_find_matching_catch_3(0|0)|0;
  $144 = tempRet0;
  ___clang_call_terminate($143);
  // unreachable;
 } else {
  ___resumeException($107|0);
  // unreachable;
 }
}
function __ZN3osg5cloneIN5osgGA15GUIEventAdapter9TouchDataEEEPT_PKS4_RKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp + 4|0;
 $3 = sp;
 $4 = ($0|0)==(0|0);
 if ($4) {
  $62 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
  if (!($62)) {
   $$1 = 0;
   STACKTOP = sp;return ($$1|0);
  }
  $63 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
  $64 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($63,166509,88)|0);
  $65 = HEAP32[$64>>2]|0;
  $66 = ((($65)) + -12|0);
  $67 = HEAP32[$66>>2]|0;
  $68 = (($64) + ($67)|0);
  __ZNKSt3__28ios_base6getlocEv($3,$68);
  __THREW__ = 0;
  $69 = (invoke_iii(3255,($3|0),(215188|0))|0);
  $70 = __THREW__; __THREW__ = 0;
  $71 = $70&1;
  if (!($71)) {
   $72 = HEAP32[$69>>2]|0;
   $73 = ((($72)) + 28|0);
   $74 = HEAP32[$73>>2]|0;
   __THREW__ = 0;
   $75 = (invoke_iii($74|0,($69|0),10)|0);
   $76 = __THREW__; __THREW__ = 0;
   $77 = $76&1;
   if (!($77)) {
    __ZNSt3__26localeD2Ev($3);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($64,$75)|0);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($64)|0);
    $$1 = 0;
    STACKTOP = sp;return ($$1|0);
   }
  }
  $78 = ___cxa_find_matching_catch_2()|0;
  $79 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3263,($3|0));
  $80 = __THREW__; __THREW__ = 0;
  $81 = $80&1;
  if ($81) {
   $82 = ___cxa_find_matching_catch_3(0|0)|0;
   $83 = tempRet0;
   ___clang_call_terminate($82);
   // unreachable;
  } else {
   ___resumeException($78|0);
   // unreachable;
  }
 }
 $5 = HEAP32[$0>>2]|0;
 $6 = ((($5)) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_iii[$7 & 8191]($0,$1)|0);
 $9 = ($8|0)==(0|0);
 if ($9) {
  label = 9;
 } else {
  $10 = ((($8)) + 8|0);
  $11 = HEAP32[$10>>2]|0;HEAP32[$10>>2] = (($11+1)|0);
  $12 = (___dynamic_cast($8,26112,8960,0)|0);
  $13 = ($12|0)==(0|0);
  if ($13) {
   label = 9;
  } else {
   __THREW__ = 0;
   (invoke_ii(3335,($8|0))|0);
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if ($15) {
    label = 5;
   } else {
    $$1 = $12;
    STACKTOP = sp;return ($$1|0);
   }
  }
 }
 L19: do {
  if ((label|0) == 9) {
   __THREW__ = 0;
   $23 = (invoke_ii(3265,2)|0);
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   if ($25) {
    label = 5;
   } else {
    do {
     if ($23) {
      __THREW__ = 0;
      $26 = (invoke_ii(3266,2)|0);
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       label = 5;
       break L19;
      }
      __THREW__ = 0;
      $29 = (invoke_iiii(3267,($26|0),(166420|0),88)|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 5;
       break L19;
      }
      $32 = HEAP32[$29>>2]|0;
      $33 = ((($32)) + -12|0);
      $34 = HEAP32[$33>>2]|0;
      $35 = (($29) + ($34)|0);
      __THREW__ = 0;
      invoke_vii(3257,($2|0),($35|0));
      $36 = __THREW__; __THREW__ = 0;
      $37 = $36&1;
      if ($37) {
       label = 5;
       break L19;
      }
      __THREW__ = 0;
      $38 = (invoke_iii(3255,($2|0),(215188|0))|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       $41 = HEAP32[$38>>2]|0;
       $42 = ((($41)) + 28|0);
       $43 = HEAP32[$42>>2]|0;
       __THREW__ = 0;
       $44 = (invoke_iii($43|0,($38|0),10)|0);
       $45 = __THREW__; __THREW__ = 0;
       $46 = $45&1;
       if (!($46)) {
        __THREW__ = 0;
        invoke_vi(3263,($2|0));
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 5;
         break L19;
        }
        __THREW__ = 0;
        (invoke_iii(3268,($29|0),($44|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 5;
         break L19;
        }
        __THREW__ = 0;
        (invoke_ii(3269,($29|0))|0);
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 5;
         break L19;
        } else {
         break;
        }
       }
      }
      $49 = ___cxa_find_matching_catch_2()|0;
      $50 = tempRet0;
      __THREW__ = 0;
      invoke_vi(3263,($2|0));
      $51 = __THREW__; __THREW__ = 0;
      $52 = $51&1;
      if ($52) {
       $53 = ___cxa_find_matching_catch_3(0|0)|0;
       $54 = tempRet0;
       ___clang_call_terminate($53);
       // unreachable;
      } else {
       $eh$lpad$body$index2Z2D = $50;$eh$lpad$body$indexZ2D = $49;
       break L19;
      }
     }
    } while(0);
    if ($9) {
     $$1 = 0;
     STACKTOP = sp;return ($$1|0);
    }
    $59 = ((($8)) + 8|0);
    $60 = HEAP32[$59>>2]|0;HEAP32[$59>>2] = (($60-1)|0);
    $61 = ($60|0)==(1);
    if (!($61)) {
     $$1 = 0;
     STACKTOP = sp;return ($$1|0);
    }
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($8,1,1);
    $$1 = 0;
    STACKTOP = sp;return ($$1|0);
   }
  }
 } while(0);
 if ((label|0) == 5) {
  $16 = ___cxa_find_matching_catch_2()|0;
  $17 = tempRet0;
  $eh$lpad$body$index2Z2D = $17;$eh$lpad$body$indexZ2D = $16;
 }
 if ($9) {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 $18 = ((($8)) + 8|0);
 $19 = HEAP32[$18>>2]|0;HEAP32[$18>>2] = (($19-1)|0);
 $20 = ($19|0)==(1);
 if (!($20)) {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(3262,($8|0),1,1);
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if ($22) {
  $84 = ___cxa_find_matching_catch_3(0|0)|0;
  $85 = tempRet0;
  ___clang_call_terminate($84);
  // unreachable;
 } else {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 return (0)|0;
}
function __ZN5osgGA15GUIEventAdapterC2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 __ZN5osgGA5EventC2Ev($0);
 HEAP32[$0>>2] = (42596);
 $1 = ((($0)) + 48|0);
 $2 = ((($0)) + 68|0);
 ;HEAP32[$1>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;HEAP32[$1+12>>2]=0|0;HEAP32[$1+16>>2]=0|0;
 HEAP32[$2>>2] = 1280;
 $3 = ((($0)) + 72|0);
 HEAP32[$3>>2] = 1024;
 $4 = ((($0)) + 76|0);
 HEAP32[$4>>2] = 0;
 $5 = ((($0)) + 80|0);
 HEAP32[$5>>2] = 0;
 $6 = ((($0)) + 84|0);
 HEAP32[$6>>2] = 0;
 $7 = ((($0)) + 88|0);
 HEAPF32[$7>>2] = -1.0;
 $8 = ((($0)) + 92|0);
 HEAPF32[$8>>2] = 1.0;
 $9 = ((($0)) + 96|0);
 HEAPF32[$9>>2] = -1.0;
 $10 = ((($0)) + 100|0);
 HEAPF32[$10>>2] = 1.0;
 $11 = ((($0)) + 104|0);
 $12 = ((($0)) + 120|0);
 ;HEAP32[$11>>2]=0|0;HEAP32[$11+4>>2]=0|0;HEAP32[$11+8>>2]=0|0;HEAP32[$11+12>>2]=0|0;
 HEAP32[$12>>2] = 1;
 $13 = ((($0)) + 124|0);
 dest=$13; stop=dest+48|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 return;
}
function __ZN5osgGA15GUIEventAdapter18setWindowRectangleEiiiib($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0.0, $15 = 0.0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $6 = ((($0)) + 60|0);
 HEAP32[$6>>2] = $1;
 $7 = ((($0)) + 64|0);
 HEAP32[$7>>2] = $2;
 $8 = ((($0)) + 68|0);
 HEAP32[$8>>2] = $3;
 $9 = ((($0)) + 72|0);
 HEAP32[$9>>2] = $4;
 if (!($5)) {
  return;
 }
 $10 = ((($0)) + 100|0);
 $11 = ((($0)) + 92|0);
 $12 = ((($0)) + 96|0);
 $13 = ((($0)) + 88|0);
 $14 = (+($4|0));
 $15 = (+($3|0));
 HEAPF32[$13>>2] = 0.0;
 HEAPF32[$12>>2] = 0.0;
 HEAPF32[$11>>2] = $15;
 HEAPF32[$10>>2] = $14;
 return;
}
function __ZN5osgGA15GUIEventAdapter19copyPointerDataFromERKS0_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$$i$i = 0, $$pr$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 52|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $15 = 0;$28 = 0;
 } else {
  $5 = ((($3)) + 24|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==(0|0);
  if ($7) {
   $15 = 0;$28 = 0;
  } else {
   $8 = ((($1)) + 56|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = ($9|0)==(0|0);
   if ($10) {
    $15 = 0;$28 = 0;
   } else {
    $11 = (__ZNK3osg10Referenced22getOrCreateObserverSetEv($9)|0);
    $15 = $11;$28 = $9;
   }
  }
 }
 $12 = ((($0)) + 52|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==($15|0);
 if ($14) {
  $23 = $15;
 } else {
  HEAP32[$12>>2] = $15;
  $16 = ($15|0)==(0|0);
  if (!($16)) {
   $17 = ((($15)) + 8|0);
   $18 = HEAP32[$17>>2]|0;HEAP32[$17>>2] = (($18+1)|0);
  }
  $19 = ($13|0)==(0|0);
  if (!($19)) {
   $20 = ((($13)) + 8|0);
   $21 = HEAP32[$20>>2]|0;HEAP32[$20>>2] = (($21-1)|0);
   $22 = ($21|0)==(1);
   if ($22) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($13,1,1);
   }
  }
  $$pr$i$i = HEAP32[$12>>2]|0;
  $23 = $$pr$i$i;
 }
 $24 = ($23|0)==(0|0);
 if ($24) {
  $30 = 0;
 } else {
  $25 = ((($23)) + 24|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = ($26|0)!=(0|0);
  $$$i$i = $27 ? $28 : 0;
  $30 = $$$i$i;
 }
 $29 = ((($0)) + 56|0);
 HEAP32[$29>>2] = $30;
 $31 = ((($1)) + 104|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = ((($0)) + 104|0);
 HEAP32[$33>>2] = $32;
 $34 = ((($1)) + 108|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = ((($0)) + 108|0);
 HEAP32[$36>>2] = $35;
 $37 = ((($1)) + 88|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = ((($1)) + 96|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ((($1)) + 92|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ((($1)) + 100|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = ((($0)) + 88|0);
 HEAP32[$45>>2] = $38;
 $46 = ((($0)) + 96|0);
 HEAP32[$46>>2] = $40;
 $47 = ((($0)) + 92|0);
 HEAP32[$47>>2] = $42;
 $48 = ((($0)) + 100|0);
 HEAP32[$48>>2] = $44;
 $49 = ((($1)) + 112|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = ((($0)) + 112|0);
 HEAP32[$51>>2] = $50;
 $52 = ((($1)) + 120|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = ((($0)) + 120|0);
 HEAP32[$54>>2] = $53;
 $55 = ($0|0)==($1|0);
 if ($55) {
  return;
 }
 $56 = ((($0)) + 160|0);
 $57 = ((($1)) + 160|0);
 $58 = HEAP32[$57>>2]|0;
 $59 = ((($1)) + 164|0);
 $60 = HEAP32[$59>>2]|0;
 __ZNSt3__26vectorIN3osg7ref_ptrIN5osgGA11PointerDataEEENS_9allocatorIS5_EEE6assignIPS5_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS5_NS_15iterator_traitsISC_E9referenceEEE5valueEvE4typeESC_SC_($56,$58,$60);
 return;
}
function __ZNSt3__26vectorIN3osg7ref_ptrIN5osgGA11PointerDataEEENS_9allocatorIS5_EEE6assignIPS5_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS5_NS_15iterator_traitsISC_E9referenceEEE5valueEvE4typeESC_SC_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$ = 0, $$0$lcssa$i$i = 0, $$07$i$i = 0, $$07$i$i21 = 0, $$078$i$i = 0, $$09$i$i = 0, $$pre$i = 0, $$pre$i$i19 = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = $2;
 $4 = $1;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 $7 = ((($0)) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$0>>2]|0;
 $10 = (($8) - ($9))|0;
 $11 = $10 >> 2;
 $12 = ($6>>>0)>($11>>>0);
 $13 = $9;
 if ($12) {
  $59 = ($9|0)==(0);
  if ($59) {
   $80 = $8;
  } else {
   $60 = $9;
   $61 = ((($0)) + 4|0);
   $62 = HEAP32[$61>>2]|0;
   $63 = ($62|0)==($13|0);
   do {
    if ($63) {
     $77 = $60;
    } else {
     $65 = $62;
     while(1) {
      $64 = ((($65)) + -4|0);
      HEAP32[$61>>2] = $64;
      $66 = HEAP32[$64>>2]|0;
      $67 = ($66|0)==(0|0);
      if (!($67)) {
       $68 = ((($66)) + 8|0);
       $69 = HEAP32[$68>>2]|0;HEAP32[$68>>2] = (($69-1)|0);
       $70 = ($69|0)==(1);
       if ($70) {
        __THREW__ = 0;
        invoke_viii(3262,($66|0),1,1);
        $71 = __THREW__; __THREW__ = 0;
        $72 = $71&1;
        if ($72) {
         label = 28;
         break;
        }
       }
      }
      HEAP32[$64>>2] = 0;
      $73 = HEAP32[$61>>2]|0;
      $74 = ($73|0)==($13|0);
      if ($74) {
       label = 29;
       break;
      } else {
       $65 = $73;
      }
     }
     if ((label|0) == 28) {
      $75 = ___cxa_find_matching_catch_2()|0;
      $76 = tempRet0;
      ___cxa_call_unexpected(($75|0));
      // unreachable;
     }
     else if ((label|0) == 29) {
      $$pre$i = HEAP32[$0>>2]|0;
      $77 = $$pre$i;
      break;
     }
    }
   } while(0);
   __ZdlPv($77);
   HEAP32[$7>>2] = 0;
   HEAP32[$61>>2] = 0;
   HEAP32[$0>>2] = 0;
   $80 = 0;
  }
  $78 = ($6>>>0)>(1073741823);
  if ($78) {
   __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
   // unreachable;
  }
  $79 = $80 >> 2;
  $81 = ($79>>>0)<(536870911);
  $82 = $80 >> 1;
  $83 = ($82>>>0)<($6>>>0);
  $$sroa$speculated$i = $83 ? $6 : $82;
  $$sroa$speculated$$i = $81 ? $$sroa$speculated$i : 1073741823;
  $84 = ($$sroa$speculated$$i>>>0)>(1073741823);
  if ($84) {
   __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
   // unreachable;
  }
  $85 = $$sroa$speculated$$i << 2;
  $86 = (__Znwj($85)|0);
  $87 = ((($0)) + 4|0);
  HEAP32[$87>>2] = $86;
  HEAP32[$0>>2] = $86;
  $88 = (($86) + ($$sroa$speculated$$i<<2)|0);
  HEAP32[$7>>2] = $88;
  $89 = ($1|0)==($2|0);
  if ($89) {
   return;
  }
  $$07$i$i = $1;$91 = $86;
  while(1) {
   $90 = HEAP32[$$07$i$i>>2]|0;
   HEAP32[$91>>2] = $90;
   $92 = ($90|0)==(0|0);
   if (!($92)) {
    $93 = ((($90)) + 8|0);
    $94 = HEAP32[$93>>2]|0;HEAP32[$93>>2] = (($94+1)|0);
   }
   $95 = ((($$07$i$i)) + 4|0);
   $96 = HEAP32[$87>>2]|0;
   $97 = ((($96)) + 4|0);
   HEAP32[$87>>2] = $97;
   $98 = ($95|0)==($2|0);
   if ($98) {
    break;
   } else {
    $$07$i$i = $95;$91 = $97;
   }
  }
  return;
 }
 $14 = ((($0)) + 4|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($15) - ($9))|0;
 $17 = $16 >> 2;
 $18 = ($6>>>0)>($17>>>0);
 $19 = (($1) + ($17<<2)|0);
 $$ = $18 ? $19 : $2;
 $20 = ($$|0)==($1|0);
 if ($20) {
  $$0$lcssa$i$i = $13;
 } else {
  $$078$i$i = $1;$$09$i$i = $13;
  while(1) {
   $21 = HEAP32[$$09$i$i>>2]|0;
   $22 = HEAP32[$$078$i$i>>2]|0;
   $23 = ($21|0)==($22|0);
   if (!($23)) {
    HEAP32[$$09$i$i>>2] = $22;
    $24 = ($22|0)==(0|0);
    if (!($24)) {
     $25 = ((($22)) + 8|0);
     $26 = HEAP32[$25>>2]|0;HEAP32[$25>>2] = (($26+1)|0);
    }
    $27 = ($21|0)==(0|0);
    if (!($27)) {
     $28 = ((($21)) + 8|0);
     $29 = HEAP32[$28>>2]|0;HEAP32[$28>>2] = (($29-1)|0);
     $30 = ($29|0)==(1);
     if ($30) {
      __ZNK3osg10Referenced24signalObserversAndDeleteEbb($21,1,1);
     }
    }
   }
   $31 = ((($$078$i$i)) + 4|0);
   $32 = ((($$09$i$i)) + 4|0);
   $33 = ($31|0)==($$|0);
   if ($33) {
    $$0$lcssa$i$i = $32;
    break;
   } else {
    $$078$i$i = $31;$$09$i$i = $32;
   }
  }
 }
 if ($18) {
  $34 = ($$|0)==($2|0);
  if ($34) {
   return;
  }
  $$pre$i$i19 = HEAP32[$14>>2]|0;
  $$07$i$i21 = $19;$36 = $$pre$i$i19;
  while(1) {
   $35 = HEAP32[$$07$i$i21>>2]|0;
   HEAP32[$36>>2] = $35;
   $37 = ($35|0)==(0|0);
   if (!($37)) {
    $38 = ((($35)) + 8|0);
    $39 = HEAP32[$38>>2]|0;HEAP32[$38>>2] = (($39+1)|0);
   }
   $40 = ((($$07$i$i21)) + 4|0);
   $41 = HEAP32[$14>>2]|0;
   $42 = ((($41)) + 4|0);
   HEAP32[$14>>2] = $42;
   $43 = ($40|0)==($2|0);
   if ($43) {
    break;
   } else {
    $$07$i$i21 = $40;$36 = $42;
   }
  }
  return;
 }
 $44 = HEAP32[$14>>2]|0;
 $45 = ($44|0)==($$0$lcssa$i$i|0);
 if ($45) {
  return;
 } else {
  $47 = $44;
 }
 while(1) {
  $46 = ((($47)) + -4|0);
  HEAP32[$14>>2] = $46;
  $48 = HEAP32[$46>>2]|0;
  $49 = ($48|0)==(0|0);
  if (!($49)) {
   $50 = ((($48)) + 8|0);
   $51 = HEAP32[$50>>2]|0;HEAP32[$50>>2] = (($51-1)|0);
   $52 = ($51|0)==(1);
   if ($52) {
    __THREW__ = 0;
    invoke_viii(3262,($48|0),1,1);
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if ($54) {
     label = 21;
     break;
    }
   }
  }
  HEAP32[$46>>2] = 0;
  $55 = HEAP32[$14>>2]|0;
  $56 = ($55|0)==($$0$lcssa$i$i|0);
  if ($56) {
   label = 40;
   break;
  } else {
   $47 = $55;
  }
 }
 if ((label|0) == 21) {
  $57 = ___cxa_find_matching_catch_2()|0;
  $58 = tempRet0;
  ___cxa_call_unexpected(($57|0));
  // unreachable;
 }
 else if ((label|0) == 40) {
  return;
 }
}
function __ZN5osgGA15GUIEventAdapter35setMouseYOrientationAndUpdateCoordsENS0_17MouseYOrientationE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$sroa$07$0$$sroa$07$0$917 = 0, $10 = 0, $11 = 0.0, $12 = 0.0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0.0, $23 = 0.0, $24 = 0.0, $25 = 0, $26 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0.0, $7 = 0, $8 = 0.0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 120|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==($1|0);
 if ($4) {
  return;
 }
 HEAP32[$2>>2] = $1;
 $5 = ((($0)) + 100|0);
 $6 = +HEAPF32[$5>>2];
 $7 = ((($0)) + 108|0);
 $8 = +HEAPF32[$7>>2];
 $9 = $6 - $8;
 $10 = ((($0)) + 96|0);
 $11 = +HEAPF32[$10>>2];
 $12 = $9 + $11;
 HEAPF32[$7>>2] = $12;
 $13 = ((($0)) + 156|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(0|0);
 if ($15) {
  return;
 }
 $16 = ((($14)) + 32|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ((($14)) + 36|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($17|0)==($19|0);
 if ($20) {
  return;
 } else {
  $$sroa$07$0$$sroa$07$0$917 = $17;
 }
 while(1) {
  $21 = ((($$sroa$07$0$$sroa$07$0$917)) + 12|0);
  $22 = +HEAPF32[$21>>2];
  $23 = $6 - $22;
  $24 = $23 + $11;
  HEAPF32[$21>>2] = $24;
  $25 = ((($$sroa$07$0$$sroa$07$0$917)) + 20|0);
  $26 = ($25|0)==($19|0);
  if ($26) {
   break;
  } else {
   $$sroa$07$0$$sroa$07$0$917 = $25;
  }
 }
 return;
}
function __ZN5osgGA15GUIEventHandlerD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 8|0);
 HEAP32[$1>>2] = ((29984));
 $2 = ((($1)) + 8|0);
 HEAP32[$2>>2] = ((30232));
 $3 = ((($0)) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  HEAP32[$3>>2] = 0;
  $15 = ((($0)) + 16|0);
  __ZN3osg6ObjectD2Ev($15);
  return;
 }
 $6 = HEAP32[$4>>2]|0;
 $7 = ((($6)) + -12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($4) + ($8)|0);
 $10 = ((($9)) + 8|0);
 $11 = HEAP32[$10>>2]|0;HEAP32[$10>>2] = (($11-1)|0);
 $12 = ($11|0)==(1);
 if (!($12)) {
  HEAP32[$3>>2] = 0;
  $15 = ((($0)) + 16|0);
  __ZN3osg6ObjectD2Ev($15);
  return;
 }
 __THREW__ = 0;
 invoke_viii(3262,($9|0),1,1);
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 if (!($14)) {
  HEAP32[$3>>2] = 0;
  $15 = ((($0)) + 16|0);
  __ZN3osg6ObjectD2Ev($15);
  return;
 }
 $16 = ___cxa_find_matching_catch_2()|0;
 $17 = tempRet0;
 $18 = ((($0)) + 16|0);
 __THREW__ = 0;
 invoke_vi(388,($18|0));
 $19 = __THREW__; __THREW__ = 0;
 $20 = $19&1;
 if ($20) {
  $21 = ___cxa_find_matching_catch_3(0|0)|0;
  $22 = tempRet0;
  ___clang_call_terminate($21);
  // unreachable;
 } else {
  ___resumeException($16|0);
  // unreachable;
 }
}
function __ZN5osgGA15GUIEventHandlerD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 8|0);
 HEAP32[$1>>2] = ((29984));
 $2 = ((($1)) + 8|0);
 HEAP32[$2>>2] = ((30232));
 $3 = ((($0)) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if (!($5)) {
  $6 = HEAP32[$4>>2]|0;
  $7 = ((($6)) + -12|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($4) + ($8)|0);
  $10 = ((($9)) + 8|0);
  $11 = HEAP32[$10>>2]|0;HEAP32[$10>>2] = (($11-1)|0);
  $12 = ($11|0)==(1);
  if ($12) {
   __THREW__ = 0;
   invoke_viii(3262,($9|0),1,1);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if ($14) {
    $18 = ___cxa_find_matching_catch_2()|0;
    $19 = tempRet0;
    $20 = ((($0)) + 16|0);
    __THREW__ = 0;
    invoke_vi(388,($20|0));
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if ($22) {
     $23 = ___cxa_find_matching_catch_3(0|0)|0;
     $24 = tempRet0;
     ___clang_call_terminate($23);
     // unreachable;
    } else {
     $eh$lpad$body$index2Z2D = $19;$eh$lpad$body$indexZ2D = $18;
     __ZdlPv($0);
     ___resumeException($eh$lpad$body$indexZ2D|0);
     // unreachable;
    }
   }
  }
 }
 HEAP32[$3>>2] = 0;
 $15 = ((($0)) + 16|0);
 __THREW__ = 0;
 invoke_vi(388,($15|0));
 $16 = __THREW__; __THREW__ = 0;
 $17 = $16&1;
 if (!($17)) {
  __ZdlPv($0);
  return;
 }
 $25 = ___cxa_find_matching_catch_2()|0;
 $26 = tempRet0;
 $eh$lpad$body$index2Z2D = $26;$eh$lpad$body$indexZ2D = $25;
 __ZdlPv($0);
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
}
function __ZN5osgGA15GUIEventHandler6handleEPNS_5EventEPN3osg6ObjectEPNS3_11NodeVisitorE($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($4)) + 52|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_ii[$6 & 8191]($3)|0);
 $8 = HEAP32[$1>>2]|0;
 $9 = ((($8)) + 140|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (FUNCTION_TABLE_ii[$10 & 8191]($1)|0);
 $12 = ($11|0)!=(0|0);
 $13 = ($7|0)!=(0|0);
 $or$cond = $13 & $12;
 if (!($or$cond)) {
  $$0 = 0;
  return ($$0|0);
 }
 $14 = ((($7)) + 56|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0|0);
 if ($16) {
  $$0 = 0;
  return ($$0|0);
 }
 $17 = HEAP32[$0>>2]|0;
 $18 = ((($17)) + 72|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (FUNCTION_TABLE_iiiiii[$19 & 8191]($0,$11,$15,$2,$3)|0);
 if (!($20)) {
  $$0 = 0;
  return ($$0|0);
 }
 $21 = ((($11)) + 32|0);
 HEAP8[$21>>0] = 1;
 $$0 = 1;
 return ($$0|0);
}
function __ZThn4_N5osgGA15GUIEventHandlerD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -4|0);
 $2 = ((($1)) + 8|0);
 HEAP32[$2>>2] = ((29984));
 $3 = ((($1)) + 16|0);
 HEAP32[$3>>2] = ((30232));
 $4 = ((($1)) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  HEAP32[$4>>2] = 0;
  __ZN3osg6ObjectD2Ev($3);
  return;
 }
 $7 = HEAP32[$5>>2]|0;
 $8 = ((($7)) + -12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($5) + ($9)|0);
 $11 = ((($10)) + 8|0);
 $12 = HEAP32[$11>>2]|0;HEAP32[$11>>2] = (($12-1)|0);
 $13 = ($12|0)==(1);
 if (!($13)) {
  HEAP32[$4>>2] = 0;
  __ZN3osg6ObjectD2Ev($3);
  return;
 }
 __THREW__ = 0;
 invoke_viii(3262,($10|0),1,1);
 $14 = __THREW__; __THREW__ = 0;
 $15 = $14&1;
 if (!($15)) {
  HEAP32[$4>>2] = 0;
  __ZN3osg6ObjectD2Ev($3);
  return;
 }
 $16 = ___cxa_find_matching_catch_2()|0;
 $17 = tempRet0;
 __THREW__ = 0;
 invoke_vi(388,($3|0));
 $18 = __THREW__; __THREW__ = 0;
 $19 = $18&1;
 if ($19) {
  $20 = ___cxa_find_matching_catch_3(0|0)|0;
  $21 = tempRet0;
  ___clang_call_terminate($20);
  // unreachable;
 } else {
  ___resumeException($16|0);
  // unreachable;
 }
}
function __ZThn4_N5osgGA15GUIEventHandlerD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -4|0);
 __ZN5osgGA15GUIEventHandlerD0Ev($1);
 return;
}
function __ZTv0_n112_N5osgGA15GUIEventHandlerD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -112|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 $5 = ((($4)) + 8|0);
 HEAP32[$5>>2] = ((29984));
 $6 = ((($5)) + 8|0);
 HEAP32[$6>>2] = ((30232));
 $7 = ((($4)) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if ($9) {
  HEAP32[$7>>2] = 0;
  $26 = ((($4)) + 16|0);
  __ZN3osg6ObjectD2Ev($26);
  return;
 }
 $10 = HEAP32[$8>>2]|0;
 $11 = ((($10)) + -12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($8) + ($12)|0);
 $14 = ((($13)) + 8|0);
 $15 = HEAP32[$14>>2]|0;HEAP32[$14>>2] = (($15-1)|0);
 $16 = ($15|0)==(1);
 if (!($16)) {
  HEAP32[$7>>2] = 0;
  $26 = ((($4)) + 16|0);
  __ZN3osg6ObjectD2Ev($26);
  return;
 }
 __THREW__ = 0;
 invoke_viii(3262,($13|0),1,1);
 $17 = __THREW__; __THREW__ = 0;
 $18 = $17&1;
 if (!($18)) {
  HEAP32[$7>>2] = 0;
  $26 = ((($4)) + 16|0);
  __ZN3osg6ObjectD2Ev($26);
  return;
 }
 $19 = ___cxa_find_matching_catch_2()|0;
 $20 = tempRet0;
 $21 = ((($4)) + 16|0);
 __THREW__ = 0;
 invoke_vi(388,($21|0));
 $22 = __THREW__; __THREW__ = 0;
 $23 = $22&1;
 if ($23) {
  $24 = ___cxa_find_matching_catch_3(0|0)|0;
  $25 = tempRet0;
  ___clang_call_terminate($24);
  // unreachable;
 } else {
  ___resumeException($19|0);
  // unreachable;
 }
}
function __ZTv0_n112_N5osgGA15GUIEventHandlerD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -112|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __ZN5osgGA15GUIEventHandlerD0Ev($4);
 return;
}
function __ZTv0_n16_N5osgGA15GUIEventHandlerD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 $5 = ((($4)) + 8|0);
 HEAP32[$5>>2] = ((29984));
 $6 = ((($5)) + 8|0);
 HEAP32[$6>>2] = ((30232));
 $7 = ((($4)) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if ($9) {
  HEAP32[$7>>2] = 0;
  $26 = ((($4)) + 16|0);
  __ZN3osg6ObjectD2Ev($26);
  return;
 }
 $10 = HEAP32[$8>>2]|0;
 $11 = ((($10)) + -12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($8) + ($12)|0);
 $14 = ((($13)) + 8|0);
 $15 = HEAP32[$14>>2]|0;HEAP32[$14>>2] = (($15-1)|0);
 $16 = ($15|0)==(1);
 if (!($16)) {
  HEAP32[$7>>2] = 0;
  $26 = ((($4)) + 16|0);
  __ZN3osg6ObjectD2Ev($26);
  return;
 }
 __THREW__ = 0;
 invoke_viii(3262,($13|0),1,1);
 $17 = __THREW__; __THREW__ = 0;
 $18 = $17&1;
 if (!($18)) {
  HEAP32[$7>>2] = 0;
  $26 = ((($4)) + 16|0);
  __ZN3osg6ObjectD2Ev($26);
  return;
 }
 $19 = ___cxa_find_matching_catch_2()|0;
 $20 = tempRet0;
 $21 = ((($4)) + 16|0);
 __THREW__ = 0;
 invoke_vi(388,($21|0));
 $22 = __THREW__; __THREW__ = 0;
 $23 = $22&1;
 if ($23) {
  $24 = ___cxa_find_matching_catch_3(0|0)|0;
  $25 = tempRet0;
  ___clang_call_terminate($24);
  // unreachable;
 } else {
  ___resumeException($19|0);
  // unreachable;
 }
}
function __ZTv0_n16_N5osgGA15GUIEventHandlerD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __ZN5osgGA15GUIEventHandlerD0Ev($4);
 return;
}
function __ZN5osgGA15GUIEventHandlerD2Ev($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN5osgGA19StandardManipulatorD2Ev($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$03 = 0, $$1 = 0, $$14 = 0, $$2 = 0, $$25 = 0, $$cast = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $2;
 $3 = ((($1)) + 76|0);
 $4 = HEAP32[$3>>2]|0;
 $$cast = $2;
 $5 = ((($$cast)) + -12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($0) + ($6)|0);
 HEAP32[$7>>2] = $4;
 $8 = ((($1)) + 80|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$0>>2]|0;
 $11 = ((($10)) + -16|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($0) + ($12)|0);
 HEAP32[$13>>2] = $9;
 $14 = ((($1)) + 84|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ((($0)) + 4|0);
 HEAP32[$16>>2] = $15;
 $17 = ((($0)) + 148|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ($18|0)==(0|0);
 if ($19) {
  label = 4;
 } else {
  $20 = ((($18)) + 8|0);
  $21 = HEAP32[$20>>2]|0;HEAP32[$20>>2] = (($21-1)|0);
  $22 = ($21|0)==(1);
  if ($22) {
   __THREW__ = 0;
   invoke_viii(3262,($18|0),1,1);
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if ($24) {
    $50 = ___cxa_find_matching_catch_2()|0;
    $51 = tempRet0;
    $52 = ((($0)) + 128|0);
    $53 = HEAP32[$52>>2]|0;
    $54 = ($53|0)==(0|0);
    if (!($54)) {
     $55 = ((($53)) + 8|0);
     $56 = HEAP32[$55>>2]|0;HEAP32[$55>>2] = (($56-1)|0);
     $57 = ($56|0)==(1);
     if ($57) {
      __THREW__ = 0;
      invoke_viii(3262,($53|0),1,1);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       $85 = ___cxa_find_matching_catch_3(0|0)|0;
       $86 = tempRet0;
       ___clang_call_terminate($85);
       // unreachable;
      }
     }
    }
    HEAP32[$52>>2] = 0;
    $$0 = $51;$$03 = $50;
    label = 20;
   } else {
    label = 4;
   }
  } else {
   label = 4;
  }
 }
 do {
  if ((label|0) == 4) {
   HEAP32[$17>>2] = 0;
   $25 = ((($0)) + 128|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = ($26|0)==(0|0);
   if (!($27)) {
    $28 = ((($26)) + 8|0);
    $29 = HEAP32[$28>>2]|0;HEAP32[$28>>2] = (($29-1)|0);
    $30 = ($29|0)==(1);
    if ($30) {
     __THREW__ = 0;
     invoke_viii(3262,($26|0),1,1);
     $31 = __THREW__; __THREW__ = 0;
     $32 = $31&1;
     if ($32) {
      $60 = ___cxa_find_matching_catch_2()|0;
      $61 = tempRet0;
      $$0 = $61;$$03 = $60;
      label = 20;
      break;
     }
    }
   }
   HEAP32[$25>>2] = 0;
   $33 = ((($0)) + 108|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = ($34|0)==(0|0);
   if (!($35)) {
    $36 = ((($34)) + 8|0);
    $37 = HEAP32[$36>>2]|0;HEAP32[$36>>2] = (($37-1)|0);
    $38 = ($37|0)==(1);
    if ($38) {
     __THREW__ = 0;
     invoke_viii(3262,($34|0),1,1);
     $39 = __THREW__; __THREW__ = 0;
     $40 = $39&1;
     if ($40) {
      $62 = ___cxa_find_matching_catch_2()|0;
      $63 = tempRet0;
      $$1 = $63;$$14 = $62;
      label = 25;
      break;
     }
    }
   }
   HEAP32[$33>>2] = 0;
   $41 = ((($0)) + 104|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = ($42|0)==(0|0);
   if ($43) {
    HEAP32[$41>>2] = 0;
    $49 = ((($1)) + 4|0);
    __ZN5osgGA17CameraManipulatorD2Ev($0,$49);
    return;
   }
   $44 = ((($42)) + 8|0);
   $45 = HEAP32[$44>>2]|0;HEAP32[$44>>2] = (($45-1)|0);
   $46 = ($45|0)==(1);
   if (!($46)) {
    HEAP32[$41>>2] = 0;
    $49 = ((($1)) + 4|0);
    __ZN5osgGA17CameraManipulatorD2Ev($0,$49);
    return;
   }
   __THREW__ = 0;
   invoke_viii(3262,($42|0),1,1);
   $47 = __THREW__; __THREW__ = 0;
   $48 = $47&1;
   if ($48) {
    $72 = ___cxa_find_matching_catch_2()|0;
    $73 = tempRet0;
    $$2 = $73;$$25 = $72;
    break;
   } else {
    HEAP32[$41>>2] = 0;
    $49 = ((($1)) + 4|0);
    __ZN5osgGA17CameraManipulatorD2Ev($0,$49);
    return;
   }
  }
 } while(0);
 if ((label|0) == 20) {
  $64 = ((($0)) + 108|0);
  $65 = HEAP32[$64>>2]|0;
  $66 = ($65|0)==(0|0);
  if (!($66)) {
   $67 = ((($65)) + 8|0);
   $68 = HEAP32[$67>>2]|0;HEAP32[$67>>2] = (($68-1)|0);
   $69 = ($68|0)==(1);
   if ($69) {
    __THREW__ = 0;
    invoke_viii(3262,($65|0),1,1);
    $70 = __THREW__; __THREW__ = 0;
    $71 = $70&1;
    if ($71) {
     $85 = ___cxa_find_matching_catch_3(0|0)|0;
     $86 = tempRet0;
     ___clang_call_terminate($85);
     // unreachable;
    }
   }
  }
  HEAP32[$64>>2] = 0;
  $$1 = $$0;$$14 = $$03;
  label = 25;
 }
 if ((label|0) == 25) {
  $74 = ((($0)) + 104|0);
  $75 = HEAP32[$74>>2]|0;
  $76 = ($75|0)==(0|0);
  if (!($76)) {
   $77 = ((($75)) + 8|0);
   $78 = HEAP32[$77>>2]|0;HEAP32[$77>>2] = (($78-1)|0);
   $79 = ($78|0)==(1);
   if ($79) {
    __THREW__ = 0;
    invoke_viii(3262,($75|0),1,1);
    $80 = __THREW__; __THREW__ = 0;
    $81 = $80&1;
    if ($81) {
     $85 = ___cxa_find_matching_catch_3(0|0)|0;
     $86 = tempRet0;
     ___clang_call_terminate($85);
     // unreachable;
    }
   }
  }
  HEAP32[$74>>2] = 0;
  $$2 = $$1;$$25 = $$14;
 }
 $82 = ((($1)) + 4|0);
 __THREW__ = 0;
 invoke_vii(3525,($0|0),($82|0));
 $83 = __THREW__; __THREW__ = 0;
 $84 = $83&1;
 if ($84) {
  $85 = ___cxa_find_matching_catch_3(0|0)|0;
  $86 = tempRet0;
  ___clang_call_terminate($85);
  // unreachable;
 } else {
  ___resumeException($$25|0);
  // unreachable;
 }
}
function __ZN5osgGA20TrackballManipulatorC1Ei($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$03 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 256|0);
 __ZN3osg10ReferencedC2Ev($2);
 $3 = ((($0)) + 268|0);
 ;HEAP32[$3>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;
 $4 = ((($0)) + 280|0);
 HEAP32[$4>>2] = 2;
 $5 = ((($0)) + 284|0);
 HEAP32[$5>>2] = 0;
 $6 = ((($0)) + 248|0);
 HEAP32[$6>>2] = ((29984));
 $7 = ((($6)) + 8|0);
 HEAP32[$7>>2] = ((30232));
 $8 = ((($0)) + 252|0);
 HEAP32[$8>>2] = 0;
 __THREW__ = 0;
 invoke_viii(3526,($0|0),((43476)|0),($1|0));
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if ($10) {
  $14 = ___cxa_find_matching_catch_2()|0;
  $15 = tempRet0;
  $$0 = $15;$$03 = $14;
 } else {
  HEAP32[$0>>2] = (43616);
  HEAP32[$6>>2] = (44104);
  HEAP32[$2>>2] = (44352);
  $11 = ((($0)) + 4|0);
  HEAP32[$11>>2] = (43948);
  __THREW__ = 0;
  invoke_vii(798,($0|0),0);
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if (!($13)) {
   return;
  }
  $16 = ___cxa_find_matching_catch_2()|0;
  $17 = tempRet0;
  __THREW__ = 0;
  invoke_vii(3527,($0|0),((43480)|0));
  $18 = __THREW__; __THREW__ = 0;
  $19 = $18&1;
  if ($19) {
   $33 = ___cxa_find_matching_catch_3(0|0)|0;
   $34 = tempRet0;
   ___clang_call_terminate($33);
   // unreachable;
  } else {
   $$0 = $17;$$03 = $16;
  }
 }
 HEAP32[$6>>2] = ((29984));
 HEAP32[$7>>2] = ((30232));
 $20 = HEAP32[$8>>2]|0;
 $21 = ($20|0)==(0|0);
 if (!($21)) {
  $22 = HEAP32[$20>>2]|0;
  $23 = ((($22)) + -12|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = (($20) + ($24)|0);
  $26 = ((($25)) + 8|0);
  $27 = HEAP32[$26>>2]|0;HEAP32[$26>>2] = (($27-1)|0);
  $28 = ($27|0)==(1);
  if ($28) {
   __THREW__ = 0;
   invoke_viii(3262,($25|0),1,1);
   $29 = __THREW__; __THREW__ = 0;
   $30 = $29&1;
   if ($30) {
    $33 = ___cxa_find_matching_catch_3(0|0)|0;
    $34 = tempRet0;
    ___clang_call_terminate($33);
    // unreachable;
   }
  }
 }
 HEAP32[$8>>2] = 0;
 __THREW__ = 0;
 invoke_vi(388,($2|0));
 $31 = __THREW__; __THREW__ = 0;
 $32 = $31&1;
 if ($32) {
  $33 = ___cxa_find_matching_catch_3(0|0)|0;
  $34 = tempRet0;
  ___clang_call_terminate($33);
  // unreachable;
 } else {
  ___resumeException($$03|0);
  // unreachable;
 }
}
function __ZNK5osgGA20TrackballManipulator9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(288)|0);
 __THREW__ = 0;
 invoke_vii(3390,($1|0),5);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $8 = ___cxa_find_matching_catch_2()|0;
  $9 = tempRet0;
  __ZdlPv($1);
  ___resumeException($8|0);
  // unreachable;
 } else {
  $4 = HEAP32[$1>>2]|0;
  $5 = ((($4)) + -16|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($1) + ($6)|0);
  return ($7|0);
 }
 return (0)|0;
}
function __ZNK5osgGA20TrackballManipulator5cloneERKN3osg6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(288)|0);
 __THREW__ = 0;
 invoke_viii(3528,($2|0),($0|0),($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $9 = ___cxa_find_matching_catch_2()|0;
  $10 = tempRet0;
  __ZdlPv($2);
  ___resumeException($9|0);
  // unreachable;
 } else {
  $5 = HEAP32[$2>>2]|0;
  $6 = ((($5)) + -16|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($2) + ($7)|0);
  return ($8|0);
 }
 return (0)|0;
}
function __ZNK5osgGA20TrackballManipulator12isSameKindAsEPKN3osg6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,9568,-1)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK5osgGA20TrackballManipulator11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (109961|0);
}
function __ZNK5osgGA20TrackballManipulator9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (109756|0);
}
function __ZN5osgGA20TrackballManipulatorD1Ev($0) {
 $0 = $0|0;
 var $$0 = 0, $$02 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vii(3527,($0|0),((43480)|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if ($2) {
   $18 = ___cxa_find_matching_catch_2()|0;
   $19 = tempRet0;
   $20 = ((($0)) + 248|0);
   HEAP32[$20>>2] = ((29984));
   $21 = ((($20)) + 8|0);
   HEAP32[$21>>2] = ((30232));
   $22 = ((($0)) + 252|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = ($23|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$23>>2]|0;
    $26 = ((($25)) + -12|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = (($23) + ($27)|0);
    $29 = ((($28)) + 8|0);
    $30 = HEAP32[$29>>2]|0;HEAP32[$29>>2] = (($30-1)|0);
    $31 = ($30|0)==(1);
    if ($31) {
     __THREW__ = 0;
     invoke_viii(3262,($28|0),1,1);
     $32 = __THREW__; __THREW__ = 0;
     $33 = $32&1;
     if ($33) {
      $39 = ___cxa_find_matching_catch_3(0|0)|0;
      $40 = tempRet0;
      ___clang_call_terminate($39);
      // unreachable;
     }
    }
   }
   HEAP32[$22>>2] = 0;
   $$0 = $19;$$02 = $18;
  } else {
   $3 = ((($0)) + 248|0);
   HEAP32[$3>>2] = ((29984));
   $4 = ((($3)) + 8|0);
   HEAP32[$4>>2] = ((30232));
   $5 = ((($0)) + 252|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($6|0)==(0|0);
   if ($7) {
    HEAP32[$5>>2] = 0;
    $17 = ((($0)) + 256|0);
    __ZN3osg6ObjectD2Ev($17);
    return;
   }
   $8 = HEAP32[$6>>2]|0;
   $9 = ((($8)) + -12|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (($6) + ($10)|0);
   $12 = ((($11)) + 8|0);
   $13 = HEAP32[$12>>2]|0;HEAP32[$12>>2] = (($13-1)|0);
   $14 = ($13|0)==(1);
   if (!($14)) {
    HEAP32[$5>>2] = 0;
    $17 = ((($0)) + 256|0);
    __ZN3osg6ObjectD2Ev($17);
    return;
   }
   __THREW__ = 0;
   invoke_viii(3262,($11|0),1,1);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if ($16) {
    $34 = ___cxa_find_matching_catch_2()|0;
    $35 = tempRet0;
    $$0 = $35;$$02 = $34;
    break;
   } else {
    HEAP32[$5>>2] = 0;
    $17 = ((($0)) + 256|0);
    __ZN3osg6ObjectD2Ev($17);
    return;
   }
  }
 } while(0);
 $36 = ((($0)) + 256|0);
 __THREW__ = 0;
 invoke_vi(388,($36|0));
 $37 = __THREW__; __THREW__ = 0;
 $38 = $37&1;
 if ($38) {
  $39 = ___cxa_find_matching_catch_3(0|0)|0;
  $40 = tempRet0;
  ___clang_call_terminate($39);
  // unreachable;
 } else {
  ___resumeException($$02|0);
  // unreachable;
 }
}
function __ZN5osgGA20TrackballManipulatorD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(770,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZN5osgGA17CameraManipulator6handleEPNS_5EventEPN3osg6ObjectEPNS3_11NodeVisitorE($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = (__ZN5osgGA15GUIEventHandler6handleEPNS_5EventEPN3osg6ObjectEPNS3_11NodeVisitorE($0,$1,$2,$3)|0);
 return ($4|0);
}
function __ZN5osgGA17CameraManipulator26setCoordinateFrameCallbackEPNS0_23CoordinateFrameCallbackE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 88|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==($1|0);
 if ($4) {
  return;
 }
 HEAP32[$2>>2] = $1;
 $5 = ($1|0)==(0|0);
 if (!($5)) {
  $6 = ((($1)) + 8|0);
  $7 = HEAP32[$6>>2]|0;HEAP32[$6>>2] = (($7+1)|0);
 }
 $8 = ($3|0)==(0|0);
 if ($8) {
  return;
 }
 $9 = ((($3)) + 8|0);
 $10 = HEAP32[$9>>2]|0;HEAP32[$9>>2] = (($10-1)|0);
 $11 = ($10|0)==(1);
 if (!($11)) {
  return;
 }
 __ZNK3osg10Referenced24signalObserversAndDeleteEbb($3,1,1);
 return;
}
function __ZN5osgGA17CameraManipulator12updateCameraERN3osg6CameraE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0.0, $13 = 0, $14 = 0, $15 = 0.0, $16 = 0, $17 = 0, $18 = 0.0, $19 = 0, $2 = 0, $20 = 0, $21 = 0.0, $22 = 0, $23 = 0, $24 = 0.0, $25 = 0, $26 = 0, $27 = 0.0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0.0, $31 = 0, $32 = 0, $33 = 0.0, $34 = 0, $35 = 0, $36 = 0.0, $37 = 0, $38 = 0, $39 = 0.0, $4 = 0, $40 = 0, $41 = 0, $42 = 0.0, $43 = 0, $44 = 0, $45 = 0.0, $46 = 0;
 var $47 = 0, $48 = 0.0, $49 = 0, $5 = 0, $50 = 0, $51 = 0.0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0.0, $7 = 0, $8 = 0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(128|0);
 $2 = sp;
 $3 = HEAP32[$0>>2]|0;
 $4 = ((($3)) + 96|0);
 $5 = HEAP32[$4>>2]|0;
 FUNCTION_TABLE_vii[$5 & 8191]($2,$0);
 $6 = +HEAPF64[$2>>3];
 $7 = ((($1)) + 432|0);
 HEAPF64[$7>>3] = $6;
 $8 = ((($2)) + 8|0);
 $9 = +HEAPF64[$8>>3];
 $10 = ((($1)) + 440|0);
 HEAPF64[$10>>3] = $9;
 $11 = ((($2)) + 16|0);
 $12 = +HEAPF64[$11>>3];
 $13 = ((($1)) + 448|0);
 HEAPF64[$13>>3] = $12;
 $14 = ((($2)) + 24|0);
 $15 = +HEAPF64[$14>>3];
 $16 = ((($1)) + 456|0);
 HEAPF64[$16>>3] = $15;
 $17 = ((($2)) + 32|0);
 $18 = +HEAPF64[$17>>3];
 $19 = ((($1)) + 464|0);
 HEAPF64[$19>>3] = $18;
 $20 = ((($2)) + 40|0);
 $21 = +HEAPF64[$20>>3];
 $22 = ((($1)) + 472|0);
 HEAPF64[$22>>3] = $21;
 $23 = ((($2)) + 48|0);
 $24 = +HEAPF64[$23>>3];
 $25 = ((($1)) + 480|0);
 HEAPF64[$25>>3] = $24;
 $26 = ((($2)) + 56|0);
 $27 = +HEAPF64[$26>>3];
 $28 = ((($1)) + 488|0);
 HEAPF64[$28>>3] = $27;
 $29 = ((($2)) + 64|0);
 $30 = +HEAPF64[$29>>3];
 $31 = ((($1)) + 496|0);
 HEAPF64[$31>>3] = $30;
 $32 = ((($2)) + 72|0);
 $33 = +HEAPF64[$32>>3];
 $34 = ((($1)) + 504|0);
 HEAPF64[$34>>3] = $33;
 $35 = ((($2)) + 80|0);
 $36 = +HEAPF64[$35>>3];
 $37 = ((($1)) + 512|0);
 HEAPF64[$37>>3] = $36;
 $38 = ((($2)) + 88|0);
 $39 = +HEAPF64[$38>>3];
 $40 = ((($1)) + 520|0);
 HEAPF64[$40>>3] = $39;
 $41 = ((($2)) + 96|0);
 $42 = +HEAPF64[$41>>3];
 $43 = ((($1)) + 528|0);
 HEAPF64[$43>>3] = $42;
 $44 = ((($2)) + 104|0);
 $45 = +HEAPF64[$44>>3];
 $46 = ((($1)) + 536|0);
 HEAPF64[$46>>3] = $45;
 $47 = ((($2)) + 112|0);
 $48 = +HEAPF64[$47>>3];
 $49 = ((($1)) + 544|0);
 HEAPF64[$49>>3] = $48;
 $50 = ((($2)) + 120|0);
 $51 = +HEAPF64[$50>>3];
 $52 = ((($1)) + 552|0);
 HEAPF64[$52>>3] = $51;
 __THREW__ = 0;
 invoke_vi(3323,($1|0));
 $53 = __THREW__; __THREW__ = 0;
 $54 = $53&1;
 if ($54) {
  $55 = ___cxa_find_matching_catch_2()|0;
  $56 = tempRet0;
  ___resumeException($55|0);
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN5osgGA17CameraManipulator15setHomePositionERKN3osg5Vec3dES4_S4_b($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $10 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = HEAP32[$0>>2]|0;
 $6 = ((($5)) + 132|0);
 $7 = HEAP32[$6>>2]|0;
 FUNCTION_TABLE_vii[$7 & 8191]($0,$4);
 $8 = ((($0)) + 16|0);
 ;HEAP32[$8>>2]=HEAP32[$1>>2]|0;HEAP32[$8+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$8+12>>2]=HEAP32[$1+12>>2]|0;HEAP32[$8+16>>2]=HEAP32[$1+16>>2]|0;HEAP32[$8+20>>2]=HEAP32[$1+20>>2]|0;
 $9 = ((($0)) + 40|0);
 ;HEAP32[$9>>2]=HEAP32[$2>>2]|0;HEAP32[$9+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$9+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$9+12>>2]=HEAP32[$2+12>>2]|0;HEAP32[$9+16>>2]=HEAP32[$2+16>>2]|0;HEAP32[$9+20>>2]=HEAP32[$2+20>>2]|0;
 $10 = ((($0)) + 64|0);
 ;HEAP32[$10>>2]=HEAP32[$3>>2]|0;HEAP32[$10+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$10+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$10+12>>2]=HEAP32[$3+12>>2]|0;HEAP32[$10+16>>2]=HEAP32[$3+16>>2]|0;HEAP32[$10+20>>2]=HEAP32[$3+20>>2]|0;
 return;
}
function __ZNK5osgGA17CameraManipulator15getHomePositionERN3osg5Vec3dES3_S3_($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ((($0)) + 16|0);
 ;HEAP32[$1>>2]=HEAP32[$4>>2]|0;HEAP32[$1+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$4+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$4+12>>2]|0;HEAP32[$1+16>>2]=HEAP32[$4+16>>2]|0;HEAP32[$1+20>>2]=HEAP32[$4+20>>2]|0;
 $5 = ((($0)) + 40|0);
 ;HEAP32[$2>>2]=HEAP32[$5>>2]|0;HEAP32[$2+4>>2]=HEAP32[$5+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$5+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$5+12>>2]|0;HEAP32[$2+16>>2]=HEAP32[$5+16>>2]|0;HEAP32[$2+20>>2]=HEAP32[$5+20>>2]|0;
 $6 = ((($0)) + 64|0);
 ;HEAP32[$3>>2]=HEAP32[$6>>2]|0;HEAP32[$3+4>>2]=HEAP32[$6+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$6+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$6+12>>2]|0;HEAP32[$3+16>>2]=HEAP32[$6+16>>2]|0;HEAP32[$3+20>>2]=HEAP32[$6+20>>2]|0;
 return;
}
function __ZN5osgGA17CameraManipulator26setAutoComputeHomePositionEb($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = $1&1;
 $3 = ((($0)) + 12|0);
 HEAP8[$3>>0] = $2;
 return;
}
function __ZN5osgGA16OrbitManipulator18allocAnimationDataEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $1 = (__Znwj(72)|0);
 dest=$1; stop=dest+72|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 __THREW__ = 0;
 invoke_vi(3529,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $14 = ___cxa_find_matching_catch_2()|0;
  $15 = tempRet0;
  __ZdlPv($1);
  ___resumeException($14|0);
  // unreachable;
 }
 HEAP32[$1>>2] = (44500);
 $4 = ((($1)) + 48|0);
 ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;HEAP32[$4+12>>2]=0|0;HEAP32[$4+16>>2]=0|0;HEAP32[$4+20>>2]=0|0;
 $5 = ((($0)) + 148|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==($1|0);
 if ($7) {
  return;
 }
 HEAP32[$5>>2] = $1;
 $8 = ((($1)) + 8|0);
 $9 = HEAP32[$8>>2]|0;HEAP32[$8>>2] = (($9+1)|0);
 $10 = ($6|0)==(0|0);
 if ($10) {
  return;
 }
 $11 = ((($6)) + 8|0);
 $12 = HEAP32[$11>>2]|0;HEAP32[$11>>2] = (($12-1)|0);
 $13 = ($12|0)==(1);
 if (!($13)) {
  return;
 }
 __ZNK3osg10Referenced24signalObserversAndDeleteEbb($6,1,1);
 return;
}
function __ZThn4_NK5osgGA20TrackballManipulator9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(288)|0);
 __THREW__ = 0;
 invoke_vii(3390,($1|0),5);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch_2()|0;
  $5 = tempRet0;
  __ZdlPv($1);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $6 = HEAP32[$1>>2]|0;
  $7 = ((($6)) + -16|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($1) + ($8)|0);
  return ($9|0);
 }
 return (0)|0;
}
function __ZThn4_NK5osgGA20TrackballManipulator5cloneERKN3osg6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + -4|0);
 $3 = (__Znwj(288)|0);
 __THREW__ = 0;
 invoke_viii(3528,($3|0),($2|0),($1|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch_2()|0;
  $7 = tempRet0;
  __ZdlPv($3);
  ___resumeException($6|0);
  // unreachable;
 } else {
  $8 = HEAP32[$3>>2]|0;
  $9 = ((($8)) + -16|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($3) + ($10)|0);
  return ($11|0);
 }
 return (0)|0;
}
function __ZThn4_NK5osgGA20TrackballManipulator12isSameKindAsEPKN3osg6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,9568,-1)|0);
 $phitmp$i = ($3|0)!=(0|0);
 $4 = $phitmp$i;
 return ($4|0);
}
function __ZThn4_NK5osgGA20TrackballManipulator11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (109961|0);
}
function __ZThn4_NK5osgGA20TrackballManipulator9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (109756|0);
}
function __ZThn4_N5osgGA20TrackballManipulatorD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -4|0);
 __ZN5osgGA20TrackballManipulatorD1Ev($1);
 return;
}
function __ZThn4_N5osgGA20TrackballManipulatorD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -4|0);
 __THREW__ = 0;
 invoke_vi(770,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch_2()|0;
  $5 = tempRet0;
  __ZdlPv($1);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZdlPv($1);
  return;
 }
}
function __ZTv0_n16_NK5osgGA20TrackballManipulator9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(288)|0);
 __THREW__ = 0;
 invoke_vii(3390,($1|0),5);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch_2()|0;
  $5 = tempRet0;
  __ZdlPv($1);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $6 = HEAP32[$1>>2]|0;
  $7 = ((($6)) + -16|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($1) + ($8)|0);
  return ($9|0);
 }
 return (0)|0;
}
function __ZTv0_n20_NK5osgGA20TrackballManipulator5cloneERKN3osg6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $3 = ((($2)) + -20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($0) + ($4)|0);
 $6 = (__Znwj(288)|0);
 __THREW__ = 0;
 invoke_viii(3528,($6|0),($5|0),($1|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch_2()|0;
  $10 = tempRet0;
  __ZdlPv($6);
  ___resumeException($9|0);
  // unreachable;
 } else {
  $11 = HEAP32[$6>>2]|0;
  $12 = ((($11)) + -16|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($6) + ($13)|0);
  return ($14|0);
 }
 return (0)|0;
}
function __ZTv0_n24_NK5osgGA20TrackballManipulator12isSameKindAsEPKN3osg6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,9568,-1)|0);
 $phitmp$i = ($3|0)!=(0|0);
 $4 = $phitmp$i;
 return ($4|0);
}
function __ZTv0_n28_NK5osgGA20TrackballManipulator11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (109961|0);
}
function __ZTv0_n32_NK5osgGA20TrackballManipulator9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (109756|0);
}
function __ZTv0_n112_N5osgGA20TrackballManipulatorD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -112|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __ZN5osgGA20TrackballManipulatorD1Ev($4);
 return;
}
function __ZTv0_n112_N5osgGA20TrackballManipulatorD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -112|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __THREW__ = 0;
 invoke_vi(770,($4|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $7 = ___cxa_find_matching_catch_2()|0;
  $8 = tempRet0;
  __ZdlPv($4);
  ___resumeException($7|0);
  // unreachable;
 } else {
  __ZdlPv($4);
  return;
 }
}
function __ZTv0_n16_N5osgGA20TrackballManipulatorD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __ZN5osgGA20TrackballManipulatorD1Ev($4);
 return;
}
function __ZTv0_n16_N5osgGA20TrackballManipulatorD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __THREW__ = 0;
 invoke_vi(770,($4|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $7 = ___cxa_find_matching_catch_2()|0;
  $8 = tempRet0;
  __ZdlPv($4);
  ___resumeException($7|0);
  // unreachable;
 } else {
  __ZdlPv($4);
  return;
 }
}
function __ZTv0_n20_NK5osgGA20TrackballManipulator9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(288)|0);
 __THREW__ = 0;
 invoke_vii(3390,($1|0),5);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch_2()|0;
  $5 = tempRet0;
  __ZdlPv($1);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $6 = HEAP32[$1>>2]|0;
  $7 = ((($6)) + -16|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($1) + ($8)|0);
  return ($9|0);
 }
 return (0)|0;
}
function __ZTv0_n24_NK5osgGA20TrackballManipulator5cloneERKN3osg6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $3 = ((($2)) + -24|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($0) + ($4)|0);
 $6 = (__Znwj(288)|0);
 __THREW__ = 0;
 invoke_viii(3528,($6|0),($5|0),($1|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch_2()|0;
  $10 = tempRet0;
  __ZdlPv($6);
  ___resumeException($9|0);
  // unreachable;
 } else {
  $11 = HEAP32[$6>>2]|0;
  $12 = ((($11)) + -16|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($6) + ($13)|0);
  return ($14|0);
 }
 return (0)|0;
}
function __ZTv0_n28_NK5osgGA20TrackballManipulator12isSameKindAsEPKN3osg6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,9568,-1)|0);
 $phitmp$i = ($3|0)!=(0|0);
 $4 = $phitmp$i;
 return ($4|0);
}
function __ZTv0_n32_NK5osgGA20TrackballManipulator11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (109961|0);
}
function __ZTv0_n36_NK5osgGA20TrackballManipulator9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (109756|0);
}
function __ZN5osgGA20TrackballManipulatorC1ERKS0_RKN3osg6CopyOpE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 256|0);
 $4 = HEAP32[$1>>2]|0;
 $5 = ((($4)) + -16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($1) + ($6)|0);
 __ZN3osg6ObjectC2ERKS0_RKNS_6CopyOpE($3,$7,$2);
 $8 = ((($0)) + 248|0);
 $9 = HEAP32[$1>>2]|0;
 $10 = ((($9)) + -12|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($1) + ($11)|0);
 HEAP32[$8>>2] = ((29984));
 $13 = ((($8)) + 8|0);
 HEAP32[$13>>2] = ((30232));
 $14 = ((($0)) + 252|0);
 $15 = ((($12)) + 4|0);
 $16 = HEAP32[$15>>2]|0;
 HEAP32[$14>>2] = $16;
 $17 = ($16|0)==(0|0);
 if (!($17)) {
  $18 = HEAP32[$16>>2]|0;
  $19 = ((($18)) + -12|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = (($16) + ($20)|0);
  $22 = ((($21)) + 8|0);
  $23 = HEAP32[$22>>2]|0;HEAP32[$22>>2] = (($23+1)|0);
 }
 __THREW__ = 0;
 invoke_viiii(3530,($0|0),((43476)|0),($1|0),($2|0));
 $24 = __THREW__; __THREW__ = 0;
 $25 = $24&1;
 if (!($25)) {
  HEAP32[$0>>2] = (43616);
  HEAP32[$8>>2] = (44104);
  HEAP32[$3>>2] = (44352);
  $26 = ((($0)) + 4|0);
  HEAP32[$26>>2] = (43948);
  return;
 }
 $27 = ___cxa_find_matching_catch_2()|0;
 $28 = tempRet0;
 HEAP32[$8>>2] = ((29984));
 HEAP32[$13>>2] = ((30232));
 $29 = HEAP32[$14>>2]|0;
 $30 = ($29|0)==(0|0);
 if (!($30)) {
  $31 = HEAP32[$29>>2]|0;
  $32 = ((($31)) + -12|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = (($29) + ($33)|0);
  $35 = ((($34)) + 8|0);
  $36 = HEAP32[$35>>2]|0;HEAP32[$35>>2] = (($36-1)|0);
  $37 = ($36|0)==(1);
  if ($37) {
   __THREW__ = 0;
   invoke_viii(3262,($34|0),1,1);
   $38 = __THREW__; __THREW__ = 0;
   $39 = $38&1;
   if ($39) {
    $42 = ___cxa_find_matching_catch_3(0|0)|0;
    $43 = tempRet0;
    ___clang_call_terminate($42);
    // unreachable;
   }
  }
 }
 HEAP32[$14>>2] = 0;
 __THREW__ = 0;
 invoke_vi(388,($3|0));
 $40 = __THREW__; __THREW__ = 0;
 $41 = $40&1;
 if ($41) {
  $42 = ___cxa_find_matching_catch_3(0|0)|0;
  $43 = tempRet0;
  ___clang_call_terminate($42);
  // unreachable;
 } else {
  ___resumeException($27|0);
  // unreachable;
 }
}
function __ZN5osgGA16OrbitManipulator18OrbitAnimationDataD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK5osgGA17CameraManipulator9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (109900|0);
}
function __ZNK5osgGA17CameraManipulator21getFusionDistanceModeEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 1;
}
function __ZNK5osgGA17CameraManipulator22getFusionDistanceValueEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return +1;
}
function __ZN5osgGA17CameraManipulator7setNodeEPN3osg4NodeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZNK5osgGA17CameraManipulator7getNodeEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZN5osgGA17CameraManipulator7getNodeEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZN5osgGA17CameraManipulator15finishAnimationEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN5osgGA17CameraManipulator4homeERKNS_15GUIEventAdapterERNS_16GUIActionAdapterE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN5osgGA17CameraManipulator4homeEd($0,$1) {
 $0 = $0|0;
 $1 = +$1;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN5osgGA17CameraManipulator4initERKNS_15GUIEventAdapterERNS_16GUIActionAdapterE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZThn4_NK5osgGA17CameraManipulator9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (109900|0);
}
function __ZTv0_n32_NK5osgGA17CameraManipulator9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (109900|0);
}
function __ZTv0_n36_NK5osgGA17CameraManipulator9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (109900|0);
}
function __ZNK5osgGA19StandardManipulator9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (109918|0);
}
function __ZN5osgGA19StandardManipulatorD1Ev($0) {
 $0 = $0|0;
 var $$0 = 0, $$02 = 0, $$cast$i = 0, $$cast$i3 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vii(3527,($0|0),(46440|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if ($2) {
   $22 = ___cxa_find_matching_catch_2()|0;
   $23 = tempRet0;
   $24 = ((($0)) + 160|0);
   $25 = HEAP32[(46528)>>2]|0;
   HEAP32[$24>>2] = $25;
   $26 = HEAP32[(46532)>>2]|0;
   $$cast$i3 = $25;
   $27 = ((($$cast$i3)) + -12|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = (($24) + ($28)|0);
   HEAP32[$29>>2] = $26;
   $30 = ((($0)) + 164|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = ($31|0)==(0|0);
   if (!($32)) {
    $33 = HEAP32[$31>>2]|0;
    $34 = ((($33)) + -12|0);
    $35 = HEAP32[$34>>2]|0;
    $36 = (($31) + ($35)|0);
    $37 = ((($36)) + 8|0);
    $38 = HEAP32[$37>>2]|0;HEAP32[$37>>2] = (($38-1)|0);
    $39 = ($38|0)==(1);
    if ($39) {
     __THREW__ = 0;
     invoke_viii(3262,($36|0),1,1);
     $40 = __THREW__; __THREW__ = 0;
     $41 = $40&1;
     if ($41) {
      $47 = ___cxa_find_matching_catch_3(0|0)|0;
      $48 = tempRet0;
      ___clang_call_terminate($47);
      // unreachable;
     }
    }
   }
   HEAP32[$30>>2] = 0;
   $$0 = $23;$$02 = $22;
  } else {
   $3 = ((($0)) + 160|0);
   $4 = HEAP32[(46528)>>2]|0;
   HEAP32[$3>>2] = $4;
   $5 = HEAP32[(46532)>>2]|0;
   $$cast$i = $4;
   $6 = ((($$cast$i)) + -12|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = (($3) + ($7)|0);
   HEAP32[$8>>2] = $5;
   $9 = ((($0)) + 164|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($10|0)==(0|0);
   if ($11) {
    HEAP32[$9>>2] = 0;
    $21 = ((($0)) + 168|0);
    __ZN3osg6ObjectD2Ev($21);
    return;
   }
   $12 = HEAP32[$10>>2]|0;
   $13 = ((($12)) + -12|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = (($10) + ($14)|0);
   $16 = ((($15)) + 8|0);
   $17 = HEAP32[$16>>2]|0;HEAP32[$16>>2] = (($17-1)|0);
   $18 = ($17|0)==(1);
   if (!($18)) {
    HEAP32[$9>>2] = 0;
    $21 = ((($0)) + 168|0);
    __ZN3osg6ObjectD2Ev($21);
    return;
   }
   __THREW__ = 0;
   invoke_viii(3262,($15|0),1,1);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if ($20) {
    $42 = ___cxa_find_matching_catch_2()|0;
    $43 = tempRet0;
    $$0 = $43;$$02 = $42;
    break;
   } else {
    HEAP32[$9>>2] = 0;
    $21 = ((($0)) + 168|0);
    __ZN3osg6ObjectD2Ev($21);
    return;
   }
  }
 } while(0);
 $44 = ((($0)) + 168|0);
 __THREW__ = 0;
 invoke_vi(388,($44|0));
 $45 = __THREW__; __THREW__ = 0;
 $46 = $45&1;
 if ($46) {
  $47 = ___cxa_find_matching_catch_3(0|0)|0;
  $48 = tempRet0;
  ___clang_call_terminate($47);
  // unreachable;
 } else {
  ___resumeException($$02|0);
  // unreachable;
 }
}
function __ZN5osgGA19StandardManipulatorD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(915,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZN5osgGA19StandardManipulator18allocAnimationDataEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(48)|0);
 __THREW__ = 0;
 invoke_vi(3529,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $13 = ___cxa_find_matching_catch_2()|0;
  $14 = tempRet0;
  __ZdlPv($1);
  ___resumeException($13|0);
  // unreachable;
 }
 $4 = ((($0)) + 148|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==($1|0);
 if ($6) {
  return;
 }
 HEAP32[$4>>2] = $1;
 $7 = ((($1)) + 8|0);
 $8 = HEAP32[$7>>2]|0;HEAP32[$7>>2] = (($8+1)|0);
 $9 = ($5|0)==(0|0);
 if ($9) {
  return;
 }
 $10 = ((($5)) + 8|0);
 $11 = HEAP32[$10>>2]|0;HEAP32[$10>>2] = (($11-1)|0);
 $12 = ($11|0)==(1);
 if (!($12)) {
  return;
 }
 __ZNK3osg10Referenced24signalObserversAndDeleteEbb($5,1,1);
 return;
}
function __ZThn4_NK5osgGA19StandardManipulator9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (109918|0);
}
function __ZThn4_N5osgGA19StandardManipulatorD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -4|0);
 __ZN5osgGA19StandardManipulatorD1Ev($1);
 return;
}
function __ZThn4_N5osgGA19StandardManipulatorD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -4|0);
 __THREW__ = 0;
 invoke_vi(915,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch_2()|0;
  $5 = tempRet0;
  __ZdlPv($1);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZdlPv($1);
  return;
 }
}
function __ZTv0_n32_NK5osgGA19StandardManipulator9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (109918|0);
}
function __ZTv0_n112_N5osgGA19StandardManipulatorD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -112|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __ZN5osgGA19StandardManipulatorD1Ev($4);
 return;
}
function __ZTv0_n112_N5osgGA19StandardManipulatorD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -112|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __THREW__ = 0;
 invoke_vi(915,($4|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $7 = ___cxa_find_matching_catch_2()|0;
  $8 = tempRet0;
  __ZdlPv($4);
  ___resumeException($7|0);
  // unreachable;
 } else {
  __ZdlPv($4);
  return;
 }
}
function __ZTv0_n16_N5osgGA19StandardManipulatorD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __ZN5osgGA19StandardManipulatorD1Ev($4);
 return;
}
function __ZTv0_n16_N5osgGA19StandardManipulatorD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __THREW__ = 0;
 invoke_vi(915,($4|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $7 = ___cxa_find_matching_catch_2()|0;
  $8 = tempRet0;
  __ZdlPv($4);
  ___resumeException($7|0);
  // unreachable;
 } else {
  __ZdlPv($4);
  return;
 }
}
function __ZTv0_n36_NK5osgGA19StandardManipulator9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (109918|0);
}
function __ZNK5osgGA16OrbitManipulator9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(288)|0);
 __THREW__ = 0;
 invoke_vii(3531,($1|0),5);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $8 = ___cxa_find_matching_catch_2()|0;
  $9 = tempRet0;
  __ZdlPv($1);
  ___resumeException($8|0);
  // unreachable;
 } else {
  $4 = HEAP32[$1>>2]|0;
  $5 = ((($4)) + -16|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($1) + ($6)|0);
  return ($7|0);
 }
 return (0)|0;
}
function __ZNK5osgGA16OrbitManipulator5cloneERKN3osg6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(288)|0);
 __THREW__ = 0;
 invoke_viii(3532,($2|0),($0|0),($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $9 = ___cxa_find_matching_catch_2()|0;
  $10 = tempRet0;
  __ZdlPv($2);
  ___resumeException($9|0);
  // unreachable;
 } else {
  $5 = HEAP32[$2>>2]|0;
  $6 = ((($5)) + -16|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($2) + ($7)|0);
  return ($8|0);
 }
 return (0)|0;
}
function __ZNK5osgGA16OrbitManipulator12isSameKindAsEPKN3osg6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,12056,-1)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK5osgGA16OrbitManipulator11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (109961|0);
}
function __ZNK5osgGA16OrbitManipulator9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (109938|0);
}
function __ZN5osgGA16OrbitManipulatorD1Ev($0) {
 $0 = $0|0;
 var $$0 = 0, $$02 = 0, $$cast$i = 0, $$cast$i3 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vii(3527,($0|0),((45484)|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if ($2) {
   $22 = ___cxa_find_matching_catch_2()|0;
   $23 = tempRet0;
   $24 = ((($0)) + 248|0);
   $25 = HEAP32[(45584)>>2]|0;
   HEAP32[$24>>2] = $25;
   $26 = HEAP32[(45588)>>2]|0;
   $$cast$i3 = $25;
   $27 = ((($$cast$i3)) + -12|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = (($24) + ($28)|0);
   HEAP32[$29>>2] = $26;
   $30 = ((($0)) + 252|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = ($31|0)==(0|0);
   if (!($32)) {
    $33 = HEAP32[$31>>2]|0;
    $34 = ((($33)) + -12|0);
    $35 = HEAP32[$34>>2]|0;
    $36 = (($31) + ($35)|0);
    $37 = ((($36)) + 8|0);
    $38 = HEAP32[$37>>2]|0;HEAP32[$37>>2] = (($38-1)|0);
    $39 = ($38|0)==(1);
    if ($39) {
     __THREW__ = 0;
     invoke_viii(3262,($36|0),1,1);
     $40 = __THREW__; __THREW__ = 0;
     $41 = $40&1;
     if ($41) {
      $47 = ___cxa_find_matching_catch_3(0|0)|0;
      $48 = tempRet0;
      ___clang_call_terminate($47);
      // unreachable;
     }
    }
   }
   HEAP32[$30>>2] = 0;
   $$0 = $23;$$02 = $22;
  } else {
   $3 = ((($0)) + 248|0);
   $4 = HEAP32[(45584)>>2]|0;
   HEAP32[$3>>2] = $4;
   $5 = HEAP32[(45588)>>2]|0;
   $$cast$i = $4;
   $6 = ((($$cast$i)) + -12|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = (($3) + ($7)|0);
   HEAP32[$8>>2] = $5;
   $9 = ((($0)) + 252|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($10|0)==(0|0);
   if ($11) {
    HEAP32[$9>>2] = 0;
    $21 = ((($0)) + 256|0);
    __ZN3osg6ObjectD2Ev($21);
    return;
   }
   $12 = HEAP32[$10>>2]|0;
   $13 = ((($12)) + -12|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = (($10) + ($14)|0);
   $16 = ((($15)) + 8|0);
   $17 = HEAP32[$16>>2]|0;HEAP32[$16>>2] = (($17-1)|0);
   $18 = ($17|0)==(1);
   if (!($18)) {
    HEAP32[$9>>2] = 0;
    $21 = ((($0)) + 256|0);
    __ZN3osg6ObjectD2Ev($21);
    return;
   }
   __THREW__ = 0;
   invoke_viii(3262,($15|0),1,1);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if ($20) {
    $42 = ___cxa_find_matching_catch_2()|0;
    $43 = tempRet0;
    $$0 = $43;$$02 = $42;
    break;
   } else {
    HEAP32[$9>>2] = 0;
    $21 = ((($0)) + 256|0);
    __ZN3osg6ObjectD2Ev($21);
    return;
   }
  }
 } while(0);
 $44 = ((($0)) + 256|0);
 __THREW__ = 0;
 invoke_vi(388,($44|0));
 $45 = __THREW__; __THREW__ = 0;
 $46 = $45&1;
 if ($46) {
  $47 = ___cxa_find_matching_catch_3(0|0)|0;
  $48 = tempRet0;
  ___clang_call_terminate($47);
  // unreachable;
 } else {
  ___resumeException($$02|0);
  // unreachable;
 }
}
function __ZN5osgGA16OrbitManipulatorD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(891,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZThn4_NK5osgGA16OrbitManipulator9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(288)|0);
 __THREW__ = 0;
 invoke_vii(3531,($1|0),5);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch_2()|0;
  $5 = tempRet0;
  __ZdlPv($1);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $6 = HEAP32[$1>>2]|0;
  $7 = ((($6)) + -16|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($1) + ($8)|0);
  return ($9|0);
 }
 return (0)|0;
}
function __ZThn4_NK5osgGA16OrbitManipulator5cloneERKN3osg6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + -4|0);
 $3 = (__Znwj(288)|0);
 __THREW__ = 0;
 invoke_viii(3532,($3|0),($2|0),($1|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch_2()|0;
  $7 = tempRet0;
  __ZdlPv($3);
  ___resumeException($6|0);
  // unreachable;
 } else {
  $8 = HEAP32[$3>>2]|0;
  $9 = ((($8)) + -16|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($3) + ($10)|0);
  return ($11|0);
 }
 return (0)|0;
}
function __ZThn4_NK5osgGA16OrbitManipulator12isSameKindAsEPKN3osg6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,12056,-1)|0);
 $phitmp$i = ($3|0)!=(0|0);
 $4 = $phitmp$i;
 return ($4|0);
}
function __ZThn4_NK5osgGA16OrbitManipulator11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (109961|0);
}
function __ZThn4_NK5osgGA16OrbitManipulator9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (109938|0);
}
function __ZThn4_N5osgGA16OrbitManipulatorD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -4|0);
 __ZN5osgGA16OrbitManipulatorD1Ev($1);
 return;
}
function __ZThn4_N5osgGA16OrbitManipulatorD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -4|0);
 __THREW__ = 0;
 invoke_vi(891,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch_2()|0;
  $5 = tempRet0;
  __ZdlPv($1);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZdlPv($1);
  return;
 }
}
function __ZTv0_n16_NK5osgGA16OrbitManipulator9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(288)|0);
 __THREW__ = 0;
 invoke_vii(3531,($1|0),5);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch_2()|0;
  $5 = tempRet0;
  __ZdlPv($1);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $6 = HEAP32[$1>>2]|0;
  $7 = ((($6)) + -16|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($1) + ($8)|0);
  return ($9|0);
 }
 return (0)|0;
}
function __ZTv0_n20_NK5osgGA16OrbitManipulator5cloneERKN3osg6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $3 = ((($2)) + -20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($0) + ($4)|0);
 $6 = (__Znwj(288)|0);
 __THREW__ = 0;
 invoke_viii(3532,($6|0),($5|0),($1|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch_2()|0;
  $10 = tempRet0;
  __ZdlPv($6);
  ___resumeException($9|0);
  // unreachable;
 } else {
  $11 = HEAP32[$6>>2]|0;
  $12 = ((($11)) + -16|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($6) + ($13)|0);
  return ($14|0);
 }
 return (0)|0;
}
function __ZTv0_n24_NK5osgGA16OrbitManipulator12isSameKindAsEPKN3osg6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,12056,-1)|0);
 $phitmp$i = ($3|0)!=(0|0);
 $4 = $phitmp$i;
 return ($4|0);
}
function __ZTv0_n28_NK5osgGA16OrbitManipulator11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (109961|0);
}
function __ZTv0_n32_NK5osgGA16OrbitManipulator9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (109938|0);
}
function __ZTv0_n112_N5osgGA16OrbitManipulatorD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -112|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __ZN5osgGA16OrbitManipulatorD1Ev($4);
 return;
}
function __ZTv0_n112_N5osgGA16OrbitManipulatorD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -112|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __THREW__ = 0;
 invoke_vi(891,($4|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $7 = ___cxa_find_matching_catch_2()|0;
  $8 = tempRet0;
  __ZdlPv($4);
  ___resumeException($7|0);
  // unreachable;
 } else {
  __ZdlPv($4);
  return;
 }
}
function __ZTv0_n16_N5osgGA16OrbitManipulatorD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __ZN5osgGA16OrbitManipulatorD1Ev($4);
 return;
}
function __ZTv0_n16_N5osgGA16OrbitManipulatorD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __THREW__ = 0;
 invoke_vi(891,($4|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $7 = ___cxa_find_matching_catch_2()|0;
  $8 = tempRet0;
  __ZdlPv($4);
  ___resumeException($7|0);
  // unreachable;
 } else {
  __ZdlPv($4);
  return;
 }
}
function __ZTv0_n20_NK5osgGA16OrbitManipulator9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(288)|0);
 __THREW__ = 0;
 invoke_vii(3531,($1|0),5);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch_2()|0;
  $5 = tempRet0;
  __ZdlPv($1);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $6 = HEAP32[$1>>2]|0;
  $7 = ((($6)) + -16|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($1) + ($8)|0);
  return ($9|0);
 }
 return (0)|0;
}
function __ZTv0_n24_NK5osgGA16OrbitManipulator5cloneERKN3osg6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $3 = ((($2)) + -24|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($0) + ($4)|0);
 $6 = (__Znwj(288)|0);
 __THREW__ = 0;
 invoke_viii(3532,($6|0),($5|0),($1|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch_2()|0;
  $10 = tempRet0;
  __ZdlPv($6);
  ___resumeException($9|0);
  // unreachable;
 } else {
  $11 = HEAP32[$6>>2]|0;
  $12 = ((($11)) + -16|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($6) + ($13)|0);
  return ($14|0);
 }
 return (0)|0;
}
function __ZTv0_n28_NK5osgGA16OrbitManipulator12isSameKindAsEPKN3osg6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,12056,-1)|0);
 $phitmp$i = ($3|0)!=(0|0);
 $4 = $phitmp$i;
 return ($4|0);
}
function __ZTv0_n32_NK5osgGA16OrbitManipulator11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (109961|0);
}
function __ZTv0_n36_NK5osgGA16OrbitManipulator9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (109938|0);
}
function __ZN5osgGA5EventC2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg10ReferencedC2Ev($0);
 $1 = ((($0)) + 12|0);
 ;HEAP32[$1>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;
 $2 = ((($0)) + 24|0);
 HEAP32[$2>>2] = 2;
 $3 = ((($0)) + 28|0);
 HEAP32[$3>>2] = 0;
 HEAP32[$0>>2] = (44520);
 $4 = ((($0)) + 32|0);
 HEAP8[$4>>0] = 0;
 $5 = ((($0)) + 40|0);
 HEAPF64[$5>>3] = 0.0;
 return;
}
function __ZN5osgGA5EventD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(388,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK5osgGA5Event9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(48)|0);
 __THREW__ = 0;
 invoke_vi(3282,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $9 = ___cxa_find_matching_catch_2()|0;
  $10 = tempRet0;
  __ZdlPv($1);
  ___resumeException($9|0);
  // unreachable;
 } else {
  $4 = ((($1)) + 12|0);
  ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;
  $5 = ((($1)) + 24|0);
  HEAP32[$5>>2] = 2;
  $6 = ((($1)) + 28|0);
  HEAP32[$6>>2] = 0;
  HEAP32[$1>>2] = (44520);
  $7 = ((($1)) + 32|0);
  HEAP8[$7>>0] = 0;
  $8 = ((($1)) + 40|0);
  HEAPF64[$8>>3] = 0.0;
  return ($1|0);
 }
 return (0)|0;
}
function __ZNK5osgGA5Event5cloneERKN3osg6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0.0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(48)|0);
 __THREW__ = 0;
 invoke_viii(3468,($2|0),($0|0),($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $11 = ___cxa_find_matching_catch_2()|0;
  $12 = tempRet0;
  __ZdlPv($2);
  ___resumeException($11|0);
  // unreachable;
 } else {
  HEAP32[$2>>2] = (44520);
  $5 = ((($2)) + 32|0);
  $6 = ((($0)) + 32|0);
  $7 = HEAP8[$6>>0]|0;
  HEAP8[$5>>0] = $7;
  $8 = ((($2)) + 40|0);
  $9 = ((($0)) + 40|0);
  $10 = +HEAPF64[$9>>3];
  HEAPF64[$8>>3] = $10;
  return ($2|0);
 }
 return (0)|0;
}
function __ZNK5osgGA5Event12isSameKindAsEPKN3osg6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,8976,0)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK5osgGA5Event11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (109961|0);
}
function __ZNK5osgGA5Event9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (109955|0);
}
function __ZN5osgGA5Event17asGUIEventAdapterEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZNK5osgGA5Event17asGUIEventAdapterEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZN5osgGA5EventC2ERKS0_RKN3osg6CopyOpE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg6ObjectC2ERKS0_RKNS_6CopyOpE($0,$1,$2);
 HEAP32[$0>>2] = (44520);
 $3 = ((($0)) + 32|0);
 $4 = ((($1)) + 32|0);
 $5 = HEAP8[$4>>0]|0;
 HEAP8[$3>>0] = $5;
 $6 = ((($0)) + 40|0);
 $7 = ((($1)) + 40|0);
 $8 = +HEAPF64[$7>>3];
 HEAPF64[$6>>3] = $8;
 return;
}
function __ZN5osgGA17CameraManipulatorD1Ev($0) {
 $0 = $0|0;
 var $$0 = 0, $$02 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = ((44684));
 $1 = ((($0)) + 92|0);
 HEAP32[$1>>2] = ((45012));
 $2 = ((($0)) + 100|0);
 HEAP32[$2>>2] = ((45260));
 $3 = ((($0)) + 4|0);
 HEAP32[$3>>2] = ((44856));
 $4 = ((($0)) + 88|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  label = 4;
 } else {
  $7 = ((($5)) + 8|0);
  $8 = HEAP32[$7>>2]|0;HEAP32[$7>>2] = (($8-1)|0);
  $9 = ($8|0)==(1);
  if ($9) {
   __THREW__ = 0;
   invoke_viii(3262,($5|0),1,1);
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if ($11) {
    $14 = ___cxa_find_matching_catch_2()|0;
    $15 = tempRet0;
    __THREW__ = 0;
    invoke_vii(3484,($0|0),((45404)|0));
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     $18 = ___cxa_find_matching_catch_3(0|0)|0;
     $19 = tempRet0;
     ___clang_call_terminate($18);
     // unreachable;
    } else {
     $eh$lpad$body$index2Z2D = $15;$eh$lpad$body$indexZ2D = $14;
     label = 12;
    }
   } else {
    label = 4;
   }
  } else {
   label = 4;
  }
 }
 do {
  if ((label|0) == 4) {
   HEAP32[$4>>2] = 0;
   __THREW__ = 0;
   invoke_vii(3484,($0|0),((45404)|0));
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if ($13) {
    $33 = ___cxa_find_matching_catch_2()|0;
    $34 = tempRet0;
    $eh$lpad$body$index2Z2D = $34;$eh$lpad$body$indexZ2D = $33;
    label = 12;
    break;
   }
   HEAP32[$1>>2] = ((29984));
   $20 = ((($1)) + 8|0);
   HEAP32[$20>>2] = ((30232));
   $21 = ((($0)) + 96|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = ($22|0)==(0|0);
   if ($23) {
    HEAP32[$21>>2] = 0;
    __ZN3osg6ObjectD2Ev($2);
    return;
   }
   $24 = HEAP32[$22>>2]|0;
   $25 = ((($24)) + -12|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = (($22) + ($26)|0);
   $28 = ((($27)) + 8|0);
   $29 = HEAP32[$28>>2]|0;HEAP32[$28>>2] = (($29-1)|0);
   $30 = ($29|0)==(1);
   if (!($30)) {
    HEAP32[$21>>2] = 0;
    __ZN3osg6ObjectD2Ev($2);
    return;
   }
   __THREW__ = 0;
   invoke_viii(3262,($27|0),1,1);
   $31 = __THREW__; __THREW__ = 0;
   $32 = $31&1;
   if ($32) {
    $48 = ___cxa_find_matching_catch_2()|0;
    $49 = tempRet0;
    $$0 = $49;$$02 = $48;
    break;
   } else {
    HEAP32[$21>>2] = 0;
    __ZN3osg6ObjectD2Ev($2);
    return;
   }
  }
 } while(0);
 if ((label|0) == 12) {
  HEAP32[$1>>2] = ((29984));
  $35 = ((($1)) + 8|0);
  HEAP32[$35>>2] = ((30232));
  $36 = ((($0)) + 96|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = ($37|0)==(0|0);
  if (!($38)) {
   $39 = HEAP32[$37>>2]|0;
   $40 = ((($39)) + -12|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = (($37) + ($41)|0);
   $43 = ((($42)) + 8|0);
   $44 = HEAP32[$43>>2]|0;HEAP32[$43>>2] = (($44-1)|0);
   $45 = ($44|0)==(1);
   if ($45) {
    __THREW__ = 0;
    invoke_viii(3262,($42|0),1,1);
    $46 = __THREW__; __THREW__ = 0;
    $47 = $46&1;
    if ($47) {
     $52 = ___cxa_find_matching_catch_3(0|0)|0;
     $53 = tempRet0;
     ___clang_call_terminate($52);
     // unreachable;
    }
   }
  }
  HEAP32[$36>>2] = 0;
  $$0 = $eh$lpad$body$index2Z2D;$$02 = $eh$lpad$body$indexZ2D;
 }
 __THREW__ = 0;
 invoke_vi(388,($2|0));
 $50 = __THREW__; __THREW__ = 0;
 $51 = $50&1;
 if ($51) {
  $52 = ___cxa_find_matching_catch_3(0|0)|0;
  $53 = tempRet0;
  ___clang_call_terminate($52);
  // unreachable;
 } else {
  ___resumeException($$02|0);
  // unreachable;
 }
}
function __ZN5osgGA17CameraManipulatorD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(865,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZN5osgGA17CameraManipulator6handleERKNS_15GUIEventAdapterERNS_16GUIActionAdapterE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function __ZN5osgGA17CameraManipulator19computeHomePositionEPKN3osg6CameraEb($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$030 = 0.0, $$1 = 0.0, $$cast$i$i = 0, $$cast$i$i32 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0.0, $153 = 0, $154 = 0, $155 = 0.0, $156 = 0, $157 = 0, $158 = 0.0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0.0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0.0, $204 = 0.0;
 var $205 = 0.0, $206 = 0, $207 = 0, $208 = 0.0, $209 = 0.0, $21 = 0, $210 = 0.0, $211 = 0.0, $212 = 0.0, $213 = 0.0, $214 = 0.0, $215 = 0.0, $216 = 0.0, $217 = 0.0, $218 = 0.0, $219 = 0.0, $22 = 0, $220 = 0.0, $221 = 0, $222 = 0.0;
 var $223 = 0.0, $224 = 0.0, $225 = 0.0, $226 = 0.0, $227 = 0.0, $228 = 0, $229 = 0.0, $23 = 0, $230 = 0.0, $231 = 0.0, $232 = 0.0, $233 = 0.0, $234 = 0, $235 = 0, $236 = 0, $237 = 0.0, $238 = 0.0, $239 = 0.0, $24 = 0, $240 = 0.0;
 var $241 = 0.0, $242 = 0.0, $243 = 0.0, $244 = 0.0, $245 = 0.0, $246 = 0, $247 = 0.0, $248 = 0, $249 = 0.0, $25 = 0, $250 = 0.0, $251 = 0, $252 = 0.0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0.0, $65 = 0.0, $66 = 0, $67 = 0, $68 = 0.0, $69 = 0, $7 = 0, $70 = 0.0, $71 = 0, $72 = 0, $73 = 0.0, $74 = 0, $75 = 0.0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $eh$lpad$body$indexZ2D = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i33 = 0, $scevgep5$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i34 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 288|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(288|0);
 $3 = sp + 272|0;
 $4 = sp + 268|0;
 $5 = sp + 264|0;
 $6 = sp + 248|0;
 $7 = sp + 120|0;
 $8 = sp + 112|0;
 $9 = sp + 104|0;
 $10 = sp + 96|0;
 $11 = sp + 88|0;
 $12 = sp + 80|0;
 $13 = sp + 72|0;
 $14 = sp + 48|0;
 $15 = sp + 24|0;
 $16 = sp;
 $17 = HEAP32[$0>>2]|0;
 $18 = ((($17)) + 120|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (FUNCTION_TABLE_ii[$19 & 8191]($0)|0);
 $21 = ($20|0)==(0|0);
 if ($21) {
  STACKTOP = sp;return;
 }
 HEAPF32[$6>>2] = 0.0;
 $22 = ((($6)) + 4|0);
 HEAPF32[$22>>2] = 0.0;
 $23 = ((($6)) + 8|0);
 HEAPF32[$23>>2] = 0.0;
 $24 = ((($6)) + 12|0);
 HEAPF32[$24>>2] = -1.0;
 $25 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
 do {
  if ($25) {
   $26 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
   $27 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($26,109967,40)|0);
   $28 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEPKv($27,$1)|0);
   $29 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($28,146554,2)|0);
   $30 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEb($29,$2)|0);
   $31 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($30,174996,1)|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ((($32)) + -12|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = (($31) + ($34)|0);
   __ZNKSt3__28ios_base6getlocEv($5,$35);
   __THREW__ = 0;
   $36 = (invoke_iii(3255,($5|0),(215188|0))|0);
   $37 = __THREW__; __THREW__ = 0;
   $38 = $37&1;
   if (!($38)) {
    $39 = HEAP32[$36>>2]|0;
    $40 = ((($39)) + 28|0);
    $41 = HEAP32[$40>>2]|0;
    __THREW__ = 0;
    $42 = (invoke_iii($41|0,($36|0),10)|0);
    $43 = __THREW__; __THREW__ = 0;
    $44 = $43&1;
    if (!($44)) {
     __ZNSt3__26localeD2Ev($5);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($31,$42)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($31)|0);
     break;
    }
   }
   $45 = ___cxa_find_matching_catch_2()|0;
   $46 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($5|0));
   $47 = __THREW__; __THREW__ = 0;
   $48 = $47&1;
   if ($48) {
    $49 = ___cxa_find_matching_catch_3(0|0)|0;
    $50 = tempRet0;
    ___clang_call_terminate($49);
    // unreachable;
   } else {
    ___resumeException($45|0);
    // unreachable;
   }
  }
 } while(0);
 L14: do {
  if ($2) {
   __ZN3osg20ComputeBoundsVisitorC1ENS_11NodeVisitor13TraversalModeE($7,2);
   $51 = HEAP32[$0>>2]|0;
   $52 = ((($51)) + 120|0);
   $53 = HEAP32[$52>>2]|0;
   __THREW__ = 0;
   $54 = (invoke_ii($53|0,($0|0))|0);
   $55 = __THREW__; __THREW__ = 0;
   $56 = $55&1;
   do {
    if (!($56)) {
     $57 = HEAP32[$54>>2]|0;
     $58 = ((($57)) + 188|0);
     $59 = HEAP32[$58>>2]|0;
     __THREW__ = 0;
     invoke_vii($59|0,($54|0),($7|0));
     $60 = __THREW__; __THREW__ = 0;
     $61 = $60&1;
     if (!($61)) {
      $62 = ((($7)) + 68|0);
      $63 = ((($7)) + 80|0);
      $64 = +HEAPF32[$63>>2];
      $65 = +HEAPF32[$62>>2];
      $66 = !($64 >= $65);
      if ($66) {
       label = 16;
      } else {
       $67 = ((($7)) + 84|0);
       $68 = +HEAPF32[$67>>2];
       $69 = ((($7)) + 72|0);
       $70 = +HEAPF32[$69>>2];
       $71 = !($68 >= $70);
       if ($71) {
        label = 16;
       } else {
        $72 = ((($7)) + 88|0);
        $73 = +HEAPF32[$72>>2];
        $74 = ((($7)) + 76|0);
        $75 = +HEAPF32[$74>>2];
        $76 = !($73 >= $75);
        if ($76) {
         label = 16;
        } else {
         __THREW__ = 0;
         invoke_vii(3533,($6|0),($62|0));
         $77 = __THREW__; __THREW__ = 0;
         $78 = $77&1;
         if ($78) {
          break;
         }
        }
       }
      }
      if ((label|0) == 16) {
       $79 = HEAP32[$0>>2]|0;
       $80 = ((($79)) + 120|0);
       $81 = HEAP32[$80>>2]|0;
       __THREW__ = 0;
       $82 = (invoke_ii($81|0,($0|0))|0);
       $83 = __THREW__; __THREW__ = 0;
       $84 = $83&1;
       if ($84) {
        break;
       }
       __THREW__ = 0;
       $85 = (invoke_ii(3534,($82|0))|0);
       $86 = __THREW__; __THREW__ = 0;
       $87 = $86&1;
       if ($87) {
        break;
       }
       ;HEAP32[$6>>2]=HEAP32[$85>>2]|0;HEAP32[$6+4>>2]=HEAP32[$85+4>>2]|0;HEAP32[$6+8>>2]=HEAP32[$85+8>>2]|0;HEAP32[$6+12>>2]=HEAP32[$85+12>>2]|0;
      }
      $88 = HEAP32[14515]|0;
      HEAP32[$7>>2] = $88;
      $89 = HEAP32[(58072)>>2]|0;
      $$cast$i$i = $88;
      $90 = ((($$cast$i$i)) + -12|0);
      $91 = HEAP32[$90>>2]|0;
      $92 = (($7) + ($91)|0);
      HEAP32[$92>>2] = $89;
      $93 = ((($7)) + 56|0);
      $94 = HEAP32[$93>>2]|0;
      $95 = ($94|0)==(0|0);
      if (!($95)) {
       $96 = ((($7)) + 60|0);
       $97 = HEAP32[$96>>2]|0;
       $98 = ($97|0)==($94|0);
       if (!($98)) {
        $scevgep$i$i$i$i$i = ((($97)) + -128|0);
        $99 = $scevgep$i$i$i$i$i;
        $100 = $94;
        $101 = (($99) - ($100))|0;
        $102 = $101 >>> 7;
        $103 = $102 ^ -1;
        $scevgep5$i$i$i$i$i = (($97) + ($103<<7)|0);
        HEAP32[$96>>2] = $scevgep5$i$i$i$i$i;
       }
       __ZdlPv($94);
      }
      __THREW__ = 0;
      invoke_vii(3284,($7|0),((58064)|0));
      $104 = __THREW__; __THREW__ = 0;
      $105 = $104&1;
      if (!($105)) {
       $113 = ((($7)) + 92|0);
       __ZN3osg6ObjectD2Ev($113);
       break L14;
      }
      $106 = ___cxa_find_matching_catch_2()|0;
      $107 = tempRet0;
      $108 = ((($7)) + 92|0);
      __THREW__ = 0;
      invoke_vi(388,($108|0));
      $109 = __THREW__; __THREW__ = 0;
      $110 = $109&1;
      if ($110) {
       $111 = ___cxa_find_matching_catch_3(0|0)|0;
       $112 = tempRet0;
       ___clang_call_terminate($111);
       // unreachable;
      } else {
       ___resumeException($106|0);
       // unreachable;
      }
     }
    }
   } while(0);
   $114 = ___cxa_find_matching_catch_2()|0;
   $115 = tempRet0;
   $116 = HEAP32[14515]|0;
   HEAP32[$7>>2] = $116;
   $117 = HEAP32[(58072)>>2]|0;
   $$cast$i$i32 = $116;
   $118 = ((($$cast$i$i32)) + -12|0);
   $119 = HEAP32[$118>>2]|0;
   $120 = (($7) + ($119)|0);
   HEAP32[$120>>2] = $117;
   $121 = ((($7)) + 56|0);
   $122 = HEAP32[$121>>2]|0;
   $123 = ($122|0)==(0|0);
   if (!($123)) {
    $124 = ((($7)) + 60|0);
    $125 = HEAP32[$124>>2]|0;
    $126 = ($125|0)==($122|0);
    if (!($126)) {
     $scevgep$i$i$i$i$i33 = ((($125)) + -128|0);
     $127 = $scevgep$i$i$i$i$i33;
     $128 = $122;
     $129 = (($127) - ($128))|0;
     $130 = $129 >>> 7;
     $131 = $130 ^ -1;
     $scevgep5$i$i$i$i$i34 = (($125) + ($131<<7)|0);
     HEAP32[$124>>2] = $scevgep5$i$i$i$i$i34;
    }
    __ZdlPv($122);
   }
   __THREW__ = 0;
   invoke_vii(3284,($7|0),((58064)|0));
   $132 = __THREW__; __THREW__ = 0;
   $133 = $132&1;
   if ($133) {
    $137 = ___cxa_find_matching_catch_3(0|0)|0;
    $138 = tempRet0;
    $139 = ((($7)) + 92|0);
    __THREW__ = 0;
    invoke_vi(388,($139|0));
    $140 = __THREW__; __THREW__ = 0;
    $141 = $140&1;
    if ($141) {
     $142 = ___cxa_find_matching_catch_3(0|0)|0;
     $143 = tempRet0;
     ___clang_call_terminate($142);
     // unreachable;
    } else {
     $eh$lpad$body$indexZ2D = $137;
     ___clang_call_terminate($eh$lpad$body$indexZ2D);
     // unreachable;
    }
   }
   $134 = ((($7)) + 92|0);
   __THREW__ = 0;
   invoke_vi(388,($134|0));
   $135 = __THREW__; __THREW__ = 0;
   $136 = $135&1;
   if (!($136)) {
    ___resumeException($114|0);
    // unreachable;
   }
   $258 = ___cxa_find_matching_catch_3(0|0)|0;
   $259 = tempRet0;
   $eh$lpad$body$indexZ2D = $258;
   ___clang_call_terminate($eh$lpad$body$indexZ2D);
   // unreachable;
  } else {
   $144 = HEAP32[$0>>2]|0;
   $145 = ((($144)) + 120|0);
   $146 = HEAP32[$145>>2]|0;
   $147 = (FUNCTION_TABLE_ii[$146 & 8191]($0)|0);
   $148 = (__ZNK3osg4Node8getBoundEv($147)|0);
   ;HEAP32[$6>>2]=HEAP32[$148>>2]|0;HEAP32[$6+4>>2]=HEAP32[$148+4>>2]|0;HEAP32[$6+8>>2]=HEAP32[$148+8>>2]|0;HEAP32[$6+12>>2]=HEAP32[$148+12>>2]|0;
  }
 } while(0);
 $149 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
 do {
  if ($149) {
   $150 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
   $151 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($150,110008,31)|0);
   $152 = +HEAPF32[$6>>2];
   $153 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEf($151,$152)|0);
   $154 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($153,159071,1)|0);
   $155 = +HEAPF32[$22>>2];
   $156 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEf($154,$155)|0);
   $157 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($156,159071,1)|0);
   $158 = +HEAPF32[$23>>2];
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEf($157,$158)|0);
   $159 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($151,174996,1)|0);
   $160 = HEAP32[$159>>2]|0;
   $161 = ((($160)) + -12|0);
   $162 = HEAP32[$161>>2]|0;
   $163 = (($159) + ($162)|0);
   __ZNKSt3__28ios_base6getlocEv($3,$163);
   __THREW__ = 0;
   $164 = (invoke_iii(3255,($3|0),(215188|0))|0);
   $165 = __THREW__; __THREW__ = 0;
   $166 = $165&1;
   if (!($166)) {
    $167 = HEAP32[$164>>2]|0;
    $168 = ((($167)) + 28|0);
    $169 = HEAP32[$168>>2]|0;
    __THREW__ = 0;
    $170 = (invoke_iii($169|0,($164|0),10)|0);
    $171 = __THREW__; __THREW__ = 0;
    $172 = $171&1;
    if (!($172)) {
     __ZNSt3__26localeD2Ev($3);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($159,$170)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($159)|0);
     break;
    }
   }
   $173 = ___cxa_find_matching_catch_2()|0;
   $174 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($3|0));
   $175 = __THREW__; __THREW__ = 0;
   $176 = $175&1;
   if ($176) {
    $177 = ___cxa_find_matching_catch_3(0|0)|0;
    $178 = tempRet0;
    ___clang_call_terminate($177);
    // unreachable;
   } else {
    ___resumeException($173|0);
    // unreachable;
   }
  }
 } while(0);
 $179 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
 do {
  if ($179) {
   $180 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
   $181 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($180,110040,30)|0);
   $182 = +HEAPF32[$24>>2];
   $183 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEf($181,$182)|0);
   $184 = HEAP32[$183>>2]|0;
   $185 = ((($184)) + -12|0);
   $186 = HEAP32[$185>>2]|0;
   $187 = (($183) + ($186)|0);
   __ZNKSt3__28ios_base6getlocEv($4,$187);
   __THREW__ = 0;
   $188 = (invoke_iii(3255,($4|0),(215188|0))|0);
   $189 = __THREW__; __THREW__ = 0;
   $190 = $189&1;
   if (!($190)) {
    $191 = HEAP32[$188>>2]|0;
    $192 = ((($191)) + 28|0);
    $193 = HEAP32[$192>>2]|0;
    __THREW__ = 0;
    $194 = (invoke_iii($193|0,($188|0),10)|0);
    $195 = __THREW__; __THREW__ = 0;
    $196 = $195&1;
    if (!($196)) {
     __ZNSt3__26localeD2Ev($4);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($183,$194)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($183)|0);
     break;
    }
   }
   $197 = ___cxa_find_matching_catch_2()|0;
   $198 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($4|0));
   $199 = __THREW__; __THREW__ = 0;
   $200 = $199&1;
   if ($200) {
    $201 = ___cxa_find_matching_catch_3(0|0)|0;
    $202 = tempRet0;
    ___clang_call_terminate($201);
    // unreachable;
   } else {
    ___resumeException($197|0);
    // unreachable;
   }
  }
 } while(0);
 $203 = +HEAPF32[$24>>2];
 $204 = $203 * 3.5;
 $205 = $204;
 $206 = ($1|0)==(0|0);
 if ($206) {
  $$1 = $205;
 } else {
  $207 = (__ZNK3osg6Camera28getProjectionMatrixAsFrustumERdS1_S1_S1_S1_S1_($1,$8,$9,$10,$11,$12,$13)|0);
  if ($207) {
   $208 = +HEAPF64[$9>>3];
   $209 = +HEAPF64[$8>>3];
   $210 = $208 - $209;
   $211 = (+Math_abs((+$210)));
   $212 = +HEAPF64[$12>>3];
   $213 = $211 / $212;
   $214 = $213 * 0.5;
   $215 = +HEAPF64[$11>>3];
   $216 = +HEAPF64[$10>>3];
   $217 = $215 - $216;
   $218 = (+Math_abs((+$217)));
   $219 = $218 / $212;
   $220 = $219 * 0.5;
   $221 = $220 < $214;
   $222 = $221 ? $220 : $214;
   $223 = (+Math_atan2((+$222),1.0));
   $224 = +HEAPF32[$24>>2];
   $225 = $224;
   $226 = (+Math_sin((+$223)));
   $227 = $225 / $226;
   $$030 = $227;
  } else {
   $228 = (__ZNK3osg6Camera26getProjectionMatrixAsOrthoERdS1_S1_S1_S1_S1_($1,$8,$9,$10,$11,$12,$13)|0);
   if ($228) {
    $229 = +HEAPF64[$13>>3];
    $230 = +HEAPF64[$12>>3];
    $231 = $229 - $230;
    $232 = (+Math_abs((+$231)));
    $233 = $232 * 0.5;
    $$030 = $233;
   } else {
    $$030 = $205;
   }
  }
  $$1 = $$030;
 }
 $234 = HEAP32[$0>>2]|0;
 $235 = ((($234)) + 124|0);
 $236 = HEAP32[$235>>2]|0;
 $237 = $$1;
 $238 = +HEAPF32[$6>>2];
 $239 = $238 + 0.0;
 $240 = +HEAPF32[$22>>2];
 $241 = $240 - $237;
 $242 = +HEAPF32[$23>>2];
 $243 = $242 + 0.0;
 $244 = $239;
 HEAPF64[$14>>3] = $244;
 $245 = $241;
 $246 = ((($14)) + 8|0);
 HEAPF64[$246>>3] = $245;
 $247 = $243;
 $248 = ((($14)) + 16|0);
 HEAPF64[$248>>3] = $247;
 $249 = $238;
 HEAPF64[$15>>3] = $249;
 $250 = $240;
 $251 = ((($15)) + 8|0);
 HEAPF64[$251>>3] = $250;
 $252 = $242;
 $253 = ((($15)) + 16|0);
 HEAPF64[$253>>3] = $252;
 $254 = ((($16)) + 16|0);
 ;HEAP32[$16>>2]=0|0;HEAP32[$16+4>>2]=0|0;HEAP32[$16+8>>2]=0|0;HEAP32[$16+12>>2]=0|0;
 HEAPF64[$254>>3] = 1.0;
 $255 = ((($0)) + 12|0);
 $256 = HEAP8[$255>>0]|0;
 $257 = ($256<<24>>24)!=(0);
 FUNCTION_TABLE_viiiii[$236 & 8191]($0,$14,$15,$16,$257);
 STACKTOP = sp;return;
}
function __ZThn4_N5osgGA17CameraManipulatorD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -4|0);
 __ZN5osgGA17CameraManipulatorD1Ev($1);
 return;
}
function __ZThn4_N5osgGA17CameraManipulatorD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -4|0);
 __THREW__ = 0;
 invoke_vi(865,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch_2()|0;
  $5 = tempRet0;
  __ZdlPv($1);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZdlPv($1);
  return;
 }
}
function __ZTv0_n112_N5osgGA17CameraManipulatorD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -112|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __ZN5osgGA17CameraManipulatorD1Ev($4);
 return;
}
function __ZTv0_n112_N5osgGA17CameraManipulatorD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -112|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __THREW__ = 0;
 invoke_vi(865,($4|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $7 = ___cxa_find_matching_catch_2()|0;
  $8 = tempRet0;
  __ZdlPv($4);
  ___resumeException($7|0);
  // unreachable;
 } else {
  __ZdlPv($4);
  return;
 }
}
function __ZTv0_n16_N5osgGA17CameraManipulatorD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __ZN5osgGA17CameraManipulatorD1Ev($4);
 return;
}
function __ZTv0_n16_N5osgGA17CameraManipulatorD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __THREW__ = 0;
 invoke_vi(865,($4|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $7 = ___cxa_find_matching_catch_2()|0;
  $8 = tempRet0;
  __ZdlPv($4);
  ___resumeException($7|0);
  // unreachable;
 } else {
  __ZdlPv($4);
  return;
 }
}
function __ZN3osg18BoundingSphereImplINS_5Vec3fEE8expandByIS1_EEvRKNS_15BoundingBoxImplIT_EE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$068 = 0, $$sink$i = 0, $$sink1$i = 0, $$sink2$i = 0, $$sroa$024$0 = 0.0, $$sroa$037$062 = 0.0, $$sroa$037$1 = 0.0, $$sroa$11$0 = 0.0, $$sroa$1145$064 = 0.0, $$sroa$1145$1 = 0.0, $$sroa$15$065 = 0.0, $$sroa$15$1 = 0.0, $$sroa$19$066 = 0.0, $$sroa$19$1 = 0.0, $$sroa$20$0 = 0.0, $$sroa$23$067 = 0.0, $$sroa$23$1 = 0.0, $$sroa$4$0$$sroa_idx10 = 0, $$sroa$5$0$$sroa_idx12 = 0, $$sroa$7$063 = 0.0;
 var $$sroa$7$1 = 0.0, $10 = 0, $100 = 0.0, $101 = 0.0, $11 = 0, $12 = 0.0, $13 = 0, $14 = 0.0, $15 = 0, $16 = 0, $17 = 0.0, $18 = 0, $19 = 0, $2 = 0, $20 = 0.0, $21 = 0, $22 = 0.0, $23 = 0, $24 = 0.0, $25 = 0.0;
 var $26 = 0.0, $27 = 0.0, $28 = 0.0, $29 = 0.0, $3 = 0.0, $30 = 0.0, $31 = 0.0, $32 = 0.0, $33 = 0.0, $34 = 0.0, $35 = 0.0, $36 = 0.0, $37 = 0.0, $38 = 0.0, $39 = 0.0, $4 = 0.0, $40 = 0.0, $41 = 0.0, $42 = 0, $43 = 0;
 var $44 = 0.0, $45 = 0, $46 = 0, $47 = 0, $48 = 0.0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0.0, $53 = 0.0, $54 = 0.0, $55 = 0.0, $56 = 0.0, $57 = 0.0, $58 = 0.0, $59 = 0.0, $6 = 0, $60 = 0.0, $61 = 0.0;
 var $62 = 0, $63 = 0.0, $64 = 0.0, $65 = 0.0, $66 = 0.0, $67 = 0.0, $68 = 0.0, $69 = 0.0, $7 = 0.0, $70 = 0.0, $71 = 0.0, $72 = 0.0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0.0, $81 = 0.0, $82 = 0.0, $83 = 0.0, $84 = 0.0, $85 = 0.0, $86 = 0.0, $87 = 0.0, $88 = 0.0, $89 = 0.0, $9 = 0.0, $90 = 0.0, $91 = 0.0, $92 = 0.0, $93 = 0.0, $94 = 0.0, $95 = 0.0, $96 = 0.0, $97 = 0.0, $98 = 0.0;
 var $99 = 0.0, $exitcond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 12|0);
 $3 = +HEAPF32[$2>>2];
 $4 = +HEAPF32[$1>>2];
 $5 = !($3 >= $4);
 if ($5) {
  return;
 }
 $6 = ((($1)) + 16|0);
 $7 = +HEAPF32[$6>>2];
 $8 = ((($1)) + 4|0);
 $9 = +HEAPF32[$8>>2];
 $10 = !($7 >= $9);
 if ($10) {
  return;
 }
 $11 = ((($1)) + 20|0);
 $12 = +HEAPF32[$11>>2];
 $13 = ((($1)) + 8|0);
 $14 = +HEAPF32[$13>>2];
 $15 = !($12 >= $14);
 if ($15) {
  return;
 }
 $16 = ((($0)) + 12|0);
 $17 = +HEAPF32[$16>>2];
 $18 = !($17 >= 0.0);
 if ($18) {
  $80 = $4 + $3;
  $81 = $9 + $7;
  $82 = $14 + $12;
  $83 = $80 * 0.5;
  $84 = $81 * 0.5;
  $85 = $82 * 0.5;
  HEAPF32[$0>>2] = $83;
  $$sroa$4$0$$sroa_idx10 = ((($0)) + 4|0);
  HEAPF32[$$sroa$4$0$$sroa_idx10>>2] = $84;
  $$sroa$5$0$$sroa_idx12 = ((($0)) + 8|0);
  HEAPF32[$$sroa$5$0$$sroa_idx12>>2] = $85;
  $86 = +HEAPF32[$2>>2];
  $87 = +HEAPF32[$1>>2];
  $88 = $86 - $87;
  $89 = +HEAPF32[$6>>2];
  $90 = +HEAPF32[$8>>2];
  $91 = $89 - $90;
  $92 = +HEAPF32[$11>>2];
  $93 = +HEAPF32[$13>>2];
  $94 = $92 - $93;
  $95 = $88 * $88;
  $96 = $91 * $91;
  $97 = $95 + $96;
  $98 = $94 * $94;
  $99 = $97 + $98;
  $100 = $99 * 0.25;
  $101 = (+Math_sqrt((+$100)));
  HEAPF32[$16>>2] = $101;
  return;
 }
 $19 = ((($1)) + 12|0);
 $20 = +HEAPF32[$0>>2];
 $21 = ((($0)) + 4|0);
 $22 = +HEAPF32[$21>>2];
 $23 = ((($0)) + 8|0);
 $24 = +HEAPF32[$23>>2];
 $25 = -$17;
 $$068 = 0;$$sroa$037$062 = $4;$$sroa$1145$064 = $14;$$sroa$15$065 = $3;$$sroa$19$066 = $7;$$sroa$23$067 = $12;$$sroa$7$063 = $9;
 while(1) {
  $42 = $$068 & 1;
  $43 = ($42|0)!=(0);
  $$sink$i = $43 ? $19 : $1;
  $44 = +HEAPF32[$$sink$i>>2];
  $45 = $$068 & 2;
  $46 = ($45|0)!=(0);
  $$sink1$i = $46 ? $19 : $1;
  $47 = ((($$sink1$i)) + 4|0);
  $48 = +HEAPF32[$47>>2];
  $49 = $$068 & 4;
  $50 = ($49|0)!=(0);
  $$sink2$i = $50 ? $19 : $1;
  $51 = ((($$sink2$i)) + 8|0);
  $52 = +HEAPF32[$51>>2];
  $53 = $44 - $20;
  $54 = $48 - $22;
  $55 = $52 - $24;
  $56 = $53 * $53;
  $57 = $54 * $54;
  $58 = $56 + $57;
  $59 = $55 * $55;
  $60 = $58 + $59;
  $61 = (+Math_sqrt((+$60)));
  $62 = $61 > 0.0;
  $63 = 1.0 / $61;
  $64 = $53 * $63;
  $65 = $54 * $63;
  $66 = $55 * $63;
  $$sroa$024$0 = $62 ? $64 : $53;
  $$sroa$11$0 = $62 ? $65 : $54;
  $$sroa$20$0 = $62 ? $66 : $55;
  $67 = $$sroa$024$0 * $25;
  $68 = $$sroa$11$0 * $25;
  $69 = $$sroa$20$0 * $25;
  $70 = $20 + $67;
  $71 = $22 + $68;
  $72 = $24 + $69;
  $73 = $70 < $$sroa$037$062;
  $$sroa$037$1 = $73 ? $70 : $$sroa$037$062;
  $74 = $70 > $$sroa$15$065;
  $$sroa$15$1 = $74 ? $70 : $$sroa$15$065;
  $75 = $71 < $$sroa$7$063;
  $$sroa$7$1 = $75 ? $71 : $$sroa$7$063;
  $76 = $71 > $$sroa$19$066;
  $$sroa$19$1 = $76 ? $71 : $$sroa$19$066;
  $77 = $72 < $$sroa$1145$064;
  $$sroa$1145$1 = $77 ? $72 : $$sroa$1145$064;
  $78 = $72 > $$sroa$23$067;
  $$sroa$23$1 = $78 ? $72 : $$sroa$23$067;
  $79 = (($$068) + 1)|0;
  $exitcond = ($79|0)==(8);
  if ($exitcond) {
   break;
  } else {
   $$068 = $79;$$sroa$037$062 = $$sroa$037$1;$$sroa$1145$064 = $$sroa$1145$1;$$sroa$15$065 = $$sroa$15$1;$$sroa$19$066 = $$sroa$19$1;$$sroa$23$067 = $$sroa$23$1;$$sroa$7$063 = $$sroa$7$1;
  }
 }
 $26 = $$sroa$037$1 + $$sroa$15$1;
 $27 = $$sroa$7$1 + $$sroa$19$1;
 $28 = $$sroa$1145$1 + $$sroa$23$1;
 $29 = $26 * 0.5;
 $30 = $27 * 0.5;
 $31 = $28 * 0.5;
 HEAPF32[$0>>2] = $29;
 HEAPF32[$21>>2] = $30;
 HEAPF32[$23>>2] = $31;
 $32 = $$sroa$15$1 - $$sroa$037$1;
 $33 = $$sroa$19$1 - $$sroa$7$1;
 $34 = $$sroa$23$1 - $$sroa$1145$1;
 $35 = $32 * $32;
 $36 = $33 * $33;
 $37 = $35 + $36;
 $38 = $34 * $34;
 $39 = $37 + $38;
 $40 = $39 * 0.25;
 $41 = (+Math_sqrt((+$40)));
 HEAPF32[$16>>2] = $41;
 return;
}
function __ZNK3osg4Node8getBoundEv($0) {
 $0 = $0|0;
 var $$pre = 0, $$pre$phiZ2D = 0, $1 = 0, $10 = 0, $100 = 0.0, $101 = 0, $102 = 0.0, $103 = 0, $104 = 0.0, $105 = 0.0, $106 = 0.0, $107 = 0.0, $108 = 0.0, $109 = 0.0, $11 = 0, $110 = 0.0, $111 = 0.0, $112 = 0.0, $113 = 0.0, $114 = 0.0;
 var $115 = 0.0, $116 = 0.0, $117 = 0.0, $118 = 0.0, $119 = 0.0, $12 = 0, $120 = 0.0, $121 = 0.0, $122 = 0.0, $123 = 0.0, $124 = 0.0, $125 = 0.0, $126 = 0.0, $13 = 0, $14 = 0, $15 = 0.0, $16 = 0, $17 = 0, $18 = 0.0, $19 = 0;
 var $2 = 0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0, $24 = 0.0, $25 = 0, $26 = 0.0, $27 = 0.0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0.0, $32 = 0.0, $33 = 0.0, $34 = 0.0, $35 = 0.0, $36 = 0.0, $37 = 0.0;
 var $38 = 0.0, $39 = 0.0, $4 = 0, $40 = 0.0, $41 = 0.0, $42 = 0.0, $43 = 0, $44 = 0.0, $45 = 0, $46 = 0.0, $47 = 0.0, $48 = 0.0, $49 = 0.0, $5 = 0, $50 = 0.0, $51 = 0.0, $52 = 0.0, $53 = 0.0, $54 = 0.0, $55 = 0.0;
 var $56 = 0.0, $57 = 0.0, $58 = 0.0, $59 = 0.0, $6 = 0, $60 = 0.0, $61 = 0.0, $62 = 0.0, $63 = 0.0, $64 = 0.0, $65 = 0.0, $66 = 0.0, $67 = 0.0, $68 = 0.0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0.0;
 var $74 = 0, $75 = 0, $76 = 0.0, $77 = 0, $78 = 0.0, $79 = 0.0, $8 = 0, $80 = 0.0, $81 = 0, $82 = 0.0, $83 = 0, $84 = 0.0, $85 = 0.0, $86 = 0, $87 = 0.0, $88 = 0, $89 = 0.0, $9 = 0, $90 = 0.0, $91 = 0.0;
 var $92 = 0.0, $93 = 0.0, $94 = 0.0, $95 = 0.0, $96 = 0.0, $97 = 0.0, $98 = 0.0, $99 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $1 = sp + 16|0;
 $2 = sp;
 $3 = ((($0)) + 68|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)==(0);
 if (!($5)) {
  $$pre = ((($0)) + 52|0);
  $$pre$phiZ2D = $$pre;
  STACKTOP = sp;return ($$pre$phiZ2D|0);
 }
 $6 = ((($0)) + 32|0);
 $7 = ((($0)) + 52|0);
 ;HEAP32[$7>>2]=HEAP32[$6>>2]|0;HEAP32[$7+4>>2]=HEAP32[$6+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[$6+8>>2]|0;HEAP32[$7+12>>2]=HEAP32[$6+12>>2]|0;
 $8 = ((($0)) + 48|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if ($10) {
  $69 = HEAP32[$0>>2]|0;
  $70 = ((($69)) + 200|0);
  $71 = HEAP32[$70>>2]|0;
  FUNCTION_TABLE_vii[$71 & 8191]($2,$0);
  $72 = ((($2)) + 12|0);
  $73 = +HEAPF32[$72>>2];
  $74 = !($73 >= 0.0);
  do {
   if (!($74)) {
    $75 = ((($0)) + 64|0);
    $76 = +HEAPF32[$75>>2];
    $77 = !($76 >= 0.0);
    if ($77) {
     ;HEAP32[$7>>2]=HEAP32[$2>>2]|0;HEAP32[$7+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[$2+8>>2]|0;
     HEAPF32[$75>>2] = $73;
     break;
    }
    $78 = +HEAPF32[$7>>2];
    $79 = +HEAPF32[$2>>2];
    $80 = $78 - $79;
    $81 = ((($0)) + 56|0);
    $82 = +HEAPF32[$81>>2];
    $83 = ((($2)) + 4|0);
    $84 = +HEAPF32[$83>>2];
    $85 = $82 - $84;
    $86 = ((($0)) + 60|0);
    $87 = +HEAPF32[$86>>2];
    $88 = ((($2)) + 8|0);
    $89 = +HEAPF32[$88>>2];
    $90 = $87 - $89;
    $91 = $80 * $80;
    $92 = $85 * $85;
    $93 = $91 + $92;
    $94 = $90 * $90;
    $95 = $93 + $94;
    $96 = (+Math_sqrt((+$95)));
    $97 = $96;
    $98 = $73;
    $99 = $98 + $97;
    $100 = $76;
    $101 = !($99 <= $100);
    if ($101) {
     $102 = $100 + $97;
     $103 = !($102 <= $98);
     if ($103) {
      $104 = $98 + $102;
      $105 = $104 * 0.5;
      $106 = $105 - $100;
      $107 = $106 / $97;
      $108 = $79 - $78;
      $109 = $108;
      $110 = $109 * $107;
      $111 = $78;
      $112 = $111 + $110;
      $113 = $112;
      HEAPF32[$7>>2] = $113;
      $114 = $84 - $82;
      $115 = $114;
      $116 = $107 * $115;
      $117 = $82;
      $118 = $117 + $116;
      $119 = $118;
      HEAPF32[$81>>2] = $119;
      $120 = $89 - $87;
      $121 = $120;
      $122 = $107 * $121;
      $123 = $87;
      $124 = $123 + $122;
      $125 = $124;
      HEAPF32[$86>>2] = $125;
      $126 = $105;
      HEAPF32[$75>>2] = $126;
      break;
     } else {
      ;HEAP32[$7>>2]=HEAP32[$2>>2]|0;HEAP32[$7+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[$2+8>>2]|0;
      HEAPF32[$75>>2] = $73;
      break;
     }
    }
   }
  } while(0);
 } else {
  $11 = HEAP32[$9>>2]|0;
  $12 = ((($11)) + 140|0);
  $13 = HEAP32[$12>>2]|0;
  FUNCTION_TABLE_viii[$13 & 8191]($1,$9,$0);
  $14 = ((($1)) + 12|0);
  $15 = +HEAPF32[$14>>2];
  $16 = !($15 >= 0.0);
  do {
   if (!($16)) {
    $17 = ((($0)) + 64|0);
    $18 = +HEAPF32[$17>>2];
    $19 = !($18 >= 0.0);
    if ($19) {
     ;HEAP32[$7>>2]=HEAP32[$1>>2]|0;HEAP32[$7+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[$1+8>>2]|0;
     HEAPF32[$17>>2] = $15;
     break;
    }
    $20 = +HEAPF32[$7>>2];
    $21 = +HEAPF32[$1>>2];
    $22 = $20 - $21;
    $23 = ((($0)) + 56|0);
    $24 = +HEAPF32[$23>>2];
    $25 = ((($1)) + 4|0);
    $26 = +HEAPF32[$25>>2];
    $27 = $24 - $26;
    $28 = ((($0)) + 60|0);
    $29 = +HEAPF32[$28>>2];
    $30 = ((($1)) + 8|0);
    $31 = +HEAPF32[$30>>2];
    $32 = $29 - $31;
    $33 = $22 * $22;
    $34 = $27 * $27;
    $35 = $33 + $34;
    $36 = $32 * $32;
    $37 = $35 + $36;
    $38 = (+Math_sqrt((+$37)));
    $39 = $38;
    $40 = $15;
    $41 = $40 + $39;
    $42 = $18;
    $43 = !($41 <= $42);
    if ($43) {
     $44 = $42 + $39;
     $45 = !($44 <= $40);
     if ($45) {
      $46 = $40 + $44;
      $47 = $46 * 0.5;
      $48 = $47 - $42;
      $49 = $48 / $39;
      $50 = $21 - $20;
      $51 = $50;
      $52 = $51 * $49;
      $53 = $20;
      $54 = $53 + $52;
      $55 = $54;
      HEAPF32[$7>>2] = $55;
      $56 = $26 - $24;
      $57 = $56;
      $58 = $49 * $57;
      $59 = $24;
      $60 = $59 + $58;
      $61 = $60;
      HEAPF32[$23>>2] = $61;
      $62 = $31 - $29;
      $63 = $62;
      $64 = $49 * $63;
      $65 = $29;
      $66 = $65 + $64;
      $67 = $66;
      HEAPF32[$28>>2] = $67;
      $68 = $47;
      HEAPF32[$17>>2] = $68;
      break;
     } else {
      ;HEAP32[$7>>2]=HEAP32[$1>>2]|0;HEAP32[$7+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[$1+8>>2]|0;
      HEAPF32[$17>>2] = $15;
      break;
     }
    }
   }
  } while(0);
 }
 HEAP8[$3>>0] = 1;
 $$pre$phiZ2D = $7;
 STACKTOP = sp;return ($$pre$phiZ2D|0);
}
function __ZN5osgGA17CameraManipulatorC2Ev($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$cast = 0, $$cast$i = 0, $$cast$i$i = 0, $$cast$i$i$i = 0, $$cast$i2$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 4|0);
 $3 = ((($1)) + 8|0);
 $4 = ((($1)) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 HEAP32[$0>>2] = $5;
 $6 = ((($1)) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $$cast$i$i$i = $5;
 $8 = ((($$cast$i$i$i)) + -12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($0) + ($9)|0);
 HEAP32[$10>>2] = $7;
 $11 = ((($1)) + 20|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = HEAP32[$0>>2]|0;
 $14 = ((($13)) + -16|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($0) + ($15)|0);
 HEAP32[$16>>2] = $12;
 $17 = ((($0)) + 4|0);
 $18 = ((($1)) + 24|0);
 $19 = HEAP32[$18>>2]|0;
 HEAP32[$17>>2] = $19;
 $20 = ((($1)) + 28|0);
 $21 = HEAP32[$20>>2]|0;
 $$cast$i2$i$i = $19;
 $22 = ((($$cast$i2$i$i)) + -12|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($17) + ($23)|0);
 HEAP32[$24>>2] = $21;
 $25 = ((($1)) + 32|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = HEAP32[$17>>2]|0;
 $28 = ((($27)) + -16|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (($17) + ($29)|0);
 HEAP32[$30>>2] = $26;
 $31 = HEAP32[$3>>2]|0;
 HEAP32[$0>>2] = $31;
 $32 = ((($1)) + 36|0);
 $33 = HEAP32[$32>>2]|0;
 $$cast$i$i = $31;
 $34 = ((($$cast$i$i)) + -12|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (($0) + ($35)|0);
 HEAP32[$36>>2] = $33;
 $37 = ((($1)) + 40|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = HEAP32[$0>>2]|0;
 $40 = ((($39)) + -16|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = (($0) + ($41)|0);
 HEAP32[$42>>2] = $38;
 $43 = ((($1)) + 44|0);
 $44 = HEAP32[$43>>2]|0;
 HEAP32[$17>>2] = $44;
 $45 = HEAP32[$2>>2]|0;
 HEAP32[$0>>2] = $45;
 $46 = ((($1)) + 48|0);
 $47 = HEAP32[$46>>2]|0;
 $$cast$i = $45;
 $48 = ((($$cast$i)) + -12|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = (($0) + ($49)|0);
 HEAP32[$50>>2] = $47;
 $51 = ((($1)) + 52|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = HEAP32[$0>>2]|0;
 $54 = ((($53)) + -16|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = (($0) + ($55)|0);
 HEAP32[$56>>2] = $52;
 $57 = ((($1)) + 56|0);
 $58 = HEAP32[$57>>2]|0;
 HEAP32[$17>>2] = $58;
 $59 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $59;
 $60 = ((($1)) + 60|0);
 $61 = HEAP32[$60>>2]|0;
 $$cast = $59;
 $62 = ((($$cast)) + -12|0);
 $63 = HEAP32[$62>>2]|0;
 $64 = (($0) + ($63)|0);
 HEAP32[$64>>2] = $61;
 $65 = ((($1)) + 64|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = HEAP32[$0>>2]|0;
 $68 = ((($67)) + -16|0);
 $69 = HEAP32[$68>>2]|0;
 $70 = (($0) + ($69)|0);
 HEAP32[$70>>2] = $66;
 $71 = ((($1)) + 68|0);
 $72 = HEAP32[$71>>2]|0;
 HEAP32[$17>>2] = $72;
 $73 = ((($0)) + 16|0);
 $74 = ((($0)) + 8|0);
 $75 = ((($73)) + 72|0);
 HEAP32[$75>>2] = 0;
 HEAP32[$74>>2] = -1;
 $76 = ((($0)) + 12|0);
 HEAP8[$76>>0] = 1;
 HEAPF64[$73>>3] = 0.0;
 $77 = ((($0)) + 24|0);
 HEAPF64[$77>>3] = -1.0;
 $78 = ((($0)) + 32|0);
 $79 = ((($0)) + 80|0);
 dest=$78; stop=dest+48|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF64[$79>>3] = 1.0;
 return;
}
function __ZN5osgGA17CameraManipulatorC2ERKS0_RKN3osg6CopyOpE($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$cast = 0, $$cast$i = 0, $$cast$i$i = 0, $$cast$i$i$i = 0, $$cast$i6$i$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ((($1)) + 4|0);
 $5 = ((($1)) + 8|0);
 $6 = ((($1)) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 HEAP32[$0>>2] = $7;
 $8 = ((($1)) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $$cast$i$i$i = $7;
 $10 = ((($$cast$i$i$i)) + -12|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($0) + ($11)|0);
 HEAP32[$12>>2] = $9;
 $13 = ((($1)) + 20|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP32[$0>>2]|0;
 $16 = ((($15)) + -16|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($0) + ($17)|0);
 HEAP32[$18>>2] = $14;
 $19 = ((($0)) + 4|0);
 $20 = ((($1)) + 24|0);
 $21 = HEAP32[$20>>2]|0;
 HEAP32[$19>>2] = $21;
 $22 = ((($1)) + 28|0);
 $23 = HEAP32[$22>>2]|0;
 $$cast$i6$i$i = $21;
 $24 = ((($$cast$i6$i$i)) + -12|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($19) + ($25)|0);
 HEAP32[$26>>2] = $23;
 $27 = ((($1)) + 32|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = HEAP32[$19>>2]|0;
 $30 = ((($29)) + -16|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (($19) + ($31)|0);
 HEAP32[$32>>2] = $28;
 $33 = HEAP32[$5>>2]|0;
 HEAP32[$0>>2] = $33;
 $34 = ((($1)) + 36|0);
 $35 = HEAP32[$34>>2]|0;
 $$cast$i$i = $33;
 $36 = ((($$cast$i$i)) + -12|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (($0) + ($37)|0);
 HEAP32[$38>>2] = $35;
 $39 = ((($1)) + 40|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = HEAP32[$0>>2]|0;
 $42 = ((($41)) + -16|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = (($0) + ($43)|0);
 HEAP32[$44>>2] = $40;
 $45 = ((($1)) + 44|0);
 $46 = HEAP32[$45>>2]|0;
 HEAP32[$19>>2] = $46;
 $47 = HEAP32[$4>>2]|0;
 HEAP32[$0>>2] = $47;
 $48 = ((($1)) + 48|0);
 $49 = HEAP32[$48>>2]|0;
 $$cast$i = $47;
 $50 = ((($$cast$i)) + -12|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = (($0) + ($51)|0);
 HEAP32[$52>>2] = $49;
 $53 = ((($1)) + 52|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = HEAP32[$0>>2]|0;
 $56 = ((($55)) + -16|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = (($0) + ($57)|0);
 HEAP32[$58>>2] = $54;
 $59 = ((($1)) + 56|0);
 $60 = HEAP32[$59>>2]|0;
 HEAP32[$19>>2] = $60;
 $61 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $61;
 $62 = ((($1)) + 60|0);
 $63 = HEAP32[$62>>2]|0;
 $$cast = $61;
 $64 = ((($$cast)) + -12|0);
 $65 = HEAP32[$64>>2]|0;
 $66 = (($0) + ($65)|0);
 HEAP32[$66>>2] = $63;
 $67 = ((($1)) + 64|0);
 $68 = HEAP32[$67>>2]|0;
 $69 = HEAP32[$0>>2]|0;
 $70 = ((($69)) + -16|0);
 $71 = HEAP32[$70>>2]|0;
 $72 = (($0) + ($71)|0);
 HEAP32[$72>>2] = $68;
 $73 = ((($1)) + 68|0);
 $74 = HEAP32[$73>>2]|0;
 HEAP32[$19>>2] = $74;
 $75 = ((($0)) + 8|0);
 $76 = ((($2)) + 8|0);
 $77 = HEAP32[$76>>2]|0;
 HEAP32[$75>>2] = $77;
 $78 = ((($0)) + 12|0);
 $79 = ((($2)) + 12|0);
 $80 = HEAP8[$79>>0]|0;
 HEAP8[$78>>0] = $80;
 $81 = ((($0)) + 16|0);
 $82 = ((($2)) + 16|0);
 ;HEAP32[$81>>2]=HEAP32[$82>>2]|0;HEAP32[$81+4>>2]=HEAP32[$82+4>>2]|0;HEAP32[$81+8>>2]=HEAP32[$82+8>>2]|0;HEAP32[$81+12>>2]=HEAP32[$82+12>>2]|0;HEAP32[$81+16>>2]=HEAP32[$82+16>>2]|0;HEAP32[$81+20>>2]=HEAP32[$82+20>>2]|0;
 $83 = ((($0)) + 40|0);
 $84 = ((($2)) + 40|0);
 ;HEAP32[$83>>2]=HEAP32[$84>>2]|0;HEAP32[$83+4>>2]=HEAP32[$84+4>>2]|0;HEAP32[$83+8>>2]=HEAP32[$84+8>>2]|0;HEAP32[$83+12>>2]=HEAP32[$84+12>>2]|0;HEAP32[$83+16>>2]=HEAP32[$84+16>>2]|0;HEAP32[$83+20>>2]=HEAP32[$84+20>>2]|0;
 $85 = ((($0)) + 64|0);
 $86 = ((($2)) + 64|0);
 ;HEAP32[$85>>2]=HEAP32[$86>>2]|0;HEAP32[$85+4>>2]=HEAP32[$86+4>>2]|0;HEAP32[$85+8>>2]=HEAP32[$86+8>>2]|0;HEAP32[$85+12>>2]=HEAP32[$86+12>>2]|0;HEAP32[$85+16>>2]=HEAP32[$86+16>>2]|0;HEAP32[$85+20>>2]=HEAP32[$86+20>>2]|0;
 $87 = ((($0)) + 88|0);
 $88 = HEAP32[$3>>2]|0;
 $89 = ((($88)) + 8|0);
 $90 = HEAP32[$89>>2]|0;
 $91 = ((($2)) + 88|0);
 $92 = HEAP32[$91>>2]|0;
 __THREW__ = 0;
 $93 = (invoke_iii($90|0,($3|0),($92|0))|0);
 $94 = __THREW__; __THREW__ = 0;
 $95 = $94&1;
 if ($95) {
  $97 = ___cxa_find_matching_catch_2()|0;
  $98 = tempRet0;
  __THREW__ = 0;
  invoke_vii(3484,($0|0),($4|0));
  $99 = __THREW__; __THREW__ = 0;
  $100 = $99&1;
  if ($100) {
   $105 = ___cxa_find_matching_catch_3(0|0)|0;
   $106 = tempRet0;
   ___clang_call_terminate($105);
   // unreachable;
  } else {
   ___resumeException($97|0);
   // unreachable;
  }
 }
 $96 = ($93|0)==(0|0);
 if ($96) {
  HEAP32[$87>>2] = 0;
  return;
 }
 $101 = (___dynamic_cast($93,26488,4064,0)|0);
 HEAP32[$87>>2] = $101;
 $102 = ($101|0)==(0|0);
 if ($102) {
  return;
 }
 $103 = ((($101)) + 8|0);
 $104 = HEAP32[$103>>2]|0;HEAP32[$103>>2] = (($104+1)|0);
 return;
}
function __ZN5osgGA17CameraManipulatorD2Ev($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$cast = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $2;
 $3 = ((($1)) + 60|0);
 $4 = HEAP32[$3>>2]|0;
 $$cast = $2;
 $5 = ((($$cast)) + -12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($0) + ($6)|0);
 HEAP32[$7>>2] = $4;
 $8 = ((($1)) + 64|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$0>>2]|0;
 $11 = ((($10)) + -16|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($0) + ($12)|0);
 HEAP32[$13>>2] = $9;
 $14 = ((($1)) + 68|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ((($0)) + 4|0);
 HEAP32[$16>>2] = $15;
 $17 = ((($0)) + 88|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ($18|0)==(0|0);
 if ($19) {
  HEAP32[$17>>2] = 0;
  $25 = ((($1)) + 4|0);
  __ZN5osgGA15GUIEventHandlerD2Ev($0,$25);
  return;
 }
 $20 = ((($18)) + 8|0);
 $21 = HEAP32[$20>>2]|0;HEAP32[$20>>2] = (($21-1)|0);
 $22 = ($21|0)==(1);
 if (!($22)) {
  HEAP32[$17>>2] = 0;
  $25 = ((($1)) + 4|0);
  __ZN5osgGA15GUIEventHandlerD2Ev($0,$25);
  return;
 }
 __THREW__ = 0;
 invoke_viii(3262,($18|0),1,1);
 $23 = __THREW__; __THREW__ = 0;
 $24 = $23&1;
 if (!($24)) {
  HEAP32[$17>>2] = 0;
  $25 = ((($1)) + 4|0);
  __ZN5osgGA15GUIEventHandlerD2Ev($0,$25);
  return;
 }
 $26 = ___cxa_find_matching_catch_2()|0;
 $27 = tempRet0;
 $28 = ((($1)) + 4|0);
 __THREW__ = 0;
 invoke_vii(3484,($0|0),($28|0));
 $29 = __THREW__; __THREW__ = 0;
 $30 = $29&1;
 if ($30) {
  $31 = ___cxa_find_matching_catch_3(0|0)|0;
  $32 = tempRet0;
  ___clang_call_terminate($31);
  // unreachable;
 } else {
  ___resumeException($26|0);
  // unreachable;
 }
}
function __ZNK5osgGA17CameraManipulator18getManipulatorNameEv($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$016$i$i = 0, $$016$i$i10 = 0, $$017$i$i = 0, $$017$i$i11 = 0, $$sink = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_ii[$4 & 8191]($1)|0);
 $6 = (_strstr($5,110099)|0);
 $7 = ($6|0)==(0|0);
 if ($7) {
  ;HEAP32[$0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;
  $8 = (_strlen($5)|0);
  $9 = ($8>>>0)>(4294967279);
  if ($9) {
   __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv($0);
   // unreachable;
  }
  $10 = ($8>>>0)<(11);
  if ($10) {
   $17 = $8&255;
   $18 = ((($0)) + 11|0);
   HEAP8[$18>>0] = $17;
   $19 = ($8|0)==(0);
   if ($19) {
    $$017$i$i = $0;
   } else {
    $$016$i$i = $0;
    label = 7;
   }
  } else {
   $11 = (($8) + 16)|0;
   $12 = $11 & -16;
   $13 = (__Znwj($12)|0);
   HEAP32[$0>>2] = $13;
   $14 = $12 | -2147483648;
   $15 = ((($0)) + 8|0);
   HEAP32[$15>>2] = $14;
   $16 = ((($0)) + 4|0);
   HEAP32[$16>>2] = $8;
   $$016$i$i = $13;
   label = 7;
  }
  if ((label|0) == 7) {
   _memcpy(($$016$i$i|0),($5|0),($8|0))|0;
   $$017$i$i = $$016$i$i;
  }
  $20 = (($$017$i$i) + ($8)|0);
  $$sink = $20;
  HEAP8[$$sink>>0] = 0;
  return;
 } else {
  $21 = $6;
  $22 = $5;
  $23 = (($21) - ($22))|0;
  ;HEAP32[$0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;
  $24 = ($23>>>0)>(4294967279);
  if ($24) {
   __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv($0);
   // unreachable;
  }
  $25 = ($23>>>0)<(11);
  if ($25) {
   $32 = $23&255;
   $33 = ((($0)) + 11|0);
   HEAP8[$33>>0] = $32;
   $34 = ($23|0)==(0);
   if ($34) {
    $$017$i$i11 = $0;
   } else {
    $$016$i$i10 = $0;
    label = 14;
   }
  } else {
   $26 = (($23) + 16)|0;
   $27 = $26 & -16;
   $28 = (__Znwj($27)|0);
   HEAP32[$0>>2] = $28;
   $29 = $27 | -2147483648;
   $30 = ((($0)) + 8|0);
   HEAP32[$30>>2] = $29;
   $31 = ((($0)) + 4|0);
   HEAP32[$31>>2] = $23;
   $$016$i$i10 = $28;
   label = 14;
  }
  if ((label|0) == 14) {
   _memcpy(($$016$i$i10|0),($5|0),($23|0))|0;
   $$017$i$i11 = $$016$i$i10;
  }
  $35 = (($$017$i$i11) + ($23)|0);
  $$sink = $35;
  HEAP8[$$sink>>0] = 0;
  return;
 }
}
function __ZN5osgGA16OrbitManipulator11setByMatrixERKN3osg7MatrixdE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$sroa$06$0$$sroa_idx = 0, $$sroa$48$0$$sroa_idx9 = 0, $$sroa$5$0$$sroa_idx11 = 0, $10 = 0.0, $11 = 0.0, $12 = 0.0, $13 = 0, $14 = 0.0, $15 = 0.0, $16 = 0.0, $17 = 0, $18 = 0.0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0, $24 = 0.0, $25 = 0.0;
 var $26 = 0.0, $27 = 0, $28 = 0.0, $29 = 0.0, $3 = 0, $30 = 0.0, $31 = 0, $32 = 0.0, $33 = 0.0, $34 = 0.0, $35 = 0, $36 = 0.0, $37 = 0.0, $38 = 0, $39 = 0.0, $4 = 0.0, $40 = 0.0, $41 = 0.0, $42 = 0, $43 = 0.0;
 var $44 = 0.0, $45 = 0.0, $46 = 0, $47 = 0.0, $48 = 0.0, $49 = 0.0, $5 = 0.0, $50 = 0, $51 = 0.0, $52 = 0.0, $53 = 0, $54 = 0.0, $55 = 0.0, $56 = 0.0, $57 = 0, $58 = 0.0, $59 = 0.0, $6 = 0, $60 = 0.0, $61 = 0;
 var $62 = 0.0, $63 = 0.0, $64 = 0.0, $65 = 0, $66 = 0.0, $67 = 0, $68 = 0.0, $69 = 0, $7 = 0.0, $70 = 0, $71 = 0.0, $72 = 0, $73 = 0, $74 = 0.0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0.0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $2 = sp;
 $3 = ((($0)) + 216|0);
 $4 = +HEAPF64[$3>>3];
 $5 = -$4;
 $6 = ((($1)) + 24|0);
 $7 = +HEAPF64[$6>>3];
 $8 = $7 * 0.0;
 $9 = ((($1)) + 56|0);
 $10 = +HEAPF64[$9>>3];
 $11 = $10 * 0.0;
 $12 = $8 + $11;
 $13 = ((($1)) + 88|0);
 $14 = +HEAPF64[$13>>3];
 $15 = $14 * $5;
 $16 = $12 + $15;
 $17 = ((($1)) + 120|0);
 $18 = +HEAPF64[$17>>3];
 $19 = $18 + $16;
 $20 = 1.0 / $19;
 $21 = +HEAPF64[$1>>3];
 $22 = $21 * 0.0;
 $23 = ((($1)) + 32|0);
 $24 = +HEAPF64[$23>>3];
 $25 = $24 * 0.0;
 $26 = $22 + $25;
 $27 = ((($1)) + 64|0);
 $28 = +HEAPF64[$27>>3];
 $29 = $28 * $5;
 $30 = $26 + $29;
 $31 = ((($1)) + 96|0);
 $32 = +HEAPF64[$31>>3];
 $33 = $32 + $30;
 $34 = $20 * $33;
 $35 = ((($1)) + 8|0);
 $36 = +HEAPF64[$35>>3];
 $37 = $36 * 0.0;
 $38 = ((($1)) + 40|0);
 $39 = +HEAPF64[$38>>3];
 $40 = $39 * 0.0;
 $41 = $37 + $40;
 $42 = ((($1)) + 72|0);
 $43 = +HEAPF64[$42>>3];
 $44 = $43 * $5;
 $45 = $41 + $44;
 $46 = ((($1)) + 104|0);
 $47 = +HEAPF64[$46>>3];
 $48 = $47 + $45;
 $49 = $20 * $48;
 $50 = ((($1)) + 16|0);
 $51 = +HEAPF64[$50>>3];
 $52 = $51 * 0.0;
 $53 = ((($1)) + 48|0);
 $54 = +HEAPF64[$53>>3];
 $55 = $54 * 0.0;
 $56 = $52 + $55;
 $57 = ((($1)) + 80|0);
 $58 = +HEAPF64[$57>>3];
 $59 = $58 * $5;
 $60 = $56 + $59;
 $61 = ((($1)) + 112|0);
 $62 = +HEAPF64[$61>>3];
 $63 = $62 + $60;
 $64 = $20 * $63;
 $$sroa$06$0$$sroa_idx = ((($0)) + 160|0);
 HEAPF64[$$sroa$06$0$$sroa_idx>>3] = $34;
 $$sroa$48$0$$sroa_idx9 = ((($0)) + 168|0);
 HEAPF64[$$sroa$48$0$$sroa_idx9>>3] = $49;
 $$sroa$5$0$$sroa_idx11 = ((($0)) + 176|0);
 HEAPF64[$$sroa$5$0$$sroa_idx11>>3] = $64;
 __ZNK3osg7Matrixd9getRotateEv($2,$1);
 $65 = ((($0)) + 184|0);
 $66 = +HEAPF64[$2>>3];
 HEAPF64[$65>>3] = $66;
 $67 = ((($2)) + 8|0);
 $68 = +HEAPF64[$67>>3];
 $69 = ((($0)) + 192|0);
 HEAPF64[$69>>3] = $68;
 $70 = ((($2)) + 16|0);
 $71 = +HEAPF64[$70>>3];
 $72 = ((($0)) + 200|0);
 HEAPF64[$72>>3] = $71;
 $73 = ((($2)) + 24|0);
 $74 = +HEAPF64[$73>>3];
 $75 = ((($0)) + 208|0);
 HEAPF64[$75>>3] = $74;
 $76 = ((($0)) + 144|0);
 $77 = HEAP8[$76>>0]|0;
 $78 = ($77<<24>>24)==(0);
 if ($78) {
  STACKTOP = sp;return;
 }
 $79 = ((($0)) + 160|0);
 __ZN5osgGA19StandardManipulator15fixVerticalAxisERN3osg5Vec3dERNS1_4QuatEb($0,$79,$65,1);
 STACKTOP = sp;return;
}
function __ZN5osgGA16OrbitManipulator18setByInverseMatrixERKN3osg7MatrixdE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0.0, $11 = 0, $12 = 0, $13 = 0.0, $14 = 0, $15 = 0, $16 = 0.0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0.0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(128|0);
 $2 = sp;
 $3 = HEAP32[$0>>2]|0;
 $4 = ((($3)) + 84|0);
 $5 = HEAP32[$4>>2]|0;
 __ZN3osg7Matrixd12makeIdentityEv($2);
 $6 = ((($1)) + 24|0);
 $7 = +HEAPF64[$6>>3];
 $8 = $7 == 0.0;
 if ($8) {
  $9 = ((($1)) + 56|0);
  $10 = +HEAPF64[$9>>3];
  $11 = $10 == 0.0;
  if ($11) {
   $12 = ((($1)) + 88|0);
   $13 = +HEAPF64[$12>>3];
   $14 = $13 == 0.0;
   if ($14) {
    $15 = ((($1)) + 120|0);
    $16 = +HEAPF64[$15>>3];
    $17 = $16 == 1.0;
    if ($17) {
     (__ZN3osg7Matrixd10invert_4x3ERKS0_($2,$1)|0);
    } else {
     label = 6;
    }
   } else {
    label = 6;
   }
  } else {
   label = 6;
  }
 } else {
  label = 6;
 }
 if ((label|0) == 6) {
  (__ZN3osg7Matrixd10invert_4x4ERKS0_($2,$1)|0);
 }
 __THREW__ = 0;
 invoke_vii($5|0,($0|0),($2|0));
 $18 = __THREW__; __THREW__ = 0;
 $19 = $18&1;
 if ($19) {
  $20 = ___cxa_find_matching_catch_2()|0;
  $21 = tempRet0;
  ___resumeException($20|0);
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZNK5osgGA16OrbitManipulator9getMatrixEv($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$2 = 0, $$24 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0.0, $17 = 0, $18 = 0.0, $19 = 0, $2 = 0, $20 = 0.0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0.0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 512|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(512|0);
 $2 = sp + 384|0;
 $3 = sp + 256|0;
 $4 = sp + 128|0;
 $5 = sp;
 $6 = ((($1)) + 216|0);
 $7 = +HEAPF64[$6>>3];
 __ZN3osg7Matrixd12makeIdentityEv($3);
 __ZN3osg7Matrixd13makeTranslateEddd($3,0.0,0.0,$7);
 $8 = ((($1)) + 184|0);
 __THREW__ = 0;
 invoke_vii(3535,($4|0),($8|0));
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if ($10) {
  $29 = ___cxa_find_matching_catch_2()|0;
  $30 = tempRet0;
  $$2 = $30;$$24 = $29;
  ___resumeException($$24|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_vi(3299,($2|0));
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if (!($12)) {
  __THREW__ = 0;
  invoke_viii(3300,($2|0),($3|0),($4|0));
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if (!($14)) {
   $15 = ((($1)) + 160|0);
   $16 = +HEAPF64[$15>>3];
   $17 = ((($1)) + 168|0);
   $18 = +HEAPF64[$17>>3];
   $19 = ((($1)) + 176|0);
   $20 = +HEAPF64[$19>>3];
   __THREW__ = 0;
   invoke_vi(3299,($5|0));
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if (!($22)) {
    __THREW__ = 0;
    invoke_viddd(3306,($5|0),(+$16),(+$18),(+$20));
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if (!($24)) {
     __THREW__ = 0;
     invoke_vi(3299,($0|0));
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if (!($26)) {
      __THREW__ = 0;
      invoke_viii(3300,($0|0),($2|0),($5|0));
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if (!($28)) {
       STACKTOP = sp;return;
      }
     }
    }
   }
   $33 = ___cxa_find_matching_catch_2()|0;
   $34 = tempRet0;
   $$2 = $34;$$24 = $33;
   ___resumeException($$24|0);
   // unreachable;
  }
 }
 $31 = ___cxa_find_matching_catch_2()|0;
 $32 = tempRet0;
 $$2 = $32;$$24 = $31;
 ___resumeException($$24|0);
 // unreachable;
}
function __ZNK5osgGA16OrbitManipulator16getInverseMatrixEv($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$2 = 0, $$24 = 0, $10 = 0, $11 = 0.0, $12 = 0.0, $13 = 0, $14 = 0.0, $15 = 0.0, $16 = 0, $17 = 0.0, $18 = 0, $19 = 0.0, $2 = 0, $20 = 0, $21 = 0.0, $22 = 0, $23 = 0.0, $24 = 0.0, $25 = 0.0, $26 = 0.0;
 var $27 = 0.0, $28 = 0.0, $29 = 0.0, $3 = 0, $30 = 0.0, $31 = 0.0, $32 = 0.0, $33 = 0.0, $34 = 0.0, $35 = 0.0, $36 = 0.0, $37 = 0.0, $38 = 0.0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0.0, $5 = 0, $50 = 0, $51 = 0, $52 = 0.0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $7 = 0, $8 = 0.0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 544|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(544|0);
 $2 = sp + 416|0;
 $3 = sp + 288|0;
 $4 = sp + 160|0;
 $5 = sp + 128|0;
 $6 = sp;
 $7 = ((($1)) + 160|0);
 $8 = +HEAPF64[$7>>3];
 $9 = -$8;
 $10 = ((($1)) + 168|0);
 $11 = +HEAPF64[$10>>3];
 $12 = -$11;
 $13 = ((($1)) + 176|0);
 $14 = +HEAPF64[$13>>3];
 $15 = -$14;
 __ZN3osg7Matrixd12makeIdentityEv($3);
 __ZN3osg7Matrixd13makeTranslateEddd($3,$9,$12,$15);
 $16 = ((($1)) + 184|0);
 $17 = +HEAPF64[$16>>3];
 $18 = ((($1)) + 192|0);
 $19 = +HEAPF64[$18>>3];
 $20 = ((($1)) + 200|0);
 $21 = +HEAPF64[$20>>3];
 $22 = ((($1)) + 208|0);
 $23 = +HEAPF64[$22>>3];
 $24 = $17 * $17;
 $25 = $19 * $19;
 $26 = $24 + $25;
 $27 = $21 * $21;
 $28 = $26 + $27;
 $29 = $23 * $23;
 $30 = $28 + $29;
 $31 = 1.0 / $30;
 $32 = $17 * $31;
 $33 = -$32;
 $34 = $19 * $31;
 $35 = -$34;
 $36 = $21 * $31;
 $37 = -$36;
 $38 = $23 * $31;
 HEAPF64[$5>>3] = $33;
 $39 = ((($5)) + 8|0);
 HEAPF64[$39>>3] = $35;
 $40 = ((($5)) + 16|0);
 HEAPF64[$40>>3] = $37;
 $41 = ((($5)) + 24|0);
 HEAPF64[$41>>3] = $38;
 __THREW__ = 0;
 invoke_vii(3535,($4|0),($5|0));
 $42 = __THREW__; __THREW__ = 0;
 $43 = $42&1;
 if ($43) {
  $59 = ___cxa_find_matching_catch_2()|0;
  $60 = tempRet0;
  $$2 = $60;$$24 = $59;
  ___resumeException($$24|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_vi(3299,($2|0));
 $44 = __THREW__; __THREW__ = 0;
 $45 = $44&1;
 if (!($45)) {
  __THREW__ = 0;
  invoke_viii(3300,($2|0),($3|0),($4|0));
  $46 = __THREW__; __THREW__ = 0;
  $47 = $46&1;
  if (!($47)) {
   $48 = ((($1)) + 216|0);
   $49 = +HEAPF64[$48>>3];
   __THREW__ = 0;
   invoke_vi(3299,($6|0));
   $50 = __THREW__; __THREW__ = 0;
   $51 = $50&1;
   if (!($51)) {
    $52 = -$49;
    __THREW__ = 0;
    invoke_viddd(3306,($6|0),0.0,0.0,(+$52));
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if (!($54)) {
     __THREW__ = 0;
     invoke_vi(3299,($0|0));
     $55 = __THREW__; __THREW__ = 0;
     $56 = $55&1;
     if (!($56)) {
      __THREW__ = 0;
      invoke_viii(3300,($0|0),($2|0),($6|0));
      $57 = __THREW__; __THREW__ = 0;
      $58 = $57&1;
      if (!($58)) {
       STACKTOP = sp;return;
      }
     }
    }
   }
   $63 = ___cxa_find_matching_catch_2()|0;
   $64 = tempRet0;
   $$2 = $64;$$24 = $63;
   ___resumeException($$24|0);
   // unreachable;
  }
 }
 $61 = ___cxa_find_matching_catch_2()|0;
 $62 = tempRet0;
 $$2 = $62;$$24 = $61;
 ___resumeException($$24|0);
 // unreachable;
}
function __ZNK5osgGA16OrbitManipulator21getFusionDistanceModeEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function __ZNK5osgGA16OrbitManipulator22getFusionDistanceValueEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0.0, $3 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 216|0);
 $2 = +HEAPF64[$1>>3];
 $3 = $2;
 return (+$3);
}
function __ZN5osgGA16OrbitManipulator17setTransformationERKN3osg5Vec3dERKNS1_4QuatE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$sroa$013$0$$sroa_idx = 0, $$sroa$415$0$$sroa_idx16 = 0, $$sroa$5$0$$sroa_idx18 = 0, $10 = 0.0, $11 = 0.0, $12 = 0.0, $13 = 0.0, $14 = 0.0, $15 = 0.0, $16 = 0.0, $17 = 0.0, $18 = 0.0, $19 = 0.0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0.0, $25 = 0.0, $26 = 0.0;
 var $27 = 0.0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0.0, $31 = 0.0, $32 = 0.0, $33 = 0.0, $34 = 0.0, $35 = 0.0, $36 = 0.0, $37 = 0.0, $38 = 0.0, $39 = 0.0, $4 = 0.0, $40 = 0.0, $41 = 0.0, $42 = 0.0, $43 = 0.0, $44 = 0.0;
 var $45 = 0, $46 = 0.0, $47 = 0.0, $48 = 0, $49 = 0.0, $5 = 0.0, $50 = 0.0, $51 = 0, $52 = 0.0, $53 = 0.0, $54 = 0, $55 = 0.0, $56 = 0, $57 = 0.0, $58 = 0, $59 = 0, $6 = 0.0, $60 = 0, $61 = 0, $62 = 0;
 var $7 = 0, $8 = 0.0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 216|0);
 $4 = +HEAPF64[$3>>3];
 $5 = -$4;
 $6 = +HEAPF64[$2>>3];
 $7 = ((($2)) + 8|0);
 $8 = +HEAPF64[$7>>3];
 $9 = ((($2)) + 16|0);
 $10 = +HEAPF64[$9>>3];
 $11 = $8 * $5;
 $12 = $10 * 0.0;
 $13 = $11 - $12;
 $14 = $6 * $5;
 $15 = $12 - $14;
 $16 = $6 * 0.0;
 $17 = $8 * 0.0;
 $18 = $16 - $17;
 $19 = $8 * $18;
 $20 = $10 * $15;
 $21 = $19 - $20;
 $22 = $10 * $13;
 $23 = $6 * $18;
 $24 = $22 - $23;
 $25 = $6 * $15;
 $26 = $8 * $13;
 $27 = $25 - $26;
 $28 = ((($2)) + 24|0);
 $29 = +HEAPF64[$28>>3];
 $30 = $29 * 2.0;
 $31 = $13 * $30;
 $32 = $15 * $30;
 $33 = $18 * $30;
 $34 = $21 * 2.0;
 $35 = $24 * 2.0;
 $36 = $27 * 2.0;
 $37 = $31 + 0.0;
 $38 = $32 + 0.0;
 $39 = $33 - $4;
 $40 = $37 + $34;
 $41 = $38 + $35;
 $42 = $39 + $36;
 $43 = +HEAPF64[$1>>3];
 $44 = $43 + $40;
 $45 = ((($1)) + 8|0);
 $46 = +HEAPF64[$45>>3];
 $47 = $46 + $41;
 $48 = ((($1)) + 16|0);
 $49 = +HEAPF64[$48>>3];
 $50 = $49 + $42;
 $$sroa$013$0$$sroa_idx = ((($0)) + 160|0);
 HEAPF64[$$sroa$013$0$$sroa_idx>>3] = $44;
 $$sroa$415$0$$sroa_idx16 = ((($0)) + 168|0);
 HEAPF64[$$sroa$415$0$$sroa_idx16>>3] = $47;
 $$sroa$5$0$$sroa_idx18 = ((($0)) + 176|0);
 HEAPF64[$$sroa$5$0$$sroa_idx18>>3] = $50;
 $51 = ((($0)) + 184|0);
 $52 = +HEAPF64[$2>>3];
 HEAPF64[$51>>3] = $52;
 $53 = +HEAPF64[$7>>3];
 $54 = ((($0)) + 192|0);
 HEAPF64[$54>>3] = $53;
 $55 = +HEAPF64[$9>>3];
 $56 = ((($0)) + 200|0);
 HEAPF64[$56>>3] = $55;
 $57 = +HEAPF64[$28>>3];
 $58 = ((($0)) + 208|0);
 HEAPF64[$58>>3] = $57;
 $59 = ((($0)) + 144|0);
 $60 = HEAP8[$59>>0]|0;
 $61 = ($60<<24>>24)==(0);
 if ($61) {
  return;
 }
 $62 = ((($0)) + 160|0);
 __ZN5osgGA19StandardManipulator15fixVerticalAxisERN3osg5Vec3dERNS1_4QuatEb($0,$62,$51,1);
 return;
}
function __ZN5osgGA16OrbitManipulator17setTransformationERKN3osg5Vec3dES4_S4_($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$sroa$017$0 = 0.0, $$sroa$028$0 = 0.0, $$sroa$041$0 = 0.0, $$sroa$11$0 = 0.0, $$sroa$13$0 = 0.0, $$sroa$14$0 = 0.0, $$sroa$721$0 = 0.0, $$sroa$8$0 = 0.0, $$sroa$947$0 = 0.0, $10 = 0.0, $100 = 0.0, $101 = 0.0, $102 = 0.0, $103 = 0.0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $12 = 0.0, $13 = 0.0, $14 = 0, $15 = 0.0, $16 = 0, $17 = 0.0, $18 = 0.0, $19 = 0.0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0.0, $25 = 0;
 var $26 = 0.0, $27 = 0.0, $28 = 0.0, $29 = 0.0, $30 = 0, $31 = 0.0, $32 = 0.0, $33 = 0, $34 = 0.0, $35 = 0.0, $36 = 0.0, $37 = 0.0, $38 = 0.0, $39 = 0.0, $4 = 0, $40 = 0.0, $41 = 0.0, $42 = 0.0, $43 = 0.0, $44 = 0.0;
 var $45 = 0.0, $46 = 0.0, $47 = 0.0, $48 = 0.0, $49 = 0.0, $5 = 0, $50 = 0, $51 = 0.0, $52 = 0.0, $53 = 0.0, $54 = 0.0, $55 = 0.0, $56 = 0.0, $57 = 0.0, $58 = 0.0, $59 = 0.0, $6 = 0.0, $60 = 0.0, $61 = 0.0, $62 = 0.0;
 var $63 = 0.0, $64 = 0.0, $65 = 0.0, $66 = 0.0, $67 = 0.0, $68 = 0.0, $69 = 0.0, $7 = 0.0, $70 = 0, $71 = 0.0, $72 = 0.0, $73 = 0.0, $74 = 0.0, $75 = 0.0, $76 = 0.0, $77 = 0.0, $78 = 0, $79 = 0, $8 = 0.0, $80 = 0;
 var $81 = 0, $82 = 0.0, $83 = 0, $84 = 0.0, $85 = 0, $86 = 0.0, $87 = 0, $88 = 0.0, $89 = 0.0, $9 = 0, $90 = 0.0, $91 = 0.0, $92 = 0.0, $93 = 0.0, $94 = 0.0, $95 = 0.0, $96 = 0.0, $97 = 0.0, $98 = 0.0, $99 = 0.0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(160|0);
 $4 = sp + 32|0;
 $5 = sp;
 $6 = +HEAPF64[$2>>3];
 $7 = +HEAPF64[$1>>3];
 $8 = $6 - $7;
 $9 = ((($2)) + 8|0);
 $10 = +HEAPF64[$9>>3];
 $11 = ((($1)) + 8|0);
 $12 = +HEAPF64[$11>>3];
 $13 = $10 - $12;
 $14 = ((($2)) + 16|0);
 $15 = +HEAPF64[$14>>3];
 $16 = ((($1)) + 16|0);
 $17 = +HEAPF64[$16>>3];
 $18 = $15 - $17;
 $19 = $8 * $8;
 $20 = $13 * $13;
 $21 = $19 + $20;
 $22 = $18 * $18;
 $23 = $21 + $22;
 $24 = (+Math_sqrt((+$23)));
 $25 = $24 > 0.0;
 $26 = 1.0 / $24;
 $27 = $8 * $26;
 $28 = $13 * $26;
 $29 = $18 * $26;
 $$sroa$041$0 = $25 ? $27 : $8;
 $$sroa$947$0 = $25 ? $28 : $13;
 $$sroa$14$0 = $25 ? $29 : $18;
 $30 = ((($3)) + 16|0);
 $31 = +HEAPF64[$30>>3];
 $32 = $31 * $$sroa$947$0;
 $33 = ((($3)) + 8|0);
 $34 = +HEAPF64[$33>>3];
 $35 = $34 * $$sroa$14$0;
 $36 = $32 - $35;
 $37 = +HEAPF64[$3>>3];
 $38 = $$sroa$14$0 * $37;
 $39 = $31 * $$sroa$041$0;
 $40 = $38 - $39;
 $41 = $34 * $$sroa$041$0;
 $42 = $$sroa$947$0 * $37;
 $43 = $41 - $42;
 $44 = $36 * $36;
 $45 = $40 * $40;
 $46 = $44 + $45;
 $47 = $43 * $43;
 $48 = $47 + $46;
 $49 = (+Math_sqrt((+$48)));
 $50 = $49 > 0.0;
 $51 = 1.0 / $49;
 $52 = $36 * $51;
 $53 = $51 * $40;
 $54 = $51 * $43;
 $$sroa$8$0 = $50 ? $53 : $40;
 $$sroa$028$0 = $50 ? $52 : $36;
 $$sroa$13$0 = $50 ? $54 : $43;
 $55 = $$sroa$14$0 * $$sroa$8$0;
 $56 = $$sroa$947$0 * $$sroa$13$0;
 $57 = $55 - $56;
 $58 = $$sroa$041$0 * $$sroa$13$0;
 $59 = $$sroa$14$0 * $$sroa$028$0;
 $60 = $58 - $59;
 $61 = $$sroa$947$0 * $$sroa$028$0;
 $62 = $$sroa$041$0 * $$sroa$8$0;
 $63 = $61 - $62;
 $64 = $57 * $57;
 $65 = $60 * $60;
 $66 = $64 + $65;
 $67 = $63 * $63;
 $68 = $67 + $66;
 $69 = (+Math_sqrt((+$68)));
 $70 = $69 > 0.0;
 $71 = 1.0 / $69;
 $72 = $71 * $57;
 $73 = $71 * $60;
 $74 = $71 * $63;
 $$sroa$11$0 = $70 ? $74 : $63;
 $$sroa$721$0 = $70 ? $73 : $60;
 $$sroa$017$0 = $70 ? $72 : $57;
 $75 = -$$sroa$041$0;
 $76 = -$$sroa$947$0;
 $77 = -$$sroa$14$0;
 __ZN3osg7MatrixdC2Edddddddddddddddd($4,$$sroa$028$0,$$sroa$017$0,$75,0.0,$$sroa$8$0,$$sroa$721$0,$76,0.0,$$sroa$13$0,$$sroa$11$0,$77,0.0,0.0,0.0,0.0,1.0);
 $78 = ((($0)) + 160|0);
 ;HEAP32[$78>>2]=HEAP32[$2>>2]|0;HEAP32[$78+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$78+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$78+12>>2]=HEAP32[$2+12>>2]|0;HEAP32[$78+16>>2]=HEAP32[$2+16>>2]|0;HEAP32[$78+20>>2]=HEAP32[$2+20>>2]|0;
 $79 = ((($0)) + 216|0);
 HEAPF64[$79>>3] = $24;
 __THREW__ = 0;
 invoke_vii(3536,($5|0),($4|0));
 $80 = __THREW__; __THREW__ = 0;
 $81 = $80&1;
 if ($81) {
  $113 = ___cxa_find_matching_catch_2()|0;
  $114 = tempRet0;
  ___resumeException($113|0);
  // unreachable;
 }
 $82 = +HEAPF64[$5>>3];
 $83 = ((($5)) + 8|0);
 $84 = +HEAPF64[$83>>3];
 $85 = ((($5)) + 16|0);
 $86 = +HEAPF64[$85>>3];
 $87 = ((($5)) + 24|0);
 $88 = +HEAPF64[$87>>3];
 $89 = $82 * $82;
 $90 = $84 * $84;
 $91 = $89 + $90;
 $92 = $86 * $86;
 $93 = $91 + $92;
 $94 = $88 * $88;
 $95 = $93 + $94;
 $96 = 1.0 / $95;
 $97 = $82 * $96;
 $98 = -$97;
 $99 = $84 * $96;
 $100 = -$99;
 $101 = $86 * $96;
 $102 = -$101;
 $103 = $88 * $96;
 $104 = ((($0)) + 184|0);
 HEAPF64[$104>>3] = $98;
 $105 = ((($0)) + 192|0);
 HEAPF64[$105>>3] = $100;
 $106 = ((($0)) + 200|0);
 HEAPF64[$106>>3] = $102;
 $107 = ((($0)) + 208|0);
 HEAPF64[$107>>3] = $103;
 $108 = ((($0)) + 144|0);
 $109 = HEAP8[$108>>0]|0;
 $110 = ($109<<24>>24)==(0);
 if ($110) {
  STACKTOP = sp;return;
 }
 __THREW__ = 0;
 invoke_viiii(3537,($0|0),($78|0),($104|0),1);
 $111 = __THREW__; __THREW__ = 0;
 $112 = $111&1;
 if ($112) {
  $113 = ___cxa_find_matching_catch_2()|0;
  $114 = tempRet0;
  ___resumeException($113|0);
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZNK5osgGA16OrbitManipulator17getTransformationERN3osg5Vec3dERNS1_4QuatE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$sroa$414$0$$sroa_idx15 = 0, $$sroa$5$0$$sroa_idx17 = 0, $10 = 0, $11 = 0.0, $12 = 0.0, $13 = 0.0, $14 = 0.0, $15 = 0.0, $16 = 0.0, $17 = 0.0, $18 = 0.0, $19 = 0.0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0.0, $25 = 0.0, $26 = 0.0, $27 = 0.0;
 var $28 = 0.0, $29 = 0, $3 = 0, $30 = 0.0, $31 = 0.0, $32 = 0.0, $33 = 0.0, $34 = 0.0, $35 = 0.0, $36 = 0.0, $37 = 0.0, $38 = 0.0, $39 = 0.0, $4 = 0.0, $40 = 0.0, $41 = 0.0, $42 = 0.0, $43 = 0.0, $44 = 0, $45 = 0.0;
 var $46 = 0.0, $47 = 0, $48 = 0.0, $49 = 0.0, $5 = 0.0, $50 = 0, $51 = 0.0, $52 = 0.0, $53 = 0.0, $54 = 0.0, $55 = 0, $56 = 0.0, $57 = 0, $58 = 0.0, $59 = 0, $6 = 0, $7 = 0.0, $8 = 0, $9 = 0.0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 216|0);
 $4 = +HEAPF64[$3>>3];
 $5 = -$4;
 $6 = ((($0)) + 184|0);
 $7 = +HEAPF64[$6>>3];
 $8 = ((($0)) + 192|0);
 $9 = +HEAPF64[$8>>3];
 $10 = ((($0)) + 200|0);
 $11 = +HEAPF64[$10>>3];
 $12 = $9 * $5;
 $13 = $11 * 0.0;
 $14 = $12 - $13;
 $15 = $7 * $5;
 $16 = $13 - $15;
 $17 = $7 * 0.0;
 $18 = $9 * 0.0;
 $19 = $17 - $18;
 $20 = $9 * $19;
 $21 = $11 * $16;
 $22 = $20 - $21;
 $23 = $11 * $14;
 $24 = $7 * $19;
 $25 = $23 - $24;
 $26 = $7 * $16;
 $27 = $9 * $14;
 $28 = $26 - $27;
 $29 = ((($0)) + 208|0);
 $30 = +HEAPF64[$29>>3];
 $31 = $30 * 2.0;
 $32 = $14 * $31;
 $33 = $16 * $31;
 $34 = $19 * $31;
 $35 = $22 * 2.0;
 $36 = $25 * 2.0;
 $37 = $28 * 2.0;
 $38 = $32 + 0.0;
 $39 = $33 + 0.0;
 $40 = $34 - $4;
 $41 = $38 + $35;
 $42 = $39 + $36;
 $43 = $40 + $37;
 $44 = ((($0)) + 160|0);
 $45 = +HEAPF64[$44>>3];
 $46 = $45 - $41;
 $47 = ((($0)) + 168|0);
 $48 = +HEAPF64[$47>>3];
 $49 = $48 - $42;
 $50 = ((($0)) + 176|0);
 $51 = +HEAPF64[$50>>3];
 $52 = $51 - $43;
 HEAPF64[$1>>3] = $46;
 $$sroa$414$0$$sroa_idx15 = ((($1)) + 8|0);
 HEAPF64[$$sroa$414$0$$sroa_idx15>>3] = $49;
 $$sroa$5$0$$sroa_idx17 = ((($1)) + 16|0);
 HEAPF64[$$sroa$5$0$$sroa_idx17>>3] = $52;
 $53 = +HEAPF64[$6>>3];
 HEAPF64[$2>>3] = $53;
 $54 = +HEAPF64[$8>>3];
 $55 = ((($2)) + 8|0);
 HEAPF64[$55>>3] = $54;
 $56 = +HEAPF64[$10>>3];
 $57 = ((($2)) + 16|0);
 HEAPF64[$57>>3] = $56;
 $58 = +HEAPF64[$29>>3];
 $59 = ((($2)) + 24|0);
 HEAPF64[$59>>3] = $58;
 return;
}
function __ZNK5osgGA16OrbitManipulator17getTransformationERN3osg5Vec3dES3_S3_($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$sroa$428$0$$sroa_idx29 = 0, $$sroa$49$0$$sroa_idx10 = 0, $$sroa$5$0$$sroa_idx12 = 0, $$sroa$531$0$$sroa_idx32 = 0, $10 = 0.0, $11 = 0, $12 = 0.0, $13 = 0.0, $14 = 0.0, $15 = 0.0, $16 = 0.0, $17 = 0.0, $18 = 0.0, $19 = 0.0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0.0, $25 = 0.0;
 var $26 = 0.0, $27 = 0.0, $28 = 0.0, $29 = 0.0, $30 = 0, $31 = 0.0, $32 = 0.0, $33 = 0.0, $34 = 0.0, $35 = 0.0, $36 = 0.0, $37 = 0.0, $38 = 0.0, $39 = 0.0, $4 = 0, $40 = 0.0, $41 = 0.0, $42 = 0.0, $43 = 0.0, $44 = 0.0;
 var $45 = 0.0, $46 = 0.0, $47 = 0, $48 = 0.0, $49 = 0.0, $5 = 0, $50 = 0, $51 = 0.0, $52 = 0.0, $53 = 0.0, $54 = 0.0, $55 = 0.0, $56 = 0.0, $57 = 0.0, $58 = 0.0, $59 = 0.0, $6 = 0.0, $60 = 0.0, $61 = 0.0, $62 = 0.0;
 var $63 = 0.0, $64 = 0.0, $65 = 0.0, $66 = 0.0, $67 = 0.0, $68 = 0.0, $69 = 0.0, $7 = 0, $70 = 0.0, $71 = 0.0, $72 = 0.0, $73 = 0.0, $74 = 0.0, $75 = 0.0, $76 = 0.0, $77 = 0.0, $78 = 0.0, $79 = 0.0, $8 = 0.0, $80 = 0.0;
 var $81 = 0.0, $82 = 0.0, $83 = 0.0, $84 = 0.0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ((($0)) + 160|0);
 ;HEAP32[$2>>2]=HEAP32[$4>>2]|0;HEAP32[$2+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$4+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$4+12>>2]|0;HEAP32[$2+16>>2]=HEAP32[$4+16>>2]|0;HEAP32[$2+20>>2]=HEAP32[$4+20>>2]|0;
 $5 = ((($0)) + 216|0);
 $6 = +HEAPF64[$5>>3];
 $7 = ((($0)) + 184|0);
 $8 = +HEAPF64[$7>>3];
 $9 = ((($0)) + 192|0);
 $10 = +HEAPF64[$9>>3];
 $11 = ((($0)) + 200|0);
 $12 = +HEAPF64[$11>>3];
 $13 = $6 * $10;
 $14 = $12 * 0.0;
 $15 = $13 - $14;
 $16 = $6 * $8;
 $17 = $14 - $16;
 $18 = $8 * 0.0;
 $19 = $10 * 0.0;
 $20 = $18 - $19;
 $21 = $10 * $20;
 $22 = $12 * $17;
 $23 = $21 - $22;
 $24 = $12 * $15;
 $25 = $8 * $20;
 $26 = $24 - $25;
 $27 = $8 * $17;
 $28 = $10 * $15;
 $29 = $27 - $28;
 $30 = ((($0)) + 208|0);
 $31 = +HEAPF64[$30>>3];
 $32 = $31 * 2.0;
 $33 = $15 * $32;
 $34 = $17 * $32;
 $35 = $20 * $32;
 $36 = $23 * 2.0;
 $37 = $26 * 2.0;
 $38 = $29 * 2.0;
 $39 = $33 + 0.0;
 $40 = $34 + 0.0;
 $41 = $6 + $35;
 $42 = $39 + $36;
 $43 = $40 + $37;
 $44 = $41 + $38;
 $45 = +HEAPF64[$4>>3];
 $46 = $45 + $42;
 $47 = ((($0)) + 168|0);
 $48 = +HEAPF64[$47>>3];
 $49 = $48 + $43;
 $50 = ((($0)) + 176|0);
 $51 = +HEAPF64[$50>>3];
 $52 = $51 + $44;
 HEAPF64[$1>>3] = $46;
 $$sroa$428$0$$sroa_idx29 = ((($1)) + 8|0);
 HEAPF64[$$sroa$428$0$$sroa_idx29>>3] = $49;
 $$sroa$531$0$$sroa_idx32 = ((($1)) + 16|0);
 HEAPF64[$$sroa$531$0$$sroa_idx32>>3] = $52;
 $53 = +HEAPF64[$7>>3];
 $54 = +HEAPF64[$9>>3];
 $55 = +HEAPF64[$11>>3];
 $56 = $54 * 0.0;
 $57 = $56 - $55;
 $58 = $55 * 0.0;
 $59 = $53 * 0.0;
 $60 = $58 - $59;
 $61 = $53 - $56;
 $62 = $54 * $61;
 $63 = $55 * $60;
 $64 = $62 - $63;
 $65 = $55 * $57;
 $66 = $53 * $61;
 $67 = $65 - $66;
 $68 = $53 * $60;
 $69 = $54 * $57;
 $70 = $68 - $69;
 $71 = +HEAPF64[$30>>3];
 $72 = $71 * 2.0;
 $73 = $57 * $72;
 $74 = $60 * $72;
 $75 = $61 * $72;
 $76 = $64 * 2.0;
 $77 = $67 * 2.0;
 $78 = $70 * 2.0;
 $79 = $73 + 0.0;
 $80 = $74 + 1.0;
 $81 = $75 + 0.0;
 $82 = $79 + $76;
 $83 = $80 + $77;
 $84 = $81 + $78;
 HEAPF64[$3>>3] = $82;
 $$sroa$49$0$$sroa_idx10 = ((($3)) + 8|0);
 HEAPF64[$$sroa$49$0$$sroa_idx10>>3] = $83;
 $$sroa$5$0$$sroa_idx12 = ((($3)) + 16|0);
 HEAPF64[$$sroa$5$0$$sroa_idx12>>3] = $84;
 return;
}
function __ZN5osgGA16OrbitManipulator16handleMouseWheelERKNS_15GUIEventAdapterERNS_16GUIActionAdapterE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$phi$trans$insert = 0, $$phi$trans$insert15 = 0, $$pre = 0.0, $$pre16 = 0.0, $10 = 0.0, $11 = 0, $12 = 0, $13 = 0.0, $14 = 0, $15 = 0.0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0.0, $28 = 0.0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0.0, $44 = 0.0, $45 = 0.0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $3 = ((($1)) + 124|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 152|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $6 & 8;
 $8 = ($7|0)==(0);
 L1: do {
  if ($8) {
   label = 9;
  } else {
   switch ($4|0) {
   case 4:  {
    $9 = ((($0)) + 232|0);
    $10 = +HEAPF64[$9>>3];
    $11 = $10 > 0.0;
    if (!($11)) {
     $44 = $10;
     label = 15;
     break L1;
    }
    break;
   }
   case 3:  {
    $12 = ((($0)) + 232|0);
    $13 = +HEAPF64[$12>>3];
    $14 = $13 < 0.0;
    if (!($14)) {
     $28 = $13;
     label = 12;
     break L1;
    }
    break;
   }
   default: {
    $$0 = 0;
    return ($$0|0);
   }
   }
   $15 = (+__ZNK5osgGA19StandardManipulator16getAnimationTimeEv($0));
   $16 = !($15 <= 0.0);
   if (!($16)) {
    $17 = HEAP32[$0>>2]|0;
    $18 = ((($17)) + 260|0);
    $19 = HEAP32[$18>>2]|0;
    (FUNCTION_TABLE_iiii[$19 & 8191]($0,$1,$2)|0);
    label = 9;
    break;
   }
   $20 = (__ZNK5osgGA19StandardManipulator11isAnimatingEv($0)|0);
   if ($20) {
    label = 9;
   } else {
    $21 = HEAP32[$0>>2]|0;
    $22 = ((($21)) + 264|0);
    $23 = HEAP32[$22>>2]|0;
    (FUNCTION_TABLE_iiii[$23 & 8191]($0,$1,$2)|0);
    label = 9;
   }
  }
 } while(0);
 L12: do {
  if ((label|0) == 9) {
   switch ($4|0) {
   case 3:  {
    $$phi$trans$insert15 = ((($0)) + 232|0);
    $$pre16 = +HEAPF64[$$phi$trans$insert15>>3];
    $28 = $$pre16;
    label = 12;
    break L12;
    break;
   }
   case 4:  {
    $$phi$trans$insert = ((($0)) + 232|0);
    $$pre = +HEAPF64[$$phi$trans$insert>>3];
    $44 = $$pre;
    label = 15;
    break L12;
    break;
   }
   default: {
    $$0 = 0;
    return ($$0|0);
   }
   }
  }
 } while(0);
 if ((label|0) == 12) {
  $24 = HEAP32[$0>>2]|0;
  $25 = ((($24)) + 312|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = $28;
  FUNCTION_TABLE_vidi[$26 & 4095]($0,$27,1);
  $29 = HEAP32[$2>>2]|0;
  $30 = ((($29)) + 12|0);
  $31 = HEAP32[$30>>2]|0;
  FUNCTION_TABLE_vi[$31 & 8191]($2);
  $32 = HEAP32[$2>>2]|0;
  $33 = ((($32)) + 16|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = (__ZNK5osgGA19StandardManipulator11isAnimatingEv($0)|0);
  if ($35) {
   $39 = 1;
  } else {
   $36 = ((($0)) + 92|0);
   $37 = HEAP8[$36>>0]|0;
   $38 = ($37<<24>>24)!=(0);
   $39 = $38;
  }
  FUNCTION_TABLE_vii[$34 & 8191]($2,$39);
  $$0 = 1;
  return ($$0|0);
 }
 else if ((label|0) == 15) {
  $40 = HEAP32[$0>>2]|0;
  $41 = ((($40)) + 312|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = $44;
  $45 = -$43;
  FUNCTION_TABLE_vidi[$42 & 4095]($0,$45,1);
  $46 = HEAP32[$2>>2]|0;
  $47 = ((($46)) + 12|0);
  $48 = HEAP32[$47>>2]|0;
  FUNCTION_TABLE_vi[$48 & 8191]($2);
  $49 = HEAP32[$2>>2]|0;
  $50 = ((($49)) + 16|0);
  $51 = HEAP32[$50>>2]|0;
  $52 = (__ZNK5osgGA19StandardManipulator11isAnimatingEv($0)|0);
  if ($52) {
   $56 = 1;
  } else {
   $53 = ((($0)) + 92|0);
   $54 = HEAP8[$53>>0]|0;
   $55 = ($54<<24>>24)!=(0);
   $56 = $55;
  }
  FUNCTION_TABLE_vii[$51 & 8191]($2,$56);
  $$0 = 1;
  return ($$0|0);
 }
 return (0)|0;
}
function __ZN5osgGA16OrbitManipulator30performMovementLeftMouseButtonEddd($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = +$1;
 $2 = +$2;
 $3 = +$3;
 var $$$i = 0.0, $$$i4 = 0.0, $$in = 0.0, $$in8 = 0.0, $10 = 0.0, $100 = 0.0, $101 = 0.0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0.0, $108 = 0, $109 = 0.0, $11 = 0.0, $110 = 0.0, $111 = 0, $112 = 0.0, $113 = 0.0;
 var $114 = 0.0, $115 = 0.0, $116 = 0.0, $117 = 0, $118 = 0.0, $119 = 0, $12 = 0, $120 = 0.0, $121 = 0.0, $122 = 0.0, $123 = 0, $124 = 0.0, $125 = 0.0, $126 = 0.0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0.0;
 var $132 = 0, $133 = 0.0, $134 = 0.0, $135 = 0.0, $136 = 0, $137 = 0.0, $138 = 0.0, $139 = 0.0, $14 = 0, $140 = 0.0, $141 = 0.0, $142 = 0.0, $143 = 0.0, $144 = 0.0, $145 = 0.0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0.0, $30 = 0, $31 = 0.0, $32 = 0.0, $33 = 0, $34 = 0.0, $35 = 0.0, $36 = 0.0, $37 = 0.0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0.0, $44 = 0, $45 = 0.0, $46 = 0.0, $47 = 0, $48 = 0.0, $49 = 0.0, $5 = 0, $50 = 0.0, $51 = 0.0, $52 = 0.0, $53 = 0, $54 = 0.0, $55 = 0, $56 = 0.0, $57 = 0.0;
 var $58 = 0.0, $59 = 0, $6 = 0, $60 = 0.0, $61 = 0.0, $62 = 0.0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0.0, $68 = 0, $69 = 0.0, $7 = 0, $70 = 0.0, $71 = 0.0, $72 = 0, $73 = 0.0, $74 = 0.0, $75 = 0.0;
 var $76 = 0.0, $77 = 0.0, $78 = 0.0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0.0;
 var $94 = 0, $95 = 0.0, $96 = 0.0, $97 = 0, $98 = 0.0, $99 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ((($0)) + 144|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)==(0);
 if (!($6)) {
  $7 = HEAP32[$0>>2]|0;
  $8 = ((($7)) + 300|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = $2;
  $11 = $3;
  FUNCTION_TABLE_vidd[$9 & 8191]($0,$10,$11);
  return 1;
 }
 $12 = HEAP32[$0>>2]|0;
 $13 = ((($12)) + 296|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ((($0)) + 108|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ((($16)) + 160|0);
 $18 = ((($16)) + 164|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$17>>2]|0;
 $21 = (($19) - ($20))|0;
 $22 = $21 >> 2;
 $23 = ($22|0)==(0);
 if ($23) {
  $53 = ((($16)) + 104|0);
  $54 = +HEAPF32[$53>>2];
  $55 = ((($16)) + 88|0);
  $56 = +HEAPF32[$55>>2];
  $57 = $54 - $56;
  $58 = $57 * 2.0;
  $59 = ((($16)) + 92|0);
  $60 = +HEAPF32[$59>>2];
  $61 = $60 - $56;
  $62 = $58 / $61;
  $63 = ((($16)) + 120|0);
  $64 = HEAP32[$63>>2]|0;
  $65 = ($64|0)==(0);
  $66 = ((($16)) + 108|0);
  $67 = +HEAPF32[$66>>2];
  $68 = ((($16)) + 96|0);
  $69 = +HEAPF32[$68>>2];
  $70 = $67 - $69;
  $71 = $70 * 2.0;
  $72 = ((($16)) + 100|0);
  $73 = +HEAPF32[$72>>2];
  $74 = $73 - $69;
  $75 = $71 / $74;
  $76 = $75 + -1.0;
  $77 = -$76;
  $$$i4 = $65 ? $76 : $77;
  $$in = $62;$144 = $$$i4;
 } else {
  $24 = $20;
  $25 = (($22) + -1)|0;
  $26 = (($24) + ($25<<2)|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = ((($27)) + 20|0);
  $29 = +HEAPF32[$28>>2];
  $30 = ((($27)) + 24|0);
  $31 = +HEAPF32[$30>>2];
  $32 = $29 - $31;
  $33 = ((($27)) + 28|0);
  $34 = +HEAPF32[$33>>2];
  $35 = $34 - $31;
  $36 = $32 / $35;
  $37 = $36 * 2.0;
  $38 = $20;
  $39 = (($22) + -1)|0;
  $40 = (($38) + ($39<<2)|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = ((($41)) + 32|0);
  $43 = +HEAPF32[$42>>2];
  $44 = ((($41)) + 36|0);
  $45 = +HEAPF32[$44>>2];
  $46 = $43 - $45;
  $47 = ((($41)) + 40|0);
  $48 = +HEAPF32[$47>>2];
  $49 = $48 - $45;
  $50 = $46 / $49;
  $51 = $50 * 2.0;
  $52 = $51 + -1.0;
  $$in = $37;$144 = $52;
 }
 $78 = $$in + -1.0;
 $79 = ((($0)) + 104|0);
 $80 = HEAP32[$79>>2]|0;
 $81 = ((($80)) + 160|0);
 $82 = ((($80)) + 164|0);
 $83 = HEAP32[$82>>2]|0;
 $84 = HEAP32[$81>>2]|0;
 $85 = (($83) - ($84))|0;
 $86 = $85 >> 2;
 $87 = ($86|0)==(0);
 if ($87) {
  $117 = ((($80)) + 104|0);
  $118 = +HEAPF32[$117>>2];
  $119 = ((($80)) + 88|0);
  $120 = +HEAPF32[$119>>2];
  $121 = $118 - $120;
  $122 = $121 * 2.0;
  $123 = ((($80)) + 92|0);
  $124 = +HEAPF32[$123>>2];
  $125 = $124 - $120;
  $126 = $122 / $125;
  $127 = ((($80)) + 120|0);
  $128 = HEAP32[$127>>2]|0;
  $129 = ($128|0)==(0);
  $130 = ((($80)) + 108|0);
  $131 = +HEAPF32[$130>>2];
  $132 = ((($80)) + 96|0);
  $133 = +HEAPF32[$132>>2];
  $134 = $131 - $133;
  $135 = $134 * 2.0;
  $136 = ((($80)) + 100|0);
  $137 = +HEAPF32[$136>>2];
  $138 = $137 - $133;
  $139 = $135 / $138;
  $140 = $139 + -1.0;
  $141 = -$140;
  $$$i = $129 ? $140 : $141;
  $$in8 = $126;$145 = $$$i;
 } else {
  $88 = $84;
  $89 = (($86) + -1)|0;
  $90 = (($88) + ($89<<2)|0);
  $91 = HEAP32[$90>>2]|0;
  $92 = ((($91)) + 20|0);
  $93 = +HEAPF32[$92>>2];
  $94 = ((($91)) + 24|0);
  $95 = +HEAPF32[$94>>2];
  $96 = $93 - $95;
  $97 = ((($91)) + 28|0);
  $98 = +HEAPF32[$97>>2];
  $99 = $98 - $95;
  $100 = $96 / $99;
  $101 = $100 * 2.0;
  $102 = $84;
  $103 = (($86) + -1)|0;
  $104 = (($102) + ($103<<2)|0);
  $105 = HEAP32[$104>>2]|0;
  $106 = ((($105)) + 32|0);
  $107 = +HEAPF32[$106>>2];
  $108 = ((($105)) + 36|0);
  $109 = +HEAPF32[$108>>2];
  $110 = $107 - $109;
  $111 = ((($105)) + 40|0);
  $112 = +HEAPF32[$111>>2];
  $113 = $112 - $109;
  $114 = $110 / $113;
  $115 = $114 * 2.0;
  $116 = $115 + -1.0;
  $$in8 = $101;$145 = $116;
 }
 $142 = $$in8 + -1.0;
 $143 = (+__ZNK5osgGA19StandardManipulator13getThrowScaleEd($0,$1));
 FUNCTION_TABLE_viddddd[$14 & 1023]($0,$78,$144,$142,$145,$143);
 return 1;
}
function __ZN5osgGA16OrbitManipulator32performMovementMiddleMouseButtonEddd($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = +$1;
 $2 = +$2;
 $3 = +$3;
 var $10 = 0.0, $11 = 0, $12 = 0, $13 = 0, $14 = 0.0, $15 = 0.0, $16 = 0.0, $17 = 0.0, $18 = 0.0, $4 = 0, $5 = 0.0, $6 = 0.0, $7 = 0.0, $8 = 0.0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ((($0)) + 216|0);
 $5 = +HEAPF64[$4>>3];
 $6 = $5 * -0.30000001192092896;
 $7 = (+__ZNK5osgGA19StandardManipulator13getThrowScaleEd($0,$1));
 $8 = $7;
 $9 = $6 * $8;
 $10 = $9;
 $11 = HEAP32[$0>>2]|0;
 $12 = ((($11)) + 308|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $10;
 $15 = $14 * $2;
 $16 = $15;
 $17 = $14 * $3;
 $18 = $17;
 FUNCTION_TABLE_viddd[$13 & 8191]($0,$16,$18,0.0);
 return 1;
}
function __ZN5osgGA16OrbitManipulator31performMovementRightMouseButtonEddd($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = +$1;
 $2 = +$2;
 $3 = +$3;
 var $10 = 0.0, $4 = 0, $5 = 0, $6 = 0, $7 = 0.0, $8 = 0.0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = HEAP32[$0>>2]|0;
 $5 = ((($4)) + 312|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (+__ZNK5osgGA19StandardManipulator13getThrowScaleEd($0,$1));
 $8 = $7;
 $9 = $8 * $3;
 $10 = $9;
 FUNCTION_TABLE_vidi[$6 & 4095]($0,$10,1);
 return 1;
}
function __ZN5osgGA16OrbitManipulator25performMouseDeltaMovementEff($0,$1,$2) {
 $0 = $0|0;
 $1 = +$1;
 $2 = +$2;
 var $10 = 0, $11 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 144|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)==(0);
 if ($5) {
  $9 = HEAP32[$0>>2]|0;
  $10 = ((($9)) + 296|0);
  $11 = HEAP32[$10>>2]|0;
  FUNCTION_TABLE_viddddd[$11 & 1023]($0,0.0,0.0,$1,$2,1.0);
  return 1;
 } else {
  $6 = HEAP32[$0>>2]|0;
  $7 = ((($6)) + 300|0);
  $8 = HEAP32[$7>>2]|0;
  FUNCTION_TABLE_vidd[$8 & 8191]($0,$1,$2);
  return 1;
 }
 return (0)|0;
}
function __ZN5osgGA16OrbitManipulator18applyAnimationStepEdd($0,$1,$2) {
 $0 = $0|0;
 $1 = +$1;
 $2 = +$2;
 var $$sroa$011$0$copyload = 0.0, $$sroa$2$0$$sroa_idx12 = 0, $$sroa$2$0$copyload = 0.0, $$sroa$3$0$$sroa_idx13 = 0, $$sroa$3$0$copyload = 0.0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0.0, $18 = 0, $19 = 0, $20 = 0.0, $21 = 0.0, $22 = 0, $23 = 0.0, $24 = 0.0;
 var $25 = 0, $26 = 0.0, $27 = 0.0, $28 = 0.0, $29 = 0.0, $3 = 0, $30 = 0.0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0.0, $44 = 0, $45 = 0.0, $46 = 0, $47 = 0.0, $48 = 0, $49 = 0, $5 = 0, $50 = 0.0, $51 = 0.0, $52 = 0.0, $53 = 0.0, $54 = 0, $55 = 0.0, $56 = 0.0, $57 = 0.0, $58 = 0, $59 = 0.0, $6 = 0, $60 = 0.0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 272|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(272|0);
 $3 = sp + 248|0;
 $4 = sp + 224|0;
 $5 = sp + 200|0;
 $6 = sp + 176|0;
 $7 = sp + 48|0;
 $8 = sp + 24|0;
 $9 = sp;
 $10 = ((($0)) + 148|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0|0);
 if ($12) {
  $19 = 0;
 } else {
  $13 = (___dynamic_cast($11,9600,9584,0)|0);
  $19 = $13;
 }
 ;HEAP32[$3>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;HEAP32[$3+12>>2]=0|0;HEAP32[$3+16>>2]=0|0;HEAP32[$3+20>>2]=0|0;
 ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;HEAP32[$4+12>>2]=0|0;HEAP32[$4+16>>2]=0|0;HEAP32[$4+20>>2]=0|0;
 ;HEAP32[$5>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;HEAP32[$5+12>>2]=0|0;HEAP32[$5+16>>2]=0|0;HEAP32[$5+20>>2]=0|0;
 $14 = HEAP32[$0>>2]|0;
 $15 = ((($14)) + 168|0);
 $16 = HEAP32[$15>>2]|0;
 FUNCTION_TABLE_viiii[$16 & 8191]($0,$4,$3,$5);
 $$sroa$011$0$copyload = +HEAPF64[$3>>3];
 $$sroa$2$0$$sroa_idx12 = ((($3)) + 8|0);
 $$sroa$2$0$copyload = +HEAPF64[$$sroa$2$0$$sroa_idx12>>3];
 $$sroa$3$0$$sroa_idx13 = ((($3)) + 16|0);
 $$sroa$3$0$copyload = +HEAPF64[$$sroa$3$0$$sroa_idx13>>3];
 $17 = $1 - $2;
 $18 = ((($19)) + 48|0);
 $20 = +HEAPF64[$18>>3];
 $21 = $17 * $20;
 $22 = ((($19)) + 56|0);
 $23 = +HEAPF64[$22>>3];
 $24 = $17 * $23;
 $25 = ((($19)) + 64|0);
 $26 = +HEAPF64[$25>>3];
 $27 = $17 * $26;
 $28 = $$sroa$011$0$copyload + $21;
 $29 = $$sroa$2$0$copyload + $24;
 $30 = $$sroa$3$0$copyload + $27;
 HEAPF64[$6>>3] = $28;
 $31 = ((($6)) + 8|0);
 HEAPF64[$31>>3] = $29;
 $32 = ((($6)) + 16|0);
 HEAPF64[$32>>3] = $30;
 $33 = ((($0)) + 144|0);
 $34 = HEAP8[$33>>0]|0;
 $35 = ($34<<24>>24)==(0);
 if ($35) {
  $67 = HEAP32[$0>>2]|0;
  $68 = ((($67)) + 160|0);
  $69 = HEAP32[$68>>2]|0;
  FUNCTION_TABLE_viiii[$69 & 8191]($0,$4,$6,$5);
  STACKTOP = sp;return;
 }
 $36 = ((($0)) + 88|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = ($37|0)==(0|0);
 if ($38) {
  __ZN3osg7Matrixd12makeIdentityEv($7);
 } else {
  $39 = HEAP32[$37>>2]|0;
  $40 = ((($39)) + 12|0);
  $41 = HEAP32[$40>>2]|0;
  FUNCTION_TABLE_viii[$41 & 8191]($7,$37,$6);
 }
 $42 = ((($7)) + 64|0);
 $43 = +HEAPF64[$42>>3];
 $44 = ((($7)) + 72|0);
 $45 = +HEAPF64[$44>>3];
 $46 = ((($7)) + 80|0);
 $47 = +HEAPF64[$46>>3];
 HEAPF64[$8>>3] = $43;
 $48 = ((($8)) + 8|0);
 HEAPF64[$48>>3] = $45;
 $49 = ((($8)) + 16|0);
 HEAPF64[$49>>3] = $47;
 $50 = +HEAPF64[$6>>3];
 $51 = +HEAPF64[$4>>3];
 $52 = $50 - $51;
 $53 = +HEAPF64[$31>>3];
 $54 = ((($4)) + 8|0);
 $55 = +HEAPF64[$54>>3];
 $56 = $53 - $55;
 $57 = +HEAPF64[$32>>3];
 $58 = ((($4)) + 16|0);
 $59 = +HEAPF64[$58>>3];
 $60 = $57 - $59;
 HEAPF64[$9>>3] = $52;
 $61 = ((($9)) + 8|0);
 HEAPF64[$61>>3] = $56;
 $62 = ((($9)) + 16|0);
 HEAPF64[$62>>3] = $60;
 __THREW__ = 0;
 invoke_viiiii(3538,($9|0),($5|0),($5|0),($8|0),0);
 $63 = __THREW__; __THREW__ = 0;
 $64 = $63&1;
 if ($64) {
  $65 = ___cxa_find_matching_catch_2()|0;
  $66 = tempRet0;
  ___resumeException($65|0);
  // unreachable;
 }
 $67 = HEAP32[$0>>2]|0;
 $68 = ((($67)) + 160|0);
 $69 = HEAP32[$68>>2]|0;
 FUNCTION_TABLE_viiii[$69 & 8191]($0,$4,$6,$5);
 STACKTOP = sp;return;
}
function __ZN5osgGA16OrbitManipulator40startAnimationByMousePointerIntersectionERKNS_15GUIEventAdapterERNS_16GUIActionAdapterE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$1 = 0, $$sroa$0$0$$sroa_idx = 0, $$sroa$0$0$copyload = 0.0, $$sroa$010$0$$sroa_idx = 0, $$sroa$2$0$$sroa_idx8 = 0, $$sroa$2$0$copyload = 0.0, $$sroa$3$0$$sroa_idx9 = 0, $$sroa$3$0$copyload = 0.0, $$sroa$4$0$$sroa_idx13 = 0, $$sroa$5$0$$sroa_idx15 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0.0, $19 = 0.0;
 var $20 = 0, $21 = 0.0, $22 = 0.0, $23 = 0, $24 = 0.0, $25 = 0.0, $26 = 0, $27 = 0.0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(80|0);
 $3 = sp + 48|0;
 $4 = sp + 24|0;
 $5 = sp;
 ;HEAP32[$3>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;HEAP32[$3+12>>2]=0|0;HEAP32[$3+16>>2]=0|0;HEAP32[$3+20>>2]=0|0;
 ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;HEAP32[$4+12>>2]=0|0;HEAP32[$4+16>>2]=0|0;HEAP32[$4+20>>2]=0|0;
 ;HEAP32[$5>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;HEAP32[$5+12>>2]=0|0;HEAP32[$5+16>>2]=0|0;HEAP32[$5+20>>2]=0|0;
 $6 = HEAP32[$0>>2]|0;
 $7 = ((($6)) + 168|0);
 $8 = HEAP32[$7>>2]|0;
 FUNCTION_TABLE_viiii[$8 & 8191]($0,$4,$3,$5);
 $9 = HEAP32[$0>>2]|0;
 $10 = ((($9)) + 260|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (FUNCTION_TABLE_iiii[$11 & 8191]($0,$1,$2)|0);
 if (!($12)) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $13 = ((($0)) + 148|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(0|0);
 if ($15) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $16 = (___dynamic_cast($14,9600,9584,0)|0);
 $17 = ($16|0)==(0|0);
 if ($17) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $$sroa$0$0$$sroa_idx = ((($0)) + 160|0);
 $$sroa$0$0$copyload = +HEAPF64[$$sroa$0$0$$sroa_idx>>3];
 $$sroa$2$0$$sroa_idx8 = ((($0)) + 168|0);
 $$sroa$2$0$copyload = +HEAPF64[$$sroa$2$0$$sroa_idx8>>3];
 $$sroa$3$0$$sroa_idx9 = ((($0)) + 176|0);
 $$sroa$3$0$copyload = +HEAPF64[$$sroa$3$0$$sroa_idx9>>3];
 $18 = +HEAPF64[$3>>3];
 $19 = $$sroa$0$0$copyload - $18;
 $20 = ((($3)) + 8|0);
 $21 = +HEAPF64[$20>>3];
 $22 = $$sroa$2$0$copyload - $21;
 $23 = ((($3)) + 16|0);
 $24 = +HEAPF64[$23>>3];
 $25 = $$sroa$3$0$copyload - $24;
 $26 = ((($1)) + 40|0);
 $27 = +HEAPF64[$26>>3];
 __ZN5osgGA19StandardManipulator13AnimationData5startEd($16,$27);
 $$sroa$010$0$$sroa_idx = ((($16)) + 48|0);
 HEAPF64[$$sroa$010$0$$sroa_idx>>3] = $19;
 $$sroa$4$0$$sroa_idx13 = ((($16)) + 56|0);
 HEAPF64[$$sroa$4$0$$sroa_idx13>>3] = $22;
 $$sroa$5$0$$sroa_idx15 = ((($16)) + 64|0);
 HEAPF64[$$sroa$5$0$$sroa_idx15>>3] = $25;
 $28 = HEAP32[$0>>2]|0;
 $29 = ((($28)) + 160|0);
 $30 = HEAP32[$29>>2]|0;
 FUNCTION_TABLE_viiii[$30 & 8191]($0,$4,$3,$5);
 $$1 = 1;
 STACKTOP = sp;return ($$1|0);
}
function __ZN5osgGA16OrbitManipulator9setCenterERKN3osg5Vec3dE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 160|0);
 ;HEAP32[$2>>2]=HEAP32[$1>>2]|0;HEAP32[$2+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$1+12>>2]|0;HEAP32[$2+16>>2]=HEAP32[$1+16>>2]|0;HEAP32[$2+20>>2]=HEAP32[$1+20>>2]|0;
 return;
}
function __ZN5osgGA16OrbitManipulator11setRotationERKN3osg4QuatE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0.0, $12 = 0, $2 = 0.0, $3 = 0, $4 = 0, $5 = 0.0, $6 = 0, $7 = 0, $8 = 0.0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = +HEAPF64[$1>>3];
 $3 = ((($0)) + 184|0);
 HEAPF64[$3>>3] = $2;
 $4 = ((($1)) + 8|0);
 $5 = +HEAPF64[$4>>3];
 $6 = ((($0)) + 192|0);
 HEAPF64[$6>>3] = $5;
 $7 = ((($1)) + 16|0);
 $8 = +HEAPF64[$7>>3];
 $9 = ((($0)) + 200|0);
 HEAPF64[$9>>3] = $8;
 $10 = ((($1)) + 24|0);
 $11 = +HEAPF64[$10>>3];
 $12 = ((($0)) + 208|0);
 HEAPF64[$12>>3] = $11;
 return;
}
function __ZN5osgGA16OrbitManipulator11setDistanceEd($0,$1) {
 $0 = $0|0;
 $1 = +$1;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 216|0);
 HEAPF64[$2>>3] = $1;
 return;
}
function __ZN5osgGA16OrbitManipulator16setTrackballSizeERKd($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0.0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = +HEAPF64[$1>>3];
 $3 = ((($0)) + 224|0);
 HEAPF64[$3>>3] = $2;
 __ZN3osg17clampBetweenRangeIdEEvRT_S1_S1_PKc($3,0.10000000000000001,1.0,110111);
 return;
}
function __ZN5osgGA16OrbitManipulator18setWheelZoomFactorEd($0,$1) {
 $0 = $0|0;
 $1 = +$1;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 232|0);
 HEAPF64[$2>>3] = $1;
 return;
}
function __ZN5osgGA16OrbitManipulator18setMinimumDistanceERKdb($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$sink$i = 0, $10 = 0, $11 = 0, $3 = 0.0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = +HEAPF64[$1>>3];
 $4 = ((($0)) + 240|0);
 HEAPF64[$4>>3] = $3;
 $5 = HEAP32[51975]|0;
 $6 = 1 << $5;
 $7 = ((($0)) + 156|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $6 ^ -1;
 $10 = $8 & $9;
 $11 = $8 | $6;
 $$sink$i = $2 ? $11 : $10;
 HEAP32[$7>>2] = $$sink$i;
 return;
}
function __ZN5osgGA16OrbitManipulator15rotateTrackballEfffff($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = +$1;
 $2 = +$2;
 $3 = +$3;
 $4 = +$4;
 $5 = +$5;
 var $10 = 0.0, $11 = 0.0, $12 = 0.0, $13 = 0.0, $14 = 0.0, $15 = 0, $16 = 0.0, $17 = 0.0, $18 = 0.0, $19 = 0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0, $24 = 0.0, $25 = 0.0, $26 = 0.0, $27 = 0, $28 = 0.0, $29 = 0;
 var $30 = 0.0, $31 = 0.0, $32 = 0.0, $33 = 0, $34 = 0.0, $35 = 0, $36 = 0.0, $37 = 0.0, $38 = 0.0, $39 = 0.0, $40 = 0.0, $41 = 0.0, $42 = 0.0, $43 = 0.0, $44 = 0.0, $45 = 0.0, $46 = 0.0, $47 = 0.0, $48 = 0.0, $49 = 0.0;
 var $50 = 0.0, $51 = 0.0, $52 = 0.0, $53 = 0.0, $54 = 0.0, $55 = 0.0, $56 = 0.0, $57 = 0.0, $58 = 0.0, $59 = 0.0, $6 = 0, $7 = 0, $8 = 0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(64|0);
 $6 = sp + 32|0;
 $7 = sp + 56|0;
 $8 = sp;
 ;HEAP32[$6>>2]=0|0;HEAP32[$6+4>>2]=0|0;HEAP32[$6+8>>2]=0|0;HEAP32[$6+12>>2]=0|0;HEAP32[$6+16>>2]=0|0;HEAP32[$6+20>>2]=0|0;
 $9 = $3 - $1;
 $10 = $9 * $5;
 $11 = $10 + $1;
 $12 = $4 - $2;
 $13 = $12 * $5;
 $14 = $13 + $2;
 __ZN5osgGA16OrbitManipulator9trackballERN3osg5Vec3dERfffff($0,$6,$7,$11,$14,$1,$2);
 $15 = ((($8)) + 24|0);
 ;HEAP32[$8>>2]=0|0;HEAP32[$8+4>>2]=0|0;HEAP32[$8+8>>2]=0|0;HEAP32[$8+12>>2]=0|0;HEAP32[$8+16>>2]=0|0;HEAP32[$8+20>>2]=0|0;
 HEAPF64[$15>>3] = 1.0;
 $16 = +HEAPF32[$7>>2];
 $17 = $16;
 __ZN3osg4Quat10makeRotateEdRKNS_5Vec3dE($8,$17,$6);
 $18 = +HEAPF64[$15>>3];
 $19 = ((($0)) + 184|0);
 $20 = +HEAPF64[$19>>3];
 $21 = $18 * $20;
 $22 = +HEAPF64[$8>>3];
 $23 = ((($0)) + 208|0);
 $24 = +HEAPF64[$23>>3];
 $25 = $22 * $24;
 $26 = $21 + $25;
 $27 = ((($8)) + 8|0);
 $28 = +HEAPF64[$27>>3];
 $29 = ((($0)) + 200|0);
 $30 = +HEAPF64[$29>>3];
 $31 = $28 * $30;
 $32 = $26 + $31;
 $33 = ((($8)) + 16|0);
 $34 = +HEAPF64[$33>>3];
 $35 = ((($0)) + 192|0);
 $36 = +HEAPF64[$35>>3];
 $37 = $34 * $36;
 $38 = $32 - $37;
 $39 = $18 * $36;
 $40 = $22 * $30;
 $41 = $39 - $40;
 $42 = $24 * $28;
 $43 = $42 + $41;
 $44 = $20 * $34;
 $45 = $44 + $43;
 $46 = $18 * $30;
 $47 = $22 * $36;
 $48 = $46 + $47;
 $49 = $20 * $28;
 $50 = $48 - $49;
 $51 = $24 * $34;
 $52 = $51 + $50;
 $53 = $18 * $24;
 $54 = $20 * $22;
 $55 = $53 - $54;
 $56 = $28 * $36;
 $57 = $55 - $56;
 $58 = $30 * $34;
 $59 = $57 - $58;
 HEAPF64[$19>>3] = $38;
 HEAPF64[$35>>3] = $45;
 HEAPF64[$29>>3] = $52;
 HEAPF64[$23>>3] = $59;
 STACKTOP = sp;return;
}
function __ZN5osgGA16OrbitManipulator23rotateWithFixedVerticalEff($0,$1,$2) {
 $0 = $0|0;
 $1 = +$1;
 $2 = +$2;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0.0, $14 = 0, $15 = 0.0, $16 = 0, $17 = 0.0, $18 = 0, $19 = 0, $20 = 0, $21 = 0.0, $22 = 0.0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(160|0);
 $3 = sp + 24|0;
 $4 = sp;
 $5 = ((($0)) + 88|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  __ZN3osg7Matrixd12makeIdentityEv($3);
 } else {
  $8 = ((($0)) + 160|0);
  $9 = HEAP32[$6>>2]|0;
  $10 = ((($9)) + 12|0);
  $11 = HEAP32[$10>>2]|0;
  FUNCTION_TABLE_viii[$11 & 8191]($3,$6,$8);
 }
 $12 = ((($3)) + 64|0);
 $13 = +HEAPF64[$12>>3];
 $14 = ((($3)) + 72|0);
 $15 = +HEAPF64[$14>>3];
 $16 = ((($3)) + 80|0);
 $17 = +HEAPF64[$16>>3];
 HEAPF64[$4>>3] = $13;
 $18 = ((($4)) + 8|0);
 HEAPF64[$18>>3] = $15;
 $19 = ((($4)) + 16|0);
 HEAPF64[$19>>3] = $17;
 $20 = ((($0)) + 184|0);
 $21 = $1;
 $22 = $2;
 __THREW__ = 0;
 invoke_viddi(3539,($20|0),(+$21),(+$22),($4|0));
 $23 = __THREW__; __THREW__ = 0;
 $24 = $23&1;
 if ($24) {
  $25 = ___cxa_find_matching_catch_2()|0;
  $26 = tempRet0;
  ___resumeException($25|0);
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN5osgGA16OrbitManipulator23rotateWithFixedVerticalEffRKN3osg5Vec3fE($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = +$1;
 $2 = +$2;
 $3 = $3|0;
 var $10 = 0, $11 = 0.0, $12 = 0.0, $13 = 0, $14 = 0, $15 = 0.0, $16 = 0.0, $17 = 0, $4 = 0, $5 = 0, $6 = 0.0, $7 = 0.0, $8 = 0.0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $4 = sp;
 $5 = ((($0)) + 184|0);
 $6 = $1;
 $7 = $2;
 $8 = +HEAPF32[$3>>2];
 $9 = $8;
 HEAPF64[$4>>3] = $9;
 $10 = ((($3)) + 4|0);
 $11 = +HEAPF32[$10>>2];
 $12 = $11;
 $13 = ((($4)) + 8|0);
 HEAPF64[$13>>3] = $12;
 $14 = ((($3)) + 8|0);
 $15 = +HEAPF32[$14>>2];
 $16 = $15;
 $17 = ((($4)) + 16|0);
 HEAPF64[$17>>3] = $16;
 __ZN5osgGA19StandardManipulator14rotateYawPitchERN3osg4QuatEddRKNS1_5Vec3dE($5,$6,$7,$4);
 STACKTOP = sp;return;
}
function __ZN5osgGA16OrbitManipulator8panModelEfff($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = +$1;
 $2 = +$2;
 $3 = +$3;
 var $10 = 0.0, $11 = 0, $12 = 0.0, $13 = 0.0, $14 = 0, $15 = 0.0, $16 = 0.0, $17 = 0.0, $18 = 0, $19 = 0.0, $20 = 0.0, $21 = 0.0, $22 = 0, $23 = 0.0, $24 = 0.0, $25 = 0.0, $26 = 0.0, $27 = 0.0, $28 = 0, $29 = 0.0;
 var $30 = 0.0, $31 = 0.0, $32 = 0, $33 = 0.0, $34 = 0.0, $35 = 0.0, $36 = 0, $37 = 0.0, $38 = 0.0, $39 = 0.0, $4 = 0, $40 = 0, $41 = 0.0, $42 = 0.0, $43 = 0, $44 = 0.0, $45 = 0.0, $46 = 0.0, $47 = 0, $48 = 0.0;
 var $49 = 0.0, $5 = 0, $50 = 0.0, $51 = 0, $52 = 0.0, $53 = 0.0, $54 = 0.0, $55 = 0, $56 = 0.0, $57 = 0.0, $58 = 0, $59 = 0.0, $6 = 0, $60 = 0.0, $61 = 0.0, $62 = 0, $63 = 0.0, $64 = 0.0, $65 = 0.0, $66 = 0;
 var $67 = 0.0, $68 = 0.0, $69 = 0.0, $7 = 0, $70 = 0, $71 = 0.0, $72 = 0.0, $73 = 0, $74 = 0.0, $75 = 0.0, $76 = 0, $77 = 0.0, $78 = 0.0, $79 = 0, $8 = 0.0, $80 = 0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(128|0);
 $4 = sp;
 __ZN3osg7Matrixd12makeIdentityEv($4);
 $5 = ((($0)) + 184|0);
 __THREW__ = 0;
 invoke_vii(3535,($4|0),($5|0));
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if ($7) {
  $79 = ___cxa_find_matching_catch_2()|0;
  $80 = tempRet0;
  ___resumeException($79|0);
  // unreachable;
 } else {
  $8 = $1;
  $9 = $2;
  $10 = $3;
  $11 = ((($4)) + 24|0);
  $12 = +HEAPF64[$11>>3];
  $13 = $8 * $12;
  $14 = ((($4)) + 56|0);
  $15 = +HEAPF64[$14>>3];
  $16 = $9 * $15;
  $17 = $13 + $16;
  $18 = ((($4)) + 88|0);
  $19 = +HEAPF64[$18>>3];
  $20 = $10 * $19;
  $21 = $17 + $20;
  $22 = ((($4)) + 120|0);
  $23 = +HEAPF64[$22>>3];
  $24 = $23 + $21;
  $25 = 1.0 / $24;
  $26 = +HEAPF64[$4>>3];
  $27 = $8 * $26;
  $28 = ((($4)) + 32|0);
  $29 = +HEAPF64[$28>>3];
  $30 = $9 * $29;
  $31 = $27 + $30;
  $32 = ((($4)) + 64|0);
  $33 = +HEAPF64[$32>>3];
  $34 = $10 * $33;
  $35 = $31 + $34;
  $36 = ((($4)) + 96|0);
  $37 = +HEAPF64[$36>>3];
  $38 = $37 + $35;
  $39 = $25 * $38;
  $40 = ((($4)) + 8|0);
  $41 = +HEAPF64[$40>>3];
  $42 = $8 * $41;
  $43 = ((($4)) + 40|0);
  $44 = +HEAPF64[$43>>3];
  $45 = $9 * $44;
  $46 = $42 + $45;
  $47 = ((($4)) + 72|0);
  $48 = +HEAPF64[$47>>3];
  $49 = $10 * $48;
  $50 = $46 + $49;
  $51 = ((($4)) + 104|0);
  $52 = +HEAPF64[$51>>3];
  $53 = $52 + $50;
  $54 = $25 * $53;
  $55 = ((($4)) + 16|0);
  $56 = +HEAPF64[$55>>3];
  $57 = $8 * $56;
  $58 = ((($4)) + 48|0);
  $59 = +HEAPF64[$58>>3];
  $60 = $9 * $59;
  $61 = $57 + $60;
  $62 = ((($4)) + 80|0);
  $63 = +HEAPF64[$62>>3];
  $64 = $10 * $63;
  $65 = $61 + $64;
  $66 = ((($4)) + 112|0);
  $67 = +HEAPF64[$66>>3];
  $68 = $67 + $65;
  $69 = $25 * $68;
  $70 = ((($0)) + 160|0);
  $71 = +HEAPF64[$70>>3];
  $72 = $39 + $71;
  HEAPF64[$70>>3] = $72;
  $73 = ((($0)) + 168|0);
  $74 = +HEAPF64[$73>>3];
  $75 = $54 + $74;
  HEAPF64[$73>>3] = $75;
  $76 = ((($0)) + 176|0);
  $77 = +HEAPF64[$76>>3];
  $78 = $69 + $77;
  HEAPF64[$76>>3] = $78;
  STACKTOP = sp;return;
 }
}
function __ZN5osgGA16OrbitManipulator9zoomModelEfb($0,$1,$2) {
 $0 = $0|0;
 $1 = +$1;
 $2 = $2|0;
 var $$0 = 0.0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0.0, $15 = 0, $16 = 0.0, $17 = 0.0, $18 = 0.0, $19 = 0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0, $25 = 0, $26 = 0, $27 = 0.0, $28 = 0.0;
 var $29 = 0, $3 = 0, $30 = 0.0, $31 = 0.0, $32 = 0.0, $33 = 0, $34 = 0.0, $35 = 0.0, $36 = 0, $37 = 0.0, $38 = 0.0, $39 = 0.0, $4 = 0.0, $40 = 0.0, $41 = 0.0, $42 = 0, $43 = 0.0, $44 = 0.0, $45 = 0.0, $46 = 0;
 var $47 = 0.0, $48 = 0.0, $49 = 0, $5 = 0, $50 = 0.0, $51 = 0.0, $52 = 0.0, $53 = 0, $54 = 0.0, $55 = 0.0, $56 = 0, $57 = 0.0, $58 = 0.0, $59 = 0.0, $6 = 0.0, $60 = 0, $61 = 0.0, $62 = 0.0, $63 = 0, $64 = 0.0;
 var $65 = 0.0, $66 = 0.0, $67 = 0, $68 = 0.0, $69 = 0.0, $7 = 0.0, $70 = 0, $71 = 0.0, $72 = 0.0, $73 = 0.0, $74 = 0, $75 = 0.0, $76 = 0.0, $77 = 0, $78 = 0.0, $79 = 0.0, $8 = 0, $80 = 0.0, $81 = 0.0, $82 = 0.0;
 var $83 = 0.0, $84 = 0.0, $85 = 0.0, $86 = 0.0, $87 = 0.0, $88 = 0, $89 = 0.0, $9 = 0, $90 = 0.0, $91 = 0, $92 = 0.0, $93 = 0.0, $94 = 0, $95 = 0.0, $96 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(128|0);
 $3 = sp;
 $4 = $1 + 1.0;
 $5 = ((($0)) + 240|0);
 $6 = +HEAPF64[$5>>3];
 $7 = $6;
 $8 = HEAP32[51975]|0;
 $9 = ((($0)) + 156|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = 1 << $8;
 $12 = $10 & $11;
 $13 = ($12|0)==(0);
 if ($13) {
  $$0 = $7;
 } else {
  $14 = $7;
  $15 = ((($0)) + 136|0);
  $16 = +HEAPF64[$15>>3];
  $17 = $14 * $16;
  $18 = $17;
  $$0 = $18;
 }
 $19 = ((($0)) + 216|0);
 $20 = +HEAPF64[$19>>3];
 $21 = $4;
 $22 = $21 * $20;
 $23 = $$0;
 $24 = $22 > $23;
 if ($24) {
  HEAPF64[$19>>3] = $22;
  STACKTOP = sp;return;
 }
 if ($2) {
  $25 = ((($0)) + 184|0);
  __ZN3osg7Matrixd10makeRotateERKNS_4QuatE($3,$25);
  $26 = ((($3)) + 24|0);
  $27 = +HEAPF64[$26>>3];
  $28 = $27 * 0.0;
  $29 = ((($3)) + 56|0);
  $30 = +HEAPF64[$29>>3];
  $31 = $30 * 0.0;
  $32 = $28 + $31;
  $33 = ((($3)) + 88|0);
  $34 = +HEAPF64[$33>>3];
  $35 = $32 - $34;
  $36 = ((($3)) + 120|0);
  $37 = +HEAPF64[$36>>3];
  $38 = $37 + $35;
  $39 = 1.0 / $38;
  $40 = +HEAPF64[$3>>3];
  $41 = $40 * 0.0;
  $42 = ((($3)) + 32|0);
  $43 = +HEAPF64[$42>>3];
  $44 = $43 * 0.0;
  $45 = $41 + $44;
  $46 = ((($3)) + 64|0);
  $47 = +HEAPF64[$46>>3];
  $48 = $45 - $47;
  $49 = ((($3)) + 96|0);
  $50 = +HEAPF64[$49>>3];
  $51 = $50 + $48;
  $52 = $39 * $51;
  $53 = ((($3)) + 8|0);
  $54 = +HEAPF64[$53>>3];
  $55 = $54 * 0.0;
  $56 = ((($3)) + 40|0);
  $57 = +HEAPF64[$56>>3];
  $58 = $57 * 0.0;
  $59 = $55 + $58;
  $60 = ((($3)) + 72|0);
  $61 = +HEAPF64[$60>>3];
  $62 = $59 - $61;
  $63 = ((($3)) + 104|0);
  $64 = +HEAPF64[$63>>3];
  $65 = $64 + $62;
  $66 = $39 * $65;
  $67 = ((($3)) + 16|0);
  $68 = +HEAPF64[$67>>3];
  $69 = $68 * 0.0;
  $70 = ((($3)) + 48|0);
  $71 = +HEAPF64[$70>>3];
  $72 = $71 * 0.0;
  $73 = $69 + $72;
  $74 = ((($3)) + 80|0);
  $75 = +HEAPF64[$74>>3];
  $76 = $73 - $75;
  $77 = ((($3)) + 112|0);
  $78 = +HEAPF64[$77>>3];
  $79 = $78 + $76;
  $80 = $39 * $79;
  $81 = $20;
  $82 = $81 * $1;
  $83 = -$82;
  $84 = $83;
  $85 = $84 * $52;
  $86 = $84 * $66;
  $87 = $84 * $80;
  $88 = ((($0)) + 160|0);
  $89 = +HEAPF64[$88>>3];
  $90 = $85 + $89;
  HEAPF64[$88>>3] = $90;
  $91 = ((($0)) + 168|0);
  $92 = +HEAPF64[$91>>3];
  $93 = $86 + $92;
  HEAPF64[$91>>3] = $93;
  $94 = ((($0)) + 176|0);
  $95 = +HEAPF64[$94>>3];
  $96 = $87 + $95;
  HEAPF64[$94>>3] = $96;
  STACKTOP = sp;return;
 } else {
  HEAPF64[$19>>3] = $23;
  STACKTOP = sp;return;
 }
}
function __ZN5osgGA16OrbitManipulator9trackballERN3osg5Vec3dERfffff($0,$1,$2,$3,$4,$5,$6) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = +$3;
 $4 = +$4;
 $5 = +$5;
 $6 = +$6;
 var $$0 = 0.0, $$0$i = 0.0, $$0$i27 = 0.0, $$1 = 0.0, $$sroa$5$0$$sroa_idx32 = 0, $$sroa$6$0$$sroa_idx35 = 0, $10 = 0.0, $100 = 0.0, $101 = 0.0, $102 = 0.0, $103 = 0.0, $104 = 0.0, $105 = 0.0, $106 = 0.0, $107 = 0.0, $108 = 0.0, $109 = 0.0, $11 = 0.0, $110 = 0.0, $111 = 0;
 var $112 = 0.0, $113 = 0.0, $114 = 0.0, $115 = 0.0, $116 = 0.0, $117 = 0.0, $118 = 0.0, $119 = 0.0, $12 = 0, $120 = 0.0, $121 = 0, $122 = 0.0, $123 = 0.0, $124 = 0.0, $125 = 0.0, $126 = 0.0, $127 = 0.0, $128 = 0.0, $129 = 0.0, $13 = 0.0;
 var $130 = 0.0, $131 = 0.0, $132 = 0.0, $133 = 0.0, $134 = 0.0, $135 = 0.0, $136 = 0.0, $137 = 0.0, $138 = 0.0, $139 = 0.0, $14 = 0.0, $140 = 0.0, $141 = 0.0, $142 = 0.0, $143 = 0.0, $144 = 0.0, $145 = 0.0, $146 = 0.0, $147 = 0.0, $148 = 0.0;
 var $149 = 0.0, $15 = 0, $150 = 0.0, $151 = 0.0, $152 = 0.0, $153 = 0, $154 = 0.0, $155 = 0.0, $156 = 0.0, $157 = 0.0, $158 = 0.0, $159 = 0.0, $16 = 0.0, $160 = 0.0, $161 = 0.0, $162 = 0.0, $163 = 0.0, $164 = 0.0, $165 = 0.0, $166 = 0.0;
 var $167 = 0.0, $168 = 0.0, $169 = 0.0, $17 = 0.0, $170 = 0.0, $171 = 0.0, $172 = 0.0, $173 = 0.0, $174 = 0.0, $175 = 0.0, $176 = 0.0, $177 = 0.0, $178 = 0.0, $179 = 0.0, $18 = 0.0, $180 = 0.0, $181 = 0.0, $182 = 0.0, $183 = 0.0, $184 = 0;
 var $185 = 0.0, $186 = 0.0, $187 = 0.0, $188 = 0.0, $189 = 0.0, $19 = 0, $190 = 0.0, $191 = 0.0, $192 = 0.0, $193 = 0.0, $194 = 0.0, $195 = 0.0, $196 = 0.0, $197 = 0.0, $198 = 0.0, $199 = 0.0, $20 = 0.0, $200 = 0.0, $201 = 0.0, $202 = 0;
 var $203 = 0, $204 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0.0, $25 = 0, $26 = 0.0, $27 = 0.0, $28 = 0, $29 = 0.0, $30 = 0.0, $31 = 0.0, $32 = 0, $33 = 0.0, $34 = 0.0, $35 = 0.0, $36 = 0, $37 = 0.0, $38 = 0.0;
 var $39 = 0, $40 = 0.0, $41 = 0.0, $42 = 0, $43 = 0.0, $44 = 0.0, $45 = 0.0, $46 = 0, $47 = 0.0, $48 = 0.0, $49 = 0.0, $50 = 0, $51 = 0.0, $52 = 0.0, $53 = 0, $54 = 0.0, $55 = 0.0, $56 = 0, $57 = 0.0, $58 = 0.0;
 var $59 = 0.0, $60 = 0, $61 = 0.0, $62 = 0.0, $63 = 0.0, $64 = 0.0, $65 = 0.0, $66 = 0.0, $67 = 0.0, $68 = 0.0, $69 = 0.0, $7 = 0, $70 = 0.0, $71 = 0.0, $72 = 0.0, $73 = 0.0, $74 = 0.0, $75 = 0.0, $76 = 0.0, $77 = 0.0;
 var $78 = 0.0, $79 = 0.0, $8 = 0, $80 = 0.0, $81 = 0.0, $82 = 0.0, $83 = 0.0, $84 = 0.0, $85 = 0.0, $86 = 0.0, $87 = 0.0, $88 = 0.0, $89 = 0.0, $9 = 0, $90 = 0.0, $91 = 0.0, $92 = 0.0, $93 = 0.0, $94 = 0.0, $95 = 0.0;
 var $96 = 0.0, $97 = 0.0, $98 = 0.0, $99 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(128|0);
 $7 = sp;
 $8 = ((($0)) + 184|0);
 __ZN3osg7Matrixd10makeRotateERKNS_4QuatE($7,$8);
 $9 = ((($7)) + 24|0);
 $10 = +HEAPF64[$9>>3];
 $11 = $10 * 0.0;
 $12 = ((($7)) + 56|0);
 $13 = +HEAPF64[$12>>3];
 $14 = $11 + $13;
 $15 = ((($7)) + 88|0);
 $16 = +HEAPF64[$15>>3];
 $17 = $16 * 0.0;
 $18 = $14 + $17;
 $19 = ((($7)) + 120|0);
 $20 = +HEAPF64[$19>>3];
 $21 = $20 + $18;
 $22 = 1.0 / $21;
 $23 = +HEAPF64[$7>>3];
 $24 = $23 * 0.0;
 $25 = ((($7)) + 32|0);
 $26 = +HEAPF64[$25>>3];
 $27 = $24 + $26;
 $28 = ((($7)) + 64|0);
 $29 = +HEAPF64[$28>>3];
 $30 = $29 * 0.0;
 $31 = $27 + $30;
 $32 = ((($7)) + 96|0);
 $33 = +HEAPF64[$32>>3];
 $34 = $33 + $31;
 $35 = $22 * $34;
 $36 = ((($7)) + 8|0);
 $37 = +HEAPF64[$36>>3];
 $38 = $37 * 0.0;
 $39 = ((($7)) + 40|0);
 $40 = +HEAPF64[$39>>3];
 $41 = $38 + $40;
 $42 = ((($7)) + 72|0);
 $43 = +HEAPF64[$42>>3];
 $44 = $43 * 0.0;
 $45 = $41 + $44;
 $46 = ((($7)) + 104|0);
 $47 = +HEAPF64[$46>>3];
 $48 = $47 + $45;
 $49 = $22 * $48;
 $50 = ((($7)) + 16|0);
 $51 = +HEAPF64[$50>>3];
 $52 = $51 * 0.0;
 $53 = ((($7)) + 48|0);
 $54 = +HEAPF64[$53>>3];
 $55 = $52 + $54;
 $56 = ((($7)) + 80|0);
 $57 = +HEAPF64[$56>>3];
 $58 = $57 * 0.0;
 $59 = $55 + $58;
 $60 = ((($7)) + 112|0);
 $61 = +HEAPF64[$60>>3];
 $62 = $61 + $59;
 $63 = $22 * $62;
 $64 = $13 * 0.0;
 $65 = $10 + $64;
 $66 = $65 + $17;
 $67 = $20 + $66;
 $68 = 1.0 / $67;
 $69 = $26 * 0.0;
 $70 = $23 + $69;
 $71 = $70 + $30;
 $72 = $33 + $71;
 $73 = $68 * $72;
 $74 = $40 * 0.0;
 $75 = $37 + $74;
 $76 = $75 + $44;
 $77 = $47 + $76;
 $78 = $68 * $77;
 $79 = $54 * 0.0;
 $80 = $51 + $79;
 $81 = $80 + $58;
 $82 = $61 + $81;
 $83 = $68 * $82;
 $84 = $11 + $64;
 $85 = $84 - $16;
 $86 = $20 + $85;
 $87 = 1.0 / $86;
 $88 = $24 + $69;
 $89 = $88 - $29;
 $90 = $33 + $89;
 $91 = $87 * $90;
 $92 = $38 + $74;
 $93 = $92 - $43;
 $94 = $47 + $93;
 $95 = $87 * $94;
 $96 = $52 + $79;
 $97 = $96 - $57;
 $98 = $61 + $97;
 $99 = $87 * $98;
 $100 = $3;
 $101 = $100 * $73;
 $102 = $100 * $78;
 $103 = $100 * $83;
 $104 = $4;
 $105 = $104 * $35;
 $106 = $104 * $49;
 $107 = $104 * $63;
 $108 = $101 + $105;
 $109 = $102 + $106;
 $110 = $103 + $107;
 $111 = ((($0)) + 224|0);
 $112 = +HEAPF64[$111>>3];
 $113 = $112;
 $114 = $3 * $3;
 $115 = $4 * $4;
 $116 = $114 + $115;
 $117 = (+Math_sqrt((+$116)));
 $118 = $117;
 $119 = $113;
 $120 = $119 * 0.70710678118654757;
 $121 = $118 < $120;
 if ($121) {
  $122 = $113 * $113;
  $123 = $117 * $117;
  $124 = $122 - $123;
  $125 = (+Math_sqrt((+$124)));
  $$0$i27 = $125;
 } else {
  $126 = $119 / 1.4142135623730951;
  $127 = $126;
  $128 = $127 * $127;
  $129 = $128 / $117;
  $$0$i27 = $129;
 }
 $130 = $$0$i27;
 $131 = $91 * $130;
 $132 = $95 * $130;
 $133 = $99 * $130;
 $134 = $108 - $131;
 $135 = $109 - $132;
 $136 = $110 - $133;
 $137 = $5;
 $138 = $137 * $73;
 $139 = $137 * $78;
 $140 = $137 * $83;
 $141 = $6;
 $142 = $141 * $35;
 $143 = $141 * $49;
 $144 = $141 * $63;
 $145 = $138 + $142;
 $146 = $139 + $143;
 $147 = $140 + $144;
 $148 = $5 * $5;
 $149 = $6 * $6;
 $150 = $148 + $149;
 $151 = (+Math_sqrt((+$150)));
 $152 = $151;
 $153 = $152 < $120;
 if ($153) {
  $154 = $113 * $113;
  $155 = $151 * $151;
  $156 = $154 - $155;
  $157 = (+Math_sqrt((+$156)));
  $$0$i = $157;
 } else {
  $158 = $119 / 1.4142135623730951;
  $159 = $158;
  $160 = $159 * $159;
  $161 = $160 / $151;
  $$0$i = $161;
 }
 $162 = $$0$i;
 $163 = $91 * $162;
 $164 = $95 * $162;
 $165 = $99 * $162;
 $166 = $145 - $163;
 $167 = $146 - $164;
 $168 = $147 - $165;
 $169 = $136 * $167;
 $170 = $135 * $168;
 $171 = $169 - $170;
 $172 = $134 * $168;
 $173 = $136 * $166;
 $174 = $172 - $173;
 $175 = $135 * $166;
 $176 = $134 * $167;
 $177 = $175 - $176;
 HEAPF64[$1>>3] = $171;
 $$sroa$5$0$$sroa_idx32 = ((($1)) + 8|0);
 HEAPF64[$$sroa$5$0$$sroa_idx32>>3] = $174;
 $$sroa$6$0$$sroa_idx35 = ((($1)) + 16|0);
 HEAPF64[$$sroa$6$0$$sroa_idx35>>3] = $177;
 $178 = $171 * $171;
 $179 = $174 * $174;
 $180 = $178 + $179;
 $181 = $177 * $177;
 $182 = $181 + $180;
 $183 = (+Math_sqrt((+$182)));
 $184 = $183 > 0.0;
 $185 = 1.0 / $183;
 if (!($184)) {
  $189 = $166 - $134;
  $190 = $167 - $135;
  $191 = $168 - $136;
  $192 = $189 * $189;
  $193 = $190 * $190;
  $194 = $192 + $193;
  $195 = $191 * $191;
  $196 = $195 + $194;
  $197 = (+Math_sqrt((+$196)));
  $198 = +HEAPF64[$111>>3];
  $199 = $198 * 2.0;
  $200 = $197 / $199;
  $201 = $200;
  $202 = $201 > 1.0;
  $$0 = $202 ? 1.0 : $201;
  $203 = $$0 < -1.0;
  $$1 = $203 ? -1.0 : $$0;
  $204 = (+Math_asin((+$$1)));
  HEAPF32[$2>>2] = $204;
  STACKTOP = sp;return;
 }
 $186 = $185 * $177;
 $187 = $185 * $174;
 $188 = $171 * $185;
 HEAPF64[$1>>3] = $188;
 HEAPF64[$$sroa$5$0$$sroa_idx32>>3] = $187;
 HEAPF64[$$sroa$6$0$$sroa_idx35>>3] = $186;
 $189 = $166 - $134;
 $190 = $167 - $135;
 $191 = $168 - $136;
 $192 = $189 * $189;
 $193 = $190 * $190;
 $194 = $192 + $193;
 $195 = $191 * $191;
 $196 = $195 + $194;
 $197 = (+Math_sqrt((+$196)));
 $198 = +HEAPF64[$111>>3];
 $199 = $198 * 2.0;
 $200 = $197 / $199;
 $201 = $200;
 $202 = $201 > 1.0;
 $$0 = $202 ? 1.0 : $201;
 $203 = $$0 < -1.0;
 $$1 = $203 ? -1.0 : $$0;
 $204 = (+Math_asin((+$$1)));
 HEAPF32[$2>>2] = $204;
 STACKTOP = sp;return;
}
function __ZN3osg17clampBetweenRangeIdEEvRT_S1_S1_PKc($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = +$1;
 $2 = +$2;
 $3 = $3|0;
 var $$sink = 0.0, $10 = 0, $11 = 0, $12 = 0, $13 = 0.0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0.0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0.0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $4 = sp + 4|0;
 $5 = sp;
 $6 = +HEAPF64[$0>>3];
 $7 = $6 < $1;
 do {
  if ($7) {
   $8 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
   $9 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($8,110157,9)|0);
   $10 = (_strlen($3)|0);
   $11 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($9,$3,$10)|0);
   $12 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($11,110167,4)|0);
   $13 = +HEAPF64[$0>>3];
   $14 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEd($12,$13)|0);
   $15 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($14,110172,41)|0);
   $16 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEd($15,$1)|0);
   $17 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($16,199839,1)|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = ((($18)) + -12|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($17) + ($20)|0);
   __ZNKSt3__28ios_base6getlocEv($5,$21);
   __THREW__ = 0;
   $22 = (invoke_iii(3255,($5|0),(215188|0))|0);
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if (!($24)) {
    $25 = HEAP32[$22>>2]|0;
    $26 = ((($25)) + 28|0);
    $27 = HEAP32[$26>>2]|0;
    __THREW__ = 0;
    $28 = (invoke_iii($27|0,($22|0),10)|0);
    $29 = __THREW__; __THREW__ = 0;
    $30 = $29&1;
    if (!($30)) {
     __ZNSt3__26localeD2Ev($5);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($17,$28)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($17)|0);
     $$sink = $1;
     break;
    }
   }
   $31 = ___cxa_find_matching_catch_2()|0;
   $32 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($5|0));
   $33 = __THREW__; __THREW__ = 0;
   $34 = $33&1;
   if ($34) {
    $35 = ___cxa_find_matching_catch_3(0|0)|0;
    $36 = tempRet0;
    ___clang_call_terminate($35);
    // unreachable;
   } else {
    ___resumeException($31|0);
    // unreachable;
   }
  } else {
   $37 = $6 > $2;
   if (!($37)) {
    STACKTOP = sp;return;
   }
   $38 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
   $39 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($38,110157,9)|0);
   $40 = (_strlen($3)|0);
   $41 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($39,$3,$40)|0);
   $42 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($41,110167,4)|0);
   $43 = +HEAPF64[$0>>3];
   $44 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEd($42,$43)|0);
   $45 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($44,110214,41)|0);
   $46 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEd($45,$2)|0);
   $47 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($46,199839,1)|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = ((($48)) + -12|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = (($47) + ($50)|0);
   __ZNKSt3__28ios_base6getlocEv($4,$51);
   __THREW__ = 0;
   $52 = (invoke_iii(3255,($4|0),(215188|0))|0);
   $53 = __THREW__; __THREW__ = 0;
   $54 = $53&1;
   if (!($54)) {
    $55 = HEAP32[$52>>2]|0;
    $56 = ((($55)) + 28|0);
    $57 = HEAP32[$56>>2]|0;
    __THREW__ = 0;
    $58 = (invoke_iii($57|0,($52|0),10)|0);
    $59 = __THREW__; __THREW__ = 0;
    $60 = $59&1;
    if (!($60)) {
     __ZNSt3__26localeD2Ev($4);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($47,$58)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($47)|0);
     $$sink = $2;
     break;
    }
   }
   $61 = ___cxa_find_matching_catch_2()|0;
   $62 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($4|0));
   $63 = __THREW__; __THREW__ = 0;
   $64 = $63&1;
   if ($64) {
    $65 = ___cxa_find_matching_catch_3(0|0)|0;
    $66 = tempRet0;
    ___clang_call_terminate($65);
    // unreachable;
   } else {
    ___resumeException($61|0);
    // unreachable;
   }
  }
 } while(0);
 HEAPF64[$0>>3] = $$sink;
 STACKTOP = sp;return;
}
function __GLOBAL__sub_I_OrbitManipulator_cpp() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF32[51976] = 1.0;
 HEAPF32[(207908)>>2] = 0.0;
 HEAPF32[(207912)>>2] = 0.0;
 HEAPF32[51979] = 0.0;
 HEAPF32[(207920)>>2] = 1.0;
 HEAPF32[(207924)>>2] = 0.0;
 HEAPF32[51982] = 0.0;
 HEAPF32[(207932)>>2] = 0.0;
 HEAPF32[(207936)>>2] = 1.0;
 $0 = (__ZN5osgGA19StandardManipulator20allocateRelativeFlagEv()|0);
 HEAP32[51975] = $0;
 return;
}
function __ZN5osgGA16OrbitManipulatorC2Ei($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$04 = 0, $$cast = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = ((($1)) + 4|0);
 __ZN5osgGA19StandardManipulatorC2Ei($0,$4,$2);
 $5 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $5;
 $6 = ((($1)) + 92|0);
 $7 = HEAP32[$6>>2]|0;
 $$cast = $5;
 $8 = ((($$cast)) + -12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($0) + ($9)|0);
 HEAP32[$10>>2] = $7;
 $11 = ((($1)) + 96|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = HEAP32[$0>>2]|0;
 $14 = ((($13)) + -16|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($0) + ($15)|0);
 HEAP32[$16>>2] = $12;
 $17 = ((($1)) + 100|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ((($0)) + 4|0);
 HEAP32[$19>>2] = $18;
 $20 = ((($0)) + 160|0);
 $21 = ((($0)) + 208|0);
 dest=$20; stop=dest+48|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF64[$21>>3] = 1.0;
 $22 = ((($0)) + 216|0);
 HEAPF64[$22>>3] = 1.0;
 $23 = ((($0)) + 224|0);
 HEAPF64[$23>>3] = 0.80000000000000004;
 $24 = HEAP32[$0>>2]|0;
 $25 = ((($24)) + 292|0);
 $26 = HEAP32[$25>>2]|0;
 HEAPF64[$3>>3] = 0.050000000000000003;
 __THREW__ = 0;
 invoke_viii($26|0,($0|0),($3|0),1);
 $27 = __THREW__; __THREW__ = 0;
 $28 = $27&1;
 if ($28) {
  $45 = ___cxa_find_matching_catch_2()|0;
  $46 = tempRet0;
  $$0 = $46;$$04 = $45;
 } else {
  $29 = HEAP32[$0>>2]|0;
  $30 = ((($29)) + 288|0);
  $31 = HEAP32[$30>>2]|0;
  __THREW__ = 0;
  invoke_vid($31|0,($0|0),0.10000000000000001);
  $32 = __THREW__; __THREW__ = 0;
  $33 = $32&1;
  if (!($33)) {
   $34 = ((($0)) + 152|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = $35 & 8;
   $37 = ($36|0)==(0);
   if ($37) {
    STACKTOP = sp;return;
   }
   $38 = HEAP32[$0>>2]|0;
   $39 = ((($38)) + 180|0);
   $40 = HEAP32[$39>>2]|0;
   __THREW__ = 0;
   invoke_vid($40|0,($0|0),0.20000000000000001);
   $41 = __THREW__; __THREW__ = 0;
   $42 = $41&1;
   if (!($42)) {
    STACKTOP = sp;return;
   }
  }
  $43 = ___cxa_find_matching_catch_2()|0;
  $44 = tempRet0;
  $$0 = $44;$$04 = $43;
 }
 __THREW__ = 0;
 invoke_vii(3527,($0|0),($4|0));
 $47 = __THREW__; __THREW__ = 0;
 $48 = $47&1;
 if ($48) {
  $49 = ___cxa_find_matching_catch_3(0|0)|0;
  $50 = tempRet0;
  ___clang_call_terminate($49);
  // unreachable;
 } else {
  ___resumeException($$04|0);
  // unreachable;
 }
}
function __ZN5osgGA16OrbitManipulatorC1Ei($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$1 = 0, $$14 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 256|0);
 __ZN3osg10ReferencedC2Ev($2);
 $3 = ((($0)) + 268|0);
 ;HEAP32[$3>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;
 $4 = ((($0)) + 280|0);
 HEAP32[$4>>2] = 2;
 $5 = ((($0)) + 284|0);
 HEAP32[$5>>2] = 0;
 $6 = ((($0)) + 248|0);
 HEAP32[$6>>2] = ((29984));
 $7 = ((($6)) + 8|0);
 HEAP32[$7>>2] = ((30232));
 $8 = ((($0)) + 252|0);
 HEAP32[$8>>2] = 0;
 __THREW__ = 0;
 invoke_viii(3540,($0|0),((45484)|0),($1|0));
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if ($10) {
  $29 = ___cxa_find_matching_catch_2()|0;
  $30 = tempRet0;
  $$1 = $30;$$14 = $29;
 } else {
  HEAP32[$0>>2] = (688);
  HEAP32[$6>>2] = (1176);
  HEAP32[$2>>2] = (1424);
  $11 = ((($0)) + 4|0);
  HEAP32[$11>>2] = (1020);
  $12 = ((($0)) + 160|0);
  $13 = ((($0)) + 208|0);
  dest=$12; stop=dest+48|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
  HEAPF64[$13>>3] = 1.0;
  $14 = ((($0)) + 216|0);
  HEAPF64[$14>>3] = 1.0;
  $15 = ((($0)) + 224|0);
  HEAPF64[$15>>3] = 0.80000000000000004;
  $16 = ((($0)) + 240|0);
  HEAPF64[$16>>3] = 0.050000000000000003;
  $17 = HEAP32[51975]|0;
  $18 = 1 << $17;
  $19 = ((($0)) + 156|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = $20 | $18;
  HEAP32[$19>>2] = $21;
  $22 = ((($0)) + 232|0);
  HEAPF64[$22>>3] = 0.10000000000000001;
  $23 = ((($0)) + 152|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = $24 & 8;
  $26 = ($25|0)==(0);
  if ($26) {
   return;
  }
  __THREW__ = 0;
  invoke_vid(800,($0|0),0.20000000000000001);
  $27 = __THREW__; __THREW__ = 0;
  $28 = $27&1;
  if (!($28)) {
   return;
  }
  $31 = ___cxa_find_matching_catch_2()|0;
  $32 = tempRet0;
  __THREW__ = 0;
  invoke_vii(3527,($0|0),((45484)|0));
  $33 = __THREW__; __THREW__ = 0;
  $34 = $33&1;
  if ($34) {
   $48 = ___cxa_find_matching_catch_3(0|0)|0;
   $49 = tempRet0;
   ___clang_call_terminate($48);
   // unreachable;
  } else {
   $$1 = $32;$$14 = $31;
  }
 }
 HEAP32[$6>>2] = ((29984));
 HEAP32[$7>>2] = ((30232));
 $35 = HEAP32[$8>>2]|0;
 $36 = ($35|0)==(0|0);
 if (!($36)) {
  $37 = HEAP32[$35>>2]|0;
  $38 = ((($37)) + -12|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = (($35) + ($39)|0);
  $41 = ((($40)) + 8|0);
  $42 = HEAP32[$41>>2]|0;HEAP32[$41>>2] = (($42-1)|0);
  $43 = ($42|0)==(1);
  if ($43) {
   __THREW__ = 0;
   invoke_viii(3262,($40|0),1,1);
   $44 = __THREW__; __THREW__ = 0;
   $45 = $44&1;
   if ($45) {
    $48 = ___cxa_find_matching_catch_3(0|0)|0;
    $49 = tempRet0;
    ___clang_call_terminate($48);
    // unreachable;
   }
  }
 }
 HEAP32[$8>>2] = 0;
 __THREW__ = 0;
 invoke_vi(388,($2|0));
 $46 = __THREW__; __THREW__ = 0;
 $47 = $46&1;
 if ($47) {
  $48 = ___cxa_find_matching_catch_3(0|0)|0;
  $49 = tempRet0;
  ___clang_call_terminate($48);
  // unreachable;
 } else {
  ___resumeException($$14|0);
  // unreachable;
 }
}
function __ZN5osgGA16OrbitManipulatorC2ERKS0_RKN3osg6CopyOpE($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$cast = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0.0, $27 = 0, $28 = 0;
 var $29 = 0.0, $30 = 0, $31 = 0, $32 = 0.0, $33 = 0, $34 = 0, $35 = 0.0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ((($1)) + 4|0);
 __ZN5osgGA19StandardManipulatorC2ERKS0_RKN3osg6CopyOpE($0,$4,$2,$3);
 $5 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $5;
 $6 = ((($1)) + 92|0);
 $7 = HEAP32[$6>>2]|0;
 $$cast = $5;
 $8 = ((($$cast)) + -12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($0) + ($9)|0);
 HEAP32[$10>>2] = $7;
 $11 = ((($1)) + 96|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = HEAP32[$0>>2]|0;
 $14 = ((($13)) + -16|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($0) + ($15)|0);
 HEAP32[$16>>2] = $12;
 $17 = ((($1)) + 100|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ((($0)) + 4|0);
 HEAP32[$19>>2] = $18;
 $20 = ((($0)) + 160|0);
 $21 = ((($2)) + 160|0);
 ;HEAP32[$20>>2]=HEAP32[$21>>2]|0;HEAP32[$20+4>>2]=HEAP32[$21+4>>2]|0;HEAP32[$20+8>>2]=HEAP32[$21+8>>2]|0;HEAP32[$20+12>>2]=HEAP32[$21+12>>2]|0;HEAP32[$20+16>>2]=HEAP32[$21+16>>2]|0;HEAP32[$20+20>>2]=HEAP32[$21+20>>2]|0;
 $22 = ((($0)) + 184|0);
 $23 = ((($2)) + 184|0);
 ;HEAP32[$22>>2]=HEAP32[$23>>2]|0;HEAP32[$22+4>>2]=HEAP32[$23+4>>2]|0;HEAP32[$22+8>>2]=HEAP32[$23+8>>2]|0;HEAP32[$22+12>>2]=HEAP32[$23+12>>2]|0;HEAP32[$22+16>>2]=HEAP32[$23+16>>2]|0;HEAP32[$22+20>>2]=HEAP32[$23+20>>2]|0;HEAP32[$22+24>>2]=HEAP32[$23+24>>2]|0;HEAP32[$22+28>>2]=HEAP32[$23+28>>2]|0;
 $24 = ((($0)) + 216|0);
 $25 = ((($2)) + 216|0);
 $26 = +HEAPF64[$25>>3];
 HEAPF64[$24>>3] = $26;
 $27 = ((($0)) + 224|0);
 $28 = ((($2)) + 224|0);
 $29 = +HEAPF64[$28>>3];
 HEAPF64[$27>>3] = $29;
 $30 = ((($0)) + 232|0);
 $31 = ((($2)) + 232|0);
 $32 = +HEAPF64[$31>>3];
 HEAPF64[$30>>3] = $32;
 $33 = ((($0)) + 240|0);
 $34 = ((($2)) + 240|0);
 $35 = +HEAPF64[$34>>3];
 HEAPF64[$33>>3] = $35;
 return;
}
function __ZN5osgGA16OrbitManipulatorC1ERKS0_RKN3osg6CopyOpE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0.0, $34 = 0, $35 = 0, $36 = 0.0, $37 = 0, $38 = 0, $39 = 0.0, $4 = 0, $40 = 0, $41 = 0, $42 = 0.0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 256|0);
 $4 = HEAP32[$1>>2]|0;
 $5 = ((($4)) + -16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($1) + ($6)|0);
 __ZN3osg6ObjectC2ERKS0_RKNS_6CopyOpE($3,$7,$2);
 $8 = ((($0)) + 248|0);
 $9 = HEAP32[$1>>2]|0;
 $10 = ((($9)) + -12|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($1) + ($11)|0);
 HEAP32[$8>>2] = ((29984));
 $13 = ((($8)) + 8|0);
 HEAP32[$13>>2] = ((30232));
 $14 = ((($0)) + 252|0);
 $15 = ((($12)) + 4|0);
 $16 = HEAP32[$15>>2]|0;
 HEAP32[$14>>2] = $16;
 $17 = ($16|0)==(0|0);
 if (!($17)) {
  $18 = HEAP32[$16>>2]|0;
  $19 = ((($18)) + -12|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = (($16) + ($20)|0);
  $22 = ((($21)) + 8|0);
  $23 = HEAP32[$22>>2]|0;HEAP32[$22>>2] = (($23+1)|0);
 }
 __THREW__ = 0;
 invoke_viiii(3541,($0|0),((45484)|0),($1|0),($2|0));
 $24 = __THREW__; __THREW__ = 0;
 $25 = $24&1;
 if (!($25)) {
  HEAP32[$0>>2] = (688);
  HEAP32[$8>>2] = (1176);
  HEAP32[$3>>2] = (1424);
  $26 = ((($0)) + 4|0);
  HEAP32[$26>>2] = (1020);
  $27 = ((($0)) + 160|0);
  $28 = ((($1)) + 160|0);
  ;HEAP32[$27>>2]=HEAP32[$28>>2]|0;HEAP32[$27+4>>2]=HEAP32[$28+4>>2]|0;HEAP32[$27+8>>2]=HEAP32[$28+8>>2]|0;HEAP32[$27+12>>2]=HEAP32[$28+12>>2]|0;HEAP32[$27+16>>2]=HEAP32[$28+16>>2]|0;HEAP32[$27+20>>2]=HEAP32[$28+20>>2]|0;
  $29 = ((($0)) + 184|0);
  $30 = ((($1)) + 184|0);
  ;HEAP32[$29>>2]=HEAP32[$30>>2]|0;HEAP32[$29+4>>2]=HEAP32[$30+4>>2]|0;HEAP32[$29+8>>2]=HEAP32[$30+8>>2]|0;HEAP32[$29+12>>2]=HEAP32[$30+12>>2]|0;HEAP32[$29+16>>2]=HEAP32[$30+16>>2]|0;HEAP32[$29+20>>2]=HEAP32[$30+20>>2]|0;HEAP32[$29+24>>2]=HEAP32[$30+24>>2]|0;HEAP32[$29+28>>2]=HEAP32[$30+28>>2]|0;
  $31 = ((($0)) + 216|0);
  $32 = ((($1)) + 216|0);
  $33 = +HEAPF64[$32>>3];
  HEAPF64[$31>>3] = $33;
  $34 = ((($0)) + 224|0);
  $35 = ((($1)) + 224|0);
  $36 = +HEAPF64[$35>>3];
  HEAPF64[$34>>3] = $36;
  $37 = ((($0)) + 232|0);
  $38 = ((($1)) + 232|0);
  $39 = +HEAPF64[$38>>3];
  HEAPF64[$37>>3] = $39;
  $40 = ((($0)) + 240|0);
  $41 = ((($1)) + 240|0);
  $42 = +HEAPF64[$41>>3];
  HEAPF64[$40>>3] = $42;
  return;
 }
 $43 = ___cxa_find_matching_catch_2()|0;
 $44 = tempRet0;
 HEAP32[$8>>2] = ((29984));
 HEAP32[$13>>2] = ((30232));
 $45 = HEAP32[$14>>2]|0;
 $46 = ($45|0)==(0|0);
 if (!($46)) {
  $47 = HEAP32[$45>>2]|0;
  $48 = ((($47)) + -12|0);
  $49 = HEAP32[$48>>2]|0;
  $50 = (($45) + ($49)|0);
  $51 = ((($50)) + 8|0);
  $52 = HEAP32[$51>>2]|0;HEAP32[$51>>2] = (($52-1)|0);
  $53 = ($52|0)==(1);
  if ($53) {
   __THREW__ = 0;
   invoke_viii(3262,($50|0),1,1);
   $54 = __THREW__; __THREW__ = 0;
   $55 = $54&1;
   if ($55) {
    $58 = ___cxa_find_matching_catch_3(0|0)|0;
    $59 = tempRet0;
    ___clang_call_terminate($58);
    // unreachable;
   }
  }
 }
 HEAP32[$14>>2] = 0;
 __THREW__ = 0;
 invoke_vi(388,($3|0));
 $56 = __THREW__; __THREW__ = 0;
 $57 = $56&1;
 if ($57) {
  $58 = ___cxa_find_matching_catch_3(0|0)|0;
  $59 = tempRet0;
  ___clang_call_terminate($58);
  // unreachable;
 } else {
  ___resumeException($43|0);
  // unreachable;
 }
}
function __ZNK5osgGA19StandardManipulator8getUsageERN3osg16ApplicationUsageE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$03 = 0, $$1 = 0, $$14 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $2 = sp + 24|0;
 $3 = sp + 12|0;
 $4 = sp;
 __ZNK5osgGA17CameraManipulator18getManipulatorNameEv($3,$0);
 __THREW__ = 0;
 invoke_viii(3542,($2|0),($3|0),(110398|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $27 = ___cxa_find_matching_catch_2()|0;
  $28 = tempRet0;
  $$1 = $28;$$14 = $27;
 } else {
  ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;
  __THREW__ = 0;
  $7 = (invoke_ii(3276,48)|0);
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  do {
   if ($9) {
    $29 = ___cxa_find_matching_catch_2()|0;
    $30 = tempRet0;
    $$0 = $30;$$03 = $29;
   } else {
    HEAP32[$4>>2] = $7;
    $10 = ((($4)) + 8|0);
    HEAP32[$10>>2] = -2147483600;
    $11 = ((($4)) + 4|0);
    HEAP32[$11>>2] = 34;
    dest=$7; src=110406; stop=dest+34|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
    $12 = ((($7)) + 34|0);
    HEAP8[$12>>0] = 0;
    __THREW__ = 0;
    invoke_viii(3543,($1|0),($2|0),($4|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     $31 = ___cxa_find_matching_catch_2()|0;
     $32 = tempRet0;
     $33 = ((($4)) + 11|0);
     $34 = HEAP8[$33>>0]|0;
     $35 = ($34<<24>>24)<(0);
     if (!($35)) {
      $$0 = $32;$$03 = $31;
      break;
     }
     $36 = HEAP32[$4>>2]|0;
     __ZdlPv($36);
     $$0 = $32;$$03 = $31;
     break;
    }
    $15 = ((($4)) + 11|0);
    $16 = HEAP8[$15>>0]|0;
    $17 = ($16<<24>>24)<(0);
    if ($17) {
     $18 = HEAP32[$4>>2]|0;
     __ZdlPv($18);
    }
    $19 = ((($2)) + 11|0);
    $20 = HEAP8[$19>>0]|0;
    $21 = ($20<<24>>24)<(0);
    if ($21) {
     $22 = HEAP32[$2>>2]|0;
     __ZdlPv($22);
    }
    $23 = ((($3)) + 11|0);
    $24 = HEAP8[$23>>0]|0;
    $25 = ($24<<24>>24)<(0);
    if (!($25)) {
     STACKTOP = sp;return;
    }
    $26 = HEAP32[$3>>2]|0;
    __ZdlPv($26);
    STACKTOP = sp;return;
   }
  } while(0);
  $37 = ((($2)) + 11|0);
  $38 = HEAP8[$37>>0]|0;
  $39 = ($38<<24>>24)<(0);
  if ($39) {
   $40 = HEAP32[$2>>2]|0;
   __ZdlPv($40);
   $$1 = $$0;$$14 = $$03;
  } else {
   $$1 = $$0;$$14 = $$03;
  }
 }
 $41 = ((($3)) + 11|0);
 $42 = HEAP8[$41>>0]|0;
 $43 = ($42<<24>>24)<(0);
 if (!($43)) {
  ___resumeException($$14|0);
  // unreachable;
 }
 $44 = HEAP32[$3>>2]|0;
 __ZdlPv($44);
 ___resumeException($$14|0);
 // unreachable;
}
function __ZN5osgGA19StandardManipulator6handleERKNS_15GUIEventAdapterERNS_16GUIActionAdapterE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = HEAP32[$1>>2]|0;
 $4 = ((($3)) + 148|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_ii[$5 & 8191]($1)|0);
 switch ($6|0) {
 case 128:  {
  $7 = HEAP32[$0>>2]|0;
  $8 = ((($7)) + 184|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (FUNCTION_TABLE_iiii[$9 & 8191]($0,$1,$2)|0);
  $$0 = $10;
  return ($$0|0);
  break;
 }
 case 256:  {
  $11 = HEAP32[$0>>2]|0;
  $12 = ((($11)) + 188|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (FUNCTION_TABLE_iiii[$13 & 8191]($0,$1,$2)|0);
  $$0 = $14;
  return ($$0|0);
  break;
 }
 default: {
  $15 = ((($1)) + 32|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = ($16<<24>>24)==(0);
  if (!($17)) {
   $$0 = 0;
   return ($$0|0);
  }
  $18 = HEAP32[$1>>2]|0;
  $19 = ((($18)) + 148|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = (FUNCTION_TABLE_ii[$20 & 8191]($1)|0);
  switch ($21|0) {
  case 16:  {
   $22 = HEAP32[$0>>2]|0;
   $23 = ((($22)) + 192|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = (FUNCTION_TABLE_iiii[$24 & 8191]($0,$1,$2)|0);
   $$0 = $25;
   return ($$0|0);
   break;
  }
  case 8:  {
   $26 = HEAP32[$0>>2]|0;
   $27 = ((($26)) + 196|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = (FUNCTION_TABLE_iiii[$28 & 8191]($0,$1,$2)|0);
   $$0 = $29;
   return ($$0|0);
   break;
  }
  case 1:  {
   $30 = HEAP32[$0>>2]|0;
   $31 = ((($30)) + 200|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = (FUNCTION_TABLE_iiii[$32 & 8191]($0,$1,$2)|0);
   $$0 = $33;
   return ($$0|0);
   break;
  }
  case 2:  {
   $34 = HEAP32[$0>>2]|0;
   $35 = ((($34)) + 204|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (FUNCTION_TABLE_iiii[$36 & 8191]($0,$1,$2)|0);
   $$0 = $37;
   return ($$0|0);
   break;
  }
  case 32:  {
   $38 = HEAP32[$0>>2]|0;
   $39 = ((($38)) + 208|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = (FUNCTION_TABLE_iiii[$40 & 8191]($0,$1,$2)|0);
   $$0 = $41;
   return ($$0|0);
   break;
  }
  case 64:  {
   $42 = HEAP32[$0>>2]|0;
   $43 = ((($42)) + 212|0);
   $44 = HEAP32[$43>>2]|0;
   $45 = (FUNCTION_TABLE_iiii[$44 & 8191]($0,$1,$2)|0);
   $$0 = $45;
   return ($$0|0);
   break;
  }
  case 512:  {
   $46 = ((($0)) + 152|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = $47 & 4;
   $49 = ($48|0)==(0);
   if ($49) {
    $$0 = 0;
    return ($$0|0);
   }
   $50 = HEAP32[$0>>2]|0;
   $51 = ((($50)) + 216|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = (FUNCTION_TABLE_iiii[$52 & 8191]($0,$1,$2)|0);
   $$0 = $53;
   return ($$0|0);
   break;
  }
  default: {
   $$0 = 0;
   return ($$0|0);
  }
  }
 }
 }
 return (0)|0;
}
function __ZN5osgGA19StandardManipulator7setNodeEPN3osg4NodeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$pr = 0, $$sink = 0.0, $10 = 0, $100 = 0.0, $101 = 0, $102 = 0.0, $103 = 0.0, $104 = 0.0, $105 = 0.0, $106 = 0.0, $107 = 0.0, $108 = 0.0, $109 = 0.0, $11 = 0, $110 = 0.0, $111 = 0.0, $112 = 0.0, $113 = 0.0, $114 = 0, $115 = 0.0;
 var $116 = 0, $117 = 0.0, $118 = 0.0, $119 = 0.0, $12 = 0, $120 = 0.0, $121 = 0.0, $122 = 0.0, $123 = 0.0, $124 = 0.0, $125 = 0.0, $126 = 0.0, $127 = 0.0, $128 = 0.0, $129 = 0.0, $13 = 0, $130 = 0.0, $131 = 0.0, $132 = 0.0, $133 = 0.0;
 var $134 = 0.0, $135 = 0.0, $136 = 0.0, $137 = 0.0, $138 = 0.0, $139 = 0.0, $14 = 0, $140 = 0, $141 = 0.0, $142 = 0.0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0.0, $29 = 0, $3 = 0, $30 = 0, $31 = 0.0;
 var $32 = 0, $33 = 0.0, $34 = 0.0, $35 = 0.0, $36 = 0, $37 = 0.0, $38 = 0, $39 = 0.0, $4 = 0, $40 = 0.0, $41 = 0, $42 = 0.0, $43 = 0, $44 = 0.0, $45 = 0.0, $46 = 0.0, $47 = 0.0, $48 = 0.0, $49 = 0.0, $5 = 0;
 var $50 = 0.0, $51 = 0.0, $52 = 0.0, $53 = 0.0, $54 = 0.0, $55 = 0.0, $56 = 0, $57 = 0.0, $58 = 0, $59 = 0.0, $6 = 0, $60 = 0.0, $61 = 0.0, $62 = 0.0, $63 = 0.0, $64 = 0.0, $65 = 0.0, $66 = 0.0, $67 = 0.0, $68 = 0.0;
 var $69 = 0.0, $7 = 0, $70 = 0.0, $71 = 0.0, $72 = 0.0, $73 = 0.0, $74 = 0.0, $75 = 0.0, $76 = 0.0, $77 = 0.0, $78 = 0.0, $79 = 0.0, $8 = 0, $80 = 0.0, $81 = 0.0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0.0;
 var $87 = 0, $88 = 0, $89 = 0.0, $9 = 0, $90 = 0, $91 = 0.0, $92 = 0.0, $93 = 0.0, $94 = 0, $95 = 0.0, $96 = 0, $97 = 0.0, $98 = 0.0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $2 = sp + 16|0;
 $3 = sp;
 $4 = ((($0)) + 128|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==($1|0);
 if ($6) {
  $14 = $1;
 } else {
  HEAP32[$4>>2] = $1;
  $7 = ($1|0)==(0|0);
  if (!($7)) {
   $8 = ((($1)) + 8|0);
   $9 = HEAP32[$8>>2]|0;HEAP32[$8>>2] = (($9+1)|0);
  }
  $10 = ($5|0)==(0|0);
  if (!($10)) {
   $11 = ((($5)) + 8|0);
   $12 = HEAP32[$11>>2]|0;HEAP32[$11>>2] = (($12-1)|0);
   $13 = ($12|0)==(1);
   if ($13) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($5,1,1);
   }
  }
  $$pr = HEAP32[$4>>2]|0;
  $14 = $$pr;
 }
 $15 = ($14|0)==(0|0);
 if ($15) {
  $$sink = 0.0;
 } else {
  $16 = ((($14)) + 68|0);
  $17 = HEAP8[$16>>0]|0;
  $18 = ($17<<24>>24)==(0);
  if ($18) {
   $19 = ((($14)) + 32|0);
   $20 = ((($14)) + 52|0);
   ;HEAP32[$20>>2]=HEAP32[$19>>2]|0;HEAP32[$20+4>>2]=HEAP32[$19+4>>2]|0;HEAP32[$20+8>>2]=HEAP32[$19+8>>2]|0;HEAP32[$20+12>>2]=HEAP32[$19+12>>2]|0;
   $21 = ((($14)) + 48|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = ($22|0)==(0|0);
   if ($23) {
    $82 = HEAP32[$14>>2]|0;
    $83 = ((($82)) + 200|0);
    $84 = HEAP32[$83>>2]|0;
    FUNCTION_TABLE_vii[$84 & 8191]($3,$14);
    $85 = ((($3)) + 12|0);
    $86 = +HEAPF32[$85>>2];
    $87 = !($86 >= 0.0);
    do {
     if (!($87)) {
      $88 = ((($14)) + 64|0);
      $89 = +HEAPF32[$88>>2];
      $90 = !($89 >= 0.0);
      if ($90) {
       ;HEAP32[$20>>2]=HEAP32[$3>>2]|0;HEAP32[$20+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$20+8>>2]=HEAP32[$3+8>>2]|0;
       HEAPF32[$88>>2] = $86;
       break;
      }
      $91 = +HEAPF32[$20>>2];
      $92 = +HEAPF32[$3>>2];
      $93 = $91 - $92;
      $94 = ((($14)) + 56|0);
      $95 = +HEAPF32[$94>>2];
      $96 = ((($3)) + 4|0);
      $97 = +HEAPF32[$96>>2];
      $98 = $95 - $97;
      $99 = ((($14)) + 60|0);
      $100 = +HEAPF32[$99>>2];
      $101 = ((($3)) + 8|0);
      $102 = +HEAPF32[$101>>2];
      $103 = $100 - $102;
      $104 = $93 * $93;
      $105 = $98 * $98;
      $106 = $104 + $105;
      $107 = $103 * $103;
      $108 = $106 + $107;
      $109 = (+Math_sqrt((+$108)));
      $110 = $109;
      $111 = $86;
      $112 = $111 + $110;
      $113 = $89;
      $114 = !($112 <= $113);
      if ($114) {
       $115 = $113 + $110;
       $116 = !($115 <= $111);
       if ($116) {
        $117 = $111 + $115;
        $118 = $117 * 0.5;
        $119 = $118 - $113;
        $120 = $119 / $110;
        $121 = $92 - $91;
        $122 = $121;
        $123 = $122 * $120;
        $124 = $91;
        $125 = $124 + $123;
        $126 = $125;
        HEAPF32[$20>>2] = $126;
        $127 = $97 - $95;
        $128 = $127;
        $129 = $120 * $128;
        $130 = $95;
        $131 = $130 + $129;
        $132 = $131;
        HEAPF32[$94>>2] = $132;
        $133 = $102 - $100;
        $134 = $133;
        $135 = $120 * $134;
        $136 = $100;
        $137 = $136 + $135;
        $138 = $137;
        HEAPF32[$99>>2] = $138;
        $139 = $118;
        HEAPF32[$88>>2] = $139;
        break;
       } else {
        ;HEAP32[$20>>2]=HEAP32[$3>>2]|0;HEAP32[$20+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$20+8>>2]=HEAP32[$3+8>>2]|0;
        HEAPF32[$88>>2] = $86;
        break;
       }
      }
     }
    } while(0);
   } else {
    $24 = HEAP32[$22>>2]|0;
    $25 = ((($24)) + 140|0);
    $26 = HEAP32[$25>>2]|0;
    FUNCTION_TABLE_viii[$26 & 8191]($2,$22,$14);
    $27 = ((($2)) + 12|0);
    $28 = +HEAPF32[$27>>2];
    $29 = !($28 >= 0.0);
    do {
     if (!($29)) {
      $30 = ((($14)) + 64|0);
      $31 = +HEAPF32[$30>>2];
      $32 = !($31 >= 0.0);
      if ($32) {
       ;HEAP32[$20>>2]=HEAP32[$2>>2]|0;HEAP32[$20+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$20+8>>2]=HEAP32[$2+8>>2]|0;
       HEAPF32[$30>>2] = $28;
       break;
      }
      $33 = +HEAPF32[$20>>2];
      $34 = +HEAPF32[$2>>2];
      $35 = $33 - $34;
      $36 = ((($14)) + 56|0);
      $37 = +HEAPF32[$36>>2];
      $38 = ((($2)) + 4|0);
      $39 = +HEAPF32[$38>>2];
      $40 = $37 - $39;
      $41 = ((($14)) + 60|0);
      $42 = +HEAPF32[$41>>2];
      $43 = ((($2)) + 8|0);
      $44 = +HEAPF32[$43>>2];
      $45 = $42 - $44;
      $46 = $35 * $35;
      $47 = $40 * $40;
      $48 = $46 + $47;
      $49 = $45 * $45;
      $50 = $48 + $49;
      $51 = (+Math_sqrt((+$50)));
      $52 = $51;
      $53 = $28;
      $54 = $53 + $52;
      $55 = $31;
      $56 = !($54 <= $55);
      if ($56) {
       $57 = $55 + $52;
       $58 = !($57 <= $53);
       if ($58) {
        $59 = $53 + $57;
        $60 = $59 * 0.5;
        $61 = $60 - $55;
        $62 = $61 / $52;
        $63 = $34 - $33;
        $64 = $63;
        $65 = $64 * $62;
        $66 = $33;
        $67 = $66 + $65;
        $68 = $67;
        HEAPF32[$20>>2] = $68;
        $69 = $39 - $37;
        $70 = $69;
        $71 = $62 * $70;
        $72 = $37;
        $73 = $72 + $71;
        $74 = $73;
        HEAPF32[$36>>2] = $74;
        $75 = $44 - $42;
        $76 = $75;
        $77 = $62 * $76;
        $78 = $42;
        $79 = $78 + $77;
        $80 = $79;
        HEAPF32[$41>>2] = $80;
        $81 = $60;
        HEAPF32[$30>>2] = $81;
        break;
       } else {
        ;HEAP32[$20>>2]=HEAP32[$2>>2]|0;HEAP32[$20+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$20+8>>2]=HEAP32[$2+8>>2]|0;
        HEAPF32[$30>>2] = $28;
        break;
       }
      }
     }
    } while(0);
   }
   HEAP8[$16>>0] = 1;
  }
  $140 = ((($14)) + 64|0);
  $141 = +HEAPF32[$140>>2];
  $142 = $141;
  $$sink = $142;
 }
 $143 = ((($0)) + 136|0);
 HEAPF64[$143>>3] = $$sink;
 $144 = ((($0)) + 12|0);
 $145 = HEAP8[$144>>0]|0;
 $146 = ($145<<24>>24)==(0);
 if ($146) {
  STACKTOP = sp;return;
 }
 $147 = HEAP32[$0>>2]|0;
 $148 = ((($147)) + 136|0);
 $149 = HEAP32[$148>>2]|0;
 $150 = ((($0)) + 152|0);
 $151 = HEAP32[$150>>2]|0;
 $152 = $151 & 2;
 $153 = ($152|0)!=(0);
 FUNCTION_TABLE_viii[$149 & 8191]($0,0,$153);
 STACKTOP = sp;return;
}
function __ZNK5osgGA19StandardManipulator7getNodeEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 128|0);
 $2 = HEAP32[$1>>2]|0;
 return ($2|0);
}
function __ZN5osgGA19StandardManipulator7getNodeEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 128|0);
 $2 = HEAP32[$1>>2]|0;
 return ($2|0);
}
function __ZN5osgGA19StandardManipulator15finishAnimationEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0.0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 92|0);
 HEAP8[$1>>0] = 0;
 $2 = ((($0)) + 148|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  return;
 }
 $5 = ((($3)) + 24|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = ($6<<24>>24)==(0);
 if ($7) {
  return;
 }
 $8 = HEAP32[$0>>2]|0;
 $9 = ((($8)) + 248|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ((($3)) + 40|0);
 $12 = +HEAPF64[$11>>3];
 FUNCTION_TABLE_vidd[$10 & 8191]($0,1.0,$12);
 return;
}
function __ZN5osgGA19StandardManipulator4homeERKNS_15GUIEventAdapterERNS_16GUIActionAdapterE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 12|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)==(0);
 if (!($5)) {
  $6 = HEAP32[$2>>2]|0;
  $7 = ((($6)) + 8|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (FUNCTION_TABLE_ii[$8 & 8191]($2)|0);
  $10 = ($9|0)==(0|0);
  if ($10) {
   $24 = 0;
  } else {
   $11 = HEAP32[$2>>2]|0;
   $12 = ((($11)) + 8|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (FUNCTION_TABLE_ii[$13 & 8191]($2)|0);
   $15 = ((($14)) + 16|0);
   $16 = HEAP32[$15>>2]|0;
   $24 = $16;
  }
  $17 = HEAP32[$0>>2]|0;
  $18 = ((($17)) + 136|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = ((($0)) + 152|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = $21 & 2;
  $23 = ($22|0)!=(0);
  FUNCTION_TABLE_viii[$19 & 8191]($0,$24,$23);
 }
 $25 = ((($0)) + 92|0);
 HEAP8[$25>>0] = 0;
 $26 = HEAP32[$0>>2]|0;
 $27 = ((($26)) + 160|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = ((($0)) + 16|0);
 $30 = ((($0)) + 40|0);
 $31 = ((($0)) + 64|0);
 FUNCTION_TABLE_viiii[$28 & 8191]($0,$29,$30,$31);
 $32 = HEAP32[$2>>2]|0;
 $33 = ((($32)) + 12|0);
 $34 = HEAP32[$33>>2]|0;
 FUNCTION_TABLE_vi[$34 & 8191]($2);
 $35 = HEAP32[$2>>2]|0;
 $36 = ((($35)) + 16|0);
 $37 = HEAP32[$36>>2]|0;
 FUNCTION_TABLE_vii[$37 & 8191]($2,0);
 $38 = ((($0)) + 104|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = ($39|0)==(0|0);
 if (!($40)) {
  HEAP32[$38>>2] = 0;
  $41 = ((($39)) + 8|0);
  $42 = HEAP32[$41>>2]|0;HEAP32[$41>>2] = (($42-1)|0);
  $43 = ($42|0)==(1);
  if ($43) {
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($39,1,1);
  }
 }
 $44 = ((($0)) + 108|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = ($45|0)==(0|0);
 if ($46) {
  return;
 }
 HEAP32[$44>>2] = 0;
 $47 = ((($45)) + 8|0);
 $48 = HEAP32[$47>>2]|0;HEAP32[$47>>2] = (($48-1)|0);
 $49 = ($48|0)==(1);
 if (!($49)) {
  return;
 }
 __ZNK3osg10Referenced24signalObserversAndDeleteEbb($45,1,1);
 return;
}
function __ZN5osgGA19StandardManipulator4homeEd($0,$1) {
 $0 = $0|0;
 $1 = +$1;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 12|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if (!($4)) {
  $5 = HEAP32[$0>>2]|0;
  $6 = ((($5)) + 136|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ((($0)) + 152|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = $9 & 2;
  $11 = ($10|0)!=(0);
  FUNCTION_TABLE_viii[$7 & 8191]($0,0,$11);
 }
 $12 = ((($0)) + 92|0);
 HEAP8[$12>>0] = 0;
 $13 = HEAP32[$0>>2]|0;
 $14 = ((($13)) + 160|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ((($0)) + 16|0);
 $17 = ((($0)) + 40|0);
 $18 = ((($0)) + 64|0);
 FUNCTION_TABLE_viiii[$15 & 8191]($0,$16,$17,$18);
 $19 = ((($0)) + 104|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)==(0|0);
 if (!($21)) {
  HEAP32[$19>>2] = 0;
  $22 = ((($20)) + 8|0);
  $23 = HEAP32[$22>>2]|0;HEAP32[$22>>2] = (($23-1)|0);
  $24 = ($23|0)==(1);
  if ($24) {
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($20,1,1);
  }
 }
 $25 = ((($0)) + 108|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($26|0)==(0|0);
 if ($27) {
  return;
 }
 HEAP32[$25>>2] = 0;
 $28 = ((($26)) + 8|0);
 $29 = HEAP32[$28>>2]|0;HEAP32[$28>>2] = (($29-1)|0);
 $30 = ($29|0)==(1);
 if (!($30)) {
  return;
 }
 __ZNK3osg10Referenced24signalObserversAndDeleteEbb($26,1,1);
 return;
}
function __ZN5osgGA19StandardManipulator4initERKNS_15GUIEventAdapterERNS_16GUIActionAdapterE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 104|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if (!($5)) {
  HEAP32[$3>>2] = 0;
  $6 = ((($4)) + 8|0);
  $7 = HEAP32[$6>>2]|0;HEAP32[$6>>2] = (($7-1)|0);
  $8 = ($7|0)==(1);
  if ($8) {
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($4,1,1);
  }
 }
 $9 = ((($0)) + 108|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if (!($11)) {
  HEAP32[$9>>2] = 0;
  $12 = ((($10)) + 8|0);
  $13 = HEAP32[$12>>2]|0;HEAP32[$12>>2] = (($13-1)|0);
  $14 = ($13|0)==(1);
  if ($14) {
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($10,1,1);
  }
 }
 $15 = ((($0)) + 92|0);
 HEAP8[$15>>0] = 0;
 $16 = HEAP32[$2>>2]|0;
 $17 = ((($16)) + 16|0);
 $18 = HEAP32[$17>>2]|0;
 FUNCTION_TABLE_vii[$18 & 8191]($2,0);
 return;
}
function __ZN5osgGA19StandardManipulator20setVerticalAxisFixedEb($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = $1&1;
 $3 = ((($0)) + 144|0);
 HEAP8[$3>>0] = $2;
 return;
}
function __ZN5osgGA19StandardManipulator13setAllowThrowEb($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = $1&1;
 $3 = ((($0)) + 93|0);
 HEAP8[$3>>0] = $2;
 return;
}
function __ZN5osgGA19StandardManipulator16setAnimationTimeEd($0,$1) {
 $0 = $0|0;
 $1 = +$1;
 var $$pre = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $2 = !($1 <= 0.0);
 if ($2) {
  $12 = ((($0)) + 148|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($13|0)==(0|0);
  if ($14) {
   $15 = HEAP32[$0>>2]|0;
   $16 = ((($15)) + 268|0);
   $17 = HEAP32[$16>>2]|0;
   FUNCTION_TABLE_vi[$17 & 8191]($0);
   $$pre = HEAP32[$12>>2]|0;
   $19 = $$pre;
  } else {
   $19 = $13;
  }
  $18 = ((($19)) + 16|0);
  HEAPF64[$18>>3] = $1;
  return;
 }
 $3 = HEAP32[$0>>2]|0;
 $4 = ((($3)) + 140|0);
 $5 = HEAP32[$4>>2]|0;
 FUNCTION_TABLE_vi[$5 & 8191]($0);
 $6 = ((($0)) + 148|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if ($8) {
  return;
 }
 HEAP32[$6>>2] = 0;
 $9 = ((($7)) + 8|0);
 $10 = HEAP32[$9>>2]|0;HEAP32[$9>>2] = (($10-1)|0);
 $11 = ($10|0)==(1);
 if (!($11)) {
  return;
 }
 __ZNK3osg10Referenced24signalObserversAndDeleteEbb($7,1,1);
 return;
}
function __ZN5osgGA19StandardManipulator11handleFrameERKNS_15GUIEventAdapterERNS_16GUIActionAdapterE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0.0;
 var $5 = 0, $6 = 0.0, $7 = 0.0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($1)) + 40|0);
 $4 = +HEAPF64[$3>>3];
 $5 = ((($0)) + 120|0);
 $6 = +HEAPF64[$5>>3];
 $7 = $4 - $6;
 $8 = ((($0)) + 112|0);
 HEAPF64[$8>>3] = $7;
 HEAPF64[$5>>3] = $4;
 $9 = ((($0)) + 92|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = ($10<<24>>24)==(0);
 if (!($11)) {
  $12 = HEAP32[$0>>2]|0;
  $13 = ((($12)) + 224|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (FUNCTION_TABLE_ii[$14 & 8191]($0)|0);
  if ($15) {
   $16 = HEAP32[$2>>2]|0;
   $17 = ((($16)) + 12|0);
   $18 = HEAP32[$17>>2]|0;
   FUNCTION_TABLE_vi[$18 & 8191]($2);
  }
 }
 $19 = ((($0)) + 148|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)==(0|0);
 if ($21) {
  return 0;
 }
 $22 = ((($20)) + 24|0);
 $23 = HEAP8[$22>>0]|0;
 $24 = ($23<<24>>24)==(0);
 if ($24) {
  return 0;
 }
 $25 = HEAP32[$0>>2]|0;
 $26 = ((($25)) + 244|0);
 $27 = HEAP32[$26>>2]|0;
 (FUNCTION_TABLE_iiii[$27 & 8191]($0,$1,$2)|0);
 return 0;
}
function __ZN5osgGA19StandardManipulator12handleResizeERKNS_15GUIEventAdapterERNS_16GUIActionAdapterE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = HEAP32[$0>>2]|0;
 $4 = ((($3)) + 152|0);
 $5 = HEAP32[$4>>2]|0;
 FUNCTION_TABLE_viii[$5 & 8191]($0,$1,$2);
 $6 = HEAP32[$2>>2]|0;
 $7 = ((($6)) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 FUNCTION_TABLE_vi[$8 & 8191]($2);
 return 1;
}
function __ZN5osgGA19StandardManipulator15handleMouseMoveERKNS_15GUIEventAdapterERNS_16GUIActionAdapterE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function __ZN5osgGA19StandardManipulator15handleMouseDragERKNS_15GUIEventAdapterERNS_16GUIActionAdapterE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$pr$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 104|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 108|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4|0)==($6|0);
 if ($7) {
  $15 = $4;
 } else {
  HEAP32[$3>>2] = $6;
  $8 = ($6|0)==(0|0);
  if (!($8)) {
   $9 = ((($6)) + 8|0);
   $10 = HEAP32[$9>>2]|0;HEAP32[$9>>2] = (($10+1)|0);
  }
  $11 = ($4|0)==(0|0);
  if (!($11)) {
   $12 = ((($4)) + 8|0);
   $13 = HEAP32[$12>>2]|0;HEAP32[$12>>2] = (($13-1)|0);
   $14 = ($13|0)==(1);
   if ($14) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($4,1,1);
   }
  }
  $$pr$i = HEAP32[$5>>2]|0;
  $15 = $$pr$i;
 }
 $16 = ($15|0)==($1|0);
 if (!($16)) {
  HEAP32[$5>>2] = $1;
  $17 = ((($1)) + 8|0);
  $18 = HEAP32[$17>>2]|0;HEAP32[$17>>2] = (($18+1)|0);
  $19 = ($15|0)==(0|0);
  if (!($19)) {
   $20 = ((($15)) + 8|0);
   $21 = HEAP32[$20>>2]|0;HEAP32[$20>>2] = (($21-1)|0);
   $22 = ($21|0)==(1);
   if ($22) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($15,1,1);
   }
  }
 }
 $23 = HEAP32[$0>>2]|0;
 $24 = ((($23)) + 224|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (FUNCTION_TABLE_ii[$25 & 8191]($0)|0);
 if (!($26)) {
  $30 = HEAP32[$2>>2]|0;
  $31 = ((($30)) + 16|0);
  $32 = HEAP32[$31>>2]|0;
  FUNCTION_TABLE_vii[$32 & 8191]($2,0);
  $33 = ((($0)) + 92|0);
  HEAP8[$33>>0] = 0;
  return 1;
 }
 $27 = HEAP32[$2>>2]|0;
 $28 = ((($27)) + 12|0);
 $29 = HEAP32[$28>>2]|0;
 FUNCTION_TABLE_vi[$29 & 8191]($2);
 $30 = HEAP32[$2>>2]|0;
 $31 = ((($30)) + 16|0);
 $32 = HEAP32[$31>>2]|0;
 FUNCTION_TABLE_vii[$32 & 8191]($2,0);
 $33 = ((($0)) + 92|0);
 HEAP8[$33>>0] = 0;
 return 1;
}
function __ZN5osgGA19StandardManipulator15handleMousePushERKNS_15GUIEventAdapterERNS_16GUIActionAdapterE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$pr = 0, $$pr$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 104|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if (!($5)) {
  HEAP32[$3>>2] = 0;
  $6 = ((($4)) + 8|0);
  $7 = HEAP32[$6>>2]|0;HEAP32[$6>>2] = (($7-1)|0);
  $8 = ($7|0)==(1);
  if ($8) {
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($4,1,1);
  }
 }
 $9 = ((($0)) + 108|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  $17 = 0;
 } else {
  HEAP32[$9>>2] = 0;
  $12 = ((($10)) + 8|0);
  $13 = HEAP32[$12>>2]|0;HEAP32[$12>>2] = (($13-1)|0);
  $14 = ($13|0)==(1);
  if ($14) {
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($10,1,1);
  }
  $$pr = HEAP32[$9>>2]|0;
  $17 = $$pr;
 }
 $15 = HEAP32[$3>>2]|0;
 $16 = ($15|0)==($17|0);
 if ($16) {
  $25 = $17;
 } else {
  HEAP32[$3>>2] = $17;
  $18 = ($17|0)==(0|0);
  if (!($18)) {
   $19 = ((($17)) + 8|0);
   $20 = HEAP32[$19>>2]|0;HEAP32[$19>>2] = (($20+1)|0);
  }
  $21 = ($15|0)==(0|0);
  if (!($21)) {
   $22 = ((($15)) + 8|0);
   $23 = HEAP32[$22>>2]|0;HEAP32[$22>>2] = (($23-1)|0);
   $24 = ($23|0)==(1);
   if ($24) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($15,1,1);
   }
  }
  $$pr$i = HEAP32[$9>>2]|0;
  $25 = $$pr$i;
 }
 $26 = ($25|0)==($1|0);
 if (!($26)) {
  HEAP32[$9>>2] = $1;
  $27 = ((($1)) + 8|0);
  $28 = HEAP32[$27>>2]|0;HEAP32[$27>>2] = (($28+1)|0);
  $29 = ($25|0)==(0|0);
  if (!($29)) {
   $30 = ((($25)) + 8|0);
   $31 = HEAP32[$30>>2]|0;HEAP32[$30>>2] = (($31-1)|0);
   $32 = ($31|0)==(1);
   if ($32) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($25,1,1);
   }
  }
 }
 $33 = HEAP32[$0>>2]|0;
 $34 = ((($33)) + 224|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (FUNCTION_TABLE_ii[$35 & 8191]($0)|0);
 if (!($36)) {
  $40 = HEAP32[$2>>2]|0;
  $41 = ((($40)) + 16|0);
  $42 = HEAP32[$41>>2]|0;
  FUNCTION_TABLE_vii[$42 & 8191]($2,0);
  $43 = ((($0)) + 92|0);
  HEAP8[$43>>0] = 0;
  return 1;
 }
 $37 = HEAP32[$2>>2]|0;
 $38 = ((($37)) + 12|0);
 $39 = HEAP32[$38>>2]|0;
 FUNCTION_TABLE_vi[$39 & 8191]($2);
 $40 = HEAP32[$2>>2]|0;
 $41 = ((($40)) + 16|0);
 $42 = HEAP32[$41>>2]|0;
 FUNCTION_TABLE_vii[$42 & 8191]($2,0);
 $43 = ((($0)) + 92|0);
 HEAP8[$43>>0] = 0;
 return 1;
}
function __ZN5osgGA19StandardManipulator18handleMouseReleaseERKNS_15GUIEventAdapterERNS_16GUIActionAdapterE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$pr = 0, $$pr$i = 0, $10 = 0.0, $11 = 0, $12 = 0.0, $13 = 0.0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $9 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($1)) + 112|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 if ($5) {
  $6 = ((($0)) + 108|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)==(0|0);
  if ($8) {
   label = 4;
  } else {
   $9 = ((($1)) + 40|0);
   $10 = +HEAPF64[$9>>3];
   $11 = ((($7)) + 40|0);
   $12 = +HEAPF64[$11>>3];
   $13 = $10 - $12;
   $phitmp = $13 > 0.02;
   if ($phitmp) {
    label = 4;
   }
  }
  if ((label|0) == 4) {
   $14 = ((($0)) + 104|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = ($15|0)==(0|0);
   if (!($16)) {
    HEAP32[$14>>2] = 0;
    $17 = ((($15)) + 8|0);
    $18 = HEAP32[$17>>2]|0;HEAP32[$17>>2] = (($18-1)|0);
    $19 = ($18|0)==(1);
    if ($19) {
     __ZNK3osg10Referenced24signalObserversAndDeleteEbb($15,1,1);
    }
   }
   $20 = HEAP32[$6>>2]|0;
   $21 = ($20|0)==(0|0);
   if (!($21)) {
    HEAP32[$6>>2] = 0;
    $22 = ((($20)) + 8|0);
    $23 = HEAP32[$22>>2]|0;HEAP32[$22>>2] = (($23-1)|0);
    $24 = ($23|0)==(1);
    if ($24) {
     __ZNK3osg10Referenced24signalObserversAndDeleteEbb($20,1,1);
    }
   }
  }
  $25 = HEAP32[$0>>2]|0;
  $26 = ((($25)) + 252|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = (FUNCTION_TABLE_ii[$27 & 8191]($0)|0);
  if ($28) {
   $29 = HEAP32[$0>>2]|0;
   $30 = ((($29)) + 224|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = (FUNCTION_TABLE_ii[$31 & 8191]($0)|0);
   if (!($32)) {
    return 1;
   }
   $33 = ((($0)) + 93|0);
   $34 = HEAP8[$33>>0]|0;
   $35 = ($34<<24>>24)==(0);
   if ($35) {
    return 1;
   }
   $36 = HEAP32[$2>>2]|0;
   $37 = ((($36)) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vi[$38 & 8191]($2);
   $39 = HEAP32[$2>>2]|0;
   $40 = ((($39)) + 16|0);
   $41 = HEAP32[$40>>2]|0;
   FUNCTION_TABLE_vii[$41 & 8191]($2,1);
   $42 = ((($0)) + 92|0);
   HEAP8[$42>>0] = 1;
   return 1;
  }
 }
 $43 = ((($0)) + 104|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = ($44|0)==(0|0);
 if (!($45)) {
  HEAP32[$43>>2] = 0;
  $46 = ((($44)) + 8|0);
  $47 = HEAP32[$46>>2]|0;HEAP32[$46>>2] = (($47-1)|0);
  $48 = ($47|0)==(1);
  if ($48) {
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($44,1,1);
  }
 }
 $49 = ((($0)) + 108|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = ($50|0)==(0|0);
 if ($51) {
  $57 = 0;
 } else {
  HEAP32[$49>>2] = 0;
  $52 = ((($50)) + 8|0);
  $53 = HEAP32[$52>>2]|0;HEAP32[$52>>2] = (($53-1)|0);
  $54 = ($53|0)==(1);
  if ($54) {
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($50,1,1);
  }
  $$pr = HEAP32[$49>>2]|0;
  $57 = $$pr;
 }
 $55 = HEAP32[$43>>2]|0;
 $56 = ($55|0)==($57|0);
 if ($56) {
  $65 = $57;
 } else {
  HEAP32[$43>>2] = $57;
  $58 = ($57|0)==(0|0);
  if (!($58)) {
   $59 = ((($57)) + 8|0);
   $60 = HEAP32[$59>>2]|0;HEAP32[$59>>2] = (($60+1)|0);
  }
  $61 = ($55|0)==(0|0);
  if (!($61)) {
   $62 = ((($55)) + 8|0);
   $63 = HEAP32[$62>>2]|0;HEAP32[$62>>2] = (($63-1)|0);
   $64 = ($63|0)==(1);
   if ($64) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($55,1,1);
   }
  }
  $$pr$i = HEAP32[$49>>2]|0;
  $65 = $$pr$i;
 }
 $66 = ($65|0)==($1|0);
 if (!($66)) {
  HEAP32[$49>>2] = $1;
  $67 = ((($1)) + 8|0);
  $68 = HEAP32[$67>>2]|0;HEAP32[$67>>2] = (($68+1)|0);
  $69 = ($65|0)==(0|0);
  if (!($69)) {
   $70 = ((($65)) + 8|0);
   $71 = HEAP32[$70>>2]|0;HEAP32[$70>>2] = (($71-1)|0);
   $72 = ($71|0)==(1);
   if ($72) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($65,1,1);
   }
  }
 }
 $73 = HEAP32[$0>>2]|0;
 $74 = ((($73)) + 224|0);
 $75 = HEAP32[$74>>2]|0;
 $76 = (FUNCTION_TABLE_ii[$75 & 8191]($0)|0);
 if ($76) {
  $77 = HEAP32[$2>>2]|0;
  $78 = ((($77)) + 12|0);
  $79 = HEAP32[$78>>2]|0;
  FUNCTION_TABLE_vi[$79 & 8191]($2);
 }
 $80 = HEAP32[$2>>2]|0;
 $81 = ((($80)) + 16|0);
 $82 = HEAP32[$81>>2]|0;
 FUNCTION_TABLE_vii[$82 & 8191]($2,0);
 $83 = ((($0)) + 92|0);
 HEAP8[$83>>0] = 0;
 return 1;
}
function __ZN5osgGA19StandardManipulator13handleKeyDownERKNS_15GUIEventAdapterERNS_16GUIActionAdapterE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = HEAP32[$1>>2]|0;
 $4 = ((($3)) + 152|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_ii[$5 & 8191]($1)|0);
 $7 = ($6|0)==(32);
 if (!($7)) {
  $$0 = 0;
  return ($$0|0);
 }
 $8 = ((($0)) + 104|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if (!($10)) {
  HEAP32[$8>>2] = 0;
  $11 = ((($9)) + 8|0);
  $12 = HEAP32[$11>>2]|0;HEAP32[$11>>2] = (($12-1)|0);
  $13 = ($12|0)==(1);
  if ($13) {
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($9,1,1);
  }
 }
 $14 = ((($0)) + 108|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0|0);
 if (!($16)) {
  HEAP32[$14>>2] = 0;
  $17 = ((($15)) + 8|0);
  $18 = HEAP32[$17>>2]|0;HEAP32[$17>>2] = (($18-1)|0);
  $19 = ($18|0)==(1);
  if ($19) {
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($15,1,1);
  }
 }
 $20 = ((($0)) + 92|0);
 HEAP8[$20>>0] = 0;
 $21 = HEAP32[$0>>2]|0;
 $22 = ((($21)) + 144|0);
 $23 = HEAP32[$22>>2]|0;
 FUNCTION_TABLE_viii[$23 & 8191]($0,$1,$2);
 $$0 = 1;
 return ($$0|0);
}
function __ZN5osgGA19StandardManipulator11handleKeyUpERKNS_15GUIEventAdapterERNS_16GUIActionAdapterE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function __ZN5osgGA19StandardManipulator16handleMouseWheelERKNS_15GUIEventAdapterERNS_16GUIActionAdapterE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function __ZN5osgGA19StandardManipulator24handleMouseDeltaMovementERKNS_15GUIEventAdapterERNS_16GUIActionAdapterE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$pr$i = 0, $10 = 0, $11 = 0.0, $12 = 0.0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0.0, $40 = 0, $41 = 0, $5 = 0, $6 = 0.0, $7 = 0.0, $8 = 0;
 var $9 = 0.0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($1)) + 104|0);
 $4 = +HEAPF32[$3>>2];
 $5 = ((($0)) + 96|0);
 $6 = +HEAPF32[$5>>2];
 $7 = $4 - $6;
 $8 = ((($1)) + 108|0);
 $9 = +HEAPF32[$8>>2];
 $10 = ((($0)) + 100|0);
 $11 = +HEAPF32[$10>>2];
 $12 = $9 - $11;
 $13 = $7 == 0.0;
 $14 = $12 == 0.0;
 $or$cond = $13 & $14;
 if ($or$cond) {
  $$0 = 0;
  return ($$0|0);
 }
 $15 = ((($0)) + 104|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ((($0)) + 108|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ($16|0)==($18|0);
 if ($19) {
  $27 = $16;
 } else {
  HEAP32[$15>>2] = $18;
  $20 = ($18|0)==(0|0);
  if (!($20)) {
   $21 = ((($18)) + 8|0);
   $22 = HEAP32[$21>>2]|0;HEAP32[$21>>2] = (($22+1)|0);
  }
  $23 = ($16|0)==(0|0);
  if (!($23)) {
   $24 = ((($16)) + 8|0);
   $25 = HEAP32[$24>>2]|0;HEAP32[$24>>2] = (($25-1)|0);
   $26 = ($25|0)==(1);
   if ($26) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($16,1,1);
   }
  }
  $$pr$i = HEAP32[$17>>2]|0;
  $27 = $$pr$i;
 }
 $28 = ($27|0)==($1|0);
 if (!($28)) {
  HEAP32[$17>>2] = $1;
  $29 = ((($1)) + 8|0);
  $30 = HEAP32[$29>>2]|0;HEAP32[$29>>2] = (($30+1)|0);
  $31 = ($27|0)==(0|0);
  if (!($31)) {
   $32 = ((($27)) + 8|0);
   $33 = HEAP32[$32>>2]|0;HEAP32[$32>>2] = (($33-1)|0);
   $34 = ($33|0)==(1);
   if ($34) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($27,1,1);
   }
  }
 }
 $35 = HEAP32[$0>>2]|0;
 $36 = ((($35)) + 256|0);
 $37 = HEAP32[$36>>2]|0;
 FUNCTION_TABLE_viii[$37 & 8191]($0,$1,$2);
 $38 = HEAP32[$0>>2]|0;
 $39 = ((($38)) + 240|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = (FUNCTION_TABLE_iidd[$40 & 1023]($0,$7,$12)|0);
 $$0 = $41;
 return ($$0|0);
}
function __ZN5osgGA19StandardManipulator15performMovementEv($0) {
 $0 = $0|0;
 var $$$i = 0.0, $$$i33 = 0.0, $$031 = 0.0, $$2 = 0, $$sink$i = 0.0, $$sink$i35 = 0.0, $1 = 0, $10 = 0, $100 = 0.0, $101 = 0.0, $102 = 0.0, $103 = 0.0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0.0, $11 = 0.0, $110 = 0;
 var $111 = 0.0, $112 = 0.0, $113 = 0, $114 = 0.0, $115 = 0.0, $116 = 0.0, $117 = 0.0, $118 = 0.0, $119 = 0, $12 = 0.0, $120 = 0, $121 = 0, $122 = 0, $123 = 0.0, $124 = 0, $125 = 0.0, $126 = 0.0, $127 = 0.0, $128 = 0, $129 = 0.0;
 var $13 = 0, $130 = 0.0, $131 = 0.0, $132 = 0.0, $133 = 0.0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0.0, $14 = 0, $140 = 0, $141 = 0.0, $142 = 0.0, $143 = 0, $144 = 0.0, $145 = 0.0, $146 = 0.0, $147 = 0.0;
 var $148 = 0.0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0.0, $154 = 0, $155 = 0.0, $156 = 0.0, $157 = 0.0, $158 = 0, $159 = 0.0, $16 = 0, $160 = 0.0, $161 = 0.0, $162 = 0.0, $163 = 0.0, $164 = 0.0, $165 = 0.0;
 var $166 = 0.0, $167 = 0.0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0.0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0.0, $187 = 0, $188 = 0.0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0.0, $51 = 0, $52 = 0.0, $53 = 0.0, $54 = 0, $55 = 0.0, $56 = 0.0, $57 = 0.0, $58 = 0.0, $59 = 0, $6 = 0, $60 = 0.0, $61 = 0, $62 = 0.0, $63 = 0.0, $64 = 0.0;
 var $65 = 0, $66 = 0.0, $67 = 0.0, $68 = 0.0, $69 = 0.0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0.0, $84 = 0, $85 = 0.0, $86 = 0.0, $87 = 0, $88 = 0.0, $89 = 0.0, $9 = 0.0, $90 = 0.0, $91 = 0.0, $92 = 0, $93 = 0.0, $94 = 0, $95 = 0.0, $96 = 0.0, $97 = 0.0, $98 = 0, $99 = 0.0, $or$cond = 0, $or$cond32 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $2 = ((($0)) + 108|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $$2 = 0;
  STACKTOP = sp;return ($$2|0);
 }
 $5 = ((($0)) + 104|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $$2 = 0;
  STACKTOP = sp;return ($$2|0);
 }
 $8 = ((($3)) + 40|0);
 $9 = +HEAPF64[$8>>3];
 $10 = ((($6)) + 40|0);
 $11 = +HEAPF64[$10>>3];
 $12 = $9 - $11;
 $13 = $12 < 0.0;
 do {
  if ($13) {
   $14 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
   if ($14) {
    $15 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
    $16 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($15,110359,38)|0);
    $17 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEd($16,$12)|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = ((($18)) + -12|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = (($17) + ($20)|0);
    __ZNKSt3__28ios_base6getlocEv($1,$21);
    __THREW__ = 0;
    $22 = (invoke_iii(3255,($1|0),(215188|0))|0);
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if (!($24)) {
     $25 = HEAP32[$22>>2]|0;
     $26 = ((($25)) + 28|0);
     $27 = HEAP32[$26>>2]|0;
     __THREW__ = 0;
     $28 = (invoke_iii($27|0,($22|0),10)|0);
     $29 = __THREW__; __THREW__ = 0;
     $30 = $29&1;
     if (!($30)) {
      __ZNSt3__26localeD2Ev($1);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($17,$28)|0);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($17)|0);
      $$031 = 0.0;
      break;
     }
    }
    $31 = ___cxa_find_matching_catch_2()|0;
    $32 = tempRet0;
    __THREW__ = 0;
    invoke_vi(3263,($1|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     $35 = ___cxa_find_matching_catch_3(0|0)|0;
     $36 = tempRet0;
     ___clang_call_terminate($35);
     // unreachable;
    } else {
     ___resumeException($31|0);
     // unreachable;
    }
   } else {
    $$031 = 0.0;
   }
  } else {
   $$031 = $12;
  }
 } while(0);
 $37 = HEAP32[$2>>2]|0;
 $38 = ((($37)) + 160|0);
 $39 = ((($37)) + 164|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = HEAP32[$38>>2]|0;
 $42 = (($40) - ($41))|0;
 $43 = $42 >> 2;
 $44 = ($43|0)==(0);
 if ($44) {
  $59 = ((($37)) + 104|0);
  $60 = +HEAPF32[$59>>2];
  $61 = ((($37)) + 88|0);
  $62 = +HEAPF32[$61>>2];
  $63 = $60 - $62;
  $64 = $63 * 2.0;
  $65 = ((($37)) + 92|0);
  $66 = +HEAPF32[$65>>2];
  $67 = $66 - $62;
  $68 = $64 / $67;
  $$sink$i35 = $68;
 } else {
  $45 = $41;
  $46 = (($43) + -1)|0;
  $47 = (($45) + ($46<<2)|0);
  $48 = HEAP32[$47>>2]|0;
  $49 = ((($48)) + 20|0);
  $50 = +HEAPF32[$49>>2];
  $51 = ((($48)) + 24|0);
  $52 = +HEAPF32[$51>>2];
  $53 = $50 - $52;
  $54 = ((($48)) + 28|0);
  $55 = +HEAPF32[$54>>2];
  $56 = $55 - $52;
  $57 = $53 / $56;
  $58 = $57 * 2.0;
  $$sink$i35 = $58;
 }
 $69 = $$sink$i35 + -1.0;
 $70 = HEAP32[$5>>2]|0;
 $71 = ((($70)) + 160|0);
 $72 = ((($70)) + 164|0);
 $73 = HEAP32[$72>>2]|0;
 $74 = HEAP32[$71>>2]|0;
 $75 = (($73) - ($74))|0;
 $76 = $75 >> 2;
 $77 = ($76|0)==(0);
 if ($77) {
  $92 = ((($70)) + 104|0);
  $93 = +HEAPF32[$92>>2];
  $94 = ((($70)) + 88|0);
  $95 = +HEAPF32[$94>>2];
  $96 = $93 - $95;
  $97 = $96 * 2.0;
  $98 = ((($70)) + 92|0);
  $99 = +HEAPF32[$98>>2];
  $100 = $99 - $95;
  $101 = $97 / $100;
  $$sink$i = $101;
 } else {
  $78 = $74;
  $79 = (($76) + -1)|0;
  $80 = (($78) + ($79<<2)|0);
  $81 = HEAP32[$80>>2]|0;
  $82 = ((($81)) + 20|0);
  $83 = +HEAPF32[$82>>2];
  $84 = ((($81)) + 24|0);
  $85 = +HEAPF32[$84>>2];
  $86 = $83 - $85;
  $87 = ((($81)) + 28|0);
  $88 = +HEAPF32[$87>>2];
  $89 = $88 - $85;
  $90 = $86 / $89;
  $91 = $90 * 2.0;
  $$sink$i = $91;
 }
 $102 = $$sink$i + -1.0;
 $103 = $69 - $102;
 if ($44) {
  $119 = ((($37)) + 120|0);
  $120 = HEAP32[$119>>2]|0;
  $121 = ($120|0)==(0);
  $122 = ((($37)) + 108|0);
  $123 = +HEAPF32[$122>>2];
  $124 = ((($37)) + 96|0);
  $125 = +HEAPF32[$124>>2];
  $126 = $123 - $125;
  $127 = $126 * 2.0;
  $128 = ((($37)) + 100|0);
  $129 = +HEAPF32[$128>>2];
  $130 = $129 - $125;
  $131 = $127 / $130;
  $132 = $131 + -1.0;
  $133 = -$132;
  $$$i33 = $121 ? $132 : $133;
  $166 = $$$i33;
 } else {
  $104 = $41;
  $105 = (($43) + -1)|0;
  $106 = (($104) + ($105<<2)|0);
  $107 = HEAP32[$106>>2]|0;
  $108 = ((($107)) + 32|0);
  $109 = +HEAPF32[$108>>2];
  $110 = ((($107)) + 36|0);
  $111 = +HEAPF32[$110>>2];
  $112 = $109 - $111;
  $113 = ((($107)) + 40|0);
  $114 = +HEAPF32[$113>>2];
  $115 = $114 - $111;
  $116 = $112 / $115;
  $117 = $116 * 2.0;
  $118 = $117 + -1.0;
  $166 = $118;
 }
 if ($77) {
  $149 = ((($70)) + 120|0);
  $150 = HEAP32[$149>>2]|0;
  $151 = ($150|0)==(0);
  $152 = ((($70)) + 108|0);
  $153 = +HEAPF32[$152>>2];
  $154 = ((($70)) + 96|0);
  $155 = +HEAPF32[$154>>2];
  $156 = $153 - $155;
  $157 = $156 * 2.0;
  $158 = ((($70)) + 100|0);
  $159 = +HEAPF32[$158>>2];
  $160 = $159 - $155;
  $161 = $157 / $160;
  $162 = $161 + -1.0;
  $163 = -$162;
  $$$i = $151 ? $162 : $163;
  $165 = $$$i;
 } else {
  $134 = $74;
  $135 = (($76) + -1)|0;
  $136 = (($134) + ($135<<2)|0);
  $137 = HEAP32[$136>>2]|0;
  $138 = ((($137)) + 32|0);
  $139 = +HEAPF32[$138>>2];
  $140 = ((($137)) + 36|0);
  $141 = +HEAPF32[$140>>2];
  $142 = $139 - $141;
  $143 = ((($137)) + 40|0);
  $144 = +HEAPF32[$143>>2];
  $145 = $144 - $141;
  $146 = $142 / $145;
  $147 = $146 * 2.0;
  $148 = $147 + -1.0;
  $165 = $148;
 }
 $164 = $166 - $165;
 $167 = $103;
 $168 = $103 == 0.0;
 $169 = $164 == 0.0;
 $or$cond32 = $168 & $169;
 if ($or$cond32) {
  $$2 = 0;
  STACKTOP = sp;return ($$2|0);
 }
 $170 = ((($70)) + 112|0);
 $171 = HEAP32[$170>>2]|0;
 $172 = ((($70)) + 116|0);
 $173 = HEAP32[$172>>2]|0;
 switch ($171|0) {
 case 1:  {
  $174 = HEAP32[$0>>2]|0;
  $175 = ((($174)) + 228|0);
  $176 = HEAP32[$175>>2]|0;
  $177 = $164;
  $178 = (FUNCTION_TABLE_iiddd[$176 & 1023]($0,$$031,$167,$177)|0);
  $$2 = $178;
  STACKTOP = sp;return ($$2|0);
  break;
 }
 case 2:  {
  break;
 }
 default: {
  label = 26;
 }
 }
 do {
  if ((label|0) == 26) {
   $179 = ($171|0)==(4);
   $180 = ($171|0)==(5);
   if (!($179)) {
    if ($180) {
     break;
    } else {
     $$2 = 0;
    }
    STACKTOP = sp;return ($$2|0);
   }
   $181 = $173 & 12;
   $182 = ($181|0)!=(0);
   $or$cond = $180 | $182;
   if (!($or$cond)) {
    $188 = $164;
    $189 = HEAP32[$0>>2]|0;
    $190 = ((($189)) + 236|0);
    $191 = HEAP32[$190>>2]|0;
    $192 = (FUNCTION_TABLE_iiddd[$191 & 1023]($0,$$031,$167,$188)|0);
    $$2 = $192;
    STACKTOP = sp;return ($$2|0);
   }
  }
 } while(0);
 $183 = HEAP32[$0>>2]|0;
 $184 = ((($183)) + 232|0);
 $185 = HEAP32[$184>>2]|0;
 $186 = $164;
 $187 = (FUNCTION_TABLE_iiddd[$185 & 1023]($0,$$031,$167,$186)|0);
 $$2 = $187;
 STACKTOP = sp;return ($$2|0);
}
function __ZN5osgGA19StandardManipulator30performMovementLeftMouseButtonEddd($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = +$1;
 $2 = +$2;
 $3 = +$3;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function __ZN5osgGA19StandardManipulator32performMovementMiddleMouseButtonEddd($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = +$1;
 $2 = +$2;
 $3 = +$3;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function __ZN5osgGA19StandardManipulator31performMovementRightMouseButtonEddd($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = +$1;
 $2 = +$2;
 $3 = +$3;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function __ZN5osgGA19StandardManipulator25performMouseDeltaMovementEff($0,$1,$2) {
 $0 = $0|0;
 $1 = +$1;
 $2 = +$2;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function __ZN5osgGA19StandardManipulator24performAnimationMovementERKNS_15GUIEventAdapterERNS_16GUIActionAdapterE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0.0, $$pre = 0, $10 = 0, $11 = 0.0, $12 = 0.0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0.0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0.0, $5 = 0, $6 = 0, $7 = 0, $8 = 0.0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($1)) + 40|0);
 $4 = +HEAPF64[$3>>3];
 $5 = ((($0)) + 148|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($6)) + 32|0);
 $8 = +HEAPF64[$7>>3];
 $9 = $4 - $8;
 $10 = ((($6)) + 16|0);
 $11 = +HEAPF64[$10>>3];
 $12 = $9 / $11;
 $13 = !($12 >= 1.0);
 if ($13) {
  $$0 = $12;$25 = $6;
 } else {
  $14 = ((($6)) + 24|0);
  HEAP8[$14>>0] = 0;
  $15 = ((($0)) + 92|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   $18 = HEAP32[$2>>2]|0;
   $19 = ((($18)) + 16|0);
   $20 = HEAP32[$19>>2]|0;
   FUNCTION_TABLE_vii[$20 & 8191]($2,0);
   $$pre = HEAP32[$5>>2]|0;
   $$0 = 1.0;$25 = $$pre;
  } else {
   $$0 = 1.0;$25 = $6;
  }
 }
 $21 = HEAP32[$0>>2]|0;
 $22 = ((($21)) + 248|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ((($25)) + 40|0);
 $26 = +HEAPF64[$24>>3];
 FUNCTION_TABLE_vidd[$23 & 8191]($0,$$0,$26);
 $27 = HEAP32[$5>>2]|0;
 $28 = ((($27)) + 40|0);
 HEAPF64[$28>>3] = $$0;
 $29 = HEAP32[$2>>2]|0;
 $30 = ((($29)) + 12|0);
 $31 = HEAP32[$30>>2]|0;
 FUNCTION_TABLE_vi[$31 & 8191]($2);
 $32 = HEAP32[$5>>2]|0;
 $33 = ((($32)) + 24|0);
 $34 = HEAP8[$33>>0]|0;
 $35 = ($34<<24>>24)!=(0);
 return ($35|0);
}
function __ZN5osgGA19StandardManipulator18applyAnimationStepEdd($0,$1,$2) {
 $0 = $0|0;
 $1 = +$1;
 $2 = +$2;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZNK5osgGA19StandardManipulator13isMouseMovingEv($0) {
 $0 = $0|0;
 var $$$i = 0.0, $$$i15 = 0.0, $$0 = 0, $$sink$i = 0.0, $$sink$i17 = 0.0, $1 = 0, $10 = 0, $100 = 0.0, $101 = 0.0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0.0, $108 = 0, $109 = 0.0, $11 = 0, $110 = 0.0, $111 = 0;
 var $112 = 0.0, $113 = 0.0, $114 = 0.0, $115 = 0.0, $116 = 0.0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0.0, $122 = 0, $123 = 0.0, $124 = 0.0, $125 = 0.0, $126 = 0, $127 = 0.0, $128 = 0.0, $129 = 0.0, $13 = 0;
 var $130 = 0.0, $131 = 0.0, $132 = 0.0, $133 = 0.0, $134 = 0.0, $135 = 0.0, $136 = 0.0, $137 = 0.0, $138 = 0.0, $139 = 0, $14 = 0, $140 = 0.0, $141 = 0, $142 = 0.0, $143 = 0.0, $144 = 0.0, $145 = 0.0, $146 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0.0, $2 = 0, $20 = 0, $21 = 0.0, $22 = 0.0, $23 = 0, $24 = 0.0, $25 = 0.0, $26 = 0.0, $27 = 0.0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0.0, $32 = 0.0, $33 = 0.0, $34 = 0;
 var $35 = 0.0, $36 = 0.0, $37 = 0.0, $38 = 0.0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0.0, $52 = 0;
 var $53 = 0.0, $54 = 0.0, $55 = 0, $56 = 0.0, $57 = 0.0, $58 = 0.0, $59 = 0.0, $6 = 0, $60 = 0, $61 = 0.0, $62 = 0, $63 = 0.0, $64 = 0.0, $65 = 0.0, $66 = 0, $67 = 0.0, $68 = 0.0, $69 = 0.0, $7 = 0, $70 = 0.0;
 var $71 = 0.0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0.0, $78 = 0, $79 = 0.0, $8 = 0, $80 = 0.0, $81 = 0, $82 = 0.0, $83 = 0.0, $84 = 0.0, $85 = 0.0, $86 = 0.0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0.0, $92 = 0, $93 = 0.0, $94 = 0.0, $95 = 0.0, $96 = 0, $97 = 0.0, $98 = 0.0, $99 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 108|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  $$0 = 0;
  return ($$0|0);
 }
 $4 = ((($0)) + 104|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $$0 = 0;
  return ($$0|0);
 }
 $7 = ((($2)) + 160|0);
 $8 = ((($2)) + 164|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$7>>2]|0;
 $11 = (($9) - ($10))|0;
 $12 = $11 >> 2;
 $13 = ($12|0)==(0);
 if ($13) {
  $28 = ((($2)) + 104|0);
  $29 = +HEAPF32[$28>>2];
  $30 = ((($2)) + 88|0);
  $31 = +HEAPF32[$30>>2];
  $32 = $29 - $31;
  $33 = $32 * 2.0;
  $34 = ((($2)) + 92|0);
  $35 = +HEAPF32[$34>>2];
  $36 = $35 - $31;
  $37 = $33 / $36;
  $$sink$i17 = $37;
 } else {
  $14 = $10;
  $15 = (($12) + -1)|0;
  $16 = (($14) + ($15<<2)|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = ((($17)) + 20|0);
  $19 = +HEAPF32[$18>>2];
  $20 = ((($17)) + 24|0);
  $21 = +HEAPF32[$20>>2];
  $22 = $19 - $21;
  $23 = ((($17)) + 28|0);
  $24 = +HEAPF32[$23>>2];
  $25 = $24 - $21;
  $26 = $22 / $25;
  $27 = $26 * 2.0;
  $$sink$i17 = $27;
 }
 $38 = $$sink$i17 + -1.0;
 $39 = ((($5)) + 160|0);
 $40 = ((($5)) + 164|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = HEAP32[$39>>2]|0;
 $43 = (($41) - ($42))|0;
 $44 = $43 >> 2;
 $45 = ($44|0)==(0);
 if ($45) {
  $60 = ((($5)) + 104|0);
  $61 = +HEAPF32[$60>>2];
  $62 = ((($5)) + 88|0);
  $63 = +HEAPF32[$62>>2];
  $64 = $61 - $63;
  $65 = $64 * 2.0;
  $66 = ((($5)) + 92|0);
  $67 = +HEAPF32[$66>>2];
  $68 = $67 - $63;
  $69 = $65 / $68;
  $$sink$i = $69;
 } else {
  $46 = $42;
  $47 = (($44) + -1)|0;
  $48 = (($46) + ($47<<2)|0);
  $49 = HEAP32[$48>>2]|0;
  $50 = ((($49)) + 20|0);
  $51 = +HEAPF32[$50>>2];
  $52 = ((($49)) + 24|0);
  $53 = +HEAPF32[$52>>2];
  $54 = $51 - $53;
  $55 = ((($49)) + 28|0);
  $56 = +HEAPF32[$55>>2];
  $57 = $56 - $53;
  $58 = $54 / $57;
  $59 = $58 * 2.0;
  $$sink$i = $59;
 }
 $70 = $$sink$i + -1.0;
 $71 = $38 - $70;
 if ($13) {
  $87 = ((($2)) + 120|0);
  $88 = HEAP32[$87>>2]|0;
  $89 = ($88|0)==(0);
  $90 = ((($2)) + 108|0);
  $91 = +HEAPF32[$90>>2];
  $92 = ((($2)) + 96|0);
  $93 = +HEAPF32[$92>>2];
  $94 = $91 - $93;
  $95 = $94 * 2.0;
  $96 = ((($2)) + 100|0);
  $97 = +HEAPF32[$96>>2];
  $98 = $97 - $93;
  $99 = $95 / $98;
  $100 = $99 + -1.0;
  $101 = -$100;
  $$$i15 = $89 ? $100 : $101;
  $134 = $$$i15;
 } else {
  $72 = $10;
  $73 = (($12) + -1)|0;
  $74 = (($72) + ($73<<2)|0);
  $75 = HEAP32[$74>>2]|0;
  $76 = ((($75)) + 32|0);
  $77 = +HEAPF32[$76>>2];
  $78 = ((($75)) + 36|0);
  $79 = +HEAPF32[$78>>2];
  $80 = $77 - $79;
  $81 = ((($75)) + 40|0);
  $82 = +HEAPF32[$81>>2];
  $83 = $82 - $79;
  $84 = $80 / $83;
  $85 = $84 * 2.0;
  $86 = $85 + -1.0;
  $134 = $86;
 }
 if ($45) {
  $117 = ((($5)) + 120|0);
  $118 = HEAP32[$117>>2]|0;
  $119 = ($118|0)==(0);
  $120 = ((($5)) + 108|0);
  $121 = +HEAPF32[$120>>2];
  $122 = ((($5)) + 96|0);
  $123 = +HEAPF32[$122>>2];
  $124 = $121 - $123;
  $125 = $124 * 2.0;
  $126 = ((($5)) + 100|0);
  $127 = +HEAPF32[$126>>2];
  $128 = $127 - $123;
  $129 = $125 / $128;
  $130 = $129 + -1.0;
  $131 = -$130;
  $$$i = $119 ? $130 : $131;
  $133 = $$$i;
 } else {
  $102 = $42;
  $103 = (($44) + -1)|0;
  $104 = (($102) + ($103<<2)|0);
  $105 = HEAP32[$104>>2]|0;
  $106 = ((($105)) + 32|0);
  $107 = +HEAPF32[$106>>2];
  $108 = ((($105)) + 36|0);
  $109 = +HEAPF32[$108>>2];
  $110 = $107 - $109;
  $111 = ((($105)) + 40|0);
  $112 = +HEAPF32[$111>>2];
  $113 = $112 - $109;
  $114 = $110 / $113;
  $115 = $114 * 2.0;
  $116 = $115 + -1.0;
  $133 = $116;
 }
 $132 = $134 - $133;
 $135 = $71 * $71;
 $136 = $132 * $132;
 $137 = $135 + $136;
 $138 = (+Math_sqrt((+$137)));
 $139 = ((($2)) + 40|0);
 $140 = +HEAPF64[$139>>3];
 $141 = ((($5)) + 40|0);
 $142 = +HEAPF64[$141>>3];
 $143 = $140 - $142;
 $144 = $143;
 $145 = $144 * 0.10000000149011612;
 $146 = $138 > $145;
 $$0 = $146;
 return ($$0|0);
}
function __ZN5osgGA19StandardManipulator18centerMousePointerERKNS_15GUIEventAdapterERNS_16GUIActionAdapterE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0.0, $12 = 0, $13 = 0.0, $14 = 0.0, $15 = 0.0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $3 = 0, $4 = 0.0, $5 = 0, $6 = 0.0, $7 = 0.0, $8 = 0.0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($1)) + 88|0);
 $4 = +HEAPF32[$3>>2];
 $5 = ((($1)) + 92|0);
 $6 = +HEAPF32[$5>>2];
 $7 = $4 + $6;
 $8 = $7 * 0.5;
 $9 = ((($0)) + 96|0);
 HEAPF32[$9>>2] = $8;
 $10 = ((($1)) + 96|0);
 $11 = +HEAPF32[$10>>2];
 $12 = ((($1)) + 100|0);
 $13 = +HEAPF32[$12>>2];
 $14 = $11 + $13;
 $15 = $14 * 0.5;
 $16 = ((($0)) + 100|0);
 HEAPF32[$16>>2] = $15;
 $17 = HEAP32[$2>>2]|0;
 $18 = ((($17)) + 20|0);
 $19 = HEAP32[$18>>2]|0;
 FUNCTION_TABLE_vidd[$19 & 8191]($2,$8,$15);
 return;
}
function __ZN5osgGA19StandardManipulator35setCenterByMousePointerIntersectionERKNS_15GUIEventAdapterERNS_16GUIActionAdapterE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$$i = 0, $$0 = 0, $$058 = 0, $$059 = 0.0, $$060 = 0.0, $$149 = 0, $$152 = 0, $$2 = 0, $$250 = 0, $$253 = 0, $$3 = 0, $$354 = 0, $$4 = 0, $$455 = 0, $$5 = 0, $$556 = 0, $$6 = 0, $$657 = 0, $10 = 0, $100 = 0;
 var $101 = 0.0, $102 = 0, $103 = 0.0, $104 = 0.0, $105 = 0.0, $106 = 0, $107 = 0.0, $108 = 0.0, $109 = 0.0, $11 = 0, $110 = 0, $111 = 0.0, $112 = 0.0, $113 = 0, $114 = 0.0, $115 = 0.0, $116 = 0.0, $117 = 0, $118 = 0.0, $119 = 0.0;
 var $12 = 0, $120 = 0.0, $121 = 0, $122 = 0.0, $123 = 0.0, $124 = 0.0, $125 = 0, $126 = 0.0, $127 = 0.0, $128 = 0, $129 = 0.0, $13 = 0, $130 = 0.0, $131 = 0.0, $132 = 0, $133 = 0.0, $134 = 0.0, $135 = 0.0, $136 = 0, $137 = 0.0;
 var $138 = 0.0, $139 = 0.0, $14 = 0, $140 = 0, $141 = 0.0, $142 = 0.0, $143 = 0, $144 = 0.0, $145 = 0.0, $146 = 0.0, $147 = 0, $148 = 0.0, $149 = 0.0, $15 = 0, $150 = 0.0, $151 = 0, $152 = 0.0, $153 = 0.0, $154 = 0.0, $155 = 0;
 var $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0.0, $172 = 0, $173 = 0.0;
 var $174 = 0, $175 = 0.0, $176 = 0, $177 = 0, $178 = 0.0, $179 = 0.0, $18 = 0, $180 = 0.0, $181 = 0, $182 = 0.0, $183 = 0, $184 = 0.0, $185 = 0.0, $186 = 0, $187 = 0.0, $188 = 0, $189 = 0.0, $19 = 0, $190 = 0.0, $191 = 0;
 var $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0.0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0;
 var $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0.0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0;
 var $229 = 0, $23 = 0.0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $25 = 0.0, $26 = 0.0;
 var $27 = 0.0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0.0, $32 = 0.0, $33 = 0, $34 = 0.0, $35 = 0.0, $36 = 0.0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0.0, $42 = 0.0, $43 = 0.0, $44 = 0.0;
 var $45 = 0, $46 = 0.0, $47 = 0.0, $48 = 0.0, $49 = 0.0, $5 = 0, $50 = 0, $51 = 0.0, $52 = 0.0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0.0, $92 = 0.0, $93 = 0.0, $94 = 0, $95 = 0.0, $96 = 0, $97 = 0.0, $98 = 0.0, $99 = 0.0;
 var $eh$lpad$body$indexZ2D = 0, $eh$lpad$body65$index2Z2D = 0, $eh$lpad$body65$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 464|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(464|0);
 $3 = sp + 272|0;
 $4 = sp + 248|0;
 $5 = sp + 224|0;
 $6 = sp + 200|0;
 $7 = sp + 176|0;
 $8 = sp + 48|0;
 $9 = sp + 24|0;
 $10 = sp;
 $11 = HEAP32[$2>>2]|0;
 $12 = ((($11)) + 8|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (FUNCTION_TABLE_ii[$13 & 8191]($2)|0);
 $15 = ($14|0)==(0|0);
 if ($15) {
  $$2 = 0;
  STACKTOP = sp;return ($$2|0);
 }
 $16 = ((($14)) + 16|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==(0|0);
 if ($18) {
  $$2 = 0;
  STACKTOP = sp;return ($$2|0);
 }
 $19 = ((($1)) + 104|0);
 $20 = +HEAPF32[$19>>2];
 $21 = ((($1)) + 88|0);
 $22 = +HEAPF32[$21>>2];
 $23 = $20 - $22;
 $24 = ((($1)) + 92|0);
 $25 = +HEAPF32[$24>>2];
 $26 = $25 - $22;
 $27 = $23 / $26;
 $28 = ((($1)) + 108|0);
 $29 = +HEAPF32[$28>>2];
 $30 = ((($1)) + 96|0);
 $31 = +HEAPF32[$30>>2];
 $32 = $29 - $31;
 $33 = ((($1)) + 100|0);
 $34 = +HEAPF32[$33>>2];
 $35 = $34 - $31;
 $36 = $32 / $35;
 $37 = ((($17)) + 288|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = ($38|0)==(0|0);
 if ($39) {
  $$058 = 1;$$059 = $36;$$060 = $27;
 } else {
  $40 = ((($38)) + 72|0);
  $41 = +HEAPF64[$40>>3];
  $42 = $27;
  $43 = $42 * $41;
  $44 = $43;
  $45 = ((($38)) + 80|0);
  $46 = +HEAPF64[$45>>3];
  $47 = $36;
  $48 = $47 * $46;
  $49 = $48;
  $$058 = 0;$$059 = $49;$$060 = $44;
 }
 $50 = (__Znwj(96)|0);
 $51 = $$060;
 $52 = $$059;
 __THREW__ = 0;
 invoke_viidd(3319,($50|0),($$058|0),(+$51),(+$52));
 $53 = __THREW__; __THREW__ = 0;
 $54 = $53&1;
 if ($54) {
  $70 = ___cxa_find_matching_catch_2()|0;
  $71 = tempRet0;
  __ZdlPv($50);
  $$6 = $71;$$657 = $70;
  ___resumeException($$657|0);
  // unreachable;
 }
 $55 = ((($50)) + 8|0);
 $56 = HEAP32[$55>>2]|0;HEAP32[$55>>2] = (($56+1)|0);
 __THREW__ = 0;
 invoke_viii(3310,($3|0),($50|0),(0|0));
 $57 = __THREW__; __THREW__ = 0;
 $58 = $57&1;
 L14: do {
  if ($58) {
   $72 = ___cxa_find_matching_catch_2()|0;
   $73 = tempRet0;
   $$5 = $73;$$556 = $72;
   label = 44;
  } else {
   $59 = HEAP32[$17>>2]|0;
   $60 = ((($59)) + 188|0);
   $61 = HEAP32[$60>>2]|0;
   __THREW__ = 0;
   invoke_vii($61|0,($17|0),($3|0));
   $62 = __THREW__; __THREW__ = 0;
   $63 = $62&1;
   L17: do {
    if ($63) {
     label = 12;
    } else {
     $64 = HEAP32[$50>>2]|0;
     $65 = ((($64)) + 32|0);
     $66 = HEAP32[$65>>2]|0;
     __THREW__ = 0;
     $67 = (invoke_ii($66|0,($50|0))|0);
     $68 = __THREW__; __THREW__ = 0;
     $69 = $68&1;
     if ($69) {
      label = 12;
     } else {
      do {
       if ($67) {
        $76 = ((($50)) + 28|0);
        $77 = HEAP32[$76>>2]|0;
        ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;HEAP32[$4+12>>2]=0|0;HEAP32[$4+16>>2]=0|0;HEAP32[$4+20>>2]=0|0;
        ;HEAP32[$5>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;HEAP32[$5+12>>2]=0|0;HEAP32[$5+16>>2]=0|0;HEAP32[$5+20>>2]=0|0;
        ;HEAP32[$6>>2]=0|0;HEAP32[$6+4>>2]=0|0;HEAP32[$6+8>>2]=0|0;HEAP32[$6+12>>2]=0|0;HEAP32[$6+16>>2]=0|0;HEAP32[$6+20>>2]=0|0;
        $78 = HEAP32[$0>>2]|0;
        $79 = ((($78)) + 168|0);
        $80 = HEAP32[$79>>2]|0;
        __THREW__ = 0;
        invoke_viiii($80|0,($0|0),($4|0),($5|0),($6|0));
        $81 = __THREW__; __THREW__ = 0;
        $82 = $81&1;
        if ($82) {
         $195 = ___cxa_find_matching_catch_2()|0;
         $196 = tempRet0;
         $$250 = $196;$$253 = $195;
        } else {
         $83 = ($77|0)==(0|0);
         $$$i = $83 ? $50 : $77;
         $84 = ((($$$i)) + 80|0);
         $85 = HEAP32[$84>>2]|0;
         $86 = ((($85)) + 40|0);
         $87 = HEAP32[$86>>2]|0;
         $88 = ($87|0)==(0|0);
         $89 = ((($85)) + 48|0);
         if ($88) {
          ;HEAP32[$7>>2]=HEAP32[$89>>2]|0;HEAP32[$7+4>>2]=HEAP32[$89+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[$89+8>>2]|0;HEAP32[$7+12>>2]=HEAP32[$89+12>>2]|0;HEAP32[$7+16>>2]=HEAP32[$89+16>>2]|0;HEAP32[$7+20>>2]=HEAP32[$89+20>>2]|0;
         } else {
          $90 = ((($87)) + 56|0);
          $91 = +HEAPF64[$90>>3];
          $92 = +HEAPF64[$89>>3];
          $93 = $91 * $92;
          $94 = ((($87)) + 88|0);
          $95 = +HEAPF64[$94>>3];
          $96 = ((($85)) + 56|0);
          $97 = +HEAPF64[$96>>3];
          $98 = $95 * $97;
          $99 = $93 + $98;
          $100 = ((($87)) + 120|0);
          $101 = +HEAPF64[$100>>3];
          $102 = ((($85)) + 64|0);
          $103 = +HEAPF64[$102>>3];
          $104 = $101 * $103;
          $105 = $99 + $104;
          $106 = ((($87)) + 152|0);
          $107 = +HEAPF64[$106>>3];
          $108 = $107 + $105;
          $109 = 1.0 / $108;
          $110 = ((($87)) + 32|0);
          $111 = +HEAPF64[$110>>3];
          $112 = $92 * $111;
          $113 = ((($87)) + 64|0);
          $114 = +HEAPF64[$113>>3];
          $115 = $97 * $114;
          $116 = $112 + $115;
          $117 = ((($87)) + 96|0);
          $118 = +HEAPF64[$117>>3];
          $119 = $103 * $118;
          $120 = $116 + $119;
          $121 = ((($87)) + 128|0);
          $122 = +HEAPF64[$121>>3];
          $123 = $122 + $120;
          $124 = $109 * $123;
          $125 = ((($87)) + 40|0);
          $126 = +HEAPF64[$125>>3];
          $127 = $92 * $126;
          $128 = ((($87)) + 72|0);
          $129 = +HEAPF64[$128>>3];
          $130 = $97 * $129;
          $131 = $127 + $130;
          $132 = ((($87)) + 104|0);
          $133 = +HEAPF64[$132>>3];
          $134 = $103 * $133;
          $135 = $131 + $134;
          $136 = ((($87)) + 136|0);
          $137 = +HEAPF64[$136>>3];
          $138 = $137 + $135;
          $139 = $109 * $138;
          $140 = ((($87)) + 48|0);
          $141 = +HEAPF64[$140>>3];
          $142 = $92 * $141;
          $143 = ((($87)) + 80|0);
          $144 = +HEAPF64[$143>>3];
          $145 = $97 * $144;
          $146 = $142 + $145;
          $147 = ((($87)) + 112|0);
          $148 = +HEAPF64[$147>>3];
          $149 = $103 * $148;
          $150 = $146 + $149;
          $151 = ((($87)) + 144|0);
          $152 = +HEAPF64[$151>>3];
          $153 = $152 + $150;
          $154 = $109 * $153;
          HEAPF64[$7>>3] = $124;
          $155 = ((($7)) + 8|0);
          HEAPF64[$155>>3] = $139;
          $156 = ((($7)) + 16|0);
          HEAPF64[$156>>3] = $154;
         }
         $157 = ((($0)) + 144|0);
         $158 = HEAP8[$157>>0]|0;
         $159 = ($158<<24>>24)==(0);
         do {
          if ($159) {
           label = 26;
          } else {
           $160 = ((($0)) + 88|0);
           $161 = HEAP32[$160>>2]|0;
           $162 = ($161|0)==(0|0);
           if ($162) {
            __THREW__ = 0;
            invoke_vi(3299,($8|0));
            $168 = __THREW__; __THREW__ = 0;
            $169 = $168&1;
            if ($169) {
             label = 24;
             break;
            }
           } else {
            $163 = HEAP32[$161>>2]|0;
            $164 = ((($163)) + 12|0);
            $165 = HEAP32[$164>>2]|0;
            __THREW__ = 0;
            invoke_viii($165|0,($8|0),($161|0),($7|0));
            $166 = __THREW__; __THREW__ = 0;
            $167 = $166&1;
            if ($167) {
             label = 24;
             break;
            }
           }
           $170 = ((($8)) + 64|0);
           $171 = +HEAPF64[$170>>3];
           $172 = ((($8)) + 72|0);
           $173 = +HEAPF64[$172>>3];
           $174 = ((($8)) + 80|0);
           $175 = +HEAPF64[$174>>3];
           HEAPF64[$9>>3] = $171;
           $176 = ((($9)) + 8|0);
           HEAPF64[$176>>3] = $173;
           $177 = ((($9)) + 16|0);
           HEAPF64[$177>>3] = $175;
           $178 = +HEAPF64[$7>>3];
           $179 = +HEAPF64[$4>>3];
           $180 = $178 - $179;
           $181 = ((($7)) + 8|0);
           $182 = +HEAPF64[$181>>3];
           $183 = ((($4)) + 8|0);
           $184 = +HEAPF64[$183>>3];
           $185 = $182 - $184;
           $186 = ((($7)) + 16|0);
           $187 = +HEAPF64[$186>>3];
           $188 = ((($4)) + 16|0);
           $189 = +HEAPF64[$188>>3];
           $190 = $187 - $189;
           HEAPF64[$10>>3] = $180;
           $191 = ((($10)) + 8|0);
           HEAPF64[$191>>3] = $185;
           $192 = ((($10)) + 16|0);
           HEAPF64[$192>>3] = $190;
           __THREW__ = 0;
           invoke_viiiii(3538,($10|0),($6|0),($6|0),($9|0),0);
           $193 = __THREW__; __THREW__ = 0;
           $194 = $193&1;
           if ($194) {
            $199 = ___cxa_find_matching_catch_2()|0;
            $200 = tempRet0;
            $$149 = $200;$$152 = $199;
            break;
           } else {
            label = 26;
            break;
           }
          }
         } while(0);
         if ((label|0) == 26) {
          $201 = HEAP32[$0>>2]|0;
          $202 = ((($201)) + 160|0);
          $203 = HEAP32[$202>>2]|0;
          __THREW__ = 0;
          invoke_viiii($203|0,($0|0),($4|0),($7|0),($6|0));
          $204 = __THREW__; __THREW__ = 0;
          $205 = $204&1;
          if ($205) {
           label = 24;
          } else {
           $206 = HEAP32[$0>>2]|0;
           $207 = ((($206)) + 256|0);
           $208 = HEAP32[$207>>2]|0;
           __THREW__ = 0;
           invoke_viii($208|0,($0|0),($1|0),($2|0));
           $209 = __THREW__; __THREW__ = 0;
           $210 = $209&1;
           if ($210) {
            label = 24;
           } else {
            $$0 = 1;
            break;
           }
          }
         }
         if ((label|0) == 24) {
          $197 = ___cxa_find_matching_catch_2()|0;
          $198 = tempRet0;
          $$149 = $198;$$152 = $197;
         }
         $$250 = $$149;$$253 = $$152;
        }
        $$3 = $$250;$$354 = $$253;
        label = 39;
        break L17;
       } else {
        $$0 = 0;
       }
      } while(0);
      __THREW__ = 0;
      invoke_vii(3312,($3|0),(47564|0));
      $211 = __THREW__; __THREW__ = 0;
      $212 = $211&1;
      do {
       if ($212) {
        $216 = ___cxa_find_matching_catch_2()|0;
        $217 = tempRet0;
        $218 = ((($3)) + 160|0);
        __THREW__ = 0;
        invoke_vi(388,($218|0));
        $219 = __THREW__; __THREW__ = 0;
        $220 = $219&1;
        if ($220) {
         $221 = ___cxa_find_matching_catch_3(0|0)|0;
         $222 = tempRet0;
         ___clang_call_terminate($221);
         // unreachable;
        } else {
         $eh$lpad$body65$index2Z2D = $217;$eh$lpad$body65$indexZ2D = $216;
        }
       } else {
        $213 = ((($3)) + 160|0);
        __THREW__ = 0;
        invoke_vi(388,($213|0));
        $214 = __THREW__; __THREW__ = 0;
        $215 = $214&1;
        if ($215) {
         $225 = ___cxa_find_matching_catch_2()|0;
         $226 = tempRet0;
         $eh$lpad$body65$index2Z2D = $226;$eh$lpad$body65$indexZ2D = $225;
         break;
        }
        $223 = HEAP32[$55>>2]|0;HEAP32[$55>>2] = (($223-1)|0);
        $224 = ($223|0)==(1);
        if (!($224)) {
         $$2 = $$0;
         STACKTOP = sp;return ($$2|0);
        }
        __ZNK3osg10Referenced24signalObserversAndDeleteEbb($50,1,1);
        $$2 = $$0;
        STACKTOP = sp;return ($$2|0);
       }
      } while(0);
      $$4 = $eh$lpad$body65$index2Z2D;$$455 = $eh$lpad$body65$indexZ2D;
     }
    }
   } while(0);
   if ((label|0) == 12) {
    $74 = ___cxa_find_matching_catch_2()|0;
    $75 = tempRet0;
    $$3 = $75;$$354 = $74;
    label = 39;
   }
   do {
    if ((label|0) == 39) {
     __THREW__ = 0;
     invoke_vii(3312,($3|0),(47564|0));
     $227 = __THREW__; __THREW__ = 0;
     $228 = $227&1;
     if (!($228)) {
      $229 = ((($3)) + 160|0);
      __THREW__ = 0;
      invoke_vi(388,($229|0));
      $230 = __THREW__; __THREW__ = 0;
      $231 = $230&1;
      if ($231) {
       break L14;
      } else {
       $$4 = $$3;$$455 = $$354;
       break;
      }
     }
     $232 = ___cxa_find_matching_catch_3(0|0)|0;
     $233 = tempRet0;
     $234 = ((($3)) + 160|0);
     __THREW__ = 0;
     invoke_vi(388,($234|0));
     $235 = __THREW__; __THREW__ = 0;
     $236 = $235&1;
     if ($236) {
      $237 = ___cxa_find_matching_catch_3(0|0)|0;
      $238 = tempRet0;
      ___clang_call_terminate($237);
      // unreachable;
     } else {
      $eh$lpad$body$indexZ2D = $232;
      ___clang_call_terminate($eh$lpad$body$indexZ2D);
      // unreachable;
     }
    }
   } while(0);
   $$5 = $$4;$$556 = $$455;
   label = 44;
  }
 } while(0);
 if ((label|0) == 44) {
  $239 = HEAP32[$55>>2]|0;HEAP32[$55>>2] = (($239-1)|0);
  $240 = ($239|0)==(1);
  if (!($240)) {
   $$6 = $$5;$$657 = $$556;
   ___resumeException($$657|0);
   // unreachable;
  }
  __THREW__ = 0;
  invoke_viii(3262,($50|0),1,1);
  $241 = __THREW__; __THREW__ = 0;
  $242 = $241&1;
  if (!($242)) {
   $$6 = $$5;$$657 = $$556;
   ___resumeException($$657|0);
   // unreachable;
  }
 }
 $243 = ___cxa_find_matching_catch_3(0|0)|0;
 $244 = tempRet0;
 $eh$lpad$body$indexZ2D = $243;
 ___clang_call_terminate($eh$lpad$body$indexZ2D);
 // unreachable;
 return (0)|0;
}
function __ZN5osgGA19StandardManipulator40startAnimationByMousePointerIntersectionERKNS_15GUIEventAdapterERNS_16GUIActionAdapterE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function __ZN5osgGA19StandardManipulator15fixVerticalAxisERKN3osg5Vec3dES4_RS2_S4_b($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$ = 0, $$sroa$0$0 = 0.0, $$sroa$013$0$copyload = 0.0, $$sroa$4$0$$sroa_idx15 = 0, $$sroa$4$0$copyload = 0.0, $$sroa$5$0$$sroa_idx17 = 0, $$sroa$5$0$copyload = 0.0, $$sroa$6$0 = 0.0, $$sroa$6$0$$sroa_idx9 = 0, $$sroa$9$0 = 0.0, $$sroa$9$0$$sroa_idx11 = 0, $10 = 0, $11 = 0.0, $12 = 0.0, $13 = 0, $14 = 0.0, $15 = 0, $16 = 0.0, $17 = 0.0, $18 = 0.0;
 var $19 = 0.0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0.0, $25 = 0.0, $26 = 0.0, $27 = 0, $28 = 0, $29 = 0, $30 = 0.0, $31 = 0.0, $32 = 0, $33 = 0.0, $34 = 0.0, $35 = 0.0, $36 = 0.0, $37 = 0.0, $38 = 0.0;
 var $39 = 0.0, $40 = 0.0, $41 = 0.0, $42 = 0.0, $43 = 0, $44 = 0, $45 = 0.0, $46 = 0.0, $47 = 0.0, $48 = 0.0, $49 = 0.0, $5 = 0, $50 = 0.0, $51 = 0.0, $52 = 0.0, $53 = 0.0, $54 = 0.0, $55 = 0, $56 = 0.0, $57 = 0.0;
 var $58 = 0.0, $59 = 0.0, $6 = 0, $60 = 0.0, $61 = 0.0, $62 = 0.0, $63 = 0.0, $64 = 0.0, $65 = 0.0, $66 = 0.0, $67 = 0.0, $68 = 0.0, $69 = 0.0, $7 = 0, $70 = 0.0, $71 = 0, $72 = 0.0, $73 = 0, $74 = 0.0, $75 = 0.0;
 var $76 = 0.0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0.0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(64|0);
 $5 = sp + 48|0;
 $6 = sp + 24|0;
 $7 = sp;
 $8 = ((($0)) + 8|0);
 $9 = +HEAPF64[$8>>3];
 $10 = ((($3)) + 16|0);
 $11 = +HEAPF64[$10>>3];
 $12 = $9 * $11;
 $13 = ((($0)) + 16|0);
 $14 = +HEAPF64[$13>>3];
 $15 = ((($3)) + 8|0);
 $16 = +HEAPF64[$15>>3];
 $17 = $14 * $16;
 $18 = $12 - $17;
 $19 = +HEAPF64[$3>>3];
 $20 = $14 * $19;
 $21 = +HEAPF64[$0>>3];
 $22 = $11 * $21;
 $23 = $20 - $22;
 $24 = $16 * $21;
 $25 = $9 * $19;
 $26 = $24 - $25;
 HEAPF64[$6>>3] = $18;
 $27 = ((($6)) + 8|0);
 HEAPF64[$27>>3] = $23;
 $28 = ((($6)) + 16|0);
 HEAPF64[$28>>3] = $26;
 $29 = ((($1)) + 8|0);
 $30 = +HEAPF64[$29>>3];
 $31 = $30 * $11;
 $32 = ((($1)) + 16|0);
 $33 = +HEAPF64[$32>>3];
 $34 = $33 * $16;
 $35 = $31 - $34;
 $36 = $33 * $19;
 $37 = +HEAPF64[$1>>3];
 $38 = $11 * $37;
 $39 = $36 - $38;
 $40 = $16 * $37;
 $41 = $30 * $19;
 $42 = $40 - $41;
 HEAPF64[$7>>3] = $35;
 $43 = ((($7)) + 8|0);
 HEAPF64[$43>>3] = $39;
 $44 = ((($7)) + 16|0);
 HEAPF64[$44>>3] = $42;
 $45 = $18 * $18;
 $46 = $23 * $23;
 $47 = $45 + $46;
 $48 = $26 * $26;
 $49 = $47 + $48;
 $50 = $35 * $35;
 $51 = $39 * $39;
 $52 = $50 + $51;
 $53 = $42 * $42;
 $54 = $53 + $52;
 $55 = $49 > $54;
 $$ = $55 ? $6 : $7;
 $$sroa$013$0$copyload = +HEAPF64[$$>>3];
 $$sroa$4$0$$sroa_idx15 = ((($$)) + 8|0);
 $$sroa$4$0$copyload = +HEAPF64[$$sroa$4$0$$sroa_idx15>>3];
 $$sroa$5$0$$sroa_idx17 = ((($$)) + 16|0);
 $$sroa$5$0$copyload = +HEAPF64[$$sroa$5$0$$sroa_idx17>>3];
 $56 = $$sroa$4$0$copyload * $14;
 $57 = $$sroa$5$0$copyload * $9;
 $58 = $56 - $57;
 $59 = $$sroa$5$0$copyload * $21;
 $60 = $$sroa$013$0$copyload * $14;
 $61 = $59 - $60;
 $62 = $$sroa$013$0$copyload * $9;
 $63 = $$sroa$4$0$copyload * $21;
 $64 = $62 - $63;
 $65 = $58 * $58;
 $66 = $61 * $61;
 $67 = $65 + $66;
 $68 = $64 * $64;
 $69 = $68 + $67;
 $70 = (+Math_sqrt((+$69)));
 $71 = $70 > 0.0;
 $72 = 1.0 / $70;
 $73 = !($70 >= 0.0);
 if (!($73)) {
  $74 = $58 * $72;
  $$sroa$0$0 = $71 ? $74 : $58;
  $75 = $72 * $61;
  $$sroa$6$0 = $71 ? $75 : $61;
  $76 = $72 * $64;
  $$sroa$9$0 = $71 ? $76 : $64;
  HEAPF64[$2>>3] = $$sroa$0$0;
  $$sroa$6$0$$sroa_idx9 = ((($2)) + 8|0);
  HEAPF64[$$sroa$6$0$$sroa_idx9>>3] = $$sroa$6$0;
  $$sroa$9$0$$sroa_idx11 = ((($2)) + 16|0);
  HEAPF64[$$sroa$9$0$$sroa_idx11>>3] = $$sroa$9$0;
  STACKTOP = sp;return;
 }
 $77 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
 do {
  if ($77) {
   $78 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
   $79 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($78,110283,75)|0);
   $80 = HEAP32[$79>>2]|0;
   $81 = ((($80)) + -12|0);
   $82 = HEAP32[$81>>2]|0;
   $83 = (($79) + ($82)|0);
   __ZNKSt3__28ios_base6getlocEv($5,$83);
   __THREW__ = 0;
   $84 = (invoke_iii(3255,($5|0),(215188|0))|0);
   $85 = __THREW__; __THREW__ = 0;
   $86 = $85&1;
   if (!($86)) {
    $87 = HEAP32[$84>>2]|0;
    $88 = ((($87)) + 28|0);
    $89 = HEAP32[$88>>2]|0;
    __THREW__ = 0;
    $90 = (invoke_iii($89|0,($84|0),10)|0);
    $91 = __THREW__; __THREW__ = 0;
    $92 = $91&1;
    if (!($92)) {
     __ZNSt3__26localeD2Ev($5);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($79,$90)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($79)|0);
     break;
    }
   }
   $93 = ___cxa_find_matching_catch_2()|0;
   $94 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($5|0));
   $95 = __THREW__; __THREW__ = 0;
   $96 = $95&1;
   if ($96) {
    $97 = ___cxa_find_matching_catch_3(0|0)|0;
    $98 = tempRet0;
    ___clang_call_terminate($97);
    // unreachable;
   } else {
    ___resumeException($93|0);
    // unreachable;
   }
  }
 } while(0);
 ;HEAP32[$2>>2]=HEAP32[$1>>2]|0;HEAP32[$2+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$1+12>>2]|0;HEAP32[$2+16>>2]=HEAP32[$1+16>>2]|0;HEAP32[$2+20>>2]=HEAP32[$1+20>>2]|0;
 STACKTOP = sp;return;
}
function __ZNSt3__2plIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_12basic_stringIT_T0_T1_EERKS9_PKS6_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 ;HEAP32[$0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;
 $3 = ((($1)) + 11|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)<(0);
 $6 = ((($1)) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $4&255;
 $9 = $5 ? $7 : $8;
 $10 = (_strlen($2)|0);
 $11 = HEAP32[$1>>2]|0;
 $12 = $5 ? $11 : $1;
 $13 = (($9) + ($10))|0;
 $14 = ($13>>>0)>(4294967279);
 do {
  if ($14) {
   __THREW__ = 0;
   invoke_vi(3367,($0|0));
   $15 = __THREW__; __THREW__ = 0;
  } else {
   $16 = ($13>>>0)<(11);
   if ($16) {
    $17 = $9&255;
    $18 = ((($0)) + 11|0);
    HEAP8[$18>>0] = $17;
    $$0$i = $0;
   } else {
    $19 = (($13) + 16)|0;
    $20 = $19 & -16;
    __THREW__ = 0;
    $21 = (invoke_ii(3276,($20|0))|0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    HEAP32[$0>>2] = $21;
    $24 = $20 | -2147483648;
    $25 = ((($0)) + 8|0);
    HEAP32[$25>>2] = $24;
    $26 = ((($0)) + 4|0);
    HEAP32[$26>>2] = $9;
    $$0$i = $21;
   }
   $27 = ($9|0)==(0);
   if (!($27)) {
    _memcpy(($$0$i|0),($12|0),($9|0))|0;
   }
   $28 = (($$0$i) + ($9)|0);
   HEAP8[$28>>0] = 0;
   __THREW__ = 0;
   (invoke_iiii(3544,($0|0),($2|0),($10|0))|0);
   $29 = __THREW__; __THREW__ = 0;
   $30 = $29&1;
   if (!($30)) {
    return;
   }
  }
 } while(0);
 $31 = ___cxa_find_matching_catch_2()|0;
 $32 = tempRet0;
 $33 = ((($0)) + 11|0);
 $34 = HEAP8[$33>>0]|0;
 $35 = ($34<<24>>24)<(0);
 if (!($35)) {
  ___resumeException($31|0);
  // unreachable;
 }
 $36 = HEAP32[$0>>2]|0;
 __ZdlPv($36);
 ___resumeException($31|0);
 // unreachable;
}
function __ZN5osgGA19StandardManipulator20allocateRelativeFlagEv() {
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[51985]|0;
 $1 = (($0) + 1)|0;
 HEAP32[51985] = $1;
 return ($0|0);
}
function __ZN5osgGA19StandardManipulatorC2Ei($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$cast = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($1)) + 4|0);
 __ZN5osgGA17CameraManipulatorC2Ev($0,$3);
 $4 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $4;
 $5 = ((($1)) + 76|0);
 $6 = HEAP32[$5>>2]|0;
 $$cast = $4;
 $7 = ((($$cast)) + -12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($0) + ($8)|0);
 HEAP32[$9>>2] = $6;
 $10 = ((($1)) + 80|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = HEAP32[$0>>2]|0;
 $13 = ((($12)) + -16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($0) + ($14)|0);
 HEAP32[$15>>2] = $11;
 $16 = ((($1)) + 84|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ((($0)) + 4|0);
 HEAP32[$18>>2] = $17;
 $19 = ((($0)) + 92|0);
 HEAP8[$19>>0] = 0;
 $20 = ((($0)) + 93|0);
 HEAP8[$20>>0] = 1;
 $21 = ((($0)) + 96|0);
 $22 = ((($0)) + 112|0);
 ;HEAP32[$21>>2]=0|0;HEAP32[$21+4>>2]=0|0;HEAP32[$21+8>>2]=0|0;HEAP32[$21+12>>2]=0|0;
 HEAPF64[$22>>3] = 0.01;
 $23 = ((($0)) + 120|0);
 HEAPF64[$23>>3] = 0.0;
 $24 = ((($0)) + 128|0);
 HEAP32[$24>>2] = 0;
 $25 = ((($0)) + 136|0);
 HEAPF64[$25>>3] = 0.0;
 $26 = ((($0)) + 144|0);
 HEAP8[$26>>0] = 1;
 $27 = ((($0)) + 148|0);
 HEAP32[$27>>2] = 0;
 $28 = ((($0)) + 152|0);
 HEAP32[$28>>2] = $2;
 $29 = ((($0)) + 156|0);
 HEAP32[$29>>2] = 0;
 return;
}
function __ZN5osgGA19StandardManipulatorC2ERKS0_RKN3osg6CopyOpE($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $$015 = 0, $$cast = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0.0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ((($1)) + 4|0);
 __ZN5osgGA17CameraManipulatorC2ERKS0_RKN3osg6CopyOpE($0,$4,$2,$3);
 $5 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $5;
 $6 = ((($1)) + 76|0);
 $7 = HEAP32[$6>>2]|0;
 $$cast = $5;
 $8 = ((($$cast)) + -12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($0) + ($9)|0);
 HEAP32[$10>>2] = $7;
 $11 = ((($1)) + 80|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = HEAP32[$0>>2]|0;
 $14 = ((($13)) + -16|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($0) + ($15)|0);
 HEAP32[$16>>2] = $12;
 $17 = ((($1)) + 84|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ((($0)) + 4|0);
 HEAP32[$19>>2] = $18;
 $20 = ((($0)) + 92|0);
 $21 = ((($2)) + 92|0);
 $22 = HEAP8[$21>>0]|0;
 HEAP8[$20>>0] = $22;
 $23 = ((($0)) + 93|0);
 $24 = ((($2)) + 93|0);
 $25 = HEAP8[$24>>0]|0;
 HEAP8[$23>>0] = $25;
 $26 = ((($0)) + 96|0);
 HEAPF32[$26>>2] = 0.0;
 $27 = ((($0)) + 100|0);
 HEAPF32[$27>>2] = 0.0;
 $28 = ((($0)) + 104|0);
 $29 = HEAP32[$3>>2]|0;
 $30 = ((($29)) + 12|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ((($2)) + 104|0);
 $33 = HEAP32[$32>>2]|0;
 __THREW__ = 0;
 $34 = (invoke_iii($31|0,($3|0),($33|0))|0);
 $35 = __THREW__; __THREW__ = 0;
 $36 = $35&1;
 do {
  if ($36) {
   $38 = ___cxa_find_matching_catch_2()|0;
   $39 = tempRet0;
   $$0 = $39;$$015 = $38;
  } else {
   $37 = ($34|0)==(0|0);
   if ($37) {
    HEAP32[$28>>2] = 0;
    $57 = $28;
   } else {
    $40 = (___dynamic_cast($34,26112,8944,0)|0);
    HEAP32[$28>>2] = $40;
    $41 = ($40|0)==(0|0);
    if ($41) {
     $57 = $28;
    } else {
     $42 = ((($40)) + 8|0);
     $43 = HEAP32[$42>>2]|0;HEAP32[$42>>2] = (($43+1)|0);
     $57 = $28;
    }
   }
   $44 = ((($0)) + 108|0);
   $45 = HEAP32[$3>>2]|0;
   $46 = ((($45)) + 12|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = ((($2)) + 108|0);
   $49 = HEAP32[$48>>2]|0;
   __THREW__ = 0;
   $50 = (invoke_iii($47|0,($3|0),($49|0))|0);
   $51 = __THREW__; __THREW__ = 0;
   $52 = $51&1;
   if ($52) {
    $54 = ___cxa_find_matching_catch_2()|0;
    $55 = tempRet0;
    $56 = HEAP32[$57>>2]|0;
    $58 = ($56|0)==(0|0);
    if (!($58)) {
     $59 = ((($56)) + 8|0);
     $60 = HEAP32[$59>>2]|0;HEAP32[$59>>2] = (($60-1)|0);
     $61 = ($60|0)==(1);
     if ($61) {
      __THREW__ = 0;
      invoke_viii(3262,($56|0),1,1);
      $62 = __THREW__; __THREW__ = 0;
      $63 = $62&1;
      if ($63) {
       $86 = ___cxa_find_matching_catch_3(0|0)|0;
       $87 = tempRet0;
       ___clang_call_terminate($86);
       // unreachable;
      }
     }
    }
    HEAP32[$57>>2] = 0;
    $$0 = $55;$$015 = $54;
    break;
   } else {
    $53 = ($50|0)==(0|0);
    if ($53) {
     HEAP32[$44>>2] = 0;
    } else {
     $64 = (___dynamic_cast($50,26112,8944,0)|0);
     HEAP32[$44>>2] = $64;
     $65 = ($64|0)==(0|0);
     if (!($65)) {
      $66 = ((($64)) + 8|0);
      $67 = HEAP32[$66>>2]|0;HEAP32[$66>>2] = (($67+1)|0);
     }
    }
    $68 = ((($0)) + 112|0);
    HEAPF64[$68>>3] = 0.01;
    $69 = ((($0)) + 120|0);
    HEAPF64[$69>>3] = 0.0;
    $70 = ((($0)) + 128|0);
    HEAP32[$70>>2] = 0;
    $71 = ((($0)) + 136|0);
    $72 = ((($2)) + 136|0);
    $73 = +HEAPF64[$72>>3];
    HEAPF64[$71>>3] = $73;
    $74 = ((($0)) + 144|0);
    $75 = ((($2)) + 144|0);
    $76 = HEAP8[$75>>0]|0;
    HEAP8[$74>>0] = $76;
    $77 = ((($0)) + 148|0);
    HEAP32[$77>>2] = 0;
    $78 = ((($0)) + 152|0);
    $79 = ((($2)) + 152|0);
    $80 = HEAP32[$79>>2]|0;
    HEAP32[$78>>2] = $80;
    $81 = ((($0)) + 156|0);
    $82 = ((($2)) + 156|0);
    $83 = HEAP32[$82>>2]|0;
    HEAP32[$81>>2] = $83;
    return;
   }
  }
 } while(0);
 __THREW__ = 0;
 invoke_vii(3525,($0|0),($4|0));
 $84 = __THREW__; __THREW__ = 0;
 $85 = $84&1;
 if ($85) {
  $86 = ___cxa_find_matching_catch_3(0|0)|0;
  $87 = tempRet0;
  ___clang_call_terminate($86);
  // unreachable;
 } else {
  ___resumeException($$015|0);
  // unreachable;
 }
}
function __ZNK5osgGA19StandardManipulator16getAnimationTimeEv($0) {
 $0 = $0|0;
 var $$0 = 0.0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 148|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  $$0 = 0.0;
  return (+$$0);
 }
 $4 = ((($2)) + 16|0);
 $5 = +HEAPF64[$4>>3];
 $$0 = $5;
 return (+$$0);
}
function __ZNK5osgGA19StandardManipulator11isAnimatingEv($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 148|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  $$0 = 0;
  return ($$0|0);
 }
 $4 = ((($2)) + 24|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)!=(0);
 $$0 = $6;
 return ($$0|0);
}
function __ZNK5osgGA19StandardManipulator13getThrowScaleEd($0,$1) {
 $0 = $0|0;
 $1 = +$1;
 var $$0 = 0.0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0.0, $8 = 0.0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 92|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  $$0 = 1.0;
  return (+$$0);
 }
 $5 = $1 == 0.0;
 if ($5) {
  $$0 = 0.0;
  return (+$$0);
 }
 $6 = ((($0)) + 112|0);
 $7 = +HEAPF64[$6>>3];
 $8 = $7 / $1;
 $9 = $8;
 $$0 = $9;
 return (+$$0);
}
function __ZN5osgGA19StandardManipulator14rotateYawPitchERN3osg4QuatEddRKNS1_5Vec3dE($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = +$1;
 $2 = +$2;
 $3 = $3|0;
 var $$024 = 0, $$025 = 0.0, $$pre = 0.0, $$pre$phi101Z2D = 0, $$pre$phi93Z2D = 0, $$pre$phi95Z2D = 0, $$pre$phi97Z2D = 0, $$pre$phiZ2D = 0, $$pre100 = 0, $$pre102 = 0, $$pre88 = 0.0, $$pre89 = 0.0, $$pre90 = 0.0, $$pre92 = 0, $$pre94 = 0, $$pre96 = 0, $$sink = 0.0, $10 = 0, $100 = 0.0, $101 = 0.0;
 var $102 = 0.0, $103 = 0.0, $104 = 0.0, $105 = 0.0, $106 = 0.0, $107 = 0.0, $108 = 0.0, $109 = 0.0, $11 = 0.0, $110 = 0.0, $111 = 0.0, $112 = 0.0, $113 = 0.0, $114 = 0.0, $115 = 0.0, $116 = 0.0, $117 = 0.0, $118 = 0.0, $119 = 0.0, $12 = 0;
 var $120 = 0.0, $121 = 0.0, $122 = 0.0, $123 = 0.0, $124 = 0.0, $125 = 0.0, $126 = 0.0, $127 = 0.0, $128 = 0.0, $129 = 0.0, $13 = 0, $130 = 0.0, $131 = 0.0, $132 = 0.0, $133 = 0.0, $134 = 0.0, $135 = 0.0, $136 = 0.0, $137 = 0.0, $138 = 0.0;
 var $139 = 0.0, $14 = 0.0, $140 = 0.0, $141 = 0.0, $142 = 0.0, $143 = 0.0, $144 = 0.0, $145 = 0.0, $146 = 0.0, $147 = 0.0, $148 = 0.0, $149 = 0.0, $15 = 0, $150 = 0.0, $151 = 0.0, $152 = 0.0, $153 = 0.0, $154 = 0.0, $155 = 0.0, $156 = 0.0;
 var $157 = 0.0, $158 = 0.0, $159 = 0.0, $16 = 0.0, $160 = 0.0, $161 = 0.0, $162 = 0.0, $163 = 0.0, $164 = 0.0, $165 = 0.0, $166 = 0.0, $167 = 0.0, $168 = 0.0, $169 = 0.0, $17 = 0.0, $170 = 0.0, $171 = 0.0, $172 = 0.0, $173 = 0.0, $174 = 0.0;
 var $175 = 0.0, $176 = 0.0, $177 = 0.0, $178 = 0.0, $179 = 0.0, $18 = 0.0, $180 = 0.0, $181 = 0.0, $182 = 0.0, $183 = 0.0, $184 = 0.0, $185 = 0.0, $186 = 0.0, $187 = 0.0, $188 = 0.0, $189 = 0.0, $19 = 0, $190 = 0.0, $191 = 0.0, $192 = 0.0;
 var $193 = 0.0, $194 = 0.0, $195 = 0.0, $196 = 0.0, $197 = 0.0, $198 = 0.0, $199 = 0.0, $20 = 0.0, $200 = 0.0, $201 = 0.0, $202 = 0.0, $203 = 0.0, $204 = 0.0, $205 = 0.0, $206 = 0, $207 = 0.0, $208 = 0, $209 = 0, $21 = 0, $210 = 0.0;
 var $211 = 0.0, $212 = 0.0, $213 = 0.0, $214 = 0.0, $215 = 0.0, $216 = 0.0, $217 = 0.0, $218 = 0.0, $219 = 0.0, $22 = 0.0, $220 = 0.0, $221 = 0.0, $222 = 0.0, $223 = 0.0, $224 = 0.0, $225 = 0.0, $226 = 0.0, $227 = 0.0, $228 = 0.0, $229 = 0.0;
 var $23 = 0.0, $230 = 0.0, $231 = 0.0, $232 = 0.0, $233 = 0.0, $234 = 0.0, $235 = 0.0, $236 = 0.0, $237 = 0.0, $238 = 0.0, $239 = 0.0, $24 = 0.0, $240 = 0.0, $241 = 0.0, $242 = 0.0, $243 = 0.0, $244 = 0.0, $245 = 0.0, $246 = 0, $247 = 0;
 var $248 = 0, $25 = 0.0, $26 = 0.0, $27 = 0.0, $28 = 0.0, $29 = 0.0, $30 = 0.0, $31 = 0.0, $32 = 0.0, $33 = 0.0, $34 = 0.0, $35 = 0.0, $36 = 0.0, $37 = 0.0, $38 = 0, $39 = 0.0, $4 = 0, $40 = 0.0, $41 = 0.0, $42 = 0.0;
 var $43 = 0.0, $44 = 0.0, $45 = 0.0, $46 = 0.0, $47 = 0.0, $48 = 0.0, $49 = 0.0, $5 = 0, $50 = 0.0, $51 = 0.0, $52 = 0.0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0.0, $58 = 0.0, $59 = 0.0, $6 = 0, $60 = 0.0;
 var $61 = 0.0, $62 = 0.0, $63 = 0.0, $64 = 0.0, $65 = 0.0, $66 = 0.0, $67 = 0.0, $68 = 0.0, $69 = 0.0, $7 = 0, $70 = 0.0, $71 = 0.0, $72 = 0.0, $73 = 0.0, $74 = 0.0, $75 = 0.0, $76 = 0.0, $77 = 0.0, $78 = 0.0, $79 = 0.0;
 var $8 = 0, $80 = 0.0, $81 = 0.0, $82 = 0.0, $83 = 0.0, $84 = 0.0, $85 = 0.0, $86 = 0.0, $87 = 0.0, $88 = 0.0, $89 = 0, $9 = 0.0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0.0, $99 = 0.0, $or$cond = 0, $storemerge = 0.0, $storemerge103 = 0.0, $storemerge104 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(144|0);
 $4 = sp + 112|0;
 $5 = sp + 88|0;
 $6 = sp + 56|0;
 $7 = sp + 24|0;
 $8 = sp;
 $9 = +HEAPF64[$3>>3];
 $10 = $9 != 0.0;
 $$pre102 = ((($3)) + 8|0);
 $11 = +HEAPF64[$$pre102>>3];
 $12 = $11 != 0.0;
 $or$cond = $10 | $12;
 if ($or$cond) {
  label = 3;
 } else {
  $13 = ((($3)) + 16|0);
  $14 = +HEAPF64[$13>>3];
  $15 = $14 != 0.0;
  if ($15) {
   label = 3;
  } else {
   $17 = -$1;
   $18 = +HEAPF64[$0>>3];
   $19 = ((($0)) + 8|0);
   $20 = +HEAPF64[$19>>3];
   $21 = ((($0)) + 16|0);
   $22 = +HEAPF64[$21>>3];
   $23 = $20 * 0.0;
   $24 = $23 - $22;
   $25 = $22 * 0.0;
   $26 = $18 * 0.0;
   $27 = $25 - $26;
   $28 = $18 - $23;
   $29 = $20 * $28;
   $30 = $22 * $27;
   $31 = $29 - $30;
   $32 = $22 * $24;
   $33 = $18 * $28;
   $34 = $32 - $33;
   $35 = $18 * $27;
   $36 = $20 * $24;
   $37 = $35 - $36;
   $38 = ((($0)) + 24|0);
   $39 = +HEAPF64[$38>>3];
   $40 = $39 * 2.0;
   $41 = $24 * $40;
   $42 = $27 * $40;
   $43 = $28 * $40;
   $44 = $31 * 2.0;
   $45 = $34 * 2.0;
   $46 = $37 * 2.0;
   $47 = $41 + 0.0;
   $48 = $42 + 1.0;
   $49 = $43 + 0.0;
   $50 = $47 + $44;
   $51 = $48 + $45;
   $52 = $49 + $46;
   HEAPF64[$5>>3] = $50;
   $53 = ((($5)) + 8|0);
   HEAPF64[$53>>3] = $51;
   $54 = ((($5)) + 16|0);
   HEAPF64[$54>>3] = $52;
   __ZN3osg4Quat10makeRotateEdRKNS_5Vec3dE($4,$17,$5);
   $$pre$phi101Z2D = $13;$$pre$phi93Z2D = $19;$$pre$phi95Z2D = $21;$$pre$phi97Z2D = $38;$$pre$phiZ2D = $0;$246 = $5;$247 = $4;$248 = 0;
  }
 }
 if ((label|0) == 3) {
  __ZN5osgGA19StandardManipulator15fixVerticalAxisERN3osg4QuatERKNS1_5Vec3dEb($0,$3,1);
  $16 = -$1;
  ;HEAP32[$5>>2]=HEAP32[$3>>2]|0;HEAP32[$5+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$3+12>>2]|0;HEAP32[$5+16>>2]=HEAP32[$3+16>>2]|0;HEAP32[$5+20>>2]=HEAP32[$3+20>>2]|0;
  __ZN3osg4Quat10makeRotateEdRKNS_5Vec3dE($4,$16,$5);
  $$pre92 = ((($0)) + 8|0);
  $$pre94 = ((($0)) + 16|0);
  $$pre96 = ((($0)) + 24|0);
  $$pre100 = ((($3)) + 16|0);
  $$pre$phi101Z2D = $$pre100;$$pre$phi93Z2D = $$pre92;$$pre$phi95Z2D = $$pre94;$$pre$phi97Z2D = $$pre96;$$pre$phiZ2D = $0;$246 = $5;$247 = $4;$248 = 1;
 }
 $55 = ((($6)) + 24|0);
 ;HEAP32[$6>>2]=0|0;HEAP32[$6+4>>2]=0|0;HEAP32[$6+8>>2]=0|0;HEAP32[$6+12>>2]=0|0;HEAP32[$6+16>>2]=0|0;HEAP32[$6+20>>2]=0|0;
 HEAPF64[$55>>3] = 1.0;
 $56 = ((($7)) + 24|0);
 ;HEAP32[$7>>2]=0|0;HEAP32[$7+4>>2]=0|0;HEAP32[$7+8>>2]=0|0;HEAP32[$7+12>>2]=0|0;HEAP32[$7+16>>2]=0|0;HEAP32[$7+20>>2]=0|0;
 HEAPF64[$56>>3] = 1.0;
 $57 = +HEAPF64[$$pre$phiZ2D>>3];
 $58 = +HEAPF64[$$pre$phi93Z2D>>3];
 $59 = +HEAPF64[$$pre$phi95Z2D>>3];
 $60 = $58 * 0.0;
 $61 = $59 * 0.0;
 $62 = $60 - $61;
 $63 = $57 * 0.0;
 $64 = $59 - $63;
 $65 = $63 - $58;
 $66 = $58 * $65;
 $67 = $59 * $64;
 $68 = $66 - $67;
 $69 = $59 * $62;
 $70 = $57 * $65;
 $71 = $69 - $70;
 $72 = $57 * $64;
 $73 = $58 * $62;
 $74 = $72 - $73;
 $75 = +HEAPF64[$$pre$phi97Z2D>>3];
 $76 = $75 * 2.0;
 $77 = $62 * $76;
 $78 = $64 * $76;
 $79 = $65 * $76;
 $80 = $68 * 2.0;
 $81 = $71 * 2.0;
 $82 = $74 * 2.0;
 $83 = $77 + 1.0;
 $84 = $78 + 0.0;
 $85 = $79 + 0.0;
 $86 = $83 + $80;
 $87 = $84 + $81;
 $88 = $85 + $82;
 HEAPF64[$8>>3] = $86;
 $89 = ((($8)) + 8|0);
 HEAPF64[$89>>3] = $87;
 $90 = ((($8)) + 16|0);
 HEAPF64[$90>>3] = $88;
 $91 = ((($4)) + 24|0);
 $92 = ((($4)) + 8|0);
 $93 = ((($4)) + 16|0);
 $94 = ((($6)) + 8|0);
 $95 = ((($6)) + 16|0);
 $96 = ((($7)) + 8|0);
 $97 = ((($7)) + 16|0);
 $$024 = 0;$$025 = $2;
 while(1) {
  __ZN3osg4Quat10makeRotateEdRKNS_5Vec3dE($6,$$025,$8);
  $98 = +HEAPF64[$91>>3];
  $99 = +HEAPF64[$$pre$phiZ2D>>3];
  $100 = $98 * $99;
  $101 = +HEAPF64[$4>>3];
  $102 = +HEAPF64[$$pre$phi97Z2D>>3];
  $103 = $101 * $102;
  $104 = $100 + $103;
  $105 = +HEAPF64[$92>>3];
  $106 = +HEAPF64[$$pre$phi95Z2D>>3];
  $107 = $105 * $106;
  $108 = $104 + $107;
  $109 = +HEAPF64[$93>>3];
  $110 = +HEAPF64[$$pre$phi93Z2D>>3];
  $111 = $109 * $110;
  $112 = $108 - $111;
  $113 = $98 * $110;
  $114 = $101 * $106;
  $115 = $113 - $114;
  $116 = $102 * $105;
  $117 = $116 + $115;
  $118 = $99 * $109;
  $119 = $118 + $117;
  $120 = $98 * $106;
  $121 = $101 * $110;
  $122 = $120 + $121;
  $123 = $99 * $105;
  $124 = $122 - $123;
  $125 = $102 * $109;
  $126 = $125 + $124;
  $127 = $98 * $102;
  $128 = $99 * $101;
  $129 = $127 - $128;
  $130 = $105 * $110;
  $131 = $129 - $130;
  $132 = $106 * $109;
  $133 = $131 - $132;
  $134 = +HEAPF64[$55>>3];
  $135 = $134 * $112;
  $136 = +HEAPF64[$6>>3];
  $137 = $136 * $133;
  $138 = $135 + $137;
  $139 = +HEAPF64[$94>>3];
  $140 = $139 * $126;
  $141 = $138 + $140;
  $142 = +HEAPF64[$95>>3];
  $143 = $142 * $119;
  $144 = $141 - $143;
  $145 = $134 * $119;
  $146 = $136 * $126;
  $147 = $145 - $146;
  $148 = $133 * $139;
  $149 = $148 + $147;
  $150 = $112 * $142;
  $151 = $150 + $149;
  $152 = $134 * $126;
  $153 = $136 * $119;
  $154 = $152 + $153;
  $155 = $112 * $139;
  $156 = $154 - $155;
  $157 = $133 * $142;
  $158 = $157 + $156;
  $159 = $134 * $133;
  $160 = $112 * $136;
  $161 = $159 - $160;
  $162 = $139 * $119;
  $163 = $161 - $162;
  $164 = $126 * $142;
  $165 = $163 - $164;
  HEAPF64[$7>>3] = $144;
  HEAPF64[$96>>3] = $151;
  HEAPF64[$97>>3] = $158;
  HEAPF64[$56>>3] = $165;
  if ($248) {
   __ZN5osgGA19StandardManipulator15fixVerticalAxisERN3osg4QuatERKNS1_5Vec3dEb($7,$3,0);
   $$pre = +HEAPF64[$7>>3];
   $$pre88 = +HEAPF64[$96>>3];
   $$pre89 = +HEAPF64[$97>>3];
   $$pre90 = +HEAPF64[$56>>3];
   $167 = $$pre88;$169 = $$pre89;$172 = $$pre;$185 = $$pre90;
  } else {
   $167 = $151;$169 = $158;$172 = $144;$185 = $165;
  }
  $166 = $167 * 0.0;
  $168 = $166 - $169;
  $170 = $169 * 0.0;
  $171 = $172 * 0.0;
  $173 = $170 - $171;
  $174 = $172 - $166;
  $175 = $167 * $174;
  $176 = $169 * $173;
  $177 = $175 - $176;
  $178 = $169 * $168;
  $179 = $172 * $174;
  $180 = $178 - $179;
  $181 = $172 * $173;
  $182 = $167 * $168;
  $183 = $181 - $182;
  $184 = $185 * 2.0;
  $186 = $168 * $184;
  $187 = $173 * $184;
  $188 = $174 * $184;
  $189 = $177 * 2.0;
  $190 = $180 * 2.0;
  $191 = $183 * 2.0;
  $192 = $186 + 0.0;
  $193 = $187 + 1.0;
  $194 = $188 + 0.0;
  $195 = $192 + $189;
  $196 = $193 + $190;
  $197 = $194 + $191;
  $198 = +HEAPF64[$3>>3];
  $199 = $198 * $195;
  $200 = +HEAPF64[$$pre102>>3];
  $201 = $200 * $196;
  $202 = $201 + $199;
  $203 = +HEAPF64[$$pre$phi101Z2D>>3];
  $204 = $203 * $197;
  $205 = $204 + $202;
  $206 = $205 > 0.0;
  if ($206) {
   $$sink = $185;$storemerge = $169;$storemerge103 = $167;$storemerge104 = $172;
   label = 11;
   break;
  }
  $207 = $$025 * 0.5;
  $208 = (($$024) + 1)|0;
  $209 = ($208|0)==(20);
  if ($209) {
   break;
  } else {
   $$024 = $208;$$025 = $207;
  }
 }
 if ((label|0) == 11) {
  HEAPF64[$$pre$phiZ2D>>3] = $storemerge104;
  HEAPF64[$$pre$phi93Z2D>>3] = $storemerge103;
  HEAPF64[$$pre$phi95Z2D>>3] = $storemerge;
  HEAPF64[$$pre$phi97Z2D>>3] = $$sink;
  STACKTOP = sp;return;
 }
 $210 = +HEAPF64[$91>>3];
 $211 = +HEAPF64[$$pre$phiZ2D>>3];
 $212 = $210 * $211;
 $213 = +HEAPF64[$4>>3];
 $214 = +HEAPF64[$$pre$phi97Z2D>>3];
 $215 = $213 * $214;
 $216 = $212 + $215;
 $217 = +HEAPF64[$92>>3];
 $218 = +HEAPF64[$$pre$phi95Z2D>>3];
 $219 = $217 * $218;
 $220 = $216 + $219;
 $221 = +HEAPF64[$93>>3];
 $222 = +HEAPF64[$$pre$phi93Z2D>>3];
 $223 = $221 * $222;
 $224 = $220 - $223;
 $225 = $210 * $222;
 $226 = $213 * $218;
 $227 = $225 - $226;
 $228 = $214 * $217;
 $229 = $228 + $227;
 $230 = $211 * $221;
 $231 = $230 + $229;
 $232 = $210 * $218;
 $233 = $213 * $222;
 $234 = $232 + $233;
 $235 = $211 * $217;
 $236 = $234 - $235;
 $237 = $214 * $221;
 $238 = $237 + $236;
 $239 = $210 * $214;
 $240 = $211 * $213;
 $241 = $239 - $240;
 $242 = $217 * $222;
 $243 = $241 - $242;
 $244 = $218 * $221;
 $245 = $243 - $244;
 $$sink = $245;$storemerge = $238;$storemerge103 = $231;$storemerge104 = $224;
 HEAPF64[$$pre$phiZ2D>>3] = $storemerge104;
 HEAPF64[$$pre$phi93Z2D>>3] = $storemerge103;
 HEAPF64[$$pre$phi95Z2D>>3] = $storemerge;
 HEAPF64[$$pre$phi97Z2D>>3] = $$sink;
 STACKTOP = sp;return;
}
function __ZN5osgGA19StandardManipulator15fixVerticalAxisERN3osg4QuatERKNS1_5Vec3dEb($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$ = 0, $10 = 0.0, $100 = 0.0, $101 = 0.0, $102 = 0.0, $103 = 0.0, $104 = 0.0, $105 = 0.0, $106 = 0.0, $107 = 0.0, $108 = 0.0, $109 = 0.0, $11 = 0, $110 = 0, $111 = 0, $112 = 0.0, $113 = 0.0, $114 = 0.0, $115 = 0.0, $116 = 0.0;
 var $117 = 0.0, $118 = 0.0, $119 = 0.0, $12 = 0.0, $120 = 0.0, $121 = 0, $122 = 0, $123 = 0.0, $124 = 0.0, $125 = 0.0, $126 = 0.0, $127 = 0.0, $128 = 0.0, $129 = 0.0, $13 = 0, $130 = 0.0, $131 = 0.0, $132 = 0.0, $133 = 0, $134 = 0.0;
 var $135 = 0.0, $136 = 0, $137 = 0.0, $138 = 0.0, $139 = 0.0, $14 = 0.0, $140 = 0, $141 = 0.0, $142 = 0.0, $143 = 0.0, $144 = 0, $145 = 0.0, $146 = 0.0, $147 = 0.0, $148 = 0, $149 = 0.0, $15 = 0.0, $150 = 0.0, $151 = 0.0, $152 = 0.0;
 var $153 = 0.0, $154 = 0.0, $155 = 0.0, $156 = 0, $157 = 0.0, $158 = 0.0, $159 = 0.0, $16 = 0.0, $160 = 0.0, $161 = 0, $162 = 0.0, $163 = 0.0, $164 = 0.0, $165 = 0.0, $166 = 0.0, $167 = 0.0, $168 = 0.0, $169 = 0.0, $17 = 0.0, $170 = 0.0;
 var $171 = 0.0, $172 = 0.0, $173 = 0.0, $174 = 0.0, $175 = 0.0, $176 = 0.0, $177 = 0.0, $178 = 0.0, $179 = 0.0, $18 = 0.0, $180 = 0.0, $181 = 0.0, $182 = 0.0, $183 = 0.0, $184 = 0.0, $185 = 0.0, $186 = 0.0, $187 = 0.0, $188 = 0.0, $189 = 0.0;
 var $19 = 0.0, $190 = 0.0, $191 = 0.0, $192 = 0.0, $193 = 0.0, $194 = 0.0, $195 = 0.0, $196 = 0.0, $197 = 0.0, $198 = 0.0, $199 = 0.0, $20 = 0.0, $200 = 0.0, $201 = 0.0, $202 = 0.0, $203 = 0.0, $204 = 0.0, $205 = 0.0, $206 = 0.0, $207 = 0;
 var $208 = 0, $209 = 0.0, $21 = 0.0, $210 = 0.0, $211 = 0.0, $212 = 0.0, $213 = 0, $214 = 0.0, $215 = 0.0, $216 = 0.0, $217 = 0.0, $218 = 0, $219 = 0.0, $22 = 0.0, $220 = 0.0, $221 = 0.0, $222 = 0.0, $223 = 0, $224 = 0.0, $225 = 0.0;
 var $226 = 0.0, $227 = 0.0, $228 = 0.0, $229 = 0.0, $23 = 0.0, $230 = 0.0, $231 = 0.0, $232 = 0.0, $233 = 0.0, $234 = 0.0, $235 = 0.0, $236 = 0.0, $237 = 0.0, $238 = 0.0, $239 = 0.0, $24 = 0.0, $240 = 0.0, $241 = 0.0, $242 = 0.0, $243 = 0.0;
 var $244 = 0.0, $245 = 0.0, $246 = 0.0, $247 = 0.0, $25 = 0.0, $26 = 0.0, $27 = 0.0, $28 = 0.0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0.0, $32 = 0.0, $33 = 0.0, $34 = 0.0, $35 = 0.0, $36 = 0.0, $37 = 0.0, $38 = 0.0, $39 = 0.0;
 var $4 = 0, $40 = 0.0, $41 = 0.0, $42 = 0.0, $43 = 0.0, $44 = 0.0, $45 = 0.0, $46 = 0.0, $47 = 0.0, $48 = 0.0, $49 = 0.0, $5 = 0, $50 = 0.0, $51 = 0.0, $52 = 0.0, $53 = 0.0, $54 = 0.0, $55 = 0.0, $56 = 0.0, $57 = 0.0;
 var $58 = 0.0, $59 = 0.0, $6 = 0, $60 = 0.0, $61 = 0.0, $62 = 0.0, $63 = 0.0, $64 = 0.0, $65 = 0.0, $66 = 0.0, $67 = 0.0, $68 = 0.0, $69 = 0, $7 = 0, $70 = 0, $71 = 0.0, $72 = 0.0, $73 = 0.0, $74 = 0.0, $75 = 0.0;
 var $76 = 0.0, $77 = 0.0, $78 = 0.0, $79 = 0.0, $8 = 0, $80 = 0.0, $81 = 0.0, $82 = 0.0, $83 = 0.0, $84 = 0.0, $85 = 0.0, $86 = 0.0, $87 = 0.0, $88 = 0.0, $89 = 0.0, $9 = 0, $90 = 0.0, $91 = 0.0, $92 = 0.0, $93 = 0.0;
 var $94 = 0.0, $95 = 0.0, $96 = 0, $97 = 0.0, $98 = 0.0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 192|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(192|0);
 $3 = sp + 160|0;
 $4 = sp + 136|0;
 $5 = sp + 112|0;
 $6 = sp + 88|0;
 $7 = sp + 56|0;
 $8 = sp + 24|0;
 $9 = sp;
 $10 = +HEAPF64[$0>>3];
 $11 = ((($0)) + 8|0);
 $12 = +HEAPF64[$11>>3];
 $13 = ((($0)) + 16|0);
 $14 = +HEAPF64[$13>>3];
 $15 = $12 * 0.0;
 $16 = $15 - $14;
 $17 = $14 * 0.0;
 $18 = $10 * 0.0;
 $19 = $17 - $18;
 $20 = $10 - $15;
 $21 = $12 * $20;
 $22 = $14 * $19;
 $23 = $21 - $22;
 $24 = $14 * $16;
 $25 = $10 * $20;
 $26 = $24 - $25;
 $27 = $10 * $19;
 $28 = $12 * $16;
 $29 = $27 - $28;
 $30 = ((($0)) + 24|0);
 $31 = +HEAPF64[$30>>3];
 $32 = $31 * 2.0;
 $33 = $16 * $32;
 $34 = $19 * $32;
 $35 = $20 * $32;
 $36 = $23 * 2.0;
 $37 = $26 * 2.0;
 $38 = $29 * 2.0;
 $39 = $33 + 0.0;
 $40 = $34 + 1.0;
 $41 = $35 + 0.0;
 $42 = $39 + $36;
 $43 = $40 + $37;
 $44 = $41 + $38;
 $45 = $15 - $17;
 $46 = $14 - $18;
 $47 = $18 - $12;
 $48 = $12 * $47;
 $49 = $14 * $46;
 $50 = $48 - $49;
 $51 = $14 * $45;
 $52 = $10 * $47;
 $53 = $51 - $52;
 $54 = $10 * $46;
 $55 = $12 * $45;
 $56 = $54 - $55;
 $57 = $45 * $32;
 $58 = $46 * $32;
 $59 = $47 * $32;
 $60 = $50 * 2.0;
 $61 = $53 * 2.0;
 $62 = $56 * 2.0;
 $63 = $57 + 1.0;
 $64 = $58 + 0.0;
 $65 = $59 + 0.0;
 $66 = $63 + $60;
 $67 = $64 + $61;
 $68 = $65 + $62;
 HEAPF64[$3>>3] = $66;
 $69 = ((($3)) + 8|0);
 HEAPF64[$69>>3] = $67;
 $70 = ((($3)) + 16|0);
 HEAPF64[$70>>3] = $68;
 $71 = -$12;
 $72 = $71 - $17;
 $73 = $10 + $17;
 $74 = $18 - $15;
 $75 = $12 * $74;
 $76 = $14 * $73;
 $77 = $75 - $76;
 $78 = $14 * $72;
 $79 = $10 * $74;
 $80 = $78 - $79;
 $81 = $10 * $73;
 $82 = $12 * $72;
 $83 = $81 - $82;
 $84 = $72 * $32;
 $85 = $73 * $32;
 $86 = $74 * $32;
 $87 = $77 * 2.0;
 $88 = $80 * 2.0;
 $89 = $83 * 2.0;
 $90 = $84 + 0.0;
 $91 = $85 + 0.0;
 $92 = $86 + -1.0;
 $93 = $90 + $87;
 $94 = $91 + $88;
 $95 = $92 + $89;
 $96 = ((($1)) + 16|0);
 $97 = +HEAPF64[$96>>3];
 $98 = $97 * $94;
 $99 = ((($1)) + 8|0);
 $100 = +HEAPF64[$99>>3];
 $101 = $100 * $95;
 $102 = $98 - $101;
 $103 = +HEAPF64[$1>>3];
 $104 = $103 * $95;
 $105 = $97 * $93;
 $106 = $104 - $105;
 $107 = $100 * $93;
 $108 = $103 * $94;
 $109 = $107 - $108;
 HEAPF64[$4>>3] = $102;
 $110 = ((($4)) + 8|0);
 HEAPF64[$110>>3] = $106;
 $111 = ((($4)) + 16|0);
 HEAPF64[$111>>3] = $109;
 $112 = $43 * $97;
 $113 = $44 * $100;
 $114 = $112 - $113;
 $115 = $44 * $103;
 $116 = $42 * $97;
 $117 = $115 - $116;
 $118 = $42 * $100;
 $119 = $43 * $103;
 $120 = $118 - $119;
 HEAPF64[$5>>3] = $114;
 $121 = ((($5)) + 8|0);
 HEAPF64[$121>>3] = $117;
 $122 = ((($5)) + 16|0);
 HEAPF64[$122>>3] = $120;
 $123 = $102 * $102;
 $124 = $106 * $106;
 $125 = $123 + $124;
 $126 = $109 * $109;
 $127 = $125 + $126;
 $128 = $114 * $114;
 $129 = $117 * $117;
 $130 = $128 + $129;
 $131 = $120 * $120;
 $132 = $130 + $131;
 $133 = $127 > $132;
 $$ = $133 ? $4 : $5;
 ;HEAP32[$6>>2]=HEAP32[$$>>2]|0;HEAP32[$6+4>>2]=HEAP32[$$+4>>2]|0;HEAP32[$6+8>>2]=HEAP32[$$+8>>2]|0;HEAP32[$6+12>>2]=HEAP32[$$+12>>2]|0;HEAP32[$6+16>>2]=HEAP32[$$+16>>2]|0;HEAP32[$6+20>>2]=HEAP32[$$+20>>2]|0;
 $134 = +HEAPF64[$6>>3];
 $135 = $134 * $66;
 $136 = ((($6)) + 8|0);
 $137 = +HEAPF64[$136>>3];
 $138 = $137 * $67;
 $139 = $135 + $138;
 $140 = ((($6)) + 16|0);
 $141 = +HEAPF64[$140>>3];
 $142 = $141 * $68;
 $143 = $139 + $142;
 $144 = $143 < 0.0;
 if ($144) {
  $145 = -$141;
  $146 = -$137;
  $147 = -$134;
  HEAPF64[$6>>3] = $147;
  HEAPF64[$136>>3] = $146;
  HEAPF64[$140>>3] = $145;
 }
 $148 = ((($7)) + 24|0);
 ;HEAP32[$7>>2]=0|0;HEAP32[$7+4>>2]=0|0;HEAP32[$7+8>>2]=0|0;HEAP32[$7+12>>2]=0|0;HEAP32[$7+16>>2]=0|0;HEAP32[$7+20>>2]=0|0;
 HEAPF64[$148>>3] = 1.0;
 __ZN3osg4Quat10makeRotateERKNS_5Vec3dES3_($7,$3,$6);
 $149 = +HEAPF64[$148>>3];
 $150 = +HEAPF64[$0>>3];
 $151 = $149 * $150;
 $152 = +HEAPF64[$7>>3];
 $153 = +HEAPF64[$30>>3];
 $154 = $152 * $153;
 $155 = $151 + $154;
 $156 = ((($7)) + 8|0);
 $157 = +HEAPF64[$156>>3];
 $158 = +HEAPF64[$13>>3];
 $159 = $157 * $158;
 $160 = $155 + $159;
 $161 = ((($7)) + 16|0);
 $162 = +HEAPF64[$161>>3];
 $163 = +HEAPF64[$11>>3];
 $164 = $162 * $163;
 $165 = $160 - $164;
 $166 = $149 * $163;
 $167 = $152 * $158;
 $168 = $166 - $167;
 $169 = $153 * $157;
 $170 = $169 + $168;
 $171 = $150 * $162;
 $172 = $171 + $170;
 $173 = $149 * $158;
 $174 = $152 * $163;
 $175 = $173 + $174;
 $176 = $150 * $157;
 $177 = $175 - $176;
 $178 = $153 * $162;
 $179 = $178 + $177;
 $180 = $149 * $153;
 $181 = $150 * $152;
 $182 = $180 - $181;
 $183 = $157 * $163;
 $184 = $182 - $183;
 $185 = $158 * $162;
 $186 = $184 - $185;
 HEAPF64[$30>>3] = $186;
 HEAPF64[$13>>3] = $179;
 HEAPF64[$11>>3] = $172;
 HEAPF64[$0>>3] = $165;
 if (!($2)) {
  STACKTOP = sp;return;
 }
 $187 = +HEAPF64[$136>>3];
 $188 = $95 * $187;
 $189 = +HEAPF64[$140>>3];
 $190 = $94 * $189;
 $191 = $188 - $190;
 $192 = $93 * $189;
 $193 = +HEAPF64[$6>>3];
 $194 = $95 * $193;
 $195 = $192 - $194;
 $196 = $94 * $193;
 $197 = $93 * $187;
 $198 = $196 - $197;
 $199 = +HEAPF64[$1>>3];
 $200 = $191 * $199;
 $201 = +HEAPF64[$99>>3];
 $202 = $195 * $201;
 $203 = $200 + $202;
 $204 = +HEAPF64[$96>>3];
 $205 = $198 * $204;
 $206 = $203 + $205;
 $207 = $206 < 0.0;
 if (!($207)) {
  STACKTOP = sp;return;
 }
 $208 = ((($9)) + 16|0);
 ;HEAP32[$9>>2]=0|0;HEAP32[$9+4>>2]=0|0;HEAP32[$9+8>>2]=0|0;HEAP32[$9+12>>2]=0|0;
 HEAPF64[$208>>3] = 1.0;
 __ZN3osg4Quat10makeRotateEdRKNS_5Vec3dE($8,3.1415926535897931,$9);
 $209 = +HEAPF64[$30>>3];
 $210 = +HEAPF64[$8>>3];
 $211 = $209 * $210;
 $212 = +HEAPF64[$0>>3];
 $213 = ((($8)) + 24|0);
 $214 = +HEAPF64[$213>>3];
 $215 = $212 * $214;
 $216 = $211 + $215;
 $217 = +HEAPF64[$11>>3];
 $218 = ((($8)) + 16|0);
 $219 = +HEAPF64[$218>>3];
 $220 = $217 * $219;
 $221 = $216 + $220;
 $222 = +HEAPF64[$13>>3];
 $223 = ((($8)) + 8|0);
 $224 = +HEAPF64[$223>>3];
 $225 = $222 * $224;
 $226 = $221 - $225;
 $227 = $209 * $224;
 $228 = $212 * $219;
 $229 = $227 - $228;
 $230 = $214 * $217;
 $231 = $230 + $229;
 $232 = $210 * $222;
 $233 = $232 + $231;
 $234 = $209 * $219;
 $235 = $212 * $224;
 $236 = $234 + $235;
 $237 = $210 * $217;
 $238 = $236 - $237;
 $239 = $214 * $222;
 $240 = $239 + $238;
 $241 = $209 * $214;
 $242 = $210 * $212;
 $243 = $241 - $242;
 $244 = $217 * $224;
 $245 = $243 - $244;
 $246 = $219 * $222;
 $247 = $245 - $246;
 HEAPF64[$0>>3] = $226;
 HEAPF64[$11>>3] = $233;
 HEAPF64[$13>>3] = $240;
 HEAPF64[$30>>3] = $247;
 STACKTOP = sp;return;
}
function __ZN5osgGA19StandardManipulator15fixVerticalAxisERN3osg5Vec3dERNS1_4QuatEb($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0.0, $14 = 0, $15 = 0.0, $16 = 0, $17 = 0.0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(160|0);
 $4 = sp + 24|0;
 $5 = sp;
 $6 = ((($0)) + 88|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if ($8) {
  __ZN3osg7Matrixd12makeIdentityEv($4);
 } else {
  $9 = HEAP32[$7>>2]|0;
  $10 = ((($9)) + 12|0);
  $11 = HEAP32[$10>>2]|0;
  FUNCTION_TABLE_viii[$11 & 8191]($4,$7,$1);
 }
 $12 = ((($4)) + 64|0);
 $13 = +HEAPF64[$12>>3];
 $14 = ((($4)) + 72|0);
 $15 = +HEAPF64[$14>>3];
 $16 = ((($4)) + 80|0);
 $17 = +HEAPF64[$16>>3];
 HEAPF64[$5>>3] = $13;
 $18 = ((($5)) + 8|0);
 HEAPF64[$18>>3] = $15;
 $19 = ((($5)) + 16|0);
 HEAPF64[$19>>3] = $17;
 __THREW__ = 0;
 invoke_viii(3545,($2|0),($5|0),($3|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if ($21) {
  $22 = ___cxa_find_matching_catch_2()|0;
  $23 = tempRet0;
  ___resumeException($22|0);
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN5osgGA19StandardManipulator13AnimationDataC2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg10ReferencedC2Ev($0);
 HEAP32[$0>>2] = (46544);
 $1 = ((($0)) + 16|0);
 HEAPF64[$1>>3] = 0.0;
 $2 = ((($0)) + 24|0);
 HEAP8[$2>>0] = 0;
 $3 = ((($0)) + 32|0);
 ;HEAP32[$3>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;HEAP32[$3+12>>2]=0|0;
 return;
}
function __ZN5osgGA19StandardManipulator13AnimationDataD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZN5osgGA19StandardManipulator13AnimationData5startEd($0,$1) {
 $0 = $0|0;
 $1 = +$1;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 24|0);
 HEAP8[$2>>0] = 1;
 $3 = ((($0)) + 32|0);
 HEAPF64[$3>>3] = $1;
 $4 = ((($0)) + 40|0);
 HEAPF64[$4>>3] = 0.0;
 return;
}
function __ZN7osgUtil16GLObjectsVisitorD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vii(3503,($0|0),(47052|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  $3 = ((($0)) + 124|0);
  __ZN3osg6ObjectD2Ev($3);
  return;
 }
 $4 = ___cxa_find_matching_catch_2()|0;
 $5 = tempRet0;
 $6 = ((($0)) + 124|0);
 __THREW__ = 0;
 invoke_vi(388,($6|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch_3(0|0)|0;
  $10 = tempRet0;
  ___clang_call_terminate($9);
  // unreachable;
 } else {
  ___resumeException($4|0);
  // unreachable;
 }
}
function __ZN7osgUtil16GLObjectsVisitorD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vii(3503,($0|0),(47052|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $6 = ___cxa_find_matching_catch_2()|0;
  $7 = tempRet0;
  $8 = ((($0)) + 124|0);
  __THREW__ = 0;
  invoke_vi(388,($8|0));
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if ($10) {
   $11 = ___cxa_find_matching_catch_3(0|0)|0;
   $12 = tempRet0;
   ___clang_call_terminate($11);
   // unreachable;
  } else {
   $eh$lpad$body$index2Z2D = $7;$eh$lpad$body$indexZ2D = $6;
   __ZdlPv($0);
   ___resumeException($eh$lpad$body$indexZ2D|0);
   // unreachable;
  }
 }
 $3 = ((($0)) + 124|0);
 __THREW__ = 0;
 invoke_vi(388,($3|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  __ZdlPv($0);
  return;
 }
 $13 = ___cxa_find_matching_catch_2()|0;
 $14 = tempRet0;
 $eh$lpad$body$index2Z2D = $14;$eh$lpad$body$indexZ2D = $13;
 __ZdlPv($0);
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
}
function __ZNK7osgUtil16GLObjectsVisitor11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (116801|0);
}
function __ZNK7osgUtil16GLObjectsVisitor9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (110471|0);
}
function __ZN7osgUtil16GLObjectsVisitor5resetEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 96|0);
 $2 = ((($0)) + 100|0);
 $3 = HEAP32[$2>>2]|0;
 __ZNSt3__26__treeIPN3osg8DrawableENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($1,$3);
 $4 = ((($0)) + 104|0);
 HEAP32[$4>>2] = 0;
 HEAP32[$1>>2] = $2;
 HEAP32[$2>>2] = 0;
 $5 = ((($0)) + 108|0);
 $6 = ((($0)) + 112|0);
 $7 = HEAP32[$6>>2]|0;
 __ZNSt3__26__treeIPN3osg8StateSetENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($5,$7);
 $8 = ((($0)) + 116|0);
 HEAP32[$8>>2] = 0;
 HEAP32[$5>>2] = $6;
 HEAP32[$6>>2] = 0;
 return;
}
function __ZN7osgUtil16GLObjectsVisitor5applyERN3osg8DrawableE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i$i$i = 0, $$0$ph$i$i$i$i = 0, $$024$i$i$i$i = 0, $$025$i$i$i$i = 0, $$036$i$i$i = 0, $$in$i$i$i$i = 0, $$pre = 0, $$pre$i$i$i$i = 0, $$pre28 = 0, $$pre29 = 0, $$pre30 = 0, $$pre31 = 0, $$sink$be$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 96|0);
 $3 = ((($0)) + 100|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 do {
  if ($5) {
   $25 = $1;
   $$025$i$i$i$i = $3;$$036$i$i$i = $3;$30 = $25;
  } else {
   $7 = $4;
   while(1) {
    $6 = ((($7)) + 16|0);
    $8 = HEAP32[$6>>2]|0;
    $9 = ($8>>>0)>($1>>>0);
    if ($9) {
     $$sink$be$i$i = $7;
    } else {
     $10 = ($8>>>0)<($1>>>0);
     if (!($10)) {
      label = 38;
      break;
     }
     $11 = ((($7)) + 4|0);
     $$sink$be$i$i = $11;
    }
    $12 = HEAP32[$$sink$be$i$i>>2]|0;
    $13 = ($12|0)==(0|0);
    if ($13) {
     break;
    } else {
     $7 = $12;
    }
   }
   if ((label|0) == 38) {
    return;
   }
   $14 = $1;
   $15 = ((($0)) + 100|0);
   $$0$i$i$i$i = $15;$$024$i$i$i$i = $4;
   while(1) {
    $16 = ((($$024$i$i$i$i)) + 16|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = ($17>>>0)>($1>>>0);
    if ($18) {
     $19 = HEAP32[$$024$i$i$i$i>>2]|0;
     $20 = ($19|0)==(0|0);
     if ($20) {
      label = 11;
      break;
     } else {
      $$0$ph$i$i$i$i = $$024$i$i$i$i;$$in$i$i$i$i = $19;
     }
    } else {
     $21 = ($17>>>0)<($1>>>0);
     if (!($21)) {
      label = 15;
      break;
     }
     $22 = ((($$024$i$i$i$i)) + 4|0);
     $23 = HEAP32[$22>>2]|0;
     $24 = ($23|0)==(0|0);
     if ($24) {
      label = 14;
      break;
     } else {
      $$0$ph$i$i$i$i = $22;$$in$i$i$i$i = $23;
     }
    }
    $$0$i$i$i$i = $$0$ph$i$i$i$i;$$024$i$i$i$i = $$in$i$i$i$i;
   }
   if ((label|0) == 11) {
    $$025$i$i$i$i = $$024$i$i$i$i;$$036$i$i$i = $$024$i$i$i$i;$30 = $14;
    break;
   }
   else if ((label|0) == 14) {
    $$025$i$i$i$i = $22;$$036$i$i$i = $$024$i$i$i$i;$30 = $14;
    break;
   }
   else if ((label|0) == 15) {
    $$025$i$i$i$i = $$0$i$i$i$i;$$036$i$i$i = $$024$i$i$i$i;$30 = $14;
    break;
   }
  }
 } while(0);
 $26 = HEAP32[$$025$i$i$i$i>>2]|0;
 $27 = ($26|0)==(0|0);
 if ($27) {
  $28 = (__Znwj(20)|0);
  $29 = ((($28)) + 16|0);
  HEAP32[$29>>2] = $30;
  HEAP32[$28>>2] = 0;
  $31 = ((($28)) + 4|0);
  HEAP32[$31>>2] = 0;
  $32 = ((($28)) + 8|0);
  HEAP32[$32>>2] = $$036$i$i$i;
  HEAP32[$$025$i$i$i$i>>2] = $28;
  $33 = HEAP32[$2>>2]|0;
  $34 = HEAP32[$33>>2]|0;
  $35 = ($34|0)==(0|0);
  if ($35) {
   $39 = $28;
  } else {
   $36 = $34;
   HEAP32[$2>>2] = $36;
   $$pre$i$i$i$i = HEAP32[$$025$i$i$i$i>>2]|0;
   $39 = $$pre$i$i$i$i;
  }
  $37 = ((($0)) + 100|0);
  $38 = HEAP32[$37>>2]|0;
  __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($38,$39);
  $40 = ((($0)) + 104|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = (($41) + 1)|0;
  HEAP32[$40>>2] = $42;
 }
 $43 = ((($0)) + 56|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = $44 & 2;
 $46 = ($45|0)==(0);
 if ($46) {
  $48 = $44;
 } else {
  __ZN3osg8Drawable17setUseDisplayListEb($1,0);
  $$pre = HEAP32[$43>>2]|0;
  $48 = $$pre;
 }
 $47 = $48 & 1;
 $49 = ($47|0)==(0);
 if ($49) {
  $51 = $48;
 } else {
  __ZN3osg8Drawable17setUseDisplayListEb($1,1);
  $$pre28 = HEAP32[$43>>2]|0;
  $51 = $$pre28;
 }
 $50 = $51 & 64;
 $52 = ($50|0)==(0);
 if ($52) {
  $57 = $51;
 } else {
  $53 = HEAP32[$1>>2]|0;
  $54 = ((($53)) + 212|0);
  $55 = HEAP32[$54>>2]|0;
  FUNCTION_TABLE_vii[$55 & 8191]($1,1);
  $$pre29 = HEAP32[$43>>2]|0;
  $57 = $$pre29;
 }
 $56 = $57 & 128;
 $58 = ($56|0)==(0);
 if ($58) {
  $63 = $57;
 } else {
  $59 = HEAP32[$1>>2]|0;
  $60 = ((($59)) + 212|0);
  $61 = HEAP32[$60>>2]|0;
  FUNCTION_TABLE_vii[$61 & 8191]($1,0);
  $$pre30 = HEAP32[$43>>2]|0;
  $63 = $$pre30;
 }
 $62 = $63 & 4;
 $64 = ($62|0)==(0);
 do {
  if ($64) {
   $78 = $63;
  } else {
   $65 = ((($0)) + 60|0);
   $66 = HEAP32[$65>>2]|0;
   $67 = ($66|0)==(0|0);
   if ($67) {
    $78 = $63;
   } else {
    $68 = ((($1)) + 181|0);
    $69 = HEAP8[$68>>0]|0;
    $70 = ($69<<24>>24)==(0);
    if ($70) {
     $71 = ((($1)) + 183|0);
     $72 = HEAP8[$71>>0]|0;
     $73 = ($72<<24>>24)==(0);
     if ($73) {
      $78 = $63;
      break;
     }
    }
    $74 = HEAP32[$1>>2]|0;
    $75 = ((($74)) + 228|0);
    $76 = HEAP32[$75>>2]|0;
    FUNCTION_TABLE_vii[$76 & 8191]($1,$65);
    $$pre31 = HEAP32[$43>>2]|0;
    $78 = $$pre31;
   }
  }
 } while(0);
 $77 = $78 & 16;
 $79 = ($77|0)==(0);
 if (!($79)) {
  $80 = HEAP32[$1>>2]|0;
  $81 = ((($80)) + 136|0);
  $82 = HEAP32[$81>>2]|0;
  $83 = ((($0)) + 60|0);
  $84 = HEAP32[$83>>2]|0;
  FUNCTION_TABLE_vii[$82 & 8191]($1,$84);
 }
 $85 = ((($1)) + 120|0);
 $86 = HEAP32[$85>>2]|0;
 $87 = ($86|0)==(0|0);
 if ($87) {
  return;
 }
 __ZN7osgUtil16GLObjectsVisitor5applyERN3osg8StateSetE($0,$86);
 return;
}
function __ZN7osgUtil16GLObjectsVisitor5applyERN3osg4NodeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$not = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $brmerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 120|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($1)) + 120|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  __ZN7osgUtil16GLObjectsVisitor5applyERN3osg8StateSetE($0,$5);
 }
 $7 = ((($0)) + 16|0);
 $8 = HEAP32[$7>>2]|0;
 switch ($8|0) {
 case 1:  {
  $9 = HEAP32[$1>>2]|0;
  $10 = ((($9)) + 192|0);
  $11 = HEAP32[$10>>2]|0;
  FUNCTION_TABLE_vii[$11 & 8191]($1,$0);
  break;
 }
 case 0:  {
  break;
 }
 default: {
  $12 = HEAP32[$1>>2]|0;
  $13 = ((($12)) + 196|0);
  $14 = HEAP32[$13>>2]|0;
  FUNCTION_TABLE_vii[$14 & 8191]($1,$0);
 }
 }
 $15 = ((($0)) + 60|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==(0|0);
 if ($17) {
  $21 = 0;
 } else {
  $18 = ((($16)) + 664|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = ($19|0)!=(0|0);
  $21 = $20;
 }
 $$not = ($3|0)==(0|0);
 $brmerge = $$not | $21;
 if ($brmerge) {
  return;
 }
 $22 = ((($16)) + 784|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ((($23)) + 176|0);
 $25 = HEAP32[$24>>2]|0;
 FUNCTION_TABLE_vi[$25 & 8191](0);
 $26 = ((($16)) + 664|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ($27|0)==(0|0);
 if (!($28)) {
  HEAP32[$26>>2] = 0;
 }
 $29 = HEAP32[$2>>2]|0;
 $30 = ($29|0)==(0|0);
 if ($30) {
  return;
 }
 HEAP32[$2>>2] = 0;
 $31 = ((($29)) + 8|0);
 $32 = HEAP32[$31>>2]|0;HEAP32[$31>>2] = (($32-1)|0);
 $33 = ($32|0)==(1);
 if (!($33)) {
  return;
 }
 __ZNK3osg10Referenced24signalObserversAndDeleteEbb($29,1,1);
 return;
}
function __ZTv0_n16_N7osgUtil16GLObjectsVisitorD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __THREW__ = 0;
 invoke_vii(3503,($4|0),(47052|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if (!($6)) {
  $14 = ((($4)) + 124|0);
  __ZN3osg6ObjectD2Ev($14);
  return;
 }
 $7 = ___cxa_find_matching_catch_2()|0;
 $8 = tempRet0;
 $9 = ((($4)) + 124|0);
 __THREW__ = 0;
 invoke_vi(388,($9|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if ($11) {
  $12 = ___cxa_find_matching_catch_3(0|0)|0;
  $13 = tempRet0;
  ___clang_call_terminate($12);
  // unreachable;
 } else {
  ___resumeException($7|0);
  // unreachable;
 }
}
function __ZTv0_n16_N7osgUtil16GLObjectsVisitorD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$i$index2Z2D = 0, $eh$lpad$body$i$indexZ2D = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __THREW__ = 0;
 invoke_vii(3503,($4|0),(47052|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $10 = ___cxa_find_matching_catch_2()|0;
  $11 = tempRet0;
  $12 = ((($4)) + 124|0);
  __THREW__ = 0;
  invoke_vi(388,($12|0));
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if ($14) {
   $15 = ___cxa_find_matching_catch_3(0|0)|0;
   $16 = tempRet0;
   ___clang_call_terminate($15);
   // unreachable;
  } else {
   $eh$lpad$body$i$index2Z2D = $11;$eh$lpad$body$i$indexZ2D = $10;
   __ZdlPv($4);
   ___resumeException($eh$lpad$body$i$indexZ2D|0);
   // unreachable;
  }
 }
 $7 = ((($4)) + 124|0);
 __THREW__ = 0;
 invoke_vi(388,($7|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if (!($9)) {
  __ZdlPv($4);
  return;
 }
 $17 = ___cxa_find_matching_catch_2()|0;
 $18 = tempRet0;
 $eh$lpad$body$i$index2Z2D = $18;$eh$lpad$body$i$indexZ2D = $17;
 __ZdlPv($4);
 ___resumeException($eh$lpad$body$i$indexZ2D|0);
 // unreachable;
}
function __ZTv0_n32_NK7osgUtil16GLObjectsVisitor11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (116801|0);
}
function __ZTv0_n36_NK7osgUtil16GLObjectsVisitor9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (110471|0);
}
function __ZN7osgUtil16GLObjectsVisitor5applyERN3osg8StateSetE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i$i$i = 0, $$0$i$i$i$i30 = 0, $$0$ph$i$i$i$i = 0, $$024$i$i$i$i = 0, $$025$i$i$i$i = 0, $$036$i$i$i = 0, $$in$i$i$i$i = 0, $$pre = 0, $$pre$i$i$i$i = 0, $$sink$be$i$i = 0, $$sroa$033$0$be = 0, $$sroa$033$050 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 108|0);
 $3 = ((($0)) + 112|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 do {
  if ($5) {
   $25 = $1;
   $$025$i$i$i$i = $3;$$036$i$i$i = $3;$30 = $25;
  } else {
   $7 = $4;
   while(1) {
    $6 = ((($7)) + 16|0);
    $8 = HEAP32[$6>>2]|0;
    $9 = ($8>>>0)>($1>>>0);
    if ($9) {
     $$sink$be$i$i = $7;
    } else {
     $10 = ($8>>>0)<($1>>>0);
     if (!($10)) {
      label = 52;
      break;
     }
     $11 = ((($7)) + 4|0);
     $$sink$be$i$i = $11;
    }
    $12 = HEAP32[$$sink$be$i$i>>2]|0;
    $13 = ($12|0)==(0|0);
    if ($13) {
     break;
    } else {
     $7 = $12;
    }
   }
   if ((label|0) == 52) {
    return;
   }
   $14 = $1;
   $15 = ((($0)) + 112|0);
   $$0$i$i$i$i = $15;$$024$i$i$i$i = $4;
   while(1) {
    $16 = ((($$024$i$i$i$i)) + 16|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = ($17>>>0)>($1>>>0);
    if ($18) {
     $19 = HEAP32[$$024$i$i$i$i>>2]|0;
     $20 = ($19|0)==(0|0);
     if ($20) {
      label = 11;
      break;
     } else {
      $$0$ph$i$i$i$i = $$024$i$i$i$i;$$in$i$i$i$i = $19;
     }
    } else {
     $21 = ($17>>>0)<($1>>>0);
     if (!($21)) {
      label = 15;
      break;
     }
     $22 = ((($$024$i$i$i$i)) + 4|0);
     $23 = HEAP32[$22>>2]|0;
     $24 = ($23|0)==(0|0);
     if ($24) {
      label = 14;
      break;
     } else {
      $$0$ph$i$i$i$i = $22;$$in$i$i$i$i = $23;
     }
    }
    $$0$i$i$i$i = $$0$ph$i$i$i$i;$$024$i$i$i$i = $$in$i$i$i$i;
   }
   if ((label|0) == 11) {
    $$025$i$i$i$i = $$024$i$i$i$i;$$036$i$i$i = $$024$i$i$i$i;$30 = $14;
    break;
   }
   else if ((label|0) == 14) {
    $$025$i$i$i$i = $22;$$036$i$i$i = $$024$i$i$i$i;$30 = $14;
    break;
   }
   else if ((label|0) == 15) {
    $$025$i$i$i$i = $$0$i$i$i$i;$$036$i$i$i = $$024$i$i$i$i;$30 = $14;
    break;
   }
  }
 } while(0);
 $26 = HEAP32[$$025$i$i$i$i>>2]|0;
 $27 = ($26|0)==(0|0);
 if ($27) {
  $28 = (__Znwj(20)|0);
  $29 = ((($28)) + 16|0);
  HEAP32[$29>>2] = $30;
  HEAP32[$28>>2] = 0;
  $31 = ((($28)) + 4|0);
  HEAP32[$31>>2] = 0;
  $32 = ((($28)) + 8|0);
  HEAP32[$32>>2] = $$036$i$i$i;
  HEAP32[$$025$i$i$i$i>>2] = $28;
  $33 = HEAP32[$2>>2]|0;
  $34 = HEAP32[$33>>2]|0;
  $35 = ($34|0)==(0|0);
  if ($35) {
   $39 = $28;
  } else {
   $36 = $34;
   HEAP32[$2>>2] = $36;
   $$pre$i$i$i$i = HEAP32[$$025$i$i$i$i>>2]|0;
   $39 = $$pre$i$i$i$i;
  }
  $37 = ((($0)) + 112|0);
  $38 = HEAP32[$37>>2]|0;
  __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($38,$39);
  $40 = ((($0)) + 116|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = (($41) + 1)|0;
  HEAP32[$40>>2] = $42;
 }
 $43 = ((($0)) + 56|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = $44 & 8;
 $46 = ($45|0)==(0);
 L31: do {
  if (!($46)) {
   $47 = ((($0)) + 60|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = ($48|0)==(0|0);
   if (!($49)) {
    __ZNK3osg8StateSet16compileGLObjectsERNS_5StateE($1,$48);
    $50 = (__ZN3osg8StateSet12getAttributeENS_14StateAttribute4TypeEj($1,36,0)|0);
    $51 = ($50|0)==(0|0);
    do {
     if (!($51)) {
      $52 = (___dynamic_cast($50,19768,26392,0)|0);
      $53 = ($52|0)==(0|0);
      if (!($53)) {
       $54 = (__ZNK3osg7Program15isFixedFunctionEv($52)|0);
       $55 = ((($0)) + 120|0);
       $56 = HEAP32[$55>>2]|0;
       if ($54) {
        $57 = ($56|0)==(0|0);
        if ($57) {
         break;
        }
        HEAP32[$55>>2] = 0;
        $58 = ((($56)) + 8|0);
        $59 = HEAP32[$58>>2]|0;HEAP32[$58>>2] = (($59-1)|0);
        $60 = ($59|0)==(1);
        if (!($60)) {
         break;
        }
        __ZNK3osg10Referenced24signalObserversAndDeleteEbb($56,1,1);
        break;
       }
       $61 = ($56|0)==($52|0);
       if (!($61)) {
        HEAP32[$55>>2] = $52;
        $62 = ((($52)) + 8|0);
        $63 = HEAP32[$62>>2]|0;HEAP32[$62>>2] = (($63+1)|0);
        $64 = ($56|0)==(0|0);
        if (!($64)) {
         $65 = ((($56)) + 8|0);
         $66 = HEAP32[$65>>2]|0;HEAP32[$65>>2] = (($66-1)|0);
         $67 = ($66|0)==(1);
         if ($67) {
          __ZNK3osg10Referenced24signalObserversAndDeleteEbb($56,1,1);
         }
        }
       }
      }
     }
    } while(0);
    $68 = ((($0)) + 120|0);
    $69 = HEAP32[$68>>2]|0;
    $70 = ($69|0)==(0|0);
    if (!($70)) {
     $71 = ((($1)) + 100|0);
     $72 = HEAP32[$71>>2]|0;
     $73 = ($72|0)==(0);
     if (!($73)) {
      $74 = HEAP32[$47>>2]|0;
      $75 = (__ZNK3osg7Program6getPCPERNS_5StateE($69,$74)|0);
      $76 = ($75|0)==(0|0);
      if ($76) {
       break;
      }
      $77 = HEAP32[$75>>2]|0;
      $78 = ((($77)) + 28|0);
      $79 = HEAP32[$78>>2]|0;
      FUNCTION_TABLE_vi[$79 & 8191]($75);
      $80 = HEAP32[$47>>2]|0;
      $81 = ((($80)) + 664|0);
      $82 = HEAP32[$81>>2]|0;
      $83 = ($82|0)==($75|0);
      if (!($83)) {
       HEAP32[$81>>2] = $75;
      }
      $84 = ((($1)) + 92|0);
      $85 = HEAP32[$84>>2]|0;
      $86 = ((($1)) + 96|0);
      $87 = ($85|0)==($86|0);
      if ($87) {
       break;
      } else {
       $$sroa$033$050 = $85;
      }
      while(1) {
       $88 = ((($$sroa$033$050)) + 28|0);
       $89 = HEAP32[$88>>2]|0;
       __ZNK3osg7Program17PerContextProgram5applyERKNS_7UniformE($75,$89);
       $90 = ((($$sroa$033$050)) + 4|0);
       $91 = HEAP32[$90>>2]|0;
       $92 = ($91|0)==(0|0);
       if ($92) {
        $93 = ((($$sroa$033$050)) + 8|0);
        $94 = HEAP32[$93>>2]|0;
        $95 = HEAP32[$94>>2]|0;
        $96 = ($95|0)==($$sroa$033$050|0);
        if ($96) {
         $$sroa$033$0$be = $94;
        } else {
         $101 = $93;
         while(1) {
          $100 = HEAP32[$101>>2]|0;
          $102 = ((($100)) + 8|0);
          $103 = HEAP32[$102>>2]|0;
          $104 = HEAP32[$103>>2]|0;
          $105 = ($104|0)==($100|0);
          if ($105) {
           $$sroa$033$0$be = $103;
           break;
          } else {
           $101 = $102;
          }
         }
        }
       } else {
        $$0$i$i$i$i30 = $91;
        while(1) {
         $98 = HEAP32[$$0$i$i$i$i30>>2]|0;
         $99 = ($98|0)==(0|0);
         if ($99) {
          break;
         } else {
          $$0$i$i$i$i30 = $98;
         }
        }
        $$sroa$033$0$be = $$0$i$i$i$i30;
       }
       $97 = ($$sroa$033$0$be|0)==($86|0);
       if ($97) {
        break L31;
       } else {
        $$sroa$033$050 = $$sroa$033$0$be;
       }
      }
     }
    }
    $106 = HEAP32[$47>>2]|0;
    $107 = ((($106)) + 664|0);
    $108 = HEAP32[$107>>2]|0;
    $109 = ($108|0)==(0|0);
    if (!($109)) {
     $110 = ((($106)) + 784|0);
     $111 = HEAP32[$110>>2]|0;
     $112 = ((($111)) + 176|0);
     $113 = HEAP32[$112>>2]|0;
     FUNCTION_TABLE_vi[$113 & 8191](0);
     $114 = HEAP32[$47>>2]|0;
     $115 = ((($114)) + 664|0);
     $116 = HEAP32[$115>>2]|0;
     $117 = ($116|0)==(0|0);
     if (!($117)) {
      HEAP32[$115>>2] = 0;
     }
    }
   }
  }
 } while(0);
 $118 = HEAP32[$43>>2]|0;
 $119 = $118 & 32;
 $120 = ($119|0)==(0);
 if ($120) {
  $127 = $118;
 } else {
  $121 = HEAP32[$1>>2]|0;
  $122 = ((($121)) + 136|0);
  $123 = HEAP32[$122>>2]|0;
  $124 = ((($0)) + 60|0);
  $125 = HEAP32[$124>>2]|0;
  FUNCTION_TABLE_vii[$123 & 8191]($1,$125);
  $$pre = HEAP32[$43>>2]|0;
  $127 = $$pre;
 }
 $126 = $127 & 256;
 $128 = ($126|0)==(0);
 if ($128) {
  return;
 }
 $129 = ((($0)) + 60|0);
 $130 = HEAP32[$129>>2]|0;
 (__ZNK3osg8StateSet30checkValidityOfAssociatedModesERNS_5StateE($1,$130)|0);
 return;
}
function __ZNK3osg7Program17PerContextProgram5applyERKNS_7UniformE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i = 0, $$0$i$i27 = 0, $$0$i$i43 = 0, $$0$i$i59 = 0, $$0$i$i75 = 0, $$0$i$i91 = 0, $$0$ph$i$i = 0, $$0$ph$i$i24 = 0, $$0$ph$i$i40 = 0, $$0$ph$i$i56 = 0, $$0$ph$i$i72 = 0, $$0$ph$i$i88 = 0, $$0$ph$lcssa$i$i$i$i = 0, $$0$ph13$i$i$i$i = 0, $$014$i = 0, $$014$i100 = 0, $$014$i36 = 0, $$014$i52 = 0, $$014$i68 = 0, $$014$i84 = 0;
 var $$024$i$i = 0, $$024$i$i26 = 0, $$024$i$i42 = 0, $$024$i$i58 = 0, $$024$i$i74 = 0, $$024$i$i90 = 0, $$025$i$i = 0, $$025$i$i29 = 0, $$025$i$i45 = 0, $$025$i$i61 = 0, $$025$i$i77 = 0, $$025$i$i93 = 0, $$025$i53$i = 0, $$025$i53$i31 = 0, $$025$i53$i47 = 0, $$025$i53$i63 = 0, $$025$i53$i79 = 0, $$025$i53$i95 = 0, $$037$i = 0, $$037$i28 = 0;
 var $$037$i44 = 0, $$037$i60 = 0, $$037$i76 = 0, $$037$i92 = 0, $$03752$i = 0, $$03752$i32 = 0, $$03752$i48 = 0, $$03752$i64 = 0, $$03752$i80 = 0, $$03752$i96 = 0, $$07$ph12$i$i$i$i = 0, $$0710$i$i$i$i = 0, $$in$i$i = 0, $$in$i$i23 = 0, $$in$i$i39 = 0, $$in$i$i55 = 0, $$in$i$i71 = 0, $$in$i$i87 = 0, $$pre$i$i = 0, $$pre$i$i34 = 0;
 var $$pre$i$i50 = 0, $$pre$i$i66 = 0, $$pre$i$i82 = 0, $$pre$i$i98 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0;
 var $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0;
 var $240 = 0, $241 = 0, $242 = 0, $243 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__ZNK3osg7Uniform9getNameIDEv($1)|0);
 $3 = ((($0)) + 52|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  return;
 } else {
  $$0$ph13$i$i$i$i = $3;$$07$ph12$i$i$i$i = $4;
 }
 L3: while(1) {
  $$0710$i$i$i$i = $$07$ph12$i$i$i$i;
  while(1) {
   $6 = ((($$0710$i$i$i$i)) + 16|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($7>>>0)<($2>>>0);
   if (!($8)) {
    break;
   }
   $11 = ((($$0710$i$i$i$i)) + 4|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = ($12|0)==(0|0);
   if ($13) {
    $$0$ph$lcssa$i$i$i$i = $$0$ph13$i$i$i$i;
    break L3;
   } else {
    $$0710$i$i$i$i = $12;
   }
  }
  $9 = HEAP32[$$0710$i$i$i$i>>2]|0;
  $10 = ($9|0)==(0|0);
  if ($10) {
   $$0$ph$lcssa$i$i$i$i = $$0710$i$i$i$i;
   break;
  } else {
   $$0$ph13$i$i$i$i = $$0710$i$i$i$i;$$07$ph12$i$i$i$i = $9;
  }
 }
 $14 = ($$0$ph$lcssa$i$i$i$i|0)==($3|0);
 if ($14) {
  return;
 }
 $15 = ((($$0$ph$lcssa$i$i$i$i)) + 16|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16>>>0)>($2>>>0);
 if ($17) {
  return;
 }
 $18 = ((($$0$ph$lcssa$i$i$i$i)) + 20|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)>(-1);
 if (!($20)) {
  return;
 }
 $21 = ((($0)) + 84|0);
 $22 = ((($0)) + 88|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)==(0|0);
 do {
  if ($24) {
   $$025$i$i29 = $22;$$037$i28 = $22;$35 = $23;
   label = 20;
  } else {
   $25 = ((($0)) + 88|0);
   $$0$i$i27 = $25;$$024$i$i26 = $23;$238 = $23;
   while(1) {
    $26 = ((($$024$i$i26)) + 16|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = ($19>>>0)<($27>>>0);
    if ($28) {
     $29 = HEAP32[$$024$i$i26>>2]|0;
     $30 = ($29|0)==(0|0);
     if ($30) {
      label = 14;
      break;
     } else {
      $$0$ph$i$i24 = $$024$i$i26;$$in$i$i23 = $29;
     }
    } else {
     $31 = ($27>>>0)<($19>>>0);
     if (!($31)) {
      label = 18;
      break;
     }
     $32 = ((($$024$i$i26)) + 4|0);
     $33 = HEAP32[$32>>2]|0;
     $34 = ($33|0)==(0|0);
     if ($34) {
      label = 17;
      break;
     } else {
      $$0$ph$i$i24 = $32;$$in$i$i23 = $33;
     }
    }
    $$0$i$i27 = $$0$ph$i$i24;$$024$i$i26 = $$in$i$i23;$238 = $$in$i$i23;
   }
   if ((label|0) == 14) {
    $$025$i53$i31 = $$024$i$i26;$$03752$i32 = $$024$i$i26;
    label = 21;
    break;
   }
   else if ((label|0) == 17) {
    $$025$i53$i31 = $32;$$03752$i32 = $$024$i$i26;
    label = 21;
    break;
   }
   else if ((label|0) == 18) {
    $$025$i$i29 = $$0$i$i27;$$037$i28 = $$024$i$i26;$35 = $238;
    label = 20;
    break;
   }
  }
 } while(0);
 if ((label|0) == 20) {
  $36 = ($35|0)==(0|0);
  if ($36) {
   $$025$i53$i31 = $$025$i$i29;$$03752$i32 = $$037$i28;
   label = 21;
  } else {
   $$014$i36 = $35;
  }
 }
 if ((label|0) == 21) {
  $37 = (__Znwj(28)|0);
  $38 = ((($37)) + 16|0);
  HEAP32[$38>>2] = $19;
  $39 = ((($37)) + 20|0);
  HEAP32[$39>>2] = 0;
  $40 = ((($37)) + 24|0);
  HEAP32[$40>>2] = 0;
  HEAP32[$37>>2] = 0;
  $41 = ((($37)) + 4|0);
  HEAP32[$41>>2] = 0;
  $42 = ((($37)) + 8|0);
  HEAP32[$42>>2] = $$03752$i32;
  HEAP32[$$025$i53$i31>>2] = $37;
  $43 = HEAP32[$21>>2]|0;
  $44 = HEAP32[$43>>2]|0;
  $45 = ($44|0)==(0|0);
  if ($45) {
   $49 = $37;
  } else {
   $46 = $44;
   HEAP32[$21>>2] = $46;
   $$pre$i$i34 = HEAP32[$$025$i53$i31>>2]|0;
   $49 = $$pre$i$i34;
  }
  $47 = ((($0)) + 88|0);
  $48 = HEAP32[$47>>2]|0;
  __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($48,$49);
  $50 = ((($0)) + 92|0);
  $51 = HEAP32[$50>>2]|0;
  $52 = (($51) + 1)|0;
  HEAP32[$50>>2] = $52;
  $$014$i36 = $37;
 }
 $53 = ((($$014$i36)) + 20|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = ($54|0)==($1|0);
 if (!($55)) {
  $56 = ((($0)) + 16|0);
  $57 = HEAP32[$56>>2]|0;
  __ZNK3osg7Uniform5applyEPKNS_12GLExtensionsEi($1,$57,$19);
  $58 = HEAP32[$22>>2]|0;
  $59 = ($58|0)==(0|0);
  do {
   if ($59) {
    $$025$i$i45 = $22;$$037$i44 = $22;$70 = $58;
    label = 36;
   } else {
    $60 = ((($0)) + 88|0);
    $$0$i$i43 = $60;$$024$i$i42 = $58;$239 = $58;
    while(1) {
     $61 = ((($$024$i$i42)) + 16|0);
     $62 = HEAP32[$61>>2]|0;
     $63 = ($19>>>0)<($62>>>0);
     if ($63) {
      $64 = HEAP32[$$024$i$i42>>2]|0;
      $65 = ($64|0)==(0|0);
      if ($65) {
       label = 30;
       break;
      } else {
       $$0$ph$i$i40 = $$024$i$i42;$$in$i$i39 = $64;
      }
     } else {
      $66 = ($62>>>0)<($19>>>0);
      if (!($66)) {
       label = 34;
       break;
      }
      $67 = ((($$024$i$i42)) + 4|0);
      $68 = HEAP32[$67>>2]|0;
      $69 = ($68|0)==(0|0);
      if ($69) {
       label = 33;
       break;
      } else {
       $$0$ph$i$i40 = $67;$$in$i$i39 = $68;
      }
     }
     $$0$i$i43 = $$0$ph$i$i40;$$024$i$i42 = $$in$i$i39;$239 = $$in$i$i39;
    }
    if ((label|0) == 30) {
     $$025$i53$i47 = $$024$i$i42;$$03752$i48 = $$024$i$i42;
     label = 37;
     break;
    }
    else if ((label|0) == 33) {
     $$025$i53$i47 = $67;$$03752$i48 = $$024$i$i42;
     label = 37;
     break;
    }
    else if ((label|0) == 34) {
     $$025$i$i45 = $$0$i$i43;$$037$i44 = $$024$i$i42;$70 = $239;
     label = 36;
     break;
    }
   }
  } while(0);
  if ((label|0) == 36) {
   $71 = ($70|0)==(0|0);
   if ($71) {
    $$025$i53$i47 = $$025$i$i45;$$03752$i48 = $$037$i44;
    label = 37;
   } else {
    $$014$i52 = $70;
   }
  }
  if ((label|0) == 37) {
   $72 = (__Znwj(28)|0);
   $73 = ((($72)) + 16|0);
   HEAP32[$73>>2] = $19;
   $74 = ((($72)) + 20|0);
   HEAP32[$74>>2] = 0;
   $75 = ((($72)) + 24|0);
   HEAP32[$75>>2] = 0;
   HEAP32[$72>>2] = 0;
   $76 = ((($72)) + 4|0);
   HEAP32[$76>>2] = 0;
   $77 = ((($72)) + 8|0);
   HEAP32[$77>>2] = $$03752$i48;
   HEAP32[$$025$i53$i47>>2] = $72;
   $78 = HEAP32[$21>>2]|0;
   $79 = HEAP32[$78>>2]|0;
   $80 = ($79|0)==(0|0);
   if ($80) {
    $84 = $72;
   } else {
    $81 = $79;
    HEAP32[$21>>2] = $81;
    $$pre$i$i50 = HEAP32[$$025$i53$i47>>2]|0;
    $84 = $$pre$i$i50;
   }
   $82 = ((($0)) + 88|0);
   $83 = HEAP32[$82>>2]|0;
   __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($83,$84);
   $85 = ((($0)) + 92|0);
   $86 = HEAP32[$85>>2]|0;
   $87 = (($86) + 1)|0;
   HEAP32[$85>>2] = $87;
   $$014$i52 = $72;
  }
  $88 = ((($$014$i52)) + 20|0);
  $89 = HEAP32[$88>>2]|0;
  $90 = ($89|0)==($1|0);
  if (!($90)) {
   HEAP32[$88>>2] = $1;
   $91 = ((($1)) + 8|0);
   $92 = HEAP32[$91>>2]|0;HEAP32[$91>>2] = (($92+1)|0);
   $93 = ($89|0)==(0|0);
   if (!($93)) {
    $94 = ((($89)) + 8|0);
    $95 = HEAP32[$94>>2]|0;HEAP32[$94>>2] = (($95-1)|0);
    $96 = ($95|0)==(1);
    if ($96) {
     __ZNK3osg10Referenced24signalObserversAndDeleteEbb($89,1,1);
    }
   }
  }
  $97 = ((($1)) + 88|0);
  $98 = HEAP32[$97>>2]|0;
  $99 = HEAP32[$22>>2]|0;
  $100 = ($99|0)==(0|0);
  do {
   if ($100) {
    $$025$i$i61 = $22;$$037$i60 = $22;$111 = $99;
    label = 55;
   } else {
    $101 = ((($0)) + 88|0);
    $$0$i$i59 = $101;$$024$i$i58 = $99;$240 = $99;
    while(1) {
     $102 = ((($$024$i$i58)) + 16|0);
     $103 = HEAP32[$102>>2]|0;
     $104 = ($19>>>0)<($103>>>0);
     if ($104) {
      $105 = HEAP32[$$024$i$i58>>2]|0;
      $106 = ($105|0)==(0|0);
      if ($106) {
       label = 49;
       break;
      } else {
       $$0$ph$i$i56 = $$024$i$i58;$$in$i$i55 = $105;
      }
     } else {
      $107 = ($103>>>0)<($19>>>0);
      if (!($107)) {
       label = 53;
       break;
      }
      $108 = ((($$024$i$i58)) + 4|0);
      $109 = HEAP32[$108>>2]|0;
      $110 = ($109|0)==(0|0);
      if ($110) {
       label = 52;
       break;
      } else {
       $$0$ph$i$i56 = $108;$$in$i$i55 = $109;
      }
     }
     $$0$i$i59 = $$0$ph$i$i56;$$024$i$i58 = $$in$i$i55;$240 = $$in$i$i55;
    }
    if ((label|0) == 49) {
     $$025$i53$i63 = $$024$i$i58;$$03752$i64 = $$024$i$i58;
     label = 56;
     break;
    }
    else if ((label|0) == 52) {
     $$025$i53$i63 = $108;$$03752$i64 = $$024$i$i58;
     label = 56;
     break;
    }
    else if ((label|0) == 53) {
     $$025$i$i61 = $$0$i$i59;$$037$i60 = $$024$i$i58;$111 = $240;
     label = 55;
     break;
    }
   }
  } while(0);
  if ((label|0) == 55) {
   $112 = ($111|0)==(0|0);
   if ($112) {
    $$025$i53$i63 = $$025$i$i61;$$03752$i64 = $$037$i60;
    label = 56;
   } else {
    $$014$i68 = $111;
   }
  }
  if ((label|0) == 56) {
   $113 = (__Znwj(28)|0);
   $114 = ((($113)) + 16|0);
   HEAP32[$114>>2] = $19;
   $115 = ((($113)) + 20|0);
   HEAP32[$115>>2] = 0;
   $116 = ((($113)) + 24|0);
   HEAP32[$116>>2] = 0;
   HEAP32[$113>>2] = 0;
   $117 = ((($113)) + 4|0);
   HEAP32[$117>>2] = 0;
   $118 = ((($113)) + 8|0);
   HEAP32[$118>>2] = $$03752$i64;
   HEAP32[$$025$i53$i63>>2] = $113;
   $119 = HEAP32[$21>>2]|0;
   $120 = HEAP32[$119>>2]|0;
   $121 = ($120|0)==(0|0);
   if ($121) {
    $125 = $113;
   } else {
    $122 = $120;
    HEAP32[$21>>2] = $122;
    $$pre$i$i66 = HEAP32[$$025$i53$i63>>2]|0;
    $125 = $$pre$i$i66;
   }
   $123 = ((($0)) + 88|0);
   $124 = HEAP32[$123>>2]|0;
   __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($124,$125);
   $126 = ((($0)) + 92|0);
   $127 = HEAP32[$126>>2]|0;
   $128 = (($127) + 1)|0;
   HEAP32[$126>>2] = $128;
   $$014$i68 = $113;
  }
  $129 = ((($$014$i68)) + 24|0);
  HEAP32[$129>>2] = $98;
  return;
 }
 $130 = HEAP32[$22>>2]|0;
 $131 = ($130|0)==(0|0);
 do {
  if ($131) {
   $$025$i$i77 = $22;$$037$i76 = $22;$142 = $130;
   label = 71;
  } else {
   $132 = ((($0)) + 88|0);
   $$0$i$i75 = $132;$$024$i$i74 = $130;$241 = $130;
   while(1) {
    $133 = ((($$024$i$i74)) + 16|0);
    $134 = HEAP32[$133>>2]|0;
    $135 = ($19>>>0)<($134>>>0);
    if ($135) {
     $136 = HEAP32[$$024$i$i74>>2]|0;
     $137 = ($136|0)==(0|0);
     if ($137) {
      label = 65;
      break;
     } else {
      $$0$ph$i$i72 = $$024$i$i74;$$in$i$i71 = $136;
     }
    } else {
     $138 = ($134>>>0)<($19>>>0);
     if (!($138)) {
      label = 69;
      break;
     }
     $139 = ((($$024$i$i74)) + 4|0);
     $140 = HEAP32[$139>>2]|0;
     $141 = ($140|0)==(0|0);
     if ($141) {
      label = 68;
      break;
     } else {
      $$0$ph$i$i72 = $139;$$in$i$i71 = $140;
     }
    }
    $$0$i$i75 = $$0$ph$i$i72;$$024$i$i74 = $$in$i$i71;$241 = $$in$i$i71;
   }
   if ((label|0) == 65) {
    $$025$i53$i79 = $$024$i$i74;$$03752$i80 = $$024$i$i74;
    label = 72;
    break;
   }
   else if ((label|0) == 68) {
    $$025$i53$i79 = $139;$$03752$i80 = $$024$i$i74;
    label = 72;
    break;
   }
   else if ((label|0) == 69) {
    $$025$i$i77 = $$0$i$i75;$$037$i76 = $$024$i$i74;$142 = $241;
    label = 71;
    break;
   }
  }
 } while(0);
 if ((label|0) == 71) {
  $143 = ($142|0)==(0|0);
  if ($143) {
   $$025$i53$i79 = $$025$i$i77;$$03752$i80 = $$037$i76;
   label = 72;
  } else {
   $$014$i84 = $142;
  }
 }
 if ((label|0) == 72) {
  $144 = (__Znwj(28)|0);
  $145 = ((($144)) + 16|0);
  HEAP32[$145>>2] = $19;
  $146 = ((($144)) + 20|0);
  HEAP32[$146>>2] = 0;
  $147 = ((($144)) + 24|0);
  HEAP32[$147>>2] = 0;
  HEAP32[$144>>2] = 0;
  $148 = ((($144)) + 4|0);
  HEAP32[$148>>2] = 0;
  $149 = ((($144)) + 8|0);
  HEAP32[$149>>2] = $$03752$i80;
  HEAP32[$$025$i53$i79>>2] = $144;
  $150 = HEAP32[$21>>2]|0;
  $151 = HEAP32[$150>>2]|0;
  $152 = ($151|0)==(0|0);
  if ($152) {
   $156 = $144;
  } else {
   $153 = $151;
   HEAP32[$21>>2] = $153;
   $$pre$i$i82 = HEAP32[$$025$i53$i79>>2]|0;
   $156 = $$pre$i$i82;
  }
  $154 = ((($0)) + 88|0);
  $155 = HEAP32[$154>>2]|0;
  __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($155,$156);
  $157 = ((($0)) + 92|0);
  $158 = HEAP32[$157>>2]|0;
  $159 = (($158) + 1)|0;
  HEAP32[$157>>2] = $159;
  $$014$i84 = $144;
 }
 $160 = ((($$014$i84)) + 24|0);
 $161 = HEAP32[$160>>2]|0;
 $162 = ((($1)) + 88|0);
 $163 = HEAP32[$162>>2]|0;
 $164 = ($161|0)==($163|0);
 if ($164) {
  return;
 }
 $165 = ((($0)) + 16|0);
 $166 = HEAP32[$165>>2]|0;
 __ZNK3osg7Uniform5applyEPKNS_12GLExtensionsEi($1,$166,$19);
 $167 = HEAP32[$22>>2]|0;
 $168 = ($167|0)==(0|0);
 do {
  if ($168) {
   $$025$i$i93 = $22;$$037$i92 = $22;$179 = $167;
   label = 87;
  } else {
   $169 = ((($0)) + 88|0);
   $$0$i$i91 = $169;$$024$i$i90 = $167;$242 = $167;
   while(1) {
    $170 = ((($$024$i$i90)) + 16|0);
    $171 = HEAP32[$170>>2]|0;
    $172 = ($19>>>0)<($171>>>0);
    if ($172) {
     $173 = HEAP32[$$024$i$i90>>2]|0;
     $174 = ($173|0)==(0|0);
     if ($174) {
      label = 81;
      break;
     } else {
      $$0$ph$i$i88 = $$024$i$i90;$$in$i$i87 = $173;
     }
    } else {
     $175 = ($171>>>0)<($19>>>0);
     if (!($175)) {
      label = 85;
      break;
     }
     $176 = ((($$024$i$i90)) + 4|0);
     $177 = HEAP32[$176>>2]|0;
     $178 = ($177|0)==(0|0);
     if ($178) {
      label = 84;
      break;
     } else {
      $$0$ph$i$i88 = $176;$$in$i$i87 = $177;
     }
    }
    $$0$i$i91 = $$0$ph$i$i88;$$024$i$i90 = $$in$i$i87;$242 = $$in$i$i87;
   }
   if ((label|0) == 81) {
    $$025$i53$i95 = $$024$i$i90;$$03752$i96 = $$024$i$i90;
    label = 88;
    break;
   }
   else if ((label|0) == 84) {
    $$025$i53$i95 = $176;$$03752$i96 = $$024$i$i90;
    label = 88;
    break;
   }
   else if ((label|0) == 85) {
    $$025$i$i93 = $$0$i$i91;$$037$i92 = $$024$i$i90;$179 = $242;
    label = 87;
    break;
   }
  }
 } while(0);
 if ((label|0) == 87) {
  $180 = ($179|0)==(0|0);
  if ($180) {
   $$025$i53$i95 = $$025$i$i93;$$03752$i96 = $$037$i92;
   label = 88;
  } else {
   $$014$i100 = $179;
  }
 }
 if ((label|0) == 88) {
  $181 = (__Znwj(28)|0);
  $182 = ((($181)) + 16|0);
  HEAP32[$182>>2] = $19;
  $183 = ((($181)) + 20|0);
  HEAP32[$183>>2] = 0;
  $184 = ((($181)) + 24|0);
  HEAP32[$184>>2] = 0;
  HEAP32[$181>>2] = 0;
  $185 = ((($181)) + 4|0);
  HEAP32[$185>>2] = 0;
  $186 = ((($181)) + 8|0);
  HEAP32[$186>>2] = $$03752$i96;
  HEAP32[$$025$i53$i95>>2] = $181;
  $187 = HEAP32[$21>>2]|0;
  $188 = HEAP32[$187>>2]|0;
  $189 = ($188|0)==(0|0);
  if ($189) {
   $193 = $181;
  } else {
   $190 = $188;
   HEAP32[$21>>2] = $190;
   $$pre$i$i98 = HEAP32[$$025$i53$i95>>2]|0;
   $193 = $$pre$i$i98;
  }
  $191 = ((($0)) + 88|0);
  $192 = HEAP32[$191>>2]|0;
  __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($192,$193);
  $194 = ((($0)) + 92|0);
  $195 = HEAP32[$194>>2]|0;
  $196 = (($195) + 1)|0;
  HEAP32[$194>>2] = $196;
  $$014$i100 = $181;
 }
 $197 = ((($$014$i100)) + 20|0);
 $198 = HEAP32[$197>>2]|0;
 $199 = ($198|0)==($1|0);
 if (!($199)) {
  HEAP32[$197>>2] = $1;
  $200 = ((($1)) + 8|0);
  $201 = HEAP32[$200>>2]|0;HEAP32[$200>>2] = (($201+1)|0);
  $202 = ($198|0)==(0|0);
  if (!($202)) {
   $203 = ((($198)) + 8|0);
   $204 = HEAP32[$203>>2]|0;HEAP32[$203>>2] = (($204-1)|0);
   $205 = ($204|0)==(1);
   if ($205) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($198,1,1);
   }
  }
 }
 $206 = HEAP32[$162>>2]|0;
 $207 = HEAP32[$22>>2]|0;
 $208 = ($207|0)==(0|0);
 do {
  if ($208) {
   $$025$i$i = $22;$$037$i = $22;$219 = $207;
   label = 106;
  } else {
   $209 = ((($0)) + 88|0);
   $$0$i$i = $209;$$024$i$i = $207;$243 = $207;
   while(1) {
    $210 = ((($$024$i$i)) + 16|0);
    $211 = HEAP32[$210>>2]|0;
    $212 = ($19>>>0)<($211>>>0);
    if ($212) {
     $213 = HEAP32[$$024$i$i>>2]|0;
     $214 = ($213|0)==(0|0);
     if ($214) {
      label = 100;
      break;
     } else {
      $$0$ph$i$i = $$024$i$i;$$in$i$i = $213;
     }
    } else {
     $215 = ($211>>>0)<($19>>>0);
     if (!($215)) {
      label = 104;
      break;
     }
     $216 = ((($$024$i$i)) + 4|0);
     $217 = HEAP32[$216>>2]|0;
     $218 = ($217|0)==(0|0);
     if ($218) {
      label = 103;
      break;
     } else {
      $$0$ph$i$i = $216;$$in$i$i = $217;
     }
    }
    $$0$i$i = $$0$ph$i$i;$$024$i$i = $$in$i$i;$243 = $$in$i$i;
   }
   if ((label|0) == 100) {
    $$025$i53$i = $$024$i$i;$$03752$i = $$024$i$i;
    label = 107;
    break;
   }
   else if ((label|0) == 103) {
    $$025$i53$i = $216;$$03752$i = $$024$i$i;
    label = 107;
    break;
   }
   else if ((label|0) == 104) {
    $$025$i$i = $$0$i$i;$$037$i = $$024$i$i;$219 = $243;
    label = 106;
    break;
   }
  }
 } while(0);
 if ((label|0) == 106) {
  $220 = ($219|0)==(0|0);
  if ($220) {
   $$025$i53$i = $$025$i$i;$$03752$i = $$037$i;
   label = 107;
  } else {
   $$014$i = $219;
  }
 }
 if ((label|0) == 107) {
  $221 = (__Znwj(28)|0);
  $222 = ((($221)) + 16|0);
  HEAP32[$222>>2] = $19;
  $223 = ((($221)) + 20|0);
  HEAP32[$223>>2] = 0;
  $224 = ((($221)) + 24|0);
  HEAP32[$224>>2] = 0;
  HEAP32[$221>>2] = 0;
  $225 = ((($221)) + 4|0);
  HEAP32[$225>>2] = 0;
  $226 = ((($221)) + 8|0);
  HEAP32[$226>>2] = $$03752$i;
  HEAP32[$$025$i53$i>>2] = $221;
  $227 = HEAP32[$21>>2]|0;
  $228 = HEAP32[$227>>2]|0;
  $229 = ($228|0)==(0|0);
  if ($229) {
   $233 = $221;
  } else {
   $230 = $228;
   HEAP32[$21>>2] = $230;
   $$pre$i$i = HEAP32[$$025$i53$i>>2]|0;
   $233 = $$pre$i$i;
  }
  $231 = ((($0)) + 88|0);
  $232 = HEAP32[$231>>2]|0;
  __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($232,$233);
  $234 = ((($0)) + 92|0);
  $235 = HEAP32[$234>>2]|0;
  $236 = (($235) + 1)|0;
  HEAP32[$234>>2] = $236;
  $$014$i = $221;
 }
 $237 = ((($$014$i)) + 24|0);
 HEAP32[$237>>2] = $206;
 return;
}
function __ZN7osgUtil16GLObjectsVisitorC1Ej($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 124|0);
 __ZN3osg10ReferencedC2Ev($2);
 HEAP32[$2>>2] = (63412);
 $3 = ((($0)) + 136|0);
 ;HEAP32[$3>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;
 $4 = ((($0)) + 148|0);
 HEAP32[$4>>2] = 2;
 $5 = ((($0)) + 152|0);
 HEAP32[$5>>2] = 0;
 __THREW__ = 0;
 invoke_viii(3283,($0|0),((47056)|0),0);
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if (!($7)) {
  HEAP32[$0>>2] = (46568);
  HEAP32[$2>>2] = (46912);
  $8 = ((($0)) + 60|0);
  dest=$8; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
  $9 = ((($0)) + 100|0);
  HEAP32[$9>>2] = 0;
  $10 = ((($0)) + 104|0);
  HEAP32[$10>>2] = 0;
  $11 = ((($0)) + 100|0);
  $12 = ((($0)) + 96|0);
  HEAP32[$12>>2] = $11;
  $13 = ((($0)) + 112|0);
  HEAP32[$13>>2] = 0;
  $14 = ((($0)) + 116|0);
  HEAP32[$14>>2] = 0;
  $15 = ((($0)) + 112|0);
  $16 = ((($0)) + 108|0);
  HEAP32[$16>>2] = $15;
  $17 = ((($0)) + 120|0);
  HEAP32[$17>>2] = 0;
  $18 = ((($0)) + 16|0);
  HEAP32[$18>>2] = 2;
  $19 = ((($0)) + 56|0);
  HEAP32[$19>>2] = $1;
  return;
 }
 $20 = ___cxa_find_matching_catch_2()|0;
 $21 = tempRet0;
 __THREW__ = 0;
 invoke_vi(388,($2|0));
 $22 = __THREW__; __THREW__ = 0;
 $23 = $22&1;
 if ($23) {
  $24 = ___cxa_find_matching_catch_3(0|0)|0;
  $25 = tempRet0;
  ___clang_call_terminate($24);
  // unreachable;
 } else {
  ___resumeException($20|0);
  // unreachable;
 }
}
function __ZN7osgUtil19IntersectionVisitorD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vii(3312,($0|0),(47564|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  $3 = ((($0)) + 160|0);
  __ZN3osg6ObjectD2Ev($3);
  return;
 }
 $4 = ___cxa_find_matching_catch_2()|0;
 $5 = tempRet0;
 $6 = ((($0)) + 160|0);
 __THREW__ = 0;
 invoke_vi(388,($6|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch_3(0|0)|0;
  $10 = tempRet0;
  ___clang_call_terminate($9);
  // unreachable;
 } else {
  ___resumeException($4|0);
  // unreachable;
 }
}
function __ZN7osgUtil19IntersectionVisitorD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vii(3312,($0|0),(47564|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $6 = ___cxa_find_matching_catch_2()|0;
  $7 = tempRet0;
  $8 = ((($0)) + 160|0);
  __THREW__ = 0;
  invoke_vi(388,($8|0));
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if ($10) {
   $11 = ___cxa_find_matching_catch_3(0|0)|0;
   $12 = tempRet0;
   ___clang_call_terminate($11);
   // unreachable;
  } else {
   $eh$lpad$body$index2Z2D = $7;$eh$lpad$body$indexZ2D = $6;
   __ZdlPv($0);
   ___resumeException($eh$lpad$body$indexZ2D|0);
   // unreachable;
  }
 }
 $3 = ((($0)) + 160|0);
 __THREW__ = 0;
 invoke_vi(388,($3|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  __ZdlPv($0);
  return;
 }
 $13 = ___cxa_find_matching_catch_2()|0;
 $14 = tempRet0;
 $eh$lpad$body$index2Z2D = $14;$eh$lpad$body$indexZ2D = $13;
 __ZdlPv($0);
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
}
function __ZNK7osgUtil19IntersectionVisitor11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (116801|0);
}
function __ZNK7osgUtil19IntersectionVisitor9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (110564|0);
}
function __ZN7osgUtil19IntersectionVisitor21asIntersectionVisitorEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ($0|0);
}
function __ZNK7osgUtil19IntersectionVisitor21asIntersectionVisitorEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ($0|0);
}
function __ZN7osgUtil19IntersectionVisitor5resetEv($0) {
 $0 = $0|0;
 var $$023$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 56|0);
 $2 = ((($0)) + 64|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  return;
 }
 $5 = ((($0)) + 60|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($6)) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if (!($9)) {
  $10 = ((($8)) + 8|0);
  $11 = HEAP32[$10>>2]|0;HEAP32[$10>>2] = (($11+1)|0);
 }
 $12 = HEAP32[$8>>2]|0;
 $13 = ((($12)) + 28|0);
 $14 = HEAP32[$13>>2]|0;
 __THREW__ = 0;
 invoke_vi($14|0,($8|0));
 $15 = __THREW__; __THREW__ = 0;
 $16 = $15&1;
 if (!($16)) {
  $17 = HEAP32[$2>>2]|0;
  $18 = ($17|0)==(0);
  L9: do {
   if (!($18)) {
    $19 = HEAP32[$5>>2]|0;
    $20 = HEAP32[$1>>2]|0;
    $21 = ((($20)) + 4|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = HEAP32[$19>>2]|0;
    $24 = ((($23)) + 4|0);
    HEAP32[$24>>2] = $22;
    $25 = HEAP32[$21>>2]|0;
    HEAP32[$25>>2] = $23;
    HEAP32[$2>>2] = 0;
    $26 = ($19|0)==($1|0);
    if (!($26)) {
     $$023$i$i = $19;
     while(1) {
      $27 = ((($$023$i$i)) + 4|0);
      $28 = HEAP32[$27>>2]|0;
      $29 = ((($$023$i$i)) + 8|0);
      $30 = HEAP32[$29>>2]|0;
      $31 = ($30|0)==(0|0);
      if (!($31)) {
       $32 = ((($30)) + 8|0);
       $33 = HEAP32[$32>>2]|0;HEAP32[$32>>2] = (($33-1)|0);
       $34 = ($33|0)==(1);
       if ($34) {
        __THREW__ = 0;
        invoke_viii(3262,($30|0),1,1);
        $35 = __THREW__; __THREW__ = 0;
        $36 = $35&1;
        if ($36) {
         break;
        }
       }
      }
      __ZdlPv($$023$i$i);
      $37 = ($28|0)==($1|0);
      if ($37) {
       break L9;
      } else {
       $$023$i$i = $28;
      }
     }
     $38 = ___cxa_find_matching_catch_2()|0;
     $39 = tempRet0;
     ___cxa_call_unexpected(($38|0));
     // unreachable;
    }
   }
  } while(0);
  __THREW__ = 0;
  $40 = (invoke_ii(3276,12)|0);
  $41 = __THREW__; __THREW__ = 0;
  $42 = $41&1;
  if (!($42)) {
   $43 = ((($40)) + 8|0);
   HEAP32[$43>>2] = $8;
   if (!($9)) {
    $44 = ((($8)) + 8|0);
    $45 = HEAP32[$44>>2]|0;HEAP32[$44>>2] = (($45+1)|0);
   }
   $46 = ((($40)) + 4|0);
   HEAP32[$46>>2] = $1;
   $47 = HEAP32[$1>>2]|0;
   HEAP32[$40>>2] = $47;
   $48 = ((($47)) + 4|0);
   HEAP32[$48>>2] = $40;
   HEAP32[$1>>2] = $40;
   $49 = HEAP32[$2>>2]|0;
   $50 = (($49) + 1)|0;
   HEAP32[$2>>2] = $50;
   if ($9) {
    return;
   }
   $51 = ((($8)) + 8|0);
   $52 = HEAP32[$51>>2]|0;HEAP32[$51>>2] = (($52-1)|0);
   $53 = ($52|0)==(1);
   if (!($53)) {
    return;
   }
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($8,1,1);
   return;
  }
 }
 $54 = ___cxa_find_matching_catch_2()|0;
 $55 = tempRet0;
 if ($9) {
  ___resumeException($54|0);
  // unreachable;
 }
 $56 = ((($8)) + 8|0);
 $57 = HEAP32[$56>>2]|0;HEAP32[$56>>2] = (($57-1)|0);
 $58 = ($57|0)==(1);
 if (!($58)) {
  ___resumeException($54|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(3262,($8|0),1,1);
 $59 = __THREW__; __THREW__ = 0;
 $60 = $59&1;
 if ($60) {
  $61 = ___cxa_find_matching_catch_3(0|0)|0;
  $62 = tempRet0;
  ___clang_call_terminate($61);
  // unreachable;
 } else {
  ___resumeException($54|0);
  // unreachable;
 }
}
function __ZNK7osgUtil19IntersectionVisitor11getEyePointEv($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$1 = 0, $$13 = 0, $$sroa$0$0$$sroa_idx = 0, $$sroa$5$0$$sroa_idx24 = 0, $$sroa$6$0$$sroa_idx27 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0.0, $122 = 0, $123 = 0.0, $124 = 0, $125 = 0, $126 = 0.0, $127 = 0, $128 = 0, $129 = 0.0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0.0, $133 = 0, $134 = 0, $135 = 0.0, $136 = 0, $137 = 0, $138 = 0.0, $139 = 0, $14 = 0, $140 = 0, $141 = 0.0, $142 = 0, $143 = 0, $144 = 0.0, $145 = 0, $146 = 0, $147 = 0.0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0.0, $151 = 0, $152 = 0, $153 = 0.0, $154 = 0, $155 = 0, $156 = 0.0, $157 = 0, $158 = 0, $159 = 0.0, $16 = 0, $160 = 0, $161 = 0, $162 = 0.0, $163 = 0, $164 = 0, $165 = 0.0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0.0, $171 = 0, $172 = 0, $173 = 0.0, $174 = 0, $175 = 0, $176 = 0.0, $177 = 0, $178 = 0, $179 = 0.0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0;
 var $186 = 0.0, $187 = 0, $188 = 0.0, $189 = 0.0, $19 = 0, $190 = 0.0, $191 = 0, $192 = 0.0, $193 = 0, $194 = 0.0, $195 = 0.0, $196 = 0.0, $197 = 0.0, $198 = 0, $199 = 0.0, $2 = 0, $20 = 0, $200 = 0, $201 = 0.0, $202 = 0.0;
 var $203 = 0.0, $204 = 0.0, $205 = 0, $206 = 0.0, $207 = 0.0, $208 = 0.0, $209 = 0.0, $21 = 0, $210 = 0.0, $211 = 0, $212 = 0.0, $213 = 0.0, $214 = 0.0, $215 = 0, $216 = 0.0, $217 = 0.0, $218 = 0.0, $219 = 0, $22 = 0, $220 = 0.0;
 var $221 = 0.0, $222 = 0.0, $223 = 0.0, $224 = 0, $225 = 0.0, $226 = 0.0, $227 = 0, $228 = 0.0, $229 = 0.0, $23 = 0, $230 = 0.0, $231 = 0, $232 = 0.0, $233 = 0.0, $234 = 0.0, $235 = 0, $236 = 0.0, $237 = 0.0, $238 = 0.0, $239 = 0.0;
 var $24 = 0, $240 = 0, $241 = 0.0, $242 = 0.0, $243 = 0, $244 = 0.0, $245 = 0.0, $246 = 0.0, $247 = 0, $248 = 0.0, $249 = 0.0, $25 = 0, $250 = 0.0, $251 = 0, $252 = 0.0, $253 = 0.0, $254 = 0.0, $255 = 0.0, $256 = 0, $257 = 0;
 var $258 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 256|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(256|0);
 $2 = sp + 128|0;
 $3 = sp;
 $4 = ((($1)) + 144|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)==(0);
 if ($6) {
  $7 = ((($1)) + 148|0);
  ;HEAP32[$0>>2]=HEAP32[$7>>2]|0;HEAP32[$0+4>>2]=HEAP32[$7+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$7+8>>2]|0;
  STACKTOP = sp;return;
 }
 __ZN3osg7Matrixd12makeIdentityEv($2);
 $8 = ((($1)) + 136|0);
 $9 = HEAP32[$8>>2]|0;
 L5: do {
  switch ($9|0) {
  case 0:  {
   $10 = ((($1)) + 84|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = ($11|0)==(0);
   if (!($12)) {
    $13 = ((($1)) + 76|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ((($14)) + 8|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = ($16|0)==(0|0);
    if (!($17)) {
     $18 = ((($16)) + 32|0);
     __THREW__ = 0;
     invoke_vii(3546,($2|0),($18|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break L5;
     }
    }
   }
   $23 = ((($1)) + 96|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = ($24|0)==(0);
   if (!($25)) {
    $26 = ((($1)) + 88|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = ((($27)) + 8|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = ($29|0)==(0|0);
    if (!($30)) {
     $31 = ((($29)) + 32|0);
     __THREW__ = 0;
     invoke_vii(3546,($2|0),($31|0));
     $32 = __THREW__; __THREW__ = 0;
     $33 = $32&1;
     if ($33) {
      break L5;
     }
    }
   }
   $34 = ((($1)) + 108|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ($35|0)==(0);
   if (!($36)) {
    $37 = ((($1)) + 100|0);
    $38 = HEAP32[$37>>2]|0;
    $39 = ((($38)) + 8|0);
    $40 = HEAP32[$39>>2]|0;
    $41 = ($40|0)==(0|0);
    if (!($41)) {
     $42 = ((($40)) + 32|0);
     __THREW__ = 0;
     invoke_vii(3546,($2|0),($42|0));
     $43 = __THREW__; __THREW__ = 0;
     $44 = $43&1;
     if ($44) {
      break L5;
     }
    }
   }
   $45 = ((($1)) + 120|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = ($46|0)==(0);
   if ($47) {
    label = 36;
   } else {
    $48 = ((($1)) + 112|0);
    $49 = HEAP32[$48>>2]|0;
    $50 = ((($49)) + 8|0);
    $51 = HEAP32[$50>>2]|0;
    $52 = ($51|0)==(0|0);
    if ($52) {
     label = 36;
    } else {
     $53 = ((($51)) + 32|0);
     __THREW__ = 0;
     invoke_vii(3546,($2|0),($53|0));
     $54 = __THREW__; __THREW__ = 0;
     $55 = $54&1;
     if (!($55)) {
      label = 36;
     }
    }
   }
   break;
  }
  case 1:  {
   $56 = ((($1)) + 96|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = ($57|0)==(0);
   if (!($58)) {
    $59 = ((($1)) + 88|0);
    $60 = HEAP32[$59>>2]|0;
    $61 = ((($60)) + 8|0);
    $62 = HEAP32[$61>>2]|0;
    $63 = ($62|0)==(0|0);
    if (!($63)) {
     $64 = ((($62)) + 32|0);
     __THREW__ = 0;
     invoke_vii(3546,($2|0),($64|0));
     $65 = __THREW__; __THREW__ = 0;
     $66 = $65&1;
     if ($66) {
      break L5;
     }
    }
   }
   $67 = ((($1)) + 108|0);
   $68 = HEAP32[$67>>2]|0;
   $69 = ($68|0)==(0);
   if (!($69)) {
    $70 = ((($1)) + 100|0);
    $71 = HEAP32[$70>>2]|0;
    $72 = ((($71)) + 8|0);
    $73 = HEAP32[$72>>2]|0;
    $74 = ($73|0)==(0|0);
    if (!($74)) {
     $75 = ((($73)) + 32|0);
     __THREW__ = 0;
     invoke_vii(3546,($2|0),($75|0));
     $76 = __THREW__; __THREW__ = 0;
     $77 = $76&1;
     if ($77) {
      break L5;
     }
    }
   }
   $78 = ((($1)) + 120|0);
   $79 = HEAP32[$78>>2]|0;
   $80 = ($79|0)==(0);
   if ($80) {
    label = 36;
   } else {
    $81 = ((($1)) + 112|0);
    $82 = HEAP32[$81>>2]|0;
    $83 = ((($82)) + 8|0);
    $84 = HEAP32[$83>>2]|0;
    $85 = ($84|0)==(0|0);
    if ($85) {
     label = 36;
    } else {
     $86 = ((($84)) + 32|0);
     __THREW__ = 0;
     invoke_vii(3546,($2|0),($86|0));
     $87 = __THREW__; __THREW__ = 0;
     $88 = $87&1;
     if (!($88)) {
      label = 36;
     }
    }
   }
   break;
  }
  case 2:  {
   $89 = ((($1)) + 108|0);
   $90 = HEAP32[$89>>2]|0;
   $91 = ($90|0)==(0);
   if (!($91)) {
    $92 = ((($1)) + 100|0);
    $93 = HEAP32[$92>>2]|0;
    $94 = ((($93)) + 8|0);
    $95 = HEAP32[$94>>2]|0;
    $96 = ($95|0)==(0|0);
    if (!($96)) {
     $97 = ((($95)) + 32|0);
     __THREW__ = 0;
     invoke_vii(3546,($2|0),($97|0));
     $98 = __THREW__; __THREW__ = 0;
     $99 = $98&1;
     if ($99) {
      break L5;
     }
    }
   }
   $100 = ((($1)) + 120|0);
   $101 = HEAP32[$100>>2]|0;
   $102 = ($101|0)==(0);
   if ($102) {
    label = 36;
   } else {
    $103 = ((($1)) + 112|0);
    $104 = HEAP32[$103>>2]|0;
    $105 = ((($104)) + 8|0);
    $106 = HEAP32[$105>>2]|0;
    $107 = ($106|0)==(0|0);
    if ($107) {
     label = 36;
    } else {
     $108 = ((($106)) + 32|0);
     __THREW__ = 0;
     invoke_vii(3546,($2|0),($108|0));
     $109 = __THREW__; __THREW__ = 0;
     $110 = $109&1;
     if (!($110)) {
      label = 36;
     }
    }
   }
   break;
  }
  case 3:  {
   $111 = ((($1)) + 120|0);
   $112 = HEAP32[$111>>2]|0;
   $113 = ($112|0)==(0);
   if ($113) {
    label = 36;
   } else {
    $114 = ((($1)) + 112|0);
    $115 = HEAP32[$114>>2]|0;
    $116 = ((($115)) + 8|0);
    $117 = HEAP32[$116>>2]|0;
    $118 = ($117|0)==(0|0);
    if ($118) {
     label = 36;
    } else {
     $119 = ((($117)) + 32|0);
     $120 = ($119|0)==($2|0);
     if ($120) {
      label = 36;
     } else {
      $121 = +HEAPF64[$119>>3];
      HEAPF64[$2>>3] = $121;
      $122 = ((($117)) + 40|0);
      $123 = +HEAPF64[$122>>3];
      $124 = ((($2)) + 8|0);
      HEAPF64[$124>>3] = $123;
      $125 = ((($117)) + 48|0);
      $126 = +HEAPF64[$125>>3];
      $127 = ((($2)) + 16|0);
      HEAPF64[$127>>3] = $126;
      $128 = ((($117)) + 56|0);
      $129 = +HEAPF64[$128>>3];
      $130 = ((($2)) + 24|0);
      HEAPF64[$130>>3] = $129;
      $131 = ((($117)) + 64|0);
      $132 = +HEAPF64[$131>>3];
      $133 = ((($2)) + 32|0);
      HEAPF64[$133>>3] = $132;
      $134 = ((($117)) + 72|0);
      $135 = +HEAPF64[$134>>3];
      $136 = ((($2)) + 40|0);
      HEAPF64[$136>>3] = $135;
      $137 = ((($117)) + 80|0);
      $138 = +HEAPF64[$137>>3];
      $139 = ((($2)) + 48|0);
      HEAPF64[$139>>3] = $138;
      $140 = ((($117)) + 88|0);
      $141 = +HEAPF64[$140>>3];
      $142 = ((($2)) + 56|0);
      HEAPF64[$142>>3] = $141;
      $143 = ((($117)) + 96|0);
      $144 = +HEAPF64[$143>>3];
      $145 = ((($2)) + 64|0);
      HEAPF64[$145>>3] = $144;
      $146 = ((($117)) + 104|0);
      $147 = +HEAPF64[$146>>3];
      $148 = ((($2)) + 72|0);
      HEAPF64[$148>>3] = $147;
      $149 = ((($117)) + 112|0);
      $150 = +HEAPF64[$149>>3];
      $151 = ((($2)) + 80|0);
      HEAPF64[$151>>3] = $150;
      $152 = ((($117)) + 120|0);
      $153 = +HEAPF64[$152>>3];
      $154 = ((($2)) + 88|0);
      HEAPF64[$154>>3] = $153;
      $155 = ((($117)) + 128|0);
      $156 = +HEAPF64[$155>>3];
      $157 = ((($2)) + 96|0);
      HEAPF64[$157>>3] = $156;
      $158 = ((($117)) + 136|0);
      $159 = +HEAPF64[$158>>3];
      $160 = ((($2)) + 104|0);
      HEAPF64[$160>>3] = $159;
      $161 = ((($117)) + 144|0);
      $162 = +HEAPF64[$161>>3];
      $163 = ((($2)) + 112|0);
      HEAPF64[$163>>3] = $162;
      $164 = ((($117)) + 152|0);
      $165 = +HEAPF64[$164>>3];
      $166 = ((($2)) + 120|0);
      HEAPF64[$166>>3] = $165;
      label = 36;
     }
    }
   }
   break;
  }
  default: {
   label = 36;
  }
  }
 } while(0);
 if ((label|0) == 36) {
  __THREW__ = 0;
  invoke_vi(3299,($3|0));
  $167 = __THREW__; __THREW__ = 0;
  $168 = $167&1;
  if (!($168)) {
   $169 = ((($2)) + 24|0);
   $170 = +HEAPF64[$169>>3];
   $171 = $170 == 0.0;
   if ($171) {
    $172 = ((($2)) + 56|0);
    $173 = +HEAPF64[$172>>3];
    $174 = $173 == 0.0;
    if ($174) {
     $175 = ((($2)) + 88|0);
     $176 = +HEAPF64[$175>>3];
     $177 = $176 == 0.0;
     if ($177) {
      $178 = ((($2)) + 120|0);
      $179 = +HEAPF64[$178>>3];
      $180 = $179 == 1.0;
      if ($180) {
       __THREW__ = 0;
       (invoke_iii(3303,($3|0),($2|0))|0);
       $181 = __THREW__; __THREW__ = 0;
       $182 = $181&1;
       if ($182) {
        label = 44;
       } else {
        label = 43;
       }
      } else {
       label = 42;
      }
     } else {
      label = 42;
     }
    } else {
     label = 42;
    }
   } else {
    label = 42;
   }
   if ((label|0) == 42) {
    __THREW__ = 0;
    (invoke_iii(3304,($3|0),($2|0))|0);
    $183 = __THREW__; __THREW__ = 0;
    $184 = $183&1;
    if ($184) {
     label = 44;
    } else {
     label = 43;
    }
   }
   if ((label|0) == 43) {
    $185 = ((($3)) + 24|0);
    $186 = +HEAPF64[$185>>3];
    $187 = ((($1)) + 124|0);
    $188 = +HEAPF32[$187>>2];
    $189 = $188;
    $190 = $186 * $189;
    $191 = ((($3)) + 56|0);
    $192 = +HEAPF64[$191>>3];
    $193 = ((($1)) + 128|0);
    $194 = +HEAPF32[$193>>2];
    $195 = $194;
    $196 = $192 * $195;
    $197 = $190 + $196;
    $198 = ((($3)) + 88|0);
    $199 = +HEAPF64[$198>>3];
    $200 = ((($1)) + 132|0);
    $201 = +HEAPF32[$200>>2];
    $202 = $201;
    $203 = $199 * $202;
    $204 = $197 + $203;
    $205 = ((($3)) + 120|0);
    $206 = +HEAPF64[$205>>3];
    $207 = $206 + $204;
    $208 = 1.0 / $207;
    $209 = +HEAPF64[$3>>3];
    $210 = $189 * $209;
    $211 = ((($3)) + 32|0);
    $212 = +HEAPF64[$211>>3];
    $213 = $195 * $212;
    $214 = $210 + $213;
    $215 = ((($3)) + 64|0);
    $216 = +HEAPF64[$215>>3];
    $217 = $202 * $216;
    $218 = $214 + $217;
    $219 = ((($3)) + 96|0);
    $220 = +HEAPF64[$219>>3];
    $221 = $220 + $218;
    $222 = $208 * $221;
    $223 = $222;
    $224 = ((($3)) + 8|0);
    $225 = +HEAPF64[$224>>3];
    $226 = $189 * $225;
    $227 = ((($3)) + 40|0);
    $228 = +HEAPF64[$227>>3];
    $229 = $195 * $228;
    $230 = $226 + $229;
    $231 = ((($3)) + 72|0);
    $232 = +HEAPF64[$231>>3];
    $233 = $202 * $232;
    $234 = $230 + $233;
    $235 = ((($3)) + 104|0);
    $236 = +HEAPF64[$235>>3];
    $237 = $236 + $234;
    $238 = $208 * $237;
    $239 = $238;
    $240 = ((($3)) + 16|0);
    $241 = +HEAPF64[$240>>3];
    $242 = $189 * $241;
    $243 = ((($3)) + 48|0);
    $244 = +HEAPF64[$243>>3];
    $245 = $195 * $244;
    $246 = $242 + $245;
    $247 = ((($3)) + 80|0);
    $248 = +HEAPF64[$247>>3];
    $249 = $202 * $248;
    $250 = $246 + $249;
    $251 = ((($3)) + 112|0);
    $252 = +HEAPF64[$251>>3];
    $253 = $252 + $250;
    $254 = $208 * $253;
    $255 = $254;
    $256 = ((($1)) + 148|0);
    $$sroa$0$0$$sroa_idx = ((($1)) + 148|0);
    HEAPF32[$$sroa$0$0$$sroa_idx>>2] = $223;
    $$sroa$5$0$$sroa_idx24 = ((($1)) + 152|0);
    HEAPF32[$$sroa$5$0$$sroa_idx24>>2] = $239;
    $$sroa$6$0$$sroa_idx27 = ((($1)) + 156|0);
    HEAPF32[$$sroa$6$0$$sroa_idx27>>2] = $255;
    HEAP8[$4>>0] = 0;
    ;HEAP32[$0>>2]=HEAP32[$256>>2]|0;HEAP32[$0+4>>2]=HEAP32[$256+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$256+8>>2]|0;
    STACKTOP = sp;return;
   }
   else if ((label|0) == 44) {
    $257 = ___cxa_find_matching_catch_2()|0;
    $258 = tempRet0;
    $$1 = $258;$$13 = $257;
    ___resumeException($$13|0);
    // unreachable;
   }
  }
 }
 $21 = ___cxa_find_matching_catch_2()|0;
 $22 = tempRet0;
 $$1 = $22;$$13 = $21;
 ___resumeException($$13|0);
 // unreachable;
}
function __ZNK7osgUtil19IntersectionVisitor21getDistanceToEyePointERKN3osg5Vec3fEb($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0.0, $10 = 0.0, $11 = 0.0, $12 = 0.0, $13 = 0, $14 = 0.0, $15 = 0, $16 = 0.0, $17 = 0.0, $18 = 0, $19 = 0.0, $20 = 0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0.0, $25 = 0.0, $26 = 0.0, $27 = 0.0, $28 = 0.0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = ((($0)) + 140|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(1);
 if (!($6)) {
  $$0 = 0.0;
  STACKTOP = sp;return (+$$0);
 }
 $7 = HEAP32[$0>>2]|0;
 $8 = ((($7)) + 80|0);
 $9 = HEAP32[$8>>2]|0;
 FUNCTION_TABLE_vii[$9 & 8191]($3,$0);
 $10 = +HEAPF32[$1>>2];
 $11 = +HEAPF32[$3>>2];
 $12 = $10 - $11;
 $13 = ((($1)) + 4|0);
 $14 = +HEAPF32[$13>>2];
 $15 = ((($3)) + 4|0);
 $16 = +HEAPF32[$15>>2];
 $17 = $14 - $16;
 $18 = ((($1)) + 8|0);
 $19 = +HEAPF32[$18>>2];
 $20 = ((($3)) + 8|0);
 $21 = +HEAPF32[$20>>2];
 $22 = $19 - $21;
 $23 = $12 * $12;
 $24 = $17 * $17;
 $25 = $23 + $24;
 $26 = $22 * $22;
 $27 = $25 + $26;
 $28 = (+Math_sqrt((+$27)));
 $$0 = $28;
 STACKTOP = sp;return (+$$0);
}
function __ZN7osgUtil19IntersectionVisitor5applyERN3osg8DrawableE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 56|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($6)) + 24|0);
 $8 = HEAP32[$7>>2]|0;
 FUNCTION_TABLE_viii[$8 & 8191]($5,$0,$1);
 return;
}
function __ZN7osgUtil19IntersectionVisitor5applyERN3osg4NodeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 64|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  return;
 }
 $5 = ((($0)) + 56|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($6)) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($9)) + 16|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (FUNCTION_TABLE_iii[$11 & 8191]($8,$1)|0);
 if (!($12)) {
  return;
 }
 $13 = ((($0)) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 switch ($14|0) {
 case 1:  {
  $15 = HEAP32[$1>>2]|0;
  $16 = ((($15)) + 192|0);
  $17 = HEAP32[$16>>2]|0;
  FUNCTION_TABLE_vii[$17 & 8191]($1,$0);
  break;
 }
 case 0:  {
  break;
 }
 default: {
  $18 = HEAP32[$1>>2]|0;
  $19 = ((($18)) + 196|0);
  $20 = HEAP32[$19>>2]|0;
  FUNCTION_TABLE_vii[$20 & 8191]($1,$0);
 }
 }
 $21 = HEAP32[$5>>2]|0;
 $22 = ((($21)) + 8|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = HEAP32[$23>>2]|0;
 $25 = ((($24)) + 20|0);
 $26 = HEAP32[$25>>2]|0;
 FUNCTION_TABLE_vi[$26 & 8191]($23);
 return;
}
function __ZN7osgUtil19IntersectionVisitor5applyERN3osg5GeodeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$07 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 64|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  return;
 }
 $5 = ((($0)) + 56|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($6)) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($9)) + 16|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (FUNCTION_TABLE_iii[$11 & 8191]($8,$1)|0);
 if (!($12)) {
  return;
 }
 $13 = HEAP32[$1>>2]|0;
 $14 = ((($13)) + 224|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (FUNCTION_TABLE_ii[$15 & 8191]($1)|0);
 $17 = ($16|0)==(0);
 if (!($17)) {
  $18 = ((($1)) + 124|0);
  $$07 = 0;
  while(1) {
   $25 = HEAP32[$18>>2]|0;
   $26 = (($25) + ($$07<<2)|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = ($27|0)==(0|0);
   if ($28) {
    $39 = 0;
   } else {
    $29 = HEAP32[$27>>2]|0;
    $30 = ((($29)) + 80|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = (FUNCTION_TABLE_ii[$31 & 8191]($27)|0);
    $39 = $32;
   }
   $33 = HEAP32[$5>>2]|0;
   $34 = ((($33)) + 8|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = HEAP32[$35>>2]|0;
   $37 = ((($36)) + 24|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_viii[$38 & 8191]($35,$0,$39);
   $40 = (($$07) + 1)|0;
   $41 = HEAP32[$1>>2]|0;
   $42 = ((($41)) + 224|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = (FUNCTION_TABLE_ii[$43 & 8191]($1)|0);
   $45 = ($40>>>0)<($44>>>0);
   if ($45) {
    $$07 = $40;
   } else {
    break;
   }
  }
 }
 $19 = HEAP32[$5>>2]|0;
 $20 = ((($19)) + 8|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = HEAP32[$21>>2]|0;
 $23 = ((($22)) + 20|0);
 $24 = HEAP32[$23>>2]|0;
 FUNCTION_TABLE_vi[$24 & 8191]($21);
 return;
}
function __ZN7osgUtil19IntersectionVisitor5applyERN3osg9BillboardE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$02069 = 0, $$1 = 0, $$118 = 0, $$2 = 0, $$219 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0.0, $103 = 0, $104 = 0, $105 = 0.0, $106 = 0, $107 = 0, $108 = 0.0, $109 = 0, $11 = 0, $110 = 0, $111 = 0.0, $112 = 0;
 var $113 = 0, $114 = 0.0, $115 = 0, $116 = 0, $117 = 0.0, $118 = 0, $119 = 0, $12 = 0, $120 = 0.0, $121 = 0, $122 = 0, $123 = 0.0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0.0, $133 = 0, $134 = 0.0, $135 = 0, $136 = 0, $137 = 0.0, $138 = 0, $139 = 0, $14 = 0, $140 = 0.0, $141 = 0, $142 = 0, $143 = 0.0, $144 = 0, $145 = 0, $146 = 0.0, $147 = 0, $148 = 0, $149 = 0.0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0.0, $153 = 0, $154 = 0, $155 = 0.0, $156 = 0, $157 = 0, $158 = 0.0, $159 = 0, $16 = 0, $160 = 0, $161 = 0.0, $162 = 0, $163 = 0, $164 = 0.0, $165 = 0, $166 = 0, $167 = 0.0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0.0, $171 = 0, $172 = 0, $173 = 0.0, $174 = 0, $175 = 0, $176 = 0.0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0;
 var $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0.0, $191 = 0, $192 = 0, $193 = 0.0, $194 = 0, $195 = 0, $196 = 0.0, $197 = 0, $198 = 0, $199 = 0.0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0;
 var $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0;
 var $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0;
 var $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0;
 var $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0;
 var $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0;
 var $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0;
 var $311 = 0, $312 = 0, $313 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0.0, $8 = 0, $80 = 0, $81 = 0.0, $82 = 0, $83 = 0;
 var $84 = 0.0, $85 = 0, $86 = 0, $87 = 0.0, $88 = 0, $89 = 0, $9 = 0, $90 = 0.0, $91 = 0, $92 = 0, $93 = 0.0, $94 = 0, $95 = 0, $96 = 0.0, $97 = 0, $98 = 0, $99 = 0.0, $eh$lpad$body$index4Z2D = 0, $eh$lpad$body$indexZ2D = 0, $eh$lpad$body35$index11Z2D = 0;
 var $eh$lpad$body35$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(144|0);
 $2 = sp + 128|0;
 $3 = sp;
 $4 = ((($0)) + 64|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = ((($0)) + 56|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($8)) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11)) + 16|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (FUNCTION_TABLE_iii[$13 & 8191]($10,$1)|0);
 if (!($14)) {
  STACKTOP = sp;return;
 }
 $15 = HEAP32[$0>>2]|0;
 $16 = ((($15)) + 80|0);
 $17 = HEAP32[$16>>2]|0;
 FUNCTION_TABLE_vii[$17 & 8191]($2,$0);
 $18 = HEAP32[$1>>2]|0;
 $19 = ((($18)) + 224|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (FUNCTION_TABLE_ii[$20 & 8191]($1)|0);
 $22 = ($21|0)==(0);
 L7: do {
  if (!($22)) {
   $23 = ((($1)) + 320|0);
   $24 = ((($0)) + 108|0);
   $25 = ((($0)) + 120|0);
   $26 = ((($0)) + 112|0);
   $27 = ((($0)) + 60|0);
   $28 = ((($1)) + 124|0);
   $29 = ((($0)) + 56|0);
   $30 = ((($0)) + 112|0);
   $31 = ((($0)) + 144|0);
   $32 = ((($0)) + 100|0);
   $$02069 = 0;
   L9: while(1) {
    $39 = HEAP32[$23>>2]|0;
    $40 = (($39) + (($$02069*12)|0)|0);
    $41 = (__Znwj(160)|0);
    __THREW__ = 0;
    invoke_vii(3435,($41|0),0);
    $42 = __THREW__; __THREW__ = 0;
    $43 = $42&1;
    if ($43) {
     label = 15;
     break;
    }
    HEAP32[$41>>2] = (63412);
    $44 = ((($41)) + 12|0);
    ;HEAP32[$44>>2]=0|0;HEAP32[$44+4>>2]=0|0;HEAP32[$44+8>>2]=0|0;
    $45 = ((($41)) + 24|0);
    HEAP32[$45>>2] = 2;
    $46 = ((($41)) + 28|0);
    HEAP32[$46>>2] = 0;
    $47 = ((($41)) + 32|0);
    __THREW__ = 0;
    invoke_vi(3299,($47|0));
    $48 = __THREW__; __THREW__ = 0;
    $49 = $48&1;
    if ($49) {
     label = 8;
     break;
    }
    HEAP32[$41>>2] = (47588);
    $56 = ((($41)) + 8|0);
    $57 = HEAP32[$56>>2]|0;HEAP32[$56>>2] = (($57+1)|0);
    $58 = HEAP32[$24>>2]|0;
    $59 = ($58|0)==(0);
    do {
     if ($59) {
      label = 20;
     } else {
      $60 = HEAP32[$32>>2]|0;
      $61 = ((($60)) + 8|0);
      $62 = HEAP32[$61>>2]|0;
      $63 = ($62|0)==(0|0);
      if ($63) {
       label = 20;
      } else {
       $64 = HEAP32[$25>>2]|0;
       $65 = ($64|0)==(0);
       if (!($65)) {
        $66 = HEAP32[$26>>2]|0;
        $67 = ((($66)) + 8|0);
        $68 = HEAP32[$67>>2]|0;
        $69 = ($68|0)==(0|0);
        if (!($69)) {
         $70 = ((($68)) + 32|0);
         $71 = ((($62)) + 32|0);
         __THREW__ = 0;
         invoke_viii(3300,($47|0),($70|0),($71|0));
         $72 = __THREW__; __THREW__ = 0;
         $73 = $72&1;
         if ($73) {
          label = 17;
          break L9;
         } else {
          break;
         }
        }
       }
       $78 = ((($62)) + 32|0);
       $79 = +HEAPF64[$78>>3];
       HEAPF64[$47>>3] = $79;
       $80 = ((($62)) + 40|0);
       $81 = +HEAPF64[$80>>3];
       $82 = ((($41)) + 40|0);
       HEAPF64[$82>>3] = $81;
       $83 = ((($62)) + 48|0);
       $84 = +HEAPF64[$83>>3];
       $85 = ((($41)) + 48|0);
       HEAPF64[$85>>3] = $84;
       $86 = ((($62)) + 56|0);
       $87 = +HEAPF64[$86>>3];
       $88 = ((($41)) + 56|0);
       HEAPF64[$88>>3] = $87;
       $89 = ((($62)) + 64|0);
       $90 = +HEAPF64[$89>>3];
       $91 = ((($41)) + 64|0);
       HEAPF64[$91>>3] = $90;
       $92 = ((($62)) + 72|0);
       $93 = +HEAPF64[$92>>3];
       $94 = ((($41)) + 72|0);
       HEAPF64[$94>>3] = $93;
       $95 = ((($62)) + 80|0);
       $96 = +HEAPF64[$95>>3];
       $97 = ((($41)) + 80|0);
       HEAPF64[$97>>3] = $96;
       $98 = ((($62)) + 88|0);
       $99 = +HEAPF64[$98>>3];
       $100 = ((($41)) + 88|0);
       HEAPF64[$100>>3] = $99;
       $101 = ((($62)) + 96|0);
       $102 = +HEAPF64[$101>>3];
       $103 = ((($41)) + 96|0);
       HEAPF64[$103>>3] = $102;
       $104 = ((($62)) + 104|0);
       $105 = +HEAPF64[$104>>3];
       $106 = ((($41)) + 104|0);
       HEAPF64[$106>>3] = $105;
       $107 = ((($62)) + 112|0);
       $108 = +HEAPF64[$107>>3];
       $109 = ((($41)) + 112|0);
       HEAPF64[$109>>3] = $108;
       $110 = ((($62)) + 120|0);
       $111 = +HEAPF64[$110>>3];
       $112 = ((($41)) + 120|0);
       HEAPF64[$112>>3] = $111;
       $113 = ((($62)) + 128|0);
       $114 = +HEAPF64[$113>>3];
       $115 = ((($41)) + 128|0);
       HEAPF64[$115>>3] = $114;
       $116 = ((($62)) + 136|0);
       $117 = +HEAPF64[$116>>3];
       $118 = ((($41)) + 136|0);
       HEAPF64[$118>>3] = $117;
       $119 = ((($62)) + 144|0);
       $120 = +HEAPF64[$119>>3];
       $121 = ((($41)) + 144|0);
       HEAPF64[$121>>3] = $120;
       $122 = ((($62)) + 152|0);
       $123 = +HEAPF64[$122>>3];
       $124 = ((($41)) + 152|0);
       HEAPF64[$124>>3] = $123;
      }
     }
    } while(0);
    if ((label|0) == 20) {
     label = 0;
     $125 = HEAP32[$25>>2]|0;
     $126 = ($125|0)==(0);
     if (!($126)) {
      $127 = HEAP32[$26>>2]|0;
      $128 = ((($127)) + 8|0);
      $129 = HEAP32[$128>>2]|0;
      $130 = ($129|0)==(0|0);
      if (!($130)) {
       $131 = ((($129)) + 32|0);
       $132 = +HEAPF64[$131>>3];
       HEAPF64[$47>>3] = $132;
       $133 = ((($129)) + 40|0);
       $134 = +HEAPF64[$133>>3];
       $135 = ((($41)) + 40|0);
       HEAPF64[$135>>3] = $134;
       $136 = ((($129)) + 48|0);
       $137 = +HEAPF64[$136>>3];
       $138 = ((($41)) + 48|0);
       HEAPF64[$138>>3] = $137;
       $139 = ((($129)) + 56|0);
       $140 = +HEAPF64[$139>>3];
       $141 = ((($41)) + 56|0);
       HEAPF64[$141>>3] = $140;
       $142 = ((($129)) + 64|0);
       $143 = +HEAPF64[$142>>3];
       $144 = ((($41)) + 64|0);
       HEAPF64[$144>>3] = $143;
       $145 = ((($129)) + 72|0);
       $146 = +HEAPF64[$145>>3];
       $147 = ((($41)) + 72|0);
       HEAPF64[$147>>3] = $146;
       $148 = ((($129)) + 80|0);
       $149 = +HEAPF64[$148>>3];
       $150 = ((($41)) + 80|0);
       HEAPF64[$150>>3] = $149;
       $151 = ((($129)) + 88|0);
       $152 = +HEAPF64[$151>>3];
       $153 = ((($41)) + 88|0);
       HEAPF64[$153>>3] = $152;
       $154 = ((($129)) + 96|0);
       $155 = +HEAPF64[$154>>3];
       $156 = ((($41)) + 96|0);
       HEAPF64[$156>>3] = $155;
       $157 = ((($129)) + 104|0);
       $158 = +HEAPF64[$157>>3];
       $159 = ((($41)) + 104|0);
       HEAPF64[$159>>3] = $158;
       $160 = ((($129)) + 112|0);
       $161 = +HEAPF64[$160>>3];
       $162 = ((($41)) + 112|0);
       HEAPF64[$162>>3] = $161;
       $163 = ((($129)) + 120|0);
       $164 = +HEAPF64[$163>>3];
       $165 = ((($41)) + 120|0);
       HEAPF64[$165>>3] = $164;
       $166 = ((($129)) + 128|0);
       $167 = +HEAPF64[$166>>3];
       $168 = ((($41)) + 128|0);
       HEAPF64[$168>>3] = $167;
       $169 = ((($129)) + 136|0);
       $170 = +HEAPF64[$169>>3];
       $171 = ((($41)) + 136|0);
       HEAPF64[$171>>3] = $170;
       $172 = ((($129)) + 144|0);
       $173 = +HEAPF64[$172>>3];
       $174 = ((($41)) + 144|0);
       HEAPF64[$174>>3] = $173;
       $175 = ((($129)) + 152|0);
       $176 = +HEAPF64[$175>>3];
       $177 = ((($41)) + 152|0);
       HEAPF64[$177>>3] = $176;
      }
     }
    }
    __THREW__ = 0;
    (invoke_iiiii(3547,($1|0),($47|0),($2|0),($40|0))|0);
    $178 = __THREW__; __THREW__ = 0;
    $179 = $178&1;
    if ($179) {
     label = 17;
     break;
    }
    $180 = HEAP32[$24>>2]|0;
    $181 = ($180|0)==(0);
    if (!($181)) {
     $182 = HEAP32[$32>>2]|0;
     $183 = ((($182)) + 8|0);
     $184 = HEAP32[$183>>2]|0;
     $185 = ($184|0)==(0|0);
     if (!($185)) {
      $186 = ((($184)) + 32|0);
      __THREW__ = 0;
      invoke_vi(3299,($3|0));
      $187 = __THREW__; __THREW__ = 0;
      $188 = $187&1;
      if ($188) {
       label = 35;
       break;
      }
      $189 = ((($184)) + 56|0);
      $190 = +HEAPF64[$189>>3];
      $191 = $190 == 0.0;
      if ($191) {
       $192 = ((($184)) + 88|0);
       $193 = +HEAPF64[$192>>3];
       $194 = $193 == 0.0;
       if ($194) {
        $195 = ((($184)) + 120|0);
        $196 = +HEAPF64[$195>>3];
        $197 = $196 == 0.0;
        if ($197) {
         $198 = ((($184)) + 152|0);
         $199 = +HEAPF64[$198>>3];
         $200 = $199 == 1.0;
         if ($200) {
          __THREW__ = 0;
          (invoke_iii(3303,($3|0),($186|0))|0);
          $201 = __THREW__; __THREW__ = 0;
          $202 = $201&1;
          if ($202) {
           label = 35;
           break;
          }
         } else {
          label = 32;
         }
        } else {
         label = 32;
        }
       } else {
        label = 32;
       }
      } else {
       label = 32;
      }
      if ((label|0) == 32) {
       label = 0;
       __THREW__ = 0;
       (invoke_iii(3304,($3|0),($186|0))|0);
       $203 = __THREW__; __THREW__ = 0;
       $204 = $203&1;
       if ($204) {
        label = 35;
        break;
       }
      }
      __THREW__ = 0;
      invoke_vii(3302,($47|0),($3|0));
      $205 = __THREW__; __THREW__ = 0;
      $206 = $205&1;
      if ($206) {
       label = 35;
       break;
      }
     }
    }
    __THREW__ = 0;
    invoke_vii(3548,($0|0),($41|0));
    $209 = __THREW__; __THREW__ = 0;
    $210 = $209&1;
    if ($210) {
     label = 17;
     break;
    }
    $211 = HEAP32[$27>>2]|0;
    $212 = ((($211)) + 8|0);
    $213 = HEAP32[$212>>2]|0;
    $214 = HEAP32[$213>>2]|0;
    $215 = ((($214)) + 12|0);
    $216 = HEAP32[$215>>2]|0;
    __THREW__ = 0;
    $217 = (invoke_iii($216|0,($213|0),($0|0))|0);
    $218 = __THREW__; __THREW__ = 0;
    $219 = $218&1;
    if ($219) {
     label = 17;
     break;
    }
    $220 = ($217|0)==(0|0);
    if (!($220)) {
     $221 = ((($217)) + 8|0);
     $222 = HEAP32[$221>>2]|0;HEAP32[$221>>2] = (($222+1)|0);
    }
    __THREW__ = 0;
    $223 = (invoke_ii(3276,12)|0);
    $224 = __THREW__; __THREW__ = 0;
    $225 = $224&1;
    if ($225) {
     label = 46;
     break;
    }
    $226 = ((($223)) + 8|0);
    HEAP32[$226>>2] = $217;
    if (!($220)) {
     $227 = ((($217)) + 8|0);
     $228 = HEAP32[$227>>2]|0;HEAP32[$227>>2] = (($228+1)|0);
    }
    $229 = ((($223)) + 4|0);
    HEAP32[$229>>2] = $7;
    $230 = HEAP32[$7>>2]|0;
    HEAP32[$223>>2] = $230;
    $231 = ((($230)) + 4|0);
    HEAP32[$231>>2] = $223;
    HEAP32[$7>>2] = $223;
    $232 = HEAP32[$4>>2]|0;
    $233 = (($232) + 1)|0;
    HEAP32[$4>>2] = $233;
    if (!($220)) {
     $234 = ((($217)) + 8|0);
     $235 = HEAP32[$234>>2]|0;HEAP32[$234>>2] = (($235-1)|0);
     $236 = ($235|0)==(1);
     if ($236) {
      __THREW__ = 0;
      invoke_viii(3262,($217|0),1,1);
      $237 = __THREW__; __THREW__ = 0;
      $238 = $237&1;
      if ($238) {
       label = 17;
       break;
      }
     }
    }
    $248 = HEAP32[$28>>2]|0;
    $249 = (($248) + ($$02069<<2)|0);
    $250 = HEAP32[$249>>2]|0;
    $251 = ($250|0)==(0|0);
    if ($251) {
     $264 = 0;
    } else {
     $252 = HEAP32[$250>>2]|0;
     $253 = ((($252)) + 80|0);
     $254 = HEAP32[$253>>2]|0;
     __THREW__ = 0;
     $255 = (invoke_ii($254|0,($250|0))|0);
     $256 = __THREW__; __THREW__ = 0;
     $257 = $256&1;
     if ($257) {
      label = 17;
      break;
     } else {
      $264 = $255;
     }
    }
    $258 = HEAP32[$7>>2]|0;
    $259 = ((($258)) + 8|0);
    $260 = HEAP32[$259>>2]|0;
    $261 = HEAP32[$260>>2]|0;
    $262 = ((($261)) + 24|0);
    $263 = HEAP32[$262>>2]|0;
    __THREW__ = 0;
    invoke_viii($263|0,($260|0),($0|0),($264|0));
    $265 = __THREW__; __THREW__ = 0;
    $266 = $265&1;
    if ($266) {
     label = 17;
     break;
    }
    $267 = HEAP32[$4>>2]|0;
    $268 = ($267>>>0)>(1);
    if ($268) {
     $269 = HEAP32[$29>>2]|0;
     $270 = ((($269)) + 4|0);
     $271 = HEAP32[$270>>2]|0;
     $272 = HEAP32[$269>>2]|0;
     $273 = ((($272)) + 4|0);
     HEAP32[$273>>2] = $271;
     $274 = HEAP32[$270>>2]|0;
     HEAP32[$274>>2] = $272;
     $275 = (($267) + -1)|0;
     HEAP32[$4>>2] = $275;
     $276 = ((($269)) + 8|0);
     $277 = HEAP32[$276>>2]|0;
     $278 = ($277|0)==(0|0);
     do {
      if (!($278)) {
       $279 = ((($277)) + 8|0);
       $280 = HEAP32[$279>>2]|0;HEAP32[$279>>2] = (($280-1)|0);
       $281 = ($280|0)==(1);
       if (!($281)) {
        break;
       }
       __THREW__ = 0;
       invoke_viii(3262,($277|0),1,1);
       $282 = __THREW__; __THREW__ = 0;
       $283 = $282&1;
       if ($283) {
        label = 17;
        break L9;
       }
      }
     } while(0);
     __ZdlPv($269);
    }
    $284 = HEAP32[$30>>2]|0;
    $285 = ((($284)) + 4|0);
    $286 = HEAP32[$285>>2]|0;
    $287 = HEAP32[$284>>2]|0;
    $288 = ((($287)) + 4|0);
    HEAP32[$288>>2] = $286;
    $289 = HEAP32[$285>>2]|0;
    HEAP32[$289>>2] = $287;
    $290 = HEAP32[$25>>2]|0;
    $291 = (($290) + -1)|0;
    HEAP32[$25>>2] = $291;
    $292 = ((($284)) + 8|0);
    $293 = HEAP32[$292>>2]|0;
    $294 = ($293|0)==(0|0);
    do {
     if (!($294)) {
      $295 = ((($293)) + 8|0);
      $296 = HEAP32[$295>>2]|0;HEAP32[$295>>2] = (($296-1)|0);
      $297 = ($296|0)==(1);
      if (!($297)) {
       break;
      }
      __THREW__ = 0;
      invoke_viii(3262,($293|0),1,1);
      $298 = __THREW__; __THREW__ = 0;
      $299 = $298&1;
      if ($299) {
       label = 17;
       break L9;
      }
     }
    } while(0);
    __ZdlPv($284);
    HEAP8[$31>>0] = 1;
    $300 = HEAP32[$56>>2]|0;HEAP32[$56>>2] = (($300-1)|0);
    $301 = ($300|0)==(1);
    if ($301) {
     __ZNK3osg10Referenced24signalObserversAndDeleteEbb($41,1,1);
    }
    $302 = (($$02069) + 1)|0;
    $303 = HEAP32[$1>>2]|0;
    $304 = ((($303)) + 224|0);
    $305 = HEAP32[$304>>2]|0;
    $306 = (FUNCTION_TABLE_ii[$305 & 8191]($1)|0);
    $307 = ($302>>>0)<($306>>>0);
    if ($307) {
     $$02069 = $302;
    } else {
     break L7;
    }
   }
   if ((label|0) == 8) {
    $50 = ___cxa_find_matching_catch_2()|0;
    $51 = tempRet0;
    __THREW__ = 0;
    invoke_vi(388,($41|0));
    $52 = __THREW__; __THREW__ = 0;
    $53 = $52&1;
    if ($53) {
     $54 = ___cxa_find_matching_catch_3(0|0)|0;
     $55 = tempRet0;
     ___clang_call_terminate($54);
     // unreachable;
    } else {
     $eh$lpad$body$index4Z2D = $51;$eh$lpad$body$indexZ2D = $50;
     label = 16;
    }
   }
   else if ((label|0) == 15) {
    $74 = ___cxa_find_matching_catch_2()|0;
    $75 = tempRet0;
    $eh$lpad$body$index4Z2D = $75;$eh$lpad$body$indexZ2D = $74;
    label = 16;
   }
   else if ((label|0) == 17) {
    $76 = ___cxa_find_matching_catch_2()|0;
    $77 = tempRet0;
    $eh$lpad$body35$index11Z2D = $77;$eh$lpad$body35$indexZ2D = $76;
    label = 18;
   }
   else if ((label|0) == 35) {
    $207 = ___cxa_find_matching_catch_2()|0;
    $208 = tempRet0;
    $$1 = $208;$$118 = $207;
   }
   else if ((label|0) == 46) {
    $239 = ___cxa_find_matching_catch_2()|0;
    $240 = tempRet0;
    if ($220) {
     $eh$lpad$body35$index11Z2D = $240;$eh$lpad$body35$indexZ2D = $239;
     label = 18;
    } else {
     $241 = ((($217)) + 8|0);
     $242 = HEAP32[$241>>2]|0;HEAP32[$241>>2] = (($242-1)|0);
     $243 = ($242|0)==(1);
     if ($243) {
      __THREW__ = 0;
      invoke_viii(3262,($217|0),1,1);
      $244 = __THREW__; __THREW__ = 0;
      $245 = $244&1;
      if ($245) {
       $246 = ___cxa_find_matching_catch_3(0|0)|0;
       $247 = tempRet0;
       ___clang_call_terminate($246);
       // unreachable;
      } else {
       $eh$lpad$body35$index11Z2D = $240;$eh$lpad$body35$indexZ2D = $239;
       label = 18;
      }
     } else {
      $eh$lpad$body35$index11Z2D = $240;$eh$lpad$body35$indexZ2D = $239;
      label = 18;
     }
    }
   }
   if ((label|0) == 16) {
    __ZdlPv($41);
    $$2 = $eh$lpad$body$index4Z2D;$$219 = $eh$lpad$body$indexZ2D;
    ___resumeException($$219|0);
    // unreachable;
   }
   else if ((label|0) == 18) {
    $$1 = $eh$lpad$body35$index11Z2D;$$118 = $eh$lpad$body35$indexZ2D;
   }
   $308 = HEAP32[$56>>2]|0;HEAP32[$56>>2] = (($308-1)|0);
   $309 = ($308|0)==(1);
   if (!($309)) {
    $$2 = $$1;$$219 = $$118;
    ___resumeException($$219|0);
    // unreachable;
   }
   __THREW__ = 0;
   invoke_viii(3262,($41|0),1,1);
   $310 = __THREW__; __THREW__ = 0;
   $311 = $310&1;
   if ($311) {
    $312 = ___cxa_find_matching_catch_3(0|0)|0;
    $313 = tempRet0;
    ___clang_call_terminate($312);
    // unreachable;
   } else {
    $$2 = $$1;$$219 = $$118;
    ___resumeException($$219|0);
    // unreachable;
   }
  }
 } while(0);
 $33 = HEAP32[$7>>2]|0;
 $34 = ((($33)) + 8|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 $37 = ((($36)) + 20|0);
 $38 = HEAP32[$37>>2]|0;
 FUNCTION_TABLE_vi[$38 & 8191]($35);
 STACKTOP = sp;return;
}
function __ZN7osgUtil19IntersectionVisitor5applyERN3osg5GroupE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 64|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  return;
 }
 $5 = ((($0)) + 56|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($6)) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($9)) + 16|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (FUNCTION_TABLE_iii[$11 & 8191]($8,$1)|0);
 if (!($12)) {
  return;
 }
 $13 = ((($0)) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 switch ($14|0) {
 case 1:  {
  $15 = HEAP32[$1>>2]|0;
  $16 = ((($15)) + 192|0);
  $17 = HEAP32[$16>>2]|0;
  FUNCTION_TABLE_vii[$17 & 8191]($1,$0);
  break;
 }
 case 0:  {
  break;
 }
 default: {
  $18 = HEAP32[$1>>2]|0;
  $19 = ((($18)) + 196|0);
  $20 = HEAP32[$19>>2]|0;
  FUNCTION_TABLE_vii[$20 & 8191]($1,$0);
 }
 }
 $21 = HEAP32[$5>>2]|0;
 $22 = ((($21)) + 8|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = HEAP32[$23>>2]|0;
 $25 = ((($24)) + 20|0);
 $26 = HEAP32[$25>>2]|0;
 FUNCTION_TABLE_vi[$26 & 8191]($23);
 return;
}
function __ZN7osgUtil19IntersectionVisitor5applyERN3osg10ProjectionE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0;
 var $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0.0, $21 = 0, $22 = 0, $23 = 0.0, $24 = 0, $25 = 0, $26 = 0.0, $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0, $32 = 0.0, $33 = 0, $34 = 0, $35 = 0.0, $36 = 0, $37 = 0;
 var $38 = 0.0, $39 = 0, $4 = 0, $40 = 0, $41 = 0.0, $42 = 0, $43 = 0, $44 = 0.0, $45 = 0, $46 = 0, $47 = 0.0, $48 = 0, $49 = 0, $5 = 0, $50 = 0.0, $51 = 0, $52 = 0, $53 = 0.0, $54 = 0, $55 = 0;
 var $56 = 0.0, $57 = 0, $58 = 0, $59 = 0.0, $6 = 0, $60 = 0, $61 = 0, $62 = 0.0, $63 = 0, $64 = 0, $65 = 0.0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 64|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  return;
 }
 $5 = ((($0)) + 56|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($6)) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($9)) + 16|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (FUNCTION_TABLE_iii[$11 & 8191]($8,$1)|0);
 if (!($12)) {
  return;
 }
 $13 = (__Znwj(160)|0);
 __THREW__ = 0;
 invoke_vii(3435,($13|0),0);
 $14 = __THREW__; __THREW__ = 0;
 $15 = $14&1;
 if ($15) {
  $148 = ___cxa_find_matching_catch_2()|0;
  $149 = tempRet0;
  __ZdlPv($13);
  ___resumeException($148|0);
  // unreachable;
 }
 $16 = ((($13)) + 12|0);
 ;HEAP32[$16>>2]=0|0;HEAP32[$16+4>>2]=0|0;HEAP32[$16+8>>2]=0|0;
 $17 = ((($13)) + 24|0);
 HEAP32[$17>>2] = 2;
 $18 = ((($13)) + 28|0);
 HEAP32[$18>>2] = 0;
 $19 = ((($1)) + 136|0);
 $20 = +HEAPF64[$19>>3];
 $21 = ((($13)) + 32|0);
 HEAPF64[$21>>3] = $20;
 $22 = ((($1)) + 144|0);
 $23 = +HEAPF64[$22>>3];
 $24 = ((($13)) + 40|0);
 HEAPF64[$24>>3] = $23;
 $25 = ((($1)) + 152|0);
 $26 = +HEAPF64[$25>>3];
 $27 = ((($13)) + 48|0);
 HEAPF64[$27>>3] = $26;
 $28 = ((($1)) + 160|0);
 $29 = +HEAPF64[$28>>3];
 $30 = ((($13)) + 56|0);
 HEAPF64[$30>>3] = $29;
 $31 = ((($1)) + 168|0);
 $32 = +HEAPF64[$31>>3];
 $33 = ((($13)) + 64|0);
 HEAPF64[$33>>3] = $32;
 $34 = ((($1)) + 176|0);
 $35 = +HEAPF64[$34>>3];
 $36 = ((($13)) + 72|0);
 HEAPF64[$36>>3] = $35;
 $37 = ((($1)) + 184|0);
 $38 = +HEAPF64[$37>>3];
 $39 = ((($13)) + 80|0);
 HEAPF64[$39>>3] = $38;
 $40 = ((($1)) + 192|0);
 $41 = +HEAPF64[$40>>3];
 $42 = ((($13)) + 88|0);
 HEAPF64[$42>>3] = $41;
 $43 = ((($1)) + 200|0);
 $44 = +HEAPF64[$43>>3];
 $45 = ((($13)) + 96|0);
 HEAPF64[$45>>3] = $44;
 $46 = ((($1)) + 208|0);
 $47 = +HEAPF64[$46>>3];
 $48 = ((($13)) + 104|0);
 HEAPF64[$48>>3] = $47;
 $49 = ((($1)) + 216|0);
 $50 = +HEAPF64[$49>>3];
 $51 = ((($13)) + 112|0);
 HEAPF64[$51>>3] = $50;
 $52 = ((($1)) + 224|0);
 $53 = +HEAPF64[$52>>3];
 $54 = ((($13)) + 120|0);
 HEAPF64[$54>>3] = $53;
 $55 = ((($1)) + 232|0);
 $56 = +HEAPF64[$55>>3];
 $57 = ((($13)) + 128|0);
 HEAPF64[$57>>3] = $56;
 $58 = ((($1)) + 240|0);
 $59 = +HEAPF64[$58>>3];
 $60 = ((($13)) + 136|0);
 HEAPF64[$60>>3] = $59;
 $61 = ((($1)) + 248|0);
 $62 = +HEAPF64[$61>>3];
 $63 = ((($13)) + 144|0);
 HEAPF64[$63>>3] = $62;
 $64 = ((($1)) + 256|0);
 $65 = +HEAPF64[$64>>3];
 $66 = ((($13)) + 152|0);
 HEAPF64[$66>>3] = $65;
 HEAP32[$13>>2] = (47588);
 __ZN7osgUtil19IntersectionVisitor20pushProjectionMatrixEPN3osg10RefMatrixdE($0,$13);
 $67 = ((($0)) + 60|0);
 $68 = HEAP32[$67>>2]|0;
 $69 = ((($68)) + 8|0);
 $70 = HEAP32[$69>>2]|0;
 $71 = HEAP32[$70>>2]|0;
 $72 = ((($71)) + 12|0);
 $73 = HEAP32[$72>>2]|0;
 $74 = (FUNCTION_TABLE_iii[$73 & 8191]($70,$0)|0);
 $75 = ($74|0)==(0|0);
 if (!($75)) {
  $76 = ((($74)) + 8|0);
  $77 = HEAP32[$76>>2]|0;HEAP32[$76>>2] = (($77+1)|0);
 }
 __THREW__ = 0;
 $78 = (invoke_ii(3276,12)|0);
 $79 = __THREW__; __THREW__ = 0;
 $80 = $79&1;
 if ($80) {
  $92 = ___cxa_find_matching_catch_2()|0;
  $93 = tempRet0;
  if ($75) {
   ___resumeException($92|0);
   // unreachable;
  }
  $94 = ((($74)) + 8|0);
  $95 = HEAP32[$94>>2]|0;HEAP32[$94>>2] = (($95-1)|0);
  $96 = ($95|0)==(1);
  if (!($96)) {
   ___resumeException($92|0);
   // unreachable;
  }
  __THREW__ = 0;
  invoke_viii(3262,($74|0),1,1);
  $97 = __THREW__; __THREW__ = 0;
  $98 = $97&1;
  if ($98) {
   $99 = ___cxa_find_matching_catch_3(0|0)|0;
   $100 = tempRet0;
   ___clang_call_terminate($99);
   // unreachable;
  } else {
   ___resumeException($92|0);
   // unreachable;
  }
 }
 $81 = ((($78)) + 8|0);
 HEAP32[$81>>2] = $74;
 if (!($75)) {
  $82 = ((($74)) + 8|0);
  $83 = HEAP32[$82>>2]|0;HEAP32[$82>>2] = (($83+1)|0);
 }
 $84 = ((($78)) + 4|0);
 HEAP32[$84>>2] = $5;
 $85 = HEAP32[$5>>2]|0;
 HEAP32[$78>>2] = $85;
 $86 = ((($85)) + 4|0);
 HEAP32[$86>>2] = $78;
 HEAP32[$5>>2] = $78;
 $87 = HEAP32[$2>>2]|0;
 $88 = (($87) + 1)|0;
 HEAP32[$2>>2] = $88;
 if (!($75)) {
  $89 = ((($74)) + 8|0);
  $90 = HEAP32[$89>>2]|0;HEAP32[$89>>2] = (($90-1)|0);
  $91 = ($90|0)==(1);
  if ($91) {
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($74,1,1);
  }
 }
 $101 = ((($0)) + 16|0);
 $102 = HEAP32[$101>>2]|0;
 switch ($102|0) {
 case 1:  {
  $103 = HEAP32[$1>>2]|0;
  $104 = ((($103)) + 192|0);
  $105 = HEAP32[$104>>2]|0;
  FUNCTION_TABLE_vii[$105 & 8191]($1,$0);
  break;
 }
 case 0:  {
  break;
 }
 default: {
  $106 = HEAP32[$1>>2]|0;
  $107 = ((($106)) + 196|0);
  $108 = HEAP32[$107>>2]|0;
  FUNCTION_TABLE_vii[$108 & 8191]($1,$0);
 }
 }
 $109 = HEAP32[$2>>2]|0;
 $110 = ($109>>>0)>(1);
 if ($110) {
  $111 = ((($0)) + 56|0);
  $112 = HEAP32[$111>>2]|0;
  $113 = ((($112)) + 4|0);
  $114 = HEAP32[$113>>2]|0;
  $115 = HEAP32[$112>>2]|0;
  $116 = ((($115)) + 4|0);
  HEAP32[$116>>2] = $114;
  $117 = HEAP32[$113>>2]|0;
  HEAP32[$117>>2] = $115;
  $118 = (($109) + -1)|0;
  HEAP32[$2>>2] = $118;
  $119 = ((($112)) + 8|0);
  $120 = HEAP32[$119>>2]|0;
  $121 = ($120|0)==(0|0);
  if (!($121)) {
   $122 = ((($120)) + 8|0);
   $123 = HEAP32[$122>>2]|0;HEAP32[$122>>2] = (($123-1)|0);
   $124 = ($123|0)==(1);
   if ($124) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($120,1,1);
   }
  }
  __ZdlPv($112);
 }
 $125 = ((($0)) + 88|0);
 $126 = HEAP32[$125>>2]|0;
 $127 = ((($126)) + 4|0);
 $128 = HEAP32[$127>>2]|0;
 $129 = HEAP32[$126>>2]|0;
 $130 = ((($129)) + 4|0);
 HEAP32[$130>>2] = $128;
 $131 = HEAP32[$127>>2]|0;
 HEAP32[$131>>2] = $129;
 $132 = ((($0)) + 96|0);
 $133 = HEAP32[$132>>2]|0;
 $134 = (($133) + -1)|0;
 HEAP32[$132>>2] = $134;
 $135 = ((($126)) + 8|0);
 $136 = HEAP32[$135>>2]|0;
 $137 = ($136|0)==(0|0);
 if (!($137)) {
  $138 = ((($136)) + 8|0);
  $139 = HEAP32[$138>>2]|0;HEAP32[$138>>2] = (($139-1)|0);
  $140 = ($139|0)==(1);
  if ($140) {
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($136,1,1);
  }
 }
 __ZdlPv($126);
 $141 = ((($0)) + 144|0);
 HEAP8[$141>>0] = 1;
 $142 = HEAP32[$5>>2]|0;
 $143 = ((($142)) + 8|0);
 $144 = HEAP32[$143>>2]|0;
 $145 = HEAP32[$144>>2]|0;
 $146 = ((($145)) + 20|0);
 $147 = HEAP32[$146>>2]|0;
 FUNCTION_TABLE_vi[$147 & 8191]($144);
 return;
}
function __ZN7osgUtil19IntersectionVisitor5applyERN3osg9TransformE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$011 = 0, $$1 = 0, $$112 = 0, $$pre$phi36Z2D = 0, $$sink = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0;
 var $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0;
 var $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0;
 var $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0.0, $41 = 0, $42 = 0, $43 = 0.0, $44 = 0, $45 = 0, $46 = 0.0, $47 = 0, $48 = 0, $49 = 0.0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0.0, $53 = 0, $54 = 0, $55 = 0.0, $56 = 0, $57 = 0, $58 = 0.0, $59 = 0, $6 = 0, $60 = 0, $61 = 0.0, $62 = 0, $63 = 0, $64 = 0.0, $65 = 0, $66 = 0, $67 = 0.0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0.0, $71 = 0, $72 = 0, $73 = 0.0, $74 = 0, $75 = 0, $76 = 0.0, $77 = 0, $78 = 0, $79 = 0.0, $8 = 0, $80 = 0, $81 = 0, $82 = 0.0, $83 = 0, $84 = 0, $85 = 0.0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, $eh$lpad$body19$index16Z2D = 0, $eh$lpad$body19$indexZ2D = 0, $eh$lpad$body24$index9Z2D = 0, $eh$lpad$body24$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = ((($0)) + 64|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $6 = ((($0)) + 56|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($7)) + 8|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$9>>2]|0;
 $11 = ((($10)) + 16|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (FUNCTION_TABLE_iii[$12 & 8191]($9,$1)|0);
 if (!($13)) {
  STACKTOP = sp;return;
 }
 $14 = ((($0)) + 120|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0);
 $17 = (__Znwj(160)|0);
 do {
  if ($16) {
   __THREW__ = 0;
   invoke_vii(3435,($17|0),0);
   $18 = __THREW__; __THREW__ = 0;
   $19 = $18&1;
   if ($19) {
    $116 = ___cxa_find_matching_catch_2()|0;
    $117 = tempRet0;
    $eh$lpad$body$index2Z2D = $117;$eh$lpad$body$indexZ2D = $116;
   } else {
    HEAP32[$17>>2] = (63412);
    $20 = ((($17)) + 12|0);
    ;HEAP32[$20>>2]=0|0;HEAP32[$20+4>>2]=0|0;HEAP32[$20+8>>2]=0|0;
    $21 = ((($17)) + 24|0);
    HEAP32[$21>>2] = 2;
    $22 = ((($17)) + 28|0);
    HEAP32[$22>>2] = 0;
    $23 = ((($17)) + 32|0);
    __THREW__ = 0;
    invoke_vi(3299,($23|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $$pre$phi36Z2D = $23;$$sink = $17;
     break;
    }
    $26 = ___cxa_find_matching_catch_2()|0;
    $27 = tempRet0;
    __THREW__ = 0;
    invoke_vi(388,($17|0));
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if ($29) {
     $30 = ___cxa_find_matching_catch_3(0|0)|0;
     $31 = tempRet0;
     ___clang_call_terminate($30);
     // unreachable;
    } else {
     $eh$lpad$body$index2Z2D = $27;$eh$lpad$body$indexZ2D = $26;
    }
   }
   __ZdlPv($17);
   $$1 = $eh$lpad$body$index2Z2D;$$112 = $eh$lpad$body$indexZ2D;
   ___resumeException($$112|0);
   // unreachable;
  } else {
   $32 = ((($0)) + 112|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = ((($33)) + 8|0);
   $35 = HEAP32[$34>>2]|0;
   HEAP32[$2>>2] = (58136);
   $36 = ((($2)) + 4|0);
   HEAP32[$36>>2] = 0;
   __THREW__ = 0;
   invoke_viii(3468,($17|0),($35|0),($2|0));
   $37 = __THREW__; __THREW__ = 0;
   $38 = $37&1;
   if (!($38)) {
    $39 = ((($35)) + 32|0);
    $40 = +HEAPF64[$39>>3];
    $41 = ((($17)) + 32|0);
    HEAPF64[$41>>3] = $40;
    $42 = ((($35)) + 40|0);
    $43 = +HEAPF64[$42>>3];
    $44 = ((($17)) + 40|0);
    HEAPF64[$44>>3] = $43;
    $45 = ((($35)) + 48|0);
    $46 = +HEAPF64[$45>>3];
    $47 = ((($17)) + 48|0);
    HEAPF64[$47>>3] = $46;
    $48 = ((($35)) + 56|0);
    $49 = +HEAPF64[$48>>3];
    $50 = ((($17)) + 56|0);
    HEAPF64[$50>>3] = $49;
    $51 = ((($35)) + 64|0);
    $52 = +HEAPF64[$51>>3];
    $53 = ((($17)) + 64|0);
    HEAPF64[$53>>3] = $52;
    $54 = ((($35)) + 72|0);
    $55 = +HEAPF64[$54>>3];
    $56 = ((($17)) + 72|0);
    HEAPF64[$56>>3] = $55;
    $57 = ((($35)) + 80|0);
    $58 = +HEAPF64[$57>>3];
    $59 = ((($17)) + 80|0);
    HEAPF64[$59>>3] = $58;
    $60 = ((($35)) + 88|0);
    $61 = +HEAPF64[$60>>3];
    $62 = ((($17)) + 88|0);
    HEAPF64[$62>>3] = $61;
    $63 = ((($35)) + 96|0);
    $64 = +HEAPF64[$63>>3];
    $65 = ((($17)) + 96|0);
    HEAPF64[$65>>3] = $64;
    $66 = ((($35)) + 104|0);
    $67 = +HEAPF64[$66>>3];
    $68 = ((($17)) + 104|0);
    HEAPF64[$68>>3] = $67;
    $69 = ((($35)) + 112|0);
    $70 = +HEAPF64[$69>>3];
    $71 = ((($17)) + 112|0);
    HEAPF64[$71>>3] = $70;
    $72 = ((($35)) + 120|0);
    $73 = +HEAPF64[$72>>3];
    $74 = ((($17)) + 120|0);
    HEAPF64[$74>>3] = $73;
    $75 = ((($35)) + 128|0);
    $76 = +HEAPF64[$75>>3];
    $77 = ((($17)) + 128|0);
    HEAPF64[$77>>3] = $76;
    $78 = ((($35)) + 136|0);
    $79 = +HEAPF64[$78>>3];
    $80 = ((($17)) + 136|0);
    HEAPF64[$80>>3] = $79;
    $81 = ((($35)) + 144|0);
    $82 = +HEAPF64[$81>>3];
    $83 = ((($17)) + 144|0);
    HEAPF64[$83>>3] = $82;
    $84 = ((($35)) + 152|0);
    $85 = +HEAPF64[$84>>3];
    $86 = ((($17)) + 152|0);
    HEAPF64[$86>>3] = $85;
    $$pre$phi36Z2D = $41;$$sink = $17;
    break;
   }
   $118 = ___cxa_find_matching_catch_2()|0;
   $119 = tempRet0;
   __ZdlPv($17);
   $$1 = $119;$$112 = $118;
   ___resumeException($$112|0);
   // unreachable;
  }
 } while(0);
 HEAP32[$$sink>>2] = (47588);
 $87 = ((($17)) + 8|0);
 $88 = HEAP32[$87>>2]|0;HEAP32[$87>>2] = (($88+1)|0);
 $89 = HEAP32[$1>>2]|0;
 $90 = ((($89)) + 264|0);
 $91 = HEAP32[$90>>2]|0;
 __THREW__ = 0;
 (invoke_iiii($91|0,($1|0),($$pre$phi36Z2D|0),($0|0))|0);
 $92 = __THREW__; __THREW__ = 0;
 $93 = $92&1;
 L22: do {
  if ($93) {
   label = 21;
  } else {
   $94 = ((($1)) + 136|0);
   $95 = HEAP32[$94>>2]|0;
   $96 = ($95|0)==(0);
   do {
    if (!($96)) {
     __THREW__ = 0;
     $97 = (invoke_ii(3276,160)|0);
     $98 = __THREW__; __THREW__ = 0;
     $99 = $98&1;
     if ($99) {
      label = 21;
      break L22;
     }
     __THREW__ = 0;
     invoke_vii(3435,($97|0),0);
     $100 = __THREW__; __THREW__ = 0;
     $101 = $100&1;
     if ($101) {
      $122 = ___cxa_find_matching_catch_2()|0;
      $123 = tempRet0;
      $eh$lpad$body19$index16Z2D = $123;$eh$lpad$body19$indexZ2D = $122;
     } else {
      HEAP32[$97>>2] = (63412);
      $102 = ((($97)) + 12|0);
      ;HEAP32[$102>>2]=0|0;HEAP32[$102+4>>2]=0|0;HEAP32[$102+8>>2]=0|0;
      $103 = ((($97)) + 24|0);
      HEAP32[$103>>2] = 2;
      $104 = ((($97)) + 28|0);
      HEAP32[$104>>2] = 0;
      $105 = ((($97)) + 32|0);
      __THREW__ = 0;
      invoke_vi(3299,($105|0));
      $106 = __THREW__; __THREW__ = 0;
      $107 = $106&1;
      if (!($107)) {
       HEAP32[$97>>2] = (47588);
       __THREW__ = 0;
       invoke_vii(3549,($0|0),($97|0));
       $114 = __THREW__; __THREW__ = 0;
       $115 = $114&1;
       if ($115) {
        label = 21;
        break L22;
       } else {
        break;
       }
      }
      $108 = ___cxa_find_matching_catch_2()|0;
      $109 = tempRet0;
      __THREW__ = 0;
      invoke_vi(388,($97|0));
      $110 = __THREW__; __THREW__ = 0;
      $111 = $110&1;
      if ($111) {
       $112 = ___cxa_find_matching_catch_3(0|0)|0;
       $113 = tempRet0;
       ___clang_call_terminate($112);
       // unreachable;
      } else {
       $eh$lpad$body19$index16Z2D = $109;$eh$lpad$body19$indexZ2D = $108;
      }
     }
     __ZdlPv($97);
     $$0 = $eh$lpad$body19$index16Z2D;$$011 = $eh$lpad$body19$indexZ2D;
     break L22;
    }
   } while(0);
   __THREW__ = 0;
   invoke_vii(3548,($0|0),($17|0));
   $124 = __THREW__; __THREW__ = 0;
   $125 = $124&1;
   if ($125) {
    label = 21;
   } else {
    $126 = ((($0)) + 60|0);
    $127 = HEAP32[$126>>2]|0;
    $128 = ((($127)) + 8|0);
    $129 = HEAP32[$128>>2]|0;
    $130 = HEAP32[$129>>2]|0;
    $131 = ((($130)) + 12|0);
    $132 = HEAP32[$131>>2]|0;
    __THREW__ = 0;
    $133 = (invoke_iii($132|0,($129|0),($0|0))|0);
    $134 = __THREW__; __THREW__ = 0;
    $135 = $134&1;
    if ($135) {
     label = 21;
    } else {
     $136 = ($133|0)==(0|0);
     if (!($136)) {
      $137 = ((($133)) + 8|0);
      $138 = HEAP32[$137>>2]|0;HEAP32[$137>>2] = (($138+1)|0);
     }
     __THREW__ = 0;
     $139 = (invoke_ii(3276,12)|0);
     $140 = __THREW__; __THREW__ = 0;
     $141 = $140&1;
     if ($141) {
      $155 = ___cxa_find_matching_catch_2()|0;
      $156 = tempRet0;
      if ($136) {
       $eh$lpad$body24$index9Z2D = $156;$eh$lpad$body24$indexZ2D = $155;
       label = 22;
       break;
      }
      $157 = ((($133)) + 8|0);
      $158 = HEAP32[$157>>2]|0;HEAP32[$157>>2] = (($158-1)|0);
      $159 = ($158|0)==(1);
      if (!($159)) {
       $eh$lpad$body24$index9Z2D = $156;$eh$lpad$body24$indexZ2D = $155;
       label = 22;
       break;
      }
      __THREW__ = 0;
      invoke_viii(3262,($133|0),1,1);
      $160 = __THREW__; __THREW__ = 0;
      $161 = $160&1;
      if (!($161)) {
       $eh$lpad$body24$index9Z2D = $156;$eh$lpad$body24$indexZ2D = $155;
       label = 22;
       break;
      }
      $162 = ___cxa_find_matching_catch_3(0|0)|0;
      $163 = tempRet0;
      ___clang_call_terminate($162);
      // unreachable;
     }
     $142 = ((($139)) + 8|0);
     HEAP32[$142>>2] = $133;
     if (!($136)) {
      $143 = ((($133)) + 8|0);
      $144 = HEAP32[$143>>2]|0;HEAP32[$143>>2] = (($144+1)|0);
     }
     $145 = ((($139)) + 4|0);
     HEAP32[$145>>2] = $6;
     $146 = HEAP32[$6>>2]|0;
     HEAP32[$139>>2] = $146;
     $147 = ((($146)) + 4|0);
     HEAP32[$147>>2] = $139;
     HEAP32[$6>>2] = $139;
     $148 = HEAP32[$3>>2]|0;
     $149 = (($148) + 1)|0;
     HEAP32[$3>>2] = $149;
     if (!($136)) {
      $150 = ((($133)) + 8|0);
      $151 = HEAP32[$150>>2]|0;HEAP32[$150>>2] = (($151-1)|0);
      $152 = ($151|0)==(1);
      if ($152) {
       __THREW__ = 0;
       invoke_viii(3262,($133|0),1,1);
       $153 = __THREW__; __THREW__ = 0;
       $154 = $153&1;
       if ($154) {
        label = 21;
        break;
       }
      }
     }
     $164 = ((($0)) + 16|0);
     $165 = HEAP32[$164>>2]|0;
     switch ($165|0) {
     case 1:  {
      $166 = HEAP32[$1>>2]|0;
      $167 = ((($166)) + 192|0);
      $168 = HEAP32[$167>>2]|0;
      __THREW__ = 0;
      invoke_vii($168|0,($1|0),($0|0));
      $169 = __THREW__; __THREW__ = 0;
      $170 = $169&1;
      if ($170) {
       label = 21;
       break L22;
      }
      break;
     }
     case 0:  {
      break;
     }
     default: {
      $171 = HEAP32[$1>>2]|0;
      $172 = ((($171)) + 196|0);
      $173 = HEAP32[$172>>2]|0;
      __THREW__ = 0;
      invoke_vii($173|0,($1|0),($0|0));
      $174 = __THREW__; __THREW__ = 0;
      $175 = $174&1;
      if ($175) {
       label = 21;
       break L22;
      }
     }
     }
     $176 = HEAP32[$3>>2]|0;
     $177 = ($176>>>0)>(1);
     if ($177) {
      $178 = ((($0)) + 56|0);
      $179 = HEAP32[$178>>2]|0;
      $180 = ((($179)) + 4|0);
      $181 = HEAP32[$180>>2]|0;
      $182 = HEAP32[$179>>2]|0;
      $183 = ((($182)) + 4|0);
      HEAP32[$183>>2] = $181;
      $184 = HEAP32[$180>>2]|0;
      HEAP32[$184>>2] = $182;
      $185 = (($176) + -1)|0;
      HEAP32[$3>>2] = $185;
      $186 = ((($179)) + 8|0);
      $187 = HEAP32[$186>>2]|0;
      $188 = ($187|0)==(0|0);
      if (!($188)) {
       $189 = ((($187)) + 8|0);
       $190 = HEAP32[$189>>2]|0;HEAP32[$189>>2] = (($190-1)|0);
       $191 = ($190|0)==(1);
       if ($191) {
        __THREW__ = 0;
        invoke_viii(3262,($187|0),1,1);
        $192 = __THREW__; __THREW__ = 0;
        $193 = $192&1;
        if ($193) {
         label = 21;
         break;
        }
       }
      }
      __ZdlPv($179);
     }
     $194 = ((($0)) + 112|0);
     $195 = HEAP32[$194>>2]|0;
     $196 = ((($195)) + 4|0);
     $197 = HEAP32[$196>>2]|0;
     $198 = HEAP32[$195>>2]|0;
     $199 = ((($198)) + 4|0);
     HEAP32[$199>>2] = $197;
     $200 = HEAP32[$196>>2]|0;
     HEAP32[$200>>2] = $198;
     $201 = HEAP32[$14>>2]|0;
     $202 = (($201) + -1)|0;
     HEAP32[$14>>2] = $202;
     $203 = ((($195)) + 8|0);
     $204 = HEAP32[$203>>2]|0;
     $205 = ($204|0)==(0|0);
     if (!($205)) {
      $206 = ((($204)) + 8|0);
      $207 = HEAP32[$206>>2]|0;HEAP32[$206>>2] = (($207-1)|0);
      $208 = ($207|0)==(1);
      if ($208) {
       __THREW__ = 0;
       invoke_viii(3262,($204|0),1,1);
       $209 = __THREW__; __THREW__ = 0;
       $210 = $209&1;
       if ($210) {
        label = 21;
        break;
       }
      }
     }
     __ZdlPv($195);
     $211 = ((($0)) + 144|0);
     HEAP8[$211>>0] = 1;
     $212 = HEAP32[$94>>2]|0;
     $213 = ($212|0)==(0);
     if (!($213)) {
      $214 = ((($0)) + 100|0);
      $215 = HEAP32[$214>>2]|0;
      $216 = ((($215)) + 4|0);
      $217 = HEAP32[$216>>2]|0;
      $218 = HEAP32[$215>>2]|0;
      $219 = ((($218)) + 4|0);
      HEAP32[$219>>2] = $217;
      $220 = HEAP32[$216>>2]|0;
      HEAP32[$220>>2] = $218;
      $221 = ((($0)) + 108|0);
      $222 = HEAP32[$221>>2]|0;
      $223 = (($222) + -1)|0;
      HEAP32[$221>>2] = $223;
      $224 = ((($215)) + 8|0);
      $225 = HEAP32[$224>>2]|0;
      $226 = ($225|0)==(0|0);
      if (!($226)) {
       $227 = ((($225)) + 8|0);
       $228 = HEAP32[$227>>2]|0;HEAP32[$227>>2] = (($228-1)|0);
       $229 = ($228|0)==(1);
       if ($229) {
        __THREW__ = 0;
        invoke_viii(3262,($225|0),1,1);
        $230 = __THREW__; __THREW__ = 0;
        $231 = $230&1;
        if ($231) {
         label = 21;
         break;
        }
       }
      }
      __ZdlPv($215);
      HEAP8[$211>>0] = 1;
     }
     $232 = HEAP32[$6>>2]|0;
     $233 = ((($232)) + 8|0);
     $234 = HEAP32[$233>>2]|0;
     $235 = HEAP32[$234>>2]|0;
     $236 = ((($235)) + 20|0);
     $237 = HEAP32[$236>>2]|0;
     __THREW__ = 0;
     invoke_vi($237|0,($234|0));
     $238 = __THREW__; __THREW__ = 0;
     $239 = $238&1;
     if ($239) {
      label = 21;
     } else {
      $240 = HEAP32[$87>>2]|0;HEAP32[$87>>2] = (($240-1)|0);
      $241 = ($240|0)==(1);
      if (!($241)) {
       STACKTOP = sp;return;
      }
      __ZNK3osg10Referenced24signalObserversAndDeleteEbb($17,1,1);
      STACKTOP = sp;return;
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 21) {
  $120 = ___cxa_find_matching_catch_2()|0;
  $121 = tempRet0;
  $eh$lpad$body24$index9Z2D = $121;$eh$lpad$body24$indexZ2D = $120;
  label = 22;
 }
 if ((label|0) == 22) {
  $$0 = $eh$lpad$body24$index9Z2D;$$011 = $eh$lpad$body24$indexZ2D;
 }
 $242 = HEAP32[$87>>2]|0;HEAP32[$87>>2] = (($242-1)|0);
 $243 = ($242|0)==(1);
 if (!($243)) {
  $$1 = $$0;$$112 = $$011;
  ___resumeException($$112|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(3262,($17|0),1,1);
 $244 = __THREW__; __THREW__ = 0;
 $245 = $244&1;
 if ($245) {
  $246 = ___cxa_find_matching_catch_3(0|0)|0;
  $247 = tempRet0;
  ___clang_call_terminate($246);
  // unreachable;
 } else {
  $$1 = $$0;$$112 = $$011;
  ___resumeException($$112|0);
  // unreachable;
 }
}
function __ZN7osgUtil19IntersectionVisitor5applyERN3osg6CameraE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$034$in = 0, $$035$in = 0, $$036 = 0, $$4 = 0, $$433 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0.0, $109 = 0, $11 = 0, $110 = 0, $111 = 0.0, $112 = 0;
 var $113 = 0, $114 = 0.0, $115 = 0, $116 = 0, $117 = 0.0, $118 = 0, $119 = 0, $12 = 0, $120 = 0.0, $121 = 0, $122 = 0, $123 = 0.0, $124 = 0, $125 = 0, $126 = 0.0, $127 = 0, $128 = 0, $129 = 0.0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0.0, $133 = 0, $134 = 0, $135 = 0.0, $136 = 0, $137 = 0, $138 = 0.0, $139 = 0, $14 = 0, $140 = 0, $141 = 0.0, $142 = 0, $143 = 0, $144 = 0.0, $145 = 0, $146 = 0, $147 = 0.0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0.0, $151 = 0, $152 = 0, $153 = 0.0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0.0, $169 = 0, $17 = 0, $170 = 0, $171 = 0.0, $172 = 0, $173 = 0, $174 = 0.0, $175 = 0, $176 = 0, $177 = 0.0, $178 = 0, $179 = 0, $18 = 0, $180 = 0.0, $181 = 0, $182 = 0, $183 = 0.0, $184 = 0, $185 = 0;
 var $186 = 0.0, $187 = 0, $188 = 0, $189 = 0.0, $19 = 0, $190 = 0, $191 = 0, $192 = 0.0, $193 = 0, $194 = 0, $195 = 0.0, $196 = 0, $197 = 0, $198 = 0.0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0.0, $202 = 0;
 var $203 = 0, $204 = 0.0, $205 = 0, $206 = 0, $207 = 0.0, $208 = 0, $209 = 0, $21 = 0, $210 = 0.0, $211 = 0, $212 = 0, $213 = 0.0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0;
 var $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0.0, $234 = 0, $235 = 0, $236 = 0.0, $237 = 0, $238 = 0, $239 = 0.0;
 var $24 = 0, $240 = 0, $241 = 0, $242 = 0.0, $243 = 0, $244 = 0, $245 = 0.0, $246 = 0, $247 = 0, $248 = 0.0, $249 = 0, $25 = 0, $250 = 0, $251 = 0.0, $252 = 0, $253 = 0, $254 = 0.0, $255 = 0, $256 = 0, $257 = 0.0;
 var $258 = 0, $259 = 0, $26 = 0, $260 = 0.0, $261 = 0, $262 = 0, $263 = 0.0, $264 = 0, $265 = 0, $266 = 0.0, $267 = 0, $268 = 0, $269 = 0.0, $27 = 0, $270 = 0, $271 = 0, $272 = 0.0, $273 = 0, $274 = 0, $275 = 0.0;
 var $276 = 0, $277 = 0, $278 = 0.0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0.0, $292 = 0, $293 = 0;
 var $294 = 0.0, $295 = 0, $296 = 0, $297 = 0.0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0.0, $301 = 0, $302 = 0, $303 = 0.0, $304 = 0, $305 = 0, $306 = 0.0, $307 = 0, $308 = 0, $309 = 0.0, $31 = 0, $310 = 0;
 var $311 = 0, $312 = 0.0, $313 = 0, $314 = 0, $315 = 0.0, $316 = 0, $317 = 0, $318 = 0.0, $319 = 0, $32 = 0, $320 = 0, $321 = 0.0, $322 = 0, $323 = 0, $324 = 0.0, $325 = 0, $326 = 0, $327 = 0.0, $328 = 0, $329 = 0;
 var $33 = 0, $330 = 0.0, $331 = 0, $332 = 0, $333 = 0.0, $334 = 0, $335 = 0, $336 = 0.0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0;
 var $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0.0, $359 = 0, $36 = 0, $360 = 0, $361 = 0.0, $362 = 0, $363 = 0, $364 = 0.0, $365 = 0;
 var $366 = 0, $367 = 0.0, $368 = 0, $369 = 0, $37 = 0, $370 = 0.0, $371 = 0, $372 = 0, $373 = 0.0, $374 = 0, $375 = 0, $376 = 0.0, $377 = 0, $378 = 0, $379 = 0.0, $38 = 0, $380 = 0, $381 = 0, $382 = 0.0, $383 = 0;
 var $384 = 0, $385 = 0.0, $386 = 0, $387 = 0, $388 = 0.0, $389 = 0, $39 = 0, $390 = 0, $391 = 0.0, $392 = 0, $393 = 0, $394 = 0.0, $395 = 0, $396 = 0, $397 = 0.0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0.0;
 var $401 = 0, $402 = 0, $403 = 0.0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0.0, $419 = 0;
 var $42 = 0, $420 = 0, $421 = 0.0, $422 = 0, $423 = 0, $424 = 0.0, $425 = 0, $426 = 0, $427 = 0.0, $428 = 0, $429 = 0, $43 = 0.0, $430 = 0.0, $431 = 0, $432 = 0, $433 = 0.0, $434 = 0, $435 = 0, $436 = 0.0, $437 = 0;
 var $438 = 0, $439 = 0.0, $44 = 0, $440 = 0, $441 = 0, $442 = 0.0, $443 = 0, $444 = 0, $445 = 0.0, $446 = 0, $447 = 0, $448 = 0.0, $449 = 0, $45 = 0, $450 = 0, $451 = 0.0, $452 = 0, $453 = 0, $454 = 0.0, $455 = 0;
 var $456 = 0, $457 = 0.0, $458 = 0, $459 = 0, $46 = 0.0, $460 = 0.0, $461 = 0, $462 = 0, $463 = 0.0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0.0, $473 = 0;
 var $474 = 0, $475 = 0.0, $476 = 0, $477 = 0, $478 = 0.0, $479 = 0, $48 = 0, $480 = 0, $481 = 0.0, $482 = 0, $483 = 0, $484 = 0.0, $485 = 0, $486 = 0, $487 = 0.0, $488 = 0, $489 = 0, $49 = 0.0, $490 = 0.0, $491 = 0;
 var $492 = 0, $493 = 0.0, $494 = 0, $495 = 0, $496 = 0.0, $497 = 0, $498 = 0, $499 = 0.0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0.0, $503 = 0, $504 = 0, $505 = 0.0, $506 = 0, $507 = 0, $508 = 0.0, $509 = 0;
 var $51 = 0, $510 = 0, $511 = 0.0, $512 = 0, $513 = 0, $514 = 0.0, $515 = 0, $516 = 0, $517 = 0.0, $518 = 0, $519 = 0, $52 = 0.0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0;
 var $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0;
 var $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0.0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0;
 var $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0.0, $580 = 0, $581 = 0;
 var $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0;
 var $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0.0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0;
 var $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0;
 var $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0.0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0;
 var $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0.0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0.0, $71 = 0, $72 = 0, $73 = 0.0, $74 = 0, $75 = 0, $76 = 0.0, $77 = 0, $78 = 0, $79 = 0.0, $8 = 0, $80 = 0, $81 = 0, $82 = 0.0, $83 = 0, $84 = 0, $85 = 0.0, $86 = 0, $87 = 0;
 var $88 = 0.0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body68$index10Z2D = 0, $eh$lpad$body68$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 528|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(528|0);
 $2 = sp + 520|0;
 $3 = sp + 512|0;
 $4 = sp + 384|0;
 $5 = sp + 256|0;
 $6 = sp + 128|0;
 $7 = sp;
 $8 = ((($1)) + 136|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0);
 do {
  if ($10) {
   $11 = ((($0)) + 96|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = ($12|0)==(0);
   if ($13) {
    label = 37;
   } else {
    $14 = ((($0)) + 88|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = ((($15)) + 8|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = ($17|0)==(0|0);
    if ($18) {
     label = 37;
    } else {
     $19 = ((($0)) + 108|0);
     $20 = HEAP32[$19>>2]|0;
     $21 = ($20|0)==(0);
     if ($21) {
      label = 37;
     } else {
      $22 = ((($0)) + 100|0);
      $23 = HEAP32[$22>>2]|0;
      $24 = ((($23)) + 8|0);
      $25 = HEAP32[$24>>2]|0;
      $26 = ($25|0)==(0|0);
      if ($26) {
       label = 37;
      } else {
       $27 = ((($1)) + 292|0);
       $28 = HEAP32[$27>>2]|0;
       $29 = ($28|0)==(1);
       $30 = (__Znwj(160)|0);
       if ($29) {
        $31 = HEAP32[$16>>2]|0;
        __THREW__ = 0;
        invoke_vi(3299,($4|0));
        $32 = __THREW__; __THREW__ = 0;
        $33 = $32&1;
        if (!($33)) {
         $34 = ((($1)) + 304|0);
         $35 = ((($31)) + 32|0);
         __THREW__ = 0;
         invoke_viii(3300,($4|0),($35|0),($34|0));
         $36 = __THREW__; __THREW__ = 0;
         $37 = $36&1;
         if (!($37)) {
          __THREW__ = 0;
          invoke_vii(3435,($30|0),0);
          $38 = __THREW__; __THREW__ = 0;
          $39 = $38&1;
          if (!($39)) {
           $40 = ((($30)) + 12|0);
           ;HEAP32[$40>>2]=0|0;HEAP32[$40+4>>2]=0|0;HEAP32[$40+8>>2]=0|0;
           $41 = ((($30)) + 24|0);
           HEAP32[$41>>2] = 2;
           $42 = ((($30)) + 28|0);
           HEAP32[$42>>2] = 0;
           $43 = +HEAPF64[$4>>3];
           $44 = ((($30)) + 32|0);
           HEAPF64[$44>>3] = $43;
           $45 = ((($4)) + 8|0);
           $46 = +HEAPF64[$45>>3];
           $47 = ((($30)) + 40|0);
           HEAPF64[$47>>3] = $46;
           $48 = ((($4)) + 16|0);
           $49 = +HEAPF64[$48>>3];
           $50 = ((($30)) + 48|0);
           HEAPF64[$50>>3] = $49;
           $51 = ((($4)) + 24|0);
           $52 = +HEAPF64[$51>>3];
           $53 = ((($30)) + 56|0);
           HEAPF64[$53>>3] = $52;
           $54 = ((($4)) + 32|0);
           $55 = +HEAPF64[$54>>3];
           $56 = ((($30)) + 64|0);
           HEAPF64[$56>>3] = $55;
           $57 = ((($4)) + 40|0);
           $58 = +HEAPF64[$57>>3];
           $59 = ((($30)) + 72|0);
           HEAPF64[$59>>3] = $58;
           $60 = ((($4)) + 48|0);
           $61 = +HEAPF64[$60>>3];
           $62 = ((($30)) + 80|0);
           HEAPF64[$62>>3] = $61;
           $63 = ((($4)) + 56|0);
           $64 = +HEAPF64[$63>>3];
           $65 = ((($30)) + 88|0);
           HEAPF64[$65>>3] = $64;
           $66 = ((($4)) + 64|0);
           $67 = +HEAPF64[$66>>3];
           $68 = ((($30)) + 96|0);
           HEAPF64[$68>>3] = $67;
           $69 = ((($4)) + 72|0);
           $70 = +HEAPF64[$69>>3];
           $71 = ((($30)) + 104|0);
           HEAPF64[$71>>3] = $70;
           $72 = ((($4)) + 80|0);
           $73 = +HEAPF64[$72>>3];
           $74 = ((($30)) + 112|0);
           HEAPF64[$74>>3] = $73;
           $75 = ((($4)) + 88|0);
           $76 = +HEAPF64[$75>>3];
           $77 = ((($30)) + 120|0);
           HEAPF64[$77>>3] = $76;
           $78 = ((($4)) + 96|0);
           $79 = +HEAPF64[$78>>3];
           $80 = ((($30)) + 128|0);
           HEAPF64[$80>>3] = $79;
           $81 = ((($4)) + 104|0);
           $82 = +HEAPF64[$81>>3];
           $83 = ((($30)) + 136|0);
           HEAPF64[$83>>3] = $82;
           $84 = ((($4)) + 112|0);
           $85 = +HEAPF64[$84>>3];
           $86 = ((($30)) + 144|0);
           HEAPF64[$86>>3] = $85;
           $87 = ((($4)) + 120|0);
           $88 = +HEAPF64[$87>>3];
           $89 = ((($30)) + 152|0);
           HEAPF64[$89>>3] = $88;
           HEAP32[$30>>2] = (47588);
           $90 = (__Znwj(160)|0);
           $91 = HEAP32[$19>>2]|0;
           $92 = ($91|0)==(0);
           if ($92) {
            $100 = 0;
           } else {
            $93 = HEAP32[$22>>2]|0;
            $94 = ((($93)) + 8|0);
            $95 = HEAP32[$94>>2]|0;
            $100 = $95;
           }
           __THREW__ = 0;
           invoke_vi(3299,($5|0));
           $96 = __THREW__; __THREW__ = 0;
           $97 = $96&1;
           if (!($97)) {
            $98 = ((($1)) + 432|0);
            $99 = ((($100)) + 32|0);
            __THREW__ = 0;
            invoke_viii(3300,($5|0),($99|0),($98|0));
            $101 = __THREW__; __THREW__ = 0;
            $102 = $101&1;
            if (!($102)) {
             __THREW__ = 0;
             invoke_vii(3435,($90|0),0);
             $103 = __THREW__; __THREW__ = 0;
             $104 = $103&1;
             if (!($104)) {
              $105 = ((($90)) + 12|0);
              ;HEAP32[$105>>2]=0|0;HEAP32[$105+4>>2]=0|0;HEAP32[$105+8>>2]=0|0;
              $106 = ((($90)) + 24|0);
              HEAP32[$106>>2] = 2;
              $107 = ((($90)) + 28|0);
              HEAP32[$107>>2] = 0;
              $108 = +HEAPF64[$5>>3];
              $109 = ((($90)) + 32|0);
              HEAPF64[$109>>3] = $108;
              $110 = ((($5)) + 8|0);
              $111 = +HEAPF64[$110>>3];
              $112 = ((($90)) + 40|0);
              HEAPF64[$112>>3] = $111;
              $113 = ((($5)) + 16|0);
              $114 = +HEAPF64[$113>>3];
              $115 = ((($90)) + 48|0);
              HEAPF64[$115>>3] = $114;
              $116 = ((($5)) + 24|0);
              $117 = +HEAPF64[$116>>3];
              $118 = ((($90)) + 56|0);
              HEAPF64[$118>>3] = $117;
              $119 = ((($5)) + 32|0);
              $120 = +HEAPF64[$119>>3];
              $121 = ((($90)) + 64|0);
              HEAPF64[$121>>3] = $120;
              $122 = ((($5)) + 40|0);
              $123 = +HEAPF64[$122>>3];
              $124 = ((($90)) + 72|0);
              HEAPF64[$124>>3] = $123;
              $125 = ((($5)) + 48|0);
              $126 = +HEAPF64[$125>>3];
              $127 = ((($90)) + 80|0);
              HEAPF64[$127>>3] = $126;
              $128 = ((($5)) + 56|0);
              $129 = +HEAPF64[$128>>3];
              $130 = ((($90)) + 88|0);
              HEAPF64[$130>>3] = $129;
              $131 = ((($5)) + 64|0);
              $132 = +HEAPF64[$131>>3];
              $133 = ((($90)) + 96|0);
              HEAPF64[$133>>3] = $132;
              $134 = ((($5)) + 72|0);
              $135 = +HEAPF64[$134>>3];
              $136 = ((($90)) + 104|0);
              HEAPF64[$136>>3] = $135;
              $137 = ((($5)) + 80|0);
              $138 = +HEAPF64[$137>>3];
              $139 = ((($90)) + 112|0);
              HEAPF64[$139>>3] = $138;
              $140 = ((($5)) + 88|0);
              $141 = +HEAPF64[$140>>3];
              $142 = ((($90)) + 120|0);
              HEAPF64[$142>>3] = $141;
              $143 = ((($5)) + 96|0);
              $144 = +HEAPF64[$143>>3];
              $145 = ((($90)) + 128|0);
              HEAPF64[$145>>3] = $144;
              $146 = ((($5)) + 104|0);
              $147 = +HEAPF64[$146>>3];
              $148 = ((($90)) + 136|0);
              HEAPF64[$148>>3] = $147;
              $149 = ((($5)) + 112|0);
              $150 = +HEAPF64[$149>>3];
              $151 = ((($90)) + 144|0);
              HEAPF64[$151>>3] = $150;
              $152 = ((($5)) + 120|0);
              $153 = +HEAPF64[$152>>3];
              $154 = ((($90)) + 152|0);
              HEAPF64[$154>>3] = $153;
              HEAP32[$90>>2] = (47588);
              $155 = (__Znwj(160)|0);
              $156 = ((($0)) + 120|0);
              $157 = HEAP32[$156>>2]|0;
              $158 = ($157|0)==(0);
              if ($158) {
               $164 = 0;
              } else {
               $159 = ((($0)) + 112|0);
               $160 = HEAP32[$159>>2]|0;
               $161 = ((($160)) + 8|0);
               $162 = HEAP32[$161>>2]|0;
               $164 = $162;
              }
              HEAP32[$3>>2] = (58136);
              $163 = ((($3)) + 4|0);
              HEAP32[$163>>2] = 0;
              __THREW__ = 0;
              invoke_viii(3468,($155|0),($164|0),($3|0));
              $165 = __THREW__; __THREW__ = 0;
              $166 = $165&1;
              if (!($166)) {
               $167 = ((($164)) + 32|0);
               $168 = +HEAPF64[$167>>3];
               $169 = ((($155)) + 32|0);
               HEAPF64[$169>>3] = $168;
               $170 = ((($164)) + 40|0);
               $171 = +HEAPF64[$170>>3];
               $172 = ((($155)) + 40|0);
               HEAPF64[$172>>3] = $171;
               $173 = ((($164)) + 48|0);
               $174 = +HEAPF64[$173>>3];
               $175 = ((($155)) + 48|0);
               HEAPF64[$175>>3] = $174;
               $176 = ((($164)) + 56|0);
               $177 = +HEAPF64[$176>>3];
               $178 = ((($155)) + 56|0);
               HEAPF64[$178>>3] = $177;
               $179 = ((($164)) + 64|0);
               $180 = +HEAPF64[$179>>3];
               $181 = ((($155)) + 64|0);
               HEAPF64[$181>>3] = $180;
               $182 = ((($164)) + 72|0);
               $183 = +HEAPF64[$182>>3];
               $184 = ((($155)) + 72|0);
               HEAPF64[$184>>3] = $183;
               $185 = ((($164)) + 80|0);
               $186 = +HEAPF64[$185>>3];
               $187 = ((($155)) + 80|0);
               HEAPF64[$187>>3] = $186;
               $188 = ((($164)) + 88|0);
               $189 = +HEAPF64[$188>>3];
               $190 = ((($155)) + 88|0);
               HEAPF64[$190>>3] = $189;
               $191 = ((($164)) + 96|0);
               $192 = +HEAPF64[$191>>3];
               $193 = ((($155)) + 96|0);
               HEAPF64[$193>>3] = $192;
               $194 = ((($164)) + 104|0);
               $195 = +HEAPF64[$194>>3];
               $196 = ((($155)) + 104|0);
               HEAPF64[$196>>3] = $195;
               $197 = ((($164)) + 112|0);
               $198 = +HEAPF64[$197>>3];
               $199 = ((($155)) + 112|0);
               HEAPF64[$199>>3] = $198;
               $200 = ((($164)) + 120|0);
               $201 = +HEAPF64[$200>>3];
               $202 = ((($155)) + 120|0);
               HEAPF64[$202>>3] = $201;
               $203 = ((($164)) + 128|0);
               $204 = +HEAPF64[$203>>3];
               $205 = ((($155)) + 128|0);
               HEAPF64[$205>>3] = $204;
               $206 = ((($164)) + 136|0);
               $207 = +HEAPF64[$206>>3];
               $208 = ((($155)) + 136|0);
               HEAPF64[$208>>3] = $207;
               $209 = ((($164)) + 144|0);
               $210 = +HEAPF64[$209>>3];
               $211 = ((($155)) + 144|0);
               HEAPF64[$211>>3] = $210;
               $212 = ((($164)) + 152|0);
               $213 = +HEAPF64[$212>>3];
               $214 = ((($155)) + 152|0);
               HEAPF64[$214>>3] = $213;
               HEAP32[$155>>2] = (47588);
               $$034$in = $155;$$035$in = $90;$$036 = $30;
               break;
              }
              $219 = ___cxa_find_matching_catch_2()|0;
              $220 = tempRet0;
              __ZdlPv($155);
              $$4 = $220;$$433 = $219;
              ___resumeException($$433|0);
              // unreachable;
             }
            }
           }
           $217 = ___cxa_find_matching_catch_2()|0;
           $218 = tempRet0;
           __ZdlPv($90);
           $$4 = $218;$$433 = $217;
           ___resumeException($$433|0);
           // unreachable;
          }
         }
        }
        $215 = ___cxa_find_matching_catch_2()|0;
        $216 = tempRet0;
        __ZdlPv($30);
        $$4 = $216;$$433 = $215;
        ___resumeException($$433|0);
        // unreachable;
       } else {
        $221 = HEAP32[$16>>2]|0;
        __THREW__ = 0;
        invoke_vi(3299,($6|0));
        $222 = __THREW__; __THREW__ = 0;
        $223 = $222&1;
        if (!($223)) {
         $224 = ((($1)) + 304|0);
         $225 = ((($221)) + 32|0);
         __THREW__ = 0;
         invoke_viii(3300,($6|0),($224|0),($225|0));
         $226 = __THREW__; __THREW__ = 0;
         $227 = $226&1;
         if (!($227)) {
          __THREW__ = 0;
          invoke_vii(3435,($30|0),0);
          $228 = __THREW__; __THREW__ = 0;
          $229 = $228&1;
          if (!($229)) {
           $230 = ((($30)) + 12|0);
           ;HEAP32[$230>>2]=0|0;HEAP32[$230+4>>2]=0|0;HEAP32[$230+8>>2]=0|0;
           $231 = ((($30)) + 24|0);
           HEAP32[$231>>2] = 2;
           $232 = ((($30)) + 28|0);
           HEAP32[$232>>2] = 0;
           $233 = +HEAPF64[$6>>3];
           $234 = ((($30)) + 32|0);
           HEAPF64[$234>>3] = $233;
           $235 = ((($6)) + 8|0);
           $236 = +HEAPF64[$235>>3];
           $237 = ((($30)) + 40|0);
           HEAPF64[$237>>3] = $236;
           $238 = ((($6)) + 16|0);
           $239 = +HEAPF64[$238>>3];
           $240 = ((($30)) + 48|0);
           HEAPF64[$240>>3] = $239;
           $241 = ((($6)) + 24|0);
           $242 = +HEAPF64[$241>>3];
           $243 = ((($30)) + 56|0);
           HEAPF64[$243>>3] = $242;
           $244 = ((($6)) + 32|0);
           $245 = +HEAPF64[$244>>3];
           $246 = ((($30)) + 64|0);
           HEAPF64[$246>>3] = $245;
           $247 = ((($6)) + 40|0);
           $248 = +HEAPF64[$247>>3];
           $249 = ((($30)) + 72|0);
           HEAPF64[$249>>3] = $248;
           $250 = ((($6)) + 48|0);
           $251 = +HEAPF64[$250>>3];
           $252 = ((($30)) + 80|0);
           HEAPF64[$252>>3] = $251;
           $253 = ((($6)) + 56|0);
           $254 = +HEAPF64[$253>>3];
           $255 = ((($30)) + 88|0);
           HEAPF64[$255>>3] = $254;
           $256 = ((($6)) + 64|0);
           $257 = +HEAPF64[$256>>3];
           $258 = ((($30)) + 96|0);
           HEAPF64[$258>>3] = $257;
           $259 = ((($6)) + 72|0);
           $260 = +HEAPF64[$259>>3];
           $261 = ((($30)) + 104|0);
           HEAPF64[$261>>3] = $260;
           $262 = ((($6)) + 80|0);
           $263 = +HEAPF64[$262>>3];
           $264 = ((($30)) + 112|0);
           HEAPF64[$264>>3] = $263;
           $265 = ((($6)) + 88|0);
           $266 = +HEAPF64[$265>>3];
           $267 = ((($30)) + 120|0);
           HEAPF64[$267>>3] = $266;
           $268 = ((($6)) + 96|0);
           $269 = +HEAPF64[$268>>3];
           $270 = ((($30)) + 128|0);
           HEAPF64[$270>>3] = $269;
           $271 = ((($6)) + 104|0);
           $272 = +HEAPF64[$271>>3];
           $273 = ((($30)) + 136|0);
           HEAPF64[$273>>3] = $272;
           $274 = ((($6)) + 112|0);
           $275 = +HEAPF64[$274>>3];
           $276 = ((($30)) + 144|0);
           HEAPF64[$276>>3] = $275;
           $277 = ((($6)) + 120|0);
           $278 = +HEAPF64[$277>>3];
           $279 = ((($30)) + 152|0);
           HEAPF64[$279>>3] = $278;
           HEAP32[$30>>2] = (47588);
           $280 = (__Znwj(160)|0);
           $281 = HEAP32[$19>>2]|0;
           $282 = ($281|0)==(0);
           if ($282) {
            $287 = 0;
           } else {
            $283 = HEAP32[$22>>2]|0;
            $284 = ((($283)) + 8|0);
            $285 = HEAP32[$284>>2]|0;
            $287 = $285;
           }
           HEAP32[$2>>2] = (58136);
           $286 = ((($2)) + 4|0);
           HEAP32[$286>>2] = 0;
           __THREW__ = 0;
           invoke_viii(3468,($280|0),($287|0),($2|0));
           $288 = __THREW__; __THREW__ = 0;
           $289 = $288&1;
           if ($289) {
            $407 = ___cxa_find_matching_catch_2()|0;
            $408 = tempRet0;
            __ZdlPv($280);
            $$4 = $408;$$433 = $407;
            ___resumeException($$433|0);
            // unreachable;
           }
           $290 = ((($287)) + 32|0);
           $291 = +HEAPF64[$290>>3];
           $292 = ((($280)) + 32|0);
           HEAPF64[$292>>3] = $291;
           $293 = ((($287)) + 40|0);
           $294 = +HEAPF64[$293>>3];
           $295 = ((($280)) + 40|0);
           HEAPF64[$295>>3] = $294;
           $296 = ((($287)) + 48|0);
           $297 = +HEAPF64[$296>>3];
           $298 = ((($280)) + 48|0);
           HEAPF64[$298>>3] = $297;
           $299 = ((($287)) + 56|0);
           $300 = +HEAPF64[$299>>3];
           $301 = ((($280)) + 56|0);
           HEAPF64[$301>>3] = $300;
           $302 = ((($287)) + 64|0);
           $303 = +HEAPF64[$302>>3];
           $304 = ((($280)) + 64|0);
           HEAPF64[$304>>3] = $303;
           $305 = ((($287)) + 72|0);
           $306 = +HEAPF64[$305>>3];
           $307 = ((($280)) + 72|0);
           HEAPF64[$307>>3] = $306;
           $308 = ((($287)) + 80|0);
           $309 = +HEAPF64[$308>>3];
           $310 = ((($280)) + 80|0);
           HEAPF64[$310>>3] = $309;
           $311 = ((($287)) + 88|0);
           $312 = +HEAPF64[$311>>3];
           $313 = ((($280)) + 88|0);
           HEAPF64[$313>>3] = $312;
           $314 = ((($287)) + 96|0);
           $315 = +HEAPF64[$314>>3];
           $316 = ((($280)) + 96|0);
           HEAPF64[$316>>3] = $315;
           $317 = ((($287)) + 104|0);
           $318 = +HEAPF64[$317>>3];
           $319 = ((($280)) + 104|0);
           HEAPF64[$319>>3] = $318;
           $320 = ((($287)) + 112|0);
           $321 = +HEAPF64[$320>>3];
           $322 = ((($280)) + 112|0);
           HEAPF64[$322>>3] = $321;
           $323 = ((($287)) + 120|0);
           $324 = +HEAPF64[$323>>3];
           $325 = ((($280)) + 120|0);
           HEAPF64[$325>>3] = $324;
           $326 = ((($287)) + 128|0);
           $327 = +HEAPF64[$326>>3];
           $328 = ((($280)) + 128|0);
           HEAPF64[$328>>3] = $327;
           $329 = ((($287)) + 136|0);
           $330 = +HEAPF64[$329>>3];
           $331 = ((($280)) + 136|0);
           HEAPF64[$331>>3] = $330;
           $332 = ((($287)) + 144|0);
           $333 = +HEAPF64[$332>>3];
           $334 = ((($280)) + 144|0);
           HEAPF64[$334>>3] = $333;
           $335 = ((($287)) + 152|0);
           $336 = +HEAPF64[$335>>3];
           $337 = ((($280)) + 152|0);
           HEAPF64[$337>>3] = $336;
           HEAP32[$280>>2] = (47588);
           $338 = (__Znwj(160)|0);
           $339 = ((($1)) + 432|0);
           $340 = ((($0)) + 120|0);
           $341 = HEAP32[$340>>2]|0;
           $342 = ($341|0)==(0);
           if ($342) {
            $350 = 0;
           } else {
            $343 = ((($0)) + 112|0);
            $344 = HEAP32[$343>>2]|0;
            $345 = ((($344)) + 8|0);
            $346 = HEAP32[$345>>2]|0;
            $350 = $346;
           }
           __THREW__ = 0;
           invoke_vi(3299,($7|0));
           $347 = __THREW__; __THREW__ = 0;
           $348 = $347&1;
           if (!($348)) {
            $349 = ((($350)) + 32|0);
            __THREW__ = 0;
            invoke_viii(3300,($7|0),($339|0),($349|0));
            $351 = __THREW__; __THREW__ = 0;
            $352 = $351&1;
            if (!($352)) {
             __THREW__ = 0;
             invoke_vii(3435,($338|0),0);
             $353 = __THREW__; __THREW__ = 0;
             $354 = $353&1;
             if (!($354)) {
              $355 = ((($338)) + 12|0);
              ;HEAP32[$355>>2]=0|0;HEAP32[$355+4>>2]=0|0;HEAP32[$355+8>>2]=0|0;
              $356 = ((($338)) + 24|0);
              HEAP32[$356>>2] = 2;
              $357 = ((($338)) + 28|0);
              HEAP32[$357>>2] = 0;
              $358 = +HEAPF64[$7>>3];
              $359 = ((($338)) + 32|0);
              HEAPF64[$359>>3] = $358;
              $360 = ((($7)) + 8|0);
              $361 = +HEAPF64[$360>>3];
              $362 = ((($338)) + 40|0);
              HEAPF64[$362>>3] = $361;
              $363 = ((($7)) + 16|0);
              $364 = +HEAPF64[$363>>3];
              $365 = ((($338)) + 48|0);
              HEAPF64[$365>>3] = $364;
              $366 = ((($7)) + 24|0);
              $367 = +HEAPF64[$366>>3];
              $368 = ((($338)) + 56|0);
              HEAPF64[$368>>3] = $367;
              $369 = ((($7)) + 32|0);
              $370 = +HEAPF64[$369>>3];
              $371 = ((($338)) + 64|0);
              HEAPF64[$371>>3] = $370;
              $372 = ((($7)) + 40|0);
              $373 = +HEAPF64[$372>>3];
              $374 = ((($338)) + 72|0);
              HEAPF64[$374>>3] = $373;
              $375 = ((($7)) + 48|0);
              $376 = +HEAPF64[$375>>3];
              $377 = ((($338)) + 80|0);
              HEAPF64[$377>>3] = $376;
              $378 = ((($7)) + 56|0);
              $379 = +HEAPF64[$378>>3];
              $380 = ((($338)) + 88|0);
              HEAPF64[$380>>3] = $379;
              $381 = ((($7)) + 64|0);
              $382 = +HEAPF64[$381>>3];
              $383 = ((($338)) + 96|0);
              HEAPF64[$383>>3] = $382;
              $384 = ((($7)) + 72|0);
              $385 = +HEAPF64[$384>>3];
              $386 = ((($338)) + 104|0);
              HEAPF64[$386>>3] = $385;
              $387 = ((($7)) + 80|0);
              $388 = +HEAPF64[$387>>3];
              $389 = ((($338)) + 112|0);
              HEAPF64[$389>>3] = $388;
              $390 = ((($7)) + 88|0);
              $391 = +HEAPF64[$390>>3];
              $392 = ((($338)) + 120|0);
              HEAPF64[$392>>3] = $391;
              $393 = ((($7)) + 96|0);
              $394 = +HEAPF64[$393>>3];
              $395 = ((($338)) + 128|0);
              HEAPF64[$395>>3] = $394;
              $396 = ((($7)) + 104|0);
              $397 = +HEAPF64[$396>>3];
              $398 = ((($338)) + 136|0);
              HEAPF64[$398>>3] = $397;
              $399 = ((($7)) + 112|0);
              $400 = +HEAPF64[$399>>3];
              $401 = ((($338)) + 144|0);
              HEAPF64[$401>>3] = $400;
              $402 = ((($7)) + 120|0);
              $403 = +HEAPF64[$402>>3];
              $404 = ((($338)) + 152|0);
              HEAPF64[$404>>3] = $403;
              HEAP32[$338>>2] = (47588);
              $$034$in = $338;$$035$in = $280;$$036 = $30;
              break;
             }
            }
           }
           $409 = ___cxa_find_matching_catch_2()|0;
           $410 = tempRet0;
           __ZdlPv($338);
           $$4 = $410;$$433 = $409;
           ___resumeException($$433|0);
           // unreachable;
          }
         }
        }
        $405 = ___cxa_find_matching_catch_2()|0;
        $406 = tempRet0;
        __ZdlPv($30);
        $$4 = $406;$$433 = $405;
        ___resumeException($$433|0);
        // unreachable;
       }
      }
     }
    }
   }
  } else {
   label = 37;
  }
 } while(0);
 do {
  if ((label|0) == 37) {
   $411 = (__Znwj(160)|0);
   __THREW__ = 0;
   invoke_vii(3435,($411|0),0);
   $412 = __THREW__; __THREW__ = 0;
   $413 = $412&1;
   if ($413) {
    $534 = ___cxa_find_matching_catch_2()|0;
    $535 = tempRet0;
    __ZdlPv($411);
    $$4 = $535;$$433 = $534;
    ___resumeException($$433|0);
    // unreachable;
   }
   $414 = ((($411)) + 12|0);
   ;HEAP32[$414>>2]=0|0;HEAP32[$414+4>>2]=0|0;HEAP32[$414+8>>2]=0|0;
   $415 = ((($411)) + 24|0);
   HEAP32[$415>>2] = 2;
   $416 = ((($411)) + 28|0);
   HEAP32[$416>>2] = 0;
   $417 = ((($1)) + 304|0);
   $418 = +HEAPF64[$417>>3];
   $419 = ((($411)) + 32|0);
   HEAPF64[$419>>3] = $418;
   $420 = ((($1)) + 312|0);
   $421 = +HEAPF64[$420>>3];
   $422 = ((($411)) + 40|0);
   HEAPF64[$422>>3] = $421;
   $423 = ((($1)) + 320|0);
   $424 = +HEAPF64[$423>>3];
   $425 = ((($411)) + 48|0);
   HEAPF64[$425>>3] = $424;
   $426 = ((($1)) + 328|0);
   $427 = +HEAPF64[$426>>3];
   $428 = ((($411)) + 56|0);
   HEAPF64[$428>>3] = $427;
   $429 = ((($1)) + 336|0);
   $430 = +HEAPF64[$429>>3];
   $431 = ((($411)) + 64|0);
   HEAPF64[$431>>3] = $430;
   $432 = ((($1)) + 344|0);
   $433 = +HEAPF64[$432>>3];
   $434 = ((($411)) + 72|0);
   HEAPF64[$434>>3] = $433;
   $435 = ((($1)) + 352|0);
   $436 = +HEAPF64[$435>>3];
   $437 = ((($411)) + 80|0);
   HEAPF64[$437>>3] = $436;
   $438 = ((($1)) + 360|0);
   $439 = +HEAPF64[$438>>3];
   $440 = ((($411)) + 88|0);
   HEAPF64[$440>>3] = $439;
   $441 = ((($1)) + 368|0);
   $442 = +HEAPF64[$441>>3];
   $443 = ((($411)) + 96|0);
   HEAPF64[$443>>3] = $442;
   $444 = ((($1)) + 376|0);
   $445 = +HEAPF64[$444>>3];
   $446 = ((($411)) + 104|0);
   HEAPF64[$446>>3] = $445;
   $447 = ((($1)) + 384|0);
   $448 = +HEAPF64[$447>>3];
   $449 = ((($411)) + 112|0);
   HEAPF64[$449>>3] = $448;
   $450 = ((($1)) + 392|0);
   $451 = +HEAPF64[$450>>3];
   $452 = ((($411)) + 120|0);
   HEAPF64[$452>>3] = $451;
   $453 = ((($1)) + 400|0);
   $454 = +HEAPF64[$453>>3];
   $455 = ((($411)) + 128|0);
   HEAPF64[$455>>3] = $454;
   $456 = ((($1)) + 408|0);
   $457 = +HEAPF64[$456>>3];
   $458 = ((($411)) + 136|0);
   HEAPF64[$458>>3] = $457;
   $459 = ((($1)) + 416|0);
   $460 = +HEAPF64[$459>>3];
   $461 = ((($411)) + 144|0);
   HEAPF64[$461>>3] = $460;
   $462 = ((($1)) + 424|0);
   $463 = +HEAPF64[$462>>3];
   $464 = ((($411)) + 152|0);
   HEAPF64[$464>>3] = $463;
   HEAP32[$411>>2] = (47588);
   $465 = (__Znwj(160)|0);
   __THREW__ = 0;
   invoke_vii(3435,($465|0),0);
   $466 = __THREW__; __THREW__ = 0;
   $467 = $466&1;
   if ($467) {
    $536 = ___cxa_find_matching_catch_2()|0;
    $537 = tempRet0;
    __ZdlPv($465);
    $$4 = $537;$$433 = $536;
    ___resumeException($$433|0);
    // unreachable;
   }
   $468 = ((($465)) + 12|0);
   ;HEAP32[$468>>2]=0|0;HEAP32[$468+4>>2]=0|0;HEAP32[$468+8>>2]=0|0;
   $469 = ((($465)) + 24|0);
   HEAP32[$469>>2] = 2;
   $470 = ((($465)) + 28|0);
   HEAP32[$470>>2] = 0;
   $471 = ((($1)) + 432|0);
   $472 = +HEAPF64[$471>>3];
   $473 = ((($465)) + 32|0);
   HEAPF64[$473>>3] = $472;
   $474 = ((($1)) + 440|0);
   $475 = +HEAPF64[$474>>3];
   $476 = ((($465)) + 40|0);
   HEAPF64[$476>>3] = $475;
   $477 = ((($1)) + 448|0);
   $478 = +HEAPF64[$477>>3];
   $479 = ((($465)) + 48|0);
   HEAPF64[$479>>3] = $478;
   $480 = ((($1)) + 456|0);
   $481 = +HEAPF64[$480>>3];
   $482 = ((($465)) + 56|0);
   HEAPF64[$482>>3] = $481;
   $483 = ((($1)) + 464|0);
   $484 = +HEAPF64[$483>>3];
   $485 = ((($465)) + 64|0);
   HEAPF64[$485>>3] = $484;
   $486 = ((($1)) + 472|0);
   $487 = +HEAPF64[$486>>3];
   $488 = ((($465)) + 72|0);
   HEAPF64[$488>>3] = $487;
   $489 = ((($1)) + 480|0);
   $490 = +HEAPF64[$489>>3];
   $491 = ((($465)) + 80|0);
   HEAPF64[$491>>3] = $490;
   $492 = ((($1)) + 488|0);
   $493 = +HEAPF64[$492>>3];
   $494 = ((($465)) + 88|0);
   HEAPF64[$494>>3] = $493;
   $495 = ((($1)) + 496|0);
   $496 = +HEAPF64[$495>>3];
   $497 = ((($465)) + 96|0);
   HEAPF64[$497>>3] = $496;
   $498 = ((($1)) + 504|0);
   $499 = +HEAPF64[$498>>3];
   $500 = ((($465)) + 104|0);
   HEAPF64[$500>>3] = $499;
   $501 = ((($1)) + 512|0);
   $502 = +HEAPF64[$501>>3];
   $503 = ((($465)) + 112|0);
   HEAPF64[$503>>3] = $502;
   $504 = ((($1)) + 520|0);
   $505 = +HEAPF64[$504>>3];
   $506 = ((($465)) + 120|0);
   HEAPF64[$506>>3] = $505;
   $507 = ((($1)) + 528|0);
   $508 = +HEAPF64[$507>>3];
   $509 = ((($465)) + 128|0);
   HEAPF64[$509>>3] = $508;
   $510 = ((($1)) + 536|0);
   $511 = +HEAPF64[$510>>3];
   $512 = ((($465)) + 136|0);
   HEAPF64[$512>>3] = $511;
   $513 = ((($1)) + 544|0);
   $514 = +HEAPF64[$513>>3];
   $515 = ((($465)) + 144|0);
   HEAPF64[$515>>3] = $514;
   $516 = ((($1)) + 552|0);
   $517 = +HEAPF64[$516>>3];
   $518 = ((($465)) + 152|0);
   HEAPF64[$518>>3] = $517;
   HEAP32[$465>>2] = (47588);
   $519 = (__Znwj(160)|0);
   __THREW__ = 0;
   invoke_vii(3435,($519|0),0);
   $520 = __THREW__; __THREW__ = 0;
   $521 = $520&1;
   if ($521) {
    $538 = ___cxa_find_matching_catch_2()|0;
    $539 = tempRet0;
    $eh$lpad$body68$index10Z2D = $539;$eh$lpad$body68$indexZ2D = $538;
   } else {
    HEAP32[$519>>2] = (63412);
    $522 = ((($519)) + 12|0);
    ;HEAP32[$522>>2]=0|0;HEAP32[$522+4>>2]=0|0;HEAP32[$522+8>>2]=0|0;
    $523 = ((($519)) + 24|0);
    HEAP32[$523>>2] = 2;
    $524 = ((($519)) + 28|0);
    HEAP32[$524>>2] = 0;
    $525 = ((($519)) + 32|0);
    __THREW__ = 0;
    invoke_vi(3299,($525|0));
    $526 = __THREW__; __THREW__ = 0;
    $527 = $526&1;
    if (!($527)) {
     HEAP32[$519>>2] = (47588);
     $$034$in = $519;$$035$in = $465;$$036 = $411;
     break;
    }
    $528 = ___cxa_find_matching_catch_2()|0;
    $529 = tempRet0;
    __THREW__ = 0;
    invoke_vi(388,($519|0));
    $530 = __THREW__; __THREW__ = 0;
    $531 = $530&1;
    if ($531) {
     $532 = ___cxa_find_matching_catch_3(0|0)|0;
     $533 = tempRet0;
     ___clang_call_terminate($532);
     // unreachable;
    } else {
     $eh$lpad$body68$index10Z2D = $529;$eh$lpad$body68$indexZ2D = $528;
    }
   }
   __ZdlPv($519);
   $$4 = $eh$lpad$body68$index10Z2D;$$433 = $eh$lpad$body68$indexZ2D;
   ___resumeException($$433|0);
   // unreachable;
  }
 } while(0);
 $540 = ((($1)) + 288|0);
 $541 = HEAP32[$540>>2]|0;
 $542 = ($541|0)==(0|0);
 if (!($542)) {
  __ZN7osgUtil19IntersectionVisitor16pushWindowMatrixEPN3osg8ViewportE($0,$541);
 }
 __ZN7osgUtil19IntersectionVisitor20pushProjectionMatrixEPN3osg10RefMatrixdE($0,$$036);
 __ZN7osgUtil19IntersectionVisitor14pushViewMatrixEPN3osg10RefMatrixdE($0,$$035$in);
 __ZN7osgUtil19IntersectionVisitor15pushModelMatrixEPN3osg10RefMatrixdE($0,$$034$in);
 $543 = ((($0)) + 56|0);
 $544 = ((($0)) + 60|0);
 $545 = HEAP32[$544>>2]|0;
 $546 = ((($545)) + 8|0);
 $547 = HEAP32[$546>>2]|0;
 $548 = HEAP32[$547>>2]|0;
 $549 = ((($548)) + 12|0);
 $550 = HEAP32[$549>>2]|0;
 $551 = (FUNCTION_TABLE_iii[$550 & 8191]($547,$0)|0);
 $552 = ($551|0)==(0|0);
 if (!($552)) {
  $553 = ((($551)) + 8|0);
  $554 = HEAP32[$553>>2]|0;HEAP32[$553>>2] = (($554+1)|0);
 }
 __THREW__ = 0;
 $555 = (invoke_ii(3276,12)|0);
 $556 = __THREW__; __THREW__ = 0;
 $557 = $556&1;
 if ($557) {
  $570 = ___cxa_find_matching_catch_2()|0;
  $571 = tempRet0;
  if ($552) {
   ___resumeException($570|0);
   // unreachable;
  }
  $572 = ((($551)) + 8|0);
  $573 = HEAP32[$572>>2]|0;HEAP32[$572>>2] = (($573-1)|0);
  $574 = ($573|0)==(1);
  if (!($574)) {
   ___resumeException($570|0);
   // unreachable;
  }
  __THREW__ = 0;
  invoke_viii(3262,($551|0),1,1);
  $575 = __THREW__; __THREW__ = 0;
  $576 = $575&1;
  if ($576) {
   $577 = ___cxa_find_matching_catch_3(0|0)|0;
   $578 = tempRet0;
   ___clang_call_terminate($577);
   // unreachable;
  } else {
   ___resumeException($570|0);
   // unreachable;
  }
 }
 $558 = ((($555)) + 8|0);
 HEAP32[$558>>2] = $551;
 if (!($552)) {
  $559 = ((($551)) + 8|0);
  $560 = HEAP32[$559>>2]|0;HEAP32[$559>>2] = (($560+1)|0);
 }
 $561 = ((($555)) + 4|0);
 HEAP32[$561>>2] = $543;
 $562 = HEAP32[$543>>2]|0;
 HEAP32[$555>>2] = $562;
 $563 = ((($562)) + 4|0);
 HEAP32[$563>>2] = $555;
 HEAP32[$543>>2] = $555;
 $564 = ((($0)) + 64|0);
 $565 = HEAP32[$564>>2]|0;
 $566 = (($565) + 1)|0;
 HEAP32[$564>>2] = $566;
 if (!($552)) {
  $567 = ((($551)) + 8|0);
  $568 = HEAP32[$567>>2]|0;HEAP32[$567>>2] = (($568-1)|0);
  $569 = ($568|0)==(1);
  if ($569) {
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($551,1,1);
  }
 }
 $579 = ((($0)) + 16|0);
 $580 = HEAP32[$579>>2]|0;
 switch ($580|0) {
 case 1:  {
  $581 = HEAP32[$1>>2]|0;
  $582 = ((($581)) + 192|0);
  $583 = HEAP32[$582>>2]|0;
  FUNCTION_TABLE_vii[$583 & 8191]($1,$0);
  break;
 }
 case 0:  {
  break;
 }
 default: {
  $584 = HEAP32[$1>>2]|0;
  $585 = ((($584)) + 196|0);
  $586 = HEAP32[$585>>2]|0;
  FUNCTION_TABLE_vii[$586 & 8191]($1,$0);
 }
 }
 $587 = HEAP32[$564>>2]|0;
 $588 = ($587>>>0)>(1);
 if ($588) {
  $589 = ((($0)) + 56|0);
  $590 = HEAP32[$589>>2]|0;
  $591 = ((($590)) + 4|0);
  $592 = HEAP32[$591>>2]|0;
  $593 = HEAP32[$590>>2]|0;
  $594 = ((($593)) + 4|0);
  HEAP32[$594>>2] = $592;
  $595 = HEAP32[$591>>2]|0;
  HEAP32[$595>>2] = $593;
  $596 = (($587) + -1)|0;
  HEAP32[$564>>2] = $596;
  $597 = ((($590)) + 8|0);
  $598 = HEAP32[$597>>2]|0;
  $599 = ($598|0)==(0|0);
  if (!($599)) {
   $600 = ((($598)) + 8|0);
   $601 = HEAP32[$600>>2]|0;HEAP32[$600>>2] = (($601-1)|0);
   $602 = ($601|0)==(1);
   if ($602) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($598,1,1);
   }
  }
  __ZdlPv($590);
 }
 $603 = ((($0)) + 112|0);
 $604 = HEAP32[$603>>2]|0;
 $605 = ((($604)) + 4|0);
 $606 = HEAP32[$605>>2]|0;
 $607 = HEAP32[$604>>2]|0;
 $608 = ((($607)) + 4|0);
 HEAP32[$608>>2] = $606;
 $609 = HEAP32[$605>>2]|0;
 HEAP32[$609>>2] = $607;
 $610 = ((($0)) + 120|0);
 $611 = HEAP32[$610>>2]|0;
 $612 = (($611) + -1)|0;
 HEAP32[$610>>2] = $612;
 $613 = ((($604)) + 8|0);
 $614 = HEAP32[$613>>2]|0;
 $615 = ($614|0)==(0|0);
 if (!($615)) {
  $616 = ((($614)) + 8|0);
  $617 = HEAP32[$616>>2]|0;HEAP32[$616>>2] = (($617-1)|0);
  $618 = ($617|0)==(1);
  if ($618) {
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($614,1,1);
  }
 }
 __ZdlPv($604);
 $619 = ((($0)) + 144|0);
 HEAP8[$619>>0] = 1;
 $620 = ((($0)) + 100|0);
 $621 = HEAP32[$620>>2]|0;
 $622 = ((($621)) + 4|0);
 $623 = HEAP32[$622>>2]|0;
 $624 = HEAP32[$621>>2]|0;
 $625 = ((($624)) + 4|0);
 HEAP32[$625>>2] = $623;
 $626 = HEAP32[$622>>2]|0;
 HEAP32[$626>>2] = $624;
 $627 = ((($0)) + 108|0);
 $628 = HEAP32[$627>>2]|0;
 $629 = (($628) + -1)|0;
 HEAP32[$627>>2] = $629;
 $630 = ((($621)) + 8|0);
 $631 = HEAP32[$630>>2]|0;
 $632 = ($631|0)==(0|0);
 if (!($632)) {
  $633 = ((($631)) + 8|0);
  $634 = HEAP32[$633>>2]|0;HEAP32[$633>>2] = (($634-1)|0);
  $635 = ($634|0)==(1);
  if ($635) {
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($631,1,1);
  }
 }
 __ZdlPv($621);
 HEAP8[$619>>0] = 1;
 $636 = ((($0)) + 88|0);
 $637 = HEAP32[$636>>2]|0;
 $638 = ((($637)) + 4|0);
 $639 = HEAP32[$638>>2]|0;
 $640 = HEAP32[$637>>2]|0;
 $641 = ((($640)) + 4|0);
 HEAP32[$641>>2] = $639;
 $642 = HEAP32[$638>>2]|0;
 HEAP32[$642>>2] = $640;
 $643 = ((($0)) + 96|0);
 $644 = HEAP32[$643>>2]|0;
 $645 = (($644) + -1)|0;
 HEAP32[$643>>2] = $645;
 $646 = ((($637)) + 8|0);
 $647 = HEAP32[$646>>2]|0;
 $648 = ($647|0)==(0|0);
 if (!($648)) {
  $649 = ((($647)) + 8|0);
  $650 = HEAP32[$649>>2]|0;HEAP32[$649>>2] = (($650-1)|0);
  $651 = ($650|0)==(1);
  if ($651) {
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($647,1,1);
  }
 }
 __ZdlPv($637);
 HEAP8[$619>>0] = 1;
 $652 = HEAP32[$540>>2]|0;
 $653 = ($652|0)==(0|0);
 if ($653) {
  STACKTOP = sp;return;
 }
 $654 = ((($0)) + 76|0);
 $655 = HEAP32[$654>>2]|0;
 $656 = ((($655)) + 4|0);
 $657 = HEAP32[$656>>2]|0;
 $658 = HEAP32[$655>>2]|0;
 $659 = ((($658)) + 4|0);
 HEAP32[$659>>2] = $657;
 $660 = HEAP32[$656>>2]|0;
 HEAP32[$660>>2] = $658;
 $661 = ((($0)) + 84|0);
 $662 = HEAP32[$661>>2]|0;
 $663 = (($662) + -1)|0;
 HEAP32[$661>>2] = $663;
 $664 = ((($655)) + 8|0);
 $665 = HEAP32[$664>>2]|0;
 $666 = ($665|0)==(0|0);
 if (!($666)) {
  $667 = ((($665)) + 8|0);
  $668 = HEAP32[$667>>2]|0;HEAP32[$667>>2] = (($668-1)|0);
  $669 = ($668|0)==(1);
  if ($669) {
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($665,1,1);
  }
 }
 __ZdlPv($655);
 HEAP8[$619>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN7osgUtil19IntersectionVisitor5applyERN3osg3LODE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 64|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  return;
 }
 $5 = ((($0)) + 56|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($6)) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($9)) + 16|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (FUNCTION_TABLE_iii[$11 & 8191]($8,$1)|0);
 if (!($12)) {
  return;
 }
 $13 = ((($0)) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 switch ($14|0) {
 case 1:  {
  $15 = HEAP32[$1>>2]|0;
  $16 = ((($15)) + 192|0);
  $17 = HEAP32[$16>>2]|0;
  FUNCTION_TABLE_vii[$17 & 8191]($1,$0);
  break;
 }
 case 0:  {
  break;
 }
 default: {
  $18 = HEAP32[$1>>2]|0;
  $19 = ((($18)) + 196|0);
  $20 = HEAP32[$19>>2]|0;
  FUNCTION_TABLE_vii[$20 & 8191]($1,$0);
 }
 }
 $21 = HEAP32[$5>>2]|0;
 $22 = ((($21)) + 8|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = HEAP32[$23>>2]|0;
 $25 = ((($24)) + 20|0);
 $26 = HEAP32[$25>>2]|0;
 FUNCTION_TABLE_vi[$26 & 8191]($23);
 return;
}
function __ZN7osgUtil19IntersectionVisitor5applyERN3osg8PagedLODE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$ = 0.0, $$041$ = 0, $$04196 = 0, $$1$lcssa = 0.0, $$1102 = 0.0, $$1102$us = 0.0, $$139 = 0, $$143 = 0, $$2 = 0.0, $$2$us = 0.0, $$240 = 0, $$244 = 0, $$3 = 0, $$345 = 0, $$pr = 0, $$pre = 0, $$sroa$0$1 = 0, $$sroa$0$10 = 0, $$sroa$0$3108 = 0, $$sroa$0$4 = 0;
 var $$sroa$0$6 = 0, $$sroa$0$9 = 0, $$sroa$079$0101 = 0, $$sroa$079$0101$us = 0, $$sroa$079$195 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0.0, $32 = 0, $33 = 0, $34 = 0, $35 = 0.0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0.0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i47 = 0, $scevgep5$i$i$i = 0, $scevgep5$i$i$i48 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $2 = sp + 16|0;
 $3 = sp + 12|0;
 $4 = sp;
 $5 = ((($0)) + 64|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  STACKTOP = sp;return;
 }
 $8 = ((($0)) + 56|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($9)) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = HEAP32[$11>>2]|0;
 $13 = ((($12)) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (FUNCTION_TABLE_iii[$14 & 8191]($11,$1)|0);
 if (!($15)) {
  STACKTOP = sp;return;
 }
 $16 = ((($1)) + 200|0);
 $17 = ((($1)) + 204|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = HEAP32[$16>>2]|0;
 $20 = ($18|0)==($19|0);
 if (!($20)) {
  $21 = ((($1)) + 156|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = ($22|0)==(0);
  $$ = $23 ? 1.0E+6 : 0.0;
  $24 = ((($1)) + 160|0);
  __ZNSt3__26vectorINS_4pairIffEENS_9allocatorIS2_EEEC2ERKS5_($2,$24);
  $25 = HEAP32[$2>>2]|0;
  $26 = ((($2)) + 4|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = ($25|0)==($27|0);
  do {
   if ($28) {
    $140 = $25;$142 = $25;
   } else {
    $29 = HEAP32[$21>>2]|0;
    $30 = ($29|0)==(0);
    if ($30) {
     $$1102$us = $$;$$sroa$079$0101$us = $25;
     while(1) {
      $31 = +HEAPF32[$$sroa$079$0101$us>>2];
      $32 = $31 < $$1102$us;
      $$2$us = $32 ? $31 : $$1102$us;
      $33 = ((($$sroa$079$0101$us)) + 8|0);
      $34 = ($33|0)==($27|0);
      if ($34) {
       $$1$lcssa = $$2$us;
       break;
      } else {
       $$1102$us = $$2$us;$$sroa$079$0101$us = $33;
      }
     }
    } else {
     $$1102 = $$;$$sroa$079$0101 = $25;
     while(1) {
      $35 = +HEAPF32[$$sroa$079$0101>>2];
      $36 = $35 > $$1102;
      $$2 = $36 ? $35 : $$1102;
      $37 = ((($$sroa$079$0101)) + 8|0);
      $38 = ($37|0)==($27|0);
      if ($38) {
       $$1$lcssa = $$2;
       break;
      } else {
       $$1102 = $$2;$$sroa$079$0101 = $37;
      }
     }
    }
    if ($28) {
     $140 = $25;$142 = $25;
    } else {
     $39 = ((($1)) + 124|0);
     $40 = ((($0)) + 72|0);
     $41 = ((($1)) + 176|0);
     $42 = ((($4)) + 11|0);
     $$04196 = 0;$$sroa$079$195 = $25;
     L18: while(1) {
      $43 = +HEAPF32[$$sroa$079$195>>2];
      $44 = $43 != $$1$lcssa;
      L20: do {
       if (!($44)) {
        $45 = HEAP32[$1>>2]|0;
        $46 = ((($45)) + 224|0);
        $47 = HEAP32[$46>>2]|0;
        __THREW__ = 0;
        $48 = (invoke_ii($47|0,($1|0))|0);
        $49 = __THREW__; __THREW__ = 0;
        $50 = $49&1;
        if ($50) {
         $$sroa$0$1 = 0;
         label = 14;
         break L18;
        }
        $51 = ($48>>>0)>($$04196>>>0);
        if ($51) {
         $52 = HEAP32[$39>>2]|0;
         $53 = (($52) + ($$04196<<2)|0);
         $54 = HEAP32[$53>>2]|0;
         $55 = ($54|0)==(0|0);
         if ($55) {
          label = 16;
         } else {
          $58 = ((($54)) + 8|0);
          $59 = HEAP32[$58>>2]|0;HEAP32[$58>>2] = (($59+1)|0);
          $$sroa$0$9 = $54;
         }
        } else {
         label = 16;
        }
        do {
         if ((label|0) == 16) {
          label = 0;
          $60 = HEAP32[$40>>2]|0;
          $61 = ($60|0)==(0|0);
          if (!($61)) {
           $62 = HEAP32[$17>>2]|0;
           $63 = HEAP32[$16>>2]|0;
           $64 = (($62) - ($63))|0;
           $65 = $64 >> 6;
           $66 = ($65>>>0)>($$04196>>>0);
           $67 = (($65) + -1)|0;
           $$041$ = $66 ? $$04196 : $67;
           $68 = HEAP32[$60>>2]|0;
           $69 = ((($68)) + 12|0);
           $70 = HEAP32[$69>>2]|0;
           $71 = $63;
           $72 = (($71) + ($$041$<<6)|0);
           __THREW__ = 0;
           invoke_viii(3550,($4|0),($41|0),($72|0));
           $73 = __THREW__; __THREW__ = 0;
           $74 = $73&1;
           if ($74) {
            label = 25;
            break L18;
           }
           __THREW__ = 0;
           invoke_viii($70|0,($3|0),($60|0),($4|0));
           $75 = __THREW__; __THREW__ = 0;
           $76 = $75&1;
           if ($76) {
            $$sroa$0$4 = 0;
            label = 26;
            break L18;
           }
           $77 = HEAP32[$3>>2]|0;
           $78 = ($77|0)==(0|0);
           do {
            if ($78) {
             $$sroa$0$3108 = 0;
            } else {
             $79 = ((($77)) + 8|0);
             $80 = HEAP32[$79>>2]|0;HEAP32[$79>>2] = (($80+1)|0);
             $$pr = HEAP32[$3>>2]|0;
             $81 = ($$pr|0)==(0|0);
             if ($81) {
              $$sroa$0$3108 = $77;
              break;
             }
             $82 = ((($$pr)) + 8|0);
             $83 = HEAP32[$82>>2]|0;HEAP32[$82>>2] = (($83-1)|0);
             $84 = ($83|0)==(1);
             if (!($84)) {
              $$sroa$0$3108 = $77;
              break;
             }
             __THREW__ = 0;
             invoke_viii(3262,($$pr|0),1,1);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if ($86) {
              $$sroa$0$4 = $77;
              label = 26;
              break L18;
             } else {
              $$sroa$0$3108 = $77;
             }
            }
           } while(0);
           HEAP32[$3>>2] = 0;
           $87 = HEAP8[$42>>0]|0;
           $88 = ($87<<24>>24)<(0);
           if ($88) {
            $89 = HEAP32[$4>>2]|0;
            __ZdlPv($89);
           }
           $97 = ($$sroa$0$3108|0)==(0|0);
           if (!($97)) {
            $$sroa$0$9 = $$sroa$0$3108;
            break;
           }
          }
          $98 = HEAP32[$1>>2]|0;
          $99 = ((($98)) + 224|0);
          $100 = HEAP32[$99>>2]|0;
          __THREW__ = 0;
          $101 = (invoke_ii($100|0,($1|0))|0);
          $102 = __THREW__; __THREW__ = 0;
          $103 = $102&1;
          if ($103) {
           $$sroa$0$1 = 0;
           label = 14;
           break L18;
          }
          $104 = ($101|0)==(0);
          if ($104) {
           break L20;
          }
          $105 = HEAP32[$1>>2]|0;
          $106 = ((($105)) + 224|0);
          $107 = HEAP32[$106>>2]|0;
          __THREW__ = 0;
          $108 = (invoke_ii($107|0,($1|0))|0);
          $109 = __THREW__; __THREW__ = 0;
          $110 = $109&1;
          if ($110) {
           $$sroa$0$1 = 0;
           label = 14;
           break L18;
          }
          $111 = (($108) + -1)|0;
          $112 = HEAP32[$39>>2]|0;
          $113 = (($112) + ($111<<2)|0);
          $114 = HEAP32[$113>>2]|0;
          $115 = ($114|0)==(0|0);
          if ($115) {
           break L20;
          }
          $116 = ((($114)) + 8|0);
          $117 = HEAP32[$116>>2]|0;HEAP32[$116>>2] = (($117+1)|0);
          $$sroa$0$9 = $114;
         }
        } while(0);
        $118 = HEAP32[$$sroa$0$9>>2]|0;
        $119 = ((($118)) + 188|0);
        $120 = HEAP32[$119>>2]|0;
        __THREW__ = 0;
        invoke_vii($120|0,($$sroa$0$9|0),($0|0));
        $121 = __THREW__; __THREW__ = 0;
        $122 = $121&1;
        if ($122) {
         $$sroa$0$1 = $$sroa$0$9;
         label = 14;
         break L18;
        }
        $123 = ((($$sroa$0$9)) + 8|0);
        $124 = HEAP32[$123>>2]|0;HEAP32[$123>>2] = (($124-1)|0);
        $125 = ($124|0)==(1);
        if ($125) {
         __THREW__ = 0;
         invoke_viii(3262,($$sroa$0$9|0),1,1);
         $126 = __THREW__; __THREW__ = 0;
         $127 = $126&1;
         if ($127) {
          label = 39;
          break L18;
         }
        }
       }
      } while(0);
      $128 = ((($$sroa$079$195)) + 8|0);
      $129 = (($$04196) + 1)|0;
      $130 = HEAP32[$26>>2]|0;
      $131 = ($128|0)==($130|0);
      if ($131) {
       label = 43;
       break;
      } else {
       $$04196 = $129;$$sroa$079$195 = $128;
      }
     }
     if ((label|0) == 14) {
      $56 = ___cxa_find_matching_catch_2()|0;
      $57 = tempRet0;
      $$240 = $56;$$244 = $57;$$sroa$0$10 = $$sroa$0$1;
      label = 40;
     }
     else if ((label|0) == 25) {
      $90 = ___cxa_find_matching_catch_2()|0;
      $91 = tempRet0;
      $$139 = $90;$$143 = $91;$$sroa$0$6 = 0;
      label = 28;
     }
     else if ((label|0) == 26) {
      $92 = ___cxa_find_matching_catch_2()|0;
      $93 = tempRet0;
      $94 = HEAP8[$42>>0]|0;
      $95 = ($94<<24>>24)<(0);
      if ($95) {
       $96 = HEAP32[$4>>2]|0;
       __ZdlPv($96);
       $$139 = $92;$$143 = $93;$$sroa$0$6 = $$sroa$0$4;
       label = 28;
      } else {
       $$139 = $92;$$143 = $93;$$sroa$0$6 = $$sroa$0$4;
       label = 28;
      }
     }
     else if ((label|0) == 39) {
      $132 = ___cxa_find_matching_catch_2()|0;
      $133 = tempRet0;
      $$3 = $132;$$345 = $133;
     }
     else if ((label|0) == 43) {
      $$pre = HEAP32[$2>>2]|0;
      $140 = $$pre;$142 = $128;
      break;
     }
     if ((label|0) == 28) {
      $$240 = $$139;$$244 = $$143;$$sroa$0$10 = $$sroa$0$6;
      label = 40;
     }
     if ((label|0) == 40) {
      $134 = ($$sroa$0$10|0)==(0|0);
      if ($134) {
       $$3 = $$240;$$345 = $$244;
      } else {
       $135 = ((($$sroa$0$10)) + 8|0);
       $136 = HEAP32[$135>>2]|0;HEAP32[$135>>2] = (($136-1)|0);
       $137 = ($136|0)==(1);
       if ($137) {
        __THREW__ = 0;
        invoke_viii(3262,($$sroa$0$10|0),1,1);
        $138 = __THREW__; __THREW__ = 0;
        $139 = $138&1;
        if ($139) {
         $164 = ___cxa_find_matching_catch_3(0|0)|0;
         $165 = tempRet0;
         ___clang_call_terminate($164);
         // unreachable;
        } else {
         $$3 = $$240;$$345 = $$244;
        }
       } else {
        $$3 = $$240;$$345 = $$244;
       }
      }
     }
     $149 = HEAP32[$2>>2]|0;
     $150 = ($149|0)==(0|0);
     if ($150) {
      ___resumeException($$3|0);
      // unreachable;
     }
     $151 = HEAP32[$26>>2]|0;
     $152 = ($151|0)==($149|0);
     if (!($152)) {
      $scevgep$i$i$i = ((($151)) + -8|0);
      $153 = $scevgep$i$i$i;
      $154 = $149;
      $155 = (($153) - ($154))|0;
      $156 = $155 >>> 3;
      $157 = $156 ^ -1;
      $scevgep5$i$i$i = (($151) + ($157<<3)|0);
      HEAP32[$26>>2] = $scevgep5$i$i$i;
     }
     __ZdlPv($149);
     ___resumeException($$3|0);
     // unreachable;
    }
   }
  } while(0);
  $141 = ($140|0)==(0|0);
  if (!($141)) {
   $143 = ($142|0)==($140|0);
   if (!($143)) {
    $scevgep$i$i$i47 = ((($142)) + -8|0);
    $144 = $scevgep$i$i$i47;
    $145 = $140;
    $146 = (($144) - ($145))|0;
    $147 = $146 >>> 3;
    $148 = $147 ^ -1;
    $scevgep5$i$i$i48 = (($142) + ($148<<3)|0);
    HEAP32[$26>>2] = $scevgep5$i$i$i48;
   }
   __ZdlPv($140);
  }
 }
 $158 = HEAP32[$8>>2]|0;
 $159 = ((($158)) + 8|0);
 $160 = HEAP32[$159>>2]|0;
 $161 = HEAP32[$160>>2]|0;
 $162 = ((($161)) + 20|0);
 $163 = HEAP32[$162>>2]|0;
 FUNCTION_TABLE_vi[$163 & 8191]($160);
 STACKTOP = sp;return;
}
function __ZTv0_n16_N7osgUtil19IntersectionVisitorD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __THREW__ = 0;
 invoke_vii(3312,($4|0),(47564|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if (!($6)) {
  $14 = ((($4)) + 160|0);
  __ZN3osg6ObjectD2Ev($14);
  return;
 }
 $7 = ___cxa_find_matching_catch_2()|0;
 $8 = tempRet0;
 $9 = ((($4)) + 160|0);
 __THREW__ = 0;
 invoke_vi(388,($9|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if ($11) {
  $12 = ___cxa_find_matching_catch_3(0|0)|0;
  $13 = tempRet0;
  ___clang_call_terminate($12);
  // unreachable;
 } else {
  ___resumeException($7|0);
  // unreachable;
 }
}
function __ZTv0_n16_N7osgUtil19IntersectionVisitorD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$i$index2Z2D = 0, $eh$lpad$body$i$indexZ2D = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __THREW__ = 0;
 invoke_vii(3312,($4|0),(47564|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $10 = ___cxa_find_matching_catch_2()|0;
  $11 = tempRet0;
  $12 = ((($4)) + 160|0);
  __THREW__ = 0;
  invoke_vi(388,($12|0));
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if ($14) {
   $15 = ___cxa_find_matching_catch_3(0|0)|0;
   $16 = tempRet0;
   ___clang_call_terminate($15);
   // unreachable;
  } else {
   $eh$lpad$body$i$index2Z2D = $11;$eh$lpad$body$i$indexZ2D = $10;
   __ZdlPv($4);
   ___resumeException($eh$lpad$body$i$indexZ2D|0);
   // unreachable;
  }
 }
 $7 = ((($4)) + 160|0);
 __THREW__ = 0;
 invoke_vi(388,($7|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if (!($9)) {
  __ZdlPv($4);
  return;
 }
 $17 = ___cxa_find_matching_catch_2()|0;
 $18 = tempRet0;
 $eh$lpad$body$i$index2Z2D = $18;$eh$lpad$body$i$indexZ2D = $17;
 __ZdlPv($4);
 ___resumeException($eh$lpad$body$i$indexZ2D|0);
 // unreachable;
}
function __ZTv0_n32_NK7osgUtil19IntersectionVisitor11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (116801|0);
}
function __ZTv0_n36_NK7osgUtil19IntersectionVisitor9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (110564|0);
}
function __ZNSt3__26vectorINS_4pairIffEENS_9allocatorIS2_EEEC2ERKS5_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i = 0, $scevgep5$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = 0;
 $2 = ((($0)) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = ((($0)) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$1>>2]|0;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 3;
 $9 = ($8|0)==(0);
 if ($9) {
  return;
 }
 $10 = ($8>>>0)>(536870911);
 if ($10) {
  __THREW__ = 0;
  invoke_vi(3307,($0|0));
  $11 = __THREW__; __THREW__ = 0;
 } else {
  __THREW__ = 0;
  $12 = (invoke_ii(3276,($7|0))|0);
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if (!($14)) {
   HEAP32[$2>>2] = $12;
   HEAP32[$0>>2] = $12;
   $15 = (($12) + ($8<<3)|0);
   $16 = ((($0)) + 8|0);
   HEAP32[$16>>2] = $15;
   $17 = HEAP32[$1>>2]|0;
   $18 = HEAP32[$4>>2]|0;
   $19 = $17;
   $20 = (($18) - ($19))|0;
   $21 = ($20|0)>(0);
   if (!($21)) {
    return;
   }
   $22 = $20 >>> 3;
   _memcpy(($12|0),($17|0),($20|0))|0;
   $23 = (($12) + ($22<<3)|0);
   HEAP32[$2>>2] = $23;
   return;
  }
 }
 $24 = ___cxa_find_matching_catch_2()|0;
 $25 = tempRet0;
 $26 = HEAP32[$0>>2]|0;
 $27 = ($26|0)==(0|0);
 if ($27) {
  ___resumeException($24|0);
  // unreachable;
 }
 $28 = HEAP32[$2>>2]|0;
 $29 = ($28|0)==($26|0);
 if (!($29)) {
  $scevgep$i$i$i = ((($28)) + -8|0);
  $30 = $scevgep$i$i$i;
  $31 = $26;
  $32 = (($30) - ($31))|0;
  $33 = $32 >>> 3;
  $34 = $33 ^ -1;
  $scevgep5$i$i$i = (($28) + ($34<<3)|0);
  HEAP32[$2>>2] = $scevgep5$i$i$i;
 }
 __ZdlPv($26);
 ___resumeException($24|0);
 // unreachable;
}
function __ZNSt3__2plIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_12basic_stringIT_T0_T1_EERKS9_SB_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 ;HEAP32[$0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;
 $3 = ((($1)) + 11|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)<(0);
 $6 = ((($1)) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $4&255;
 $9 = $5 ? $7 : $8;
 $10 = ((($2)) + 11|0);
 $11 = HEAP8[$10>>0]|0;
 $12 = ($11<<24>>24)<(0);
 $13 = ((($2)) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $11&255;
 $16 = $12 ? $14 : $15;
 $17 = HEAP32[$1>>2]|0;
 $18 = $5 ? $17 : $1;
 $19 = (($16) + ($9))|0;
 $20 = ($19>>>0)>(4294967279);
 do {
  if ($20) {
   __THREW__ = 0;
   invoke_vi(3367,($0|0));
   $21 = __THREW__; __THREW__ = 0;
  } else {
   $22 = ($19>>>0)<(11);
   if ($22) {
    $23 = $9&255;
    $24 = ((($0)) + 11|0);
    HEAP8[$24>>0] = $23;
    $$0$i = $0;
   } else {
    $25 = (($19) + 16)|0;
    $26 = $25 & -16;
    __THREW__ = 0;
    $27 = (invoke_ii(3276,($26|0))|0);
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if ($29) {
     break;
    }
    HEAP32[$0>>2] = $27;
    $30 = $26 | -2147483648;
    $31 = ((($0)) + 8|0);
    HEAP32[$31>>2] = $30;
    $32 = ((($0)) + 4|0);
    HEAP32[$32>>2] = $9;
    $$0$i = $27;
   }
   $33 = ($9|0)==(0);
   if (!($33)) {
    _memcpy(($$0$i|0),($18|0),($9|0))|0;
   }
   $34 = (($$0$i) + ($9)|0);
   HEAP8[$34>>0] = 0;
   $35 = HEAP32[$2>>2]|0;
   $36 = $12 ? $35 : $2;
   __THREW__ = 0;
   (invoke_iiii(3544,($0|0),($36|0),($16|0))|0);
   $37 = __THREW__; __THREW__ = 0;
   $38 = $37&1;
   if (!($38)) {
    return;
   }
  }
 } while(0);
 $39 = ___cxa_find_matching_catch_2()|0;
 $40 = tempRet0;
 $41 = ((($0)) + 11|0);
 $42 = HEAP8[$41>>0]|0;
 $43 = ($42<<24>>24)<(0);
 if (!($43)) {
  ___resumeException($39|0);
  // unreachable;
 }
 $44 = HEAP32[$0>>2]|0;
 __ZdlPv($44);
 ___resumeException($39|0);
 // unreachable;
}
function __ZN7osgUtil19IntersectionVisitor16pushWindowMatrixEPN3osg8ViewportE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$1516 = 0, $$1519 = 0, $$1715 = 0, $$1718 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0.0, $15 = 0, $16 = 0, $17 = 0.0, $18 = 0, $19 = 0, $2 = 0, $20 = 0.0, $21 = 0, $22 = 0, $23 = 0.0, $24 = 0;
 var $25 = 0, $26 = 0.0, $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0, $32 = 0.0, $33 = 0, $34 = 0, $35 = 0.0, $36 = 0, $37 = 0, $38 = 0.0, $39 = 0, $4 = 0, $40 = 0, $41 = 0.0, $42 = 0;
 var $43 = 0, $44 = 0.0, $45 = 0, $46 = 0, $47 = 0.0, $48 = 0, $49 = 0, $5 = 0, $50 = 0.0, $51 = 0, $52 = 0, $53 = 0.0, $54 = 0, $55 = 0, $56 = 0.0, $57 = 0, $58 = 0, $59 = 0.0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(128|0);
 $2 = sp;
 $3 = ((($0)) + 76|0);
 $4 = (__Znwj(160)|0);
 __THREW__ = 0;
 invoke_vii(3301,($2|0),($1|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 do {
  if ($6) {
   $79 = ___cxa_find_matching_catch_2()|0;
   $80 = tempRet0;
   $$1519 = $80;$$1718 = $79;
  } else {
   __THREW__ = 0;
   invoke_vii(3435,($4|0),0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $9 = ___cxa_find_matching_catch_2()|0;
    $10 = tempRet0;
    $$1519 = $10;$$1718 = $9;
    break;
   }
   $11 = ((($4)) + 12|0);
   ;HEAP32[$11>>2]=0|0;HEAP32[$11+4>>2]=0|0;HEAP32[$11+8>>2]=0|0;
   $12 = ((($4)) + 24|0);
   HEAP32[$12>>2] = 2;
   $13 = ((($4)) + 28|0);
   HEAP32[$13>>2] = 0;
   $14 = +HEAPF64[$2>>3];
   $15 = ((($4)) + 32|0);
   HEAPF64[$15>>3] = $14;
   $16 = ((($2)) + 8|0);
   $17 = +HEAPF64[$16>>3];
   $18 = ((($4)) + 40|0);
   HEAPF64[$18>>3] = $17;
   $19 = ((($2)) + 16|0);
   $20 = +HEAPF64[$19>>3];
   $21 = ((($4)) + 48|0);
   HEAPF64[$21>>3] = $20;
   $22 = ((($2)) + 24|0);
   $23 = +HEAPF64[$22>>3];
   $24 = ((($4)) + 56|0);
   HEAPF64[$24>>3] = $23;
   $25 = ((($2)) + 32|0);
   $26 = +HEAPF64[$25>>3];
   $27 = ((($4)) + 64|0);
   HEAPF64[$27>>3] = $26;
   $28 = ((($2)) + 40|0);
   $29 = +HEAPF64[$28>>3];
   $30 = ((($4)) + 72|0);
   HEAPF64[$30>>3] = $29;
   $31 = ((($2)) + 48|0);
   $32 = +HEAPF64[$31>>3];
   $33 = ((($4)) + 80|0);
   HEAPF64[$33>>3] = $32;
   $34 = ((($2)) + 56|0);
   $35 = +HEAPF64[$34>>3];
   $36 = ((($4)) + 88|0);
   HEAPF64[$36>>3] = $35;
   $37 = ((($2)) + 64|0);
   $38 = +HEAPF64[$37>>3];
   $39 = ((($4)) + 96|0);
   HEAPF64[$39>>3] = $38;
   $40 = ((($2)) + 72|0);
   $41 = +HEAPF64[$40>>3];
   $42 = ((($4)) + 104|0);
   HEAPF64[$42>>3] = $41;
   $43 = ((($2)) + 80|0);
   $44 = +HEAPF64[$43>>3];
   $45 = ((($4)) + 112|0);
   HEAPF64[$45>>3] = $44;
   $46 = ((($2)) + 88|0);
   $47 = +HEAPF64[$46>>3];
   $48 = ((($4)) + 120|0);
   HEAPF64[$48>>3] = $47;
   $49 = ((($2)) + 96|0);
   $50 = +HEAPF64[$49>>3];
   $51 = ((($4)) + 128|0);
   HEAPF64[$51>>3] = $50;
   $52 = ((($2)) + 104|0);
   $53 = +HEAPF64[$52>>3];
   $54 = ((($4)) + 136|0);
   HEAPF64[$54>>3] = $53;
   $55 = ((($2)) + 112|0);
   $56 = +HEAPF64[$55>>3];
   $57 = ((($4)) + 144|0);
   HEAPF64[$57>>3] = $56;
   $58 = ((($2)) + 120|0);
   $59 = +HEAPF64[$58>>3];
   $60 = ((($4)) + 152|0);
   HEAPF64[$60>>3] = $59;
   HEAP32[$4>>2] = (47588);
   $61 = ((($4)) + 8|0);
   $62 = HEAP32[$61>>2]|0;HEAP32[$61>>2] = (($62+1)|0);
   __THREW__ = 0;
   $63 = (invoke_ii(3276,12)|0);
   $64 = __THREW__; __THREW__ = 0;
   $65 = $64&1;
   if ($65) {
    $81 = ___cxa_find_matching_catch_2()|0;
    $82 = tempRet0;
    $83 = HEAP32[$61>>2]|0;HEAP32[$61>>2] = (($83-1)|0);
    $84 = ($83|0)==(1);
    if ($84) {
     __THREW__ = 0;
     invoke_viii(3262,($4|0),1,1);
     $85 = __THREW__; __THREW__ = 0;
     $86 = $85&1;
     if ($86) {
      $89 = ___cxa_find_matching_catch_3(0|0)|0;
      $90 = tempRet0;
      ___clang_call_terminate($89);
      // unreachable;
     }
    }
    $$1516 = $82;$$1715 = $81;
    ___resumeException($$1715|0);
    // unreachable;
   }
   $66 = ((($63)) + 8|0);
   HEAP32[$66>>2] = $4;
   $67 = HEAP32[$61>>2]|0;HEAP32[$61>>2] = (($67+1)|0);
   $68 = ((($63)) + 4|0);
   HEAP32[$68>>2] = $3;
   $69 = HEAP32[$3>>2]|0;
   HEAP32[$63>>2] = $69;
   $70 = ((($69)) + 4|0);
   HEAP32[$70>>2] = $63;
   HEAP32[$3>>2] = $63;
   $71 = ((($0)) + 84|0);
   $72 = HEAP32[$71>>2]|0;
   $73 = (($72) + 1)|0;
   HEAP32[$71>>2] = $73;
   $74 = HEAP32[$61>>2]|0;HEAP32[$61>>2] = (($74-1)|0);
   $75 = ($74|0)==(1);
   if (!($75)) {
    $78 = ((($0)) + 144|0);
    HEAP8[$78>>0] = 1;
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   invoke_viii(3262,($4|0),1,1);
   $76 = __THREW__; __THREW__ = 0;
   $77 = $76&1;
   if (!($77)) {
    $78 = ((($0)) + 144|0);
    HEAP8[$78>>0] = 1;
    STACKTOP = sp;return;
   }
   $87 = ___cxa_find_matching_catch_2()|0;
   $88 = tempRet0;
   $$1516 = $88;$$1715 = $87;
   ___resumeException($$1715|0);
   // unreachable;
  }
 } while(0);
 __ZdlPv($4);
 $$1516 = $$1519;$$1715 = $$1718;
 ___resumeException($$1715|0);
 // unreachable;
}
function __ZN7osgUtil19IntersectionVisitor20pushProjectionMatrixEPN3osg10RefMatrixdE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 88|0);
 $3 = ($1|0)==(0|0);
 if (!($3)) {
  $4 = ((($1)) + 8|0);
  $5 = HEAP32[$4>>2]|0;HEAP32[$4>>2] = (($5+1)|0);
 }
 __THREW__ = 0;
 $6 = (invoke_ii(3276,12)|0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $22 = ___cxa_find_matching_catch_2()|0;
  $23 = tempRet0;
  if ($3) {
   ___resumeException($22|0);
   // unreachable;
  }
  $24 = ((($1)) + 8|0);
  $25 = HEAP32[$24>>2]|0;HEAP32[$24>>2] = (($25-1)|0);
  $26 = ($25|0)==(1);
  if (!($26)) {
   ___resumeException($22|0);
   // unreachable;
  }
  __THREW__ = 0;
  invoke_viii(3262,($1|0),1,1);
  $27 = __THREW__; __THREW__ = 0;
  $28 = $27&1;
  if ($28) {
   $29 = ___cxa_find_matching_catch_3(0|0)|0;
   $30 = tempRet0;
   ___clang_call_terminate($29);
   // unreachable;
  } else {
   ___resumeException($22|0);
   // unreachable;
  }
 }
 $9 = ((($6)) + 8|0);
 HEAP32[$9>>2] = $1;
 if (!($3)) {
  $10 = ((($1)) + 8|0);
  $11 = HEAP32[$10>>2]|0;HEAP32[$10>>2] = (($11+1)|0);
 }
 $12 = ((($6)) + 4|0);
 HEAP32[$12>>2] = $2;
 $13 = HEAP32[$2>>2]|0;
 HEAP32[$6>>2] = $13;
 $14 = ((($13)) + 4|0);
 HEAP32[$14>>2] = $6;
 HEAP32[$2>>2] = $6;
 $15 = ((($0)) + 96|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + 1)|0;
 HEAP32[$15>>2] = $17;
 if ($3) {
  $21 = ((($0)) + 144|0);
  HEAP8[$21>>0] = 1;
  return;
 }
 $18 = ((($1)) + 8|0);
 $19 = HEAP32[$18>>2]|0;HEAP32[$18>>2] = (($19-1)|0);
 $20 = ($19|0)==(1);
 if (!($20)) {
  $21 = ((($0)) + 144|0);
  HEAP8[$21>>0] = 1;
  return;
 }
 __ZNK3osg10Referenced24signalObserversAndDeleteEbb($1,1,1);
 $21 = ((($0)) + 144|0);
 HEAP8[$21>>0] = 1;
 return;
}
function __ZN7osgUtil19IntersectionVisitor14pushViewMatrixEPN3osg10RefMatrixdE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 100|0);
 $3 = ($1|0)==(0|0);
 if (!($3)) {
  $4 = ((($1)) + 8|0);
  $5 = HEAP32[$4>>2]|0;HEAP32[$4>>2] = (($5+1)|0);
 }
 __THREW__ = 0;
 $6 = (invoke_ii(3276,12)|0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $22 = ___cxa_find_matching_catch_2()|0;
  $23 = tempRet0;
  if ($3) {
   ___resumeException($22|0);
   // unreachable;
  }
  $24 = ((($1)) + 8|0);
  $25 = HEAP32[$24>>2]|0;HEAP32[$24>>2] = (($25-1)|0);
  $26 = ($25|0)==(1);
  if (!($26)) {
   ___resumeException($22|0);
   // unreachable;
  }
  __THREW__ = 0;
  invoke_viii(3262,($1|0),1,1);
  $27 = __THREW__; __THREW__ = 0;
  $28 = $27&1;
  if ($28) {
   $29 = ___cxa_find_matching_catch_3(0|0)|0;
   $30 = tempRet0;
   ___clang_call_terminate($29);
   // unreachable;
  } else {
   ___resumeException($22|0);
   // unreachable;
  }
 }
 $9 = ((($6)) + 8|0);
 HEAP32[$9>>2] = $1;
 if (!($3)) {
  $10 = ((($1)) + 8|0);
  $11 = HEAP32[$10>>2]|0;HEAP32[$10>>2] = (($11+1)|0);
 }
 $12 = ((($6)) + 4|0);
 HEAP32[$12>>2] = $2;
 $13 = HEAP32[$2>>2]|0;
 HEAP32[$6>>2] = $13;
 $14 = ((($13)) + 4|0);
 HEAP32[$14>>2] = $6;
 HEAP32[$2>>2] = $6;
 $15 = ((($0)) + 108|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + 1)|0;
 HEAP32[$15>>2] = $17;
 if ($3) {
  $21 = ((($0)) + 144|0);
  HEAP8[$21>>0] = 1;
  return;
 }
 $18 = ((($1)) + 8|0);
 $19 = HEAP32[$18>>2]|0;HEAP32[$18>>2] = (($19-1)|0);
 $20 = ($19|0)==(1);
 if (!($20)) {
  $21 = ((($0)) + 144|0);
  HEAP8[$21>>0] = 1;
  return;
 }
 __ZNK3osg10Referenced24signalObserversAndDeleteEbb($1,1,1);
 $21 = ((($0)) + 144|0);
 HEAP8[$21>>0] = 1;
 return;
}
function __ZN7osgUtil19IntersectionVisitor15pushModelMatrixEPN3osg10RefMatrixdE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 112|0);
 $3 = ($1|0)==(0|0);
 if (!($3)) {
  $4 = ((($1)) + 8|0);
  $5 = HEAP32[$4>>2]|0;HEAP32[$4>>2] = (($5+1)|0);
 }
 __THREW__ = 0;
 $6 = (invoke_ii(3276,12)|0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $22 = ___cxa_find_matching_catch_2()|0;
  $23 = tempRet0;
  if ($3) {
   ___resumeException($22|0);
   // unreachable;
  }
  $24 = ((($1)) + 8|0);
  $25 = HEAP32[$24>>2]|0;HEAP32[$24>>2] = (($25-1)|0);
  $26 = ($25|0)==(1);
  if (!($26)) {
   ___resumeException($22|0);
   // unreachable;
  }
  __THREW__ = 0;
  invoke_viii(3262,($1|0),1,1);
  $27 = __THREW__; __THREW__ = 0;
  $28 = $27&1;
  if ($28) {
   $29 = ___cxa_find_matching_catch_3(0|0)|0;
   $30 = tempRet0;
   ___clang_call_terminate($29);
   // unreachable;
  } else {
   ___resumeException($22|0);
   // unreachable;
  }
 }
 $9 = ((($6)) + 8|0);
 HEAP32[$9>>2] = $1;
 if (!($3)) {
  $10 = ((($1)) + 8|0);
  $11 = HEAP32[$10>>2]|0;HEAP32[$10>>2] = (($11+1)|0);
 }
 $12 = ((($6)) + 4|0);
 HEAP32[$12>>2] = $2;
 $13 = HEAP32[$2>>2]|0;
 HEAP32[$6>>2] = $13;
 $14 = ((($13)) + 4|0);
 HEAP32[$14>>2] = $6;
 HEAP32[$2>>2] = $6;
 $15 = ((($0)) + 120|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + 1)|0;
 HEAP32[$15>>2] = $17;
 if ($3) {
  $21 = ((($0)) + 144|0);
  HEAP8[$21>>0] = 1;
  return;
 }
 $18 = ((($1)) + 8|0);
 $19 = HEAP32[$18>>2]|0;HEAP32[$18>>2] = (($19-1)|0);
 $20 = ($19|0)==(1);
 if (!($20)) {
  $21 = ((($0)) + 144|0);
  HEAP8[$21>>0] = 1;
  return;
 }
 __ZNK3osg10Referenced24signalObserversAndDeleteEbb($1,1,1);
 $21 = ((($0)) + 144|0);
 HEAP8[$21>>0] = 1;
 return;
}
function __ZN3osg10RefMatrixdD2Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg6ObjectD2Ev($0);
 return;
}
function __ZN3osg10RefMatrixdD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(388,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK3osg10RefMatrixd9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(160)|0);
 __THREW__ = 0;
 invoke_vii(3435,($1|0),0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $16 = ___cxa_find_matching_catch_2()|0;
  $17 = tempRet0;
  $eh$lpad$body$index2Z2D = $17;$eh$lpad$body$indexZ2D = $16;
  __ZdlPv($1);
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 HEAP32[$1>>2] = (63412);
 $4 = ((($1)) + 12|0);
 ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;
 $5 = ((($1)) + 24|0);
 HEAP32[$5>>2] = 2;
 $6 = ((($1)) + 28|0);
 HEAP32[$6>>2] = 0;
 $7 = ((($1)) + 32|0);
 __THREW__ = 0;
 invoke_vi(3299,($7|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if (!($9)) {
  HEAP32[$1>>2] = (47588);
  return ($1|0);
 }
 $10 = ___cxa_find_matching_catch_2()|0;
 $11 = tempRet0;
 __THREW__ = 0;
 invoke_vi(388,($1|0));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $14 = ___cxa_find_matching_catch_3(0|0)|0;
  $15 = tempRet0;
  ___clang_call_terminate($14);
  // unreachable;
 } else {
  $eh$lpad$body$index2Z2D = $11;$eh$lpad$body$indexZ2D = $10;
  __ZdlPv($1);
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 return (0)|0;
}
function __ZNK3osg10RefMatrixd5cloneERKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0.0, $12 = 0, $13 = 0, $14 = 0.0, $15 = 0, $16 = 0, $17 = 0.0, $18 = 0, $19 = 0, $2 = 0, $20 = 0.0, $21 = 0, $22 = 0, $23 = 0.0, $24 = 0, $25 = 0, $26 = 0.0, $27 = 0, $28 = 0;
 var $29 = 0.0, $3 = 0, $30 = 0, $31 = 0, $32 = 0.0, $33 = 0, $34 = 0, $35 = 0.0, $36 = 0, $37 = 0, $38 = 0.0, $39 = 0, $4 = 0, $40 = 0, $41 = 0.0, $42 = 0, $43 = 0, $44 = 0.0, $45 = 0, $46 = 0;
 var $47 = 0.0, $48 = 0, $49 = 0, $5 = 0, $50 = 0.0, $51 = 0, $52 = 0, $53 = 0.0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0.0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = (__Znwj(160)|0);
 HEAP32[$2>>2] = (58136);
 $4 = ((($2)) + 4|0);
 HEAP32[$4>>2] = 0;
 __THREW__ = 0;
 invoke_viii(3468,($3|0),($0|0),($2|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $55 = ___cxa_find_matching_catch_2()|0;
  $56 = tempRet0;
  __ZdlPv($3);
  ___resumeException($55|0);
  // unreachable;
 } else {
  $7 = ((($0)) + 32|0);
  $8 = +HEAPF64[$7>>3];
  $9 = ((($3)) + 32|0);
  HEAPF64[$9>>3] = $8;
  $10 = ((($0)) + 40|0);
  $11 = +HEAPF64[$10>>3];
  $12 = ((($3)) + 40|0);
  HEAPF64[$12>>3] = $11;
  $13 = ((($0)) + 48|0);
  $14 = +HEAPF64[$13>>3];
  $15 = ((($3)) + 48|0);
  HEAPF64[$15>>3] = $14;
  $16 = ((($0)) + 56|0);
  $17 = +HEAPF64[$16>>3];
  $18 = ((($3)) + 56|0);
  HEAPF64[$18>>3] = $17;
  $19 = ((($0)) + 64|0);
  $20 = +HEAPF64[$19>>3];
  $21 = ((($3)) + 64|0);
  HEAPF64[$21>>3] = $20;
  $22 = ((($0)) + 72|0);
  $23 = +HEAPF64[$22>>3];
  $24 = ((($3)) + 72|0);
  HEAPF64[$24>>3] = $23;
  $25 = ((($0)) + 80|0);
  $26 = +HEAPF64[$25>>3];
  $27 = ((($3)) + 80|0);
  HEAPF64[$27>>3] = $26;
  $28 = ((($0)) + 88|0);
  $29 = +HEAPF64[$28>>3];
  $30 = ((($3)) + 88|0);
  HEAPF64[$30>>3] = $29;
  $31 = ((($0)) + 96|0);
  $32 = +HEAPF64[$31>>3];
  $33 = ((($3)) + 96|0);
  HEAPF64[$33>>3] = $32;
  $34 = ((($0)) + 104|0);
  $35 = +HEAPF64[$34>>3];
  $36 = ((($3)) + 104|0);
  HEAPF64[$36>>3] = $35;
  $37 = ((($0)) + 112|0);
  $38 = +HEAPF64[$37>>3];
  $39 = ((($3)) + 112|0);
  HEAPF64[$39>>3] = $38;
  $40 = ((($0)) + 120|0);
  $41 = +HEAPF64[$40>>3];
  $42 = ((($3)) + 120|0);
  HEAPF64[$42>>3] = $41;
  $43 = ((($0)) + 128|0);
  $44 = +HEAPF64[$43>>3];
  $45 = ((($3)) + 128|0);
  HEAPF64[$45>>3] = $44;
  $46 = ((($0)) + 136|0);
  $47 = +HEAPF64[$46>>3];
  $48 = ((($3)) + 136|0);
  HEAPF64[$48>>3] = $47;
  $49 = ((($0)) + 144|0);
  $50 = +HEAPF64[$49>>3];
  $51 = ((($3)) + 144|0);
  HEAPF64[$51>>3] = $50;
  $52 = ((($0)) + 152|0);
  $53 = +HEAPF64[$52>>3];
  $54 = ((($3)) + 152|0);
  HEAPF64[$54>>3] = $53;
  HEAP32[$3>>2] = (47588);
  STACKTOP = sp;return ($3|0);
 }
 return (0)|0;
}
function __ZNK3osg10RefMatrixd12isSameKindAsEPKNS_6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,20312,0)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK3osg10RefMatrixd11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175113|0);
}
function __ZNK3osg10RefMatrixd9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (110584|0);
}
function __ZN7osgUtil19IntersectionVisitor14setIntersectorEPNS_11IntersectorE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$023$i$i = 0, $$05 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = ((($1)) + 8|0);
  $4 = HEAP32[$3>>2]|0;HEAP32[$3>>2] = (($4+1)|0);
 }
 $5 = ((($0)) + 56|0);
 $6 = ((($0)) + 64|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0);
 L4: do {
  if (!($8)) {
   $9 = ((($0)) + 60|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = HEAP32[$5>>2]|0;
   $12 = ((($11)) + 4|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = HEAP32[$10>>2]|0;
   $15 = ((($14)) + 4|0);
   HEAP32[$15>>2] = $13;
   $16 = HEAP32[$12>>2]|0;
   HEAP32[$16>>2] = $14;
   HEAP32[$6>>2] = 0;
   $17 = ($10|0)==($5|0);
   if (!($17)) {
    $$023$i$i = $10;
    while(1) {
     $18 = ((($$023$i$i)) + 4|0);
     $19 = HEAP32[$18>>2]|0;
     $20 = ((($$023$i$i)) + 8|0);
     $21 = HEAP32[$20>>2]|0;
     $22 = ($21|0)==(0|0);
     if (!($22)) {
      $23 = ((($21)) + 8|0);
      $24 = HEAP32[$23>>2]|0;HEAP32[$23>>2] = (($24-1)|0);
      $25 = ($24|0)==(1);
      if ($25) {
       __THREW__ = 0;
       invoke_viii(3262,($21|0),1,1);
       $26 = __THREW__; __THREW__ = 0;
       $27 = $26&1;
       if ($27) {
        break;
       }
      }
     }
     __ZdlPv($$023$i$i);
     $28 = ($19|0)==($5|0);
     if ($28) {
      break L4;
     } else {
      $$023$i$i = $19;
     }
    }
    $29 = ___cxa_find_matching_catch_2()|0;
    $30 = tempRet0;
    ___cxa_call_unexpected(($29|0));
    // unreachable;
   }
  }
 } while(0);
 if ($2) {
  return;
 }
 $31 = ((($1)) + 8|0);
 $32 = HEAP32[$31>>2]|0;HEAP32[$31>>2] = (($32+1)|0);
 __THREW__ = 0;
 $33 = (invoke_ii(3276,12)|0);
 $34 = __THREW__; __THREW__ = 0;
 $35 = $34&1;
 do {
  if ($35) {
   $49 = ___cxa_find_matching_catch_2()|0;
   $50 = tempRet0;
   $51 = HEAP32[$31>>2]|0;HEAP32[$31>>2] = (($51-1)|0);
   $52 = ($51|0)==(1);
   if ($52) {
    __THREW__ = 0;
    invoke_viii(3262,($1|0),1,1);
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if ($54) {
     $61 = ___cxa_find_matching_catch_3(0|0)|0;
     $62 = tempRet0;
     ___clang_call_terminate($61);
     // unreachable;
    } else {
     $$0 = $50;$$05 = $49;
    }
   } else {
    $$0 = $50;$$05 = $49;
   }
  } else {
   $36 = ((($33)) + 8|0);
   HEAP32[$36>>2] = $1;
   $37 = HEAP32[$31>>2]|0;HEAP32[$31>>2] = (($37+1)|0);
   $38 = ((($33)) + 4|0);
   HEAP32[$38>>2] = $5;
   $39 = HEAP32[$5>>2]|0;
   HEAP32[$33>>2] = $39;
   $40 = ((($39)) + 4|0);
   HEAP32[$40>>2] = $33;
   HEAP32[$5>>2] = $33;
   $41 = HEAP32[$6>>2]|0;
   $42 = (($41) + 1)|0;
   HEAP32[$6>>2] = $42;
   $43 = HEAP32[$31>>2]|0;HEAP32[$31>>2] = (($43-1)|0);
   $44 = ($43|0)==(1);
   if ($44) {
    __THREW__ = 0;
    invoke_viii(3262,($1|0),1,1);
    $45 = __THREW__; __THREW__ = 0;
    $46 = $45&1;
    if ($46) {
     $47 = ___cxa_find_matching_catch_2()|0;
     $48 = tempRet0;
     $$0 = $48;$$05 = $47;
     break;
    }
   }
   $59 = HEAP32[$31>>2]|0;HEAP32[$31>>2] = (($59-1)|0);
   $60 = ($59|0)==(1);
   if (!($60)) {
    return;
   }
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($1,1,1);
   return;
  }
 } while(0);
 $55 = HEAP32[$31>>2]|0;HEAP32[$31>>2] = (($55-1)|0);
 $56 = ($55|0)==(1);
 if (!($56)) {
  ___resumeException($$05|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(3262,($1|0),1,1);
 $57 = __THREW__; __THREW__ = 0;
 $58 = $57&1;
 if ($58) {
  $61 = ___cxa_find_matching_catch_3(0|0)|0;
  $62 = tempRet0;
  ___clang_call_terminate($61);
  // unreachable;
 } else {
  ___resumeException($$05|0);
  // unreachable;
 }
}
function __ZN7osgUtil19IntersectionVisitorC1EPNS_11IntersectorEPNS0_12ReadCallbackE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$023$i$i = 0, $$023$i$i17 = 0, $$023$i$i19 = 0, $$023$i$i22 = 0, $$023$i$i25 = 0, $$6 = 0, $$616 = 0, $$sink = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0;
 var $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0;
 var $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0.0, $42 = 0.0, $43 = 0, $44 = 0.0;
 var $45 = 0.0, $46 = 0, $47 = 0.0, $48 = 0.0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 160|0);
 __ZN3osg10ReferencedC2Ev($3);
 HEAP32[$3>>2] = (63412);
 $4 = ((($0)) + 172|0);
 ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;
 $5 = ((($0)) + 184|0);
 HEAP32[$5>>2] = 2;
 $6 = ((($0)) + 188|0);
 HEAP32[$6>>2] = 0;
 __THREW__ = 0;
 invoke_viiii(3522,($0|0),((47568)|0),5,3);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $36 = ___cxa_find_matching_catch_2()|0;
  $37 = tempRet0;
  $$6 = $36;$$616 = $37;
 } else {
  HEAP32[$0>>2] = (47080);
  HEAP32[$3>>2] = (47424);
  $9 = ((($0)) + 56|0);
  HEAP32[$9>>2] = $9;
  $10 = ((($0)) + 60|0);
  HEAP32[$10>>2] = $9;
  $11 = ((($0)) + 64|0);
  HEAP32[$11>>2] = 0;
  $12 = ((($0)) + 72|0);
  HEAP32[$12>>2] = 0;
  $13 = ((($0)) + 76|0);
  HEAP32[$13>>2] = $13;
  $14 = ((($0)) + 80|0);
  HEAP32[$14>>2] = $13;
  $15 = ((($0)) + 84|0);
  HEAP32[$15>>2] = 0;
  $16 = ((($0)) + 88|0);
  HEAP32[$16>>2] = $16;
  $17 = ((($0)) + 92|0);
  HEAP32[$17>>2] = $16;
  $18 = ((($0)) + 96|0);
  HEAP32[$18>>2] = 0;
  $19 = ((($0)) + 100|0);
  HEAP32[$19>>2] = $19;
  $20 = ((($0)) + 104|0);
  HEAP32[$20>>2] = $19;
  $21 = ((($0)) + 108|0);
  HEAP32[$21>>2] = 0;
  $22 = ((($0)) + 112|0);
  HEAP32[$22>>2] = $22;
  $23 = ((($0)) + 116|0);
  HEAP32[$23>>2] = $22;
  $24 = ((($0)) + 120|0);
  $25 = ((($0)) + 124|0);
  $26 = ((($0)) + 128|0);
  $27 = ((($0)) + 132|0);
  $28 = ((($0)) + 148|0);
  HEAPF32[$28>>2] = 0.0;
  $29 = ((($0)) + 152|0);
  HEAPF32[$29>>2] = 0.0;
  $30 = ((($0)) + 156|0);
  HEAPF32[$30>>2] = 0.0;
  $31 = ((($0)) + 68|0);
  ;HEAP32[$24>>2]=0|0;HEAP32[$24+4>>2]=0|0;HEAP32[$24+8>>2]=0|0;HEAP32[$24+12>>2]=0|0;
  HEAP8[$31>>0] = 1;
  $32 = ((($0)) + 69|0);
  HEAP8[$32>>0] = 0;
  $33 = ((($0)) + 140|0);
  HEAP32[$33>>2] = 0;
  $34 = ((($0)) + 144|0);
  HEAP8[$34>>0] = 1;
  $35 = ($1|0)==(0|0);
  if ($35) {
   label = 6;
  } else {
   $38 = (___dynamic_cast($1,19784,20960,0)|0);
   $39 = ($38|0)==(0|0);
   if ($39) {
    label = 6;
   } else {
    $40 = ((($38)) + 32|0);
    $41 = +HEAPF64[$40>>3];
    $42 = $41;
    $43 = ((($38)) + 40|0);
    $44 = +HEAPF64[$43>>3];
    $45 = $44;
    $46 = ((($38)) + 48|0);
    $47 = +HEAPF64[$46>>3];
    $48 = $47;
    HEAPF32[$25>>2] = $42;
    HEAPF32[$26>>2] = $45;
    HEAPF32[$27>>2] = $48;
    HEAP8[$34>>0] = 1;
    $49 = ((($38)) + 12|0);
    $50 = HEAP32[$49>>2]|0;
    $$sink = $50;
   }
  }
  if ((label|0) == 6) {
   HEAPF32[$25>>2] = 0.0;
   HEAPF32[$26>>2] = 0.0;
   HEAPF32[$27>>2] = 0.0;
   HEAP8[$34>>0] = 1;
   $$sink = 2;
  }
  $51 = ((($0)) + 136|0);
  HEAP32[$51>>2] = $$sink;
  __THREW__ = 0;
  invoke_vii(3551,($0|0),($1|0));
  $52 = __THREW__; __THREW__ = 0;
  $53 = $52&1;
  if (!($53)) {
   $54 = HEAP32[$12>>2]|0;
   $55 = ($54|0)==($2|0);
   if ($55) {
    return;
   }
   HEAP32[$12>>2] = $2;
   $56 = ($2|0)==(0|0);
   if (!($56)) {
    $57 = ((($2)) + 8|0);
    $58 = HEAP32[$57>>2]|0;HEAP32[$57>>2] = (($58+1)|0);
   }
   $59 = ($54|0)==(0|0);
   if ($59) {
    return;
   }
   $60 = ((($54)) + 8|0);
   $61 = HEAP32[$60>>2]|0;HEAP32[$60>>2] = (($61-1)|0);
   $62 = ($61|0)==(1);
   if (!($62)) {
    return;
   }
   __THREW__ = 0;
   invoke_viii(3262,($54|0),1,1);
   $63 = __THREW__; __THREW__ = 0;
   $64 = $63&1;
   if (!($64)) {
    return;
   }
  }
  $65 = ___cxa_find_matching_catch_2()|0;
  $66 = tempRet0;
  $67 = HEAP32[$24>>2]|0;
  $68 = ($67|0)==(0);
  L26: do {
   if (!($68)) {
    $69 = HEAP32[$23>>2]|0;
    $70 = HEAP32[$22>>2]|0;
    $71 = ((($70)) + 4|0);
    $72 = HEAP32[$71>>2]|0;
    $73 = HEAP32[$69>>2]|0;
    $74 = ((($73)) + 4|0);
    HEAP32[$74>>2] = $72;
    $75 = HEAP32[$71>>2]|0;
    HEAP32[$75>>2] = $73;
    HEAP32[$24>>2] = 0;
    $76 = ($69|0)==($22|0);
    if (!($76)) {
     $$023$i$i25 = $69;
     while(1) {
      $77 = ((($$023$i$i25)) + 4|0);
      $78 = HEAP32[$77>>2]|0;
      $79 = ((($$023$i$i25)) + 8|0);
      $80 = HEAP32[$79>>2]|0;
      $81 = ($80|0)==(0|0);
      if (!($81)) {
       $82 = ((($80)) + 8|0);
       $83 = HEAP32[$82>>2]|0;HEAP32[$82>>2] = (($83-1)|0);
       $84 = ($83|0)==(1);
       if ($84) {
        __THREW__ = 0;
        invoke_viii(3262,($80|0),1,1);
        $85 = __THREW__; __THREW__ = 0;
        $86 = $85&1;
        if ($86) {
         break;
        }
       }
      }
      __ZdlPv($$023$i$i25);
      $87 = ($78|0)==($22|0);
      if ($87) {
       break L26;
      } else {
       $$023$i$i25 = $78;
      }
     }
     $88 = ___cxa_find_matching_catch_2()|0;
     $89 = tempRet0;
     ___cxa_call_unexpected(($88|0));
     // unreachable;
    }
   }
  } while(0);
  $90 = HEAP32[$21>>2]|0;
  $91 = ($90|0)==(0);
  L36: do {
   if (!($91)) {
    $92 = HEAP32[$20>>2]|0;
    $93 = HEAP32[$19>>2]|0;
    $94 = ((($93)) + 4|0);
    $95 = HEAP32[$94>>2]|0;
    $96 = HEAP32[$92>>2]|0;
    $97 = ((($96)) + 4|0);
    HEAP32[$97>>2] = $95;
    $98 = HEAP32[$94>>2]|0;
    HEAP32[$98>>2] = $96;
    HEAP32[$21>>2] = 0;
    $99 = ($92|0)==($19|0);
    if (!($99)) {
     $$023$i$i22 = $92;
     while(1) {
      $100 = ((($$023$i$i22)) + 4|0);
      $101 = HEAP32[$100>>2]|0;
      $102 = ((($$023$i$i22)) + 8|0);
      $103 = HEAP32[$102>>2]|0;
      $104 = ($103|0)==(0|0);
      if (!($104)) {
       $105 = ((($103)) + 8|0);
       $106 = HEAP32[$105>>2]|0;HEAP32[$105>>2] = (($106-1)|0);
       $107 = ($106|0)==(1);
       if ($107) {
        __THREW__ = 0;
        invoke_viii(3262,($103|0),1,1);
        $108 = __THREW__; __THREW__ = 0;
        $109 = $108&1;
        if ($109) {
         break;
        }
       }
      }
      __ZdlPv($$023$i$i22);
      $110 = ($101|0)==($19|0);
      if ($110) {
       break L36;
      } else {
       $$023$i$i22 = $101;
      }
     }
     $111 = ___cxa_find_matching_catch_2()|0;
     $112 = tempRet0;
     ___cxa_call_unexpected(($111|0));
     // unreachable;
    }
   }
  } while(0);
  $113 = HEAP32[$18>>2]|0;
  $114 = ($113|0)==(0);
  L46: do {
   if (!($114)) {
    $115 = HEAP32[$17>>2]|0;
    $116 = HEAP32[$16>>2]|0;
    $117 = ((($116)) + 4|0);
    $118 = HEAP32[$117>>2]|0;
    $119 = HEAP32[$115>>2]|0;
    $120 = ((($119)) + 4|0);
    HEAP32[$120>>2] = $118;
    $121 = HEAP32[$117>>2]|0;
    HEAP32[$121>>2] = $119;
    HEAP32[$18>>2] = 0;
    $122 = ($115|0)==($16|0);
    if (!($122)) {
     $$023$i$i19 = $115;
     while(1) {
      $123 = ((($$023$i$i19)) + 4|0);
      $124 = HEAP32[$123>>2]|0;
      $125 = ((($$023$i$i19)) + 8|0);
      $126 = HEAP32[$125>>2]|0;
      $127 = ($126|0)==(0|0);
      if (!($127)) {
       $128 = ((($126)) + 8|0);
       $129 = HEAP32[$128>>2]|0;HEAP32[$128>>2] = (($129-1)|0);
       $130 = ($129|0)==(1);
       if ($130) {
        __THREW__ = 0;
        invoke_viii(3262,($126|0),1,1);
        $131 = __THREW__; __THREW__ = 0;
        $132 = $131&1;
        if ($132) {
         break;
        }
       }
      }
      __ZdlPv($$023$i$i19);
      $133 = ($124|0)==($16|0);
      if ($133) {
       break L46;
      } else {
       $$023$i$i19 = $124;
      }
     }
     $134 = ___cxa_find_matching_catch_2()|0;
     $135 = tempRet0;
     ___cxa_call_unexpected(($134|0));
     // unreachable;
    }
   }
  } while(0);
  $136 = HEAP32[$15>>2]|0;
  $137 = ($136|0)==(0);
  L56: do {
   if (!($137)) {
    $138 = HEAP32[$14>>2]|0;
    $139 = HEAP32[$13>>2]|0;
    $140 = ((($139)) + 4|0);
    $141 = HEAP32[$140>>2]|0;
    $142 = HEAP32[$138>>2]|0;
    $143 = ((($142)) + 4|0);
    HEAP32[$143>>2] = $141;
    $144 = HEAP32[$140>>2]|0;
    HEAP32[$144>>2] = $142;
    HEAP32[$15>>2] = 0;
    $145 = ($138|0)==($13|0);
    if (!($145)) {
     $$023$i$i17 = $138;
     while(1) {
      $146 = ((($$023$i$i17)) + 4|0);
      $147 = HEAP32[$146>>2]|0;
      $148 = ((($$023$i$i17)) + 8|0);
      $149 = HEAP32[$148>>2]|0;
      $150 = ($149|0)==(0|0);
      if (!($150)) {
       $151 = ((($149)) + 8|0);
       $152 = HEAP32[$151>>2]|0;HEAP32[$151>>2] = (($152-1)|0);
       $153 = ($152|0)==(1);
       if ($153) {
        __THREW__ = 0;
        invoke_viii(3262,($149|0),1,1);
        $154 = __THREW__; __THREW__ = 0;
        $155 = $154&1;
        if ($155) {
         break;
        }
       }
      }
      __ZdlPv($$023$i$i17);
      $156 = ($147|0)==($13|0);
      if ($156) {
       break L56;
      } else {
       $$023$i$i17 = $147;
      }
     }
     $157 = ___cxa_find_matching_catch_2()|0;
     $158 = tempRet0;
     ___cxa_call_unexpected(($157|0));
     // unreachable;
    }
   }
  } while(0);
  $159 = HEAP32[$12>>2]|0;
  $160 = ($159|0)==(0|0);
  if (!($160)) {
   $161 = ((($159)) + 8|0);
   $162 = HEAP32[$161>>2]|0;HEAP32[$161>>2] = (($162-1)|0);
   $163 = ($162|0)==(1);
   if ($163) {
    __THREW__ = 0;
    invoke_viii(3262,($159|0),1,1);
    $164 = __THREW__; __THREW__ = 0;
    $165 = $164&1;
    if ($165) {
     $193 = ___cxa_find_matching_catch_3(0|0)|0;
     $194 = tempRet0;
     ___clang_call_terminate($193);
     // unreachable;
    }
   }
  }
  HEAP32[$12>>2] = 0;
  $166 = HEAP32[$11>>2]|0;
  $167 = ($166|0)==(0);
  L71: do {
   if (!($167)) {
    $168 = HEAP32[$10>>2]|0;
    $169 = HEAP32[$9>>2]|0;
    $170 = ((($169)) + 4|0);
    $171 = HEAP32[$170>>2]|0;
    $172 = HEAP32[$168>>2]|0;
    $173 = ((($172)) + 4|0);
    HEAP32[$173>>2] = $171;
    $174 = HEAP32[$170>>2]|0;
    HEAP32[$174>>2] = $172;
    HEAP32[$11>>2] = 0;
    $175 = ($168|0)==($9|0);
    if (!($175)) {
     $$023$i$i = $168;
     while(1) {
      $176 = ((($$023$i$i)) + 4|0);
      $177 = HEAP32[$176>>2]|0;
      $178 = ((($$023$i$i)) + 8|0);
      $179 = HEAP32[$178>>2]|0;
      $180 = ($179|0)==(0|0);
      if (!($180)) {
       $181 = ((($179)) + 8|0);
       $182 = HEAP32[$181>>2]|0;HEAP32[$181>>2] = (($182-1)|0);
       $183 = ($182|0)==(1);
       if ($183) {
        __THREW__ = 0;
        invoke_viii(3262,($179|0),1,1);
        $184 = __THREW__; __THREW__ = 0;
        $185 = $184&1;
        if ($185) {
         break;
        }
       }
      }
      __ZdlPv($$023$i$i);
      $186 = ($177|0)==($9|0);
      if ($186) {
       break L71;
      } else {
       $$023$i$i = $177;
      }
     }
     $187 = ___cxa_find_matching_catch_2()|0;
     $188 = tempRet0;
     ___cxa_call_unexpected(($187|0));
     // unreachable;
    }
   }
  } while(0);
  __THREW__ = 0;
  invoke_vii(3284,($0|0),((47568)|0));
  $189 = __THREW__; __THREW__ = 0;
  $190 = $189&1;
  if ($190) {
   $193 = ___cxa_find_matching_catch_3(0|0)|0;
   $194 = tempRet0;
   ___clang_call_terminate($193);
   // unreachable;
  } else {
   $$6 = $65;$$616 = $66;
  }
 }
 __THREW__ = 0;
 invoke_vi(388,($3|0));
 $191 = __THREW__; __THREW__ = 0;
 $192 = $191&1;
 if ($192) {
  $193 = ___cxa_find_matching_catch_3(0|0)|0;
  $194 = tempRet0;
  ___clang_call_terminate($193);
  // unreachable;
 } else {
  ___resumeException($$6|0);
  // unreachable;
 }
}
function __ZN7osgUtil14StateToCompileD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vii(3552,($0|0),(48232|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  $3 = ((($0)) + 132|0);
  __ZN3osg6ObjectD2Ev($3);
  return;
 }
 $4 = ___cxa_find_matching_catch_2()|0;
 $5 = tempRet0;
 $6 = ((($0)) + 132|0);
 __THREW__ = 0;
 invoke_vi(388,($6|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch_3(0|0)|0;
  $10 = tempRet0;
  ___clang_call_terminate($9);
  // unreachable;
 } else {
  ___resumeException($4|0);
  // unreachable;
 }
}
function __ZN7osgUtil14StateToCompileD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vii(3552,($0|0),(48232|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $6 = ___cxa_find_matching_catch_2()|0;
  $7 = tempRet0;
  $8 = ((($0)) + 132|0);
  __THREW__ = 0;
  invoke_vi(388,($8|0));
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if ($10) {
   $11 = ___cxa_find_matching_catch_3(0|0)|0;
   $12 = tempRet0;
   ___clang_call_terminate($11);
   // unreachable;
  } else {
   $eh$lpad$body$index2Z2D = $7;$eh$lpad$body$indexZ2D = $6;
   __ZdlPv($0);
   ___resumeException($eh$lpad$body$indexZ2D|0);
   // unreachable;
  }
 }
 $3 = ((($0)) + 132|0);
 __THREW__ = 0;
 invoke_vi(388,($3|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  __ZdlPv($0);
  return;
 }
 $13 = ___cxa_find_matching_catch_2()|0;
 $14 = tempRet0;
 $eh$lpad$body$index2Z2D = $14;$eh$lpad$body$indexZ2D = $13;
 __ZdlPv($0);
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
}
function __ZN7osgUtil14StateToCompile5applyERN3osg8DrawableE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i$i$i = 0, $$0$i$i$i$i21 = 0, $$0$ph$i$i$i$i = 0, $$0$ph$i$i$i$i18 = 0, $$024$i$i$i$i = 0, $$024$i$i$i$i20 = 0, $$025$i$i$i$i = 0, $$025$i$i$i$i23 = 0, $$036$i$i$i = 0, $$036$i$i$i22 = 0, $$in$i$i$i$i = 0, $$in$i$i$i$i17 = 0, $$pre = 0, $$pre$i$i$i$i = 0, $$pre$i$i$i$i26 = 0, $$pre$phiZ2D = 0, $$pre65 = 0, $$pre66 = 0, $$pre69 = 0, $$sink$be$i$i = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 56|0);
 $3 = ((($0)) + 60|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 do {
  if ($5) {
   $25 = $1;
   $$025$i$i$i$i = $3;$$036$i$i$i = $3;$30 = $25;
  } else {
   $7 = $4;
   while(1) {
    $6 = ((($7)) + 16|0);
    $8 = HEAP32[$6>>2]|0;
    $9 = ($8>>>0)>($1>>>0);
    if ($9) {
     $$sink$be$i$i = $7;
    } else {
     $10 = ($8>>>0)<($1>>>0);
     if (!($10)) {
      label = 56;
      break;
     }
     $11 = ((($7)) + 4|0);
     $$sink$be$i$i = $11;
    }
    $12 = HEAP32[$$sink$be$i$i>>2]|0;
    $13 = ($12|0)==(0|0);
    if ($13) {
     break;
    } else {
     $7 = $12;
    }
   }
   if ((label|0) == 56) {
    return;
   }
   $14 = $1;
   $15 = ((($0)) + 60|0);
   $$0$i$i$i$i = $15;$$024$i$i$i$i = $4;
   while(1) {
    $16 = ((($$024$i$i$i$i)) + 16|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = ($17>>>0)>($1>>>0);
    if ($18) {
     $19 = HEAP32[$$024$i$i$i$i>>2]|0;
     $20 = ($19|0)==(0|0);
     if ($20) {
      label = 11;
      break;
     } else {
      $$0$ph$i$i$i$i = $$024$i$i$i$i;$$in$i$i$i$i = $19;
     }
    } else {
     $21 = ($17>>>0)<($1>>>0);
     if (!($21)) {
      label = 15;
      break;
     }
     $22 = ((($$024$i$i$i$i)) + 4|0);
     $23 = HEAP32[$22>>2]|0;
     $24 = ($23|0)==(0|0);
     if ($24) {
      label = 14;
      break;
     } else {
      $$0$ph$i$i$i$i = $22;$$in$i$i$i$i = $23;
     }
    }
    $$0$i$i$i$i = $$0$ph$i$i$i$i;$$024$i$i$i$i = $$in$i$i$i$i;
   }
   if ((label|0) == 11) {
    $$025$i$i$i$i = $$024$i$i$i$i;$$036$i$i$i = $$024$i$i$i$i;$30 = $14;
    break;
   }
   else if ((label|0) == 14) {
    $$025$i$i$i$i = $22;$$036$i$i$i = $$024$i$i$i$i;$30 = $14;
    break;
   }
   else if ((label|0) == 15) {
    $$025$i$i$i$i = $$0$i$i$i$i;$$036$i$i$i = $$024$i$i$i$i;$30 = $14;
    break;
   }
  }
 } while(0);
 $26 = HEAP32[$$025$i$i$i$i>>2]|0;
 $27 = ($26|0)==(0|0);
 if ($27) {
  $28 = (__Znwj(20)|0);
  $29 = ((($28)) + 16|0);
  HEAP32[$29>>2] = $30;
  HEAP32[$28>>2] = 0;
  $31 = ((($28)) + 4|0);
  HEAP32[$31>>2] = 0;
  $32 = ((($28)) + 8|0);
  HEAP32[$32>>2] = $$036$i$i$i;
  HEAP32[$$025$i$i$i$i>>2] = $28;
  $33 = HEAP32[$2>>2]|0;
  $34 = HEAP32[$33>>2]|0;
  $35 = ($34|0)==(0|0);
  if ($35) {
   $39 = $28;
  } else {
   $36 = $34;
   HEAP32[$2>>2] = $36;
   $$pre$i$i$i$i = HEAP32[$$025$i$i$i$i>>2]|0;
   $39 = $$pre$i$i$i$i;
  }
  $37 = ((($0)) + 60|0);
  $38 = HEAP32[$37>>2]|0;
  __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($38,$39);
  $40 = ((($0)) + 64|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = (($41) + 1)|0;
  HEAP32[$40>>2] = $42;
 }
 $43 = ((($0)) + 128|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = ($44|0)==(0|0);
 if ($45) {
  $$pre$phiZ2D = $1;
 } else {
  $46 = HEAP32[$1>>2]|0;
  $47 = ((($46)) + 124|0);
  $48 = HEAP32[$47>>2]|0;
  $49 = (FUNCTION_TABLE_ii[$48 & 8191]($1)|0);
  $50 = ($44|0)==($49|0);
  if ($50) {
   return;
  } else {
   $$pre$phiZ2D = $1;
  }
 }
 $51 = ((($1)) + 24|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = ($52|0)==(1);
 $$pre69 = ((($0)) + 80|0);
 if (!($53)) {
  $54 = HEAP32[$$pre69>>2]|0;
  $55 = $54 & 2;
  $56 = ($55|0)==(0);
  if ($56) {
   $58 = $54;
  } else {
   __ZN3osg8Drawable17setUseDisplayListEb($1,0);
   $$pre = HEAP32[$$pre69>>2]|0;
   $58 = $$pre;
  }
  $57 = $58 & 1;
  $59 = ($57|0)==(0);
  if ($59) {
   $61 = $58;
  } else {
   __ZN3osg8Drawable17setUseDisplayListEb($1,1);
   $$pre65 = HEAP32[$$pre69>>2]|0;
   $61 = $$pre65;
  }
  $60 = $61 & 64;
  $62 = ($60|0)==(0);
  if ($62) {
   $67 = $61;
  } else {
   $63 = HEAP32[$1>>2]|0;
   $64 = ((($63)) + 212|0);
   $65 = HEAP32[$64>>2]|0;
   FUNCTION_TABLE_vii[$65 & 8191]($1,1);
   $$pre66 = HEAP32[$$pre69>>2]|0;
   $67 = $$pre66;
  }
  $66 = $67 & 128;
  $68 = ($66|0)==(0);
  if (!($68)) {
   $69 = HEAP32[$1>>2]|0;
   $70 = ((($69)) + 212|0);
   $71 = HEAP32[$70>>2]|0;
   FUNCTION_TABLE_vii[$71 & 8191]($1,0);
  }
 }
 $72 = HEAP32[$$pre69>>2]|0;
 $73 = $72 & 4;
 $74 = ($73|0)==(0);
 do {
  if (!($74)) {
   $75 = ((($1)) + 181|0);
   $76 = HEAP8[$75>>0]|0;
   $77 = ($76<<24>>24)==(0);
   if ($77) {
    $78 = ((($1)) + 183|0);
    $79 = HEAP8[$78>>0]|0;
    $80 = ($79<<24>>24)==(0);
    if ($80) {
     break;
    }
   }
   $81 = ((($0)) + 84|0);
   $82 = ((($0)) + 88|0);
   $83 = HEAP32[$82>>2]|0;
   $84 = ($83|0)==(0|0);
   do {
    if ($84) {
     $$025$i$i$i$i23 = $82;$$036$i$i$i22 = $82;
    } else {
     $85 = ((($0)) + 88|0);
     $$0$i$i$i$i21 = $85;$$024$i$i$i$i20 = $83;
     while(1) {
      $86 = ((($$024$i$i$i$i20)) + 16|0);
      $87 = HEAP32[$86>>2]|0;
      $88 = ($87>>>0)>($1>>>0);
      if ($88) {
       $89 = HEAP32[$$024$i$i$i$i20>>2]|0;
       $90 = ($89|0)==(0|0);
       if ($90) {
        label = 41;
        break;
       } else {
        $$0$ph$i$i$i$i18 = $$024$i$i$i$i20;$$in$i$i$i$i17 = $89;
       }
      } else {
       $91 = ($87>>>0)<($1>>>0);
       if (!($91)) {
        label = 45;
        break;
       }
       $92 = ((($$024$i$i$i$i20)) + 4|0);
       $93 = HEAP32[$92>>2]|0;
       $94 = ($93|0)==(0|0);
       if ($94) {
        label = 44;
        break;
       } else {
        $$0$ph$i$i$i$i18 = $92;$$in$i$i$i$i17 = $93;
       }
      }
      $$0$i$i$i$i21 = $$0$ph$i$i$i$i18;$$024$i$i$i$i20 = $$in$i$i$i$i17;
     }
     if ((label|0) == 41) {
      $$025$i$i$i$i23 = $$024$i$i$i$i20;$$036$i$i$i22 = $$024$i$i$i$i20;
      break;
     }
     else if ((label|0) == 44) {
      $$025$i$i$i$i23 = $92;$$036$i$i$i22 = $$024$i$i$i$i20;
      break;
     }
     else if ((label|0) == 45) {
      $$025$i$i$i$i23 = $$0$i$i$i$i21;$$036$i$i$i22 = $$024$i$i$i$i20;
      break;
     }
    }
   } while(0);
   $95 = HEAP32[$$025$i$i$i$i23>>2]|0;
   $96 = ($95|0)==(0|0);
   if ($96) {
    $97 = (__Znwj(20)|0);
    $98 = ((($97)) + 16|0);
    HEAP32[$98>>2] = $30;
    HEAP32[$97>>2] = 0;
    $99 = ((($97)) + 4|0);
    HEAP32[$99>>2] = 0;
    $100 = ((($97)) + 8|0);
    HEAP32[$100>>2] = $$036$i$i$i22;
    HEAP32[$$025$i$i$i$i23>>2] = $97;
    $101 = HEAP32[$81>>2]|0;
    $102 = HEAP32[$101>>2]|0;
    $103 = ($102|0)==(0|0);
    if ($103) {
     $107 = $97;
    } else {
     $104 = $102;
     HEAP32[$81>>2] = $104;
     $$pre$i$i$i$i26 = HEAP32[$$025$i$i$i$i23>>2]|0;
     $107 = $$pre$i$i$i$i26;
    }
    $105 = ((($0)) + 88|0);
    $106 = HEAP32[$105>>2]|0;
    __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($106,$107);
    $108 = ((($0)) + 92|0);
    $109 = HEAP32[$108>>2]|0;
    $110 = (($109) + 1)|0;
    HEAP32[$108>>2] = $110;
   }
  }
 } while(0);
 $111 = ((($1)) + 120|0);
 $112 = HEAP32[$111>>2]|0;
 $113 = ($112|0)==(0|0);
 if (!($113)) {
  $114 = HEAP32[$0>>2]|0;
  $115 = ((($114)) + 200|0);
  $116 = HEAP32[$115>>2]|0;
  FUNCTION_TABLE_vii[$116 & 8191]($0,$112);
 }
 $117 = HEAP32[$43>>2]|0;
 $118 = ($117|0)==(0|0);
 if ($118) {
  return;
 }
 $119 = HEAP32[$1>>2]|0;
 $120 = ((($119)) + 124|0);
 $121 = HEAP32[$120>>2]|0;
 $122 = (FUNCTION_TABLE_ii[$121 & 8191]($$pre$phiZ2D)|0);
 $123 = ($122|0)==(0|0);
 if (!($123)) {
  return;
 }
 $124 = HEAP32[$1>>2]|0;
 $125 = ((($124)) + 120|0);
 $126 = HEAP32[$125>>2]|0;
 $127 = HEAP32[$43>>2]|0;
 FUNCTION_TABLE_vii[$126 & 8191]($$pre$phiZ2D,$127);
 return;
}
function __ZN7osgUtil14StateToCompile5applyERN3osg4NodeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 120|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = HEAP32[$0>>2]|0;
  $6 = ((($5)) + 200|0);
  $7 = HEAP32[$6>>2]|0;
  FUNCTION_TABLE_vii[$7 & 8191]($0,$3);
 }
 $8 = ((($0)) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 switch ($9|0) {
 case 1:  {
  $10 = HEAP32[$1>>2]|0;
  $11 = ((($10)) + 192|0);
  $12 = HEAP32[$11>>2]|0;
  FUNCTION_TABLE_vii[$12 & 8191]($1,$0);
  return;
  break;
 }
 case 0:  {
  return;
  break;
 }
 default: {
  $13 = HEAP32[$1>>2]|0;
  $14 = ((($13)) + 196|0);
  $15 = HEAP32[$14>>2]|0;
  FUNCTION_TABLE_vii[$15 & 8191]($1,$0);
  return;
 }
 }
}
function __ZN7osgUtil14StateToCompile5applyERN3osg8StateSetE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i$i$i = 0, $$0$i$i$i$i24 = 0, $$0$ph$i$i$i$i = 0, $$0$ph$i$i$i$i21 = 0, $$0$ph$lcssa$i$i$i = 0, $$0$ph14$i$i$i = 0, $$024$i$i$i$i = 0, $$024$i$i$i$i23 = 0, $$025$i$i$i$i = 0, $$025$i$i$i$i26 = 0, $$036$i$i$i = 0, $$036$i$i$i25 = 0, $$07$ph13$i$i$i = 0, $$0711$i$i$i = 0, $$in$i$i$i$i = 0, $$in$i$i$i$i20 = 0, $$pre = 0, $$pre$i$i$i$i = 0, $$pre$i$i$i$i27 = 0, $$sink$be$i$i = 0;
 var $$sink$be$i$i16 = 0, $$sroa$046$086 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 68|0);
 $3 = ((($0)) + 72|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 do {
  if ($5) {
   $25 = $1;
   $$025$i$i$i$i = $3;$$036$i$i$i = $3;$30 = $25;
  } else {
   $7 = $4;
   while(1) {
    $6 = ((($7)) + 16|0);
    $8 = HEAP32[$6>>2]|0;
    $9 = ($8>>>0)>($1>>>0);
    if ($9) {
     $$sink$be$i$i = $7;
    } else {
     $10 = ($8>>>0)<($1>>>0);
     if (!($10)) {
      label = 70;
      break;
     }
     $11 = ((($7)) + 4|0);
     $$sink$be$i$i = $11;
    }
    $12 = HEAP32[$$sink$be$i$i>>2]|0;
    $13 = ($12|0)==(0|0);
    if ($13) {
     break;
    } else {
     $7 = $12;
    }
   }
   if ((label|0) == 70) {
    return;
   }
   $14 = $1;
   $15 = ((($0)) + 72|0);
   $$0$i$i$i$i = $15;$$024$i$i$i$i = $4;
   while(1) {
    $16 = ((($$024$i$i$i$i)) + 16|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = ($17>>>0)>($1>>>0);
    if ($18) {
     $19 = HEAP32[$$024$i$i$i$i>>2]|0;
     $20 = ($19|0)==(0|0);
     if ($20) {
      label = 11;
      break;
     } else {
      $$0$ph$i$i$i$i = $$024$i$i$i$i;$$in$i$i$i$i = $19;
     }
    } else {
     $21 = ($17>>>0)<($1>>>0);
     if (!($21)) {
      label = 15;
      break;
     }
     $22 = ((($$024$i$i$i$i)) + 4|0);
     $23 = HEAP32[$22>>2]|0;
     $24 = ($23|0)==(0|0);
     if ($24) {
      label = 14;
      break;
     } else {
      $$0$ph$i$i$i$i = $22;$$in$i$i$i$i = $23;
     }
    }
    $$0$i$i$i$i = $$0$ph$i$i$i$i;$$024$i$i$i$i = $$in$i$i$i$i;
   }
   if ((label|0) == 11) {
    $$025$i$i$i$i = $$024$i$i$i$i;$$036$i$i$i = $$024$i$i$i$i;$30 = $14;
    break;
   }
   else if ((label|0) == 14) {
    $$025$i$i$i$i = $22;$$036$i$i$i = $$024$i$i$i$i;$30 = $14;
    break;
   }
   else if ((label|0) == 15) {
    $$025$i$i$i$i = $$0$i$i$i$i;$$036$i$i$i = $$024$i$i$i$i;$30 = $14;
    break;
   }
  }
 } while(0);
 $26 = HEAP32[$$025$i$i$i$i>>2]|0;
 $27 = ($26|0)==(0|0);
 if ($27) {
  $28 = (__Znwj(20)|0);
  $29 = ((($28)) + 16|0);
  HEAP32[$29>>2] = $30;
  HEAP32[$28>>2] = 0;
  $31 = ((($28)) + 4|0);
  HEAP32[$31>>2] = 0;
  $32 = ((($28)) + 8|0);
  HEAP32[$32>>2] = $$036$i$i$i;
  HEAP32[$$025$i$i$i$i>>2] = $28;
  $33 = HEAP32[$2>>2]|0;
  $34 = HEAP32[$33>>2]|0;
  $35 = ($34|0)==(0|0);
  if ($35) {
   $39 = $28;
  } else {
   $36 = $34;
   HEAP32[$2>>2] = $36;
   $$pre$i$i$i$i = HEAP32[$$025$i$i$i$i>>2]|0;
   $39 = $$pre$i$i$i$i;
  }
  $37 = ((($0)) + 72|0);
  $38 = HEAP32[$37>>2]|0;
  __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($38,$39);
  $40 = ((($0)) + 76|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = (($41) + 1)|0;
  HEAP32[$40>>2] = $42;
 }
 $43 = ((($0)) + 80|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = $44 & 8;
 $46 = ($45|0)==(0);
 if ($46) {
  return;
 }
 $47 = ((($0)) + 128|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = ($48|0)==(0|0);
 if (!($49)) {
  $50 = HEAP32[$1>>2]|0;
  $51 = ((($50)) + 124|0);
  $52 = HEAP32[$51>>2]|0;
  $53 = (FUNCTION_TABLE_ii[$52 & 8191]($1)|0);
  $54 = ($48|0)==($53|0);
  if ($54) {
   return;
  }
 }
 $55 = (__ZN3osg8StateSet12getAttributeENS_14StateAttribute4TypeEj($1,36,0)|0);
 $56 = ($55|0)==(0|0);
 do {
  if (!($56)) {
   $57 = (___dynamic_cast($55,19768,26392,0)|0);
   $58 = $57;
   $59 = ($57|0)==(0|0);
   if (!($59)) {
    $60 = HEAP32[$47>>2]|0;
    $61 = ($60|0)==(0|0);
    if (!($61)) {
     $62 = HEAP32[$57>>2]|0;
     $63 = ((($62)) + 124|0);
     $64 = HEAP32[$63>>2]|0;
     $65 = (FUNCTION_TABLE_ii[$64 & 8191]($57)|0);
     $66 = ($60|0)==($65|0);
     if ($66) {
      break;
     }
    }
    $67 = ((($0)) + 108|0);
    $68 = ((($0)) + 112|0);
    $69 = HEAP32[$68>>2]|0;
    $70 = ($69|0)==(0|0);
    do {
     if ($70) {
      $$025$i$i$i$i26 = $68;$$036$i$i$i25 = $68;
     } else {
      $71 = ((($0)) + 112|0);
      $$0$i$i$i$i24 = $71;$$024$i$i$i$i23 = $69;
      while(1) {
       $72 = ((($$024$i$i$i$i23)) + 16|0);
       $73 = HEAP32[$72>>2]|0;
       $74 = ($57>>>0)<($73>>>0);
       if ($74) {
        $75 = HEAP32[$$024$i$i$i$i23>>2]|0;
        $76 = ($75|0)==(0|0);
        if ($76) {
         label = 33;
         break;
        } else {
         $$0$ph$i$i$i$i21 = $$024$i$i$i$i23;$$in$i$i$i$i20 = $75;
        }
       } else {
        $77 = ($73>>>0)<($57>>>0);
        if (!($77)) {
         label = 37;
         break;
        }
        $78 = ((($$024$i$i$i$i23)) + 4|0);
        $79 = HEAP32[$78>>2]|0;
        $80 = ($79|0)==(0|0);
        if ($80) {
         label = 36;
         break;
        } else {
         $$0$ph$i$i$i$i21 = $78;$$in$i$i$i$i20 = $79;
        }
       }
       $$0$i$i$i$i24 = $$0$ph$i$i$i$i21;$$024$i$i$i$i23 = $$in$i$i$i$i20;
      }
      if ((label|0) == 33) {
       $$025$i$i$i$i26 = $$024$i$i$i$i23;$$036$i$i$i25 = $$024$i$i$i$i23;
       break;
      }
      else if ((label|0) == 36) {
       $$025$i$i$i$i26 = $78;$$036$i$i$i25 = $$024$i$i$i$i23;
       break;
      }
      else if ((label|0) == 37) {
       $$025$i$i$i$i26 = $$0$i$i$i$i24;$$036$i$i$i25 = $$024$i$i$i$i23;
       break;
      }
     }
    } while(0);
    $81 = HEAP32[$$025$i$i$i$i26>>2]|0;
    $82 = ($81|0)==(0|0);
    if ($82) {
     $83 = (__Znwj(20)|0);
     $84 = ((($83)) + 16|0);
     HEAP32[$84>>2] = $58;
     HEAP32[$83>>2] = 0;
     $85 = ((($83)) + 4|0);
     HEAP32[$85>>2] = 0;
     $86 = ((($83)) + 8|0);
     HEAP32[$86>>2] = $$036$i$i$i25;
     HEAP32[$$025$i$i$i$i26>>2] = $83;
     $87 = HEAP32[$67>>2]|0;
     $88 = HEAP32[$87>>2]|0;
     $89 = ($88|0)==(0|0);
     if ($89) {
      $93 = $83;
     } else {
      $90 = $88;
      HEAP32[$67>>2] = $90;
      $$pre$i$i$i$i27 = HEAP32[$$025$i$i$i$i26>>2]|0;
      $93 = $$pre$i$i$i$i27;
     }
     $91 = ((($0)) + 112|0);
     $92 = HEAP32[$91>>2]|0;
     __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($92,$93);
     $94 = ((($0)) + 116|0);
     $95 = HEAP32[$94>>2]|0;
     $96 = (($95) + 1)|0;
     HEAP32[$94>>2] = $96;
    }
    $97 = HEAP32[$47>>2]|0;
    $98 = ($97|0)==(0|0);
    if (!($98)) {
     $99 = HEAP32[$57>>2]|0;
     $100 = ((($99)) + 124|0);
     $101 = HEAP32[$100>>2]|0;
     $102 = (FUNCTION_TABLE_ii[$101 & 8191]($57)|0);
     $103 = ($102|0)==(0|0);
     if ($103) {
      $104 = HEAP32[$57>>2]|0;
      $105 = ((($104)) + 120|0);
      $106 = HEAP32[$105>>2]|0;
      $107 = HEAP32[$47>>2]|0;
      FUNCTION_TABLE_vii[$106 & 8191]($57,$107);
     }
    }
   }
  }
 } while(0);
 $108 = ((($1)) + 80|0);
 $109 = HEAP32[$108>>2]|0;
 $110 = ((($1)) + 84|0);
 $111 = HEAP32[$110>>2]|0;
 $112 = ($109|0)==($111|0);
 if (!($112)) {
  $113 = ((($0)) + 100|0);
  $$sroa$046$086 = $109;$165 = $111;
  while(1) {
   $116 = ((($$sroa$046$086)) + 4|0);
   $117 = HEAP32[$116>>2]|0;
   $118 = ($117|0)==(0|0);
   L72: do {
    if ($118) {
     $155 = $165;
    } else {
     $$0$ph14$i$i$i = $116;$$07$ph13$i$i$i = $117;
     L73: while(1) {
      $$0711$i$i$i = $$07$ph13$i$i$i;
      while(1) {
       $119 = ((($$0711$i$i$i)) + 16|0);
       $120 = HEAP32[$119>>2]|0;
       $121 = ($120|0)<(0);
       if (!($121)) {
        break;
       }
       $124 = ((($$0711$i$i$i)) + 4|0);
       $125 = HEAP32[$124>>2]|0;
       $126 = ($125|0)==(0|0);
       if ($126) {
        $$0$ph$lcssa$i$i$i = $$0$ph14$i$i$i;
        break L73;
       } else {
        $$0711$i$i$i = $125;
       }
      }
      $122 = HEAP32[$$0711$i$i$i>>2]|0;
      $123 = ($122|0)==(0|0);
      if ($123) {
       $$0$ph$lcssa$i$i$i = $$0711$i$i$i;
       break;
      } else {
       $$0$ph14$i$i$i = $$0711$i$i$i;$$07$ph13$i$i$i = $122;
      }
     }
     $127 = ($$0$ph$lcssa$i$i$i|0)==($116|0);
     if ($127) {
      $155 = $165;
     } else {
      $128 = ((($$0$ph$lcssa$i$i$i)) + 16|0);
      $129 = HEAP32[$128>>2]|0;
      $130 = ($129|0)>(0);
      if ($130) {
       $155 = $165;
      } else {
       $131 = ($129|0)<(0);
       if (!($131)) {
        $132 = ((($$0$ph$lcssa$i$i$i)) + 20|0);
        $133 = HEAP32[$132>>2]|0;
        $134 = ($133|0)==(0);
        if (!($134)) {
         $155 = $165;
         break;
        }
       }
       $135 = ((($$0$ph$lcssa$i$i$i)) + 24|0);
       $136 = HEAP32[$135>>2]|0;
       $137 = ($136|0)==(0|0);
       if ($137) {
        $155 = $165;
       } else {
        $138 = (___dynamic_cast($136,19768,26864,0)|0);
        $139 = ($138|0)==(0|0);
        if ($139) {
         $155 = $165;
        } else {
         $140 = HEAP32[$113>>2]|0;
         $141 = ($140|0)==(0|0);
         if (!($141)) {
          $143 = $140;
          while(1) {
           $142 = ((($143)) + 16|0);
           $144 = HEAP32[$142>>2]|0;
           $145 = ($138>>>0)<($144>>>0);
           if ($145) {
            $$sink$be$i$i16 = $143;
           } else {
            $146 = ($144>>>0)<($138>>>0);
            if (!($146)) {
             $155 = $165;
             break L72;
            }
            $147 = ((($143)) + 4|0);
            $$sink$be$i$i16 = $147;
           }
           $148 = HEAP32[$$sink$be$i$i16>>2]|0;
           $149 = ($148|0)==(0|0);
           if ($149) {
            break;
           } else {
            $143 = $148;
           }
          }
         }
         $150 = HEAP32[$0>>2]|0;
         $151 = ((($150)) + 204|0);
         $152 = HEAP32[$151>>2]|0;
         FUNCTION_TABLE_vii[$152 & 8191]($0,$138);
         $$pre = HEAP32[$110>>2]|0;
         $155 = $$pre;
        }
       }
      }
     }
    }
   } while(0);
   $153 = ((($$sroa$046$086)) + 12|0);
   $154 = ($153|0)==($155|0);
   if ($154) {
    break;
   } else {
    $$sroa$046$086 = $153;$165 = $155;
   }
  }
 }
 $114 = HEAP32[$47>>2]|0;
 $115 = ($114|0)==(0|0);
 if ($115) {
  return;
 }
 $156 = HEAP32[$1>>2]|0;
 $157 = ((($156)) + 124|0);
 $158 = HEAP32[$157>>2]|0;
 $159 = (FUNCTION_TABLE_ii[$158 & 8191]($1)|0);
 $160 = ($159|0)==(0|0);
 if (!($160)) {
  return;
 }
 $161 = HEAP32[$1>>2]|0;
 $162 = ((($161)) + 120|0);
 $163 = HEAP32[$162>>2]|0;
 $164 = HEAP32[$47>>2]|0;
 FUNCTION_TABLE_vii[$163 & 8191]($1,$164);
 return;
}
function __ZN7osgUtil14StateToCompile5applyERN3osg7TextureE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$0$i$i$i$i = 0, $$0$ph$i$i$i$i = 0, $$024$i$i$i$i = 0, $$025$i$i$i$i = 0, $$036$i$i$i = 0, $$038 = 0, $$039 = 0, $$1 = 0, $$24469 = 0, $$270 = 0, $$in$i$i$i$i = 0, $$pr = 0, $$pre$i$i$i$i = 0, $$sroa$059$0 = 0, $$sroa$059$2 = 0, $$sroa$059$6$ph = 0, $$sroa$059$7 = 0, $$sroa$059$8 = 0, $$sroa$059$897 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0;
 var $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0;
 var $154 = 0, $155 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 128|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = HEAP32[$1>>2]|0;
  $6 = ((($5)) + 124|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (FUNCTION_TABLE_ii[$7 & 8191]($1)|0);
  $9 = ($3|0)==($8|0);
  if ($9) {
   return;
  }
 }
 $10 = ((($0)) + 120|0);
 $11 = HEAP8[$10>>0]|0;
 $12 = ($11<<24>>24)==(0);
 L5: do {
  if (!($12)) {
   $$0 = 0;$$039 = 0;$$sroa$059$0 = 0;
   L7: while(1) {
    $13 = HEAP32[$1>>2]|0;
    $14 = ((($13)) + 208|0);
    $15 = HEAP32[$14>>2]|0;
    __THREW__ = 0;
    $16 = (invoke_ii($15|0,($1|0))|0);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     $$sroa$059$8 = $$sroa$059$0;
     label = 45;
     break;
    }
    $19 = ($$039>>>0)<($16>>>0);
    if (!($19)) {
     label = 7;
     break;
    }
    $21 = HEAP32[$1>>2]|0;
    $22 = ((($21)) + 200|0);
    $23 = HEAP32[$22>>2]|0;
    __THREW__ = 0;
    $24 = (invoke_iii($23|0,($1|0),($$039|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if ($26) {
     $$sroa$059$8 = $$sroa$059$0;
     label = 45;
     break;
    }
    $27 = ($24|0)==(0|0);
    do {
     if ($27) {
      $$1 = $$0;$$sroa$059$2 = $$sroa$059$0;
     } else {
      $28 = ((($24)) + 40|0);
      $29 = HEAP32[$28>>2]|0;
      $30 = ($29|0)==(0|0);
      if (!($30)) {
       $31 = (___dynamic_cast($29,23080,23144,0)|0);
       $32 = ($31|0)==(0|0);
       if (!($32)) {
        $33 = ($$sroa$059$0|0)==($31|0);
        if ($33) {
         $$1 = $$0;$$sroa$059$2 = $$sroa$059$0;
         break;
        }
        $34 = ($31|0)==(0|0);
        if (!($34)) {
         $35 = ((($31)) + 8|0);
         $36 = HEAP32[$35>>2]|0;HEAP32[$35>>2] = (($36+1)|0);
        }
        $37 = ($$sroa$059$0|0)==(0|0);
        if ($37) {
         $$1 = $$0;$$sroa$059$2 = $31;
         break;
        }
        $38 = ((($$sroa$059$0)) + 8|0);
        $39 = HEAP32[$38>>2]|0;HEAP32[$38>>2] = (($39-1)|0);
        $40 = ($39|0)==(1);
        if (!($40)) {
         $$1 = $$0;$$sroa$059$2 = $31;
         break;
        }
        __THREW__ = 0;
        invoke_viii(3262,($$sroa$059$0|0),1,1);
        $41 = __THREW__; __THREW__ = 0;
        $42 = $41&1;
        if ($42) {
         $$sroa$059$8 = $31;
         label = 45;
         break L7;
        } else {
         $$1 = $$0;$$sroa$059$2 = $31;
         break;
        }
       }
      }
      $43 = (($$0) + 1)|0;
      $$1 = $43;$$sroa$059$2 = $$sroa$059$0;
     }
    } while(0);
    $44 = (($$039) + 1)|0;
    $$0 = $$1;$$039 = $44;$$sroa$059$0 = $$sroa$059$2;
   }
   L25: do {
    if ((label|0) == 7) {
     $20 = ($$0|0)==(0);
     L27: do {
      if ($20) {
       $$sroa$059$7 = $$sroa$059$0;
      } else {
       $45 = ($$sroa$059$0|0)==(0|0);
       L29: do {
        if ($45) {
         $46 = ((($0)) + 124|0);
         $47 = HEAP32[$46>>2]|0;
         $48 = ($47|0)==(0|0);
         L31: do {
          if ($48) {
           __THREW__ = 0;
           $49 = (invoke_ii(3276,72)|0);
           $50 = __THREW__; __THREW__ = 0;
           $51 = $50&1;
           do {
            if (!($51)) {
             __THREW__ = 0;
             invoke_vii(3553,($49|0),(0|0));
             $52 = __THREW__; __THREW__ = 0;
             $53 = $52&1;
             if ($53) {
              $66 = ___cxa_find_matching_catch_2()|0;
              $67 = tempRet0;
              __ZdlPv($49);
              $$24469 = $66;$$270 = $67;
              ___resumeException($$24469|0);
              // unreachable;
             }
             $54 = HEAP32[$46>>2]|0;
             $55 = ($54|0)==($49|0);
             if ($55) {
              $70 = $49;
              break L31;
             }
             HEAP32[$46>>2] = $49;
             $56 = ((($49)) + 8|0);
             $57 = HEAP32[$56>>2]|0;HEAP32[$56>>2] = (($57+1)|0);
             $58 = ($54|0)==(0|0);
             if (!($58)) {
              $59 = ((($54)) + 8|0);
              $60 = HEAP32[$59>>2]|0;HEAP32[$59>>2] = (($60-1)|0);
              $61 = ($60|0)==(1);
              if ($61) {
               __THREW__ = 0;
               invoke_viii(3262,($54|0),1,1);
               $62 = __THREW__; __THREW__ = 0;
               $63 = $62&1;
               if ($63) {
                break;
               }
              }
             }
             $$pr = HEAP32[$46>>2]|0;
             $68 = ($$pr|0)==(0|0);
             if ($68) {
              $$sroa$059$6$ph = 0;
              break L29;
             } else {
              $70 = $$pr;
              break L31;
             }
            }
           } while(0);
           $64 = ___cxa_find_matching_catch_2()|0;
           $65 = tempRet0;
           $$24469 = $64;$$270 = $65;
           ___resumeException($$24469|0);
           // unreachable;
          } else {
           $70 = $47;
          }
         } while(0);
         $69 = ((($70)) + 8|0);
         $71 = HEAP32[$69>>2]|0;HEAP32[$69>>2] = (($71+1)|0);
         $$sroa$059$6$ph = $70;
        } else {
         $$sroa$059$6$ph = $$sroa$059$0;
        }
       } while(0);
       $72 = ((($$sroa$059$6$ph)) + 44|0);
       $73 = ((($$sroa$059$6$ph)) + 36|0);
       $$038 = 0;
       L48: while(1) {
        $74 = HEAP32[$1>>2]|0;
        $75 = ((($74)) + 208|0);
        $76 = HEAP32[$75>>2]|0;
        __THREW__ = 0;
        $77 = (invoke_ii($76|0,($1|0))|0);
        $78 = __THREW__; __THREW__ = 0;
        $79 = $78&1;
        if ($79) {
         $$sroa$059$8 = $$sroa$059$6$ph;
         label = 45;
         break L25;
        }
        $80 = ($$038>>>0)<($77>>>0);
        if (!($80)) {
         $$sroa$059$7 = $$sroa$059$6$ph;
         break L27;
        }
        $81 = HEAP32[$1>>2]|0;
        $82 = ((($81)) + 200|0);
        $83 = HEAP32[$82>>2]|0;
        __THREW__ = 0;
        $84 = (invoke_iii($83|0,($1|0),($$038|0))|0);
        $85 = __THREW__; __THREW__ = 0;
        $86 = $85&1;
        if ($86) {
         $$sroa$059$8 = $$sroa$059$6$ph;
         label = 45;
         break L25;
        }
        $87 = ($84|0)==(0|0);
        do {
         if (!($87)) {
          $88 = ((($84)) + 40|0);
          $89 = HEAP32[$88>>2]|0;
          $90 = ($89|0)==(0|0);
          if (!($90)) {
           $91 = (___dynamic_cast($89,23080,23144,0)|0);
           $92 = ($91|0)==(0|0);
           if (!($92)) {
            break;
           }
          }
          HEAP8[$72>>0] = 1;
          HEAP32[$73>>2] = 35048;
          __THREW__ = 0;
          invoke_vii(3554,($84|0),($$sroa$059$6$ph|0));
          $93 = __THREW__; __THREW__ = 0;
          $94 = $93&1;
          if ($94) {
           break L48;
          }
         }
        } while(0);
        $97 = (($$038) + 1)|0;
        $$038 = $97;
       }
       $95 = ___cxa_find_matching_catch_2()|0;
       $96 = tempRet0;
       $$sroa$059$897 = $$sroa$059$6$ph;$154 = $96;$155 = $95;
       break L25;
      }
     } while(0);
     $98 = ($$sroa$059$7|0)==(0|0);
     if ($98) {
      break L5;
     }
     $99 = ((($$sroa$059$7)) + 8|0);
     $100 = HEAP32[$99>>2]|0;HEAP32[$99>>2] = (($100-1)|0);
     $101 = ($100|0)==(1);
     if (!($101)) {
      break L5;
     }
     __ZNK3osg10Referenced24signalObserversAndDeleteEbb($$sroa$059$7,1,1);
     break L5;
    }
   } while(0);
   if ((label|0) == 45) {
    $102 = ___cxa_find_matching_catch_2()|0;
    $103 = tempRet0;
    $104 = ($$sroa$059$8|0)==(0|0);
    if ($104) {
     $$24469 = $102;$$270 = $103;
     ___resumeException($$24469|0);
     // unreachable;
    } else {
     $$sroa$059$897 = $$sroa$059$8;$154 = $103;$155 = $102;
    }
   }
   $105 = ((($$sroa$059$897)) + 8|0);
   $106 = HEAP32[$105>>2]|0;HEAP32[$105>>2] = (($106-1)|0);
   $107 = ($106|0)==(1);
   if (!($107)) {
    $$24469 = $155;$$270 = $154;
    ___resumeException($$24469|0);
    // unreachable;
   }
   __THREW__ = 0;
   invoke_viii(3262,($$sroa$059$897|0),1,1);
   $108 = __THREW__; __THREW__ = 0;
   $109 = $108&1;
   if ($109) {
    $152 = ___cxa_find_matching_catch_3(0|0)|0;
    $153 = tempRet0;
    ___clang_call_terminate($152);
    // unreachable;
   } else {
    $$24469 = $155;$$270 = $154;
    ___resumeException($$24469|0);
    // unreachable;
   }
  }
 } while(0);
 $110 = HEAP32[$2>>2]|0;
 $111 = ($110|0)==(0|0);
 if (!($111)) {
  $112 = HEAP32[$1>>2]|0;
  $113 = ((($112)) + 124|0);
  $114 = HEAP32[$113>>2]|0;
  $115 = (FUNCTION_TABLE_ii[$114 & 8191]($1)|0);
  $116 = ($115|0)==(0|0);
  if ($116) {
   $117 = HEAP32[$1>>2]|0;
   $118 = ((($117)) + 120|0);
   $119 = HEAP32[$118>>2]|0;
   $120 = HEAP32[$2>>2]|0;
   FUNCTION_TABLE_vii[$119 & 8191]($1,$120);
  }
 }
 $121 = ((($0)) + 96|0);
 $122 = $1;
 $123 = ((($0)) + 100|0);
 $124 = HEAP32[$123>>2]|0;
 $125 = ($124|0)==(0|0);
 do {
  if ($125) {
   $$025$i$i$i$i = $123;$$036$i$i$i = $123;
  } else {
   $126 = ((($0)) + 100|0);
   $$0$i$i$i$i = $126;$$024$i$i$i$i = $124;
   while(1) {
    $127 = ((($$024$i$i$i$i)) + 16|0);
    $128 = HEAP32[$127>>2]|0;
    $129 = ($128>>>0)>($1>>>0);
    if ($129) {
     $130 = HEAP32[$$024$i$i$i$i>>2]|0;
     $131 = ($130|0)==(0|0);
     if ($131) {
      label = 57;
      break;
     } else {
      $$0$ph$i$i$i$i = $$024$i$i$i$i;$$in$i$i$i$i = $130;
     }
    } else {
     $132 = ($128>>>0)<($1>>>0);
     if (!($132)) {
      label = 61;
      break;
     }
     $133 = ((($$024$i$i$i$i)) + 4|0);
     $134 = HEAP32[$133>>2]|0;
     $135 = ($134|0)==(0|0);
     if ($135) {
      label = 60;
      break;
     } else {
      $$0$ph$i$i$i$i = $133;$$in$i$i$i$i = $134;
     }
    }
    $$0$i$i$i$i = $$0$ph$i$i$i$i;$$024$i$i$i$i = $$in$i$i$i$i;
   }
   if ((label|0) == 57) {
    $$025$i$i$i$i = $$024$i$i$i$i;$$036$i$i$i = $$024$i$i$i$i;
    break;
   }
   else if ((label|0) == 60) {
    $$025$i$i$i$i = $133;$$036$i$i$i = $$024$i$i$i$i;
    break;
   }
   else if ((label|0) == 61) {
    $$025$i$i$i$i = $$0$i$i$i$i;$$036$i$i$i = $$024$i$i$i$i;
    break;
   }
  }
 } while(0);
 $136 = HEAP32[$$025$i$i$i$i>>2]|0;
 $137 = ($136|0)==(0|0);
 if (!($137)) {
  return;
 }
 $138 = (__Znwj(20)|0);
 $139 = ((($138)) + 16|0);
 HEAP32[$139>>2] = $122;
 HEAP32[$138>>2] = 0;
 $140 = ((($138)) + 4|0);
 HEAP32[$140>>2] = 0;
 $141 = ((($138)) + 8|0);
 HEAP32[$141>>2] = $$036$i$i$i;
 HEAP32[$$025$i$i$i$i>>2] = $138;
 $142 = HEAP32[$121>>2]|0;
 $143 = HEAP32[$142>>2]|0;
 $144 = ($143|0)==(0|0);
 if ($144) {
  $148 = $138;
 } else {
  $145 = $143;
  HEAP32[$121>>2] = $145;
  $$pre$i$i$i$i = HEAP32[$$025$i$i$i$i>>2]|0;
  $148 = $$pre$i$i$i$i;
 }
 $146 = ((($0)) + 100|0);
 $147 = HEAP32[$146>>2]|0;
 __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($147,$148);
 $149 = ((($0)) + 104|0);
 $150 = HEAP32[$149>>2]|0;
 $151 = (($150) + 1)|0;
 HEAP32[$149>>2] = $151;
 return;
}
function __ZTv0_n16_N7osgUtil14StateToCompileD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __THREW__ = 0;
 invoke_vii(3552,($4|0),(48232|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if (!($6)) {
  $14 = ((($4)) + 132|0);
  __ZN3osg6ObjectD2Ev($14);
  return;
 }
 $7 = ___cxa_find_matching_catch_2()|0;
 $8 = tempRet0;
 $9 = ((($4)) + 132|0);
 __THREW__ = 0;
 invoke_vi(388,($9|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if ($11) {
  $12 = ___cxa_find_matching_catch_3(0|0)|0;
  $13 = tempRet0;
  ___clang_call_terminate($12);
  // unreachable;
 } else {
  ___resumeException($7|0);
  // unreachable;
 }
}
function __ZTv0_n16_N7osgUtil14StateToCompileD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$i$index2Z2D = 0, $eh$lpad$body$i$indexZ2D = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __THREW__ = 0;
 invoke_vii(3552,($4|0),(48232|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $10 = ___cxa_find_matching_catch_2()|0;
  $11 = tempRet0;
  $12 = ((($4)) + 132|0);
  __THREW__ = 0;
  invoke_vi(388,($12|0));
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if ($14) {
   $15 = ___cxa_find_matching_catch_3(0|0)|0;
   $16 = tempRet0;
   ___clang_call_terminate($15);
   // unreachable;
  } else {
   $eh$lpad$body$i$index2Z2D = $11;$eh$lpad$body$i$indexZ2D = $10;
   __ZdlPv($4);
   ___resumeException($eh$lpad$body$i$indexZ2D|0);
   // unreachable;
  }
 }
 $7 = ((($4)) + 132|0);
 __THREW__ = 0;
 invoke_vi(388,($7|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if (!($9)) {
  __ZdlPv($4);
  return;
 }
 $17 = ___cxa_find_matching_catch_2()|0;
 $18 = tempRet0;
 $eh$lpad$body$i$index2Z2D = $18;$eh$lpad$body$i$indexZ2D = $17;
 __ZdlPv($4);
 ___resumeException($eh$lpad$body$i$indexZ2D|0);
 // unreachable;
}
function __ZN7osgUtil14StateToCompileD2Ev($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$03 = 0, $$cast = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $2;
 $3 = ((($1)) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $$cast = $2;
 $5 = ((($$cast)) + -12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($0) + ($6)|0);
 HEAP32[$7>>2] = $4;
 $8 = ((($0)) + 128|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if ($10) {
  label = 4;
 } else {
  $11 = ((($9)) + 8|0);
  $12 = HEAP32[$11>>2]|0;HEAP32[$11>>2] = (($12-1)|0);
  $13 = ($12|0)==(1);
  if ($13) {
   __THREW__ = 0;
   invoke_viii(3262,($9|0),1,1);
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if ($15) {
    $40 = ___cxa_find_matching_catch_2()|0;
    $41 = tempRet0;
    $42 = ((($0)) + 124|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = ($43|0)==(0|0);
    if (!($44)) {
     $45 = ((($43)) + 8|0);
     $46 = HEAP32[$45>>2]|0;HEAP32[$45>>2] = (($46-1)|0);
     $47 = ($46|0)==(1);
     if ($47) {
      __THREW__ = 0;
      invoke_viii(3262,($43|0),1,1);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       $70 = ___cxa_find_matching_catch_3(0|0)|0;
       $71 = tempRet0;
       ___clang_call_terminate($70);
       // unreachable;
      }
     }
    }
    HEAP32[$42>>2] = 0;
    $$0 = $41;$$03 = $40;
   } else {
    label = 4;
   }
  } else {
   label = 4;
  }
 }
 do {
  if ((label|0) == 4) {
   HEAP32[$8>>2] = 0;
   $16 = ((($0)) + 124|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = ($17|0)==(0|0);
   if (!($18)) {
    $19 = ((($17)) + 8|0);
    $20 = HEAP32[$19>>2]|0;HEAP32[$19>>2] = (($20-1)|0);
    $21 = ($20|0)==(1);
    if ($21) {
     __THREW__ = 0;
     invoke_viii(3262,($17|0),1,1);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      $50 = ___cxa_find_matching_catch_2()|0;
      $51 = tempRet0;
      $$0 = $51;$$03 = $50;
      break;
     }
    }
   }
   HEAP32[$16>>2] = 0;
   $24 = ((($0)) + 108|0);
   $25 = ((($0)) + 112|0);
   $26 = HEAP32[$25>>2]|0;
   __ZNSt3__26__treeIPN3osg7ProgramENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($24,$26);
   $27 = ((($0)) + 96|0);
   $28 = ((($0)) + 100|0);
   $29 = HEAP32[$28>>2]|0;
   __ZNSt3__26__treeIPN3osg7TextureENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($27,$29);
   $30 = ((($0)) + 84|0);
   $31 = ((($0)) + 88|0);
   $32 = HEAP32[$31>>2]|0;
   __ZNSt3__26__treeIPN3osg8DrawableENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($30,$32);
   $33 = ((($0)) + 68|0);
   $34 = ((($0)) + 72|0);
   $35 = HEAP32[$34>>2]|0;
   __ZNSt3__26__treeIPN3osg8StateSetENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($33,$35);
   $36 = ((($0)) + 56|0);
   $37 = ((($0)) + 60|0);
   $38 = HEAP32[$37>>2]|0;
   __ZNSt3__26__treeIPN3osg8DrawableENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($36,$38);
   $39 = ((($1)) + 4|0);
   __ZN3osg11NodeVisitorD2Ev($0,$39);
   return;
  }
 } while(0);
 $52 = ((($0)) + 108|0);
 $53 = ((($0)) + 112|0);
 $54 = HEAP32[$53>>2]|0;
 __ZNSt3__26__treeIPN3osg7ProgramENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($52,$54);
 $55 = ((($0)) + 96|0);
 $56 = ((($0)) + 100|0);
 $57 = HEAP32[$56>>2]|0;
 __ZNSt3__26__treeIPN3osg7TextureENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($55,$57);
 $58 = ((($0)) + 84|0);
 $59 = ((($0)) + 88|0);
 $60 = HEAP32[$59>>2]|0;
 __ZNSt3__26__treeIPN3osg8DrawableENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($58,$60);
 $61 = ((($0)) + 68|0);
 $62 = ((($0)) + 72|0);
 $63 = HEAP32[$62>>2]|0;
 __ZNSt3__26__treeIPN3osg8StateSetENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($61,$63);
 $64 = ((($0)) + 56|0);
 $65 = ((($0)) + 60|0);
 $66 = HEAP32[$65>>2]|0;
 __ZNSt3__26__treeIPN3osg8DrawableENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($64,$66);
 $67 = ((($1)) + 4|0);
 __THREW__ = 0;
 invoke_vii(3284,($0|0),($67|0));
 $68 = __THREW__; __THREW__ = 0;
 $69 = $68&1;
 if ($69) {
  $70 = ___cxa_find_matching_catch_3(0|0)|0;
  $71 = tempRet0;
  ___clang_call_terminate($70);
  // unreachable;
 } else {
  ___resumeException($$03|0);
  // unreachable;
 }
}
function __ZNSt3__26__treeIPN3osg7ProgramENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 } else {
  $3 = HEAP32[$1>>2]|0;
  __ZNSt3__26__treeIPN3osg7ProgramENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($0,$3);
  $4 = ((($1)) + 4|0);
  $5 = HEAP32[$4>>2]|0;
  __ZNSt3__26__treeIPN3osg7ProgramENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($0,$5);
  __ZdlPv($1);
  return;
 }
}
function __ZNSt3__26__treeIPN3osg7TextureENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 } else {
  $3 = HEAP32[$1>>2]|0;
  __ZNSt3__26__treeIPN3osg7TextureENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($0,$3);
  $4 = ((($1)) + 4|0);
  $5 = HEAP32[$4>>2]|0;
  __ZNSt3__26__treeIPN3osg7TextureENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($0,$5);
  __ZdlPv($1);
  return;
 }
}
function __ZN7osgUtil27IncrementalCompileOperation17CompileDrawableOpD2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (48256);
 $1 = ((($0)) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  HEAP32[$1>>2] = 0;
  __ZN3osg10ReferencedD2Ev($0);
  return;
 }
 $4 = ((($2)) + 8|0);
 $5 = HEAP32[$4>>2]|0;HEAP32[$4>>2] = (($5-1)|0);
 $6 = ($5|0)==(1);
 if (!($6)) {
  HEAP32[$1>>2] = 0;
  __ZN3osg10ReferencedD2Ev($0);
  return;
 }
 __THREW__ = 0;
 invoke_viii(3262,($2|0),1,1);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if (!($8)) {
  HEAP32[$1>>2] = 0;
  __ZN3osg10ReferencedD2Ev($0);
  return;
 }
 $9 = ___cxa_find_matching_catch_2()|0;
 $10 = tempRet0;
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if ($12) {
  $13 = ___cxa_find_matching_catch_3(0|0)|0;
  $14 = tempRet0;
  ___clang_call_terminate($13);
  // unreachable;
 } else {
  ___resumeException($9|0);
  // unreachable;
 }
}
function __ZN7osgUtil27IncrementalCompileOperation17CompileDrawableOpD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (48256);
 $1 = ((($0)) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = ((($2)) + 8|0);
  $5 = HEAP32[$4>>2]|0;HEAP32[$4>>2] = (($5-1)|0);
  $6 = ($5|0)==(1);
  if ($6) {
   __THREW__ = 0;
   invoke_viii(3262,($2|0),1,1);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch_2()|0;
    $12 = tempRet0;
    __THREW__ = 0;
    invoke_vi(712,($0|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     $15 = ___cxa_find_matching_catch_3(0|0)|0;
     $16 = tempRet0;
     ___clang_call_terminate($15);
     // unreachable;
    } else {
     $eh$lpad$body$index2Z2D = $12;$eh$lpad$body$indexZ2D = $11;
     __ZdlPv($0);
     ___resumeException($eh$lpad$body$indexZ2D|0);
     // unreachable;
    }
   }
  }
 }
 HEAP32[$1>>2] = 0;
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if (!($10)) {
  __ZdlPv($0);
  return;
 }
 $17 = ___cxa_find_matching_catch_2()|0;
 $18 = tempRet0;
 $eh$lpad$body$index2Z2D = $18;$eh$lpad$body$indexZ2D = $17;
 __ZdlPv($0);
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
}
function __ZNK7osgUtil27IncrementalCompileOperation17CompileDrawableOp23estimatedTimeForCompileERNS0_11CompileInfoE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0.0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0.0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = HEAP32[$1>>2]|0;
 $4 = ((($3)) + 860|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($0)) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($8)) + 140|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (FUNCTION_TABLE_ii[$10 & 8191]($7)|0);
 $12 = ($5|0)!=(0|0);
 $13 = ($11|0)!=(0|0);
 $or$cond = $12 & $13;
 if (!($or$cond)) {
  $$0 = 0.0;
  STACKTOP = sp;return (+$$0);
 }
 $14 = ((($5)) + 12|0);
 $15 = HEAP32[$14>>2]|0;
 __ZNK3osg21GeometryCostEstimator19estimateCompileCostEPKNS_8GeometryE($2,$15,$11);
 $16 = +HEAPF64[$2>>3];
 $$0 = $16;
 STACKTOP = sp;return (+$$0);
}
function __ZN7osgUtil27IncrementalCompileOperation17CompileDrawableOp7compileERNS0_11CompileInfoE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($4)) + 228|0);
 $6 = HEAP32[$5>>2]|0;
 FUNCTION_TABLE_vii[$6 & 8191]($3,$1);
 return 1;
}
function __ZN7osgUtil27IncrementalCompileOperation16CompileTextureOpD2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (48284);
 $1 = ((($0)) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  HEAP32[$1>>2] = 0;
  __ZN3osg10ReferencedD2Ev($0);
  return;
 }
 $4 = ((($2)) + 8|0);
 $5 = HEAP32[$4>>2]|0;HEAP32[$4>>2] = (($5-1)|0);
 $6 = ($5|0)==(1);
 if (!($6)) {
  HEAP32[$1>>2] = 0;
  __ZN3osg10ReferencedD2Ev($0);
  return;
 }
 __THREW__ = 0;
 invoke_viii(3262,($2|0),1,1);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if (!($8)) {
  HEAP32[$1>>2] = 0;
  __ZN3osg10ReferencedD2Ev($0);
  return;
 }
 $9 = ___cxa_find_matching_catch_2()|0;
 $10 = tempRet0;
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if ($12) {
  $13 = ___cxa_find_matching_catch_3(0|0)|0;
  $14 = tempRet0;
  ___clang_call_terminate($13);
  // unreachable;
 } else {
  ___resumeException($9|0);
  // unreachable;
 }
}
function __ZN7osgUtil27IncrementalCompileOperation16CompileTextureOpD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (48284);
 $1 = ((($0)) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = ((($2)) + 8|0);
  $5 = HEAP32[$4>>2]|0;HEAP32[$4>>2] = (($5-1)|0);
  $6 = ($5|0)==(1);
  if ($6) {
   __THREW__ = 0;
   invoke_viii(3262,($2|0),1,1);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch_2()|0;
    $12 = tempRet0;
    __THREW__ = 0;
    invoke_vi(712,($0|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     $15 = ___cxa_find_matching_catch_3(0|0)|0;
     $16 = tempRet0;
     ___clang_call_terminate($15);
     // unreachable;
    } else {
     $eh$lpad$body$index2Z2D = $12;$eh$lpad$body$indexZ2D = $11;
     __ZdlPv($0);
     ___resumeException($eh$lpad$body$indexZ2D|0);
     // unreachable;
    }
   }
  }
 }
 HEAP32[$1>>2] = 0;
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if (!($10)) {
  __ZdlPv($0);
  return;
 }
 $17 = ___cxa_find_matching_catch_2()|0;
 $18 = tempRet0;
 $eh$lpad$body$index2Z2D = $18;$eh$lpad$body$indexZ2D = $17;
 __ZdlPv($0);
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
}
function __ZNK7osgUtil27IncrementalCompileOperation16CompileTextureOp23estimatedTimeForCompileERNS0_11CompileInfoE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0.0, $10 = 0, $11 = 0.0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = HEAP32[$1>>2]|0;
 $4 = ((($3)) + 860|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $$0 = 0.0;
  STACKTOP = sp;return (+$$0);
 }
 $7 = ((($0)) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($5)) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 __ZNK3osg20TextureCostEstimator19estimateCompileCostEPKNS_7TextureE($2,$10,$8);
 $11 = +HEAPF64[$2>>3];
 $$0 = $11;
 STACKTOP = sp;return (+$$0);
}
function __ZN7osgUtil27IncrementalCompileOperation16CompileTextureOp7compileERNS0_11CompileInfoE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 36|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + 72|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $20 = ((($0)) + 12|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = HEAP32[$21>>2]|0;
  $23 = ((($22)) + 172|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = HEAP32[$1>>2]|0;
  FUNCTION_TABLE_vii[$24 & 8191]($21,$25);
  return 1;
 }
 $7 = ((($5)) + 120|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if (!($9)) {
  $10 = HEAP32[$1>>2]|0;
  __ZN3osg5State5applyEPKNS_8StateSetE($10,$8);
 }
 $11 = HEAP32[$1>>2]|0;
 $12 = ((($0)) + 12|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = HEAP32[$13>>2]|0;
 $15 = ((($14)) + 180|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (FUNCTION_TABLE_ii[$16 & 8191]($13)|0);
 (__ZN3osg5State16applyTextureModeEjjb($11,0,$17,1)|0);
 $18 = HEAP32[$1>>2]|0;
 $19 = HEAP32[$12>>2]|0;
 (__ZN3osg5State21applyTextureAttributeEjPKNS_14StateAttributeE($18,0,$19)|0);
 __ZNK3osg8Drawable4drawERNS_10RenderInfoE($5,$1);
 return 1;
}
function __ZN3osg5State16applyTextureModeEjjb($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0$i = 0, $$0$i$i = 0, $$0$ph$i$i = 0, $$014$i = 0, $$024$i$i = 0, $$025$i$i = 0, $$025$i65$i = 0, $$049$i = 0, $$04964$i = 0, $$in$i$i = 0, $$pre$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $4 = ((($0)) + 640|0);
 $5 = ((($0)) + 644|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$4>>2]|0;
 $8 = (($6) - ($7))|0;
 $9 = (($8|0) / 12)&-1;
 $10 = ($9>>>0)>($1>>>0);
 do {
  if (!($10)) {
   $11 = (($1) + 1)|0;
   $12 = ($11>>>0)>($9>>>0);
   $13 = $7;
   $14 = $6;
   if ($12) {
    $15 = (($11) - ($9))|0;
    __ZNSt3__26vectorINS_3mapIjN3osg5State9ModeStackENS_4lessIjEENS_9allocatorINS_4pairIKjS4_EEEEEENS7_ISC_EEE8__appendEj($4,$15);
    break;
   }
   $16 = ($11>>>0)<($9>>>0);
   if ($16) {
    $17 = (($13) + (($11*12)|0)|0);
    $18 = ($14|0)==($17|0);
    if (!($18)) {
     $20 = $14;
     while(1) {
      $19 = ((($20)) + -12|0);
      HEAP32[$5>>2] = $19;
      $21 = ((($20)) + -8|0);
      $22 = HEAP32[$21>>2]|0;
      __ZNSt3__26__treeINS_12__value_typeIjN3osg5State9ModeStackEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($19,$22);
      $23 = HEAP32[$5>>2]|0;
      $24 = ($23|0)==($17|0);
      if ($24) {
       break;
      } else {
       $20 = $23;
      }
     }
    }
   }
  }
 } while(0);
 $25 = HEAP32[$4>>2]|0;
 $26 = (($25) + (($1*12)|0)|0);
 $27 = (((($25) + (($1*12)|0)|0)) + 4|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = ($28|0)==(0|0);
 do {
  if ($29) {
   $$025$i$i = $27;$$049$i = $27;$40 = $28;
   label = 18;
  } else {
   $30 = (((($25) + (($1*12)|0)|0)) + 4|0);
   $$0$i$i = $30;$$024$i$i = $28;$91 = $28;
   while(1) {
    $31 = ((($$024$i$i)) + 16|0);
    $32 = HEAP32[$31>>2]|0;
    $33 = ($32>>>0)>($2>>>0);
    if ($33) {
     $34 = HEAP32[$$024$i$i>>2]|0;
     $35 = ($34|0)==(0|0);
     if ($35) {
      label = 12;
      break;
     } else {
      $$0$ph$i$i = $$024$i$i;$$in$i$i = $34;
     }
    } else {
     $36 = ($32>>>0)<($2>>>0);
     if (!($36)) {
      label = 16;
      break;
     }
     $37 = ((($$024$i$i)) + 4|0);
     $38 = HEAP32[$37>>2]|0;
     $39 = ($38|0)==(0|0);
     if ($39) {
      label = 15;
      break;
     } else {
      $$0$ph$i$i = $37;$$in$i$i = $38;
     }
    }
    $$0$i$i = $$0$ph$i$i;$$024$i$i = $$in$i$i;$91 = $$in$i$i;
   }
   if ((label|0) == 12) {
    $$025$i65$i = $$024$i$i;$$04964$i = $$024$i$i;
    label = 19;
    break;
   }
   else if ((label|0) == 15) {
    $$025$i65$i = $37;$$04964$i = $$024$i$i;
    label = 19;
    break;
   }
   else if ((label|0) == 16) {
    $$025$i$i = $$0$i$i;$$049$i = $$024$i$i;$40 = $91;
    label = 18;
    break;
   }
  }
 } while(0);
 if ((label|0) == 18) {
  $41 = ($40|0)==(0|0);
  if ($41) {
   $$025$i65$i = $$025$i$i;$$04964$i = $$049$i;
   label = 19;
  } else {
   $$014$i = $40;
  }
 }
 if ((label|0) == 19) {
  $42 = (__Znwj(36)|0);
  $43 = ((($42)) + 16|0);
  HEAP32[$43>>2] = $2;
  $44 = ((($42)) + 20|0);
  $45 = ((($42)) + 24|0);
  HEAP32[$45>>2] = 0;
  $46 = ((($42)) + 28|0);
  HEAP32[$46>>2] = 0;
  $47 = ((($42)) + 32|0);
  HEAP32[$47>>2] = 0;
  HEAP8[$44>>0] = 1;
  $48 = ((($42)) + 21|0);
  HEAP8[$48>>0] = 0;
  $49 = ((($42)) + 22|0);
  HEAP8[$49>>0] = 0;
  $50 = ((($42)) + 23|0);
  HEAP8[$50>>0] = 0;
  HEAP32[$42>>2] = 0;
  $51 = ((($42)) + 4|0);
  HEAP32[$51>>2] = 0;
  $52 = ((($42)) + 8|0);
  HEAP32[$52>>2] = $$04964$i;
  HEAP32[$$025$i65$i>>2] = $42;
  $53 = HEAP32[$26>>2]|0;
  $54 = HEAP32[$53>>2]|0;
  $55 = ($54|0)==(0|0);
  if ($55) {
   $59 = $42;
  } else {
   $56 = $54;
   HEAP32[$26>>2] = $56;
   $$pre$i$i = HEAP32[$$025$i65$i>>2]|0;
   $59 = $$pre$i$i;
  }
  $57 = (((($25) + (($1*12)|0)|0)) + 4|0);
  $58 = HEAP32[$57>>2]|0;
  __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($58,$59);
  $60 = (((($25) + (($1*12)|0)|0)) + 8|0);
  $61 = HEAP32[$60>>2]|0;
  $62 = (($61) + 1)|0;
  HEAP32[$60>>2] = $62;
  $$014$i = $42;
 }
 $63 = ((($$014$i)) + 21|0);
 HEAP8[$63>>0] = 1;
 $64 = $3&1;
 $65 = ((($$014$i)) + 20|0);
 $66 = HEAP8[$65>>0]|0;
 $67 = ($66<<24>>24)==(0);
 if ($67) {
  $$0$i = 0;
  return ($$0$i|0);
 }
 $68 = ((($$014$i)) + 22|0);
 $69 = HEAP8[$68>>0]|0;
 $70 = $69&255;
 $71 = $3&1;
 $72 = ($70|0)==($71|0);
 if ($72) {
  $$0$i = 0;
  return ($$0$i|0);
 }
 $73 = ((($0)) + 688|0);
 $74 = HEAP32[$73>>2]|0;
 $75 = ($74|0)==($1|0);
 do {
  if (!($75)) {
   $76 = ((($0)) + 728|0);
   $77 = HEAP32[$76>>2]|0;
   $78 = ($77|0)==(0|0);
   if (!($78)) {
    $79 = ((($0)) + 716|0);
    $80 = HEAP32[$79>>2]|0;
    $81 = ((($0)) + 720|0);
    $82 = HEAP32[$81>>2]|0;
    $83 = ($80|0)>($82|0);
    $84 = $83 ? $80 : $82;
    $85 = ($84>>>0)>($1>>>0);
    if ($85) {
     $86 = (($1) + 33984)|0;
     FUNCTION_TABLE_vi[$77 & 8191]($86);
     HEAP32[$73>>2] = $1;
     break;
    }
   }
   $87 = ($1|0)==(0);
   if (!($87)) {
    $$0$i = 0;
    return ($$0$i|0);
   }
  }
 } while(0);
 HEAP8[$68>>0] = $64;
 if ($3) {
  _glEnable(($2|0));
 } else {
  _glDisable(($2|0));
 }
 $88 = ((($0)) + 344|0);
 $89 = HEAP32[$88>>2]|0;
 $90 = ($89|0)==(2);
 if (!($90)) {
  $$0$i = 1;
  return ($$0$i|0);
 }
 (__ZNK3osg5State13checkGLErrorsEj($0,$2)|0);
 $$0$i = 1;
 return ($$0$i|0);
}
function __ZN3osg5State21applyTextureAttributeEjPKNS_14StateAttributeE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$i$i = 0, $$0$ph$i$i = 0, $$014$i = 0, $$024$i$i = 0, $$025$i$i = 0, $$025$i68$i = 0, $$052$i = 0, $$05267$i = 0, $$in$i$i = 0, $$pre$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 652|0);
 $4 = ((($0)) + 656|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$3>>2]|0;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 12)&-1;
 $9 = ($8>>>0)>($1>>>0);
 do {
  if (!($9)) {
   $10 = (($1) + 1)|0;
   $11 = ($10>>>0)>($8>>>0);
   $12 = $6;
   $13 = $5;
   if ($11) {
    $14 = (($10) - ($8))|0;
    __ZNSt3__26vectorINS_3mapINS_4pairIN3osg14StateAttribute4TypeEjEENS3_5State14AttributeStackENS_4lessIS6_EENS_9allocatorINS2_IKS6_S8_EEEEEENSB_ISF_EEE8__appendEj($3,$14);
    break;
   }
   $15 = ($10>>>0)<($8>>>0);
   if ($15) {
    $16 = (($12) + (($10*12)|0)|0);
    $17 = ($13|0)==($16|0);
    if (!($17)) {
     $19 = $13;
     while(1) {
      $18 = ((($19)) + -12|0);
      HEAP32[$4>>2] = $18;
      $20 = ((($19)) + -8|0);
      $21 = HEAP32[$20>>2]|0;
      __ZNSt3__26__treeINS_12__value_typeINS_4pairIN3osg14StateAttribute4TypeEjEENS3_5State14AttributeStackEEENS_19__map_value_compareIS6_S9_NS_4lessIS6_EELb1EEENS_9allocatorIS9_EEE7destroyEPNS_11__tree_nodeIS9_PvEE($18,$21);
      $22 = HEAP32[$4>>2]|0;
      $23 = ($22|0)==($16|0);
      if ($23) {
       break;
      } else {
       $19 = $22;
      }
     }
    }
   }
  }
 } while(0);
 $24 = HEAP32[$3>>2]|0;
 $25 = (($24) + (($1*12)|0)|0);
 $26 = HEAP32[$2>>2]|0;
 $27 = ((($26)) + 148|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (FUNCTION_TABLE_ii[$28 & 8191]($2)|0);
 $30 = HEAP32[$2>>2]|0;
 $31 = ((($30)) + 152|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (FUNCTION_TABLE_ii[$32 & 8191]($2)|0);
 $34 = (((($24) + (($1*12)|0)|0)) + 4|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = ($35|0)==(0|0);
 do {
  if ($36) {
   $$025$i$i = $34;$$052$i = $34;$51 = $35;
   label = 20;
  } else {
   $37 = (((($24) + (($1*12)|0)|0)) + 4|0);
   $$0$i$i = $37;$$024$i$i = $35;$75 = $35;
   L13: while(1) {
    $38 = ((($$024$i$i)) + 16|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = ($29|0)<($39|0);
    do {
     if ($40) {
      label = 13;
     } else {
      $41 = ($39|0)<($29|0);
      if (!($41)) {
       $42 = ((($$024$i$i)) + 20|0);
       $43 = HEAP32[$42>>2]|0;
       $44 = ($33>>>0)<($43>>>0);
       if ($44) {
        label = 13;
        break;
       }
       $47 = ($43>>>0)<($33>>>0);
       if (!($47)) {
        label = 18;
        break L13;
       }
      }
      $48 = ((($$024$i$i)) + 4|0);
      $49 = HEAP32[$48>>2]|0;
      $50 = ($49|0)==(0|0);
      if ($50) {
       label = 17;
       break L13;
      } else {
       $$0$ph$i$i = $48;$$in$i$i = $49;
      }
     }
    } while(0);
    if ((label|0) == 13) {
     label = 0;
     $45 = HEAP32[$$024$i$i>>2]|0;
     $46 = ($45|0)==(0|0);
     if ($46) {
      label = 14;
      break;
     } else {
      $$0$ph$i$i = $$024$i$i;$$in$i$i = $45;
     }
    }
    $$0$i$i = $$0$ph$i$i;$$024$i$i = $$in$i$i;$75 = $$in$i$i;
   }
   if ((label|0) == 14) {
    $$025$i68$i = $$024$i$i;$$05267$i = $$024$i$i;
    break;
   }
   else if ((label|0) == 17) {
    $$025$i68$i = $48;$$05267$i = $$024$i$i;
    break;
   }
   else if ((label|0) == 18) {
    $$025$i$i = $$0$i$i;$$052$i = $$024$i$i;$51 = $75;
    label = 20;
    break;
   }
  }
 } while(0);
 if ((label|0) == 20) {
  $52 = ($51|0)==(0|0);
  if ($52) {
   $$025$i68$i = $$025$i$i;$$05267$i = $$052$i;
  } else {
   $$014$i = $51;
   $73 = ((($$014$i)) + 24|0);
   HEAP8[$73>>0] = 1;
   $74 = (__ZN3osg5State23applyAttributeOnTexUnitEjPKNS_14StateAttributeERNS0_14AttributeStackE($0,$1,$2,$73)|0);
   return ($74|0);
  }
 }
 $53 = (__Znwj(52)|0);
 $54 = ((($53)) + 16|0);
 $55 = $54;
 $56 = $55;
 HEAP32[$56>>2] = $29;
 $57 = (($55) + 4)|0;
 $58 = $57;
 HEAP32[$58>>2] = $33;
 $59 = ((($53)) + 24|0);
 HEAP8[$59>>0] = 0;
 $60 = ((($53)) + 28|0);
 ;HEAP32[$60>>2]=0|0;HEAP32[$60+4>>2]=0|0;HEAP32[$60+8>>2]=0|0;HEAP32[$60+12>>2]=0|0;HEAP32[$60+16>>2]=0|0;HEAP32[$60+20>>2]=0|0;
 HEAP32[$53>>2] = 0;
 $61 = ((($53)) + 4|0);
 HEAP32[$61>>2] = 0;
 $62 = ((($53)) + 8|0);
 HEAP32[$62>>2] = $$05267$i;
 HEAP32[$$025$i68$i>>2] = $53;
 $63 = HEAP32[$25>>2]|0;
 $64 = HEAP32[$63>>2]|0;
 $65 = ($64|0)==(0|0);
 if ($65) {
  $69 = $53;
 } else {
  $66 = $64;
  HEAP32[$25>>2] = $66;
  $$pre$i$i = HEAP32[$$025$i68$i>>2]|0;
  $69 = $$pre$i$i;
 }
 $67 = (((($24) + (($1*12)|0)|0)) + 4|0);
 $68 = HEAP32[$67>>2]|0;
 __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($68,$69);
 $70 = (((($24) + (($1*12)|0)|0)) + 8|0);
 $71 = HEAP32[$70>>2]|0;
 $72 = (($71) + 1)|0;
 HEAP32[$70>>2] = $72;
 $$014$i = $53;
 $73 = ((($$014$i)) + 24|0);
 HEAP8[$73>>0] = 1;
 $74 = (__ZN3osg5State23applyAttributeOnTexUnitEjPKNS_14StateAttributeERNS0_14AttributeStackE($0,$1,$2,$73)|0);
 return ($74|0);
}
function __ZNSt3__26vectorINS_3mapINS_4pairIN3osg14StateAttribute4TypeEjEENS3_5State14AttributeStackENS_4lessIS6_EENS_9allocatorINS2_IKS6_S8_EEEEEENSB_ISF_EEE8__appendEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i = 0, $$0$i13 = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $9 = 0, $scevgep = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $2 = sp;
 $3 = ((($0)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) - ($6))|0;
 $8 = (($7|0) / 12)&-1;
 $9 = ($8>>>0)<($1>>>0);
 if (!($9)) {
  $10 = $6;
  $$0$i = $1;$12 = $10;
  while(1) {
   $11 = ((($12)) + 4|0);
   HEAP32[$11>>2] = 0;
   $13 = ((($12)) + 8|0);
   HEAP32[$13>>2] = 0;
   $14 = ((($12)) + 4|0);
   HEAP32[$12>>2] = $14;
   $15 = HEAP32[$5>>2]|0;
   $16 = ((($15)) + 12|0);
   HEAP32[$5>>2] = $16;
   $17 = (($$0$i) + -1)|0;
   $18 = ($17|0)==(0);
   if ($18) {
    break;
   } else {
    $$0$i = $17;$12 = $16;
   }
  }
  STACKTOP = sp;return;
 }
 $19 = HEAP32[$0>>2]|0;
 $20 = (($6) - ($19))|0;
 $21 = (($20|0) / 12)&-1;
 $22 = (($21) + ($1))|0;
 $23 = ($22>>>0)>(357913941);
 if ($23) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $24 = ((($0)) + 8|0);
 $25 = (($4) - ($19))|0;
 $26 = (($25|0) / 12)&-1;
 $27 = ($26>>>0)<(178956970);
 $28 = $26 << 1;
 $29 = ($28>>>0)<($22>>>0);
 $$sroa$speculated$i = $29 ? $22 : $28;
 $$sroa$speculated$$i = $27 ? $$sroa$speculated$i : 357913941;
 $30 = ((($2)) + 12|0);
 HEAP32[$30>>2] = 0;
 $31 = ((($2)) + 16|0);
 HEAP32[$31>>2] = $24;
 $32 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($32) {
   $41 = 0;
  } else {
   $33 = ($$sroa$speculated$$i>>>0)>(357913941);
   if (!($33)) {
    $39 = ($$sroa$speculated$$i*12)|0;
    $40 = (__Znwj($39)|0);
    $41 = $40;
    break;
   }
   $34 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($34|0),(204840|0));
   $35 = __THREW__; __THREW__ = 0;
   $36 = $35&1;
   if ($36) {
    $37 = ___cxa_find_matching_catch_2()|0;
    $38 = tempRet0;
    ___cxa_free_exception(($34|0));
    ___resumeException($37|0);
    // unreachable;
   } else {
    HEAP32[$34>>2] = (99824);
    ___cxa_throw(($34|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 HEAP32[$2>>2] = $41;
 $42 = (($41) + (($21*12)|0)|0);
 $43 = ((($2)) + 8|0);
 HEAP32[$43>>2] = $42;
 $44 = ((($2)) + 4|0);
 HEAP32[$44>>2] = $42;
 $45 = (($41) + (($$sroa$speculated$$i*12)|0)|0);
 $46 = ((($2)) + 12|0);
 HEAP32[$46>>2] = $45;
 $$0$i13 = $1;$48 = $42;
 while(1) {
  $47 = ((($48)) + 4|0);
  HEAP32[$47>>2] = 0;
  $49 = ((($48)) + 8|0);
  HEAP32[$49>>2] = 0;
  $50 = ((($48)) + 4|0);
  HEAP32[$48>>2] = $50;
  $51 = ((($48)) + 12|0);
  $52 = (($$0$i13) + -1)|0;
  $53 = ($52|0)==(0);
  if ($53) {
   break;
  } else {
   $$0$i13 = $52;$48 = $51;
  }
 }
 $scevgep = (($41) + (($22*12)|0)|0);
 HEAP32[$43>>2] = $scevgep;
 __THREW__ = 0;
 invoke_vii(3555,($0|0),($2|0));
 $54 = __THREW__; __THREW__ = 0;
 $55 = $54&1;
 if ($55) {
  $67 = ___cxa_find_matching_catch_2()|0;
  $68 = tempRet0;
  $69 = HEAP32[$44>>2]|0;
  $70 = HEAP32[$43>>2]|0;
  $71 = ($70|0)==($69|0);
  if (!($71)) {
   $73 = $70;
   while(1) {
    $72 = ((($73)) + -12|0);
    HEAP32[$43>>2] = $72;
    $74 = ((($73)) + -8|0);
    $75 = HEAP32[$74>>2]|0;
    __ZNSt3__26__treeINS_12__value_typeINS_4pairIN3osg14StateAttribute4TypeEjEENS3_5State14AttributeStackEEENS_19__map_value_compareIS6_S9_NS_4lessIS6_EELb1EEENS_9allocatorIS9_EEE7destroyEPNS_11__tree_nodeIS9_PvEE($72,$75);
    $76 = HEAP32[$43>>2]|0;
    $77 = ($76|0)==($69|0);
    if ($77) {
     break;
    } else {
     $73 = $76;
    }
   }
  }
  $78 = HEAP32[$2>>2]|0;
  $79 = ($78|0)==(0|0);
  if ($79) {
   ___resumeException($67|0);
   // unreachable;
  }
  __ZdlPv($78);
  ___resumeException($67|0);
  // unreachable;
 } else {
  $56 = HEAP32[$44>>2]|0;
  $57 = HEAP32[$43>>2]|0;
  $58 = ($57|0)==($56|0);
  if (!($58)) {
   $60 = $57;
   while(1) {
    $59 = ((($60)) + -12|0);
    HEAP32[$43>>2] = $59;
    $61 = ((($60)) + -8|0);
    $62 = HEAP32[$61>>2]|0;
    __ZNSt3__26__treeINS_12__value_typeINS_4pairIN3osg14StateAttribute4TypeEjEENS3_5State14AttributeStackEEENS_19__map_value_compareIS6_S9_NS_4lessIS6_EELb1EEENS_9allocatorIS9_EEE7destroyEPNS_11__tree_nodeIS9_PvEE($59,$62);
    $63 = HEAP32[$43>>2]|0;
    $64 = ($63|0)==($56|0);
    if ($64) {
     break;
    } else {
     $60 = $63;
    }
   }
  }
  $65 = HEAP32[$2>>2]|0;
  $66 = ($65|0)==(0|0);
  if (!($66)) {
   __ZdlPv($65);
  }
  STACKTOP = sp;return;
 }
}
function __ZNSt3__26__treeINS_12__value_typeINS_4pairIN3osg14StateAttribute4TypeEjEENS3_5State14AttributeStackEEENS_19__map_value_compareIS6_S9_NS_4lessIS6_EELb1EEENS_9allocatorIS9_EEE7destroyEPNS_11__tree_nodeIS9_PvEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 }
 $3 = HEAP32[$1>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_4pairIN3osg14StateAttribute4TypeEjEENS3_5State14AttributeStackEEENS_19__map_value_compareIS6_S9_NS_4lessIS6_EELb1EEENS_9allocatorIS9_EEE7destroyEPNS_11__tree_nodeIS9_PvEE($0,$3);
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_4pairIN3osg14StateAttribute4TypeEjEENS3_5State14AttributeStackEEENS_19__map_value_compareIS6_S9_NS_4lessIS6_EELb1EEENS_9allocatorIS9_EEE7destroyEPNS_11__tree_nodeIS9_PvEE($0,$5);
 $6 = ((($1)) + 40|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = ((($1)) + 44|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10|0)==($7|0);
  if (!($11)) {
   $scevgep$i$i$i$i$i$i$i = ((($10)) + -8|0);
   $12 = $scevgep$i$i$i$i$i$i$i;
   $13 = $7;
   $14 = (($12) - ($13))|0;
   $15 = $14 >>> 3;
   $16 = $15 ^ -1;
   $scevgep5$i$i$i$i$i$i$i = (($10) + ($16<<3)|0);
   HEAP32[$9>>2] = $scevgep5$i$i$i$i$i$i$i;
  }
  __ZdlPv($7);
 }
 $17 = ((($1)) + 36|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ($18|0)==(0|0);
 if (!($19)) {
  $20 = ((($18)) + 8|0);
  $21 = HEAP32[$20>>2]|0;HEAP32[$20>>2] = (($21-1)|0);
  $22 = ($21|0)==(1);
  if ($22) {
   __THREW__ = 0;
   invoke_viii(3262,($18|0),1,1);
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if ($24) {
    $25 = ___cxa_find_matching_catch_2()|0;
    $26 = tempRet0;
    ___cxa_call_unexpected(($25|0));
    // unreachable;
   }
  }
 }
 __ZdlPv($1);
 return;
}
function __ZN3osg5State23applyAttributeOnTexUnitEjPKNS_14StateAttributeERNS0_14AttributeStackE($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ((($3)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==($2|0);
 if ($6) {
  $$0 = 0;
  return ($$0|0);
 }
 $7 = ((($0)) + 688|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==($1|0);
 do {
  if (!($9)) {
   $10 = ((($0)) + 728|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = ($11|0)==(0|0);
   if (!($12)) {
    $13 = ((($0)) + 716|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ((($0)) + 720|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = ($14|0)>($16|0);
    $18 = $17 ? $14 : $16;
    $19 = ($18>>>0)>($1>>>0);
    if ($19) {
     $20 = (($1) + 33984)|0;
     FUNCTION_TABLE_vi[$11 & 8191]($20);
     HEAP32[$7>>2] = $1;
     break;
    }
   }
   $21 = ($1|0)==(0);
   if (!($21)) {
    $$0 = 0;
    return ($$0|0);
   }
  }
 } while(0);
 $22 = ((($3)) + 12|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)==(0|0);
 if ($24) {
  $25 = HEAP32[$2>>2]|0;
  $26 = ((($25)) + 12|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = (FUNCTION_TABLE_ii[$27 & 8191]($2)|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = ((($29)) + 56|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = (FUNCTION_TABLE_ii[$31 & 8191]($28)|0);
  $33 = HEAP32[$22>>2]|0;
  $34 = ($33|0)==($32|0);
  if (!($34)) {
   HEAP32[$22>>2] = $32;
   $35 = ($32|0)==(0|0);
   if (!($35)) {
    $36 = ((($32)) + 8|0);
    $37 = HEAP32[$36>>2]|0;HEAP32[$36>>2] = (($37+1)|0);
   }
   $38 = ($33|0)==(0|0);
   if (!($38)) {
    $39 = ((($33)) + 8|0);
    $40 = HEAP32[$39>>2]|0;HEAP32[$39>>2] = (($40-1)|0);
    $41 = ($40|0)==(1);
    if ($41) {
     __ZNK3osg10Referenced24signalObserversAndDeleteEbb($33,1,1);
    }
   }
  }
 }
 HEAP32[$4>>2] = $2;
 $42 = HEAP32[$2>>2]|0;
 $43 = ((($42)) + 172|0);
 $44 = HEAP32[$43>>2]|0;
 FUNCTION_TABLE_vii[$44 & 8191]($2,$0);
 $45 = ((($2)) + 44|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = ((($3)) + 8|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = ($48|0)==($46|0);
 if (!($49)) {
  HEAP32[$47>>2] = $46;
  $50 = ((($0)) + 137|0);
  HEAP8[$50>>0] = 1;
 }
 $51 = ((($0)) + 344|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = ($52|0)==(2);
 if (!($53)) {
  $$0 = 1;
  return ($$0|0);
 }
 (__ZNK3osg5State13checkGLErrorsEPKNS_14StateAttributeE($0,$2)|0);
 $$0 = 1;
 return ($$0|0);
}
function __ZNSt3__26vectorINS_3mapINS_4pairIN3osg14StateAttribute4TypeEjEENS3_5State14AttributeStackENS_4lessIS6_EENS_9allocatorINS2_IKS6_S8_EEEEEENSB_ISF_EEE26__swap_out_circular_bufferERNS_14__split_bufferISF_RSG_EE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i$i$i$i$i$i = 0, $$0$i$i$i$i$i$i$i$i = 0, $$012$i = 0, $$byval_copy = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i$i$i$i$i$i$i = 0, $$pre$phi27Z2D = 0, $$pre$phiZ2D = 0, $$pre24 = 0, $$sroa$07$0$i$i$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$i$i$i$index2Z2D = 0, $eh$lpad$body$i$i$i$indexZ2D = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy = sp + 12|0;
 $2 = sp + 8|0;
 $3 = sp + 4|0;
 $4 = sp;
 $5 = HEAP32[$0>>2]|0;
 $6 = ((($0)) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($1)) + 4|0);
 $9 = ($7|0)==($5|0);
 if ($9) {
  $10 = $5;
  $$pre24 = HEAP32[$8>>2]|0;
  $$pre$phi27Z2D = $8;$$pre$phiZ2D = $0;$98 = $$pre24;$99 = $10;
  HEAP32[$$pre$phiZ2D>>2] = $98;
  HEAP32[$$pre$phi27Z2D>>2] = $99;
  $100 = ((($1)) + 8|0);
  $101 = HEAP32[$6>>2]|0;
  $102 = HEAP32[$100>>2]|0;
  HEAP32[$6>>2] = $102;
  HEAP32[$100>>2] = $101;
  $103 = ((($0)) + 8|0);
  $104 = ((($1)) + 12|0);
  $105 = HEAP32[$103>>2]|0;
  $106 = HEAP32[$104>>2]|0;
  HEAP32[$103>>2] = $106;
  HEAP32[$104>>2] = $105;
  $107 = HEAP32[$$pre$phi27Z2D>>2]|0;
  HEAP32[$1>>2] = $107;
  STACKTOP = sp;return;
 }
 $$pre$i = HEAP32[$8>>2]|0;
 $$012$i = $7;$12 = $$pre$i;
 L5: while(1) {
  $11 = ((($12)) + -12|0);
  $13 = ((($$012$i)) + -12|0);
  $14 = ((($12)) + -8|0);
  HEAP32[$14>>2] = 0;
  $15 = ((($12)) + -4|0);
  HEAP32[$15>>2] = 0;
  $16 = ((($12)) + -8|0);
  HEAP32[$11>>2] = $16;
  $17 = HEAP32[$13>>2]|0;
  $18 = ((($$012$i)) + -8|0);
  $19 = ($17|0)==($18|0);
  if (!($19)) {
   $20 = $16;
   $$sroa$07$0$i$i$i = $17;
   while(1) {
    $21 = ((($$sroa$07$0$i$i$i)) + 16|0);
    HEAP32[$4>>2] = $20;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy>>2]=HEAP32[$4>>2]|0;
    $22 = (invoke_iiiiii(3556,($11|0),($$byval_copy|0),($2|0),($3|0),($21|0))|0);
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if ($24) {
     label = 26;
     break L5;
    }
    $25 = HEAP32[$22>>2]|0;
    $26 = ($25|0)==(0|0);
    if ($26) {
     __THREW__ = 0;
     $27 = (invoke_ii(3276,52)|0);
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      label = 26;
      break L5;
     }
     $30 = ((($27)) + 16|0);
     $31 = $21;
     $32 = $31;
     $33 = HEAP32[$32>>2]|0;
     $34 = (($31) + 4)|0;
     $35 = $34;
     $36 = HEAP32[$35>>2]|0;
     $37 = $30;
     $38 = $37;
     HEAP32[$38>>2] = $33;
     $39 = (($37) + 4)|0;
     $40 = $39;
     HEAP32[$40>>2] = $36;
     $41 = ((($27)) + 24|0);
     $42 = ((($$sroa$07$0$i$i$i)) + 24|0);
     ;HEAP32[$41>>2]=HEAP32[$42>>2]|0;HEAP32[$41+4>>2]=HEAP32[$42+4>>2]|0;HEAP32[$41+8>>2]=HEAP32[$42+8>>2]|0;
     $43 = ((($27)) + 36|0);
     $44 = ((($$sroa$07$0$i$i$i)) + 36|0);
     $45 = HEAP32[$44>>2]|0;
     HEAP32[$43>>2] = $45;
     $46 = ($45|0)==(0|0);
     if (!($46)) {
      $47 = ((($45)) + 8|0);
      $48 = HEAP32[$47>>2]|0;HEAP32[$47>>2] = (($48+1)|0);
     }
     $49 = ((($27)) + 40|0);
     $50 = ((($$sroa$07$0$i$i$i)) + 40|0);
     __THREW__ = 0;
     invoke_vii(3557,($49|0),($50|0));
     $51 = __THREW__; __THREW__ = 0;
     $52 = $51&1;
     if ($52) {
      label = 12;
      break L5;
     }
     $64 = HEAP32[$2>>2]|0;
     HEAP32[$27>>2] = 0;
     $65 = ((($27)) + 4|0);
     HEAP32[$65>>2] = 0;
     $66 = ((($27)) + 8|0);
     HEAP32[$66>>2] = $64;
     HEAP32[$22>>2] = $27;
     $67 = HEAP32[$11>>2]|0;
     $68 = HEAP32[$67>>2]|0;
     $69 = ($68|0)==(0|0);
     if ($69) {
      $72 = $27;
     } else {
      $70 = $68;
      HEAP32[$11>>2] = $70;
      $$pre$i$i$i$i$i$i$i$i = HEAP32[$22>>2]|0;
      $72 = $$pre$i$i$i$i$i$i$i$i;
     }
     $71 = HEAP32[$14>>2]|0;
     __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($71,$72);
     $73 = HEAP32[$15>>2]|0;
     $74 = (($73) + 1)|0;
     HEAP32[$15>>2] = $74;
    }
    $75 = ((($$sroa$07$0$i$i$i)) + 4|0);
    $76 = HEAP32[$75>>2]|0;
    $77 = ($76|0)==(0|0);
    if ($77) {
     $78 = ((($$sroa$07$0$i$i$i)) + 8|0);
     $79 = HEAP32[$78>>2]|0;
     $80 = HEAP32[$79>>2]|0;
     $81 = ($80|0)==($$sroa$07$0$i$i$i|0);
     if ($81) {
      $$0$i$i$i$i$i$i$i = $79;
     } else {
      $85 = $78;
      while(1) {
       $84 = HEAP32[$85>>2]|0;
       $86 = ((($84)) + 8|0);
       $87 = HEAP32[$86>>2]|0;
       $88 = HEAP32[$87>>2]|0;
       $89 = ($88|0)==($84|0);
       if ($89) {
        $$0$i$i$i$i$i$i$i = $87;
        break;
       } else {
        $85 = $86;
       }
      }
     }
    } else {
     $$0$i$i$i$i$i$i$i$i = $76;
     while(1) {
      $82 = HEAP32[$$0$i$i$i$i$i$i$i$i>>2]|0;
      $83 = ($82|0)==(0|0);
      if ($83) {
       break;
      } else {
       $$0$i$i$i$i$i$i$i$i = $82;
      }
     }
     $$0$i$i$i$i$i$i$i = $$0$i$i$i$i$i$i$i$i;
    }
    $90 = ($$0$i$i$i$i$i$i$i|0)==($18|0);
    if ($90) {
     break;
    } else {
     $$sroa$07$0$i$i$i = $$0$i$i$i$i$i$i$i;
    }
   }
  }
  $94 = HEAP32[$8>>2]|0;
  $95 = ((($94)) + -12|0);
  HEAP32[$8>>2] = $95;
  $96 = ($13|0)==($5|0);
  if ($96) {
   label = 29;
   break;
  } else {
   $$012$i = $13;$12 = $95;
  }
 }
 if ((label|0) == 12) {
  $53 = ___cxa_find_matching_catch_2()|0;
  $54 = tempRet0;
  $55 = HEAP32[$43>>2]|0;
  $56 = ($55|0)==(0|0);
  if (!($56)) {
   $57 = ((($55)) + 8|0);
   $58 = HEAP32[$57>>2]|0;HEAP32[$57>>2] = (($58-1)|0);
   $59 = ($58|0)==(1);
   if ($59) {
    __THREW__ = 0;
    invoke_viii(3262,($55|0),1,1);
    $60 = __THREW__; __THREW__ = 0;
    $61 = $60&1;
    if ($61) {
     $62 = ___cxa_find_matching_catch_3(0|0)|0;
     $63 = tempRet0;
     ___clang_call_terminate($62);
     // unreachable;
    }
   }
  }
  __ZdlPv($27);
  $eh$lpad$body$i$i$i$index2Z2D = $54;$eh$lpad$body$i$i$i$indexZ2D = $53;
  $93 = HEAP32[$16>>2]|0;
  __ZNSt3__26__treeINS_12__value_typeINS_4pairIN3osg14StateAttribute4TypeEjEENS3_5State14AttributeStackEEENS_19__map_value_compareIS6_S9_NS_4lessIS6_EELb1EEENS_9allocatorIS9_EEE7destroyEPNS_11__tree_nodeIS9_PvEE($11,$93);
  ___resumeException($eh$lpad$body$i$i$i$indexZ2D|0);
  // unreachable;
 }
 else if ((label|0) == 26) {
  $91 = ___cxa_find_matching_catch_2()|0;
  $92 = tempRet0;
  $eh$lpad$body$i$i$i$index2Z2D = $92;$eh$lpad$body$i$i$i$indexZ2D = $91;
  $93 = HEAP32[$16>>2]|0;
  __ZNSt3__26__treeINS_12__value_typeINS_4pairIN3osg14StateAttribute4TypeEjEENS3_5State14AttributeStackEEENS_19__map_value_compareIS6_S9_NS_4lessIS6_EELb1EEENS_9allocatorIS9_EEE7destroyEPNS_11__tree_nodeIS9_PvEE($11,$93);
  ___resumeException($eh$lpad$body$i$i$i$indexZ2D|0);
  // unreachable;
 }
 else if ((label|0) == 29) {
  $97 = $95;
  $$pre = HEAP32[$0>>2]|0;
  $$pre$phi27Z2D = $8;$$pre$phiZ2D = $0;$98 = $97;$99 = $$pre;
  HEAP32[$$pre$phiZ2D>>2] = $98;
  HEAP32[$$pre$phi27Z2D>>2] = $99;
  $100 = ((($1)) + 8|0);
  $101 = HEAP32[$6>>2]|0;
  $102 = HEAP32[$100>>2]|0;
  HEAP32[$6>>2] = $102;
  HEAP32[$100>>2] = $101;
  $103 = ((($0)) + 8|0);
  $104 = ((($1)) + 12|0);
  $105 = HEAP32[$103>>2]|0;
  $106 = HEAP32[$104>>2]|0;
  HEAP32[$103>>2] = $106;
  HEAP32[$104>>2] = $105;
  $107 = HEAP32[$$pre$phi27Z2D>>2]|0;
  HEAP32[$1>>2] = $107;
  STACKTOP = sp;return;
 }
}
function __ZNSt3__26__treeINS_12__value_typeINS_4pairIN3osg14StateAttribute4TypeEjEENS3_5State14AttributeStackEEENS_19__map_value_compareIS6_S9_NS_4lessIS6_EELb1EEENS_9allocatorIS9_EEE12__find_equalIS6_EERPNS_16__tree_node_baseIPvEENS_21__tree_const_iteratorIS9_PNS_11__tree_nodeIS9_SJ_EEiEERPNS_15__tree_end_nodeISL_EESM_RKT_($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0$i = 0, $$0$i$i = 0, $$0$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i$i = 0, $$0$i26 = 0, $$0$ph$i = 0, $$0$ph$i23 = 0, $$024$i = 0, $$024$i25 = 0, $$08$i$i = 0, $$2 = 0, $$in$i = 0, $$in$i22 = 0, $$pre = 0, $$sroa$050$0 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = ((($0)) + 4|0);
 $6 = HEAP32[$1>>2]|0;
 $7 = ($6|0)==($5|0);
 $8 = $6;
 do {
  if (!($7)) {
   $9 = HEAP32[$4>>2]|0;
   $10 = ((($6)) + 16|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = ($9|0)<($11|0);
   if (!($12)) {
    $13 = ($11|0)<($9|0);
    if (!($13)) {
     $14 = ((($4)) + 4|0);
     $15 = HEAP32[$14>>2]|0;
     $16 = ((($6)) + 20|0);
     $17 = HEAP32[$16>>2]|0;
     $18 = ($15>>>0)<($17>>>0);
     if ($18) {
      break;
     }
     $61 = ((($6)) + 20|0);
     $62 = HEAP32[$61>>2]|0;
     $63 = ((($4)) + 4|0);
     $64 = HEAP32[$63>>2]|0;
     $65 = ($62>>>0)<($64>>>0);
     if (!($65)) {
      HEAP32[$2>>2] = $8;
      HEAP32[$3>>2] = $8;
      $$2 = $3;
      return ($$2|0);
     }
    }
    $66 = ((($6)) + 4|0);
    $67 = HEAP32[$66>>2]|0;
    $68 = ($67|0)==(0|0);
    if ($68) {
     $69 = ((($6)) + 8|0);
     $70 = HEAP32[$69>>2]|0;
     $71 = HEAP32[$70>>2]|0;
     $72 = ($71|0)==($6|0);
     if ($72) {
      $$0$i$i$i$i$i = $70;
     } else {
      $76 = $69;
      while(1) {
       $75 = HEAP32[$76>>2]|0;
       $77 = ((($75)) + 8|0);
       $78 = HEAP32[$77>>2]|0;
       $79 = HEAP32[$78>>2]|0;
       $80 = ($79|0)==($75|0);
       if ($80) {
        $$0$i$i$i$i$i = $78;
        break;
       } else {
        $76 = $77;
       }
      }
     }
    } else {
     $$0$i$i$i$i$i$i = $67;
     while(1) {
      $73 = HEAP32[$$0$i$i$i$i$i$i>>2]|0;
      $74 = ($73|0)==(0|0);
      if ($74) {
       break;
      } else {
       $$0$i$i$i$i$i$i = $73;
      }
     }
     $$0$i$i$i$i$i = $$0$i$i$i$i$i$i;
    }
    $81 = ($$0$i$i$i$i$i|0)==($5|0);
    do {
     if (!($81)) {
      $82 = ((($$0$i$i$i$i$i)) + 16|0);
      $83 = HEAP32[$82>>2]|0;
      $84 = ($9|0)<($83|0);
      if (!($84)) {
       $85 = ($83|0)<($9|0);
       if (!($85)) {
        $86 = ((($4)) + 4|0);
        $87 = HEAP32[$86>>2]|0;
        $88 = ((($$0$i$i$i$i$i)) + 20|0);
        $89 = HEAP32[$88>>2]|0;
        $90 = ($87>>>0)<($89>>>0);
        if ($90) {
         break;
        }
       }
       $94 = HEAP32[$5>>2]|0;
       $95 = ($94|0)==(0|0);
       if ($95) {
        HEAP32[$2>>2] = $5;
        $$2 = $5;
        return ($$2|0);
       }
       $96 = ((($0)) + 4|0);
       $97 = ((($4)) + 4|0);
       $98 = HEAP32[$97>>2]|0;
       $$0$i = $96;$$024$i = $94;
       L28: while(1) {
        $99 = ((($$024$i)) + 16|0);
        $100 = HEAP32[$99>>2]|0;
        $101 = ($9|0)<($100|0);
        do {
         if ($101) {
          label = 47;
         } else {
          $102 = ($100|0)<($9|0);
          if (!($102)) {
           $103 = ((($$024$i)) + 20|0);
           $104 = HEAP32[$103>>2]|0;
           $105 = ($98>>>0)<($104>>>0);
           if ($105) {
            label = 47;
            break;
           }
           $108 = ($104>>>0)<($98>>>0);
           if (!($108)) {
            label = 52;
            break L28;
           }
          }
          $109 = ((($$024$i)) + 4|0);
          $110 = HEAP32[$109>>2]|0;
          $111 = ($110|0)==(0|0);
          if ($111) {
           label = 51;
           break L28;
          } else {
           $$0$ph$i = $109;$$in$i = $110;
          }
         }
        } while(0);
        if ((label|0) == 47) {
         label = 0;
         $106 = HEAP32[$$024$i>>2]|0;
         $107 = ($106|0)==(0|0);
         if ($107) {
          label = 48;
          break;
         } else {
          $$0$ph$i = $$024$i;$$in$i = $106;
         }
        }
        $$0$i = $$0$ph$i;$$024$i = $$in$i;
       }
       if ((label|0) == 48) {
        HEAP32[$2>>2] = $$024$i;
        $$2 = $$024$i;
        return ($$2|0);
       }
       else if ((label|0) == 51) {
        HEAP32[$2>>2] = $$024$i;
        $$2 = $109;
        return ($$2|0);
       }
       else if ((label|0) == 52) {
        HEAP32[$2>>2] = $$024$i;
        $$2 = $$0$i;
        return ($$2|0);
       }
      }
     }
    } while(0);
    $91 = ((($6)) + 4|0);
    $92 = HEAP32[$91>>2]|0;
    $93 = ($92|0)==(0|0);
    if ($93) {
     HEAP32[$2>>2] = $8;
     $$2 = $66;
     return ($$2|0);
    } else {
     HEAP32[$2>>2] = $$0$i$i$i$i$i;
     $$2 = $$0$i$i$i$i$i;
     return ($$2|0);
    }
   }
  }
 } while(0);
 $19 = HEAP32[$0>>2]|0;
 $20 = ($6|0)==($19|0);
 $$pre = HEAP32[$6>>2]|0;
 do {
  if ($20) {
   $$sroa$050$0 = $8;
  } else {
   $21 = ($$pre|0)==(0|0);
   if ($21) {
    $$0$i$i = $6;
    while(1) {
     $25 = ((($$0$i$i)) + 8|0);
     $26 = HEAP32[$25>>2]|0;
     $27 = HEAP32[$26>>2]|0;
     $28 = ($27|0)==($$0$i$i|0);
     if ($28) {
      $$0$i$i = $26;
     } else {
      $$08$i$i = $26;
      break;
     }
    }
   } else {
    $$0$i$i$i = $$pre;
    while(1) {
     $22 = ((($$0$i$i$i)) + 4|0);
     $23 = HEAP32[$22>>2]|0;
     $24 = ($23|0)==(0|0);
     if ($24) {
      $$08$i$i = $$0$i$i$i;
      break;
     } else {
      $$0$i$i$i = $23;
     }
    }
   }
   $29 = $$08$i$i;
   $30 = ((($$08$i$i)) + 16|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = HEAP32[$4>>2]|0;
   $33 = ($31|0)<($32|0);
   if ($33) {
    $$sroa$050$0 = $29;
   } else {
    $34 = ($32|0)<($31|0);
    if (!($34)) {
     $35 = ((($$08$i$i)) + 20|0);
     $36 = HEAP32[$35>>2]|0;
     $37 = ((($4)) + 4|0);
     $38 = HEAP32[$37>>2]|0;
     $39 = ($36>>>0)<($38>>>0);
     if ($39) {
      $$sroa$050$0 = $29;
      break;
     }
    }
    $43 = HEAP32[$5>>2]|0;
    $44 = ($43|0)==(0|0);
    if ($44) {
     HEAP32[$2>>2] = $5;
     $$2 = $5;
     return ($$2|0);
    }
    $45 = ((($0)) + 4|0);
    $46 = ((($4)) + 4|0);
    $47 = HEAP32[$46>>2]|0;
    $$0$i26 = $45;$$024$i25 = $43;
    L69: while(1) {
     $48 = ((($$024$i25)) + 16|0);
     $49 = HEAP32[$48>>2]|0;
     $50 = ($32|0)<($49|0);
     do {
      if ($50) {
       label = 21;
      } else {
       $51 = ($49|0)<($32|0);
       if (!($51)) {
        $52 = ((($$024$i25)) + 20|0);
        $53 = HEAP32[$52>>2]|0;
        $54 = ($47>>>0)<($53>>>0);
        if ($54) {
         label = 21;
         break;
        }
        $57 = ($53>>>0)<($47>>>0);
        if (!($57)) {
         label = 26;
         break L69;
        }
       }
       $58 = ((($$024$i25)) + 4|0);
       $59 = HEAP32[$58>>2]|0;
       $60 = ($59|0)==(0|0);
       if ($60) {
        label = 25;
        break L69;
       } else {
        $$0$ph$i23 = $58;$$in$i22 = $59;
       }
      }
     } while(0);
     if ((label|0) == 21) {
      label = 0;
      $55 = HEAP32[$$024$i25>>2]|0;
      $56 = ($55|0)==(0|0);
      if ($56) {
       label = 22;
       break;
      } else {
       $$0$ph$i23 = $$024$i25;$$in$i22 = $55;
      }
     }
     $$0$i26 = $$0$ph$i23;$$024$i25 = $$in$i22;
    }
    if ((label|0) == 22) {
     HEAP32[$2>>2] = $$024$i25;
     $$2 = $$024$i25;
     return ($$2|0);
    }
    else if ((label|0) == 25) {
     HEAP32[$2>>2] = $$024$i25;
     $$2 = $58;
     return ($$2|0);
    }
    else if ((label|0) == 26) {
     HEAP32[$2>>2] = $$024$i25;
     $$2 = $$0$i26;
     return ($$2|0);
    }
   }
  }
 } while(0);
 $40 = ($$pre|0)==(0|0);
 if ($40) {
  HEAP32[$2>>2] = $6;
  $$2 = $6;
  return ($$2|0);
 } else {
  $41 = $$sroa$050$0;
  HEAP32[$2>>2] = $41;
  $42 = ((($41)) + 4|0);
  $$2 = $42;
  return ($$2|0);
 }
 return (0)|0;
}
function __ZNSt3__26vectorINS_4pairIPKN3osg14StateAttributeEjEENS_9allocatorIS6_EEEC2ERKS9_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i = 0, $scevgep5$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = 0;
 $2 = ((($0)) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = ((($0)) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$1>>2]|0;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 3;
 $9 = ($8|0)==(0);
 if ($9) {
  return;
 }
 $10 = ($8>>>0)>(536870911);
 if ($10) {
  __THREW__ = 0;
  invoke_vi(3307,($0|0));
  $11 = __THREW__; __THREW__ = 0;
 } else {
  __THREW__ = 0;
  $12 = (invoke_ii(3276,($7|0))|0);
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if (!($14)) {
   HEAP32[$2>>2] = $12;
   HEAP32[$0>>2] = $12;
   $15 = (($12) + ($8<<3)|0);
   $16 = ((($0)) + 8|0);
   HEAP32[$16>>2] = $15;
   $17 = HEAP32[$1>>2]|0;
   $18 = HEAP32[$4>>2]|0;
   $19 = $17;
   $20 = (($18) - ($19))|0;
   $21 = ($20|0)>(0);
   if (!($21)) {
    return;
   }
   $22 = $20 >>> 3;
   _memcpy(($12|0),($17|0),($20|0))|0;
   $23 = (($12) + ($22<<3)|0);
   HEAP32[$2>>2] = $23;
   return;
  }
 }
 $24 = ___cxa_find_matching_catch_2()|0;
 $25 = tempRet0;
 $26 = HEAP32[$0>>2]|0;
 $27 = ($26|0)==(0|0);
 if ($27) {
  ___resumeException($24|0);
  // unreachable;
 }
 $28 = HEAP32[$2>>2]|0;
 $29 = ($28|0)==($26|0);
 if (!($29)) {
  $scevgep$i$i$i = ((($28)) + -8|0);
  $30 = $scevgep$i$i$i;
  $31 = $26;
  $32 = (($30) - ($31))|0;
  $33 = $32 >>> 3;
  $34 = $33 ^ -1;
  $scevgep5$i$i$i = (($28) + ($34<<3)|0);
  HEAP32[$2>>2] = $scevgep5$i$i$i;
 }
 __ZdlPv($26);
 ___resumeException($24|0);
 // unreachable;
}
function __ZNSt3__26vectorINS_3mapIjN3osg5State9ModeStackENS_4lessIjEENS_9allocatorINS_4pairIKjS4_EEEEEENS7_ISC_EEE8__appendEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i = 0, $$0$i13 = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $9 = 0, $scevgep = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $2 = sp;
 $3 = ((($0)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) - ($6))|0;
 $8 = (($7|0) / 12)&-1;
 $9 = ($8>>>0)<($1>>>0);
 if (!($9)) {
  $10 = $6;
  $$0$i = $1;$12 = $10;
  while(1) {
   $11 = ((($12)) + 4|0);
   HEAP32[$11>>2] = 0;
   $13 = ((($12)) + 8|0);
   HEAP32[$13>>2] = 0;
   $14 = ((($12)) + 4|0);
   HEAP32[$12>>2] = $14;
   $15 = HEAP32[$5>>2]|0;
   $16 = ((($15)) + 12|0);
   HEAP32[$5>>2] = $16;
   $17 = (($$0$i) + -1)|0;
   $18 = ($17|0)==(0);
   if ($18) {
    break;
   } else {
    $$0$i = $17;$12 = $16;
   }
  }
  STACKTOP = sp;return;
 }
 $19 = HEAP32[$0>>2]|0;
 $20 = (($6) - ($19))|0;
 $21 = (($20|0) / 12)&-1;
 $22 = (($21) + ($1))|0;
 $23 = ($22>>>0)>(357913941);
 if ($23) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $24 = ((($0)) + 8|0);
 $25 = (($4) - ($19))|0;
 $26 = (($25|0) / 12)&-1;
 $27 = ($26>>>0)<(178956970);
 $28 = $26 << 1;
 $29 = ($28>>>0)<($22>>>0);
 $$sroa$speculated$i = $29 ? $22 : $28;
 $$sroa$speculated$$i = $27 ? $$sroa$speculated$i : 357913941;
 $30 = ((($2)) + 12|0);
 HEAP32[$30>>2] = 0;
 $31 = ((($2)) + 16|0);
 HEAP32[$31>>2] = $24;
 $32 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($32) {
   $41 = 0;
  } else {
   $33 = ($$sroa$speculated$$i>>>0)>(357913941);
   if (!($33)) {
    $39 = ($$sroa$speculated$$i*12)|0;
    $40 = (__Znwj($39)|0);
    $41 = $40;
    break;
   }
   $34 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($34|0),(204840|0));
   $35 = __THREW__; __THREW__ = 0;
   $36 = $35&1;
   if ($36) {
    $37 = ___cxa_find_matching_catch_2()|0;
    $38 = tempRet0;
    ___cxa_free_exception(($34|0));
    ___resumeException($37|0);
    // unreachable;
   } else {
    HEAP32[$34>>2] = (99824);
    ___cxa_throw(($34|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 HEAP32[$2>>2] = $41;
 $42 = (($41) + (($21*12)|0)|0);
 $43 = ((($2)) + 8|0);
 HEAP32[$43>>2] = $42;
 $44 = ((($2)) + 4|0);
 HEAP32[$44>>2] = $42;
 $45 = (($41) + (($$sroa$speculated$$i*12)|0)|0);
 $46 = ((($2)) + 12|0);
 HEAP32[$46>>2] = $45;
 $$0$i13 = $1;$48 = $42;
 while(1) {
  $47 = ((($48)) + 4|0);
  HEAP32[$47>>2] = 0;
  $49 = ((($48)) + 8|0);
  HEAP32[$49>>2] = 0;
  $50 = ((($48)) + 4|0);
  HEAP32[$48>>2] = $50;
  $51 = ((($48)) + 12|0);
  $52 = (($$0$i13) + -1)|0;
  $53 = ($52|0)==(0);
  if ($53) {
   break;
  } else {
   $$0$i13 = $52;$48 = $51;
  }
 }
 $scevgep = (($41) + (($22*12)|0)|0);
 HEAP32[$43>>2] = $scevgep;
 __THREW__ = 0;
 invoke_vii(3558,($0|0),($2|0));
 $54 = __THREW__; __THREW__ = 0;
 $55 = $54&1;
 if ($55) {
  $67 = ___cxa_find_matching_catch_2()|0;
  $68 = tempRet0;
  $69 = HEAP32[$44>>2]|0;
  $70 = HEAP32[$43>>2]|0;
  $71 = ($70|0)==($69|0);
  if (!($71)) {
   $73 = $70;
   while(1) {
    $72 = ((($73)) + -12|0);
    HEAP32[$43>>2] = $72;
    $74 = ((($73)) + -8|0);
    $75 = HEAP32[$74>>2]|0;
    __ZNSt3__26__treeINS_12__value_typeIjN3osg5State9ModeStackEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($72,$75);
    $76 = HEAP32[$43>>2]|0;
    $77 = ($76|0)==($69|0);
    if ($77) {
     break;
    } else {
     $73 = $76;
    }
   }
  }
  $78 = HEAP32[$2>>2]|0;
  $79 = ($78|0)==(0|0);
  if ($79) {
   ___resumeException($67|0);
   // unreachable;
  }
  __ZdlPv($78);
  ___resumeException($67|0);
  // unreachable;
 } else {
  $56 = HEAP32[$44>>2]|0;
  $57 = HEAP32[$43>>2]|0;
  $58 = ($57|0)==($56|0);
  if (!($58)) {
   $60 = $57;
   while(1) {
    $59 = ((($60)) + -12|0);
    HEAP32[$43>>2] = $59;
    $61 = ((($60)) + -8|0);
    $62 = HEAP32[$61>>2]|0;
    __ZNSt3__26__treeINS_12__value_typeIjN3osg5State9ModeStackEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($59,$62);
    $63 = HEAP32[$43>>2]|0;
    $64 = ($63|0)==($56|0);
    if ($64) {
     break;
    } else {
     $60 = $63;
    }
   }
  }
  $65 = HEAP32[$2>>2]|0;
  $66 = ($65|0)==(0|0);
  if (!($66)) {
   __ZdlPv($65);
  }
  STACKTOP = sp;return;
 }
}
function __ZNSt3__26__treeINS_12__value_typeIjN3osg5State9ModeStackEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 }
 $3 = HEAP32[$1>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIjN3osg5State9ModeStackEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($0,$3);
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIjN3osg5State9ModeStackEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($0,$5);
 $6 = ((($1)) + 24|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = ((($1)) + 28|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10|0)==($7|0);
  if (!($11)) {
   $scevgep$i$i$i$i$i$i$i = ((($10)) + -4|0);
   $12 = $scevgep$i$i$i$i$i$i$i;
   $13 = $7;
   $14 = (($12) - ($13))|0;
   $15 = $14 >>> 2;
   $16 = $15 ^ -1;
   $scevgep5$i$i$i$i$i$i$i = (($10) + ($16<<2)|0);
   HEAP32[$9>>2] = $scevgep5$i$i$i$i$i$i$i;
  }
  __ZdlPv($7);
 }
 __ZdlPv($1);
 return;
}
function __ZNSt3__26vectorINS_3mapIjN3osg5State9ModeStackENS_4lessIjEENS_9allocatorINS_4pairIKjS4_EEEEEENS7_ISC_EEE26__swap_out_circular_bufferERNS_14__split_bufferISC_RSD_EE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i$i$i$i$i$i = 0, $$0$i$i$i$i$i$i$i$i = 0, $$011$i = 0, $$byval_copy = 0, $$in10$i$i$i$i = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i$i$i$i$i$i$i = 0, $$pre$phi25Z2D = 0, $$pre$phiZ2D = 0, $$pre22 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $9 = 0, $eh$lpad$body$i$i$i$index2Z2D = 0, $eh$lpad$body$i$i$i$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy = sp + 12|0;
 $2 = sp + 8|0;
 $3 = sp + 4|0;
 $4 = sp;
 $5 = HEAP32[$0>>2]|0;
 $6 = ((($0)) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($1)) + 4|0);
 $9 = ($7|0)==($5|0);
 if ($9) {
  $10 = $5;
  $$pre22 = HEAP32[$8>>2]|0;
  $$pre$phi25Z2D = $8;$$pre$phiZ2D = $0;$75 = $$pre22;$76 = $10;
  HEAP32[$$pre$phiZ2D>>2] = $75;
  HEAP32[$$pre$phi25Z2D>>2] = $76;
  $77 = ((($1)) + 8|0);
  $78 = HEAP32[$6>>2]|0;
  $79 = HEAP32[$77>>2]|0;
  HEAP32[$6>>2] = $79;
  HEAP32[$77>>2] = $78;
  $80 = ((($0)) + 8|0);
  $81 = ((($1)) + 12|0);
  $82 = HEAP32[$80>>2]|0;
  $83 = HEAP32[$81>>2]|0;
  HEAP32[$80>>2] = $83;
  HEAP32[$81>>2] = $82;
  $84 = HEAP32[$$pre$phi25Z2D>>2]|0;
  HEAP32[$1>>2] = $84;
  STACKTOP = sp;return;
 }
 $$pre$i = HEAP32[$8>>2]|0;
 $$011$i = $7;$12 = $$pre$i;
 L5: while(1) {
  $11 = ((($12)) + -12|0);
  $13 = ((($$011$i)) + -12|0);
  $14 = ((($12)) + -8|0);
  HEAP32[$14>>2] = 0;
  $15 = ((($12)) + -4|0);
  HEAP32[$15>>2] = 0;
  $16 = ((($12)) + -8|0);
  HEAP32[$11>>2] = $16;
  $17 = HEAP32[$13>>2]|0;
  $18 = ((($$011$i)) + -8|0);
  $19 = ($17|0)==($18|0);
  if (!($19)) {
   $20 = $16;
   $$in10$i$i$i$i = $17;
   while(1) {
    $21 = ((($$in10$i$i$i$i)) + 16|0);
    HEAP32[$4>>2] = $20;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy>>2]=HEAP32[$4>>2]|0;
    $22 = (invoke_iiiiii(3559,($11|0),($$byval_copy|0),($2|0),($3|0),($21|0))|0);
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if ($24) {
     label = 20;
     break L5;
    }
    $25 = HEAP32[$22>>2]|0;
    $26 = ($25|0)==(0|0);
    if ($26) {
     __THREW__ = 0;
     $27 = (invoke_ii(3276,36)|0);
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      label = 20;
      break L5;
     }
     $30 = ((($27)) + 16|0);
     $31 = HEAP32[$21>>2]|0;
     HEAP32[$30>>2] = $31;
     $32 = ((($27)) + 20|0);
     $33 = ((($$in10$i$i$i$i)) + 20|0);
     $34 = HEAP32[$33>>2]|0;
     HEAP32[$32>>2] = $34;
     $35 = ((($27)) + 24|0);
     $36 = ((($$in10$i$i$i$i)) + 24|0);
     __THREW__ = 0;
     invoke_vii(3317,($35|0),($36|0));
     $37 = __THREW__; __THREW__ = 0;
     $38 = $37&1;
     if ($38) {
      label = 10;
      break L5;
     }
     $41 = HEAP32[$2>>2]|0;
     HEAP32[$27>>2] = 0;
     $42 = ((($27)) + 4|0);
     HEAP32[$42>>2] = 0;
     $43 = ((($27)) + 8|0);
     HEAP32[$43>>2] = $41;
     HEAP32[$22>>2] = $27;
     $44 = HEAP32[$11>>2]|0;
     $45 = HEAP32[$44>>2]|0;
     $46 = ($45|0)==(0|0);
     if ($46) {
      $49 = $27;
     } else {
      $47 = $45;
      HEAP32[$11>>2] = $47;
      $$pre$i$i$i$i$i$i$i$i = HEAP32[$22>>2]|0;
      $49 = $$pre$i$i$i$i$i$i$i$i;
     }
     $48 = HEAP32[$14>>2]|0;
     __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($48,$49);
     $50 = HEAP32[$15>>2]|0;
     $51 = (($50) + 1)|0;
     HEAP32[$15>>2] = $51;
    }
    $52 = ((($$in10$i$i$i$i)) + 4|0);
    $53 = HEAP32[$52>>2]|0;
    $54 = ($53|0)==(0|0);
    if ($54) {
     $55 = ((($$in10$i$i$i$i)) + 8|0);
     $56 = HEAP32[$55>>2]|0;
     $57 = HEAP32[$56>>2]|0;
     $58 = ($57|0)==($$in10$i$i$i$i|0);
     if ($58) {
      $$0$i$i$i$i$i$i$i = $56;
     } else {
      $62 = $55;
      while(1) {
       $61 = HEAP32[$62>>2]|0;
       $63 = ((($61)) + 8|0);
       $64 = HEAP32[$63>>2]|0;
       $65 = HEAP32[$64>>2]|0;
       $66 = ($65|0)==($61|0);
       if ($66) {
        $$0$i$i$i$i$i$i$i = $64;
        break;
       } else {
        $62 = $63;
       }
      }
     }
    } else {
     $$0$i$i$i$i$i$i$i$i = $53;
     while(1) {
      $59 = HEAP32[$$0$i$i$i$i$i$i$i$i>>2]|0;
      $60 = ($59|0)==(0|0);
      if ($60) {
       break;
      } else {
       $$0$i$i$i$i$i$i$i$i = $59;
      }
     }
     $$0$i$i$i$i$i$i$i = $$0$i$i$i$i$i$i$i$i;
    }
    $67 = ($$0$i$i$i$i$i$i$i|0)==($18|0);
    if ($67) {
     break;
    } else {
     $$in10$i$i$i$i = $$0$i$i$i$i$i$i$i;
    }
   }
  }
  $71 = HEAP32[$8>>2]|0;
  $72 = ((($71)) + -12|0);
  HEAP32[$8>>2] = $72;
  $73 = ($13|0)==($5|0);
  if ($73) {
   label = 23;
   break;
  } else {
   $$011$i = $13;$12 = $72;
  }
 }
 if ((label|0) == 10) {
  $39 = ___cxa_find_matching_catch_2()|0;
  $40 = tempRet0;
  __ZdlPv($27);
  $eh$lpad$body$i$i$i$index2Z2D = $40;$eh$lpad$body$i$i$i$indexZ2D = $39;
  $70 = HEAP32[$16>>2]|0;
  __ZNSt3__26__treeINS_12__value_typeIjN3osg5State9ModeStackEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($11,$70);
  ___resumeException($eh$lpad$body$i$i$i$indexZ2D|0);
  // unreachable;
 }
 else if ((label|0) == 20) {
  $68 = ___cxa_find_matching_catch_2()|0;
  $69 = tempRet0;
  $eh$lpad$body$i$i$i$index2Z2D = $69;$eh$lpad$body$i$i$i$indexZ2D = $68;
  $70 = HEAP32[$16>>2]|0;
  __ZNSt3__26__treeINS_12__value_typeIjN3osg5State9ModeStackEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($11,$70);
  ___resumeException($eh$lpad$body$i$i$i$indexZ2D|0);
  // unreachable;
 }
 else if ((label|0) == 23) {
  $74 = $72;
  $$pre = HEAP32[$0>>2]|0;
  $$pre$phi25Z2D = $8;$$pre$phiZ2D = $0;$75 = $74;$76 = $$pre;
  HEAP32[$$pre$phiZ2D>>2] = $75;
  HEAP32[$$pre$phi25Z2D>>2] = $76;
  $77 = ((($1)) + 8|0);
  $78 = HEAP32[$6>>2]|0;
  $79 = HEAP32[$77>>2]|0;
  HEAP32[$6>>2] = $79;
  HEAP32[$77>>2] = $78;
  $80 = ((($0)) + 8|0);
  $81 = ((($1)) + 12|0);
  $82 = HEAP32[$80>>2]|0;
  $83 = HEAP32[$81>>2]|0;
  HEAP32[$80>>2] = $83;
  HEAP32[$81>>2] = $82;
  $84 = HEAP32[$$pre$phi25Z2D>>2]|0;
  HEAP32[$1>>2] = $84;
  STACKTOP = sp;return;
 }
}
function __ZNSt3__26__treeINS_12__value_typeIjN3osg5State9ModeStackEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEE12__find_equalIjEERPNS_16__tree_node_baseIPvEENS_21__tree_const_iteratorIS5_PNS_11__tree_nodeIS5_SF_EEiEERPNS_15__tree_end_nodeISH_EESI_RKT_($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0$i = 0, $$0$i$i = 0, $$0$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i$i = 0, $$0$i26 = 0, $$0$ph$i = 0, $$0$ph$i23 = 0, $$024$i = 0, $$024$i25 = 0, $$08$i$i = 0, $$2 = 0, $$in$i = 0, $$in$i22 = 0, $$pre = 0, $$sroa$043$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = ((($0)) + 4|0);
 $6 = HEAP32[$1>>2]|0;
 $7 = ($6|0)==($5|0);
 $8 = $6;
 if (!($7)) {
  $9 = ((($6)) + 16|0);
  $10 = HEAP32[$4>>2]|0;
  $11 = HEAP32[$9>>2]|0;
  $12 = ($10>>>0)<($11>>>0);
  if (!($12)) {
   $43 = ($11>>>0)<($10>>>0);
   if (!($43)) {
    HEAP32[$2>>2] = $8;
    HEAP32[$3>>2] = $8;
    $$2 = $3;
    return ($$2|0);
   }
   $44 = ((($6)) + 4|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = ($45|0)==(0|0);
   if ($46) {
    $47 = ((($6)) + 8|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = HEAP32[$48>>2]|0;
    $50 = ($49|0)==($6|0);
    if ($50) {
     $$0$i$i$i$i$i = $48;
    } else {
     $54 = $47;
     while(1) {
      $53 = HEAP32[$54>>2]|0;
      $55 = ((($53)) + 8|0);
      $56 = HEAP32[$55>>2]|0;
      $57 = HEAP32[$56>>2]|0;
      $58 = ($57|0)==($53|0);
      if ($58) {
       $$0$i$i$i$i$i = $56;
       break;
      } else {
       $54 = $55;
      }
     }
    }
   } else {
    $$0$i$i$i$i$i$i = $45;
    while(1) {
     $51 = HEAP32[$$0$i$i$i$i$i$i>>2]|0;
     $52 = ($51|0)==(0|0);
     if ($52) {
      break;
     } else {
      $$0$i$i$i$i$i$i = $51;
     }
    }
    $$0$i$i$i$i$i = $$0$i$i$i$i$i$i;
   }
   $59 = ($$0$i$i$i$i$i|0)==($5|0);
   if (!($59)) {
    $60 = ((($$0$i$i$i$i$i)) + 16|0);
    $61 = HEAP32[$60>>2]|0;
    $62 = ($10>>>0)<($61>>>0);
    if (!($62)) {
     $66 = HEAP32[$5>>2]|0;
     $67 = ($66|0)==(0|0);
     if ($67) {
      HEAP32[$2>>2] = $5;
      $$2 = $5;
      return ($$2|0);
     }
     $68 = ((($0)) + 4|0);
     $$0$i = $68;$$024$i = $66;
     while(1) {
      $69 = ((($$024$i)) + 16|0);
      $70 = HEAP32[$69>>2]|0;
      $71 = ($10>>>0)<($70>>>0);
      if ($71) {
       $72 = HEAP32[$$024$i>>2]|0;
       $73 = ($72|0)==(0|0);
       if ($73) {
        label = 39;
        break;
       } else {
        $$0$ph$i = $$024$i;$$in$i = $72;
       }
      } else {
       $74 = ($70>>>0)<($10>>>0);
       if (!($74)) {
        label = 43;
        break;
       }
       $75 = ((($$024$i)) + 4|0);
       $76 = HEAP32[$75>>2]|0;
       $77 = ($76|0)==(0|0);
       if ($77) {
        label = 42;
        break;
       } else {
        $$0$ph$i = $75;$$in$i = $76;
       }
      }
      $$0$i = $$0$ph$i;$$024$i = $$in$i;
     }
     if ((label|0) == 39) {
      HEAP32[$2>>2] = $$024$i;
      $$2 = $$024$i;
      return ($$2|0);
     }
     else if ((label|0) == 42) {
      HEAP32[$2>>2] = $$024$i;
      $$2 = $75;
      return ($$2|0);
     }
     else if ((label|0) == 43) {
      HEAP32[$2>>2] = $$024$i;
      $$2 = $$0$i;
      return ($$2|0);
     }
    }
   }
   $63 = ((($6)) + 4|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = ($64|0)==(0|0);
   if ($65) {
    HEAP32[$2>>2] = $8;
    $$2 = $44;
    return ($$2|0);
   } else {
    HEAP32[$2>>2] = $$0$i$i$i$i$i;
    $$2 = $$0$i$i$i$i$i;
    return ($$2|0);
   }
  }
 }
 $13 = HEAP32[$0>>2]|0;
 $14 = ($6|0)==($13|0);
 $$pre = HEAP32[$6>>2]|0;
 if ($14) {
  $$sroa$043$0 = $8;
 } else {
  $15 = ($$pre|0)==(0|0);
  if ($15) {
   $$0$i$i = $6;
   while(1) {
    $19 = ((($$0$i$i)) + 8|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = HEAP32[$20>>2]|0;
    $22 = ($21|0)==($$0$i$i|0);
    if ($22) {
     $$0$i$i = $20;
    } else {
     $$08$i$i = $20;
     break;
    }
   }
  } else {
   $$0$i$i$i = $$pre;
   while(1) {
    $16 = ((($$0$i$i$i)) + 4|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = ($17|0)==(0|0);
    if ($18) {
     $$08$i$i = $$0$i$i$i;
     break;
    } else {
     $$0$i$i$i = $17;
    }
   }
  }
  $23 = $$08$i$i;
  $24 = ((($$08$i$i)) + 16|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = HEAP32[$4>>2]|0;
  $27 = ($25>>>0)<($26>>>0);
  if ($27) {
   $$sroa$043$0 = $23;
  } else {
   $31 = HEAP32[$5>>2]|0;
   $32 = ($31|0)==(0|0);
   if ($32) {
    HEAP32[$2>>2] = $5;
    $$2 = $5;
    return ($$2|0);
   }
   $33 = ((($0)) + 4|0);
   $$0$i26 = $33;$$024$i25 = $31;
   while(1) {
    $34 = ((($$024$i25)) + 16|0);
    $35 = HEAP32[$34>>2]|0;
    $36 = ($26>>>0)<($35>>>0);
    if ($36) {
     $37 = HEAP32[$$024$i25>>2]|0;
     $38 = ($37|0)==(0|0);
     if ($38) {
      label = 17;
      break;
     } else {
      $$0$ph$i23 = $$024$i25;$$in$i22 = $37;
     }
    } else {
     $39 = ($35>>>0)<($26>>>0);
     if (!($39)) {
      label = 21;
      break;
     }
     $40 = ((($$024$i25)) + 4|0);
     $41 = HEAP32[$40>>2]|0;
     $42 = ($41|0)==(0|0);
     if ($42) {
      label = 20;
      break;
     } else {
      $$0$ph$i23 = $40;$$in$i22 = $41;
     }
    }
    $$0$i26 = $$0$ph$i23;$$024$i25 = $$in$i22;
   }
   if ((label|0) == 17) {
    HEAP32[$2>>2] = $$024$i25;
    $$2 = $$024$i25;
    return ($$2|0);
   }
   else if ((label|0) == 20) {
    HEAP32[$2>>2] = $$024$i25;
    $$2 = $40;
    return ($$2|0);
   }
   else if ((label|0) == 21) {
    HEAP32[$2>>2] = $$024$i25;
    $$2 = $$0$i26;
    return ($$2|0);
   }
  }
 }
 $28 = ($$pre|0)==(0|0);
 if ($28) {
  HEAP32[$2>>2] = $6;
  $$2 = $6;
  return ($$2|0);
 } else {
  $29 = $$sroa$043$0;
  HEAP32[$2>>2] = $29;
  $30 = ((($29)) + 4|0);
  $$2 = $30;
  return ($$2|0);
 }
 return (0)|0;
}
function __ZN7osgUtil27IncrementalCompileOperation16CompileProgramOpD2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (48312);
 $1 = ((($0)) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  HEAP32[$1>>2] = 0;
  __ZN3osg10ReferencedD2Ev($0);
  return;
 }
 $4 = ((($2)) + 8|0);
 $5 = HEAP32[$4>>2]|0;HEAP32[$4>>2] = (($5-1)|0);
 $6 = ($5|0)==(1);
 if (!($6)) {
  HEAP32[$1>>2] = 0;
  __ZN3osg10ReferencedD2Ev($0);
  return;
 }
 __THREW__ = 0;
 invoke_viii(3262,($2|0),1,1);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if (!($8)) {
  HEAP32[$1>>2] = 0;
  __ZN3osg10ReferencedD2Ev($0);
  return;
 }
 $9 = ___cxa_find_matching_catch_2()|0;
 $10 = tempRet0;
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if ($12) {
  $13 = ___cxa_find_matching_catch_3(0|0)|0;
  $14 = tempRet0;
  ___clang_call_terminate($13);
  // unreachable;
 } else {
  ___resumeException($9|0);
  // unreachable;
 }
}
function __ZN7osgUtil27IncrementalCompileOperation16CompileProgramOpD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (48312);
 $1 = ((($0)) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = ((($2)) + 8|0);
  $5 = HEAP32[$4>>2]|0;HEAP32[$4>>2] = (($5-1)|0);
  $6 = ($5|0)==(1);
  if ($6) {
   __THREW__ = 0;
   invoke_viii(3262,($2|0),1,1);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch_2()|0;
    $12 = tempRet0;
    __THREW__ = 0;
    invoke_vi(712,($0|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     $15 = ___cxa_find_matching_catch_3(0|0)|0;
     $16 = tempRet0;
     ___clang_call_terminate($15);
     // unreachable;
    } else {
     $eh$lpad$body$index2Z2D = $12;$eh$lpad$body$indexZ2D = $11;
     __ZdlPv($0);
     ___resumeException($eh$lpad$body$indexZ2D|0);
     // unreachable;
    }
   }
  }
 }
 HEAP32[$1>>2] = 0;
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if (!($10)) {
  __ZdlPv($0);
  return;
 }
 $17 = ___cxa_find_matching_catch_2()|0;
 $18 = tempRet0;
 $eh$lpad$body$index2Z2D = $18;$eh$lpad$body$indexZ2D = $17;
 __ZdlPv($0);
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
}
function __ZNK7osgUtil27IncrementalCompileOperation16CompileProgramOp23estimatedTimeForCompileERNS0_11CompileInfoE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0.0, $10 = 0, $11 = 0.0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = HEAP32[$1>>2]|0;
 $4 = ((($3)) + 860|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $$0 = 0.0;
  STACKTOP = sp;return (+$$0);
 }
 $7 = ((($0)) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($5)) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 __ZNK3osg20ProgramCostEstimator19estimateCompileCostEPKNS_7ProgramE($2,$10,$8);
 $11 = +HEAPF64[$2>>3];
 $$0 = $11;
 STACKTOP = sp;return (+$$0);
}
function __ZN7osgUtil27IncrementalCompileOperation16CompileProgramOp7compileERNS0_11CompileInfoE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($4)) + 176|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_vii[$6 & 8191]($3,$7);
 return 1;
}
function __GLOBAL__sub_I_IncrementalCompileOperation_cpp() {
 var $$0$i = 0, $$0$i14 = 0, $$0$i6 = 0, $$01$i = 0, $$01$i13 = 0, $$01$i5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, dest = 0, label = 0, sp = 0;
 var src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(80|0);
 $0 = sp + 60|0;
 $1 = sp + 48|0;
 $2 = sp + 36|0;
 $3 = sp + 24|0;
 $4 = sp + 12|0;
 $5 = sp;
 HEAPF32[51986] = 1.0;
 HEAPF32[(207948)>>2] = 0.0;
 HEAPF32[(207952)>>2] = 0.0;
 HEAPF32[51989] = 0.0;
 HEAPF32[(207960)>>2] = 1.0;
 HEAPF32[(207964)>>2] = 0.0;
 HEAPF32[51992] = 0.0;
 HEAPF32[(207972)>>2] = 0.0;
 HEAPF32[(207976)>>2] = 1.0;
 $6 = (__Znwj(48)|0);
 HEAP32[$2>>2] = $6;
 $7 = ((($2)) + 8|0);
 HEAP32[$7>>2] = -2147483600;
 $8 = ((($2)) + 4|0);
 HEAP32[$8>>2] = 42;
 dest=$6; src=110909; stop=dest+42|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $9 = ((($6)) + 42|0);
 HEAP8[$9>>0] = 0;
 ;HEAP32[$3>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;
 __THREW__ = 0;
 $10 = (invoke_ii(3276,96)|0);
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if ($12) {
  $29 = ___cxa_find_matching_catch_2()|0;
  $30 = tempRet0;
  $$0$i6 = $30;$$01$i5 = $29;
 } else {
  HEAP32[$3>>2] = $10;
  $13 = ((($3)) + 8|0);
  HEAP32[$13>>2] = -2147483552;
  $14 = ((($3)) + 4|0);
  HEAP32[$14>>2] = 85;
  dest=$10; src=110952; stop=dest+85|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
  $15 = ((($10)) + 85|0);
  HEAP8[$15>>0] = 0;
  __THREW__ = 0;
  $16 = (invoke_i(3459)|0);
  $17 = __THREW__; __THREW__ = 0;
  $18 = $17&1;
  if (!($18)) {
   __THREW__ = 0;
   invoke_viiii(3460,($16|0),2,($2|0),($3|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    $21 = ((($3)) + 11|0);
    $22 = HEAP8[$21>>0]|0;
    $23 = ($22<<24>>24)<(0);
    if ($23) {
     $24 = HEAP32[$3>>2]|0;
     __ZdlPv($24);
    }
    $25 = ((($2)) + 11|0);
    $26 = HEAP8[$25>>0]|0;
    $27 = ($26<<24>>24)<(0);
    if ($27) {
     $28 = HEAP32[$2>>2]|0;
     __ZdlPv($28);
    }
    $41 = (__Znwj(48)|0);
    HEAP32[$0>>2] = $41;
    $42 = ((($0)) + 8|0);
    HEAP32[$42>>2] = -2147483600;
    $43 = ((($0)) + 4|0);
    HEAP32[$43>>2] = 46;
    dest=$41; src=111038; stop=dest+46|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
    $44 = ((($41)) + 46|0);
    HEAP8[$44>>0] = 0;
    ;HEAP32[$1>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;
    __THREW__ = 0;
    $45 = (invoke_ii(3276,80)|0);
    $46 = __THREW__; __THREW__ = 0;
    $47 = $46&1;
    if ($47) {
     $64 = ___cxa_find_matching_catch_2()|0;
     $65 = tempRet0;
     $$0$i14 = $65;$$01$i13 = $64;
    } else {
     HEAP32[$1>>2] = $45;
     $48 = ((($1)) + 8|0);
     HEAP32[$48>>2] = -2147483568;
     $49 = ((($1)) + 4|0);
     HEAP32[$49>>2] = 72;
     dest=$45; src=111085; stop=dest+72|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
     $50 = ((($45)) + 72|0);
     HEAP8[$50>>0] = 0;
     __THREW__ = 0;
     $51 = (invoke_i(3459)|0);
     $52 = __THREW__; __THREW__ = 0;
     $53 = $52&1;
     if (!($53)) {
      __THREW__ = 0;
      invoke_viiii(3460,($51|0),2,($0|0),($1|0));
      $54 = __THREW__; __THREW__ = 0;
      $55 = $54&1;
      if (!($55)) {
       $56 = ((($1)) + 11|0);
       $57 = HEAP8[$56>>0]|0;
       $58 = ($57<<24>>24)<(0);
       if ($58) {
        $59 = HEAP32[$1>>2]|0;
        __ZdlPv($59);
       }
       $60 = ((($0)) + 11|0);
       $61 = HEAP8[$60>>0]|0;
       $62 = ($61<<24>>24)<(0);
       if ($62) {
        $63 = HEAP32[$0>>2]|0;
        __ZdlPv($63);
       }
       $76 = (__Znwj(48)|0);
       HEAP32[$4>>2] = $76;
       $77 = ((($4)) + 8|0);
       HEAP32[$77>>2] = -2147483600;
       $78 = ((($4)) + 4|0);
       HEAP32[$78>>2] = 35;
       dest=$76; src=111158; stop=dest+35|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
       $79 = ((($76)) + 35|0);
       HEAP8[$79>>0] = 0;
       ;HEAP32[$5>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;
       __THREW__ = 0;
       $80 = (invoke_ii(3276,80)|0);
       $81 = __THREW__; __THREW__ = 0;
       $82 = $81&1;
       if ($82) {
        $99 = ___cxa_find_matching_catch_2()|0;
        $100 = tempRet0;
        $$0$i = $100;$$01$i = $99;
       } else {
        HEAP32[$5>>2] = $80;
        $83 = ((($5)) + 8|0);
        HEAP32[$83>>2] = -2147483568;
        $84 = ((($5)) + 4|0);
        HEAP32[$84>>2] = 73;
        dest=$80; src=111194; stop=dest+73|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
        $85 = ((($80)) + 73|0);
        HEAP8[$85>>0] = 0;
        __THREW__ = 0;
        $86 = (invoke_i(3459)|0);
        $87 = __THREW__; __THREW__ = 0;
        $88 = $87&1;
        if (!($88)) {
         __THREW__ = 0;
         invoke_viiii(3460,($86|0),2,($4|0),($5|0));
         $89 = __THREW__; __THREW__ = 0;
         $90 = $89&1;
         if (!($90)) {
          $91 = ((($5)) + 11|0);
          $92 = HEAP8[$91>>0]|0;
          $93 = ($92<<24>>24)<(0);
          if ($93) {
           $94 = HEAP32[$5>>2]|0;
           __ZdlPv($94);
          }
          $95 = ((($4)) + 11|0);
          $96 = HEAP8[$95>>0]|0;
          $97 = ($96<<24>>24)<(0);
          if (!($97)) {
           STACKTOP = sp;return;
          }
          $98 = HEAP32[$4>>2]|0;
          __ZdlPv($98);
          STACKTOP = sp;return;
         }
        }
        $101 = ___cxa_find_matching_catch_2()|0;
        $102 = tempRet0;
        $103 = ((($5)) + 11|0);
        $104 = HEAP8[$103>>0]|0;
        $105 = ($104<<24>>24)<(0);
        if ($105) {
         $106 = HEAP32[$5>>2]|0;
         __ZdlPv($106);
         $$0$i = $102;$$01$i = $101;
        } else {
         $$0$i = $102;$$01$i = $101;
        }
       }
       $107 = ((($4)) + 11|0);
       $108 = HEAP8[$107>>0]|0;
       $109 = ($108<<24>>24)<(0);
       if (!($109)) {
        ___resumeException($$01$i|0);
        // unreachable;
       }
       $110 = HEAP32[$4>>2]|0;
       __ZdlPv($110);
       ___resumeException($$01$i|0);
       // unreachable;
      }
     }
     $66 = ___cxa_find_matching_catch_2()|0;
     $67 = tempRet0;
     $68 = ((($1)) + 11|0);
     $69 = HEAP8[$68>>0]|0;
     $70 = ($69<<24>>24)<(0);
     if ($70) {
      $71 = HEAP32[$1>>2]|0;
      __ZdlPv($71);
      $$0$i14 = $67;$$01$i13 = $66;
     } else {
      $$0$i14 = $67;$$01$i13 = $66;
     }
    }
    $72 = ((($0)) + 11|0);
    $73 = HEAP8[$72>>0]|0;
    $74 = ($73<<24>>24)<(0);
    if (!($74)) {
     ___resumeException($$01$i13|0);
     // unreachable;
    }
    $75 = HEAP32[$0>>2]|0;
    __ZdlPv($75);
    ___resumeException($$01$i13|0);
    // unreachable;
   }
  }
  $31 = ___cxa_find_matching_catch_2()|0;
  $32 = tempRet0;
  $33 = ((($3)) + 11|0);
  $34 = HEAP8[$33>>0]|0;
  $35 = ($34<<24>>24)<(0);
  if ($35) {
   $36 = HEAP32[$3>>2]|0;
   __ZdlPv($36);
   $$0$i6 = $32;$$01$i5 = $31;
  } else {
   $$0$i6 = $32;$$01$i5 = $31;
  }
 }
 $37 = ((($2)) + 11|0);
 $38 = HEAP8[$37>>0]|0;
 $39 = ($38<<24>>24)<(0);
 if (!($39)) {
  ___resumeException($$01$i5|0);
  // unreachable;
 }
 $40 = HEAP32[$2>>2]|0;
 __ZdlPv($40);
 ___resumeException($$01$i5|0);
 // unreachable;
}
function __ZN7osgUtil14StateToCompileC2EjPN3osg6ObjectE($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$cast = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ((($1)) + 4|0);
 __ZN3osg11NodeVisitorC2ENS0_13TraversalModeE($0,$4,2);
 $5 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $5;
 $6 = ((($1)) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $$cast = $5;
 $8 = ((($$cast)) + -12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($0) + ($9)|0);
 HEAP32[$10>>2] = $7;
 $11 = ((($0)) + 60|0);
 HEAP32[$11>>2] = 0;
 $12 = ((($0)) + 64|0);
 HEAP32[$12>>2] = 0;
 $13 = ((($0)) + 60|0);
 $14 = ((($0)) + 56|0);
 HEAP32[$14>>2] = $13;
 $15 = ((($0)) + 72|0);
 HEAP32[$15>>2] = 0;
 $16 = ((($0)) + 76|0);
 HEAP32[$16>>2] = 0;
 $17 = ((($0)) + 72|0);
 $18 = ((($0)) + 68|0);
 HEAP32[$18>>2] = $17;
 $19 = ((($0)) + 80|0);
 HEAP32[$19>>2] = $2;
 $20 = ((($0)) + 88|0);
 HEAP32[$20>>2] = 0;
 $21 = ((($0)) + 92|0);
 HEAP32[$21>>2] = 0;
 $22 = ((($0)) + 88|0);
 $23 = ((($0)) + 84|0);
 HEAP32[$23>>2] = $22;
 $24 = ((($0)) + 100|0);
 HEAP32[$24>>2] = 0;
 $25 = ((($0)) + 104|0);
 HEAP32[$25>>2] = 0;
 $26 = ((($0)) + 100|0);
 $27 = ((($0)) + 96|0);
 HEAP32[$27>>2] = $26;
 $28 = ((($0)) + 112|0);
 HEAP32[$28>>2] = 0;
 $29 = ((($0)) + 116|0);
 HEAP32[$29>>2] = 0;
 $30 = ((($0)) + 112|0);
 $31 = ((($0)) + 108|0);
 HEAP32[$31>>2] = $30;
 $32 = ((($0)) + 120|0);
 HEAP8[$32>>0] = 0;
 $33 = ((($0)) + 124|0);
 HEAP32[$33>>2] = 0;
 $34 = ((($0)) + 128|0);
 HEAP32[$34>>2] = $3;
 $35 = ($3|0)==(0|0);
 if ($35) {
  return;
 }
 $36 = ((($3)) + 8|0);
 $37 = HEAP32[$36>>2]|0;HEAP32[$36>>2] = (($37+1)|0);
 return;
}
function __ZN7osgUtil14StateToCompileC1EjPN3osg6ObjectE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 132|0);
 __ZN3osg10ReferencedC2Ev($3);
 HEAP32[$3>>2] = (63412);
 $4 = ((($0)) + 144|0);
 ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;
 $5 = ((($0)) + 156|0);
 HEAP32[$5>>2] = 2;
 $6 = ((($0)) + 160|0);
 HEAP32[$6>>2] = 0;
 __THREW__ = 0;
 invoke_viii(3283,($0|0),((48236)|0),2);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $36 = ___cxa_find_matching_catch_2()|0;
  $37 = tempRet0;
  __THREW__ = 0;
  invoke_vi(388,($3|0));
  $38 = __THREW__; __THREW__ = 0;
  $39 = $38&1;
  if ($39) {
   $40 = ___cxa_find_matching_catch_3(0|0)|0;
   $41 = tempRet0;
   ___clang_call_terminate($40);
   // unreachable;
  } else {
   ___resumeException($36|0);
   // unreachable;
  }
 }
 HEAP32[$0>>2] = (47740);
 HEAP32[$3>>2] = (48092);
 $9 = ((($0)) + 60|0);
 HEAP32[$9>>2] = 0;
 $10 = ((($0)) + 64|0);
 HEAP32[$10>>2] = 0;
 $11 = ((($0)) + 60|0);
 $12 = ((($0)) + 56|0);
 HEAP32[$12>>2] = $11;
 $13 = ((($0)) + 72|0);
 HEAP32[$13>>2] = 0;
 $14 = ((($0)) + 76|0);
 HEAP32[$14>>2] = 0;
 $15 = ((($0)) + 72|0);
 $16 = ((($0)) + 68|0);
 HEAP32[$16>>2] = $15;
 $17 = ((($0)) + 80|0);
 HEAP32[$17>>2] = $1;
 $18 = ((($0)) + 88|0);
 HEAP32[$18>>2] = 0;
 $19 = ((($0)) + 92|0);
 HEAP32[$19>>2] = 0;
 $20 = ((($0)) + 88|0);
 $21 = ((($0)) + 84|0);
 HEAP32[$21>>2] = $20;
 $22 = ((($0)) + 100|0);
 HEAP32[$22>>2] = 0;
 $23 = ((($0)) + 104|0);
 HEAP32[$23>>2] = 0;
 $24 = ((($0)) + 100|0);
 $25 = ((($0)) + 96|0);
 HEAP32[$25>>2] = $24;
 $26 = ((($0)) + 112|0);
 HEAP32[$26>>2] = 0;
 $27 = ((($0)) + 116|0);
 HEAP32[$27>>2] = 0;
 $28 = ((($0)) + 112|0);
 $29 = ((($0)) + 108|0);
 HEAP32[$29>>2] = $28;
 $30 = ((($0)) + 120|0);
 HEAP8[$30>>0] = 0;
 $31 = ((($0)) + 124|0);
 HEAP32[$31>>2] = 0;
 $32 = ((($0)) + 128|0);
 HEAP32[$32>>2] = $2;
 $33 = ($2|0)==(0|0);
 if ($33) {
  return;
 }
 $34 = ((($2)) + 8|0);
 $35 = HEAP32[$34>>2]|0;HEAP32[$34>>2] = (($35+1)|0);
 return;
}
function __ZN7osgUtil27IncrementalCompileOperation10CompileSet15buildCompileMapERNSt3__23setIPN3osg15GraphicsContextENS2_4lessIS6_EENS2_9allocatorIS6_EEEERNS_14StateToCompileE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$i$i$i = 0, $$0$i$i$i19 = 0, $$0$i$i$i25 = 0, $$0$i$i$i38 = 0, $$0$i$i32 = 0, $$0$ph$i$i = 0, $$014$i = 0, $$024$i$i = 0, $$025$i$i = 0, $$025$i59$i = 0, $$043$i = 0, $$04358$i = 0, $$in$i$i = 0, $$pre$i$i = 0, $$sroa$047$0$be = 0, $$sroa$047$093 = 0, $$sroa$053$0$be = 0, $$sroa$053$091 = 0, $$sroa$059$0$be = 0, $$sroa$059$090 = 0;
 var $$sroa$065$0$be = 0, $$sroa$065$095 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0;
 var $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0;
 var $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($1)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 if ($5) {
  return;
 }
 $6 = ((($2)) + 104|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0);
 if ($8) {
  $9 = ((($2)) + 116|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10|0)==(0);
  if ($11) {
   $12 = ((($2)) + 92|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = ($13|0)==(0);
   if ($14) {
    return;
   }
   $15 = ((($2)) + 92|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ($16|0)==(0);
   if ($17) {
    return;
   }
  }
 }
 $18 = HEAP32[$1>>2]|0;
 $19 = ((($1)) + 4|0);
 $20 = ($18|0)==($19|0);
 if ($20) {
  return;
 }
 $21 = ((($0)) + 12|0);
 $22 = ((($0)) + 32|0);
 $23 = ((($0)) + 36|0);
 $24 = ((($0)) + 36|0);
 $25 = ((($0)) + 40|0);
 $26 = ((($2)) + 84|0);
 $27 = ((($2)) + 88|0);
 $28 = ((($2)) + 96|0);
 $29 = ((($2)) + 100|0);
 $30 = ((($2)) + 108|0);
 $31 = ((($2)) + 112|0);
 $$sroa$065$095 = $18;
 L15: while(1) {
  $32 = HEAP32[$21>>2]|0;HEAP32[$21>>2] = (($32+1)|0);
  $33 = ((($$sroa$065$095)) + 16|0);
  $34 = HEAP32[$23>>2]|0;
  $35 = ($34|0)==(0|0);
  do {
   if ($35) {
    $$025$i$i = $23;$$043$i = $23;$46 = $34;
    label = 18;
   } else {
    $36 = HEAP32[$33>>2]|0;
    $$0$i$i32 = $24;$$024$i$i = $34;$237 = $34;
    while(1) {
     $37 = ((($$024$i$i)) + 16|0);
     $38 = HEAP32[$37>>2]|0;
     $39 = ($36>>>0)<($38>>>0);
     if ($39) {
      $40 = HEAP32[$$024$i$i>>2]|0;
      $41 = ($40|0)==(0|0);
      if ($41) {
       label = 13;
       break;
      } else {
       $$0$ph$i$i = $$024$i$i;$$in$i$i = $40;
      }
     } else {
      $42 = ($38>>>0)<($36>>>0);
      if (!($42)) {
       label = 17;
       break;
      }
      $43 = ((($$024$i$i)) + 4|0);
      $44 = HEAP32[$43>>2]|0;
      $45 = ($44|0)==(0|0);
      if ($45) {
       label = 16;
       break;
      } else {
       $$0$ph$i$i = $43;$$in$i$i = $44;
      }
     }
     $$0$i$i32 = $$0$ph$i$i;$$024$i$i = $$in$i$i;$237 = $$in$i$i;
    }
    if ((label|0) == 13) {
     label = 0;
     $$025$i59$i = $$024$i$i;$$04358$i = $$024$i$i;
     label = 19;
     break;
    }
    else if ((label|0) == 16) {
     label = 0;
     $$025$i59$i = $43;$$04358$i = $$024$i$i;
     label = 19;
     break;
    }
    else if ((label|0) == 17) {
     label = 0;
     $$025$i$i = $$0$i$i32;$$043$i = $$024$i$i;$46 = $237;
     label = 18;
     break;
    }
   }
  } while(0);
  if ((label|0) == 18) {
   label = 0;
   $47 = ($46|0)==(0|0);
   if ($47) {
    $$025$i59$i = $$025$i$i;$$04358$i = $$043$i;
    label = 19;
   } else {
    $$014$i = $46;
   }
  }
  if ((label|0) == 19) {
   label = 0;
   $48 = (__Znwj(32)|0);
   $49 = ((($48)) + 16|0);
   $50 = HEAP32[$33>>2]|0;
   HEAP32[$49>>2] = $50;
   $51 = ((($48)) + 20|0);
   HEAP32[$51>>2] = $51;
   $52 = ((($48)) + 24|0);
   HEAP32[$52>>2] = $51;
   $53 = ((($48)) + 28|0);
   HEAP32[$53>>2] = 0;
   HEAP32[$48>>2] = 0;
   $54 = ((($48)) + 4|0);
   HEAP32[$54>>2] = 0;
   $55 = ((($48)) + 8|0);
   HEAP32[$55>>2] = $$04358$i;
   HEAP32[$$025$i59$i>>2] = $48;
   $56 = HEAP32[$22>>2]|0;
   $57 = HEAP32[$56>>2]|0;
   $58 = ($57|0)==(0|0);
   if ($58) {
    $61 = $48;
   } else {
    $59 = $57;
    HEAP32[$22>>2] = $59;
    $$pre$i$i = HEAP32[$$025$i59$i>>2]|0;
    $61 = $$pre$i$i;
   }
   $60 = HEAP32[$24>>2]|0;
   __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($60,$61);
   $62 = HEAP32[$25>>2]|0;
   $63 = (($62) + 1)|0;
   HEAP32[$25>>2] = $63;
   $$014$i = $48;
  }
  $64 = ((($$014$i)) + 20|0);
  $65 = HEAP32[$26>>2]|0;
  $66 = ($65|0)==($27|0);
  if (!($66)) {
   $67 = ((($$014$i)) + 28|0);
   $$sroa$059$090 = $65;
   while(1) {
    $71 = ((($$sroa$059$090)) + 16|0);
    $72 = HEAP32[$71>>2]|0;
    $73 = (__Znwj(16)|0);
    __THREW__ = 0;
    invoke_vi(3282,($73|0));
    $74 = __THREW__; __THREW__ = 0;
    $75 = $74&1;
    if ($75) {
     label = 29;
     break L15;
    }
    HEAP32[$73>>2] = (48256);
    $76 = ((($73)) + 12|0);
    HEAP32[$76>>2] = $72;
    $77 = ($72|0)==(0|0);
    if (!($77)) {
     $78 = ((($72)) + 8|0);
     $79 = HEAP32[$78>>2]|0;HEAP32[$78>>2] = (($79+1)|0);
    }
    $82 = ((($73)) + 8|0);
    $83 = HEAP32[$82>>2]|0;HEAP32[$82>>2] = (($83+1)|0);
    __THREW__ = 0;
    $84 = (invoke_ii(3276,12)|0);
    $85 = __THREW__; __THREW__ = 0;
    $86 = $85&1;
    if ($86) {
     label = 33;
     break L15;
    }
    $87 = ((($84)) + 8|0);
    HEAP32[$87>>2] = $73;
    $88 = HEAP32[$82>>2]|0;HEAP32[$82>>2] = (($88+1)|0);
    $89 = ((($84)) + 4|0);
    HEAP32[$89>>2] = $64;
    $90 = HEAP32[$64>>2]|0;
    HEAP32[$84>>2] = $90;
    $91 = ((($90)) + 4|0);
    HEAP32[$91>>2] = $84;
    HEAP32[$64>>2] = $84;
    $92 = HEAP32[$67>>2]|0;
    $93 = (($92) + 1)|0;
    HEAP32[$67>>2] = $93;
    $94 = HEAP32[$82>>2]|0;HEAP32[$82>>2] = (($94-1)|0);
    $95 = ($94|0)==(1);
    if ($95) {
     __ZNK3osg10Referenced24signalObserversAndDeleteEbb($73,1,1);
    }
    $104 = ((($$sroa$059$090)) + 4|0);
    $105 = HEAP32[$104>>2]|0;
    $106 = ($105|0)==(0|0);
    if ($106) {
     $107 = ((($$sroa$059$090)) + 8|0);
     $108 = HEAP32[$107>>2]|0;
     $109 = HEAP32[$108>>2]|0;
     $110 = ($109|0)==($$sroa$059$090|0);
     if ($110) {
      $$sroa$059$0$be = $108;
     } else {
      $115 = $107;
      while(1) {
       $114 = HEAP32[$115>>2]|0;
       $116 = ((($114)) + 8|0);
       $117 = HEAP32[$116>>2]|0;
       $118 = HEAP32[$117>>2]|0;
       $119 = ($118|0)==($114|0);
       if ($119) {
        $$sroa$059$0$be = $117;
        break;
       } else {
        $115 = $116;
       }
      }
     }
    } else {
     $$0$i$i$i38 = $105;
     while(1) {
      $112 = HEAP32[$$0$i$i$i38>>2]|0;
      $113 = ($112|0)==(0|0);
      if ($113) {
       break;
      } else {
       $$0$i$i$i38 = $112;
      }
     }
     $$sroa$059$0$be = $$0$i$i$i38;
    }
    $111 = ($$sroa$059$0$be|0)==($27|0);
    if ($111) {
     break;
    } else {
     $$sroa$059$090 = $$sroa$059$0$be;
    }
   }
  }
  $68 = HEAP32[$28>>2]|0;
  $69 = ($68|0)==($29|0);
  if (!($69)) {
   $70 = ((($$014$i)) + 28|0);
   $$sroa$053$091 = $68;
   while(1) {
    $123 = ((($$sroa$053$091)) + 16|0);
    $124 = HEAP32[$123>>2]|0;
    $125 = (__Znwj(16)|0);
    __THREW__ = 0;
    invoke_vi(3282,($125|0));
    $126 = __THREW__; __THREW__ = 0;
    $127 = $126&1;
    if ($127) {
     label = 48;
     break L15;
    }
    HEAP32[$125>>2] = (48284);
    $128 = ((($125)) + 12|0);
    HEAP32[$128>>2] = $124;
    $129 = ($124|0)==(0|0);
    if (!($129)) {
     $130 = ((($124)) + 8|0);
     $131 = HEAP32[$130>>2]|0;HEAP32[$130>>2] = (($131+1)|0);
    }
    $134 = ((($125)) + 8|0);
    $135 = HEAP32[$134>>2]|0;HEAP32[$134>>2] = (($135+1)|0);
    __THREW__ = 0;
    $136 = (invoke_ii(3276,12)|0);
    $137 = __THREW__; __THREW__ = 0;
    $138 = $137&1;
    if ($138) {
     label = 52;
     break L15;
    }
    $139 = ((($136)) + 8|0);
    HEAP32[$139>>2] = $125;
    $140 = HEAP32[$134>>2]|0;HEAP32[$134>>2] = (($140+1)|0);
    $141 = ((($136)) + 4|0);
    HEAP32[$141>>2] = $64;
    $142 = HEAP32[$64>>2]|0;
    HEAP32[$136>>2] = $142;
    $143 = ((($142)) + 4|0);
    HEAP32[$143>>2] = $136;
    HEAP32[$64>>2] = $136;
    $144 = HEAP32[$70>>2]|0;
    $145 = (($144) + 1)|0;
    HEAP32[$70>>2] = $145;
    $146 = HEAP32[$134>>2]|0;HEAP32[$134>>2] = (($146-1)|0);
    $147 = ($146|0)==(1);
    if ($147) {
     __ZNK3osg10Referenced24signalObserversAndDeleteEbb($125,1,1);
    }
    $156 = ((($$sroa$053$091)) + 4|0);
    $157 = HEAP32[$156>>2]|0;
    $158 = ($157|0)==(0|0);
    if ($158) {
     $159 = ((($$sroa$053$091)) + 8|0);
     $160 = HEAP32[$159>>2]|0;
     $161 = HEAP32[$160>>2]|0;
     $162 = ($161|0)==($$sroa$053$091|0);
     if ($162) {
      $$sroa$053$0$be = $160;
     } else {
      $167 = $159;
      while(1) {
       $166 = HEAP32[$167>>2]|0;
       $168 = ((($166)) + 8|0);
       $169 = HEAP32[$168>>2]|0;
       $170 = HEAP32[$169>>2]|0;
       $171 = ($170|0)==($166|0);
       if ($171) {
        $$sroa$053$0$be = $169;
        break;
       } else {
        $167 = $168;
       }
      }
     }
    } else {
     $$0$i$i$i25 = $157;
     while(1) {
      $164 = HEAP32[$$0$i$i$i25>>2]|0;
      $165 = ($164|0)==(0|0);
      if ($165) {
       break;
      } else {
       $$0$i$i$i25 = $164;
      }
     }
     $$sroa$053$0$be = $$0$i$i$i25;
    }
    $163 = ($$sroa$053$0$be|0)==($29|0);
    if ($163) {
     break;
    } else {
     $$sroa$053$091 = $$sroa$053$0$be;
    }
   }
  }
  $120 = HEAP32[$30>>2]|0;
  $121 = ($120|0)==($31|0);
  if (!($121)) {
   $122 = ((($$014$i)) + 28|0);
   $$sroa$047$093 = $120;
   while(1) {
    $188 = ((($$sroa$047$093)) + 16|0);
    $189 = HEAP32[$188>>2]|0;
    $190 = (__Znwj(16)|0);
    __THREW__ = 0;
    invoke_vi(3282,($190|0));
    $191 = __THREW__; __THREW__ = 0;
    $192 = $191&1;
    if ($192) {
     label = 71;
     break L15;
    }
    HEAP32[$190>>2] = (48312);
    $193 = ((($190)) + 12|0);
    HEAP32[$193>>2] = $189;
    $194 = ($189|0)==(0|0);
    if (!($194)) {
     $195 = ((($189)) + 8|0);
     $196 = HEAP32[$195>>2]|0;HEAP32[$195>>2] = (($196+1)|0);
    }
    $199 = ((($190)) + 8|0);
    $200 = HEAP32[$199>>2]|0;HEAP32[$199>>2] = (($200+1)|0);
    __THREW__ = 0;
    $201 = (invoke_ii(3276,12)|0);
    $202 = __THREW__; __THREW__ = 0;
    $203 = $202&1;
    if ($203) {
     label = 75;
     break L15;
    }
    $204 = ((($201)) + 8|0);
    HEAP32[$204>>2] = $190;
    $205 = HEAP32[$199>>2]|0;HEAP32[$199>>2] = (($205+1)|0);
    $206 = ((($201)) + 4|0);
    HEAP32[$206>>2] = $64;
    $207 = HEAP32[$64>>2]|0;
    HEAP32[$201>>2] = $207;
    $208 = ((($207)) + 4|0);
    HEAP32[$208>>2] = $201;
    HEAP32[$64>>2] = $201;
    $209 = HEAP32[$122>>2]|0;
    $210 = (($209) + 1)|0;
    HEAP32[$122>>2] = $210;
    $211 = HEAP32[$199>>2]|0;HEAP32[$199>>2] = (($211-1)|0);
    $212 = ($211|0)==(1);
    if ($212) {
     __ZNK3osg10Referenced24signalObserversAndDeleteEbb($190,1,1);
    }
    $221 = ((($$sroa$047$093)) + 4|0);
    $222 = HEAP32[$221>>2]|0;
    $223 = ($222|0)==(0|0);
    if ($223) {
     $224 = ((($$sroa$047$093)) + 8|0);
     $225 = HEAP32[$224>>2]|0;
     $226 = HEAP32[$225>>2]|0;
     $227 = ($226|0)==($$sroa$047$093|0);
     if ($227) {
      $$sroa$047$0$be = $225;
     } else {
      $232 = $224;
      while(1) {
       $231 = HEAP32[$232>>2]|0;
       $233 = ((($231)) + 8|0);
       $234 = HEAP32[$233>>2]|0;
       $235 = HEAP32[$234>>2]|0;
       $236 = ($235|0)==($231|0);
       if ($236) {
        $$sroa$047$0$be = $234;
        break;
       } else {
        $232 = $233;
       }
      }
     }
    } else {
     $$0$i$i$i = $222;
     while(1) {
      $229 = HEAP32[$$0$i$i$i>>2]|0;
      $230 = ($229|0)==(0|0);
      if ($230) {
       break;
      } else {
       $$0$i$i$i = $229;
      }
     }
     $$sroa$047$0$be = $$0$i$i$i;
    }
    $228 = ($$sroa$047$0$be|0)==($31|0);
    if ($228) {
     break;
    } else {
     $$sroa$047$093 = $$sroa$047$0$be;
    }
   }
  }
  $172 = ((($$sroa$065$095)) + 4|0);
  $173 = HEAP32[$172>>2]|0;
  $174 = ($173|0)==(0|0);
  if ($174) {
   $175 = ((($$sroa$065$095)) + 8|0);
   $176 = HEAP32[$175>>2]|0;
   $177 = HEAP32[$176>>2]|0;
   $178 = ($177|0)==($$sroa$065$095|0);
   if ($178) {
    $$sroa$065$0$be = $176;
   } else {
    $183 = $175;
    while(1) {
     $182 = HEAP32[$183>>2]|0;
     $184 = ((($182)) + 8|0);
     $185 = HEAP32[$184>>2]|0;
     $186 = HEAP32[$185>>2]|0;
     $187 = ($186|0)==($182|0);
     if ($187) {
      $$sroa$065$0$be = $185;
      break;
     } else {
      $183 = $184;
     }
    }
   }
  } else {
   $$0$i$i$i19 = $173;
   while(1) {
    $180 = HEAP32[$$0$i$i$i19>>2]|0;
    $181 = ($180|0)==(0|0);
    if ($181) {
     break;
    } else {
     $$0$i$i$i19 = $180;
    }
   }
   $$sroa$065$0$be = $$0$i$i$i19;
  }
  $179 = ($$sroa$065$0$be|0)==($19|0);
  if ($179) {
   label = 85;
   break;
  } else {
   $$sroa$065$095 = $$sroa$065$0$be;
  }
 }
 if ((label|0) == 29) {
  $80 = ___cxa_find_matching_catch_2()|0;
  $81 = tempRet0;
  __ZdlPv($73);
  ___resumeException($80|0);
  // unreachable;
 }
 else if ((label|0) == 33) {
  $96 = ___cxa_find_matching_catch_2()|0;
  $97 = tempRet0;
  $98 = HEAP32[$82>>2]|0;HEAP32[$82>>2] = (($98-1)|0);
  $99 = ($98|0)==(1);
  if (!($99)) {
   ___resumeException($96|0);
   // unreachable;
  }
  __THREW__ = 0;
  invoke_viii(3262,($73|0),1,1);
  $100 = __THREW__; __THREW__ = 0;
  $101 = $100&1;
  if ($101) {
   $102 = ___cxa_find_matching_catch_3(0|0)|0;
   $103 = tempRet0;
   ___clang_call_terminate($102);
   // unreachable;
  } else {
   ___resumeException($96|0);
   // unreachable;
  }
 }
 else if ((label|0) == 48) {
  $132 = ___cxa_find_matching_catch_2()|0;
  $133 = tempRet0;
  __ZdlPv($125);
  ___resumeException($132|0);
  // unreachable;
 }
 else if ((label|0) == 52) {
  $148 = ___cxa_find_matching_catch_2()|0;
  $149 = tempRet0;
  $150 = HEAP32[$134>>2]|0;HEAP32[$134>>2] = (($150-1)|0);
  $151 = ($150|0)==(1);
  if (!($151)) {
   ___resumeException($148|0);
   // unreachable;
  }
  __THREW__ = 0;
  invoke_viii(3262,($125|0),1,1);
  $152 = __THREW__; __THREW__ = 0;
  $153 = $152&1;
  if ($153) {
   $154 = ___cxa_find_matching_catch_3(0|0)|0;
   $155 = tempRet0;
   ___clang_call_terminate($154);
   // unreachable;
  } else {
   ___resumeException($148|0);
   // unreachable;
  }
 }
 else if ((label|0) == 71) {
  $197 = ___cxa_find_matching_catch_2()|0;
  $198 = tempRet0;
  __ZdlPv($190);
  ___resumeException($197|0);
  // unreachable;
 }
 else if ((label|0) == 75) {
  $213 = ___cxa_find_matching_catch_2()|0;
  $214 = tempRet0;
  $215 = HEAP32[$199>>2]|0;HEAP32[$199>>2] = (($215-1)|0);
  $216 = ($215|0)==(1);
  if (!($216)) {
   ___resumeException($213|0);
   // unreachable;
  }
  __THREW__ = 0;
  invoke_viii(3262,($190|0),1,1);
  $217 = __THREW__; __THREW__ = 0;
  $218 = $217&1;
  if ($218) {
   $219 = ___cxa_find_matching_catch_3(0|0)|0;
   $220 = tempRet0;
   ___clang_call_terminate($219);
   // unreachable;
  } else {
   ___resumeException($213|0);
   // unreachable;
  }
 }
 else if ((label|0) == 85) {
  return;
 }
}
function __ZN7osgUtil27IncrementalCompileOperation10CompileSet15buildCompileMapERNSt3__23setIPN3osg15GraphicsContextENS2_4lessIS6_EENS2_9allocatorIS6_EEEEj($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(176|0);
 $3 = sp;
 $4 = ((($1)) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = ((($0)) + 24|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if ($9) {
  STACKTOP = sp;return;
 }
 $10 = ((($0)) + 44|0);
 $11 = HEAP32[$10>>2]|0;
 __ZN7osgUtil14StateToCompileC1EjPN3osg6ObjectE($3,$2,$11);
 $12 = HEAP32[$7>>2]|0;
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($13)) + 188|0);
 $15 = HEAP32[$14>>2]|0;
 __THREW__ = 0;
 invoke_vii($15|0,($12|0),($3|0));
 $16 = __THREW__; __THREW__ = 0;
 $17 = $16&1;
 if (!($17)) {
  __THREW__ = 0;
  invoke_viii(3560,($0|0),($1|0),($3|0));
  $18 = __THREW__; __THREW__ = 0;
  $19 = $18&1;
  if (!($19)) {
   __THREW__ = 0;
   invoke_vii(3552,($3|0),(48232|0));
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if (!($21)) {
    $29 = ((($3)) + 132|0);
    __ZN3osg6ObjectD2Ev($29);
    STACKTOP = sp;return;
   }
   $22 = ___cxa_find_matching_catch_2()|0;
   $23 = tempRet0;
   $24 = ((($3)) + 132|0);
   __THREW__ = 0;
   invoke_vi(388,($24|0));
   $25 = __THREW__; __THREW__ = 0;
   $26 = $25&1;
   if ($26) {
    $27 = ___cxa_find_matching_catch_3(0|0)|0;
    $28 = tempRet0;
    ___clang_call_terminate($27);
    // unreachable;
   } else {
    ___resumeException($22|0);
    // unreachable;
   }
  }
 }
 $30 = ___cxa_find_matching_catch_2()|0;
 $31 = tempRet0;
 __THREW__ = 0;
 invoke_vii(3552,($3|0),(48232|0));
 $32 = __THREW__; __THREW__ = 0;
 $33 = $32&1;
 if ($33) {
  $37 = ___cxa_find_matching_catch_3(0|0)|0;
  $38 = tempRet0;
  $39 = ((($3)) + 132|0);
  __THREW__ = 0;
  invoke_vi(388,($39|0));
  $40 = __THREW__; __THREW__ = 0;
  $41 = $40&1;
  if ($41) {
   $42 = ___cxa_find_matching_catch_3(0|0)|0;
   $43 = tempRet0;
   ___clang_call_terminate($42);
   // unreachable;
  } else {
   $eh$lpad$body$indexZ2D = $37;
   ___clang_call_terminate($eh$lpad$body$indexZ2D);
   // unreachable;
  }
 }
 $34 = ((($3)) + 132|0);
 __THREW__ = 0;
 invoke_vi(388,($34|0));
 $35 = __THREW__; __THREW__ = 0;
 $36 = $35&1;
 if (!($36)) {
  ___resumeException($30|0);
  // unreachable;
 }
 $44 = ___cxa_find_matching_catch_3(0|0)|0;
 $45 = tempRet0;
 $eh$lpad$body$indexZ2D = $44;
 ___clang_call_terminate($eh$lpad$body$indexZ2D);
 // unreachable;
}
function __ZN3osg11DummyObjectD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(388,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK3osg11DummyObject9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(32)|0);
 __THREW__ = 0;
 invoke_vi(3282,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $7 = ___cxa_find_matching_catch_2()|0;
  $8 = tempRet0;
  __ZdlPv($1);
  ___resumeException($7|0);
  // unreachable;
 } else {
  $4 = ((($1)) + 12|0);
  ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;
  $5 = ((($1)) + 24|0);
  HEAP32[$5>>2] = 2;
  $6 = ((($1)) + 28|0);
  HEAP32[$6>>2] = 0;
  HEAP32[$1>>2] = (48340);
  return ($1|0);
 }
 return (0)|0;
}
function __ZNK3osg11DummyObject5cloneERKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(32)|0);
 __THREW__ = 0;
 invoke_viii(3468,($2|0),($0|0),($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch_2()|0;
  $6 = tempRet0;
  __ZdlPv($2);
  ___resumeException($5|0);
  // unreachable;
 } else {
  HEAP32[$2>>2] = (48340);
  return ($2|0);
 }
 return (0)|0;
}
function __ZNK3osg11DummyObject12isSameKindAsEPKNS_6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,20928,0)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK3osg11DummyObject11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175113|0);
}
function __ZNK3osg11DummyObject9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (111268|0);
}
function __ZN7osgUtil27IncrementalCompileOperation14assignContextsERNSt3__26vectorIPN3osg15GraphicsContextENS1_9allocatorIS5_EEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$sroa$06$010 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($1)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2|0)==($4|0);
 if ($5) {
  return;
 } else {
  $$sroa$06$010 = $2;
 }
 while(1) {
  $6 = HEAP32[$$sroa$06$010>>2]|0;
  __ZN7osgUtil27IncrementalCompileOperation18addGraphicsContextEPN3osg15GraphicsContextE($0,$6);
  $7 = ((($$sroa$06$010)) + 4|0);
  $8 = HEAP32[$3>>2]|0;
  $9 = ($7|0)==($8|0);
  if ($9) {
   break;
  } else {
   $$sroa$06$010 = $7;
  }
 }
 return;
}
function __ZN7osgUtil27IncrementalCompileOperation18addGraphicsContextEPN3osg15GraphicsContextE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i$i$i = 0, $$0$ph$i$i$i$i = 0, $$024$i$i$i$i = 0, $$025$i$i$i$i = 0, $$036$i$i$i = 0, $$in$i$i$i$i = 0, $$pre$i$i$i$i = 0, $$sink$be$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = $1;
 $3 = ((($0)) + 124|0);
 $4 = ((($0)) + 128|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 L1: do {
  if (!($6)) {
   $8 = $5;
   while(1) {
    $7 = ((($8)) + 16|0);
    $9 = HEAP32[$7>>2]|0;
    $10 = ($9>>>0)>($1>>>0);
    if ($10) {
     $$sink$be$i$i = $8;
    } else {
     $11 = ($9>>>0)<($1>>>0);
     if (!($11)) {
      break;
     }
     $12 = ((($8)) + 4|0);
     $$sink$be$i$i = $12;
    }
    $13 = HEAP32[$$sink$be$i$i>>2]|0;
    $14 = ($13|0)==(0|0);
    if ($14) {
     break L1;
    } else {
     $8 = $13;
    }
   }
   return;
  }
 } while(0);
 __ZN3osg15GraphicsContext3addEPNS_9OperationE($1,$0);
 $15 = HEAP32[$4>>2]|0;
 $16 = ($15|0)==(0|0);
 do {
  if ($16) {
   $$025$i$i$i$i = $4;$$036$i$i$i = $4;
  } else {
   $17 = ((($0)) + 128|0);
   $$0$i$i$i$i = $17;$$024$i$i$i$i = $15;
   while(1) {
    $18 = ((($$024$i$i$i$i)) + 16|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = ($19>>>0)>($1>>>0);
    if ($20) {
     $21 = HEAP32[$$024$i$i$i$i>>2]|0;
     $22 = ($21|0)==(0|0);
     if ($22) {
      label = 12;
      break;
     } else {
      $$0$ph$i$i$i$i = $$024$i$i$i$i;$$in$i$i$i$i = $21;
     }
    } else {
     $23 = ($19>>>0)<($1>>>0);
     if (!($23)) {
      label = 16;
      break;
     }
     $24 = ((($$024$i$i$i$i)) + 4|0);
     $25 = HEAP32[$24>>2]|0;
     $26 = ($25|0)==(0|0);
     if ($26) {
      label = 15;
      break;
     } else {
      $$0$ph$i$i$i$i = $24;$$in$i$i$i$i = $25;
     }
    }
    $$0$i$i$i$i = $$0$ph$i$i$i$i;$$024$i$i$i$i = $$in$i$i$i$i;
   }
   if ((label|0) == 12) {
    $$025$i$i$i$i = $$024$i$i$i$i;$$036$i$i$i = $$024$i$i$i$i;
    break;
   }
   else if ((label|0) == 15) {
    $$025$i$i$i$i = $24;$$036$i$i$i = $$024$i$i$i$i;
    break;
   }
   else if ((label|0) == 16) {
    $$025$i$i$i$i = $$0$i$i$i$i;$$036$i$i$i = $$024$i$i$i$i;
    break;
   }
  }
 } while(0);
 $27 = HEAP32[$$025$i$i$i$i>>2]|0;
 $28 = ($27|0)==(0|0);
 if (!($28)) {
  return;
 }
 $29 = (__Znwj(20)|0);
 $30 = ((($29)) + 16|0);
 HEAP32[$30>>2] = $2;
 HEAP32[$29>>2] = 0;
 $31 = ((($29)) + 4|0);
 HEAP32[$31>>2] = 0;
 $32 = ((($29)) + 8|0);
 HEAP32[$32>>2] = $$036$i$i$i;
 HEAP32[$$025$i$i$i$i>>2] = $29;
 $33 = HEAP32[$3>>2]|0;
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)==(0|0);
 if ($35) {
  $39 = $29;
 } else {
  $36 = $34;
  HEAP32[$3>>2] = $36;
  $$pre$i$i$i$i = HEAP32[$$025$i$i$i$i>>2]|0;
  $39 = $$pre$i$i$i$i;
 }
 $37 = ((($0)) + 128|0);
 $38 = HEAP32[$37>>2]|0;
 __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($38,$39);
 $40 = ((($0)) + 132|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = (($41) + 1)|0;
 HEAP32[$40>>2] = $42;
 return;
}
function __ZNSt3__213__tree_removeIPNS_16__tree_node_baseIPvEEEEvT_S5_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$$0 = 0, $$$i = 0, $$$i131 = 0, $$$i132 = 0, $$$i134 = 0, $$$i136 = 0, $$$i138 = 0, $$0 = 0, $$0$i$i = 0, $$0117 = 0, $$1 = 0, $$1118 = 0, $$1118$$2 = 0, $$1118$$2130 = 0, $$193 = 0, $$2 = 0, $$2$ph = 0, $$2119 = 0, $$3120 = 0, $$4 = 0;
 var $$4121 = 0, $$5122 = 0, $$6 = 0, $$lcssa164 = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre168 = 0, $$sink = 0, $$sink1 = 0, $$sink128 = 0, $$sink203 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0;
 var $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0;
 var $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0;
 var $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $or$cond153 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  $12 = $1;$9 = 0;
 } else {
  $4 = ((($1)) + 4|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0|0);
  if ($6) {
   $12 = $1;$9 = $2;
  } else {
   $$0$i$i = $5;
   while(1) {
    $7 = HEAP32[$$0$i$i>>2]|0;
    $8 = ($7|0)==(0|0);
    if ($8) {
     $12 = $$0$i$i;$9 = 0;
     break;
    } else {
     $$0$i$i = $7;
    }
   }
  }
 }
 $10 = ($9|0)!=(0|0);
 $11 = ((($12)) + 4|0);
 $$sink = $10 ? $12 : $11;
 $13 = HEAP32[$$sink>>2]|0;
 $14 = ($13|0)==(0|0);
 $$pre168 = ((($12)) + 8|0);
 if (!($14)) {
  $15 = HEAP32[$$pre168>>2]|0;
  $16 = ((($13)) + 8|0);
  HEAP32[$16>>2] = $15;
 }
 $17 = HEAP32[$$pre168>>2]|0;
 $18 = HEAP32[$17>>2]|0;
 $19 = ($18|0)==($12|0);
 if ($19) {
  HEAP32[$17>>2] = $13;
  $20 = ($12|0)==($0|0);
  if ($20) {
   $$0 = $13;$$0117 = 0;
  } else {
   $21 = ((($17)) + 4|0);
   $$sink128 = $21;
   label = 10;
  }
 } else {
  $22 = ((($17)) + 4|0);
  HEAP32[$22>>2] = $13;
  $$sink128 = $17;
  label = 10;
 }
 if ((label|0) == 10) {
  $23 = HEAP32[$$sink128>>2]|0;
  $$0 = $0;$$0117 = $23;
 }
 $24 = ((($12)) + 12|0);
 $25 = HEAP8[$24>>0]|0;
 $26 = ($25<<24>>24)==(0);
 $27 = ($12|0)==($1|0);
 if ($27) {
  $$1 = $$0;
 } else {
  $28 = ((($1)) + 8|0);
  $29 = HEAP32[$28>>2]|0;
  HEAP32[$$pre168>>2] = $29;
  $30 = HEAP32[$28>>2]|0;
  $31 = HEAP32[$30>>2]|0;
  $32 = ($31|0)==($1|0);
  $33 = $29;
  $34 = ((($33)) + 4|0);
  $35 = $29;
  $$sink1 = $32 ? $35 : $34;
  HEAP32[$$sink1>>2] = $12;
  $36 = HEAP32[$1>>2]|0;
  HEAP32[$12>>2] = $36;
  $37 = ((($36)) + 8|0);
  HEAP32[$37>>2] = $12;
  $38 = ((($1)) + 4|0);
  $39 = HEAP32[$38>>2]|0;
  HEAP32[$11>>2] = $39;
  $40 = ($39|0)==(0|0);
  if (!($40)) {
   $41 = ((($39)) + 8|0);
   HEAP32[$41>>2] = $12;
  }
  $42 = ((($1)) + 12|0);
  $43 = HEAP8[$42>>0]|0;
  HEAP8[$24>>0] = $43;
  $44 = ($$0|0)==($1|0);
  $$$0 = $44 ? $12 : $$0;
  $$1 = $$$0;
 }
 $45 = ($$1|0)==(0|0);
 $or$cond153 = $26 | $45;
 if ($or$cond153) {
  return;
 }
 if ($14) {
  $$1118 = $$0117;$$2 = $$1;
 } else {
  $46 = ((($13)) + 12|0);
  HEAP8[$46>>0] = 1;
  return;
 }
 while(1) {
  $53 = ((($$1118)) + 8|0);
  $54 = HEAP32[$53>>2]|0;
  $55 = HEAP32[$54>>2]|0;
  $56 = ($55|0)==($$1118|0);
  $57 = ((($$1118)) + 12|0);
  $58 = HEAP8[$57>>0]|0;
  $59 = ($58<<24>>24)!=(0);
  if ($56) {
   if ($59) {
    $$4121 = $$1118;$$6 = $$2;
   } else {
    HEAP8[$57>>0] = 1;
    $133 = ((($54)) + 12|0);
    HEAP8[$133>>0] = 0;
    $134 = HEAP32[$54>>2]|0;
    $135 = ((($134)) + 4|0);
    $136 = HEAP32[$135>>2]|0;
    HEAP32[$54>>2] = $136;
    $137 = ($136|0)==(0|0);
    if (!($137)) {
     $138 = ((($136)) + 8|0);
     HEAP32[$138>>2] = $54;
    }
    $139 = ((($54)) + 8|0);
    $140 = HEAP32[$139>>2]|0;
    $141 = ((($134)) + 8|0);
    HEAP32[$141>>2] = $140;
    $142 = HEAP32[$139>>2]|0;
    $143 = HEAP32[$142>>2]|0;
    $144 = ($143|0)==($54|0);
    $145 = ((($142)) + 4|0);
    $$$i132 = $144 ? $142 : $145;
    HEAP32[$$$i132>>2] = $134;
    HEAP32[$135>>2] = $54;
    HEAP32[$139>>2] = $134;
    $146 = ((($$1118)) + 4|0);
    $147 = HEAP32[$146>>2]|0;
    $148 = ($$2|0)==($147|0);
    $$1118$$2130 = $148 ? $$1118 : $$2;
    $149 = HEAP32[$147>>2]|0;
    $$4121 = $149;$$6 = $$1118$$2130;
   }
   $150 = HEAP32[$$4121>>2]|0;
   $151 = ($150|0)==(0|0);
   if (!($151)) {
    $152 = ((($150)) + 12|0);
    $153 = HEAP8[$152>>0]|0;
    $154 = ($153<<24>>24)==(0);
    if ($154) {
     label = 50;
     break;
    }
   }
   $155 = ((($$4121)) + 4|0);
   $156 = HEAP32[$155>>2]|0;
   $157 = ($156|0)==(0|0);
   if (!($157)) {
    $158 = ((($156)) + 12|0);
    $159 = HEAP8[$158>>0]|0;
    $160 = ($159<<24>>24)==(0);
    if ($160) {
     label = 49;
     break;
    }
   }
   $161 = ((($$4121)) + 12|0);
   HEAP8[$161>>0] = 0;
   $162 = ((($$4121)) + 8|0);
   $163 = HEAP32[$162>>2]|0;
   $164 = ((($163)) + 12|0);
   $165 = HEAP8[$164>>0]|0;
   $166 = ($165<<24>>24)==(0);
   $167 = ($163|0)==($$6|0);
   $or$cond = $167 | $166;
   if ($or$cond) {
    label = 48;
    break;
   } else {
    $$2$ph = $$6;$$sink203 = $163;
   }
  } else {
   if ($59) {
    $$2119 = $$1118;$$4 = $$2;
   } else {
    HEAP8[$57>>0] = 1;
    $60 = ((($54)) + 12|0);
    HEAP8[$60>>0] = 0;
    $61 = ((($54)) + 4|0);
    $62 = HEAP32[$61>>2]|0;
    $63 = HEAP32[$62>>2]|0;
    HEAP32[$61>>2] = $63;
    $64 = ($63|0)==(0|0);
    if (!($64)) {
     $65 = ((($63)) + 8|0);
     HEAP32[$65>>2] = $54;
    }
    $66 = ((($54)) + 8|0);
    $67 = HEAP32[$66>>2]|0;
    $68 = ((($62)) + 8|0);
    HEAP32[$68>>2] = $67;
    $69 = HEAP32[$66>>2]|0;
    $70 = HEAP32[$69>>2]|0;
    $71 = ($70|0)==($54|0);
    $72 = ((($69)) + 4|0);
    $$$i138 = $71 ? $69 : $72;
    HEAP32[$$$i138>>2] = $62;
    HEAP32[$62>>2] = $54;
    HEAP32[$66>>2] = $62;
    $73 = HEAP32[$$1118>>2]|0;
    $74 = ($$2|0)==($73|0);
    $$1118$$2 = $74 ? $$1118 : $$2;
    $75 = ((($73)) + 4|0);
    $76 = HEAP32[$75>>2]|0;
    $$2119 = $76;$$4 = $$1118$$2;
   }
   $77 = HEAP32[$$2119>>2]|0;
   $78 = ($77|0)==(0|0);
   if (!($78)) {
    $79 = ((($77)) + 12|0);
    $80 = HEAP8[$79>>0]|0;
    $81 = ($80<<24>>24)==(0);
    if ($81) {
     label = 31;
     break;
    }
   }
   $82 = ((($$2119)) + 4|0);
   $83 = HEAP32[$82>>2]|0;
   $84 = ($83|0)==(0|0);
   if (!($84)) {
    $85 = ((($83)) + 12|0);
    $86 = HEAP8[$85>>0]|0;
    $87 = ($86<<24>>24)==(0);
    if ($87) {
     $98 = $83;
     label = 32;
     break;
    }
   }
   $88 = ((($$2119)) + 12|0);
   HEAP8[$88>>0] = 0;
   $89 = ((($$2119)) + 8|0);
   $90 = HEAP32[$89>>2]|0;
   $91 = ($90|0)==($$4|0);
   if ($91) {
    $$lcssa164 = $$4;
    label = 30;
    break;
   }
   $92 = ((($90)) + 12|0);
   $93 = HEAP8[$92>>0]|0;
   $94 = ($93<<24>>24)==(0);
   if ($94) {
    $$lcssa164 = $90;
    label = 30;
    break;
   } else {
    $$2$ph = $$4;$$sink203 = $90;
   }
  }
  $47 = ((($$sink203)) + 8|0);
  $48 = HEAP32[$47>>2]|0;
  $49 = HEAP32[$48>>2]|0;
  $50 = ($49|0)==($$sink203|0);
  $51 = ((($48)) + 4|0);
  $$193 = $50 ? $51 : $48;
  $52 = HEAP32[$$193>>2]|0;
  $$1118 = $52;$$2 = $$2$ph;
 }
 if ((label|0) == 30) {
  $95 = ((($$lcssa164)) + 12|0);
  HEAP8[$95>>0] = 1;
  return;
 }
 else if ((label|0) == 31) {
  $$phi$trans$insert = ((($$2119)) + 4|0);
  $$pre = HEAP32[$$phi$trans$insert>>2]|0;
  $96 = ($$pre|0)==(0|0);
  if ($96) {
   label = 33;
  } else {
   $98 = $$pre;
   label = 32;
  }
 }
 else if ((label|0) == 48) {
  HEAP8[$164>>0] = 1;
  return;
 }
 else if ((label|0) == 49) {
  if ($151) {
   label = 51;
  } else {
   label = 50;
  }
 }
 if ((label|0) == 32) {
  $97 = ((($98)) + 12|0);
  $99 = HEAP8[$97>>0]|0;
  $100 = ($99<<24>>24)==(0);
  if ($100) {
   $$3120 = $$2119;$120 = $98;
   label = 36;
  } else {
   label = 33;
  }
 }
 else if ((label|0) == 50) {
  $168 = ((($150)) + 12|0);
  $169 = HEAP8[$168>>0]|0;
  $170 = ($169<<24>>24)==(0);
  if ($170) {
   $$5122 = $$4121;$191 = $150;
   label = 54;
  } else {
   label = 51;
  }
 }
 if ((label|0) == 33) {
  $101 = ((($77)) + 12|0);
  HEAP8[$101>>0] = 1;
  $102 = ((($$2119)) + 12|0);
  HEAP8[$102>>0] = 0;
  $103 = ((($77)) + 4|0);
  $104 = HEAP32[$103>>2]|0;
  HEAP32[$$2119>>2] = $104;
  $105 = ($104|0)==(0|0);
  if (!($105)) {
   $106 = ((($104)) + 8|0);
   HEAP32[$106>>2] = $$2119;
  }
  $107 = ((($$2119)) + 8|0);
  $108 = HEAP32[$107>>2]|0;
  $109 = ((($77)) + 8|0);
  HEAP32[$109>>2] = $108;
  $110 = HEAP32[$107>>2]|0;
  $111 = HEAP32[$110>>2]|0;
  $112 = ($111|0)==($$2119|0);
  $113 = ((($110)) + 4|0);
  $$$i136 = $112 ? $110 : $113;
  HEAP32[$$$i136>>2] = $77;
  HEAP32[$103>>2] = $$2119;
  HEAP32[$107>>2] = $77;
  $$3120 = $77;$120 = $$2119;
  label = 36;
 }
 else if ((label|0) == 51) {
  $171 = ((($$4121)) + 4|0);
  $172 = HEAP32[$171>>2]|0;
  $173 = ((($172)) + 12|0);
  HEAP8[$173>>0] = 1;
  $174 = ((($$4121)) + 12|0);
  HEAP8[$174>>0] = 0;
  $175 = HEAP32[$172>>2]|0;
  HEAP32[$171>>2] = $175;
  $176 = ($175|0)==(0|0);
  if (!($176)) {
   $177 = ((($175)) + 8|0);
   HEAP32[$177>>2] = $$4121;
  }
  $178 = ((($$4121)) + 8|0);
  $179 = HEAP32[$178>>2]|0;
  $180 = ((($172)) + 8|0);
  HEAP32[$180>>2] = $179;
  $181 = HEAP32[$178>>2]|0;
  $182 = HEAP32[$181>>2]|0;
  $183 = ($182|0)==($$4121|0);
  $184 = ((($181)) + 4|0);
  $$$i131 = $183 ? $181 : $184;
  HEAP32[$$$i131>>2] = $172;
  HEAP32[$172>>2] = $$4121;
  HEAP32[$178>>2] = $172;
  $$5122 = $172;$191 = $$4121;
  label = 54;
 }
 if ((label|0) == 36) {
  $114 = ((($$3120)) + 8|0);
  $115 = HEAP32[$114>>2]|0;
  $116 = ((($115)) + 12|0);
  $117 = HEAP8[$116>>0]|0;
  $118 = ((($$3120)) + 12|0);
  HEAP8[$118>>0] = $117;
  HEAP8[$116>>0] = 1;
  $119 = ((($120)) + 12|0);
  HEAP8[$119>>0] = 1;
  $121 = ((($115)) + 4|0);
  $122 = HEAP32[$121>>2]|0;
  $123 = HEAP32[$122>>2]|0;
  HEAP32[$121>>2] = $123;
  $124 = ($123|0)==(0|0);
  if (!($124)) {
   $125 = ((($123)) + 8|0);
   HEAP32[$125>>2] = $115;
  }
  $126 = ((($115)) + 8|0);
  $127 = HEAP32[$126>>2]|0;
  $128 = ((($122)) + 8|0);
  HEAP32[$128>>2] = $127;
  $129 = HEAP32[$126>>2]|0;
  $130 = HEAP32[$129>>2]|0;
  $131 = ($130|0)==($115|0);
  $132 = ((($129)) + 4|0);
  $$$i134 = $131 ? $129 : $132;
  HEAP32[$$$i134>>2] = $122;
  HEAP32[$122>>2] = $115;
  HEAP32[$126>>2] = $122;
  return;
 }
 else if ((label|0) == 54) {
  $185 = ((($$5122)) + 8|0);
  $186 = HEAP32[$185>>2]|0;
  $187 = ((($186)) + 12|0);
  $188 = HEAP8[$187>>0]|0;
  $189 = ((($$5122)) + 12|0);
  HEAP8[$189>>0] = $188;
  HEAP8[$187>>0] = 1;
  $190 = ((($191)) + 12|0);
  HEAP8[$190>>0] = 1;
  $192 = HEAP32[$186>>2]|0;
  $193 = ((($192)) + 4|0);
  $194 = HEAP32[$193>>2]|0;
  HEAP32[$186>>2] = $194;
  $195 = ($194|0)==(0|0);
  if (!($195)) {
   $196 = ((($194)) + 8|0);
   HEAP32[$196>>2] = $186;
  }
  $197 = ((($186)) + 8|0);
  $198 = HEAP32[$197>>2]|0;
  $199 = ((($192)) + 8|0);
  HEAP32[$199>>2] = $198;
  $200 = HEAP32[$197>>2]|0;
  $201 = HEAP32[$200>>2]|0;
  $202 = ($201|0)==($186|0);
  $203 = ((($200)) + 4|0);
  $$$i = $202 ? $200 : $203;
  HEAP32[$$$i>>2] = $192;
  HEAP32[$193>>2] = $186;
  HEAP32[$197>>2] = $192;
  return;
 }
}
function __ZN7osgUtil27IncrementalCompileOperation15requiresCompileERNS_14StateToCompileE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 132|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  $13 = 0;
  return ($13|0);
 }
 $5 = ((($1)) + 104|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if (!($7)) {
  $13 = 1;
  return ($13|0);
 }
 $8 = ((($1)) + 116|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0);
 if (!($10)) {
  $13 = 1;
  return ($13|0);
 }
 $11 = ((($1)) + 92|0);
 $12 = HEAP32[$11>>2]|0;
 $phitmp = ($12|0)!=(0);
 $13 = $phitmp;
 return ($13|0);
}
function __ZN7osgUtil27IncrementalCompileOperation3addEPNS0_10CompileSetEb($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$011 = 0, $10 = 0, $100 = 0, $101 = 0.0, $102 = 0, $103 = 0.0, $104 = 0.0, $105 = 0, $106 = 0.0, $107 = 0, $108 = 0.0, $109 = 0.0, $11 = 0, $110 = 0.0, $111 = 0.0, $112 = 0.0, $113 = 0.0, $114 = 0.0, $115 = 0.0;
 var $116 = 0.0, $117 = 0.0, $118 = 0.0, $119 = 0.0, $12 = 0, $120 = 0, $121 = 0.0, $122 = 0, $123 = 0.0, $124 = 0.0, $125 = 0.0, $126 = 0.0, $127 = 0.0, $128 = 0.0, $129 = 0.0, $13 = 0, $130 = 0.0, $131 = 0.0, $132 = 0.0, $133 = 0.0;
 var $134 = 0.0, $135 = 0.0, $136 = 0.0, $137 = 0.0, $138 = 0.0, $139 = 0.0, $14 = 0, $140 = 0.0, $141 = 0.0, $142 = 0.0, $143 = 0.0, $144 = 0.0, $145 = 0.0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0;
 var $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0.0, $35 = 0, $36 = 0, $37 = 0.0, $38 = 0, $39 = 0.0, $4 = 0, $40 = 0.0, $41 = 0.0, $42 = 0, $43 = 0.0, $44 = 0, $45 = 0.0, $46 = 0.0, $47 = 0, $48 = 0.0, $49 = 0, $5 = 0, $50 = 0.0;
 var $51 = 0.0, $52 = 0.0, $53 = 0.0, $54 = 0.0, $55 = 0.0, $56 = 0.0, $57 = 0.0, $58 = 0.0, $59 = 0.0, $6 = 0, $60 = 0.0, $61 = 0.0, $62 = 0, $63 = 0.0, $64 = 0, $65 = 0.0, $66 = 0.0, $67 = 0.0, $68 = 0.0, $69 = 0.0;
 var $7 = 0, $70 = 0.0, $71 = 0.0, $72 = 0.0, $73 = 0.0, $74 = 0.0, $75 = 0.0, $76 = 0.0, $77 = 0.0, $78 = 0.0, $79 = 0.0, $8 = 0, $80 = 0.0, $81 = 0.0, $82 = 0.0, $83 = 0.0, $84 = 0.0, $85 = 0.0, $86 = 0.0, $87 = 0.0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0.0, $93 = 0, $94 = 0, $95 = 0.0, $96 = 0, $97 = 0.0, $98 = 0.0, $99 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $3 = sp + 32|0;
 $4 = sp + 16|0;
 $5 = sp;
 $6 = ($1|0)==(0|0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = ((($1)) + 44|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($0)) + 136|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8|0)==($10|0);
 if (!($11)) {
  HEAP32[$7>>2] = $10;
  $12 = ($10|0)==(0|0);
  if (!($12)) {
   $13 = ((($10)) + 8|0);
   $14 = HEAP32[$13>>2]|0;HEAP32[$13>>2] = (($14+1)|0);
  }
  $15 = ($8|0)==(0|0);
  if (!($15)) {
   $16 = ((($8)) + 8|0);
   $17 = HEAP32[$16>>2]|0;HEAP32[$16>>2] = (($17-1)|0);
   $18 = ($17|0)==(1);
   if ($18) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($8,1,1);
   }
  }
 }
 $19 = ((($1)) + 24|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)==(0|0);
 if (!($21)) {
  $22 = ((($20)) + 68|0);
  $23 = HEAP8[$22>>0]|0;
  $24 = ($23<<24>>24)==(0);
  if ($24) {
   $25 = ((($20)) + 32|0);
   $26 = ((($20)) + 52|0);
   ;HEAP32[$26>>2]=HEAP32[$25>>2]|0;HEAP32[$26+4>>2]=HEAP32[$25+4>>2]|0;HEAP32[$26+8>>2]=HEAP32[$25+8>>2]|0;HEAP32[$26+12>>2]=HEAP32[$25+12>>2]|0;
   $27 = ((($20)) + 48|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = ($28|0)==(0|0);
   if ($29) {
    $88 = HEAP32[$20>>2]|0;
    $89 = ((($88)) + 200|0);
    $90 = HEAP32[$89>>2]|0;
    FUNCTION_TABLE_vii[$90 & 8191]($5,$20);
    $91 = ((($5)) + 12|0);
    $92 = +HEAPF32[$91>>2];
    $93 = !($92 >= 0.0);
    do {
     if (!($93)) {
      $94 = ((($20)) + 64|0);
      $95 = +HEAPF32[$94>>2];
      $96 = !($95 >= 0.0);
      if ($96) {
       ;HEAP32[$26>>2]=HEAP32[$5>>2]|0;HEAP32[$26+4>>2]=HEAP32[$5+4>>2]|0;HEAP32[$26+8>>2]=HEAP32[$5+8>>2]|0;
       HEAPF32[$94>>2] = $92;
       break;
      }
      $97 = +HEAPF32[$26>>2];
      $98 = +HEAPF32[$5>>2];
      $99 = $97 - $98;
      $100 = ((($20)) + 56|0);
      $101 = +HEAPF32[$100>>2];
      $102 = ((($5)) + 4|0);
      $103 = +HEAPF32[$102>>2];
      $104 = $101 - $103;
      $105 = ((($20)) + 60|0);
      $106 = +HEAPF32[$105>>2];
      $107 = ((($5)) + 8|0);
      $108 = +HEAPF32[$107>>2];
      $109 = $106 - $108;
      $110 = $99 * $99;
      $111 = $104 * $104;
      $112 = $110 + $111;
      $113 = $109 * $109;
      $114 = $112 + $113;
      $115 = (+Math_sqrt((+$114)));
      $116 = $115;
      $117 = $92;
      $118 = $117 + $116;
      $119 = $95;
      $120 = !($118 <= $119);
      if ($120) {
       $121 = $119 + $116;
       $122 = !($121 <= $117);
       if ($122) {
        $123 = $117 + $121;
        $124 = $123 * 0.5;
        $125 = $124 - $119;
        $126 = $125 / $116;
        $127 = $98 - $97;
        $128 = $127;
        $129 = $128 * $126;
        $130 = $97;
        $131 = $130 + $129;
        $132 = $131;
        HEAPF32[$26>>2] = $132;
        $133 = $103 - $101;
        $134 = $133;
        $135 = $126 * $134;
        $136 = $101;
        $137 = $136 + $135;
        $138 = $137;
        HEAPF32[$100>>2] = $138;
        $139 = $108 - $106;
        $140 = $139;
        $141 = $126 * $140;
        $142 = $106;
        $143 = $142 + $141;
        $144 = $143;
        HEAPF32[$105>>2] = $144;
        $145 = $124;
        HEAPF32[$94>>2] = $145;
        break;
       } else {
        ;HEAP32[$26>>2]=HEAP32[$5>>2]|0;HEAP32[$26+4>>2]=HEAP32[$5+4>>2]|0;HEAP32[$26+8>>2]=HEAP32[$5+8>>2]|0;
        HEAPF32[$94>>2] = $92;
        break;
       }
      }
     }
    } while(0);
   } else {
    $30 = HEAP32[$28>>2]|0;
    $31 = ((($30)) + 140|0);
    $32 = HEAP32[$31>>2]|0;
    FUNCTION_TABLE_viii[$32 & 8191]($4,$28,$20);
    $33 = ((($4)) + 12|0);
    $34 = +HEAPF32[$33>>2];
    $35 = !($34 >= 0.0);
    do {
     if (!($35)) {
      $36 = ((($20)) + 64|0);
      $37 = +HEAPF32[$36>>2];
      $38 = !($37 >= 0.0);
      if ($38) {
       ;HEAP32[$26>>2]=HEAP32[$4>>2]|0;HEAP32[$26+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$26+8>>2]=HEAP32[$4+8>>2]|0;
       HEAPF32[$36>>2] = $34;
       break;
      }
      $39 = +HEAPF32[$26>>2];
      $40 = +HEAPF32[$4>>2];
      $41 = $39 - $40;
      $42 = ((($20)) + 56|0);
      $43 = +HEAPF32[$42>>2];
      $44 = ((($4)) + 4|0);
      $45 = +HEAPF32[$44>>2];
      $46 = $43 - $45;
      $47 = ((($20)) + 60|0);
      $48 = +HEAPF32[$47>>2];
      $49 = ((($4)) + 8|0);
      $50 = +HEAPF32[$49>>2];
      $51 = $48 - $50;
      $52 = $41 * $41;
      $53 = $46 * $46;
      $54 = $52 + $53;
      $55 = $51 * $51;
      $56 = $54 + $55;
      $57 = (+Math_sqrt((+$56)));
      $58 = $57;
      $59 = $34;
      $60 = $59 + $58;
      $61 = $37;
      $62 = !($60 <= $61);
      if ($62) {
       $63 = $61 + $58;
       $64 = !($63 <= $59);
       if ($64) {
        $65 = $59 + $63;
        $66 = $65 * 0.5;
        $67 = $66 - $61;
        $68 = $67 / $58;
        $69 = $40 - $39;
        $70 = $69;
        $71 = $70 * $68;
        $72 = $39;
        $73 = $72 + $71;
        $74 = $73;
        HEAPF32[$26>>2] = $74;
        $75 = $45 - $43;
        $76 = $75;
        $77 = $68 * $76;
        $78 = $43;
        $79 = $78 + $77;
        $80 = $79;
        HEAPF32[$42>>2] = $80;
        $81 = $50 - $48;
        $82 = $81;
        $83 = $68 * $82;
        $84 = $48;
        $85 = $84 + $83;
        $86 = $85;
        HEAPF32[$47>>2] = $86;
        $87 = $66;
        HEAPF32[$36>>2] = $87;
        break;
       } else {
        ;HEAP32[$26>>2]=HEAP32[$4>>2]|0;HEAP32[$26+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$26+8>>2]=HEAP32[$4+8>>2]|0;
        HEAPF32[$36>>2] = $34;
        break;
       }
      }
     }
    } while(0);
   }
   HEAP8[$22>>0] = 1;
  }
 }
 if ($2) {
  $146 = ((($0)) + 124|0);
  __ZN7osgUtil27IncrementalCompileOperation10CompileSet15buildCompileMapERNSt3__23setIPN3osg15GraphicsContextENS2_4lessIS6_EENS2_9allocatorIS6_EEEEj($1,$146,12);
 }
 $147 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
 do {
  if ($147) {
   $148 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
   $149 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($148,111300,46)|0);
   $150 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEPKv($149,$1)|0);
   $151 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($150,146554,2)|0);
   $152 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($151,146554,2)|0);
   $153 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEb($152,$2)|0);
   $154 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($153,174996,1)|0);
   $155 = HEAP32[$154>>2]|0;
   $156 = ((($155)) + -12|0);
   $157 = HEAP32[$156>>2]|0;
   $158 = (($154) + ($157)|0);
   __ZNKSt3__28ios_base6getlocEv($3,$158);
   __THREW__ = 0;
   $159 = (invoke_iii(3255,($3|0),(215188|0))|0);
   $160 = __THREW__; __THREW__ = 0;
   $161 = $160&1;
   if (!($161)) {
    $162 = HEAP32[$159>>2]|0;
    $163 = ((($162)) + 28|0);
    $164 = HEAP32[$163>>2]|0;
    __THREW__ = 0;
    $165 = (invoke_iii($164|0,($159|0),10)|0);
    $166 = __THREW__; __THREW__ = 0;
    $167 = $166&1;
    if (!($167)) {
     __ZNSt3__26localeD2Ev($3);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($154,$165)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($154)|0);
     break;
    }
   }
   $168 = ___cxa_find_matching_catch_2()|0;
   $169 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($3|0));
   $170 = __THREW__; __THREW__ = 0;
   $171 = $170&1;
   if ($171) {
    $172 = ___cxa_find_matching_catch_3(0|0)|0;
    $173 = tempRet0;
    ___clang_call_terminate($172);
    // unreachable;
   } else {
    ___resumeException($168|0);
    // unreachable;
   }
  }
 } while(0);
 $174 = ((($0)) + 76|0);
 $175 = HEAP32[$174>>2]|0;
 $176 = ((($175)) + 8|0);
 $177 = HEAP32[$176>>2]|0;
 (FUNCTION_TABLE_ii[$177 & 8191]($174)|0);
 $178 = ((($1)) + 8|0);
 $179 = HEAP32[$178>>2]|0;HEAP32[$178>>2] = (($179+1)|0);
 $180 = ((($0)) + 88|0);
 __THREW__ = 0;
 $181 = (invoke_ii(3276,12)|0);
 $182 = __THREW__; __THREW__ = 0;
 $183 = $182&1;
 do {
  if ($183) {
   $201 = ___cxa_find_matching_catch_2()|0;
   $202 = tempRet0;
   $203 = HEAP32[$178>>2]|0;HEAP32[$178>>2] = (($203-1)|0);
   $204 = ($203|0)==(1);
   if ($204) {
    __THREW__ = 0;
    invoke_viii(3262,($1|0),1,1);
    $205 = __THREW__; __THREW__ = 0;
    $206 = $205&1;
    if ($206) {
     $212 = ___cxa_find_matching_catch_3(0|0)|0;
     $213 = tempRet0;
     ___clang_call_terminate($212);
     // unreachable;
    } else {
     $$0 = $202;$$011 = $201;
    }
   } else {
    $$0 = $202;$$011 = $201;
   }
  } else {
   $184 = ((($181)) + 8|0);
   HEAP32[$184>>2] = $1;
   $185 = HEAP32[$178>>2]|0;HEAP32[$178>>2] = (($185+1)|0);
   $186 = ((($181)) + 4|0);
   HEAP32[$186>>2] = $180;
   $187 = HEAP32[$180>>2]|0;
   HEAP32[$181>>2] = $187;
   $188 = ((($187)) + 4|0);
   HEAP32[$188>>2] = $181;
   HEAP32[$180>>2] = $181;
   $189 = ((($0)) + 96|0);
   $190 = HEAP32[$189>>2]|0;
   $191 = (($190) + 1)|0;
   HEAP32[$189>>2] = $191;
   $192 = HEAP32[$178>>2]|0;HEAP32[$178>>2] = (($192-1)|0);
   $193 = ($192|0)==(1);
   if ($193) {
    __THREW__ = 0;
    invoke_viii(3262,($1|0),1,1);
    $194 = __THREW__; __THREW__ = 0;
    $195 = $194&1;
    if ($195) {
     $199 = ___cxa_find_matching_catch_2()|0;
     $200 = tempRet0;
     $$0 = $200;$$011 = $199;
     break;
    }
   }
   $196 = HEAP32[$174>>2]|0;
   $197 = ((($196)) + 12|0);
   $198 = HEAP32[$197>>2]|0;
   (FUNCTION_TABLE_ii[$198 & 8191]($174)|0);
   STACKTOP = sp;return;
  }
 } while(0);
 $207 = HEAP32[$174>>2]|0;
 $208 = ((($207)) + 12|0);
 $209 = HEAP32[$208>>2]|0;
 __THREW__ = 0;
 (invoke_ii($209|0,($174|0))|0);
 $210 = __THREW__; __THREW__ = 0;
 $211 = $210&1;
 if ($211) {
  $212 = ___cxa_find_matching_catch_3(0|0)|0;
  $213 = tempRet0;
  ___clang_call_terminate($212);
  // unreachable;
 } else {
  ___resumeException($$011|0);
  // unreachable;
 }
}
function __ZN7osgUtil27IncrementalCompileOperation10CompileSetD2Ev($0) {
 $0 = $0|0;
 var $$1 = 0, $$13 = 0, $$2 = 0, $$24 = 0, $$3 = 0, $$35 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (48488);
 $1 = ((($0)) + 44|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  label = 4;
 } else {
  $4 = ((($2)) + 8|0);
  $5 = HEAP32[$4>>2]|0;HEAP32[$4>>2] = (($5-1)|0);
  $6 = ($5|0)==(1);
  if ($6) {
   __THREW__ = 0;
   invoke_viii(3262,($2|0),1,1);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $42 = ___cxa_find_matching_catch_2()|0;
    $43 = tempRet0;
    $44 = ((($0)) + 32|0);
    $45 = ((($0)) + 36|0);
    $46 = HEAP32[$45>>2]|0;
    __ZNSt3__26__treeINS_12__value_typeIPN3osg15GraphicsContextEN7osgUtil27IncrementalCompileOperation11CompileListEEENS_19__map_value_compareIS4_S8_NS_4lessIS4_EELb1EEENS_9allocatorIS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($44,$46);
    $47 = ((($0)) + 28|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = ($48|0)==(0|0);
    if (!($49)) {
     $50 = HEAP32[$48>>2]|0;
     $51 = ((($50)) + -12|0);
     $52 = HEAP32[$51>>2]|0;
     $53 = (($48) + ($52)|0);
     $54 = ((($53)) + 8|0);
     $55 = HEAP32[$54>>2]|0;HEAP32[$54>>2] = (($55-1)|0);
     $56 = ($55|0)==(1);
     if ($56) {
      __THREW__ = 0;
      invoke_viii(3262,($53|0),1,1);
      $57 = __THREW__; __THREW__ = 0;
      $58 = $57&1;
      if ($58) {
       $81 = ___cxa_find_matching_catch_3(0|0)|0;
       $82 = tempRet0;
       ___clang_call_terminate($81);
       // unreachable;
      }
     }
    }
    HEAP32[$47>>2] = 0;
    $$1 = $43;$$13 = $42;
    label = 20;
   } else {
    label = 4;
   }
  } else {
   label = 4;
  }
 }
 do {
  if ((label|0) == 4) {
   HEAP32[$1>>2] = 0;
   $9 = ((($0)) + 32|0);
   $10 = ((($0)) + 36|0);
   $11 = HEAP32[$10>>2]|0;
   __ZNSt3__26__treeINS_12__value_typeIPN3osg15GraphicsContextEN7osgUtil27IncrementalCompileOperation11CompileListEEENS_19__map_value_compareIS4_S8_NS_4lessIS4_EELb1EEENS_9allocatorIS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($9,$11);
   $12 = ((($0)) + 28|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = ($13|0)==(0|0);
   if (!($14)) {
    $15 = HEAP32[$13>>2]|0;
    $16 = ((($15)) + -12|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = (($13) + ($17)|0);
    $19 = ((($18)) + 8|0);
    $20 = HEAP32[$19>>2]|0;HEAP32[$19>>2] = (($20-1)|0);
    $21 = ($20|0)==(1);
    if ($21) {
     __THREW__ = 0;
     invoke_viii(3262,($18|0),1,1);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      $40 = ___cxa_find_matching_catch_2()|0;
      $41 = tempRet0;
      $$1 = $41;$$13 = $40;
      label = 20;
      break;
     }
    }
   }
   HEAP32[$12>>2] = 0;
   $24 = ((($0)) + 24|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = ($25|0)==(0|0);
   if (!($26)) {
    $27 = ((($25)) + 8|0);
    $28 = HEAP32[$27>>2]|0;HEAP32[$27>>2] = (($28-1)|0);
    $29 = ($28|0)==(1);
    if ($29) {
     __THREW__ = 0;
     invoke_viii(3262,($25|0),1,1);
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      $59 = ___cxa_find_matching_catch_2()|0;
      $60 = tempRet0;
      $$2 = $60;$$24 = $59;
      label = 25;
      break;
     }
    }
   }
   HEAP32[$24>>2] = 0;
   $32 = ((($0)) + 16|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = ($33|0)==(0|0);
   if ($34) {
    HEAP32[$32>>2] = 0;
    __ZN3osg10ReferencedD2Ev($0);
    return;
   }
   $35 = ((($33)) + 8|0);
   $36 = HEAP32[$35>>2]|0;HEAP32[$35>>2] = (($36-1)|0);
   $37 = ($36|0)==(1);
   if (!($37)) {
    HEAP32[$32>>2] = 0;
    __ZN3osg10ReferencedD2Ev($0);
    return;
   }
   __THREW__ = 0;
   invoke_viii(3262,($33|0),1,1);
   $38 = __THREW__; __THREW__ = 0;
   $39 = $38&1;
   if ($39) {
    $69 = ___cxa_find_matching_catch_2()|0;
    $70 = tempRet0;
    $$3 = $70;$$35 = $69;
    break;
   } else {
    HEAP32[$32>>2] = 0;
    __ZN3osg10ReferencedD2Ev($0);
    return;
   }
  }
 } while(0);
 if ((label|0) == 20) {
  $61 = ((($0)) + 24|0);
  $62 = HEAP32[$61>>2]|0;
  $63 = ($62|0)==(0|0);
  if (!($63)) {
   $64 = ((($62)) + 8|0);
   $65 = HEAP32[$64>>2]|0;HEAP32[$64>>2] = (($65-1)|0);
   $66 = ($65|0)==(1);
   if ($66) {
    __THREW__ = 0;
    invoke_viii(3262,($62|0),1,1);
    $67 = __THREW__; __THREW__ = 0;
    $68 = $67&1;
    if ($68) {
     $81 = ___cxa_find_matching_catch_3(0|0)|0;
     $82 = tempRet0;
     ___clang_call_terminate($81);
     // unreachable;
    }
   }
  }
  HEAP32[$61>>2] = 0;
  $$2 = $$1;$$24 = $$13;
  label = 25;
 }
 if ((label|0) == 25) {
  $71 = ((($0)) + 16|0);
  $72 = HEAP32[$71>>2]|0;
  $73 = ($72|0)==(0|0);
  if (!($73)) {
   $74 = ((($72)) + 8|0);
   $75 = HEAP32[$74>>2]|0;HEAP32[$74>>2] = (($75-1)|0);
   $76 = ($75|0)==(1);
   if ($76) {
    __THREW__ = 0;
    invoke_viii(3262,($72|0),1,1);
    $77 = __THREW__; __THREW__ = 0;
    $78 = $77&1;
    if ($78) {
     $81 = ___cxa_find_matching_catch_3(0|0)|0;
     $82 = tempRet0;
     ___clang_call_terminate($81);
     // unreachable;
    }
   }
  }
  HEAP32[$71>>2] = 0;
  $$3 = $$2;$$35 = $$24;
 }
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $79 = __THREW__; __THREW__ = 0;
 $80 = $79&1;
 if ($80) {
  $81 = ___cxa_find_matching_catch_3(0|0)|0;
  $82 = tempRet0;
  ___clang_call_terminate($81);
  // unreachable;
 } else {
  ___resumeException($$35|0);
  // unreachable;
 }
}
function __ZN7osgUtil27IncrementalCompileOperation10CompileSetD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1002,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNSt3__26__treeINS_12__value_typeIPN3osg15GraphicsContextEN7osgUtil27IncrementalCompileOperation11CompileListEEENS_19__map_value_compareIS4_S8_NS_4lessIS4_EELb1EEENS_9allocatorIS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$023$i$i$i$i$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 }
 $3 = HEAP32[$1>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIPN3osg15GraphicsContextEN7osgUtil27IncrementalCompileOperation11CompileListEEENS_19__map_value_compareIS4_S8_NS_4lessIS4_EELb1EEENS_9allocatorIS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($0,$3);
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIPN3osg15GraphicsContextEN7osgUtil27IncrementalCompileOperation11CompileListEEENS_19__map_value_compareIS4_S8_NS_4lessIS4_EELb1EEENS_9allocatorIS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($0,$5);
 $6 = ((($1)) + 20|0);
 $7 = ((($1)) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0);
 L4: do {
  if (!($9)) {
   $10 = ((($1)) + 24|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = HEAP32[$6>>2]|0;
   $13 = ((($12)) + 4|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = HEAP32[$11>>2]|0;
   $16 = ((($15)) + 4|0);
   HEAP32[$16>>2] = $14;
   $17 = HEAP32[$13>>2]|0;
   HEAP32[$17>>2] = $15;
   HEAP32[$7>>2] = 0;
   $18 = ($11|0)==($6|0);
   if (!($18)) {
    $$023$i$i$i$i$i$i = $11;
    while(1) {
     $19 = ((($$023$i$i$i$i$i$i)) + 4|0);
     $20 = HEAP32[$19>>2]|0;
     $21 = ((($$023$i$i$i$i$i$i)) + 8|0);
     $22 = HEAP32[$21>>2]|0;
     $23 = ($22|0)==(0|0);
     if (!($23)) {
      $24 = ((($22)) + 8|0);
      $25 = HEAP32[$24>>2]|0;HEAP32[$24>>2] = (($25-1)|0);
      $26 = ($25|0)==(1);
      if ($26) {
       __THREW__ = 0;
       invoke_viii(3262,($22|0),1,1);
       $27 = __THREW__; __THREW__ = 0;
       $28 = $27&1;
       if ($28) {
        break;
       }
      }
     }
     __ZdlPv($$023$i$i$i$i$i$i);
     $29 = ($20|0)==($6|0);
     if ($29) {
      break L4;
     } else {
      $$023$i$i$i$i$i$i = $20;
     }
    }
    $30 = ___cxa_find_matching_catch_2()|0;
    $31 = tempRet0;
    ___cxa_call_unexpected(($30|0));
    // unreachable;
   }
  }
 } while(0);
 __ZdlPv($1);
 return;
}
function __ZN7osgUtil27IncrementalCompileOperation6removeEPNS0_10CompileSetE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$2 = 0, $$212 = 0, $$sroa$024$0 = 0, $$sroa$024$0$in$in = 0, $$sroa$038$0 = 0, $$sroa$038$0$in$in = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 }
 $3 = ((($0)) + 76|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($4)) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 (FUNCTION_TABLE_ii[$6 & 8191]($3)|0);
 $7 = ((($0)) + 92|0);
 $8 = ((($0)) + 88|0);
 $$sroa$038$0$in$in = $7;
 while(1) {
  $$sroa$038$0 = HEAP32[$$sroa$038$0$in$in>>2]|0;
  $9 = $$sroa$038$0;
  $10 = ($9|0)==($8|0);
  if ($10) {
   break;
  }
  $11 = $$sroa$038$0;
  $12 = ((($11)) + 8|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($13|0)==($1|0);
  $15 = ((($9)) + 4|0);
  if ($14) {
   label = 5;
   break;
  } else {
   $$sroa$038$0$in$in = $15;
  }
 }
 if ((label|0) == 5) {
  $16 = HEAP32[$15>>2]|0;
  $17 = HEAP32[$9>>2]|0;
  $18 = ((($17)) + 4|0);
  HEAP32[$18>>2] = $16;
  $19 = HEAP32[$15>>2]|0;
  HEAP32[$19>>2] = $17;
  $20 = ((($0)) + 96|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = (($21) + -1)|0;
  HEAP32[$20>>2] = $22;
  $23 = ((($9)) + 8|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = ($24|0)==(0|0);
  if (!($25)) {
   $26 = ((($24)) + 8|0);
   $27 = HEAP32[$26>>2]|0;HEAP32[$26>>2] = (($27-1)|0);
   $28 = ($27|0)==(1);
   if ($28) {
    __THREW__ = 0;
    invoke_viii(3262,($24|0),1,1);
    $29 = __THREW__; __THREW__ = 0;
    $30 = $29&1;
    if ($30) {
     $44 = ___cxa_find_matching_catch_2()|0;
     $45 = tempRet0;
     $46 = HEAP32[$3>>2]|0;
     $47 = ((($46)) + 12|0);
     $48 = HEAP32[$47>>2]|0;
     __THREW__ = 0;
     (invoke_ii($48|0,($3|0))|0);
     $49 = __THREW__; __THREW__ = 0;
     $50 = $49&1;
     if ($50) {
      $84 = ___cxa_find_matching_catch_3(0|0)|0;
      $85 = tempRet0;
      ___clang_call_terminate($84);
      // unreachable;
     } else {
      $$2 = $44;$$212 = $45;
      ___resumeException($$2|0);
      // unreachable;
     }
    }
   }
  }
  $31 = $$sroa$038$0;
  __ZdlPv($31);
  $32 = HEAP32[$3>>2]|0;
  $33 = ((($32)) + 12|0);
  $34 = HEAP32[$33>>2]|0;
  (FUNCTION_TABLE_ii[$34 & 8191]($3)|0);
  return;
 }
 $35 = HEAP32[$3>>2]|0;
 $36 = ((($35)) + 12|0);
 $37 = HEAP32[$36>>2]|0;
 (FUNCTION_TABLE_ii[$37 & 8191]($3)|0);
 $38 = ((($0)) + 100|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = ((($39)) + 8|0);
 $41 = HEAP32[$40>>2]|0;
 (FUNCTION_TABLE_ii[$41 & 8191]($38)|0);
 $42 = ((($0)) + 116|0);
 $43 = ((($0)) + 112|0);
 $$sroa$024$0$in$in = $42;
 while(1) {
  $$sroa$024$0 = HEAP32[$$sroa$024$0$in$in>>2]|0;
  $51 = $$sroa$024$0;
  $52 = ($51|0)==($43|0);
  if ($52) {
   break;
  }
  $53 = $$sroa$024$0;
  $54 = ((($53)) + 8|0);
  $55 = HEAP32[$54>>2]|0;
  $56 = ($55|0)==($1|0);
  $57 = ((($51)) + 4|0);
  if ($56) {
   label = 13;
   break;
  } else {
   $$sroa$024$0$in$in = $57;
  }
 }
 if ((label|0) == 13) {
  $58 = HEAP32[$57>>2]|0;
  $59 = HEAP32[$51>>2]|0;
  $60 = ((($59)) + 4|0);
  HEAP32[$60>>2] = $58;
  $61 = HEAP32[$57>>2]|0;
  HEAP32[$61>>2] = $59;
  $62 = ((($0)) + 120|0);
  $63 = HEAP32[$62>>2]|0;
  $64 = (($63) + -1)|0;
  HEAP32[$62>>2] = $64;
  $65 = ((($51)) + 8|0);
  $66 = HEAP32[$65>>2]|0;
  $67 = ($66|0)==(0|0);
  if (!($67)) {
   $68 = ((($66)) + 8|0);
   $69 = HEAP32[$68>>2]|0;HEAP32[$68>>2] = (($69-1)|0);
   $70 = ($69|0)==(1);
   if ($70) {
    __THREW__ = 0;
    invoke_viii(3262,($66|0),1,1);
    $71 = __THREW__; __THREW__ = 0;
    $72 = $71&1;
    if ($72) {
     $74 = ___cxa_find_matching_catch_2()|0;
     $75 = tempRet0;
     $76 = HEAP32[$38>>2]|0;
     $77 = ((($76)) + 12|0);
     $78 = HEAP32[$77>>2]|0;
     __THREW__ = 0;
     (invoke_ii($78|0,($38|0))|0);
     $79 = __THREW__; __THREW__ = 0;
     $80 = $79&1;
     if ($80) {
      $84 = ___cxa_find_matching_catch_3(0|0)|0;
      $85 = tempRet0;
      ___clang_call_terminate($84);
      // unreachable;
     } else {
      $$2 = $74;$$212 = $75;
      ___resumeException($$2|0);
      // unreachable;
     }
    }
   }
  }
  $73 = $$sroa$024$0;
  __ZdlPv($73);
 }
 $81 = HEAP32[$38>>2]|0;
 $82 = ((($81)) + 12|0);
 $83 = HEAP32[$82>>2]|0;
 (FUNCTION_TABLE_ii[$83 & 8191]($38)|0);
 return;
}
function __ZN7osgUtil27IncrementalCompileOperation22mergeCompiledSubgraphsEPKN3osg10FrameStampE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$023$i$i = 0, $$08 = 0, $$sroa$014$0 = 0, $$sroa$014$030 = 0, $$sroa$014$031 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = ((($0)) + 100|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($4)) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 (FUNCTION_TABLE_ii[$6 & 8191]($3)|0);
 $7 = ($1|0)==(0|0);
 if (!($7)) {
  $8 = ((($1)) + 12|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ((($0)) + 64|0);
  HEAP32[$10>>2] = $9;
 }
 $11 = ((($0)) + 112|0);
 $12 = ((($0)) + 116|0);
 $$sroa$014$030 = HEAP32[$12>>2]|0;
 $13 = $$sroa$014$030;
 $14 = ($13|0)==($11|0);
 L4: do {
  if (!($14)) {
   $$sroa$014$031 = $$sroa$014$030;$74 = $13;
   while(1) {
    $42 = $$sroa$014$031;
    $43 = ((($42)) + 8|0);
    $44 = HEAP32[$43>>2]|0;
    HEAP32[$2>>2] = 0;
    $45 = ((($44)) + 16|0);
    __THREW__ = 0;
    $46 = (invoke_iii(3561,($45|0),($2|0))|0);
    $47 = __THREW__; __THREW__ = 0;
    $48 = $47&1;
    if ($48) {
     label = 16;
     break;
    }
    if ($46) {
     $49 = HEAP32[$2>>2]|0;
     $50 = HEAP32[$49>>2]|0;
     $51 = ((($50)) + 204|0);
     $52 = HEAP32[$51>>2]|0;
     $53 = ((($44)) + 24|0);
     $54 = HEAP32[$53>>2]|0;
     __THREW__ = 0;
     (invoke_iii($52|0,($49|0),($54|0))|0);
     $55 = __THREW__; __THREW__ = 0;
     $56 = $55&1;
     if ($56) {
      label = 16;
      break;
     }
    }
    $66 = HEAP32[$2>>2]|0;
    $67 = ($66|0)==(0|0);
    if (!($67)) {
     $68 = ((($66)) + 8|0);
     $69 = HEAP32[$68>>2]|0;HEAP32[$68>>2] = (($69-1)|0);
     $70 = ($69|0)==(1);
     if ($70) {
      __THREW__ = 0;
      invoke_viii(3262,($66|0),1,1);
      $71 = __THREW__; __THREW__ = 0;
      $72 = $71&1;
      if ($72) {
       label = 24;
       break;
      }
     }
    }
    $73 = ((($74)) + 4|0);
    $$sroa$014$0 = HEAP32[$73>>2]|0;
    $75 = $$sroa$014$0;
    $76 = ($75|0)==($11|0);
    if ($76) {
     break L4;
    } else {
     $$sroa$014$031 = $$sroa$014$0;$74 = $75;
    }
   }
   if ((label|0) == 16) {
    $57 = ___cxa_find_matching_catch_2()|0;
    $58 = tempRet0;
    $59 = HEAP32[$2>>2]|0;
    $60 = ($59|0)==(0|0);
    if (!($60)) {
     $61 = ((($59)) + 8|0);
     $62 = HEAP32[$61>>2]|0;HEAP32[$61>>2] = (($62-1)|0);
     $63 = ($62|0)==(1);
     if ($63) {
      __THREW__ = 0;
      invoke_viii(3262,($59|0),1,1);
      $64 = __THREW__; __THREW__ = 0;
      $65 = $64&1;
      if ($65) {
       $84 = ___cxa_find_matching_catch_3(0|0)|0;
       $85 = tempRet0;
       ___clang_call_terminate($84);
       // unreachable;
      }
     }
    }
    HEAP32[$2>>2] = 0;
    $$0 = $57;$$08 = $58;
   }
   else if ((label|0) == 24) {
    $77 = ___cxa_find_matching_catch_2()|0;
    $78 = tempRet0;
    $$0 = $77;$$08 = $78;
   }
   $79 = HEAP32[$3>>2]|0;
   $80 = ((($79)) + 12|0);
   $81 = HEAP32[$80>>2]|0;
   __THREW__ = 0;
   (invoke_ii($81|0,($3|0))|0);
   $82 = __THREW__; __THREW__ = 0;
   $83 = $82&1;
   if ($83) {
    $84 = ___cxa_find_matching_catch_3(0|0)|0;
    $85 = tempRet0;
    ___clang_call_terminate($84);
    // unreachable;
   } else {
    ___resumeException($$0|0);
    // unreachable;
   }
  }
 } while(0);
 $15 = ((($0)) + 120|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==(0);
 if ($17) {
  $39 = HEAP32[$3>>2]|0;
  $40 = ((($39)) + 12|0);
  $41 = HEAP32[$40>>2]|0;
  (FUNCTION_TABLE_ii[$41 & 8191]($3)|0);
  STACKTOP = sp;return;
 }
 $18 = HEAP32[$12>>2]|0;
 $19 = HEAP32[$11>>2]|0;
 $20 = ((($19)) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = HEAP32[$18>>2]|0;
 $23 = ((($22)) + 4|0);
 HEAP32[$23>>2] = $21;
 $24 = HEAP32[$20>>2]|0;
 HEAP32[$24>>2] = $22;
 HEAP32[$15>>2] = 0;
 $25 = ($18|0)==($11|0);
 if ($25) {
  $39 = HEAP32[$3>>2]|0;
  $40 = ((($39)) + 12|0);
  $41 = HEAP32[$40>>2]|0;
  (FUNCTION_TABLE_ii[$41 & 8191]($3)|0);
  STACKTOP = sp;return;
 } else {
  $$023$i$i = $18;
 }
 while(1) {
  $26 = ((($$023$i$i)) + 4|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = ((($$023$i$i)) + 8|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = ($29|0)==(0|0);
  if (!($30)) {
   $31 = ((($29)) + 8|0);
   $32 = HEAP32[$31>>2]|0;HEAP32[$31>>2] = (($32-1)|0);
   $33 = ($32|0)==(1);
   if ($33) {
    __THREW__ = 0;
    invoke_viii(3262,($29|0),1,1);
    $34 = __THREW__; __THREW__ = 0;
    $35 = $34&1;
    if ($35) {
     label = 11;
     break;
    }
   }
  }
  __ZdlPv($$023$i$i);
  $36 = ($27|0)==($11|0);
  if ($36) {
   label = 12;
   break;
  } else {
   $$023$i$i = $27;
  }
 }
 if ((label|0) == 11) {
  $37 = ___cxa_find_matching_catch_2()|0;
  $38 = tempRet0;
  ___cxa_call_unexpected(($37|0));
  // unreachable;
 }
 else if ((label|0) == 12) {
  $39 = HEAP32[$3>>2]|0;
  $40 = ((($39)) + 12|0);
  $41 = HEAP32[$40>>2]|0;
  (FUNCTION_TABLE_ii[$41 & 8191]($3)|0);
  STACKTOP = sp;return;
 }
}
function __ZNK3osg12observer_ptrINS_5GroupEE4lockERNS_7ref_ptrIS1_EE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  $4 = HEAP32[$1>>2]|0;
  $5 = ($4|0)==(0|0);
  if ($5) {
   $$1 = 0;
   return ($$1|0);
  }
  HEAP32[$1>>2] = 0;
  $6 = ((($4)) + 8|0);
  $7 = HEAP32[$6>>2]|0;HEAP32[$6>>2] = (($7-1)|0);
  $8 = ($7|0)==(1);
  if (!($8)) {
   $$1 = 0;
   return ($$1|0);
  }
  __ZNK3osg10Referenced24signalObserversAndDeleteEbb($4,1,1);
  $$1 = 0;
  return ($$1|0);
 }
 $9 = (__ZN3osg11ObserverSet10addRefLockEv($2)|0);
 $10 = ($9|0)==(0|0);
 if ($10) {
  $11 = HEAP32[$1>>2]|0;
  $12 = ($11|0)==(0|0);
  if ($12) {
   $$1 = 0;
   return ($$1|0);
  }
  HEAP32[$1>>2] = 0;
  $13 = ((($11)) + 8|0);
  $14 = HEAP32[$13>>2]|0;HEAP32[$13>>2] = (($14-1)|0);
  $15 = ($14|0)==(1);
  if (!($15)) {
   $$1 = 0;
   return ($$1|0);
  }
  __ZNK3osg10Referenced24signalObserversAndDeleteEbb($11,1,1);
  $$1 = 0;
  return ($$1|0);
 }
 $16 = ((($0)) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = HEAP32[$1>>2]|0;
 $19 = ($18|0)==($17|0);
 if (!($19)) {
  HEAP32[$1>>2] = $17;
  $20 = ($17|0)==(0|0);
  if (!($20)) {
   $21 = ((($17)) + 8|0);
   $22 = HEAP32[$21>>2]|0;HEAP32[$21>>2] = (($22+1)|0);
  }
  $23 = ($18|0)==(0|0);
  if (!($23)) {
   $24 = ((($18)) + 8|0);
   $25 = HEAP32[$24>>2]|0;HEAP32[$24>>2] = (($25-1)|0);
   $26 = ($25|0)==(1);
   if ($26) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($18,1,1);
   }
  }
 }
 (__ZNK3osg10Referenced14unref_nodeleteEv($9)|0);
 $27 = HEAP32[$1>>2]|0;
 $28 = ($27|0)!=(0|0);
 $$1 = $28;
 return ($$1|0);
}
function __ZN7osgUtil22LineSegmentIntersectorD2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (48508);
 $1 = ((($0)) + 80|0);
 $2 = ((($0)) + 84|0);
 $3 = HEAP32[$2>>2]|0;
 __ZNSt3__26__treeIN7osgUtil22LineSegmentIntersector12IntersectionENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($1,$3);
 __ZN3osg10ReferencedD2Ev($0);
 return;
}
function __ZN7osgUtil22LineSegmentIntersectorD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (48508);
 $1 = ((($0)) + 80|0);
 $2 = ((($0)) + 84|0);
 $3 = HEAP32[$2>>2]|0;
 __ZNSt3__26__treeIN7osgUtil22LineSegmentIntersector12IntersectionENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($1,$3);
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch_2()|0;
  $7 = tempRet0;
  __ZdlPv($0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZN7osgUtil22LineSegmentIntersector5cloneERNS_19IntersectionVisitorE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$2 = 0, $$210 = 0, $$3 = 0, $$311 = 0, $$pn$in = 0, $$sroa$0$0$$sroa_idx = 0, $$sroa$031$0$$sroa_idx = 0, $$sroa$5$0$$sroa_idx27 = 0, $$sroa$534$0$$sroa_idx37 = 0, $$sroa$6$0$$sroa_idx30 = 0, $$sroa$638$0$$sroa_idx41 = 0, $10 = 0, $100 = 0.0, $101 = 0.0, $102 = 0.0, $103 = 0.0, $104 = 0.0, $105 = 0, $106 = 0, $107 = 0.0;
 var $108 = 0.0, $109 = 0.0, $11 = 0, $110 = 0.0, $111 = 0.0, $112 = 0.0, $113 = 0.0, $114 = 0.0, $115 = 0.0, $116 = 0.0, $117 = 0.0, $118 = 0.0, $119 = 0.0, $12 = 0, $120 = 0.0, $121 = 0.0, $122 = 0.0, $123 = 0.0, $124 = 0.0, $125 = 0.0;
 var $126 = 0.0, $127 = 0.0, $128 = 0.0, $129 = 0.0, $13 = 0, $130 = 0.0, $131 = 0.0, $132 = 0.0, $133 = 0.0, $134 = 0.0, $135 = 0.0, $136 = 0.0, $137 = 0.0, $138 = 0.0, $139 = 0.0, $14 = 0, $140 = 0.0, $141 = 0.0, $142 = 0.0, $143 = 0.0;
 var $144 = 0.0, $145 = 0.0, $146 = 0.0, $147 = 0.0, $148 = 0.0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0;
 var $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0.0, $5 = 0, $50 = 0, $51 = 0.0, $52 = 0.0, $53 = 0, $54 = 0.0, $55 = 0, $56 = 0.0, $57 = 0.0;
 var $58 = 0.0, $59 = 0, $6 = 0, $60 = 0.0, $61 = 0, $62 = 0.0, $63 = 0.0, $64 = 0.0, $65 = 0, $66 = 0.0, $67 = 0.0, $68 = 0.0, $69 = 0.0, $7 = 0, $70 = 0, $71 = 0.0, $72 = 0, $73 = 0.0, $74 = 0, $75 = 0.0;
 var $76 = 0, $77 = 0.0, $78 = 0, $79 = 0.0, $8 = 0, $80 = 0, $81 = 0.0, $82 = 0, $83 = 0.0, $84 = 0, $85 = 0.0, $86 = 0, $87 = 0.0, $88 = 0, $89 = 0.0, $9 = 0, $90 = 0, $91 = 0.0, $92 = 0, $93 = 0.0;
 var $94 = 0.0, $95 = 0, $96 = 0.0, $97 = 0.0, $98 = 0.0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(128|0);
 $2 = sp;
 $3 = ((($0)) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(3);
 do {
  if ($5) {
   $6 = ((($1)) + 120|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($7|0)==(0);
   if (!($8)) {
    $9 = ((($1)) + 112|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = ((($10)) + 8|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ($12|0)==(0|0);
    if (!($13)) {
     break;
    }
   }
   $14 = (__Znwj(96)|0);
   __THREW__ = 0;
   invoke_vi(3282,($14|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if ($16) {
    $37 = ___cxa_find_matching_catch_2()|0;
    $38 = tempRet0;
    __ZdlPv($14);
    $$3 = $38;$$311 = $37;
    ___resumeException($$311|0);
    // unreachable;
   }
   $17 = ((($0)) + 56|0);
   $18 = ((($0)) + 32|0);
   $19 = ((($14)) + 12|0);
   HEAP32[$19>>2] = 3;
   $20 = ((($14)) + 16|0);
   HEAP32[$20>>2] = 0;
   $21 = ((($14)) + 20|0);
   HEAP32[$21>>2] = 0;
   $22 = ((($14)) + 24|0);
   HEAP32[$22>>2] = 0;
   HEAP32[$14>>2] = (48508);
   $23 = ((($14)) + 28|0);
   HEAP32[$23>>2] = 0;
   $24 = ((($14)) + 32|0);
   ;HEAP32[$24>>2]=HEAP32[$18>>2]|0;HEAP32[$24+4>>2]=HEAP32[$18+4>>2]|0;HEAP32[$24+8>>2]=HEAP32[$18+8>>2]|0;HEAP32[$24+12>>2]=HEAP32[$18+12>>2]|0;HEAP32[$24+16>>2]=HEAP32[$18+16>>2]|0;HEAP32[$24+20>>2]=HEAP32[$18+20>>2]|0;
   $25 = ((($14)) + 56|0);
   ;HEAP32[$25>>2]=HEAP32[$17>>2]|0;HEAP32[$25+4>>2]=HEAP32[$17+4>>2]|0;HEAP32[$25+8>>2]=HEAP32[$17+8>>2]|0;HEAP32[$25+12>>2]=HEAP32[$17+12>>2]|0;HEAP32[$25+16>>2]=HEAP32[$17+16>>2]|0;HEAP32[$25+20>>2]=HEAP32[$17+20>>2]|0;
   $26 = ((($14)) + 84|0);
   HEAP32[$26>>2] = 0;
   $27 = ((($14)) + 88|0);
   HEAP32[$27>>2] = 0;
   $28 = ((($14)) + 80|0);
   HEAP32[$28>>2] = $26;
   $29 = ((($14)) + 8|0);
   $30 = HEAP32[$29>>2]|0;HEAP32[$29>>2] = (($30+1)|0);
   HEAP32[$23>>2] = $0;
   $31 = ((($0)) + 16|0);
   $32 = HEAP32[$31>>2]|0;
   HEAP32[$20>>2] = $32;
   $33 = ((($0)) + 24|0);
   $34 = HEAP32[$33>>2]|0;
   HEAP32[$22>>2] = $34;
   __THREW__ = 0;
   (invoke_ii(3335,($14|0))|0);
   $35 = __THREW__; __THREW__ = 0;
   $36 = $35&1;
   if (!($36)) {
    $$pn$in = $14;
    STACKTOP = sp;return ($$pn$in|0);
   }
   $39 = ___cxa_find_matching_catch_2()|0;
   $40 = tempRet0;
   $41 = HEAP32[$29>>2]|0;HEAP32[$29>>2] = (($41-1)|0);
   $42 = ($41|0)==(1);
   if ($42) {
    __THREW__ = 0;
    invoke_viii(3262,($14|0),1,1);
    $43 = __THREW__; __THREW__ = 0;
    $44 = $43&1;
    if ($44) {
     $175 = ___cxa_find_matching_catch_3(0|0)|0;
     $176 = tempRet0;
     ___clang_call_terminate($175);
     // unreachable;
    }
   }
   $$3 = $40;$$311 = $39;
   ___resumeException($$311|0);
   // unreachable;
  }
 } while(0);
 __ZN7osgUtil22LineSegmentIntersector17getTransformationERNS_19IntersectionVisitorENS_11Intersector15CoordinateFrameE($2,$1,$4);
 __THREW__ = 0;
 $45 = (invoke_ii(3276,96)|0);
 $46 = __THREW__; __THREW__ = 0;
 $47 = $46&1;
 do {
  if ($47) {
   $165 = ___cxa_find_matching_catch_2()|0;
   $166 = tempRet0;
   $$2 = $166;$$210 = $165;
  } else {
   $48 = ((($2)) + 24|0);
   $49 = +HEAPF64[$48>>3];
   $50 = ((($0)) + 32|0);
   $51 = +HEAPF64[$50>>3];
   $52 = $49 * $51;
   $53 = ((($2)) + 56|0);
   $54 = +HEAPF64[$53>>3];
   $55 = ((($0)) + 40|0);
   $56 = +HEAPF64[$55>>3];
   $57 = $54 * $56;
   $58 = $52 + $57;
   $59 = ((($2)) + 88|0);
   $60 = +HEAPF64[$59>>3];
   $61 = ((($0)) + 48|0);
   $62 = +HEAPF64[$61>>3];
   $63 = $60 * $62;
   $64 = $58 + $63;
   $65 = ((($2)) + 120|0);
   $66 = +HEAPF64[$65>>3];
   $67 = $66 + $64;
   $68 = 1.0 / $67;
   $69 = +HEAPF64[$2>>3];
   $70 = ((($2)) + 32|0);
   $71 = +HEAPF64[$70>>3];
   $72 = ((($2)) + 64|0);
   $73 = +HEAPF64[$72>>3];
   $74 = ((($2)) + 96|0);
   $75 = +HEAPF64[$74>>3];
   $76 = ((($2)) + 8|0);
   $77 = +HEAPF64[$76>>3];
   $78 = ((($2)) + 40|0);
   $79 = +HEAPF64[$78>>3];
   $80 = ((($2)) + 72|0);
   $81 = +HEAPF64[$80>>3];
   $82 = ((($2)) + 104|0);
   $83 = +HEAPF64[$82>>3];
   $84 = ((($2)) + 16|0);
   $85 = +HEAPF64[$84>>3];
   $86 = ((($2)) + 48|0);
   $87 = +HEAPF64[$86>>3];
   $88 = ((($2)) + 80|0);
   $89 = +HEAPF64[$88>>3];
   $90 = ((($2)) + 112|0);
   $91 = +HEAPF64[$90>>3];
   $92 = ((($0)) + 56|0);
   $93 = +HEAPF64[$92>>3];
   $94 = $49 * $93;
   $95 = ((($0)) + 64|0);
   $96 = +HEAPF64[$95>>3];
   $97 = $54 * $96;
   $98 = $94 + $97;
   $99 = ((($0)) + 72|0);
   $100 = +HEAPF64[$99>>3];
   $101 = $60 * $100;
   $102 = $98 + $101;
   $103 = $66 + $102;
   $104 = 1.0 / $103;
   __THREW__ = 0;
   invoke_vi(3282,($45|0));
   $105 = __THREW__; __THREW__ = 0;
   $106 = $105&1;
   if ($106) {
    $167 = ___cxa_find_matching_catch_2()|0;
    $168 = tempRet0;
    __ZdlPv($45);
    $$2 = $168;$$210 = $167;
    break;
   }
   $107 = $85 * $93;
   $108 = $87 * $96;
   $109 = $107 + $108;
   $110 = $89 * $100;
   $111 = $109 + $110;
   $112 = $91 + $111;
   $113 = $112 * $104;
   $114 = $77 * $93;
   $115 = $79 * $96;
   $116 = $114 + $115;
   $117 = $81 * $100;
   $118 = $116 + $117;
   $119 = $83 + $118;
   $120 = $119 * $104;
   $121 = $69 * $93;
   $122 = $71 * $96;
   $123 = $121 + $122;
   $124 = $73 * $100;
   $125 = $123 + $124;
   $126 = $75 + $125;
   $127 = $126 * $104;
   $128 = $51 * $85;
   $129 = $56 * $87;
   $130 = $128 + $129;
   $131 = $62 * $89;
   $132 = $130 + $131;
   $133 = $91 + $132;
   $134 = $68 * $133;
   $135 = $51 * $77;
   $136 = $56 * $79;
   $137 = $135 + $136;
   $138 = $62 * $81;
   $139 = $137 + $138;
   $140 = $83 + $139;
   $141 = $68 * $140;
   $142 = $51 * $69;
   $143 = $56 * $71;
   $144 = $142 + $143;
   $145 = $62 * $73;
   $146 = $144 + $145;
   $147 = $75 + $146;
   $148 = $68 * $147;
   $149 = ((($45)) + 12|0);
   HEAP32[$149>>2] = 3;
   $150 = ((($45)) + 16|0);
   HEAP32[$150>>2] = 0;
   $151 = ((($45)) + 20|0);
   HEAP32[$151>>2] = 0;
   $152 = ((($45)) + 24|0);
   HEAP32[$152>>2] = 0;
   HEAP32[$45>>2] = (48508);
   $153 = ((($45)) + 28|0);
   HEAP32[$153>>2] = 0;
   $$sroa$031$0$$sroa_idx = ((($45)) + 32|0);
   HEAPF64[$$sroa$031$0$$sroa_idx>>3] = $148;
   $$sroa$534$0$$sroa_idx37 = ((($45)) + 40|0);
   HEAPF64[$$sroa$534$0$$sroa_idx37>>3] = $141;
   $$sroa$638$0$$sroa_idx41 = ((($45)) + 48|0);
   HEAPF64[$$sroa$638$0$$sroa_idx41>>3] = $134;
   $$sroa$0$0$$sroa_idx = ((($45)) + 56|0);
   HEAPF64[$$sroa$0$0$$sroa_idx>>3] = $127;
   $$sroa$5$0$$sroa_idx27 = ((($45)) + 64|0);
   HEAPF64[$$sroa$5$0$$sroa_idx27>>3] = $120;
   $$sroa$6$0$$sroa_idx30 = ((($45)) + 72|0);
   HEAPF64[$$sroa$6$0$$sroa_idx30>>3] = $113;
   $154 = ((($45)) + 84|0);
   HEAP32[$154>>2] = 0;
   $155 = ((($45)) + 88|0);
   HEAP32[$155>>2] = 0;
   $156 = ((($45)) + 80|0);
   HEAP32[$156>>2] = $154;
   $157 = ((($45)) + 8|0);
   $158 = HEAP32[$157>>2]|0;HEAP32[$157>>2] = (($158+1)|0);
   HEAP32[$153>>2] = $0;
   $159 = ((($0)) + 16|0);
   $160 = HEAP32[$159>>2]|0;
   HEAP32[$150>>2] = $160;
   $161 = ((($0)) + 24|0);
   $162 = HEAP32[$161>>2]|0;
   HEAP32[$152>>2] = $162;
   __THREW__ = 0;
   (invoke_ii(3335,($45|0))|0);
   $163 = __THREW__; __THREW__ = 0;
   $164 = $163&1;
   if (!($164)) {
    $$pn$in = $45;
    STACKTOP = sp;return ($$pn$in|0);
   }
   $169 = ___cxa_find_matching_catch_2()|0;
   $170 = tempRet0;
   $171 = HEAP32[$157>>2]|0;HEAP32[$157>>2] = (($171-1)|0);
   $172 = ($171|0)==(1);
   if ($172) {
    __THREW__ = 0;
    invoke_viii(3262,($45|0),1,1);
    $173 = __THREW__; __THREW__ = 0;
    $174 = $173&1;
    if ($174) {
     $175 = ___cxa_find_matching_catch_3(0|0)|0;
     $176 = tempRet0;
     ___clang_call_terminate($175);
     // unreachable;
    } else {
     $$2 = $170;$$210 = $169;
    }
   } else {
    $$2 = $170;$$210 = $169;
   }
  }
 } while(0);
 $$3 = $$2;$$311 = $$210;
 ___resumeException($$311|0);
 // unreachable;
 return (0)|0;
}
function __ZN7osgUtil22LineSegmentIntersector5enterERKN3osg4NodeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0.0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(2);
 if ($4) {
  $5 = HEAP32[$0>>2]|0;
  $6 = ((($5)) + 32|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (FUNCTION_TABLE_ii[$7 & 8191]($0)|0);
  if ($8) {
   $$0 = 0;
   return ($$0|0);
  }
 }
 $9 = ((($1)) + 108|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0);
 if (!($11)) {
  $$0 = 1;
  return ($$0|0);
 }
 $12 = ((($1)) + 104|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = ($13<<24>>24)==(0);
 if ($14) {
  $$0 = 1;
  return ($$0|0);
 }
 $15 = (__ZNK3osg4Node8getBoundEv($1)|0);
 $16 = ((($15)) + 12|0);
 $17 = +HEAPF32[$16>>2];
 $18 = !($17 >= 0.0);
 if ($18) {
  $$0 = 1;
  return ($$0|0);
 }
 $19 = (__ZNK3osg4Node8getBoundEv($1)|0);
 $20 = (__ZN7osgUtil22LineSegmentIntersector10intersectsERKN3osg18BoundingSphereImplINS1_5Vec3fEEE($0,$19)|0);
 $$0 = $20;
 return ($$0|0);
}
function __ZN7osgUtil22LineSegmentIntersector5leaveEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN7osgUtil22LineSegmentIntersector9intersectERNS_19IntersectionVisitorEPN3osg8DrawableE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0.0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $3 = sp + 24|0;
 $4 = sp;
 $5 = ((($0)) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(2);
 if ($7) {
  $8 = HEAP32[$0>>2]|0;
  $9 = ((($8)) + 32|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (FUNCTION_TABLE_ii[$10 & 8191]($0)|0);
  if ($11) {
   STACKTOP = sp;return;
  }
 }
 $12 = ((($0)) + 32|0);
 ;HEAP32[$3>>2]=HEAP32[$12>>2]|0;HEAP32[$3+4>>2]=HEAP32[$12+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$12+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$12+12>>2]|0;HEAP32[$3+16>>2]=HEAP32[$12+16>>2]|0;HEAP32[$3+20>>2]=HEAP32[$12+20>>2]|0;
 $13 = ((($0)) + 56|0);
 ;HEAP32[$4>>2]=HEAP32[$13>>2]|0;HEAP32[$4+4>>2]=HEAP32[$13+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$13+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$13+12>>2]|0;HEAP32[$4+16>>2]=HEAP32[$13+16>>2]|0;HEAP32[$4+20>>2]=HEAP32[$13+20>>2]|0;
 $14 = ((($2)) + 108|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0);
 if ($16) {
  $17 = ((($2)) + 104|0);
  $18 = HEAP8[$17>>0]|0;
  $19 = ($18<<24>>24)==(0);
  if ($19) {
   label = 7;
  } else {
   $20 = (__ZNK3osg4Node8getBoundEv($2)|0);
   $21 = ((($20)) + 12|0);
   $22 = +HEAPF32[$21>>2];
   $23 = !($22 >= 0.0);
   if ($23) {
    label = 7;
   } else {
    $24 = (__ZNK3osg8Drawable14getBoundingBoxEv($2)|0);
    $25 = (__ZN7osgUtil22LineSegmentIntersector16intersectAndClipERN3osg5Vec3dES3_RKNS1_15BoundingBoxImplINS1_5Vec3fEEE(0,$3,$4,$24)|0);
    if ($25) {
     label = 7;
    }
   }
  }
 } else {
  label = 7;
 }
 if ((label|0) == 7) {
  $26 = ((($1)) + 69|0);
  $27 = HEAP8[$26>>0]|0;
  $28 = ($27<<24>>24)==(0);
  if ($28) {
   $29 = HEAP32[$0>>2]|0;
   $30 = ((($29)) + 36|0);
   $31 = HEAP32[$30>>2]|0;
   FUNCTION_TABLE_viiiii[$31 & 8191]($0,$1,$2,$3,$4);
  }
 }
 STACKTOP = sp;return;
}
function __ZN7osgUtil22LineSegmentIntersector5resetEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 20|0);
 HEAP32[$1>>2] = 0;
 $2 = ((($0)) + 80|0);
 $3 = ((($0)) + 84|0);
 $4 = HEAP32[$3>>2]|0;
 __ZNSt3__26__treeIN7osgUtil22LineSegmentIntersector12IntersectionENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($2,$4);
 $5 = ((($0)) + 88|0);
 HEAP32[$5>>2] = 0;
 HEAP32[$2>>2] = $3;
 HEAP32[$3>>2] = 0;
 return;
}
function __ZN7osgUtil22LineSegmentIntersector21containsIntersectionsEv($0) {
 $0 = $0|0;
 var $$$i = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 $$$i = $3 ? $0 : $2;
 $4 = ((($$$i)) + 88|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)!=(0);
 return ($6|0);
}
function __ZN7osgUtil22LineSegmentIntersector9intersectERNS_19IntersectionVisitorEPN3osg8DrawableERKNS3_5Vec3dES8_($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0 = 0, $$026 = 0, $$1 = 0, $$127 = 0, $$4 = 0, $$430 = 0, $$5 = 0, $$531 = 0, $$off = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0;
 var $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0;
 var $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i34 = 0, $scevgep$i$i$i$i$i42 = 0, $scevgep$i$i$i$i$i46 = 0;
 var $scevgep5$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i35 = 0, $scevgep5$i$i$i$i$i43 = 0, $scevgep5$i$i$i$i$i47 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 336|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(336|0);
 $5 = sp;
 $6 = sp + 208|0;
 $7 = ((($0)) + 16|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(2);
 if ($9) {
  $10 = HEAP32[$0>>2]|0;
  $11 = ((($10)) + 32|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (FUNCTION_TABLE_ii[$12 & 8191]($0)|0);
  if ($13) {
   STACKTOP = sp;return;
  }
 }
 $14 = (__Znwj(32)|0);
 __THREW__ = 0;
 invoke_vi(3282,($14|0));
 $15 = __THREW__; __THREW__ = 0;
 $16 = $15&1;
 if ($16) {
  $37 = ___cxa_find_matching_catch_2()|0;
  $38 = tempRet0;
  __ZdlPv($14);
  $$5 = $37;$$531 = $38;
  ___resumeException($$5|0);
  // unreachable;
 }
 HEAP32[$14>>2] = (48556);
 $17 = ((($14)) + 12|0);
 ;HEAP32[$17>>2]=0|0;HEAP32[$17+4>>2]=0|0;HEAP32[$17+8>>2]=0|0;HEAP32[$17+12>>2]=0|0;HEAP8[$17+16>>0]=0|0;
 $18 = ((($14)) + 8|0);
 $19 = HEAP32[$18>>2]|0;HEAP32[$18>>2] = (($19+1)|0);
 HEAP32[$17>>2] = $0;
 $20 = ((($14)) + 16|0);
 HEAP32[$20>>2] = $1;
 $21 = ((($14)) + 20|0);
 HEAP32[$21>>2] = $2;
 $22 = HEAP32[$7>>2]|0;
 $$off = (($22) + -1)|0;
 $23 = ($$off>>>0)<(2);
 $24 = ((($14)) + 28|0);
 $25 = $23&1;
 HEAP8[$24>>0] = $25;
 $26 = HEAP32[$2>>2]|0;
 $27 = ((($26)) + 140|0);
 $28 = HEAP32[$27>>2]|0;
 __THREW__ = 0;
 $29 = (invoke_ii($28|0,($2|0))|0);
 $30 = __THREW__; __THREW__ = 0;
 $31 = $30&1;
 L9: do {
  if ($31) {
   $39 = ___cxa_find_matching_catch_2()|0;
   $40 = tempRet0;
   $$4 = $39;$$430 = $40;
  } else {
   $32 = ($29|0)==(0|0);
   if (!($32)) {
    $33 = ((($29)) + 228|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = ($34|0)==(0|0);
    if ($35) {
     $46 = 0;
    } else {
     $36 = (___dynamic_cast($34,23016,5496,0)|0);
     $46 = $36;
    }
    $43 = ((($14)) + 24|0);
    $44 = HEAP32[$43>>2]|0;
    $45 = ($44|0)==($46|0);
    if (!($45)) {
     HEAP32[$43>>2] = $46;
     $47 = ($46|0)==(0|0);
     if (!($47)) {
      $48 = ((($46)) + 8|0);
      $49 = HEAP32[$48>>2]|0;HEAP32[$48>>2] = (($49+1)|0);
     }
     $50 = ($44|0)==(0|0);
     if (!($50)) {
      $51 = ((($44)) + 8|0);
      $52 = HEAP32[$51>>2]|0;HEAP32[$51>>2] = (($52-1)|0);
      $53 = ($52|0)==(1);
      if ($53) {
       __THREW__ = 0;
       invoke_viii(3262,($44|0),1,1);
       $54 = __THREW__; __THREW__ = 0;
       $55 = $54&1;
       if ($55) {
        $41 = ___cxa_find_matching_catch_2()|0;
        $42 = tempRet0;
        $$4 = $41;$$430 = $42;
        break;
       }
      }
     }
    }
   }
   $56 = ((($1)) + 68|0);
   $57 = HEAP8[$56>>0]|0;
   $58 = ($57<<24>>24)==(0);
   if ($58) {
    $73 = 0;
   } else {
    $59 = ((($2)) + 176|0);
    $60 = HEAP32[$59>>2]|0;
    $61 = ($60|0)==(0|0);
    if ($61) {
     $73 = 0;
    } else {
     $62 = (___dynamic_cast($60,26560,25368,0)|0);
     $73 = $62;
    }
   }
   $63 = ((($0)) + 24|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = ($64|0)==(0);
   L29: do {
    if ($65) {
     $66 = ((($5)) + 8|0);
     $67 = ((($5)) + 80|0);
     ;HEAP32[$67>>2]=0|0;HEAP32[$67+4>>2]=0|0;HEAP32[$67+8>>2]=0|0;HEAP32[$67+12>>2]=0|0;HEAP32[$67+16>>2]=0|0;HEAP32[$67+20>>2]=0|0;
     $68 = ((($5)) + 120|0);
     dest=$66; stop=dest+68|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
     dest=$68; stop=dest+72|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));HEAP8[$68+72>>0]=0|0;
     HEAP32[$5>>2] = (48576);
     $69 = ((($5)) + 196|0);
     HEAP32[$69>>2] = 0;
     $70 = ((($5)) + 200|0);
     HEAP32[$70>>2] = 0;
     __THREW__ = 0;
     invoke_viiii(3562,($66|0),($3|0),($4|0),($14|0));
     $71 = __THREW__; __THREW__ = 0;
     $72 = $71&1;
     do {
      if ($72) {
       label = 24;
      } else {
       $74 = ($73|0)==(0|0);
       if ($74) {
        $100 = HEAP32[$2>>2]|0;
        $101 = ((($100)) + 264|0);
        $102 = HEAP32[$101>>2]|0;
        __THREW__ = 0;
        invoke_vii($102|0,($2|0),($5|0));
        $103 = __THREW__; __THREW__ = 0;
        $104 = $103&1;
        if ($104) {
         label = 24;
         break;
        }
       } else {
        $75 = ((($73)) + 64|0);
        $76 = HEAP32[$75>>2]|0;
        __THREW__ = 0;
        invoke_viii(3563,($73|0),($5|0),($76|0));
        $77 = __THREW__; __THREW__ = 0;
        $78 = $77&1;
        if ($78) {
         label = 24;
         break;
        }
       }
       $105 = ((($5)) + 64|0);
       $106 = HEAP32[$105>>2]|0;
       $107 = ($106|0)==(0|0);
       if (!($107)) {
        $108 = ((($5)) + 68|0);
        $109 = HEAP32[$108>>2]|0;
        $110 = ($109|0)==($106|0);
        if (!($110)) {
         $scevgep$i$i$i$i$i42 = ((($109)) + -48|0);
         $111 = $scevgep$i$i$i$i$i42;
         $112 = $106;
         $113 = (($111) - ($112))|0;
         $114 = (($113>>>0) / 48)&-1;
         $115 = $114 ^ -1;
         $scevgep5$i$i$i$i$i43 = (($109) + (($115*48)|0)|0);
         HEAP32[$108>>2] = $scevgep5$i$i$i$i$i43;
        }
        __ZdlPv($106);
       }
       $116 = ((($5)) + 8|0);
       $117 = HEAP32[$116>>2]|0;
       $118 = ($117|0)==(0|0);
       if (!($118)) {
        $119 = ((($117)) + 8|0);
        $120 = HEAP32[$119>>2]|0;HEAP32[$119>>2] = (($120-1)|0);
        $121 = ($120|0)==(1);
        if ($121) {
         __THREW__ = 0;
         invoke_viii(3262,($117|0),1,1);
         $122 = __THREW__; __THREW__ = 0;
         $123 = $122&1;
         if ($123) {
          $124 = ___cxa_find_matching_catch_2()|0;
          $125 = tempRet0;
          $$0 = $124;$$026 = $125;
          break;
         }
        }
       }
       break L29;
      }
     } while(0);
     if ((label|0) == 24) {
      $79 = ___cxa_find_matching_catch_2()|0;
      $80 = tempRet0;
      $81 = ((($5)) + 64|0);
      $82 = HEAP32[$81>>2]|0;
      $83 = ($82|0)==(0|0);
      if (!($83)) {
       $84 = ((($5)) + 68|0);
       $85 = HEAP32[$84>>2]|0;
       $86 = ($85|0)==($82|0);
       if (!($86)) {
        $scevgep$i$i$i$i$i46 = ((($85)) + -48|0);
        $87 = $scevgep$i$i$i$i$i46;
        $88 = $82;
        $89 = (($87) - ($88))|0;
        $90 = (($89>>>0) / 48)&-1;
        $91 = $90 ^ -1;
        $scevgep5$i$i$i$i$i47 = (($85) + (($91*48)|0)|0);
        HEAP32[$84>>2] = $scevgep5$i$i$i$i$i47;
       }
       __ZdlPv($82);
      }
      $92 = ((($5)) + 8|0);
      $93 = HEAP32[$92>>2]|0;
      $94 = ($93|0)==(0|0);
      if (!($94)) {
       $95 = ((($93)) + 8|0);
       $96 = HEAP32[$95>>2]|0;HEAP32[$95>>2] = (($96-1)|0);
       $97 = ($96|0)==(1);
       if ($97) {
        __THREW__ = 0;
        invoke_viii(3262,($93|0),1,1);
        $98 = __THREW__; __THREW__ = 0;
        $99 = $98&1;
        if ($99) {
         $190 = ___cxa_find_matching_catch_3(0|0)|0;
         $191 = tempRet0;
         ___clang_call_terminate($190);
         // unreachable;
        }
       }
      }
      HEAP32[$92>>2] = 0;
      $$0 = $79;$$026 = $80;
     }
     $$4 = $$0;$$430 = $$026;
     break L9;
    } else {
     $126 = ((($6)) + 4|0);
     $127 = ((($6)) + 68|0);
     dest=$126; stop=dest+56|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
     dest=$127; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));HEAP8[$127+36>>0]=0|0;
     HEAP32[$6>>2] = (48632);
     $128 = ((($6)) + 108|0);
     HEAP32[$128>>2] = 0;
     $129 = ((($6)) + 112|0);
     HEAP32[$129>>2] = 0;
     __THREW__ = 0;
     invoke_viiii(3564,($126|0),($3|0),($4|0),($14|0));
     $130 = __THREW__; __THREW__ = 0;
     $131 = $130&1;
     do {
      if ($131) {
       label = 46;
      } else {
       $132 = ($73|0)==(0|0);
       if ($132) {
        $158 = HEAP32[$2>>2]|0;
        $159 = ((($158)) + 264|0);
        $160 = HEAP32[$159>>2]|0;
        __THREW__ = 0;
        invoke_vii($160|0,($2|0),($6|0));
        $161 = __THREW__; __THREW__ = 0;
        $162 = $161&1;
        if ($162) {
         label = 46;
         break;
        }
       } else {
        $133 = ((($73)) + 64|0);
        $134 = HEAP32[$133>>2]|0;
        __THREW__ = 0;
        invoke_viii(3565,($73|0),($6|0),($134|0));
        $135 = __THREW__; __THREW__ = 0;
        $136 = $135&1;
        if ($136) {
         label = 46;
         break;
        }
       }
       $163 = ((($6)) + 36|0);
       $164 = HEAP32[$163>>2]|0;
       $165 = ($164|0)==(0|0);
       if (!($165)) {
        $166 = ((($6)) + 40|0);
        $167 = HEAP32[$166>>2]|0;
        $168 = ($167|0)==($164|0);
        if (!($168)) {
         $scevgep$i$i$i$i$i = ((($167)) + -24|0);
         $169 = $scevgep$i$i$i$i$i;
         $170 = $164;
         $171 = (($169) - ($170))|0;
         $172 = (($171>>>0) / 24)&-1;
         $173 = $172 ^ -1;
         $scevgep5$i$i$i$i$i = (($167) + (($173*24)|0)|0);
         HEAP32[$166>>2] = $scevgep5$i$i$i$i$i;
        }
        __ZdlPv($164);
       }
       $174 = ((($6)) + 4|0);
       $175 = HEAP32[$174>>2]|0;
       $176 = ($175|0)==(0|0);
       if (!($176)) {
        $177 = ((($175)) + 8|0);
        $178 = HEAP32[$177>>2]|0;HEAP32[$177>>2] = (($178-1)|0);
        $179 = ($178|0)==(1);
        if ($179) {
         __THREW__ = 0;
         invoke_viii(3262,($175|0),1,1);
         $180 = __THREW__; __THREW__ = 0;
         $181 = $180&1;
         if ($181) {
          $182 = ___cxa_find_matching_catch_2()|0;
          $183 = tempRet0;
          $$1 = $182;$$127 = $183;
          break;
         }
        }
       }
       break L29;
      }
     } while(0);
     if ((label|0) == 46) {
      $137 = ___cxa_find_matching_catch_2()|0;
      $138 = tempRet0;
      $139 = ((($6)) + 36|0);
      $140 = HEAP32[$139>>2]|0;
      $141 = ($140|0)==(0|0);
      if (!($141)) {
       $142 = ((($6)) + 40|0);
       $143 = HEAP32[$142>>2]|0;
       $144 = ($143|0)==($140|0);
       if (!($144)) {
        $scevgep$i$i$i$i$i34 = ((($143)) + -24|0);
        $145 = $scevgep$i$i$i$i$i34;
        $146 = $140;
        $147 = (($145) - ($146))|0;
        $148 = (($147>>>0) / 24)&-1;
        $149 = $148 ^ -1;
        $scevgep5$i$i$i$i$i35 = (($143) + (($149*24)|0)|0);
        HEAP32[$142>>2] = $scevgep5$i$i$i$i$i35;
       }
       __ZdlPv($140);
      }
      $150 = ((($6)) + 4|0);
      $151 = HEAP32[$150>>2]|0;
      $152 = ($151|0)==(0|0);
      if (!($152)) {
       $153 = ((($151)) + 8|0);
       $154 = HEAP32[$153>>2]|0;HEAP32[$153>>2] = (($154-1)|0);
       $155 = ($154|0)==(1);
       if ($155) {
        __THREW__ = 0;
        invoke_viii(3262,($151|0),1,1);
        $156 = __THREW__; __THREW__ = 0;
        $157 = $156&1;
        if ($157) {
         $190 = ___cxa_find_matching_catch_3(0|0)|0;
         $191 = tempRet0;
         ___clang_call_terminate($190);
         // unreachable;
        }
       }
      }
      HEAP32[$150>>2] = 0;
      $$1 = $137;$$127 = $138;
     }
     $$4 = $$1;$$430 = $$127;
     break L9;
    }
   } while(0);
   $184 = HEAP32[$18>>2]|0;HEAP32[$18>>2] = (($184-1)|0);
   $185 = ($184|0)==(1);
   if (!($185)) {
    STACKTOP = sp;return;
   }
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($14,1,1);
   STACKTOP = sp;return;
  }
 } while(0);
 $186 = HEAP32[$18>>2]|0;HEAP32[$18>>2] = (($186-1)|0);
 $187 = ($186|0)==(1);
 if (!($187)) {
  $$5 = $$4;$$531 = $$430;
  ___resumeException($$5|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(3262,($14|0),1,1);
 $188 = __THREW__; __THREW__ = 0;
 $189 = $188&1;
 if ($189) {
  $190 = ___cxa_find_matching_catch_3(0|0)|0;
  $191 = tempRet0;
  ___clang_call_terminate($190);
  // unreachable;
 } else {
  $$5 = $$4;$$531 = $$430;
  ___resumeException($$5|0);
  // unreachable;
 }
}
function __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3dEdE3setERKS2_S5_PNS_8SettingsE($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$sroa$0$0 = 0.0, $$sroa$0$0$$sroa_idx = 0, $$sroa$011$0 = 0.0, $$sroa$011$0$$sroa_idx = 0, $$sroa$019$0 = 0.0, $$sroa$019$0$$sroa_idx = 0, $$sroa$027$0$$sroa_idx = 0, $$sroa$4$0$$sroa_idx29 = 0, $$sroa$5$0 = 0.0, $$sroa$5$0$$sroa_idx7 = 0, $$sroa$513$0 = 0.0, $$sroa$513$0$$sroa_idx14 = 0, $$sroa$521$0 = 0.0, $$sroa$521$0$$sroa_idx22 = 0, $$sroa$531$0$$sroa_idx32 = 0, $$sroa$7$0 = 0.0, $$sroa$7$0$$sroa_idx9 = 0, $$sroa$716$0 = 0.0, $$sroa$716$0$$sroa_idx17 = 0, $$sroa$724$0 = 0.0;
 var $$sroa$724$0$$sroa_idx25 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0.0, $26 = 0.0, $27 = 0.0, $28 = 0;
 var $29 = 0.0, $30 = 0, $31 = 0.0, $32 = 0.0, $33 = 0, $34 = 0.0, $35 = 0, $36 = 0.0, $37 = 0.0, $38 = 0.0, $39 = 0.0, $4 = 0, $40 = 0.0, $41 = 0.0, $42 = 0.0, $43 = 0.0, $44 = 0, $45 = 0, $46 = 0.0, $47 = 0.0;
 var $48 = 0, $49 = 0.0, $5 = 0, $50 = 0.0, $51 = 0.0, $52 = 0, $53 = 0.0, $54 = 0.0, $55 = 0.0, $56 = 0, $57 = 0.0, $58 = 0.0, $59 = 0.0, $6 = 0, $60 = 0, $61 = 0.0, $62 = 0.0, $63 = 0.0, $7 = 0, $8 = 0;
 var $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $4 = sp;
 $5 = HEAP32[$0>>2]|0;
 $6 = ($5|0)==($3|0);
 if (!($6)) {
  HEAP32[$0>>2] = $3;
  $7 = ($3|0)==(0|0);
  if (!($7)) {
   $8 = ((($3)) + 8|0);
   $9 = HEAP32[$8>>2]|0;HEAP32[$8>>2] = (($9+1)|0);
  }
  $10 = ($5|0)==(0|0);
  if (!($10)) {
   $11 = ((($5)) + 8|0);
   $12 = HEAP32[$11>>2]|0;HEAP32[$11>>2] = (($12-1)|0);
   $13 = ($12|0)==(1);
   if ($13) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($5,1,1);
   }
  }
 }
 $14 = ((($0)) + 8|0);
 ;HEAP32[$14>>2]=HEAP32[$1>>2]|0;HEAP32[$14+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$14+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$14+12>>2]=HEAP32[$1+12>>2]|0;HEAP32[$14+16>>2]=HEAP32[$1+16>>2]|0;HEAP32[$14+20>>2]=HEAP32[$1+20>>2]|0;
 $15 = ((($0)) + 32|0);
 ;HEAP32[$15>>2]=HEAP32[$2>>2]|0;HEAP32[$15+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$15+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$15+12>>2]=HEAP32[$2+12>>2]|0;HEAP32[$15+16>>2]=HEAP32[$2+16>>2]|0;HEAP32[$15+20>>2]=HEAP32[$2+20>>2]|0;
 ;HEAP32[$4>>2]=HEAP32[$14>>2]|0;HEAP32[$4+4>>2]=HEAP32[$14+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$14+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$14+12>>2]|0;HEAP32[$4+16>>2]=HEAP32[$14+16>>2]|0;HEAP32[$4+20>>2]=HEAP32[$14+20>>2]|0;
 $16 = ((($4)) + 24|0);
 ;HEAP32[$16>>2]=HEAP32[$15>>2]|0;HEAP32[$16+4>>2]=HEAP32[$15+4>>2]|0;HEAP32[$16+8>>2]=HEAP32[$15+8>>2]|0;HEAP32[$16+12>>2]=HEAP32[$15+12>>2]|0;HEAP32[$16+16>>2]=HEAP32[$15+16>>2]|0;HEAP32[$16+20>>2]=HEAP32[$15+20>>2]|0;
 $17 = ((($0)) + 60|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ((($0)) + 64|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($18|0)==($20|0);
 if ($21) {
  $24 = ((($0)) + 56|0);
  __ZNSt3__26vectorINS_4pairIN3osg5Vec3dES3_EENS_9allocatorIS4_EEE21__push_back_slow_pathIKS4_EEvRT_($24,$4);
 } else {
  dest=$18; src=$4; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  $22 = HEAP32[$17>>2]|0;
  $23 = ((($22)) + 48|0);
  HEAP32[$17>>2] = $23;
 }
 $25 = +HEAPF64[$2>>3];
 $26 = +HEAPF64[$1>>3];
 $27 = $25 - $26;
 $28 = ((($2)) + 8|0);
 $29 = +HEAPF64[$28>>3];
 $30 = ((($1)) + 8|0);
 $31 = +HEAPF64[$30>>3];
 $32 = $29 - $31;
 $33 = ((($2)) + 16|0);
 $34 = +HEAPF64[$33>>3];
 $35 = ((($1)) + 16|0);
 $36 = +HEAPF64[$35>>3];
 $37 = $34 - $36;
 $$sroa$027$0$$sroa_idx = ((($0)) + 72|0);
 $$sroa$4$0$$sroa_idx29 = ((($0)) + 80|0);
 $$sroa$531$0$$sroa_idx32 = ((($0)) + 88|0);
 $38 = $27 * $27;
 $39 = $32 * $32;
 $40 = $38 + $39;
 $41 = $37 * $37;
 $42 = $40 + $41;
 $43 = (+Math_sqrt((+$42)));
 $44 = ((($0)) + 96|0);
 HEAPF64[$44>>3] = $43;
 $45 = $43 != 0.0;
 $46 = 1.0 / $43;
 $47 = $45 ? $46 : 0.0;
 $48 = ((($0)) + 104|0);
 HEAPF64[$48>>3] = $47;
 $49 = $47 * $27;
 HEAPF64[$$sroa$027$0$$sroa_idx>>3] = $49;
 $50 = $47 * $32;
 HEAPF64[$$sroa$4$0$$sroa_idx29>>3] = $50;
 $51 = $47 * $37;
 HEAPF64[$$sroa$531$0$$sroa_idx32>>3] = $51;
 $52 = $49 != 0.0;
 if ($52) {
  $53 = $49 / $49;
  $54 = $50 / $49;
  $55 = $51 / $49;
  $$sroa$019$0 = $53;$$sroa$521$0 = $54;$$sroa$724$0 = $55;
 } else {
  $$sroa$019$0 = 0.0;$$sroa$521$0 = 0.0;$$sroa$724$0 = 0.0;
 }
 $$sroa$019$0$$sroa_idx = ((($0)) + 112|0);
 HEAPF64[$$sroa$019$0$$sroa_idx>>3] = $$sroa$019$0;
 $$sroa$521$0$$sroa_idx22 = ((($0)) + 120|0);
 HEAPF64[$$sroa$521$0$$sroa_idx22>>3] = $$sroa$521$0;
 $$sroa$724$0$$sroa_idx25 = ((($0)) + 128|0);
 HEAPF64[$$sroa$724$0$$sroa_idx25>>3] = $$sroa$724$0;
 $56 = $50 != 0.0;
 if ($56) {
  $57 = $50 / $50;
  $58 = $49 / $50;
  $59 = $51 / $50;
  $$sroa$011$0 = $58;$$sroa$513$0 = $57;$$sroa$716$0 = $59;
 } else {
  $$sroa$011$0 = 0.0;$$sroa$513$0 = 0.0;$$sroa$716$0 = 0.0;
 }
 $$sroa$011$0$$sroa_idx = ((($0)) + 136|0);
 HEAPF64[$$sroa$011$0$$sroa_idx>>3] = $$sroa$011$0;
 $$sroa$513$0$$sroa_idx14 = ((($0)) + 144|0);
 HEAPF64[$$sroa$513$0$$sroa_idx14>>3] = $$sroa$513$0;
 $$sroa$716$0$$sroa_idx17 = ((($0)) + 152|0);
 HEAPF64[$$sroa$716$0$$sroa_idx17>>3] = $$sroa$716$0;
 $60 = $51 != 0.0;
 if (!($60)) {
  $$sroa$0$0 = 0.0;$$sroa$5$0 = 0.0;$$sroa$7$0 = 0.0;
  $$sroa$0$0$$sroa_idx = ((($0)) + 160|0);
  HEAPF64[$$sroa$0$0$$sroa_idx>>3] = $$sroa$0$0;
  $$sroa$5$0$$sroa_idx7 = ((($0)) + 168|0);
  HEAPF64[$$sroa$5$0$$sroa_idx7>>3] = $$sroa$5$0;
  $$sroa$7$0$$sroa_idx9 = ((($0)) + 176|0);
  HEAPF64[$$sroa$7$0$$sroa_idx9>>3] = $$sroa$7$0;
  STACKTOP = sp;return;
 }
 $61 = $51 / $51;
 $62 = $49 / $51;
 $63 = $50 / $51;
 $$sroa$0$0 = $62;$$sroa$5$0 = $63;$$sroa$7$0 = $61;
 $$sroa$0$0$$sroa_idx = ((($0)) + 160|0);
 HEAPF64[$$sroa$0$0$$sroa_idx>>3] = $$sroa$0$0;
 $$sroa$5$0$$sroa_idx7 = ((($0)) + 168|0);
 HEAPF64[$$sroa$5$0$$sroa_idx7>>3] = $$sroa$5$0;
 $$sroa$7$0$$sroa_idx9 = ((($0)) + 176|0);
 HEAPF64[$$sroa$7$0$$sroa_idx9>>3] = $$sroa$7$0;
 STACKTOP = sp;return;
}
function __ZNK3osg6KdTree9intersectINS_24TemplatePrimitiveFunctorIN27LineSegmentIntersectorUtils16IntersectFunctorINS_5Vec3dEdEEEEEEvRT_RKNS0_6KdNodeE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$051 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $scevgep5$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = ((($2)) + 24|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)<(0);
 if (!($6)) {
  $100 = ((($1)) + 8|0);
  $101 = (__ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3dEdE5enterERKNS1_15BoundingBoxImplINS1_5Vec3fEEE($100,$2)|0);
  if (!($101)) {
   STACKTOP = sp;return;
  }
  $102 = HEAP32[$4>>2]|0;
  $103 = ($102|0)>(0);
  if ($103) {
   $104 = ((($0)) + 64|0);
   $105 = HEAP32[$104>>2]|0;
   $106 = (($105) + ($102<<5)|0);
   __ZNK3osg6KdTree9intersectINS_24TemplatePrimitiveFunctorIN27LineSegmentIntersectorUtils16IntersectFunctorINS_5Vec3dEdEEEEEEvRT_RKNS0_6KdNodeE($0,$1,$106);
  }
  $107 = ((($2)) + 28|0);
  $108 = HEAP32[$107>>2]|0;
  $109 = ($108|0)>(0);
  if ($109) {
   $110 = ((($0)) + 64|0);
   $111 = HEAP32[$110>>2]|0;
   $112 = (($111) + ($108<<5)|0);
   __ZNK3osg6KdTree9intersectINS_24TemplatePrimitiveFunctorIN27LineSegmentIntersectorUtils16IntersectFunctorINS_5Vec3dEdEEEEEEvRT_RKNS0_6KdNodeE($0,$1,$112);
  }
  $113 = ((($1)) + 68|0);
  $114 = HEAP32[$113>>2]|0;
  $scevgep5$i$i$i$i = ((($114)) + -48|0);
  HEAP32[$113>>2] = $scevgep5$i$i$i$i;
  STACKTOP = sp;return;
 }
 $7 = $5 ^ -1;
 $8 = ((($2)) + 28|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + ($7))|0;
 $11 = ($9|0)>(0);
 if (!($11)) {
  STACKTOP = sp;return;
 }
 $12 = ((($0)) + 40|0);
 $13 = ((($0)) + 52|0);
 $14 = ((($1)) + 8|0);
 $15 = ((($0)) + 36|0);
 $16 = ((($1)) + 12|0);
 $17 = ((($1)) + 192|0);
 $$051 = $7;
 L17: while(1) {
  $18 = HEAP32[$12>>2]|0;
  $19 = (($18) + ($$051<<2)|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = (($20) + 1)|0;
  $22 = HEAP32[$13>>2]|0;
  $23 = (($22) + ($20<<2)|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = (($20) + 2)|0;
  $26 = (($22) + ($21<<2)|0);
  $27 = HEAP32[$26>>2]|0;
  L19: do {
   switch ($27|0) {
   case 2: case 1:  {
    break;
   }
   case 3:  {
    $28 = HEAP32[$15>>2]|0;
    $29 = (($22) + ($25<<2)|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = (($20) + 3)|0;
    $32 = (($22) + ($31<<2)|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = (($20) + 4)|0;
    $35 = (($22) + ($34<<2)|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = HEAP32[$14>>2]|0;
    $38 = ((($37)) + 28|0);
    $39 = HEAP8[$38>>0]|0;
    $40 = ($39<<24>>24)==(0);
    if (!($40)) {
     $41 = HEAP8[$17>>0]|0;
     $42 = ($41<<24>>24)==(0);
     if (!($42)) {
      break L19;
     }
    }
    HEAP32[$16>>2] = $24;
    $43 = ((($28)) + 76|0);
    $44 = HEAP32[$43>>2]|0;
    $45 = (($44) + (($30*12)|0)|0);
    $46 = (($44) + (($33*12)|0)|0);
    $47 = (($44) + (($36*12)|0)|0);
    __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3dEdE9intersectERKNS1_5Vec3fES6_S6_($14,$45,$46,$47);
    break;
   }
   case 4:  {
    $48 = HEAP32[$15>>2]|0;
    $49 = (($22) + ($25<<2)|0);
    $50 = HEAP32[$49>>2]|0;
    $51 = (($20) + 3)|0;
    $52 = (($22) + ($51<<2)|0);
    $53 = HEAP32[$52>>2]|0;
    $54 = (($20) + 4)|0;
    $55 = (($22) + ($54<<2)|0);
    $56 = HEAP32[$55>>2]|0;
    $57 = (($20) + 5)|0;
    $58 = (($22) + ($57<<2)|0);
    $59 = HEAP32[$58>>2]|0;
    $60 = HEAP32[$14>>2]|0;
    $61 = ((($60)) + 28|0);
    $62 = HEAP8[$61>>0]|0;
    $63 = ($62<<24>>24)==(0);
    if (!($63)) {
     $64 = HEAP8[$17>>0]|0;
     $65 = ($64<<24>>24)==(0);
     if (!($65)) {
      break L19;
     }
    }
    HEAP32[$16>>2] = $24;
    $66 = ((($48)) + 76|0);
    $67 = HEAP32[$66>>2]|0;
    $68 = (($67) + (($50*12)|0)|0);
    $69 = (($67) + (($53*12)|0)|0);
    $70 = (($67) + (($59*12)|0)|0);
    __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3dEdE9intersectERKNS1_5Vec3fES6_S6_($14,$68,$69,$70);
    $71 = HEAP32[$66>>2]|0;
    $72 = (($71) + (($53*12)|0)|0);
    $73 = (($71) + (($56*12)|0)|0);
    $74 = (($71) + (($59*12)|0)|0);
    __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3dEdE9intersectERKNS1_5Vec3fES6_S6_($14,$72,$73,$74);
    break;
   }
   default: {
    $75 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
    if ($75) {
     $76 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
     $77 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($76,111399,69)|0);
     $78 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($77,$27)|0);
     $79 = HEAP32[$78>>2]|0;
     $80 = ((($79)) + -12|0);
     $81 = HEAP32[$80>>2]|0;
     $82 = (($78) + ($81)|0);
     __ZNKSt3__28ios_base6getlocEv($3,$82);
     __THREW__ = 0;
     $83 = (invoke_iii(3255,($3|0),(215188|0))|0);
     $84 = __THREW__; __THREW__ = 0;
     $85 = $84&1;
     if ($85) {
      break L17;
     }
     $86 = HEAP32[$83>>2]|0;
     $87 = ((($86)) + 28|0);
     $88 = HEAP32[$87>>2]|0;
     __THREW__ = 0;
     $89 = (invoke_iii($88|0,($83|0),10)|0);
     $90 = __THREW__; __THREW__ = 0;
     $91 = $90&1;
     if ($91) {
      break L17;
     }
     __ZNSt3__26localeD2Ev($3);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($78,$89)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($78)|0);
    }
   }
   }
  } while(0);
  $98 = (($$051) + 1)|0;
  $99 = ($98|0)<($10|0);
  if ($99) {
   $$051 = $98;
  } else {
   label = 25;
   break;
  }
 }
 if ((label|0) == 25) {
  STACKTOP = sp;return;
 }
 $92 = ___cxa_find_matching_catch_2()|0;
 $93 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($3|0));
 $94 = __THREW__; __THREW__ = 0;
 $95 = $94&1;
 if ($95) {
  $96 = ___cxa_find_matching_catch_3(0|0)|0;
  $97 = tempRet0;
  ___clang_call_terminate($96);
  // unreachable;
 } else {
  ___resumeException($92|0);
  // unreachable;
 }
}
function __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3fEfE3setERKNS1_5Vec3dES6_PNS_8SettingsE($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$sroa$0$0 = 0.0, $$sroa$0$0$$sroa_idx = 0, $$sroa$011$0 = 0.0, $$sroa$011$0$$sroa_idx = 0, $$sroa$019$0 = 0.0, $$sroa$019$0$$sroa_idx = 0, $$sroa$028$0$$sroa_idx = 0, $$sroa$036$0$$sroa_idx = 0, $$sroa$044$0$$sroa_idx = 0, $$sroa$430$0$$sroa_idx31 = 0, $$sroa$438$0$$sroa_idx39 = 0, $$sroa$446$0$$sroa_idx47 = 0, $$sroa$5$0 = 0.0, $$sroa$5$0$$sroa_idx7 = 0, $$sroa$513$0 = 0.0, $$sroa$513$0$$sroa_idx14 = 0, $$sroa$521$0 = 0.0, $$sroa$521$0$$sroa_idx22 = 0, $$sroa$533$0$$sroa_idx34 = 0, $$sroa$541$0$$sroa_idx42 = 0;
 var $$sroa$549$0$$sroa_idx50 = 0, $$sroa$7$0 = 0.0, $$sroa$7$0$$sroa_idx9 = 0, $$sroa$716$0 = 0.0, $$sroa$716$0$$sroa_idx17 = 0, $$sroa$724$0 = 0.0, $$sroa$724$0$$sroa_idx25 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0.0, $15 = 0.0, $16 = 0, $17 = 0.0, $18 = 0.0, $19 = 0, $20 = 0.0, $21 = 0.0, $22 = 0;
 var $23 = 0.0, $24 = 0.0, $25 = 0, $26 = 0.0, $27 = 0.0, $28 = 0, $29 = 0.0, $30 = 0.0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0.0;
 var $42 = 0.0, $43 = 0.0, $44 = 0.0, $45 = 0.0, $46 = 0.0, $47 = 0.0, $48 = 0.0, $49 = 0.0, $5 = 0, $50 = 0.0, $51 = 0.0, $52 = 0.0, $53 = 0.0, $54 = 0.0, $55 = 0.0, $56 = 0.0, $57 = 0.0, $58 = 0.0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0.0, $62 = 0, $63 = 0.0, $64 = 0.0, $65 = 0.0, $66 = 0, $67 = 0.0, $68 = 0.0, $69 = 0.0, $7 = 0, $70 = 0, $71 = 0.0, $72 = 0.0, $73 = 0.0, $74 = 0, $75 = 0.0, $76 = 0.0, $77 = 0.0, $8 = 0;
 var $9 = 0, $phitmp = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $4 = sp;
 $5 = HEAP32[$0>>2]|0;
 $6 = ($5|0)==($3|0);
 if (!($6)) {
  HEAP32[$0>>2] = $3;
  $7 = ($3|0)==(0|0);
  if (!($7)) {
   $8 = ((($3)) + 8|0);
   $9 = HEAP32[$8>>2]|0;HEAP32[$8>>2] = (($9+1)|0);
  }
  $10 = ($5|0)==(0|0);
  if (!($10)) {
   $11 = ((($5)) + 8|0);
   $12 = HEAP32[$11>>2]|0;HEAP32[$11>>2] = (($12-1)|0);
   $13 = ($12|0)==(1);
   if ($13) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($5,1,1);
   }
  }
 }
 $14 = +HEAPF64[$1>>3];
 $15 = $14;
 $16 = ((($1)) + 8|0);
 $17 = +HEAPF64[$16>>3];
 $18 = $17;
 $19 = ((($1)) + 16|0);
 $20 = +HEAPF64[$19>>3];
 $21 = $20;
 $22 = ((($0)) + 8|0);
 $$sroa$044$0$$sroa_idx = ((($0)) + 8|0);
 HEAPF32[$$sroa$044$0$$sroa_idx>>2] = $15;
 $$sroa$446$0$$sroa_idx47 = ((($0)) + 12|0);
 HEAPF32[$$sroa$446$0$$sroa_idx47>>2] = $18;
 $$sroa$549$0$$sroa_idx50 = ((($0)) + 16|0);
 HEAPF32[$$sroa$549$0$$sroa_idx50>>2] = $21;
 $23 = +HEAPF64[$2>>3];
 $24 = $23;
 $25 = ((($2)) + 8|0);
 $26 = +HEAPF64[$25>>3];
 $27 = $26;
 $28 = ((($2)) + 16|0);
 $29 = +HEAPF64[$28>>3];
 $30 = $29;
 $31 = ((($0)) + 20|0);
 $$sroa$036$0$$sroa_idx = ((($0)) + 20|0);
 HEAPF32[$$sroa$036$0$$sroa_idx>>2] = $24;
 $$sroa$438$0$$sroa_idx39 = ((($0)) + 24|0);
 HEAPF32[$$sroa$438$0$$sroa_idx39>>2] = $27;
 $$sroa$541$0$$sroa_idx42 = ((($0)) + 28|0);
 HEAPF32[$$sroa$541$0$$sroa_idx42>>2] = $30;
 ;HEAP32[$4>>2]=HEAP32[$22>>2]|0;HEAP32[$4+4>>2]=HEAP32[$22+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$22+8>>2]|0;
 $32 = ((($4)) + 12|0);
 ;HEAP32[$32>>2]=HEAP32[$31>>2]|0;HEAP32[$32+4>>2]=HEAP32[$31+4>>2]|0;HEAP32[$32+8>>2]=HEAP32[$31+8>>2]|0;
 $33 = ((($0)) + 36|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ((($0)) + 40|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = ($34|0)==($36|0);
 if ($37) {
  $40 = ((($0)) + 32|0);
  __ZNSt3__26vectorINS_4pairIN3osg5Vec3fES3_EENS_9allocatorIS4_EEE21__push_back_slow_pathIKS4_EEvRT_($40,$4);
 } else {
  ;HEAP32[$34>>2]=HEAP32[$4>>2]|0;HEAP32[$34+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$34+8>>2]=HEAP32[$4+8>>2]|0;HEAP32[$34+12>>2]=HEAP32[$4+12>>2]|0;HEAP32[$34+16>>2]=HEAP32[$4+16>>2]|0;HEAP32[$34+20>>2]=HEAP32[$4+20>>2]|0;
  $38 = HEAP32[$33>>2]|0;
  $39 = ((($38)) + 24|0);
  HEAP32[$33>>2] = $39;
 }
 $41 = +HEAPF64[$2>>3];
 $42 = +HEAPF64[$1>>3];
 $43 = $41 - $42;
 $44 = +HEAPF64[$25>>3];
 $45 = +HEAPF64[$16>>3];
 $46 = $44 - $45;
 $47 = +HEAPF64[$28>>3];
 $48 = +HEAPF64[$19>>3];
 $49 = $47 - $48;
 $50 = $43;
 $51 = $46;
 $52 = $49;
 $$sroa$028$0$$sroa_idx = ((($0)) + 44|0);
 $$sroa$430$0$$sroa_idx31 = ((($0)) + 48|0);
 $$sroa$533$0$$sroa_idx34 = ((($0)) + 52|0);
 $53 = $50 * $50;
 $54 = $51 * $51;
 $55 = $53 + $54;
 $56 = $52 * $52;
 $57 = $55 + $56;
 $58 = (+Math_sqrt((+$57)));
 $59 = ((($0)) + 56|0);
 HEAPF32[$59>>2] = $58;
 $60 = $58 != 0.0;
 $phitmp = 1.0 / $58;
 $61 = $60 ? $phitmp : 0.0;
 $62 = ((($0)) + 60|0);
 HEAPF32[$62>>2] = $61;
 $63 = $61 * $50;
 HEAPF32[$$sroa$028$0$$sroa_idx>>2] = $63;
 $64 = $61 * $51;
 HEAPF32[$$sroa$430$0$$sroa_idx31>>2] = $64;
 $65 = $61 * $52;
 HEAPF32[$$sroa$533$0$$sroa_idx34>>2] = $65;
 $66 = $63 != 0.0;
 if ($66) {
  $67 = $63 / $63;
  $68 = $64 / $63;
  $69 = $65 / $63;
  $$sroa$019$0 = $67;$$sroa$521$0 = $68;$$sroa$724$0 = $69;
 } else {
  $$sroa$019$0 = 0.0;$$sroa$521$0 = 0.0;$$sroa$724$0 = 0.0;
 }
 $$sroa$019$0$$sroa_idx = ((($0)) + 64|0);
 HEAPF32[$$sroa$019$0$$sroa_idx>>2] = $$sroa$019$0;
 $$sroa$521$0$$sroa_idx22 = ((($0)) + 68|0);
 HEAPF32[$$sroa$521$0$$sroa_idx22>>2] = $$sroa$521$0;
 $$sroa$724$0$$sroa_idx25 = ((($0)) + 72|0);
 HEAPF32[$$sroa$724$0$$sroa_idx25>>2] = $$sroa$724$0;
 $70 = $64 != 0.0;
 if ($70) {
  $71 = $64 / $64;
  $72 = $63 / $64;
  $73 = $65 / $64;
  $$sroa$011$0 = $72;$$sroa$513$0 = $71;$$sroa$716$0 = $73;
 } else {
  $$sroa$011$0 = 0.0;$$sroa$513$0 = 0.0;$$sroa$716$0 = 0.0;
 }
 $$sroa$011$0$$sroa_idx = ((($0)) + 76|0);
 HEAPF32[$$sroa$011$0$$sroa_idx>>2] = $$sroa$011$0;
 $$sroa$513$0$$sroa_idx14 = ((($0)) + 80|0);
 HEAPF32[$$sroa$513$0$$sroa_idx14>>2] = $$sroa$513$0;
 $$sroa$716$0$$sroa_idx17 = ((($0)) + 84|0);
 HEAPF32[$$sroa$716$0$$sroa_idx17>>2] = $$sroa$716$0;
 $74 = $65 != 0.0;
 if (!($74)) {
  $$sroa$0$0 = 0.0;$$sroa$5$0 = 0.0;$$sroa$7$0 = 0.0;
  $$sroa$0$0$$sroa_idx = ((($0)) + 88|0);
  HEAPF32[$$sroa$0$0$$sroa_idx>>2] = $$sroa$0$0;
  $$sroa$5$0$$sroa_idx7 = ((($0)) + 92|0);
  HEAPF32[$$sroa$5$0$$sroa_idx7>>2] = $$sroa$5$0;
  $$sroa$7$0$$sroa_idx9 = ((($0)) + 96|0);
  HEAPF32[$$sroa$7$0$$sroa_idx9>>2] = $$sroa$7$0;
  STACKTOP = sp;return;
 }
 $75 = $65 / $65;
 $76 = $63 / $65;
 $77 = $64 / $65;
 $$sroa$0$0 = $76;$$sroa$5$0 = $77;$$sroa$7$0 = $75;
 $$sroa$0$0$$sroa_idx = ((($0)) + 88|0);
 HEAPF32[$$sroa$0$0$$sroa_idx>>2] = $$sroa$0$0;
 $$sroa$5$0$$sroa_idx7 = ((($0)) + 92|0);
 HEAPF32[$$sroa$5$0$$sroa_idx7>>2] = $$sroa$5$0;
 $$sroa$7$0$$sroa_idx9 = ((($0)) + 96|0);
 HEAPF32[$$sroa$7$0$$sroa_idx9>>2] = $$sroa$7$0;
 STACKTOP = sp;return;
}
function __ZNK3osg6KdTree9intersectINS_24TemplatePrimitiveFunctorIN27LineSegmentIntersectorUtils16IntersectFunctorINS_5Vec3fEfEEEEEEvRT_RKNS0_6KdNodeE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$051 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $or$cond54 = 0, $scevgep5$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = ((($2)) + 24|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)<(0);
 if (!($6)) {
  $100 = ((($1)) + 4|0);
  $101 = (__ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3fEfE5enterERKNS1_15BoundingBoxImplIS2_EE($100,$2)|0);
  if (!($101)) {
   STACKTOP = sp;return;
  }
  $102 = HEAP32[$4>>2]|0;
  $103 = ($102|0)>(0);
  if ($103) {
   $104 = ((($0)) + 64|0);
   $105 = HEAP32[$104>>2]|0;
   $106 = (($105) + ($102<<5)|0);
   __ZNK3osg6KdTree9intersectINS_24TemplatePrimitiveFunctorIN27LineSegmentIntersectorUtils16IntersectFunctorINS_5Vec3fEfEEEEEEvRT_RKNS0_6KdNodeE($0,$1,$106);
  }
  $107 = ((($2)) + 28|0);
  $108 = HEAP32[$107>>2]|0;
  $109 = ($108|0)>(0);
  if ($109) {
   $110 = ((($0)) + 64|0);
   $111 = HEAP32[$110>>2]|0;
   $112 = (($111) + ($108<<5)|0);
   __ZNK3osg6KdTree9intersectINS_24TemplatePrimitiveFunctorIN27LineSegmentIntersectorUtils16IntersectFunctorINS_5Vec3fEfEEEEEEvRT_RKNS0_6KdNodeE($0,$1,$112);
  }
  $113 = ((($1)) + 40|0);
  $114 = HEAP32[$113>>2]|0;
  $scevgep5$i$i$i$i = ((($114)) + -24|0);
  HEAP32[$113>>2] = $scevgep5$i$i$i$i;
  STACKTOP = sp;return;
 }
 $7 = $5 ^ -1;
 $8 = ((($2)) + 28|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + ($7))|0;
 $11 = ($9|0)>(0);
 if (!($11)) {
  STACKTOP = sp;return;
 }
 $12 = ((($0)) + 40|0);
 $13 = ((($0)) + 52|0);
 $14 = ((($1)) + 4|0);
 $15 = ((($0)) + 36|0);
 $16 = ((($1)) + 8|0);
 $17 = ((($1)) + 104|0);
 $$051 = $7;
 L17: while(1) {
  $18 = HEAP32[$12>>2]|0;
  $19 = (($18) + ($$051<<2)|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = (($20) + 1)|0;
  $22 = HEAP32[$13>>2]|0;
  $23 = (($22) + ($20<<2)|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = (($20) + 2)|0;
  $26 = (($22) + ($21<<2)|0);
  $27 = HEAP32[$26>>2]|0;
  switch ($27|0) {
  case 2: case 1:  {
   break;
  }
  case 3:  {
   $28 = HEAP32[$14>>2]|0;
   $29 = ((($28)) + 28|0);
   $30 = HEAP8[$29>>0]|0;
   $31 = ($30<<24>>24)==(0);
   $32 = HEAP8[$17>>0]|0;
   $33 = ($32<<24>>24)==(0);
   $or$cond = $31 | $33;
   if ($or$cond) {
    $34 = (($20) + 4)|0;
    $35 = (($22) + ($34<<2)|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = (($20) + 3)|0;
    $38 = (($22) + ($37<<2)|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = (($22) + ($25<<2)|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = HEAP32[$15>>2]|0;
    HEAP32[$16>>2] = $24;
    $43 = ((($42)) + 76|0);
    $44 = HEAP32[$43>>2]|0;
    $45 = (($44) + (($41*12)|0)|0);
    $46 = (($44) + (($39*12)|0)|0);
    $47 = (($44) + (($36*12)|0)|0);
    __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3fEfE9intersectERKS2_S5_S5_($14,$45,$46,$47);
   }
   break;
  }
  case 4:  {
   $48 = (($20) + 3)|0;
   $49 = (($22) + ($48<<2)|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = (($20) + 5)|0;
   $52 = (($22) + ($51<<2)|0);
   $53 = HEAP32[$52>>2]|0;
   $54 = HEAP32[$14>>2]|0;
   $55 = ((($54)) + 28|0);
   $56 = HEAP8[$55>>0]|0;
   $57 = ($56<<24>>24)==(0);
   $58 = HEAP8[$17>>0]|0;
   $59 = ($58<<24>>24)==(0);
   $or$cond54 = $57 | $59;
   if ($or$cond54) {
    $60 = (($20) + 4)|0;
    $61 = (($22) + ($60<<2)|0);
    $62 = HEAP32[$61>>2]|0;
    $63 = (($22) + ($25<<2)|0);
    $64 = HEAP32[$63>>2]|0;
    $65 = HEAP32[$15>>2]|0;
    HEAP32[$16>>2] = $24;
    $66 = ((($65)) + 76|0);
    $67 = HEAP32[$66>>2]|0;
    $68 = (($67) + (($64*12)|0)|0);
    $69 = (($67) + (($50*12)|0)|0);
    $70 = (($67) + (($53*12)|0)|0);
    __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3fEfE9intersectERKS2_S5_S5_($14,$68,$69,$70);
    $71 = HEAP32[$66>>2]|0;
    $72 = (($71) + (($50*12)|0)|0);
    $73 = (($71) + (($62*12)|0)|0);
    $74 = (($71) + (($53*12)|0)|0);
    __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3fEfE9intersectERKS2_S5_S5_($14,$72,$73,$74);
   }
   break;
  }
  default: {
   $75 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
   if ($75) {
    $76 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
    $77 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($76,111399,69)|0);
    $78 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($77,$27)|0);
    $79 = HEAP32[$78>>2]|0;
    $80 = ((($79)) + -12|0);
    $81 = HEAP32[$80>>2]|0;
    $82 = (($78) + ($81)|0);
    __ZNKSt3__28ios_base6getlocEv($3,$82);
    __THREW__ = 0;
    $83 = (invoke_iii(3255,($3|0),(215188|0))|0);
    $84 = __THREW__; __THREW__ = 0;
    $85 = $84&1;
    if ($85) {
     break L17;
    }
    $86 = HEAP32[$83>>2]|0;
    $87 = ((($86)) + 28|0);
    $88 = HEAP32[$87>>2]|0;
    __THREW__ = 0;
    $89 = (invoke_iii($88|0,($83|0),10)|0);
    $90 = __THREW__; __THREW__ = 0;
    $91 = $90&1;
    if ($91) {
     break L17;
    }
    __ZNSt3__26localeD2Ev($3);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($78,$89)|0);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($78)|0);
   }
  }
  }
  $98 = (($$051) + 1)|0;
  $99 = ($98|0)<($10|0);
  if ($99) {
   $$051 = $98;
  } else {
   label = 23;
   break;
  }
 }
 if ((label|0) == 23) {
  STACKTOP = sp;return;
 }
 $92 = ___cxa_find_matching_catch_2()|0;
 $93 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($3|0));
 $94 = __THREW__; __THREW__ = 0;
 $95 = $94&1;
 if ($95) {
  $96 = ___cxa_find_matching_catch_3(0|0)|0;
  $97 = tempRet0;
  ___clang_call_terminate($96);
  // unreachable;
 } else {
  ___resumeException($92|0);
  // unreachable;
 }
}
function __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3fEfE9intersectERKS2_S5_S5_($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$$i$i = 0, $$0$be$in$i$i$i$i = 0, $$0$i$i$i$i = 0, $$015$i$i$i$i = 0, $$030$i$i$i = 0, $$1112 = 0, $$1114 = 0, $$6121 = 0.0, $$6121$in = 0.0, $$6128 = 0.0, $$6135 = 0.0, $$pre = 0, $$pre$i$i$i$i = 0, $$pre299 = 0, $$sink = 0.0, $$sink292 = 0, $$sroa$0$0$$sroa_idx = 0, $$sroa$0169$0 = 0.0, $$sroa$0169$0$$sroa_idx = 0, $$sroa$10$0 = 0.0;
 var $$sroa$10$0$$sroa_idx175 = 0, $$sroa$4$0$$sroa_idx165 = 0, $$sroa$5$0$$sroa_idx167 = 0, $$sroa$7$0 = 0.0, $$sroa$7$0$$sroa_idx172 = 0, $10 = 0, $100 = 0.0, $101 = 0, $102 = 0, $103 = 0.0, $104 = 0, $105 = 0.0, $106 = 0.0, $107 = 0.0, $108 = 0.0, $109 = 0.0, $11 = 0, $110 = 0.0, $111 = 0, $112 = 0.0;
 var $113 = 0.0, $114 = 0.0, $115 = 0.0, $116 = 0.0, $117 = 0, $118 = 0, $119 = 0.0, $12 = 0, $120 = 0.0, $121 = 0.0, $122 = 0.0, $123 = 0.0, $124 = 0.0, $125 = 0.0, $126 = 0.0, $127 = 0.0, $128 = 0.0, $129 = 0.0, $13 = 0, $130 = 0.0;
 var $131 = 0.0, $132 = 0.0, $133 = 0, $134 = 0, $135 = 0.0, $136 = 0, $137 = 0.0, $138 = 0.0, $139 = 0.0, $14 = 0, $140 = 0.0, $141 = 0.0, $142 = 0.0, $143 = 0.0, $144 = 0, $145 = 0, $146 = 0.0, $147 = 0, $148 = 0.0, $149 = 0.0;
 var $15 = 0, $150 = 0.0, $151 = 0.0, $152 = 0.0, $153 = 0.0, $154 = 0.0, $155 = 0.0, $156 = 0.0, $157 = 0.0, $158 = 0.0, $159 = 0.0, $16 = 0, $160 = 0.0, $161 = 0.0, $162 = 0.0, $163 = 0.0, $164 = 0.0, $165 = 0.0, $166 = 0.0, $167 = 0.0;
 var $168 = 0.0, $169 = 0.0, $17 = 0, $170 = 0.0, $171 = 0.0, $172 = 0.0, $173 = 0.0, $174 = 0.0, $175 = 0.0, $176 = 0.0, $177 = 0.0, $178 = 0.0, $179 = 0.0, $18 = 0, $180 = 0.0, $181 = 0.0, $182 = 0.0, $183 = 0.0, $184 = 0.0, $185 = 0.0;
 var $186 = 0, $187 = 0.0, $188 = 0.0, $189 = 0.0, $19 = 0.0, $190 = 0.0, $191 = 0, $192 = 0, $193 = 0.0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0.0, $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0.0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0;
 var $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0.0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0.0, $237 = 0.0, $238 = 0.0, $239 = 0, $24 = 0;
 var $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0.0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0;
 var $259 = 0, $26 = 0.0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0;
 var $277 = 0, $278 = 0, $279 = 0, $28 = 0.0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0;
 var $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $30 = 0.0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0.0, $308 = 0, $309 = 0, $31 = 0.0, $310 = 0, $311 = 0, $312 = 0;
 var $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0.0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0.0, $330 = 0;
 var $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0.0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0;
 var $35 = 0.0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0.0, $36 = 0.0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0;
 var $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0.0, $380 = 0, $381 = 0.0, $382 = 0, $383 = 0.0, $384 = 0, $385 = 0;
 var $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0.0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0.0, $400 = 0, $401 = 0, $402 = 0;
 var $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0.0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $42 = 0, $43 = 0.0, $44 = 0.0, $45 = 0, $46 = 0.0, $47 = 0.0, $48 = 0;
 var $49 = 0.0, $5 = 0, $50 = 0.0, $51 = 0, $52 = 0.0, $53 = 0.0, $54 = 0.0, $55 = 0.0, $56 = 0, $57 = 0.0, $58 = 0.0, $59 = 0.0, $6 = 0, $60 = 0.0, $61 = 0.0, $62 = 0.0, $63 = 0.0, $64 = 0.0, $65 = 0.0, $66 = 0.0;
 var $67 = 0.0, $68 = 0, $69 = 0.0, $7 = 0, $70 = 0.0, $71 = 0.0, $72 = 0.0, $73 = 0.0, $74 = 0, $75 = 0, $76 = 0.0, $77 = 0.0, $78 = 0.0, $79 = 0.0, $8 = 0, $80 = 0.0, $81 = 0.0, $82 = 0.0, $83 = 0.0, $84 = 0.0;
 var $85 = 0.0, $86 = 0.0, $87 = 0.0, $88 = 0.0, $89 = 0.0, $9 = 0, $90 = 0, $91 = 0, $92 = 0.0, $93 = 0, $94 = 0.0, $95 = 0.0, $96 = 0.0, $97 = 0.0, $98 = 0.0, $99 = 0.0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, $or$cond = 0, $or$cond142 = 0;
 var $or$cond143 = 0, $or$cond144 = 0, $or$cond146 = 0, $or$cond148 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(144|0);
 $4 = sp + 24|0;
 $5 = sp + 128|0;
 $6 = sp + 16|0;
 $7 = sp + 124|0;
 $8 = sp + 8|0;
 $9 = sp + 120|0;
 $10 = sp;
 $11 = HEAP32[$0>>2]|0;
 $12 = ((($11)) + 28|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = ($13<<24>>24)==(0);
 if (!($14)) {
  $15 = ((($0)) + 100|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = ($16<<24>>24)==(0);
  if (!($17)) {
   STACKTOP = sp;return;
  }
 }
 $18 = ((($0)) + 8|0);
 $19 = +HEAPF32[$18>>2];
 $20 = +HEAPF32[$1>>2];
 $21 = $19 - $20;
 $22 = ((($0)) + 12|0);
 $23 = +HEAPF32[$22>>2];
 $24 = ((($1)) + 4|0);
 $25 = +HEAPF32[$24>>2];
 $26 = $23 - $25;
 $27 = ((($0)) + 16|0);
 $28 = +HEAPF32[$27>>2];
 $29 = ((($1)) + 8|0);
 $30 = +HEAPF32[$29>>2];
 $31 = $28 - $30;
 $32 = +HEAPF32[$3>>2];
 $33 = $32 - $20;
 $34 = ((($3)) + 4|0);
 $35 = +HEAPF32[$34>>2];
 $36 = $35 - $25;
 $37 = ((($3)) + 8|0);
 $38 = +HEAPF32[$37>>2];
 $39 = $38 - $30;
 $40 = +HEAPF32[$2>>2];
 $41 = $40 - $20;
 $42 = ((($2)) + 4|0);
 $43 = +HEAPF32[$42>>2];
 $44 = $43 - $25;
 $45 = ((($2)) + 8|0);
 $46 = +HEAPF32[$45>>2];
 $47 = $46 - $30;
 $48 = ((($0)) + 48|0);
 $49 = +HEAPF32[$48>>2];
 $50 = $39 * $49;
 $51 = ((($0)) + 52|0);
 $52 = +HEAPF32[$51>>2];
 $53 = $36 * $52;
 $54 = $50 - $53;
 $55 = $33 * $52;
 $56 = ((($0)) + 44|0);
 $57 = +HEAPF32[$56>>2];
 $58 = $39 * $57;
 $59 = $55 - $58;
 $60 = $36 * $57;
 $61 = $33 * $49;
 $62 = $60 - $61;
 $63 = $41 * $54;
 $64 = $44 * $59;
 $65 = $63 + $64;
 $66 = $47 * $62;
 $67 = $66 + $65;
 $68 = $67 > 1.000000013351432E-10;
 if ($68) {
  $69 = $21 * $54;
  $70 = $26 * $59;
  $71 = $69 + $70;
  $72 = $31 * $62;
  $73 = $72 + $71;
  $74 = $73 < 0.0;
  $75 = $73 > $67;
  $or$cond = $74 | $75;
  if ($or$cond) {
   STACKTOP = sp;return;
  }
  $76 = $26 * $47;
  $77 = $31 * $44;
  $78 = $76 - $77;
  $79 = $31 * $41;
  $80 = $21 * $47;
  $81 = $79 - $80;
  $82 = $21 * $44;
  $83 = $26 * $41;
  $84 = $82 - $83;
  $85 = $78 * $57;
  $86 = $49 * $81;
  $87 = $85 + $86;
  $88 = $84 * $52;
  $89 = $88 + $87;
  $90 = $89 < 0.0;
  $91 = $89 > $67;
  $or$cond142 = $90 | $91;
  $92 = $89 + $73;
  $93 = $92 > $67;
  $or$cond146 = $or$cond142 | $93;
  if ($or$cond146) {
   STACKTOP = sp;return;
  }
  $94 = 1.0 / $67;
  $95 = $33 * $78;
  $96 = $36 * $81;
  $97 = $95 + $96;
  $98 = $39 * $84;
  $99 = $98 + $97;
  $100 = $99 * $94;
  $101 = $100 < 0.0;
  if ($101) {
   STACKTOP = sp;return;
  }
  $102 = ((($0)) + 56|0);
  $103 = +HEAPF32[$102>>2];
  $104 = $100 > $103;
  $105 = $73 * $94;
  $106 = $89 * $94;
  $107 = $105;
  $108 = 1.0 - $107;
  $109 = $106;
  $110 = $108 - $109;
  if ($104) {
   STACKTOP = sp;return;
  } else {
   $$6121$in = $110;$$6128 = $105;$$6135 = $106;$$sink = $100;
  }
 } else {
  $111 = $67 < -1.000000013351432E-10;
  if (!($111)) {
   STACKTOP = sp;return;
  }
  $112 = $21 * $54;
  $113 = $26 * $59;
  $114 = $112 + $113;
  $115 = $31 * $62;
  $116 = $115 + $114;
  $117 = $116 > 0.0;
  $118 = $116 < $67;
  $or$cond143 = $117 | $118;
  if ($or$cond143) {
   STACKTOP = sp;return;
  }
  $119 = $26 * $47;
  $120 = $31 * $44;
  $121 = $119 - $120;
  $122 = $31 * $41;
  $123 = $21 * $47;
  $124 = $122 - $123;
  $125 = $21 * $44;
  $126 = $26 * $41;
  $127 = $125 - $126;
  $128 = $121 * $57;
  $129 = $49 * $124;
  $130 = $128 + $129;
  $131 = $127 * $52;
  $132 = $131 + $130;
  $133 = $132 > 0.0;
  $134 = $132 < $67;
  $or$cond144 = $133 | $134;
  $135 = $132 + $116;
  $136 = $135 < $67;
  $or$cond148 = $or$cond144 | $136;
  if ($or$cond148) {
   STACKTOP = sp;return;
  }
  $137 = 1.0 / $67;
  $138 = $33 * $121;
  $139 = $36 * $124;
  $140 = $138 + $139;
  $141 = $39 * $127;
  $142 = $141 + $140;
  $143 = $142 * $137;
  $144 = $143 < 0.0;
  if ($144) {
   STACKTOP = sp;return;
  }
  $145 = ((($0)) + 56|0);
  $146 = +HEAPF32[$145>>2];
  $147 = $143 > $146;
  $148 = $116 * $137;
  $149 = $132 * $137;
  $150 = $148;
  $151 = 1.0 - $150;
  $152 = $149;
  $153 = $151 - $152;
  if ($147) {
   STACKTOP = sp;return;
  } else {
   $$6121$in = $153;$$6128 = $148;$$6135 = $149;$$sink = $143;
  }
 }
 $$6121 = $$6121$in;
 $$sink292 = ((($0)) + 60|0);
 $154 = +HEAPF32[$$sink292>>2];
 $155 = $$sink * $154;
 $156 = $$6121 * $20;
 $157 = $$6121 * $25;
 $158 = $$6121 * $30;
 $159 = $$6128 * $40;
 $160 = $$6128 * $43;
 $161 = $$6128 * $46;
 $162 = $156 + $159;
 $163 = $157 + $160;
 $164 = $158 + $161;
 $165 = $$6135 * $32;
 $166 = $$6135 * $35;
 $167 = $$6135 * $38;
 $168 = $162 + $165;
 $169 = $163 + $166;
 $170 = $164 + $167;
 $171 = $39 * $44;
 $172 = $36 * $47;
 $173 = $171 - $172;
 $174 = $33 * $47;
 $175 = $39 * $41;
 $176 = $174 - $175;
 $177 = $36 * $41;
 $178 = $33 * $44;
 $179 = $177 - $178;
 $180 = $173 * $173;
 $181 = $176 * $176;
 $182 = $180 + $181;
 $183 = $179 * $179;
 $184 = $183 + $182;
 $185 = (+Math_sqrt((+$184)));
 $186 = $185 > 0.0;
 $187 = 1.0 / $185;
 $188 = $173 * $187;
 $189 = $176 * $187;
 $190 = $179 * $187;
 $$sroa$0169$0 = $186 ? $188 : $173;
 $$sroa$7$0 = $186 ? $189 : $176;
 $$sroa$10$0 = $186 ? $190 : $179;
 $191 = ((($4)) + 8|0);
 $192 = ((($4)) + 32|0);
 ;HEAP32[$191>>2]=0|0;HEAP32[$191+4>>2]=0|0;HEAP32[$191+8>>2]=0|0;HEAP32[$191+12>>2]=0|0;HEAP32[$191+16>>2]=0|0;
 dest=$192; stop=dest+64|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $193 = $155;
 HEAPF64[$4>>3] = $193;
 $194 = ((($11)) + 16|0);
 $195 = HEAP32[$194>>2]|0;
 $196 = ((($195)) + 120|0);
 $197 = HEAP32[$196>>2]|0;
 $198 = ($197|0)==(0);
 if ($198) {
  $208 = $11;
 } else {
  $199 = ((($195)) + 112|0);
  $200 = HEAP32[$199>>2]|0;
  $201 = ((($200)) + 8|0);
  $202 = HEAP32[$201>>2]|0;
  $203 = ($202|0)==(0|0);
  if ($203) {
   $208 = $11;
  } else {
   $204 = ((($4)) + 24|0);
   HEAP32[$204>>2] = $202;
   $205 = ((($202)) + 8|0);
   $206 = HEAP32[$205>>2]|0;HEAP32[$205>>2] = (($206+1)|0);
   $$pre = HEAP32[$0>>2]|0;
   $208 = $$pre;
  }
 }
 $207 = ((($208)) + 16|0);
 $209 = HEAP32[$207>>2]|0;
 $210 = ((($209)) + 28|0);
 $211 = ((($4)) + 8|0);
 $212 = ($211|0)==($210|0);
 if ($212) {
  $219 = $208;
  label = 19;
 } else {
  $213 = HEAP32[$210>>2]|0;
  $214 = ((($209)) + 32|0);
  $215 = HEAP32[$214>>2]|0;
  __THREW__ = 0;
  invoke_viii(3566,($211|0),($213|0),($215|0));
  $216 = __THREW__; __THREW__ = 0;
  $217 = $216&1;
  if ($217) {
   label = 46;
  } else {
   $$pre299 = HEAP32[$0>>2]|0;
   $219 = $$pre299;
   label = 19;
  }
 }
 L39: do {
  if ((label|0) == 19) {
   $218 = ((($219)) + 20|0);
   $220 = HEAP32[$218>>2]|0;
   $221 = ((($4)) + 20|0);
   $222 = HEAP32[$221>>2]|0;
   $223 = ($222|0)==($220|0);
   if (!($223)) {
    HEAP32[$221>>2] = $220;
    $224 = ($220|0)==(0|0);
    if (!($224)) {
     $225 = ((($220)) + 8|0);
     $226 = HEAP32[$225>>2]|0;HEAP32[$225>>2] = (($226+1)|0);
    }
    $227 = ($222|0)==(0|0);
    if (!($227)) {
     $228 = ((($222)) + 8|0);
     $229 = HEAP32[$228>>2]|0;HEAP32[$228>>2] = (($229-1)|0);
     $230 = ($229|0)==(1);
     if ($230) {
      __THREW__ = 0;
      invoke_viii(3262,($222|0),1,1);
      $231 = __THREW__; __THREW__ = 0;
      $232 = $231&1;
      if ($232) {
       label = 46;
       break;
      }
     }
    }
   }
   $233 = ((($0)) + 4|0);
   $234 = HEAP32[$233>>2]|0;
   $235 = ((($4)) + 92|0);
   HEAP32[$235>>2] = $234;
   $236 = $168;
   $237 = $169;
   $238 = $170;
   $$sroa$0$0$$sroa_idx = ((($4)) + 32|0);
   HEAPF64[$$sroa$0$0$$sroa_idx>>3] = $236;
   $$sroa$4$0$$sroa_idx165 = ((($4)) + 40|0);
   HEAPF64[$$sroa$4$0$$sroa_idx165>>3] = $237;
   $$sroa$5$0$$sroa_idx167 = ((($4)) + 48|0);
   HEAPF64[$$sroa$5$0$$sroa_idx167>>3] = $238;
   $$sroa$0169$0$$sroa_idx = ((($4)) + 56|0);
   HEAPF32[$$sroa$0169$0$$sroa_idx>>2] = $$sroa$0169$0;
   $$sroa$7$0$$sroa_idx172 = ((($4)) + 60|0);
   HEAPF32[$$sroa$7$0$$sroa_idx172>>2] = $$sroa$7$0;
   $$sroa$10$0$$sroa_idx175 = ((($4)) + 64|0);
   HEAPF32[$$sroa$10$0$$sroa_idx175>>2] = $$sroa$10$0;
   $239 = HEAP32[$0>>2]|0;
   $240 = ((($239)) + 24|0);
   $241 = HEAP32[$240>>2]|0;
   $242 = ($241|0)==(0|0);
   L49: do {
    if (!($242)) {
     $243 = ((($241)) + 76|0);
     $244 = HEAP32[$243>>2]|0;
     $245 = ((($4)) + 68|0);
     $246 = ((($4)) + 76|0);
     $247 = HEAP32[$246>>2]|0;
     $248 = HEAP32[$245>>2]|0;
     $249 = (($247) - ($248))|0;
     $250 = $249 >> 2;
     $251 = ($250>>>0)<(3);
     if ($251) {
      $252 = ((($4)) + 72|0);
      $253 = HEAP32[$252>>2]|0;
      $254 = (($253) - ($248))|0;
      $255 = $254 >> 2;
      __THREW__ = 0;
      $256 = (invoke_ii(3276,12)|0);
      $257 = __THREW__; __THREW__ = 0;
      $258 = $257&1;
      if (!($258)) {
       $259 = (($256) + ($255<<2)|0);
       $260 = $259;
       $261 = ((($256)) + 12|0);
       $262 = $261;
       $263 = (0 - ($255))|0;
       $264 = (($259) + ($263<<2)|0);
       $265 = $264;
       $266 = ($254|0)>(0);
       if ($266) {
        $267 = $248;
        _memcpy(($264|0),($267|0),($254|0))|0;
       }
       HEAP32[$245>>2] = $265;
       HEAP32[$252>>2] = $260;
       HEAP32[$246>>2] = $262;
       $268 = ($248|0)==(0);
       if ($268) {
        label = 32;
       } else {
        $269 = $248;
        __ZdlPv($269);
        label = 32;
       }
      }
     } else {
      label = 32;
     }
     do {
      if ((label|0) == 32) {
       $270 = ((($4)) + 80|0);
       $271 = ((($4)) + 88|0);
       $272 = HEAP32[$271>>2]|0;
       $273 = HEAP32[$270>>2]|0;
       $274 = (($272) - ($273))|0;
       $275 = $274 >> 3;
       $276 = ($275>>>0)<(3);
       if ($276) {
        $277 = ((($4)) + 84|0);
        $278 = HEAP32[$277>>2]|0;
        $279 = (($278) - ($273))|0;
        $280 = $279 >> 3;
        __THREW__ = 0;
        $281 = (invoke_ii(3276,24)|0);
        $282 = __THREW__; __THREW__ = 0;
        $283 = $282&1;
        if ($283) {
         break;
        }
        $284 = (($281) + ($280<<3)|0);
        $285 = $284;
        $286 = ((($281)) + 24|0);
        $287 = $286;
        $288 = (0 - ($280))|0;
        $289 = (($284) + ($288<<3)|0);
        $290 = $289;
        $291 = ($279|0)>(0);
        if ($291) {
         $292 = $273;
         _memcpy(($289|0),($292|0),($279|0))|0;
        }
        HEAP32[$270>>2] = $290;
        HEAP32[$277>>2] = $285;
        HEAP32[$271>>2] = $287;
        $293 = ($273|0)==(0);
        if (!($293)) {
         $294 = $273;
         __ZdlPv($294);
        }
       }
       $295 = $$6121 != 0.0;
       if ($295) {
        $296 = $1;
        $297 = $244;
        $298 = (($296) - ($297))|0;
        $299 = (($298|0) / 12)&-1;
        HEAP32[$5>>2] = $299;
        $300 = ((($4)) + 72|0);
        $301 = HEAP32[$300>>2]|0;
        $302 = HEAP32[$246>>2]|0;
        $303 = ($301|0)==($302|0);
        if ($303) {
         __THREW__ = 0;
         invoke_vii(3437,($245|0),($5|0));
         $305 = __THREW__; __THREW__ = 0;
         $306 = $305&1;
         if ($306) {
          $319 = ___cxa_find_matching_catch_2()|0;
          $320 = tempRet0;
          $$1112 = $320;$$1114 = $319;
          break L39;
         }
        } else {
         HEAP32[$301>>2] = $299;
         $304 = ((($301)) + 4|0);
         HEAP32[$300>>2] = $304;
        }
        $307 = $$6121;
        HEAPF64[$6>>3] = $307;
        $308 = ((($4)) + 84|0);
        $309 = HEAP32[$308>>2]|0;
        $310 = HEAP32[$271>>2]|0;
        $311 = ($309|0)==($310|0);
        if ($311) {
         __THREW__ = 0;
         invoke_vii(3567,($270|0),($6|0));
         $313 = __THREW__; __THREW__ = 0;
         $314 = $313&1;
         if ($314) {
          $321 = ___cxa_find_matching_catch_2()|0;
          $322 = tempRet0;
          $$1112 = $322;$$1114 = $321;
          break L39;
         }
        } else {
         HEAPF64[$309>>3] = $307;
         $312 = ((($309)) + 8|0);
         HEAP32[$308>>2] = $312;
        }
       }
       $323 = $$6128 != 0.0;
       if ($323) {
        $324 = $2;
        $325 = $244;
        $326 = (($324) - ($325))|0;
        $327 = (($326|0) / 12)&-1;
        HEAP32[$7>>2] = $327;
        $328 = ((($4)) + 72|0);
        $329 = HEAP32[$328>>2]|0;
        $330 = HEAP32[$246>>2]|0;
        $331 = ($329|0)==($330|0);
        if ($331) {
         __THREW__ = 0;
         invoke_vii(3437,($245|0),($7|0));
         $333 = __THREW__; __THREW__ = 0;
         $334 = $333&1;
         if ($334) {
          $343 = ___cxa_find_matching_catch_2()|0;
          $344 = tempRet0;
          $$1112 = $344;$$1114 = $343;
          break L39;
         }
        } else {
         HEAP32[$329>>2] = $327;
         $332 = ((($329)) + 4|0);
         HEAP32[$328>>2] = $332;
        }
        $335 = $$6128;
        HEAPF64[$8>>3] = $335;
        $336 = ((($4)) + 84|0);
        $337 = HEAP32[$336>>2]|0;
        $338 = HEAP32[$271>>2]|0;
        $339 = ($337|0)==($338|0);
        if ($339) {
         __THREW__ = 0;
         invoke_vii(3567,($270|0),($8|0));
         $341 = __THREW__; __THREW__ = 0;
         $342 = $341&1;
         if ($342) {
          $345 = ___cxa_find_matching_catch_2()|0;
          $346 = tempRet0;
          $$1112 = $346;$$1114 = $345;
          break L39;
         }
        } else {
         HEAPF64[$337>>3] = $335;
         $340 = ((($337)) + 8|0);
         HEAP32[$336>>2] = $340;
        }
       }
       $347 = $$6135 != 0.0;
       if (!($347)) {
        break L49;
       }
       $348 = $3;
       $349 = $244;
       $350 = (($348) - ($349))|0;
       $351 = (($350|0) / 12)&-1;
       HEAP32[$9>>2] = $351;
       $352 = ((($4)) + 72|0);
       $353 = HEAP32[$352>>2]|0;
       $354 = HEAP32[$246>>2]|0;
       $355 = ($353|0)==($354|0);
       if ($355) {
        __THREW__ = 0;
        invoke_vii(3437,($245|0),($9|0));
        $357 = __THREW__; __THREW__ = 0;
        $358 = $357&1;
        if ($358) {
         $367 = ___cxa_find_matching_catch_2()|0;
         $368 = tempRet0;
         $$1112 = $368;$$1114 = $367;
         break L39;
        }
       } else {
        HEAP32[$353>>2] = $351;
        $356 = ((($353)) + 4|0);
        HEAP32[$352>>2] = $356;
       }
       $359 = $$6135;
       HEAPF64[$10>>3] = $359;
       $360 = ((($4)) + 84|0);
       $361 = HEAP32[$360>>2]|0;
       $362 = HEAP32[$271>>2]|0;
       $363 = ($361|0)==($362|0);
       if ($363) {
        __THREW__ = 0;
        invoke_vii(3567,($270|0),($10|0));
        $365 = __THREW__; __THREW__ = 0;
        $366 = $365&1;
        if ($366) {
         $369 = ___cxa_find_matching_catch_2()|0;
         $370 = tempRet0;
         $$1112 = $370;$$1114 = $369;
         break L39;
        }
       } else {
        HEAPF64[$361>>3] = $359;
        $364 = ((($361)) + 8|0);
        HEAP32[$360>>2] = $364;
       }
       break L49;
      }
     } while(0);
     $317 = ___cxa_find_matching_catch_2()|0;
     $318 = tempRet0;
     $$1112 = $318;$$1114 = $317;
     break L39;
    }
   } while(0);
   $371 = HEAP32[$0>>2]|0;
   $372 = ((($371)) + 12|0);
   $373 = HEAP32[$372>>2]|0;
   $374 = ((($373)) + 28|0);
   $375 = HEAP32[$374>>2]|0;
   $376 = ($375|0)==(0|0);
   $$$i$i = $376 ? $373 : $375;
   $377 = ((($$$i$i)) + 80|0);
   $378 = ((($$$i$i)) + 84|0);
   $379 = HEAP32[$378>>2]|0;
   $380 = ($379|0)==(0|0);
   do {
    if ($380) {
     $$015$i$i$i$i = $378;$$030$i$i$i = $378;
    } else {
     $381 = +HEAPF64[$4>>3];
     $$0$i$i$i$i = $379;
     while(1) {
      $382 = ((($$0$i$i$i$i)) + 16|0);
      $383 = +HEAPF64[$382>>3];
      $384 = $381 < $383;
      if ($384) {
       $385 = HEAP32[$$0$i$i$i$i>>2]|0;
       $386 = ($385|0)==(0|0);
       if ($386) {
        label = 75;
        break;
       } else {
        $$0$be$in$i$i$i$i = $385;
       }
      } else {
       $387 = ((($$0$i$i$i$i)) + 4|0);
       $388 = HEAP32[$387>>2]|0;
       $389 = ($388|0)==(0|0);
       if ($389) {
        label = 78;
        break;
       } else {
        $$0$be$in$i$i$i$i = $388;
       }
      }
      $$0$i$i$i$i = $$0$be$in$i$i$i$i;
     }
     if ((label|0) == 75) {
      $$015$i$i$i$i = $$0$i$i$i$i;$$030$i$i$i = $$0$i$i$i$i;
      break;
     }
     else if ((label|0) == 78) {
      $$015$i$i$i$i = $387;$$030$i$i$i = $$0$i$i$i$i;
      break;
     }
    }
   } while(0);
   __THREW__ = 0;
   $390 = (invoke_ii(3276,112)|0);
   $391 = __THREW__; __THREW__ = 0;
   $392 = $391&1;
   if ($392) {
    label = 46;
   } else {
    $393 = ((($390)) + 16|0);
    __THREW__ = 0;
    invoke_vii(3315,($393|0),($4|0));
    $394 = __THREW__; __THREW__ = 0;
    $395 = $394&1;
    if ($395) {
     $396 = ___cxa_find_matching_catch_2()|0;
     $397 = tempRet0;
     __ZdlPv($390);
     $eh$lpad$body$index2Z2D = $397;$eh$lpad$body$indexZ2D = $396;
     label = 47;
     break;
    }
    HEAP32[$390>>2] = 0;
    $398 = ((($390)) + 4|0);
    HEAP32[$398>>2] = 0;
    $399 = ((($390)) + 8|0);
    HEAP32[$399>>2] = $$030$i$i$i;
    HEAP32[$$015$i$i$i$i>>2] = $390;
    $400 = HEAP32[$377>>2]|0;
    $401 = HEAP32[$400>>2]|0;
    $402 = ($401|0)==(0|0);
    if ($402) {
     $406 = $390;
    } else {
     $403 = $401;
     HEAP32[$377>>2] = $403;
     $$pre$i$i$i$i = HEAP32[$$015$i$i$i$i>>2]|0;
     $406 = $$pre$i$i$i$i;
    }
    $404 = ((($$$i$i)) + 84|0);
    $405 = HEAP32[$404>>2]|0;
    __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($405,$406);
    $407 = ((($$$i$i)) + 88|0);
    $408 = HEAP32[$407>>2]|0;
    $409 = (($408) + 1)|0;
    HEAP32[$407>>2] = $409;
    $410 = ((($0)) + 100|0);
    HEAP8[$410>>0] = 1;
    __ZN7osgUtil22LineSegmentIntersector12IntersectionD2Ev($4);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 46) {
  $315 = ___cxa_find_matching_catch_2()|0;
  $316 = tempRet0;
  $eh$lpad$body$index2Z2D = $316;$eh$lpad$body$indexZ2D = $315;
  label = 47;
 }
 if ((label|0) == 47) {
  $$1112 = $eh$lpad$body$index2Z2D;$$1114 = $eh$lpad$body$indexZ2D;
 }
 __THREW__ = 0;
 invoke_vi(3316,($4|0));
 $411 = __THREW__; __THREW__ = 0;
 $412 = $411&1;
 if ($412) {
  $413 = ___cxa_find_matching_catch_3(0|0)|0;
  $414 = tempRet0;
  ___clang_call_terminate($413);
  // unreachable;
 } else {
  ___resumeException($$1114|0);
  // unreachable;
 }
}
function __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3fEfE5enterERKNS1_15BoundingBoxImplIS2_EE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$sroa$4237$0$$sroa_idx238 = 0, $$sroa$4251$0$$sroa_idx252 = 0, $$sroa$5184$0$$sroa_idx185 = 0, $$sroa$5198$0$$sroa_idx199 = 0, $$sroa$5240$0$$sroa_idx241 = 0, $$sroa$5254$0$$sroa_idx255 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0.0, $103 = 0, $104 = 0, $105 = 0.0, $106 = 0, $107 = 0.0, $108 = 0.0, $109 = 0, $11 = 0.0, $110 = 0.0;
 var $111 = 0.0, $112 = 0, $113 = 0.0, $114 = 0.0, $115 = 0.0, $116 = 0.0, $117 = 0.0, $118 = 0, $119 = 0.0, $12 = 0, $120 = 0.0, $121 = 0, $122 = 0.0, $123 = 0.0, $124 = 0, $125 = 0.0, $126 = 0.0, $127 = 0, $128 = 0.0, $129 = 0.0;
 var $13 = 0, $130 = 0, $131 = 0.0, $132 = 0.0, $133 = 0.0, $134 = 0.0, $135 = 0.0, $136 = 0, $137 = 0.0, $138 = 0.0, $139 = 0, $14 = 0.0, $140 = 0, $141 = 0.0, $142 = 0, $143 = 0, $144 = 0.0, $145 = 0, $146 = 0.0, $147 = 0.0;
 var $148 = 0, $149 = 0.0, $15 = 0, $150 = 0.0, $151 = 0, $152 = 0.0, $153 = 0.0, $154 = 0.0, $155 = 0.0, $156 = 0, $157 = 0.0, $158 = 0.0, $159 = 0, $16 = 0, $160 = 0.0, $161 = 0, $162 = 0.0, $163 = 0.0, $164 = 0, $165 = 0.0;
 var $166 = 0.0, $167 = 0, $168 = 0.0, $169 = 0.0, $17 = 0.0, $170 = 0.0, $171 = 0.0, $172 = 0, $173 = 0.0, $174 = 0.0, $175 = 0, $176 = 0.0, $177 = 0, $178 = 0.0, $179 = 0, $18 = 0, $180 = 0, $181 = 0.0, $182 = 0, $183 = 0;
 var $184 = 0.0, $185 = 0, $186 = 0, $187 = 0.0, $188 = 0, $189 = 0.0, $19 = 0.0, $190 = 0.0, $191 = 0, $192 = 0.0, $193 = 0.0, $194 = 0, $195 = 0.0, $196 = 0.0, $197 = 0.0, $198 = 0.0, $199 = 0.0, $2 = 0, $20 = 0.0, $200 = 0.0;
 var $201 = 0.0, $202 = 0, $203 = 0.0, $204 = 0.0, $205 = 0, $206 = 0.0, $207 = 0.0, $208 = 0, $209 = 0.0, $21 = 0, $210 = 0.0, $211 = 0, $212 = 0.0, $213 = 0.0, $214 = 0.0, $215 = 0.0, $216 = 0.0, $217 = 0.0, $218 = 0.0, $219 = 0;
 var $22 = 0.0, $220 = 0, $221 = 0.0, $222 = 0, $223 = 0, $224 = 0.0, $225 = 0, $226 = 0.0, $227 = 0.0, $228 = 0, $229 = 0.0, $23 = 0.0, $230 = 0.0, $231 = 0, $232 = 0.0, $233 = 0.0, $234 = 0.0, $235 = 0.0, $236 = 0.0, $237 = 0;
 var $238 = 0.0, $239 = 0, $24 = 0, $240 = 0.0, $241 = 0.0, $242 = 0, $243 = 0.0, $244 = 0.0, $245 = 0, $246 = 0.0, $247 = 0.0, $248 = 0.0, $249 = 0.0, $25 = 0.0, $250 = 0.0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0;
 var $26 = 0.0, $27 = 0.0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0.0, $31 = 0, $32 = 0.0, $33 = 0.0, $34 = 0, $35 = 0.0, $36 = 0.0, $37 = 0, $38 = 0.0, $39 = 0.0, $4 = 0, $40 = 0, $41 = 0.0, $42 = 0.0, $43 = 0;
 var $44 = 0.0, $45 = 0.0, $46 = 0.0, $47 = 0, $48 = 0.0, $49 = 0.0, $5 = 0, $50 = 0, $51 = 0.0, $52 = 0.0, $53 = 0, $54 = 0, $55 = 0.0, $56 = 0, $57 = 0, $58 = 0.0, $59 = 0, $6 = 0, $60 = 0.0, $61 = 0.0;
 var $62 = 0, $63 = 0.0, $64 = 0.0, $65 = 0, $66 = 0.0, $67 = 0.0, $68 = 0.0, $69 = 0, $7 = 0.0, $70 = 0.0, $71 = 0.0, $72 = 0, $73 = 0.0, $74 = 0.0, $75 = 0, $76 = 0.0, $77 = 0, $78 = 0.0, $79 = 0.0, $8 = 0;
 var $80 = 0, $81 = 0.0, $82 = 0.0, $83 = 0, $84 = 0.0, $85 = 0.0, $86 = 0.0, $87 = 0, $88 = 0.0, $89 = 0.0, $9 = 0.0, $90 = 0, $91 = 0.0, $92 = 0.0, $93 = 0, $94 = 0.0, $95 = 0, $96 = 0.0, $97 = 0, $98 = 0;
 var $99 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $2 = sp;
 $3 = ((($0)) + 32|0);
 $4 = ((($0)) + 36|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($5)) + -24|0);
 ;HEAP32[$2>>2]=HEAP32[$6>>2]|0;HEAP32[$2+4>>2]=HEAP32[$6+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$6+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$6+12>>2]|0;HEAP32[$2+16>>2]=HEAP32[$6+16>>2]|0;HEAP32[$2+20>>2]=HEAP32[$6+20>>2]|0;
 $7 = +HEAPF32[$2>>2];
 $8 = ((($2)) + 12|0);
 $9 = +HEAPF32[$8>>2];
 $10 = !($7 <= $9);
 $11 = +HEAPF32[$1>>2];
 if ($10) {
  $53 = $7 < $11;
  if ($53) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $54 = ((($1)) + 12|0);
  $55 = +HEAPF32[$54>>2];
  $56 = $9 > $55;
  if ($56) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $57 = $9 < $11;
  if ($57) {
   $58 = $11 - $7;
   $59 = ((($0)) + 64|0);
   $60 = +HEAPF32[$59>>2];
   $61 = $58 * $60;
   $62 = ((($0)) + 68|0);
   $63 = +HEAPF32[$62>>2];
   $64 = $58 * $63;
   $65 = ((($0)) + 72|0);
   $66 = +HEAPF32[$65>>2];
   $67 = $58 * $66;
   $68 = $7 + $61;
   $69 = ((($2)) + 4|0);
   $70 = +HEAPF32[$69>>2];
   $71 = $64 + $70;
   $72 = ((($2)) + 8|0);
   $73 = +HEAPF32[$72>>2];
   $74 = $67 + $73;
   HEAPF32[$8>>2] = $68;
   $$sroa$4237$0$$sroa_idx238 = ((($2)) + 16|0);
   HEAPF32[$$sroa$4237$0$$sroa_idx238>>2] = $71;
   $$sroa$5240$0$$sroa_idx241 = ((($2)) + 20|0);
   HEAPF32[$$sroa$5240$0$$sroa_idx241>>2] = $74;
  }
  $75 = $7 > $55;
  if ($75) {
   $76 = $55 - $7;
   $77 = ((($0)) + 64|0);
   $78 = +HEAPF32[$77>>2];
   $79 = $76 * $78;
   $80 = ((($0)) + 68|0);
   $81 = +HEAPF32[$80>>2];
   $82 = $76 * $81;
   $83 = ((($0)) + 72|0);
   $84 = +HEAPF32[$83>>2];
   $85 = $76 * $84;
   $86 = $7 + $79;
   $87 = ((($2)) + 4|0);
   $88 = +HEAPF32[$87>>2];
   $89 = $82 + $88;
   $90 = ((($2)) + 8|0);
   $91 = +HEAPF32[$90>>2];
   $92 = $85 + $91;
   HEAPF32[$2>>2] = $86;
   HEAPF32[$87>>2] = $89;
   HEAPF32[$90>>2] = $92;
   $116 = $86;
  } else {
   $116 = $7;
  }
 } else {
  $12 = $9 < $11;
  if ($12) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $13 = ((($1)) + 12|0);
  $14 = +HEAPF32[$13>>2];
  $15 = $7 > $14;
  if ($15) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $16 = $7 < $11;
  if ($16) {
   $17 = $11 - $7;
   $18 = ((($0)) + 64|0);
   $19 = +HEAPF32[$18>>2];
   $20 = $17 * $19;
   $21 = ((($0)) + 68|0);
   $22 = +HEAPF32[$21>>2];
   $23 = $17 * $22;
   $24 = ((($0)) + 72|0);
   $25 = +HEAPF32[$24>>2];
   $26 = $17 * $25;
   $27 = $7 + $20;
   $28 = ((($2)) + 4|0);
   $29 = +HEAPF32[$28>>2];
   $30 = $23 + $29;
   $31 = ((($2)) + 8|0);
   $32 = +HEAPF32[$31>>2];
   $33 = $26 + $32;
   HEAPF32[$2>>2] = $27;
   HEAPF32[$28>>2] = $30;
   HEAPF32[$31>>2] = $33;
   $36 = $27;
  } else {
   $36 = $7;
  }
  $34 = $9 > $14;
  if ($34) {
   $35 = $14 - $36;
   $37 = ((($0)) + 64|0);
   $38 = +HEAPF32[$37>>2];
   $39 = $38 * $35;
   $40 = ((($0)) + 68|0);
   $41 = +HEAPF32[$40>>2];
   $42 = $35 * $41;
   $43 = ((($0)) + 72|0);
   $44 = +HEAPF32[$43>>2];
   $45 = $35 * $44;
   $46 = $36 + $39;
   $47 = ((($2)) + 4|0);
   $48 = +HEAPF32[$47>>2];
   $49 = $42 + $48;
   $50 = ((($2)) + 8|0);
   $51 = +HEAPF32[$50>>2];
   $52 = $45 + $51;
   HEAPF32[$8>>2] = $46;
   $$sroa$4251$0$$sroa_idx252 = ((($2)) + 16|0);
   HEAPF32[$$sroa$4251$0$$sroa_idx252>>2] = $49;
   $$sroa$5254$0$$sroa_idx255 = ((($2)) + 20|0);
   HEAPF32[$$sroa$5254$0$$sroa_idx255>>2] = $52;
   $116 = $36;
  } else {
   $116 = $36;
  }
 }
 $93 = ((($2)) + 4|0);
 $94 = +HEAPF32[$93>>2];
 $95 = ((($2)) + 16|0);
 $96 = +HEAPF32[$95>>2];
 $97 = !($94 <= $96);
 $98 = ((($1)) + 4|0);
 $99 = +HEAPF32[$98>>2];
 if ($97) {
  $139 = $94 < $99;
  if ($139) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $140 = ((($1)) + 16|0);
  $141 = +HEAPF32[$140>>2];
  $142 = $96 > $141;
  if ($142) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $143 = $96 < $99;
  if ($143) {
   $144 = $99 - $94;
   $145 = ((($0)) + 76|0);
   $146 = +HEAPF32[$145>>2];
   $147 = $144 * $146;
   $148 = ((($0)) + 80|0);
   $149 = +HEAPF32[$148>>2];
   $150 = $144 * $149;
   $151 = ((($0)) + 84|0);
   $152 = +HEAPF32[$151>>2];
   $153 = $144 * $152;
   $154 = $147 + $116;
   $155 = $94 + $150;
   $156 = ((($2)) + 8|0);
   $157 = +HEAPF32[$156>>2];
   $158 = $153 + $157;
   HEAPF32[$8>>2] = $154;
   HEAPF32[$95>>2] = $155;
   $$sroa$5184$0$$sroa_idx185 = ((($2)) + 20|0);
   HEAPF32[$$sroa$5184$0$$sroa_idx185>>2] = $158;
  }
  $159 = $94 > $141;
  if ($159) {
   $160 = $141 - $94;
   $161 = ((($0)) + 76|0);
   $162 = +HEAPF32[$161>>2];
   $163 = $160 * $162;
   $164 = ((($0)) + 80|0);
   $165 = +HEAPF32[$164>>2];
   $166 = $160 * $165;
   $167 = ((($0)) + 84|0);
   $168 = +HEAPF32[$167>>2];
   $169 = $160 * $168;
   $170 = $163 + $116;
   $171 = $94 + $166;
   $172 = ((($2)) + 8|0);
   $173 = +HEAPF32[$172>>2];
   $174 = $169 + $173;
   HEAPF32[$2>>2] = $170;
   HEAPF32[$93>>2] = $171;
   HEAPF32[$172>>2] = $174;
   $198 = $170;$200 = $171;
  } else {
   $198 = $116;$200 = $94;
  }
 } else {
  $100 = $96 < $99;
  if ($100) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $101 = ((($1)) + 16|0);
  $102 = +HEAPF32[$101>>2];
  $103 = $94 > $102;
  if ($103) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $104 = $94 < $99;
  if ($104) {
   $105 = $99 - $94;
   $106 = ((($0)) + 76|0);
   $107 = +HEAPF32[$106>>2];
   $108 = $105 * $107;
   $109 = ((($0)) + 80|0);
   $110 = +HEAPF32[$109>>2];
   $111 = $105 * $110;
   $112 = ((($0)) + 84|0);
   $113 = +HEAPF32[$112>>2];
   $114 = $105 * $113;
   $115 = $108 + $116;
   $117 = $94 + $111;
   $118 = ((($2)) + 8|0);
   $119 = +HEAPF32[$118>>2];
   $120 = $114 + $119;
   HEAPF32[$2>>2] = $115;
   HEAPF32[$93>>2] = $117;
   HEAPF32[$118>>2] = $120;
   $123 = $117;$134 = $115;
  } else {
   $123 = $94;$134 = $116;
  }
  $121 = $96 > $102;
  if ($121) {
   $122 = $102 - $123;
   $124 = ((($0)) + 76|0);
   $125 = +HEAPF32[$124>>2];
   $126 = $125 * $122;
   $127 = ((($0)) + 80|0);
   $128 = +HEAPF32[$127>>2];
   $129 = $122 * $128;
   $130 = ((($0)) + 84|0);
   $131 = +HEAPF32[$130>>2];
   $132 = $122 * $131;
   $133 = $126 + $134;
   $135 = $123 + $129;
   $136 = ((($2)) + 8|0);
   $137 = +HEAPF32[$136>>2];
   $138 = $132 + $137;
   HEAPF32[$8>>2] = $133;
   HEAPF32[$95>>2] = $135;
   $$sroa$5198$0$$sroa_idx199 = ((($2)) + 20|0);
   HEAPF32[$$sroa$5198$0$$sroa_idx199>>2] = $138;
   $198 = $134;$200 = $123;
  } else {
   $198 = $134;$200 = $123;
  }
 }
 $175 = ((($2)) + 8|0);
 $176 = +HEAPF32[$175>>2];
 $177 = ((($2)) + 20|0);
 $178 = +HEAPF32[$177>>2];
 $179 = !($176 <= $178);
 $180 = ((($1)) + 8|0);
 $181 = +HEAPF32[$180>>2];
 if ($179) {
  $219 = $176 < $181;
  if ($219) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $220 = ((($1)) + 20|0);
  $221 = +HEAPF32[$220>>2];
  $222 = $178 > $221;
  if ($222) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $223 = $178 < $181;
  if ($223) {
   $224 = $181 - $176;
   $225 = ((($0)) + 88|0);
   $226 = +HEAPF32[$225>>2];
   $227 = $224 * $226;
   $228 = ((($0)) + 92|0);
   $229 = +HEAPF32[$228>>2];
   $230 = $224 * $229;
   $231 = ((($0)) + 96|0);
   $232 = +HEAPF32[$231>>2];
   $233 = $224 * $232;
   $234 = $227 + $198;
   $235 = $230 + $200;
   $236 = $176 + $233;
   HEAPF32[$8>>2] = $234;
   HEAPF32[$95>>2] = $235;
   HEAPF32[$177>>2] = $236;
  }
  $237 = $176 > $221;
  if ($237) {
   $238 = $221 - $176;
   $239 = ((($0)) + 88|0);
   $240 = +HEAPF32[$239>>2];
   $241 = $238 * $240;
   $242 = ((($0)) + 92|0);
   $243 = +HEAPF32[$242>>2];
   $244 = $238 * $243;
   $245 = ((($0)) + 96|0);
   $246 = +HEAPF32[$245>>2];
   $247 = $238 * $246;
   $248 = $241 + $198;
   $249 = $244 + $200;
   $250 = $176 + $247;
   HEAPF32[$2>>2] = $248;
   HEAPF32[$93>>2] = $249;
   HEAPF32[$175>>2] = $250;
  }
 } else {
  $182 = $178 < $181;
  if ($182) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $183 = ((($1)) + 20|0);
  $184 = +HEAPF32[$183>>2];
  $185 = $176 > $184;
  if ($185) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $186 = $176 < $181;
  if ($186) {
   $187 = $181 - $176;
   $188 = ((($0)) + 88|0);
   $189 = +HEAPF32[$188>>2];
   $190 = $187 * $189;
   $191 = ((($0)) + 92|0);
   $192 = +HEAPF32[$191>>2];
   $193 = $187 * $192;
   $194 = ((($0)) + 96|0);
   $195 = +HEAPF32[$194>>2];
   $196 = $187 * $195;
   $197 = $190 + $198;
   $199 = $193 + $200;
   $201 = $176 + $196;
   HEAPF32[$2>>2] = $197;
   HEAPF32[$93>>2] = $199;
   HEAPF32[$175>>2] = $201;
   $204 = $201;$215 = $197;$217 = $199;
  } else {
   $204 = $176;$215 = $198;$217 = $200;
  }
  $202 = $178 > $184;
  if ($202) {
   $203 = $184 - $204;
   $205 = ((($0)) + 88|0);
   $206 = +HEAPF32[$205>>2];
   $207 = $206 * $203;
   $208 = ((($0)) + 92|0);
   $209 = +HEAPF32[$208>>2];
   $210 = $203 * $209;
   $211 = ((($0)) + 96|0);
   $212 = +HEAPF32[$211>>2];
   $213 = $203 * $212;
   $214 = $207 + $215;
   $216 = $210 + $217;
   $218 = $204 + $213;
   HEAPF32[$8>>2] = $214;
   HEAPF32[$95>>2] = $216;
   HEAPF32[$177>>2] = $218;
  }
 }
 $251 = ((($0)) + 40|0);
 $252 = HEAP32[$251>>2]|0;
 $253 = ($5|0)==($252|0);
 if ($253) {
  __ZNSt3__26vectorINS_4pairIN3osg5Vec3fES3_EENS_9allocatorIS4_EEE21__push_back_slow_pathIKS4_EEvRT_($3,$2);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 } else {
  ;HEAP32[$5>>2]=HEAP32[$2>>2]|0;HEAP32[$5+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$2+12>>2]|0;HEAP32[$5+16>>2]=HEAP32[$2+16>>2]|0;HEAP32[$5+20>>2]=HEAP32[$2+20>>2]|0;
  $254 = HEAP32[$4>>2]|0;
  $255 = ((($254)) + 24|0);
  HEAP32[$4>>2] = $255;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 return (0)|0;
}
function __ZNSt3__26vectorINS_4pairIN3osg5Vec3fES3_EENS_9allocatorIS4_EEE21__push_back_slow_pathIKS4_EEvRT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = (($5|0) / 24)&-1;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(178956970);
 if ($8) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $9 = ((($0)) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) - ($4))|0;
 $12 = (($11|0) / 24)&-1;
 $13 = ($12>>>0)<(89478485);
 $14 = $12 << 1;
 $15 = ($14>>>0)<($7>>>0);
 $$sroa$speculated$i = $15 ? $7 : $14;
 $$sroa$speculated$$i = $13 ? $$sroa$speculated$i : 178956970;
 $16 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($16) {
   $26 = 0;
  } else {
   $17 = ($$sroa$speculated$$i>>>0)>(178956970);
   if (!($17)) {
    $23 = ($$sroa$speculated$$i*24)|0;
    $24 = (__Znwj($23)|0);
    $26 = $24;
    break;
   }
   $18 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($18|0),(204840|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if ($20) {
    $21 = ___cxa_find_matching_catch_2()|0;
    $22 = tempRet0;
    ___cxa_free_exception(($18|0));
    ___resumeException($21|0);
    // unreachable;
   } else {
    HEAP32[$18>>2] = (99824);
    ___cxa_throw(($18|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $25 = (($26) + (($6*24)|0)|0);
 $27 = (($26) + (($$sroa$speculated$$i*24)|0)|0);
 $28 = $27;
 ;HEAP32[$25>>2]=HEAP32[$1>>2]|0;HEAP32[$25+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$25+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$25+12>>2]=HEAP32[$1+12>>2]|0;HEAP32[$25+16>>2]=HEAP32[$1+16>>2]|0;HEAP32[$25+20>>2]=HEAP32[$1+20>>2]|0;
 $29 = ((($25)) + 24|0);
 $30 = $29;
 $31 = (($5|0) / -24)&-1;
 $32 = (($25) + (($31*24)|0)|0);
 $33 = $32;
 $34 = ($5|0)>(0);
 if ($34) {
  $35 = $4;
  _memcpy(($32|0),($35|0),($5|0))|0;
 }
 HEAP32[$0>>2] = $33;
 HEAP32[$2>>2] = $30;
 HEAP32[$9>>2] = $28;
 $36 = ($4|0)==(0);
 if ($36) {
  return;
 }
 $37 = $4;
 __ZdlPv($37);
 return;
}
function __ZNSt3__26vectorIdNS_9allocatorIdEEE21__push_back_slow_pathIKdEEvRT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 3;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(536870911);
 if ($8) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $9 = ((($0)) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) - ($4))|0;
 $12 = $11 >> 3;
 $13 = ($12>>>0)<(268435455);
 $14 = $11 >> 2;
 $15 = ($14>>>0)<($7>>>0);
 $$sroa$speculated$i = $15 ? $7 : $14;
 $$sroa$speculated$$i = $13 ? $$sroa$speculated$i : 536870911;
 $16 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($16) {
   $26 = 0;
  } else {
   $17 = ($$sroa$speculated$$i>>>0)>(536870911);
   if (!($17)) {
    $23 = $$sroa$speculated$$i << 3;
    $24 = (__Znwj($23)|0);
    $26 = $24;
    break;
   }
   $18 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($18|0),(204840|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if ($20) {
    $21 = ___cxa_find_matching_catch_2()|0;
    $22 = tempRet0;
    ___cxa_free_exception(($18|0));
    ___resumeException($21|0);
    // unreachable;
   } else {
    HEAP32[$18>>2] = (99824);
    ___cxa_throw(($18|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $25 = (($26) + ($6<<3)|0);
 $27 = (($26) + ($$sroa$speculated$$i<<3)|0);
 $28 = $27;
 $29 = +HEAPF64[$1>>3];
 HEAPF64[$25>>3] = $29;
 $30 = ((($25)) + 8|0);
 $31 = $30;
 $32 = (0 - ($6))|0;
 $33 = (($25) + ($32<<3)|0);
 $34 = $33;
 $35 = ($5|0)>(0);
 if ($35) {
  $36 = $4;
  _memcpy(($33|0),($36|0),($5|0))|0;
 }
 HEAP32[$0>>2] = $34;
 HEAP32[$2>>2] = $31;
 HEAP32[$9>>2] = $28;
 $37 = ($4|0)==(0);
 if ($37) {
  return;
 }
 $38 = $4;
 __ZdlPv($38);
 return;
}
function __ZN3osg24TemplatePrimitiveFunctorIN27LineSegmentIntersectorUtils16IntersectFunctorINS_5Vec3fEfEEED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i = 0, $scevgep5$i$i$i$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 36|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = ((($0)) + 40|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==($2|0);
  if (!($6)) {
   $scevgep$i$i$i$i = ((($5)) + -24|0);
   $7 = $scevgep$i$i$i$i;
   $8 = $2;
   $9 = (($7) - ($8))|0;
   $10 = (($9>>>0) / 24)&-1;
   $11 = $10 ^ -1;
   $scevgep5$i$i$i$i = (($5) + (($11*24)|0)|0);
   HEAP32[$4>>2] = $scevgep5$i$i$i$i;
  }
  __ZdlPv($2);
 }
 $12 = ((($0)) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  HEAP32[$12>>2] = 0;
  return;
 }
 $15 = ((($13)) + 8|0);
 $16 = HEAP32[$15>>2]|0;HEAP32[$15>>2] = (($16-1)|0);
 $17 = ($16|0)==(1);
 if (!($17)) {
  HEAP32[$12>>2] = 0;
  return;
 }
 __ZNK3osg10Referenced24signalObserversAndDeleteEbb($13,1,1);
 HEAP32[$12>>2] = 0;
 return;
}
function __ZN3osg24TemplatePrimitiveFunctorIN27LineSegmentIntersectorUtils16IntersectFunctorINS_5Vec3fEfEEED0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $scevgep$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 36|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = ((($0)) + 40|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==($2|0);
  if (!($6)) {
   $scevgep$i$i$i$i$i = ((($5)) + -24|0);
   $7 = $scevgep$i$i$i$i$i;
   $8 = $2;
   $9 = (($7) - ($8))|0;
   $10 = (($9>>>0) / 24)&-1;
   $11 = $10 ^ -1;
   $scevgep5$i$i$i$i$i = (($5) + (($11*24)|0)|0);
   HEAP32[$4>>2] = $scevgep5$i$i$i$i$i;
  }
  __ZdlPv($2);
 }
 $12 = ((($0)) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  __ZdlPv($0);
  return;
 }
 $15 = ((($13)) + 8|0);
 $16 = HEAP32[$15>>2]|0;HEAP32[$15>>2] = (($16-1)|0);
 $17 = ($16|0)==(1);
 if (!($17)) {
  __ZdlPv($0);
  return;
 }
 __THREW__ = 0;
 invoke_viii(3262,($13|0),1,1);
 $18 = __THREW__; __THREW__ = 0;
 $19 = $18&1;
 if ($19) {
  $20 = ___cxa_find_matching_catch_2()|0;
  $21 = tempRet0;
  __ZdlPv($0);
  ___resumeException($20|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZN3osg24TemplatePrimitiveFunctorIN27LineSegmentIntersectorUtils16IntersectFunctorINS_5Vec3fEfEEE14setVertexArrayEjPKNS_5Vec2fE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
 $5 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($4,115521,53)|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($6)) + -12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($5) + ($8)|0);
 __ZNKSt3__28ios_base6getlocEv($3,$9);
 __THREW__ = 0;
 $10 = (invoke_iii(3255,($3|0),(215188|0))|0);
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if (!($12)) {
  $13 = HEAP32[$10>>2]|0;
  $14 = ((($13)) + 28|0);
  $15 = HEAP32[$14>>2]|0;
  __THREW__ = 0;
  $16 = (invoke_iii($15|0,($10|0),10)|0);
  $17 = __THREW__; __THREW__ = 0;
  $18 = $17&1;
  if (!($18)) {
   __ZNSt3__26localeD2Ev($3);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($5,$16)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($5)|0);
   STACKTOP = sp;return;
  }
 }
 $19 = ___cxa_find_matching_catch_2()|0;
 $20 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($3|0));
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if ($22) {
  $23 = ___cxa_find_matching_catch_3(0|0)|0;
  $24 = tempRet0;
  ___clang_call_terminate($23);
  // unreachable;
 } else {
  ___resumeException($19|0);
  // unreachable;
 }
}
function __ZN3osg24TemplatePrimitiveFunctorIN27LineSegmentIntersectorUtils16IntersectFunctorINS_5Vec3fEfEEE14setVertexArrayEjPKS3_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 108|0);
 HEAP32[$3>>2] = $1;
 $4 = ((($0)) + 112|0);
 HEAP32[$4>>2] = $2;
 return;
}
function __ZN3osg24TemplatePrimitiveFunctorIN27LineSegmentIntersectorUtils16IntersectFunctorINS_5Vec3fEfEEE14setVertexArrayEjPKNS_5Vec4fE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
 $5 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($4,115467,53)|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($6)) + -12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($5) + ($8)|0);
 __ZNKSt3__28ios_base6getlocEv($3,$9);
 __THREW__ = 0;
 $10 = (invoke_iii(3255,($3|0),(215188|0))|0);
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if (!($12)) {
  $13 = HEAP32[$10>>2]|0;
  $14 = ((($13)) + 28|0);
  $15 = HEAP32[$14>>2]|0;
  __THREW__ = 0;
  $16 = (invoke_iii($15|0,($10|0),10)|0);
  $17 = __THREW__; __THREW__ = 0;
  $18 = $17&1;
  if (!($18)) {
   __ZNSt3__26localeD2Ev($3);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($5,$16)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($5)|0);
   STACKTOP = sp;return;
  }
 }
 $19 = ___cxa_find_matching_catch_2()|0;
 $20 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($3|0));
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if ($22) {
  $23 = ___cxa_find_matching_catch_3(0|0)|0;
  $24 = tempRet0;
  ___clang_call_terminate($23);
  // unreachable;
 } else {
  ___resumeException($19|0);
  // unreachable;
 }
}
function __ZN3osg24TemplatePrimitiveFunctorIN27LineSegmentIntersectorUtils16IntersectFunctorINS_5Vec3fEfEEE14setVertexArrayEjPKNS_5Vec2dE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
 $5 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($4,115412,54)|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($6)) + -12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($5) + ($8)|0);
 __ZNKSt3__28ios_base6getlocEv($3,$9);
 __THREW__ = 0;
 $10 = (invoke_iii(3255,($3|0),(215188|0))|0);
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if (!($12)) {
  $13 = HEAP32[$10>>2]|0;
  $14 = ((($13)) + 28|0);
  $15 = HEAP32[$14>>2]|0;
  __THREW__ = 0;
  $16 = (invoke_iii($15|0,($10|0),10)|0);
  $17 = __THREW__; __THREW__ = 0;
  $18 = $17&1;
  if (!($18)) {
   __ZNSt3__26localeD2Ev($3);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($5,$16)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($5)|0);
   STACKTOP = sp;return;
  }
 }
 $19 = ___cxa_find_matching_catch_2()|0;
 $20 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($3|0));
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if ($22) {
  $23 = ___cxa_find_matching_catch_3(0|0)|0;
  $24 = tempRet0;
  ___clang_call_terminate($23);
  // unreachable;
 } else {
  ___resumeException($19|0);
  // unreachable;
 }
}
function __ZN3osg24TemplatePrimitiveFunctorIN27LineSegmentIntersectorUtils16IntersectFunctorINS_5Vec3fEfEEE14setVertexArrayEjPKNS_5Vec3dE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
 $5 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($4,115357,54)|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($6)) + -12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($5) + ($8)|0);
 __ZNKSt3__28ios_base6getlocEv($3,$9);
 __THREW__ = 0;
 $10 = (invoke_iii(3255,($3|0),(215188|0))|0);
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if (!($12)) {
  $13 = HEAP32[$10>>2]|0;
  $14 = ((($13)) + 28|0);
  $15 = HEAP32[$14>>2]|0;
  __THREW__ = 0;
  $16 = (invoke_iii($15|0,($10|0),10)|0);
  $17 = __THREW__; __THREW__ = 0;
  $18 = $17&1;
  if (!($18)) {
   __ZNSt3__26localeD2Ev($3);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($5,$16)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($5)|0);
   STACKTOP = sp;return;
  }
 }
 $19 = ___cxa_find_matching_catch_2()|0;
 $20 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($3|0));
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if ($22) {
  $23 = ___cxa_find_matching_catch_3(0|0)|0;
  $24 = tempRet0;
  ___clang_call_terminate($23);
  // unreachable;
 } else {
  ___resumeException($19|0);
  // unreachable;
 }
}
function __ZN3osg24TemplatePrimitiveFunctorIN27LineSegmentIntersectorUtils16IntersectFunctorINS_5Vec3fEfEEE14setVertexArrayEjPKNS_5Vec4dE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
 $5 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($4,115302,54)|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($6)) + -12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($5) + ($8)|0);
 __ZNKSt3__28ios_base6getlocEv($3,$9);
 __THREW__ = 0;
 $10 = (invoke_iii(3255,($3|0),(215188|0))|0);
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if (!($12)) {
  $13 = HEAP32[$10>>2]|0;
  $14 = ((($13)) + 28|0);
  $15 = HEAP32[$14>>2]|0;
  __THREW__ = 0;
  $16 = (invoke_iii($15|0,($10|0),10)|0);
  $17 = __THREW__; __THREW__ = 0;
  $18 = $17&1;
  if (!($18)) {
   __ZNSt3__26localeD2Ev($3);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($5,$16)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($5)|0);
   STACKTOP = sp;return;
  }
 }
 $19 = ___cxa_find_matching_catch_2()|0;
 $20 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($3|0));
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if ($22) {
  $23 = ___cxa_find_matching_catch_3(0|0)|0;
  $24 = tempRet0;
  ___clang_call_terminate($23);
  // unreachable;
 } else {
  ___resumeException($19|0);
  // unreachable;
 }
}
function __ZN3osg24TemplatePrimitiveFunctorIN27LineSegmentIntersectorUtils16IntersectFunctorINS_5Vec3fEfEEE10drawArraysEjii($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0131154 = 0, $$0133156 = 0, $$0135155 = 0, $$0137159 = 0, $$0139158 = 0, $$0140165 = 0, $$0141164 = 0, $$0142162 = 0, $$0143161 = 0, $$pre$phiZ2D = 0, $$promoted = 0, $$promoted171 = 0, $$promoted175 = 0, $$promoted179 = 0, $$promoted183 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0;
 var $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0;
 var $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0;
 var $exitcond193 = 0, $or$cond = 0, $scevgep = 0, $scevgep194 = 0, $scevgep197 = 0, $scevgep199 = 0, $scevgep203 = 0, $scevgep205 = 0, $scevgep209 = 0, $scevgep211 = 0, $scevgep215 = 0, $scevgep217 = 0, $uglygep = 0, $uglygep196 = 0, $uglygep201 = 0, $uglygep201202 = 0, $uglygep207 = 0, $uglygep207208 = 0, $uglygep213 = 0, $uglygep213214 = 0;
 var $uglygep219 = 0, $uglygep219220 = 0, $umax = 0, $umax198 = 0, $umax204 = 0, $umax210 = 0, $umax216 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ((($0)) + 112|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5;
 $7 = ($5|0)==(0|0);
 $8 = ($3|0)==(0);
 $or$cond = $8 | $7;
 if ($or$cond) {
  return;
 }
 do {
  switch ($1|0) {
  case 4:  {
   $9 = (($3) + ($2))|0;
   $10 = (($5) + (($9*12)|0)|0);
   $11 = ($3|0)>(0);
   if (!($11)) {
    return;
   }
   $12 = (($5) + (($2*12)|0)|0);
   $13 = ((($0)) + 4|0);
   $14 = ((($0)) + 8|0);
   $$0131154 = $12;
   while(1) {
    $15 = ((($$0131154)) + 12|0);
    $16 = ((($$0131154)) + 24|0);
    __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3fEfE9intersectERKS2_S5_S5_($13,$$0131154,$15,$16);
    $17 = HEAP32[$14>>2]|0;
    $18 = (($17) + 1)|0;
    HEAP32[$14>>2] = $18;
    $19 = ((($$0131154)) + 36|0);
    $20 = ($19>>>0)<($10>>>0);
    if ($20) {
     $$0131154 = $19;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 5:  {
   $21 = ($3|0)>(2);
   if (!($21)) {
    return;
   }
   $22 = (($5) + (($2*12)|0)|0);
   $23 = ((($0)) + 4|0);
   $24 = ((($0)) + 8|0);
   $$0133156 = $22;$$0135155 = 2;
   while(1) {
    $25 = $$0135155 & 1;
    $26 = ($25|0)==(0);
    if ($26) {
     $29 = ((($$0133156)) + 12|0);
     $30 = ((($$0133156)) + 24|0);
     __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3fEfE9intersectERKS2_S5_S5_($23,$$0133156,$29,$30);
     $$pre$phiZ2D = $29;
    } else {
     $27 = ((($$0133156)) + 24|0);
     $28 = ((($$0133156)) + 12|0);
     __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3fEfE9intersectERKS2_S5_S5_($23,$$0133156,$27,$28);
     $$pre$phiZ2D = $28;
    }
    $31 = HEAP32[$24>>2]|0;
    $32 = (($31) + 1)|0;
    HEAP32[$24>>2] = $32;
    $33 = (($$0135155) + 1)|0;
    $exitcond = ($33|0)==($3|0);
    if ($exitcond) {
     break;
    } else {
     $$0133156 = $$pre$phiZ2D;$$0135155 = $33;
    }
   }
   return;
   break;
  }
  case 7:  {
   $34 = ($3|0)>(3);
   if (!($34)) {
    return;
   }
   $35 = (($5) + (($2*12)|0)|0);
   $36 = ((($0)) + 4|0);
   $37 = ((($0)) + 8|0);
   $$0137159 = $35;$$0139158 = 3;
   while(1) {
    $38 = ((($$0137159)) + 12|0);
    $39 = ((($$0137159)) + 24|0);
    $40 = ((($$0137159)) + 36|0);
    __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3fEfE9intersectERKS2_S5_S5_($36,$$0137159,$38,$40);
    __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3fEfE9intersectERKS2_S5_S5_($36,$38,$39,$40);
    $41 = HEAP32[$37>>2]|0;
    $42 = (($41) + 1)|0;
    HEAP32[$37>>2] = $42;
    $43 = (($$0139158) + 4)|0;
    $44 = ((($$0137159)) + 48|0);
    $45 = ($43|0)<($3|0);
    if ($45) {
     $$0137159 = $44;$$0139158 = $43;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 8:  {
   $46 = ($3|0)>(3);
   if (!($46)) {
    return;
   }
   $47 = (($5) + (($2*12)|0)|0);
   $48 = ((($0)) + 4|0);
   $49 = ((($0)) + 8|0);
   $$0142162 = $47;$$0143161 = 3;
   while(1) {
    $50 = ((($$0142162)) + 12|0);
    $51 = ((($$0142162)) + 36|0);
    $52 = ((($$0142162)) + 24|0);
    __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3fEfE9intersectERKS2_S5_S5_($48,$$0142162,$50,$52);
    __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3fEfE9intersectERKS2_S5_S5_($48,$50,$51,$52);
    $53 = HEAP32[$49>>2]|0;
    $54 = (($53) + 1)|0;
    HEAP32[$49>>2] = $54;
    $55 = (($$0143161) + 2)|0;
    $56 = ($55|0)<($3|0);
    if ($56) {
     $$0142162 = $52;$$0143161 = $55;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 6: case 9:  {
   $57 = (($5) + (($2*12)|0)|0);
   $58 = ($3|0)>(2);
   if (!($58)) {
    return;
   }
   $59 = ((($57)) + 12|0);
   $60 = ((($0)) + 4|0);
   $61 = ((($0)) + 8|0);
   $$0140165 = 2;$$0141164 = $59;
   while(1) {
    $62 = ((($$0141164)) + 12|0);
    __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3fEfE9intersectERKS2_S5_S5_($60,$57,$$0141164,$62);
    $63 = HEAP32[$61>>2]|0;
    $64 = (($63) + 1)|0;
    HEAP32[$61>>2] = $64;
    $65 = (($$0140165) + 1)|0;
    $exitcond193 = ($65|0)==($3|0);
    if ($exitcond193) {
     break;
    } else {
     $$0140165 = $65;$$0141164 = $62;
    }
   }
   return;
   break;
  }
  case 0:  {
   $66 = (($3) + ($2))|0;
   $67 = (($5) + (($66*12)|0)|0);
   $68 = ($3|0)>(0);
   if (!($68)) {
    return;
   }
   $69 = ((($0)) + 8|0);
   $$promoted = HEAP32[$69>>2]|0;
   $70 = (($2) + 1)|0;
   $scevgep = (($5) + (($70*12)|0)|0);
   $71 = ($scevgep>>>0)>($67>>>0);
   $umax = $71 ? $scevgep : $67;
   $72 = (0 - ($2))|0;
   $scevgep194 = (($umax) + (($72*12)|0)|0);
   $73 = $6 ^ -1;
   $uglygep = (($scevgep194) + ($73)|0);
   $uglygep196 = $uglygep;
   $74 = (($uglygep196>>>0) / 12)&-1;
   $75 = (($$promoted) + ($74))|0;
   $76 = (($75) + 1)|0;
   HEAP32[$69>>2] = $76;
   return;
   break;
  }
  case 1:  {
   $77 = (($2) + -1)|0;
   $78 = (($77) + ($3))|0;
   $79 = (($5) + (($78*12)|0)|0);
   $80 = ($78|0)>($2|0);
   if (!($80)) {
    return;
   }
   $81 = ((($0)) + 8|0);
   $$promoted171 = HEAP32[$81>>2]|0;
   $82 = (($2) + 2)|0;
   $scevgep197 = (($5) + (($82*12)|0)|0);
   $83 = ($79>>>0)>($scevgep197>>>0);
   $umax198 = $83 ? $79 : $scevgep197;
   $84 = (0 - ($2))|0;
   $scevgep199 = (($umax198) + (($84*12)|0)|0);
   $85 = $6 ^ -1;
   $uglygep201 = (($scevgep199) + ($85)|0);
   $uglygep201202 = $uglygep201;
   $86 = (($uglygep201202>>>0) / 24)&-1;
   $87 = (($$promoted171) + ($86))|0;
   $88 = (($87) + 1)|0;
   HEAP32[$81>>2] = $88;
   return;
   break;
  }
  case 3:  {
   $89 = (($2) + -1)|0;
   $90 = (($89) + ($3))|0;
   $91 = (($5) + (($90*12)|0)|0);
   $92 = ($90|0)>($2|0);
   if (!($92)) {
    return;
   }
   $93 = ((($0)) + 8|0);
   $$promoted175 = HEAP32[$93>>2]|0;
   $94 = (($2) + 1)|0;
   $scevgep203 = (($5) + (($94*12)|0)|0);
   $95 = ($91>>>0)>($scevgep203>>>0);
   $umax204 = $95 ? $91 : $scevgep203;
   $96 = (0 - ($2))|0;
   $scevgep205 = (($umax204) + (($96*12)|0)|0);
   $97 = $6 ^ -1;
   $uglygep207 = (($scevgep205) + ($97)|0);
   $uglygep207208 = $uglygep207;
   $98 = (($uglygep207208>>>0) / 12)&-1;
   $99 = (($$promoted175) + ($98))|0;
   $100 = (($99) + 1)|0;
   HEAP32[$93>>2] = $100;
   return;
   break;
  }
  case 11:  {
   $101 = (($2) + -2)|0;
   $102 = (($101) + ($3))|0;
   $103 = (($5) + (($102*12)|0)|0);
   $104 = (($2) + 1)|0;
   $105 = ($104|0)<($102|0);
   if (!($105)) {
    return;
   }
   $106 = ((($0)) + 8|0);
   $$promoted179 = HEAP32[$106>>2]|0;
   $107 = (($2) + 2)|0;
   $scevgep209 = (($5) + (($107*12)|0)|0);
   $108 = ($103>>>0)>($scevgep209>>>0);
   $umax210 = $108 ? $103 : $scevgep209;
   $109 = $2 ^ -1;
   $scevgep211 = (($umax210) + (($109*12)|0)|0);
   $110 = $6 ^ -1;
   $uglygep213 = (($scevgep211) + ($110)|0);
   $uglygep213214 = $uglygep213;
   $111 = (($uglygep213214>>>0) / 12)&-1;
   $112 = (($$promoted179) + ($111))|0;
   $113 = (($112) + 1)|0;
   HEAP32[$106>>2] = $113;
   return;
   break;
  }
  case 2:  {
   $114 = (($2) + -1)|0;
   $115 = (($114) + ($3))|0;
   $116 = (($5) + (($115*12)|0)|0);
   $117 = ($115|0)>($2|0);
   $118 = ((($0)) + 8|0);
   $$promoted183 = HEAP32[$118>>2]|0;
   if ($117) {
    $119 = (($2) + 1)|0;
    $scevgep215 = (($5) + (($119*12)|0)|0);
    $120 = ($116>>>0)>($scevgep215>>>0);
    $umax216 = $120 ? $116 : $scevgep215;
    $121 = (0 - ($2))|0;
    $scevgep217 = (($umax216) + (($121*12)|0)|0);
    $122 = $6 ^ -1;
    $uglygep219 = (($scevgep217) + ($122)|0);
    $uglygep219220 = $uglygep219;
    $123 = (($uglygep219220>>>0) / 12)&-1;
    $124 = (($$promoted183) + ($123))|0;
    $125 = (($124) + 1)|0;
    HEAP32[$118>>2] = $125;
    $127 = $125;
   } else {
    $127 = $$promoted183;
   }
   $126 = (($127) + 1)|0;
   HEAP32[$118>>2] = $126;
   return;
   break;
  }
  default: {
   return;
  }
  }
 } while(0);
}
function __ZN3osg24TemplatePrimitiveFunctorIN27LineSegmentIntersectorUtils16IntersectFunctorINS_5Vec3fEfEEE12drawElementsEjiPKh($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg24TemplatePrimitiveFunctorIN27LineSegmentIntersectorUtils16IntersectFunctorINS_5Vec3fEfEEE20drawElementsTemplateIhEEvjiPKT_($0,$1,$2,$3);
 return;
}
function __ZN3osg24TemplatePrimitiveFunctorIN27LineSegmentIntersectorUtils16IntersectFunctorINS_5Vec3fEfEEE12drawElementsEjiPKt($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg24TemplatePrimitiveFunctorIN27LineSegmentIntersectorUtils16IntersectFunctorINS_5Vec3fEfEEE20drawElementsTemplateItEEvjiPKT_($0,$1,$2,$3);
 return;
}
function __ZN3osg24TemplatePrimitiveFunctorIN27LineSegmentIntersectorUtils16IntersectFunctorINS_5Vec3fEfEEE12drawElementsEjiPKj($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg24TemplatePrimitiveFunctorIN27LineSegmentIntersectorUtils16IntersectFunctorINS_5Vec3fEfEEE20drawElementsTemplateIjEEvjiPKT_($0,$1,$2,$3);
 return;
}
function __ZN3osg24TemplatePrimitiveFunctorIN27LineSegmentIntersectorUtils16IntersectFunctorINS_5Vec3fEfEEE20drawElementsTemplateIjEEvjiPKT_($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0133158 = 0, $$0135160 = 0, $$0137159 = 0, $$0139163 = 0, $$0141162 = 0, $$0143166 = 0, $$0145165 = 0, $$pre223 = 0, $$promoted = 0, $$promoted175 = 0, $$promoted179 = 0, $$promoted184 = 0, $$promoted188 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $exitcond198 = 0, $exitcond198232 = 0, $or$cond = 0, $scevgep = 0, $scevgep201 = 0, $scevgep206 = 0, $scevgep211 = 0, $scevgep213 = 0, $scevgep217 = 0, $uglygep = 0, $uglygep200 = 0, $uglygep204 = 0, $uglygep204205 = 0;
 var $uglygep209 = 0, $uglygep209210 = 0, $uglygep215 = 0, $uglygep215216 = 0, $uglygep220 = 0, $uglygep220221 = 0, $umax = 0, $umax202 = 0, $umax207 = 0, $umax212 = 0, $umax218 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = $3;
 $5 = ($3|0)==(0|0);
 $6 = ($2|0)==(0);
 $or$cond = $6 | $5;
 if ($or$cond) {
  return;
 }
 do {
  switch ($1|0) {
  case 4:  {
   $19 = (($3) + ($2<<2)|0);
   $20 = ($2|0)>(0);
   if (!($20)) {
    return;
   }
   $21 = ((($0)) + 4|0);
   $22 = ((($0)) + 112|0);
   $23 = ((($0)) + 8|0);
   $$0133158 = $3;
   while(1) {
    $24 = HEAP32[$22>>2]|0;
    $25 = HEAP32[$$0133158>>2]|0;
    $26 = (($24) + (($25*12)|0)|0);
    $27 = ((($$0133158)) + 4|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = (($24) + (($28*12)|0)|0);
    $30 = ((($$0133158)) + 8|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = (($24) + (($31*12)|0)|0);
    __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3fEfE9intersectERKS2_S5_S5_($21,$26,$29,$32);
    $33 = HEAP32[$23>>2]|0;
    $34 = (($33) + 1)|0;
    HEAP32[$23>>2] = $34;
    $35 = ((($$0133158)) + 12|0);
    $36 = ($35>>>0)<($19>>>0);
    if ($36) {
     $$0133158 = $35;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 5:  {
   $15 = ($2|0)>(2);
   if (!($15)) {
    return;
   }
   $16 = ((($0)) + 4|0);
   $17 = ((($0)) + 112|0);
   $18 = ((($0)) + 8|0);
   $$0135160 = $3;$$0137159 = 2;
   while(1) {
    $37 = $$0137159 & 1;
    $38 = ($37|0)==(0);
    $39 = HEAP32[$17>>2]|0;
    $40 = HEAP32[$$0135160>>2]|0;
    $41 = (($39) + (($40*12)|0)|0);
    $42 = ((($$0135160)) + 4|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = ((($$0135160)) + 8|0);
    $45 = HEAP32[$44>>2]|0;
    if ($38) {
     $48 = (($39) + (($43*12)|0)|0);
     $49 = (($39) + (($45*12)|0)|0);
     __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3fEfE9intersectERKS2_S5_S5_($16,$41,$48,$49);
    } else {
     $46 = (($39) + (($45*12)|0)|0);
     $47 = (($39) + (($43*12)|0)|0);
     __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3fEfE9intersectERKS2_S5_S5_($16,$41,$46,$47);
    }
    $50 = HEAP32[$18>>2]|0;
    $51 = (($50) + 1)|0;
    HEAP32[$18>>2] = $51;
    $52 = (($$0137159) + 1)|0;
    $exitcond = ($52|0)==($2|0);
    if ($exitcond) {
     break;
    } else {
     $$0135160 = $42;$$0137159 = $52;
    }
   }
   return;
   break;
  }
  case 7:  {
   $11 = ($2|0)>(3);
   if (!($11)) {
    return;
   }
   $12 = ((($0)) + 4|0);
   $13 = ((($0)) + 112|0);
   $14 = ((($0)) + 8|0);
   $$0139163 = $3;$$0141162 = 3;
   while(1) {
    $53 = HEAP32[$13>>2]|0;
    $54 = HEAP32[$$0139163>>2]|0;
    $55 = (($53) + (($54*12)|0)|0);
    $56 = ((($$0139163)) + 4|0);
    $57 = HEAP32[$56>>2]|0;
    $58 = (($53) + (($57*12)|0)|0);
    $59 = ((($$0139163)) + 8|0);
    $60 = HEAP32[$59>>2]|0;
    $61 = (($53) + (($60*12)|0)|0);
    $62 = ((($$0139163)) + 12|0);
    $63 = HEAP32[$62>>2]|0;
    $64 = (($53) + (($63*12)|0)|0);
    __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3fEfE9intersectERKS2_S5_S5_($12,$55,$58,$64);
    __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3fEfE9intersectERKS2_S5_S5_($12,$58,$61,$64);
    $65 = HEAP32[$14>>2]|0;
    $66 = (($65) + 1)|0;
    HEAP32[$14>>2] = $66;
    $67 = (($$0141162) + 4)|0;
    $68 = ((($$0139163)) + 16|0);
    $69 = ($67|0)<($2|0);
    if ($69) {
     $$0139163 = $68;$$0141162 = $67;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 8:  {
   $7 = ($2|0)>(3);
   if (!($7)) {
    return;
   }
   $8 = ((($0)) + 4|0);
   $9 = ((($0)) + 112|0);
   $10 = ((($0)) + 8|0);
   $$0143166 = $3;$$0145165 = 3;
   while(1) {
    $70 = HEAP32[$9>>2]|0;
    $71 = HEAP32[$$0143166>>2]|0;
    $72 = (($70) + (($71*12)|0)|0);
    $73 = ((($$0143166)) + 4|0);
    $74 = HEAP32[$73>>2]|0;
    $75 = (($70) + (($74*12)|0)|0);
    $76 = ((($$0143166)) + 12|0);
    $77 = HEAP32[$76>>2]|0;
    $78 = (($70) + (($77*12)|0)|0);
    $79 = ((($$0143166)) + 8|0);
    $80 = HEAP32[$79>>2]|0;
    $81 = (($70) + (($80*12)|0)|0);
    __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3fEfE9intersectERKS2_S5_S5_($8,$72,$75,$81);
    __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3fEfE9intersectERKS2_S5_S5_($8,$75,$78,$81);
    $82 = HEAP32[$10>>2]|0;
    $83 = (($82) + 1)|0;
    HEAP32[$10>>2] = $83;
    $84 = (($$0145165) + 2)|0;
    $85 = ($84|0)<($2|0);
    if ($85) {
     $$0143166 = $79;$$0145165 = $84;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 6: case 9:  {
   $86 = ((($0)) + 112|0);
   $87 = HEAP32[$86>>2]|0;
   $88 = HEAP32[$3>>2]|0;
   $89 = (($87) + (($88*12)|0)|0);
   $90 = ($2|0)>(2);
   if (!($90)) {
    return;
   }
   $91 = ((($3)) + 4|0);
   $92 = ((($0)) + 4|0);
   $93 = ((($0)) + 8|0);
   $94 = HEAP32[$91>>2]|0;
   $95 = (($87) + (($94*12)|0)|0);
   $96 = ((($3)) + 8|0);
   $97 = HEAP32[$96>>2]|0;
   $98 = (($87) + (($97*12)|0)|0);
   __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3fEfE9intersectERKS2_S5_S5_($92,$89,$95,$98);
   $99 = HEAP32[$93>>2]|0;
   $100 = (($99) + 1)|0;
   HEAP32[$93>>2] = $100;
   $exitcond198232 = ($2|0)==(3);
   if ($exitcond198232) {
    return;
   } else {
    $102 = $96;$110 = 3;
   }
   while(1) {
    $$pre223 = HEAP32[$86>>2]|0;
    $101 = HEAP32[$102>>2]|0;
    $103 = (($$pre223) + (($101*12)|0)|0);
    $104 = ((($102)) + 4|0);
    $105 = HEAP32[$104>>2]|0;
    $106 = (($$pre223) + (($105*12)|0)|0);
    __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3fEfE9intersectERKS2_S5_S5_($92,$89,$103,$106);
    $107 = HEAP32[$93>>2]|0;
    $108 = (($107) + 1)|0;
    HEAP32[$93>>2] = $108;
    $109 = (($110) + 1)|0;
    $exitcond198 = ($109|0)==($2|0);
    if ($exitcond198) {
     break;
    } else {
     $102 = $104;$110 = $109;
    }
   }
   return;
   break;
  }
  case 0:  {
   $111 = (($3) + ($2<<2)|0);
   $112 = ($2|0)>(0);
   if (!($112)) {
    return;
   }
   $113 = ((($0)) + 8|0);
   $$promoted = HEAP32[$113>>2]|0;
   $scevgep = ((($3)) + 4|0);
   $114 = ($111>>>0)>($scevgep>>>0);
   $umax = $114 ? $111 : $scevgep;
   $115 = $4 ^ -1;
   $uglygep = (($umax) + ($115)|0);
   $uglygep200 = $uglygep;
   $116 = $uglygep200 >>> 2;
   $117 = (($$promoted) + ($116))|0;
   $118 = (($117) + 1)|0;
   HEAP32[$113>>2] = $118;
   return;
   break;
  }
  case 1:  {
   $119 = (($2) + -1)|0;
   $120 = (($3) + ($119<<2)|0);
   $121 = ($2|0)>(1);
   if (!($121)) {
    return;
   }
   $122 = ((($0)) + 8|0);
   $$promoted175 = HEAP32[$122>>2]|0;
   $scevgep201 = ((($3)) + 8|0);
   $123 = ($120>>>0)>($scevgep201>>>0);
   $umax202 = $123 ? $120 : $scevgep201;
   $124 = $4 ^ -1;
   $uglygep204 = (($umax202) + ($124)|0);
   $uglygep204205 = $uglygep204;
   $125 = $uglygep204205 >>> 3;
   $126 = (($$promoted175) + ($125))|0;
   $127 = (($126) + 1)|0;
   HEAP32[$122>>2] = $127;
   return;
   break;
  }
  case 3:  {
   $128 = (($2) + -1)|0;
   $129 = (($3) + ($128<<2)|0);
   $130 = ($2|0)>(1);
   if (!($130)) {
    return;
   }
   $131 = ((($0)) + 8|0);
   $$promoted179 = HEAP32[$131>>2]|0;
   $scevgep206 = ((($3)) + 4|0);
   $132 = ($129>>>0)>($scevgep206>>>0);
   $umax207 = $132 ? $129 : $scevgep206;
   $133 = $4 ^ -1;
   $uglygep209 = (($umax207) + ($133)|0);
   $uglygep209210 = $uglygep209;
   $134 = $uglygep209210 >>> 2;
   $135 = (($$promoted179) + ($134))|0;
   $136 = (($135) + 1)|0;
   HEAP32[$131>>2] = $136;
   return;
   break;
  }
  case 11:  {
   $137 = (($2) + -2)|0;
   $138 = (($3) + ($137<<2)|0);
   $139 = ($137|0)>(1);
   if (!($139)) {
    return;
   }
   $140 = ((($0)) + 8|0);
   $$promoted184 = HEAP32[$140>>2]|0;
   $scevgep211 = ((($3)) + 8|0);
   $141 = ($138>>>0)>($scevgep211>>>0);
   $umax212 = $141 ? $138 : $scevgep211;
   $scevgep213 = ((($umax212)) + -4|0);
   $142 = $4 ^ -1;
   $uglygep215 = (($scevgep213) + ($142)|0);
   $uglygep215216 = $uglygep215;
   $143 = $uglygep215216 >>> 2;
   $144 = (($$promoted184) + ($143))|0;
   $145 = (($144) + 1)|0;
   HEAP32[$140>>2] = $145;
   return;
   break;
  }
  case 2:  {
   $146 = (($2) + -1)|0;
   $147 = (($3) + ($146<<2)|0);
   $148 = ($2|0)>(1);
   $149 = ((($0)) + 8|0);
   $$promoted188 = HEAP32[$149>>2]|0;
   if ($148) {
    $scevgep217 = ((($3)) + 4|0);
    $150 = ($147>>>0)>($scevgep217>>>0);
    $umax218 = $150 ? $147 : $scevgep217;
    $151 = $4 ^ -1;
    $uglygep220 = (($umax218) + ($151)|0);
    $uglygep220221 = $uglygep220;
    $152 = $uglygep220221 >>> 2;
    $153 = (($$promoted188) + ($152))|0;
    $154 = (($153) + 1)|0;
    HEAP32[$149>>2] = $154;
    $156 = $154;
   } else {
    $156 = $$promoted188;
   }
   $155 = (($156) + 1)|0;
   HEAP32[$149>>2] = $155;
   return;
   break;
  }
  default: {
   return;
  }
  }
 } while(0);
}
function __ZN3osg24TemplatePrimitiveFunctorIN27LineSegmentIntersectorUtils16IntersectFunctorINS_5Vec3fEfEEE20drawElementsTemplateItEEvjiPKT_($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0133158 = 0, $$0135160 = 0, $$0137159 = 0, $$0139163 = 0, $$0141162 = 0, $$0142169 = 0, $$0143166 = 0, $$0144168 = 0, $$0145165 = 0, $$pre223 = 0, $$promoted = 0, $$promoted175 = 0, $$promoted179 = 0, $$promoted184 = 0, $$promoted188 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0;
 var $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0;
 var $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0;
 var $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0;
 var $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $exitcond198 = 0, $or$cond = 0;
 var $scevgep = 0, $scevgep201 = 0, $scevgep206 = 0, $scevgep211 = 0, $scevgep213 = 0, $scevgep217 = 0, $uglygep = 0, $uglygep200 = 0, $uglygep204 = 0, $uglygep204205 = 0, $uglygep209 = 0, $uglygep209210 = 0, $uglygep215 = 0, $uglygep215216 = 0, $uglygep220 = 0, $uglygep220221 = 0, $umax = 0, $umax202 = 0, $umax207 = 0, $umax212 = 0;
 var $umax218 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = $3;
 $5 = ($3|0)==(0|0);
 $6 = ($2|0)==(0);
 $or$cond = $6 | $5;
 if ($or$cond) {
  return;
 }
 do {
  switch ($1|0) {
  case 4:  {
   $19 = (($3) + ($2<<1)|0);
   $20 = ($2|0)>(0);
   if (!($20)) {
    return;
   }
   $21 = ((($0)) + 4|0);
   $22 = ((($0)) + 112|0);
   $23 = ((($0)) + 8|0);
   $$0133158 = $3;
   while(1) {
    $24 = HEAP32[$22>>2]|0;
    $25 = HEAP16[$$0133158>>1]|0;
    $26 = $25&65535;
    $27 = (($24) + (($26*12)|0)|0);
    $28 = ((($$0133158)) + 2|0);
    $29 = HEAP16[$28>>1]|0;
    $30 = $29&65535;
    $31 = (($24) + (($30*12)|0)|0);
    $32 = ((($$0133158)) + 4|0);
    $33 = HEAP16[$32>>1]|0;
    $34 = $33&65535;
    $35 = (($24) + (($34*12)|0)|0);
    __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3fEfE9intersectERKS2_S5_S5_($21,$27,$31,$35);
    $36 = HEAP32[$23>>2]|0;
    $37 = (($36) + 1)|0;
    HEAP32[$23>>2] = $37;
    $38 = ((($$0133158)) + 6|0);
    $39 = ($38>>>0)<($19>>>0);
    if ($39) {
     $$0133158 = $38;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 5:  {
   $15 = ($2|0)>(2);
   if (!($15)) {
    return;
   }
   $16 = ((($0)) + 4|0);
   $17 = ((($0)) + 112|0);
   $18 = ((($0)) + 8|0);
   $$0135160 = $3;$$0137159 = 2;
   while(1) {
    $40 = $$0137159 & 1;
    $41 = ($40|0)==(0);
    $42 = HEAP32[$17>>2]|0;
    $43 = HEAP16[$$0135160>>1]|0;
    $44 = $43&65535;
    $45 = (($42) + (($44*12)|0)|0);
    $46 = ((($$0135160)) + 2|0);
    $47 = HEAP16[$46>>1]|0;
    $48 = ((($$0135160)) + 4|0);
    $49 = HEAP16[$48>>1]|0;
    $50 = $47&65535;
    $51 = $49&65535;
    if ($41) {
     $54 = (($42) + (($50*12)|0)|0);
     $55 = (($42) + (($51*12)|0)|0);
     __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3fEfE9intersectERKS2_S5_S5_($16,$45,$54,$55);
    } else {
     $52 = (($42) + (($51*12)|0)|0);
     $53 = (($42) + (($50*12)|0)|0);
     __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3fEfE9intersectERKS2_S5_S5_($16,$45,$52,$53);
    }
    $56 = HEAP32[$18>>2]|0;
    $57 = (($56) + 1)|0;
    HEAP32[$18>>2] = $57;
    $58 = (($$0137159) + 1)|0;
    $exitcond = ($58|0)==($2|0);
    if ($exitcond) {
     break;
    } else {
     $$0135160 = $46;$$0137159 = $58;
    }
   }
   return;
   break;
  }
  case 7:  {
   $11 = ($2|0)>(3);
   if (!($11)) {
    return;
   }
   $12 = ((($0)) + 4|0);
   $13 = ((($0)) + 112|0);
   $14 = ((($0)) + 8|0);
   $$0139163 = $3;$$0141162 = 3;
   while(1) {
    $59 = HEAP32[$13>>2]|0;
    $60 = HEAP16[$$0139163>>1]|0;
    $61 = $60&65535;
    $62 = (($59) + (($61*12)|0)|0);
    $63 = ((($$0139163)) + 2|0);
    $64 = HEAP16[$63>>1]|0;
    $65 = $64&65535;
    $66 = (($59) + (($65*12)|0)|0);
    $67 = ((($$0139163)) + 4|0);
    $68 = HEAP16[$67>>1]|0;
    $69 = $68&65535;
    $70 = (($59) + (($69*12)|0)|0);
    $71 = ((($$0139163)) + 6|0);
    $72 = HEAP16[$71>>1]|0;
    $73 = $72&65535;
    $74 = (($59) + (($73*12)|0)|0);
    __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3fEfE9intersectERKS2_S5_S5_($12,$62,$66,$74);
    __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3fEfE9intersectERKS2_S5_S5_($12,$66,$70,$74);
    $75 = HEAP32[$14>>2]|0;
    $76 = (($75) + 1)|0;
    HEAP32[$14>>2] = $76;
    $77 = (($$0141162) + 4)|0;
    $78 = ((($$0139163)) + 8|0);
    $79 = ($77|0)<($2|0);
    if ($79) {
     $$0139163 = $78;$$0141162 = $77;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 8:  {
   $7 = ($2|0)>(3);
   if (!($7)) {
    return;
   }
   $8 = ((($0)) + 4|0);
   $9 = ((($0)) + 112|0);
   $10 = ((($0)) + 8|0);
   $$0143166 = $3;$$0145165 = 3;
   while(1) {
    $80 = HEAP32[$9>>2]|0;
    $81 = HEAP16[$$0143166>>1]|0;
    $82 = $81&65535;
    $83 = (($80) + (($82*12)|0)|0);
    $84 = ((($$0143166)) + 2|0);
    $85 = HEAP16[$84>>1]|0;
    $86 = $85&65535;
    $87 = (($80) + (($86*12)|0)|0);
    $88 = ((($$0143166)) + 6|0);
    $89 = HEAP16[$88>>1]|0;
    $90 = $89&65535;
    $91 = (($80) + (($90*12)|0)|0);
    $92 = ((($$0143166)) + 4|0);
    $93 = HEAP16[$92>>1]|0;
    $94 = $93&65535;
    $95 = (($80) + (($94*12)|0)|0);
    __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3fEfE9intersectERKS2_S5_S5_($8,$83,$87,$95);
    __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3fEfE9intersectERKS2_S5_S5_($8,$87,$91,$95);
    $96 = HEAP32[$10>>2]|0;
    $97 = (($96) + 1)|0;
    HEAP32[$10>>2] = $97;
    $98 = (($$0145165) + 2)|0;
    $99 = ($98|0)<($2|0);
    if ($99) {
     $$0143166 = $92;$$0145165 = $98;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 6: case 9:  {
   $100 = ((($0)) + 112|0);
   $101 = HEAP32[$100>>2]|0;
   $102 = HEAP16[$3>>1]|0;
   $103 = $102&65535;
   $104 = (($101) + (($103*12)|0)|0);
   $105 = ($2|0)>(2);
   if (!($105)) {
    return;
   }
   $106 = ((($3)) + 2|0);
   $107 = ((($0)) + 4|0);
   $108 = ((($0)) + 8|0);
   $$0142169 = 2;$$0144168 = $106;$112 = $101;
   while(1) {
    $109 = HEAP16[$$0144168>>1]|0;
    $110 = $109&65535;
    $111 = (($112) + (($110*12)|0)|0);
    $113 = ((($$0144168)) + 2|0);
    $114 = HEAP16[$113>>1]|0;
    $115 = $114&65535;
    $116 = (($112) + (($115*12)|0)|0);
    __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3fEfE9intersectERKS2_S5_S5_($107,$104,$111,$116);
    $117 = HEAP32[$108>>2]|0;
    $118 = (($117) + 1)|0;
    HEAP32[$108>>2] = $118;
    $119 = (($$0142169) + 1)|0;
    $exitcond198 = ($119|0)==($2|0);
    if ($exitcond198) {
     break;
    }
    $$pre223 = HEAP32[$100>>2]|0;
    $$0142169 = $119;$$0144168 = $113;$112 = $$pre223;
   }
   return;
   break;
  }
  case 0:  {
   $120 = (($3) + ($2<<1)|0);
   $121 = ($2|0)>(0);
   if (!($121)) {
    return;
   }
   $122 = ((($0)) + 8|0);
   $$promoted = HEAP32[$122>>2]|0;
   $scevgep = ((($3)) + 2|0);
   $123 = ($120>>>0)>($scevgep>>>0);
   $umax = $123 ? $120 : $scevgep;
   $124 = $4 ^ -1;
   $uglygep = (($umax) + ($124)|0);
   $uglygep200 = $uglygep;
   $125 = $uglygep200 >>> 1;
   $126 = (($$promoted) + ($125))|0;
   $127 = (($126) + 1)|0;
   HEAP32[$122>>2] = $127;
   return;
   break;
  }
  case 1:  {
   $128 = (($2) + -1)|0;
   $129 = (($3) + ($128<<1)|0);
   $130 = ($2|0)>(1);
   if (!($130)) {
    return;
   }
   $131 = ((($0)) + 8|0);
   $$promoted175 = HEAP32[$131>>2]|0;
   $scevgep201 = ((($3)) + 4|0);
   $132 = ($129>>>0)>($scevgep201>>>0);
   $umax202 = $132 ? $129 : $scevgep201;
   $133 = $4 ^ -1;
   $uglygep204 = (($umax202) + ($133)|0);
   $uglygep204205 = $uglygep204;
   $134 = $uglygep204205 >>> 2;
   $135 = (($$promoted175) + ($134))|0;
   $136 = (($135) + 1)|0;
   HEAP32[$131>>2] = $136;
   return;
   break;
  }
  case 3:  {
   $137 = (($2) + -1)|0;
   $138 = (($3) + ($137<<1)|0);
   $139 = ($2|0)>(1);
   if (!($139)) {
    return;
   }
   $140 = ((($0)) + 8|0);
   $$promoted179 = HEAP32[$140>>2]|0;
   $scevgep206 = ((($3)) + 2|0);
   $141 = ($138>>>0)>($scevgep206>>>0);
   $umax207 = $141 ? $138 : $scevgep206;
   $142 = $4 ^ -1;
   $uglygep209 = (($umax207) + ($142)|0);
   $uglygep209210 = $uglygep209;
   $143 = $uglygep209210 >>> 1;
   $144 = (($$promoted179) + ($143))|0;
   $145 = (($144) + 1)|0;
   HEAP32[$140>>2] = $145;
   return;
   break;
  }
  case 11:  {
   $146 = (($2) + -2)|0;
   $147 = (($3) + ($146<<1)|0);
   $148 = ($146|0)>(1);
   if (!($148)) {
    return;
   }
   $149 = ((($0)) + 8|0);
   $$promoted184 = HEAP32[$149>>2]|0;
   $scevgep211 = ((($3)) + 4|0);
   $150 = ($147>>>0)>($scevgep211>>>0);
   $umax212 = $150 ? $147 : $scevgep211;
   $scevgep213 = ((($umax212)) + -2|0);
   $151 = $4 ^ -1;
   $uglygep215 = (($scevgep213) + ($151)|0);
   $uglygep215216 = $uglygep215;
   $152 = $uglygep215216 >>> 1;
   $153 = (($$promoted184) + ($152))|0;
   $154 = (($153) + 1)|0;
   HEAP32[$149>>2] = $154;
   return;
   break;
  }
  case 2:  {
   $155 = (($2) + -1)|0;
   $156 = (($3) + ($155<<1)|0);
   $157 = ($2|0)>(1);
   $158 = ((($0)) + 8|0);
   $$promoted188 = HEAP32[$158>>2]|0;
   if ($157) {
    $scevgep217 = ((($3)) + 2|0);
    $159 = ($156>>>0)>($scevgep217>>>0);
    $umax218 = $159 ? $156 : $scevgep217;
    $160 = $4 ^ -1;
    $uglygep220 = (($umax218) + ($160)|0);
    $uglygep220221 = $uglygep220;
    $161 = $uglygep220221 >>> 1;
    $162 = (($$promoted188) + ($161))|0;
    $163 = (($162) + 1)|0;
    HEAP32[$158>>2] = $163;
    $165 = $163;
   } else {
    $165 = $$promoted188;
   }
   $164 = (($165) + 1)|0;
   HEAP32[$158>>2] = $164;
   return;
   break;
  }
  default: {
   return;
  }
  }
 } while(0);
}
function __ZN3osg24TemplatePrimitiveFunctorIN27LineSegmentIntersectorUtils16IntersectFunctorINS_5Vec3fEfEEE20drawElementsTemplateIhEEvjiPKT_($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0133158 = 0, $$0135160 = 0, $$0137159 = 0, $$0139163 = 0, $$0141162 = 0, $$0142169 = 0, $$0143166 = 0, $$0144168 = 0, $$0145165 = 0, $$pre218 = 0, $$promoted = 0, $$promoted175 = 0, $$promoted179 = 0, $$promoted184 = 0, $$promoted188 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0;
 var $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0;
 var $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0;
 var $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $exitcond198 = 0, $or$cond = 0, $scevgep = 0, $scevgep199 = 0, $scevgep199200 = 0, $scevgep201 = 0, $scevgep203 = 0, $scevgep203204 = 0, $scevgep205 = 0, $scevgep207 = 0, $scevgep207208 = 0, $scevgep209 = 0, $scevgep211 = 0;
 var $scevgep211212 = 0, $scevgep213 = 0, $scevgep215 = 0, $scevgep215216 = 0, $umax = 0, $umax202 = 0, $umax206 = 0, $umax210 = 0, $umax214 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = $3;
 $5 = ($3|0)==(0|0);
 $6 = ($2|0)==(0);
 $or$cond = $6 | $5;
 if ($or$cond) {
  return;
 }
 do {
  switch ($1|0) {
  case 4:  {
   $19 = (($3) + ($2)|0);
   $20 = ($2|0)>(0);
   if (!($20)) {
    return;
   }
   $21 = ((($0)) + 4|0);
   $22 = ((($0)) + 112|0);
   $23 = ((($0)) + 8|0);
   $$0133158 = $3;
   while(1) {
    $24 = HEAP32[$22>>2]|0;
    $25 = HEAP8[$$0133158>>0]|0;
    $26 = $25&255;
    $27 = (($24) + (($26*12)|0)|0);
    $28 = ((($$0133158)) + 1|0);
    $29 = HEAP8[$28>>0]|0;
    $30 = $29&255;
    $31 = (($24) + (($30*12)|0)|0);
    $32 = ((($$0133158)) + 2|0);
    $33 = HEAP8[$32>>0]|0;
    $34 = $33&255;
    $35 = (($24) + (($34*12)|0)|0);
    __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3fEfE9intersectERKS2_S5_S5_($21,$27,$31,$35);
    $36 = HEAP32[$23>>2]|0;
    $37 = (($36) + 1)|0;
    HEAP32[$23>>2] = $37;
    $38 = ((($$0133158)) + 3|0);
    $39 = ($38>>>0)<($19>>>0);
    if ($39) {
     $$0133158 = $38;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 5:  {
   $15 = ($2|0)>(2);
   if (!($15)) {
    return;
   }
   $16 = ((($0)) + 4|0);
   $17 = ((($0)) + 112|0);
   $18 = ((($0)) + 8|0);
   $$0135160 = $3;$$0137159 = 2;
   while(1) {
    $40 = $$0137159 & 1;
    $41 = ($40|0)==(0);
    $42 = HEAP32[$17>>2]|0;
    $43 = HEAP8[$$0135160>>0]|0;
    $44 = $43&255;
    $45 = (($42) + (($44*12)|0)|0);
    $46 = ((($$0135160)) + 1|0);
    $47 = HEAP8[$46>>0]|0;
    $48 = ((($$0135160)) + 2|0);
    $49 = HEAP8[$48>>0]|0;
    $50 = $47&255;
    $51 = $49&255;
    if ($41) {
     $54 = (($42) + (($50*12)|0)|0);
     $55 = (($42) + (($51*12)|0)|0);
     __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3fEfE9intersectERKS2_S5_S5_($16,$45,$54,$55);
    } else {
     $52 = (($42) + (($51*12)|0)|0);
     $53 = (($42) + (($50*12)|0)|0);
     __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3fEfE9intersectERKS2_S5_S5_($16,$45,$52,$53);
    }
    $56 = HEAP32[$18>>2]|0;
    $57 = (($56) + 1)|0;
    HEAP32[$18>>2] = $57;
    $58 = (($$0137159) + 1)|0;
    $exitcond = ($58|0)==($2|0);
    if ($exitcond) {
     break;
    } else {
     $$0135160 = $46;$$0137159 = $58;
    }
   }
   return;
   break;
  }
  case 7:  {
   $11 = ($2|0)>(3);
   if (!($11)) {
    return;
   }
   $12 = ((($0)) + 4|0);
   $13 = ((($0)) + 112|0);
   $14 = ((($0)) + 8|0);
   $$0139163 = $3;$$0141162 = 3;
   while(1) {
    $59 = HEAP32[$13>>2]|0;
    $60 = HEAP8[$$0139163>>0]|0;
    $61 = $60&255;
    $62 = (($59) + (($61*12)|0)|0);
    $63 = ((($$0139163)) + 1|0);
    $64 = HEAP8[$63>>0]|0;
    $65 = $64&255;
    $66 = (($59) + (($65*12)|0)|0);
    $67 = ((($$0139163)) + 2|0);
    $68 = HEAP8[$67>>0]|0;
    $69 = $68&255;
    $70 = (($59) + (($69*12)|0)|0);
    $71 = ((($$0139163)) + 3|0);
    $72 = HEAP8[$71>>0]|0;
    $73 = $72&255;
    $74 = (($59) + (($73*12)|0)|0);
    __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3fEfE9intersectERKS2_S5_S5_($12,$62,$66,$74);
    __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3fEfE9intersectERKS2_S5_S5_($12,$66,$70,$74);
    $75 = HEAP32[$14>>2]|0;
    $76 = (($75) + 1)|0;
    HEAP32[$14>>2] = $76;
    $77 = (($$0141162) + 4)|0;
    $78 = ((($$0139163)) + 4|0);
    $79 = ($77|0)<($2|0);
    if ($79) {
     $$0139163 = $78;$$0141162 = $77;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 8:  {
   $7 = ($2|0)>(3);
   if (!($7)) {
    return;
   }
   $8 = ((($0)) + 4|0);
   $9 = ((($0)) + 112|0);
   $10 = ((($0)) + 8|0);
   $$0143166 = $3;$$0145165 = 3;
   while(1) {
    $80 = HEAP32[$9>>2]|0;
    $81 = HEAP8[$$0143166>>0]|0;
    $82 = $81&255;
    $83 = (($80) + (($82*12)|0)|0);
    $84 = ((($$0143166)) + 1|0);
    $85 = HEAP8[$84>>0]|0;
    $86 = $85&255;
    $87 = (($80) + (($86*12)|0)|0);
    $88 = ((($$0143166)) + 3|0);
    $89 = HEAP8[$88>>0]|0;
    $90 = $89&255;
    $91 = (($80) + (($90*12)|0)|0);
    $92 = ((($$0143166)) + 2|0);
    $93 = HEAP8[$92>>0]|0;
    $94 = $93&255;
    $95 = (($80) + (($94*12)|0)|0);
    __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3fEfE9intersectERKS2_S5_S5_($8,$83,$87,$95);
    __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3fEfE9intersectERKS2_S5_S5_($8,$87,$91,$95);
    $96 = HEAP32[$10>>2]|0;
    $97 = (($96) + 1)|0;
    HEAP32[$10>>2] = $97;
    $98 = (($$0145165) + 2)|0;
    $99 = ($98|0)<($2|0);
    if ($99) {
     $$0143166 = $92;$$0145165 = $98;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 6: case 9:  {
   $100 = ((($0)) + 112|0);
   $101 = HEAP32[$100>>2]|0;
   $102 = HEAP8[$3>>0]|0;
   $103 = $102&255;
   $104 = (($101) + (($103*12)|0)|0);
   $105 = ($2|0)>(2);
   if (!($105)) {
    return;
   }
   $106 = ((($3)) + 1|0);
   $107 = ((($0)) + 4|0);
   $108 = ((($0)) + 8|0);
   $$0142169 = 2;$$0144168 = $106;$112 = $101;
   while(1) {
    $109 = HEAP8[$$0144168>>0]|0;
    $110 = $109&255;
    $111 = (($112) + (($110*12)|0)|0);
    $113 = ((($$0144168)) + 1|0);
    $114 = HEAP8[$113>>0]|0;
    $115 = $114&255;
    $116 = (($112) + (($115*12)|0)|0);
    __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3fEfE9intersectERKS2_S5_S5_($107,$104,$111,$116);
    $117 = HEAP32[$108>>2]|0;
    $118 = (($117) + 1)|0;
    HEAP32[$108>>2] = $118;
    $119 = (($$0142169) + 1)|0;
    $exitcond198 = ($119|0)==($2|0);
    if ($exitcond198) {
     break;
    }
    $$pre218 = HEAP32[$100>>2]|0;
    $$0142169 = $119;$$0144168 = $113;$112 = $$pre218;
   }
   return;
   break;
  }
  case 0:  {
   $120 = (($3) + ($2)|0);
   $121 = ($2|0)>(0);
   if (!($121)) {
    return;
   }
   $122 = ((($0)) + 8|0);
   $$promoted = HEAP32[$122>>2]|0;
   $scevgep = ((($3)) + 1|0);
   $123 = ($120>>>0)>($scevgep>>>0);
   $umax = $123 ? $120 : $scevgep;
   $124 = (($$promoted) - ($4))|0;
   $scevgep199 = (($umax) + ($124)|0);
   $scevgep199200 = $scevgep199;
   HEAP32[$122>>2] = $scevgep199200;
   return;
   break;
  }
  case 1:  {
   $125 = (($2) + -1)|0;
   $126 = (($3) + ($125)|0);
   $127 = ($2|0)>(1);
   if (!($127)) {
    return;
   }
   $128 = ((($0)) + 8|0);
   $$promoted175 = HEAP32[$128>>2]|0;
   $scevgep201 = ((($3)) + 2|0);
   $129 = ($126>>>0)>($scevgep201>>>0);
   $umax202 = $129 ? $126 : $scevgep201;
   $130 = $4 ^ -1;
   $scevgep203 = (($umax202) + ($130)|0);
   $scevgep203204 = $scevgep203;
   $131 = $scevgep203204 >>> 1;
   $132 = (($$promoted175) + ($131))|0;
   $133 = (($132) + 1)|0;
   HEAP32[$128>>2] = $133;
   return;
   break;
  }
  case 3:  {
   $134 = (($2) + -1)|0;
   $135 = (($3) + ($134)|0);
   $136 = ($2|0)>(1);
   if (!($136)) {
    return;
   }
   $137 = ((($0)) + 8|0);
   $$promoted179 = HEAP32[$137>>2]|0;
   $scevgep205 = ((($3)) + 1|0);
   $138 = ($135>>>0)>($scevgep205>>>0);
   $umax206 = $138 ? $135 : $scevgep205;
   $139 = (($$promoted179) - ($4))|0;
   $scevgep207 = (($umax206) + ($139)|0);
   $scevgep207208 = $scevgep207;
   HEAP32[$137>>2] = $scevgep207208;
   return;
   break;
  }
  case 11:  {
   $140 = (($2) + -2)|0;
   $141 = (($3) + ($140)|0);
   $142 = ($140|0)>(1);
   if (!($142)) {
    return;
   }
   $143 = ((($0)) + 8|0);
   $$promoted184 = HEAP32[$143>>2]|0;
   $scevgep209 = ((($3)) + 2|0);
   $144 = ($141>>>0)>($scevgep209>>>0);
   $umax210 = $144 ? $141 : $scevgep209;
   $145 = (($$promoted184) + -1)|0;
   $146 = (($145) - ($4))|0;
   $scevgep211 = (($umax210) + ($146)|0);
   $scevgep211212 = $scevgep211;
   HEAP32[$143>>2] = $scevgep211212;
   return;
   break;
  }
  case 2:  {
   $147 = (($2) + -1)|0;
   $148 = (($3) + ($147)|0);
   $149 = ($2|0)>(1);
   $150 = ((($0)) + 8|0);
   $$promoted188 = HEAP32[$150>>2]|0;
   if ($149) {
    $scevgep213 = ((($3)) + 1|0);
    $151 = ($148>>>0)>($scevgep213>>>0);
    $umax214 = $151 ? $148 : $scevgep213;
    $152 = (($$promoted188) - ($4))|0;
    $scevgep215 = (($umax214) + ($152)|0);
    $scevgep215216 = $scevgep215;
    HEAP32[$150>>2] = $scevgep215216;
    $154 = $scevgep215216;
   } else {
    $154 = $$promoted188;
   }
   $153 = (($154) + 1)|0;
   HEAP32[$150>>2] = $153;
   return;
   break;
  }
  default: {
   return;
  }
  }
 } while(0);
}
function __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3dEdE9intersectERKNS1_5Vec3fES6_S6_($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$$i$i = 0, $$0$be$in$i$i$i$i = 0, $$0$i$i$i$i = 0, $$015$i$i$i$i = 0, $$030$i$i$i = 0, $$194 = 0, $$196 = 0, $$pre = 0, $$pre$i$i$i$i = 0, $$pre311 = 0, $$sink = 0.0, $$sink303 = 0.0, $$sink304 = 0.0, $$sroa$0$0$$sroa_idx = 0, $$sroa$0133$0 = 0.0, $$sroa$0165$0$$sroa_idx = 0, $$sroa$11$0 = 0.0, $$sroa$5$0$$sroa_idx127 = 0, $$sroa$5168$0$$sroa_idx169 = 0, $$sroa$6$0$$sroa_idx130 = 0;
 var $$sroa$6172$0$$sroa_idx173 = 0, $$sroa$7$0 = 0.0, $10 = 0, $100 = 0.0, $101 = 0.0, $102 = 0.0, $103 = 0.0, $104 = 0.0, $105 = 0.0, $106 = 0, $107 = 0, $108 = 0.0, $109 = 0, $11 = 0, $110 = 0.0, $111 = 0.0, $112 = 0.0, $113 = 0.0, $114 = 0.0, $115 = 0.0;
 var $116 = 0.0, $117 = 0.0, $118 = 0, $119 = 0, $12 = 0, $120 = 0.0, $121 = 0, $122 = 0.0, $123 = 0.0, $124 = 0, $125 = 0.0, $126 = 0.0, $127 = 0.0, $128 = 0.0, $129 = 0.0, $13 = 0, $130 = 0, $131 = 0, $132 = 0.0, $133 = 0.0;
 var $134 = 0.0, $135 = 0.0, $136 = 0.0, $137 = 0.0, $138 = 0.0, $139 = 0.0, $14 = 0, $140 = 0.0, $141 = 0.0, $142 = 0.0, $143 = 0.0, $144 = 0.0, $145 = 0.0, $146 = 0, $147 = 0, $148 = 0.0, $149 = 0, $15 = 0, $150 = 0.0, $151 = 0.0;
 var $152 = 0.0, $153 = 0.0, $154 = 0.0, $155 = 0.0, $156 = 0.0, $157 = 0, $158 = 0, $159 = 0.0, $16 = 0, $160 = 0, $161 = 0.0, $162 = 0.0, $163 = 0.0, $164 = 0.0, $165 = 0, $166 = 0.0, $167 = 0.0, $168 = 0.0, $169 = 0.0, $17 = 0;
 var $170 = 0.0, $171 = 0.0, $172 = 0.0, $173 = 0.0, $174 = 0.0, $175 = 0.0, $176 = 0.0, $177 = 0.0, $178 = 0.0, $179 = 0.0, $18 = 0.0, $180 = 0.0, $181 = 0.0, $182 = 0.0, $183 = 0.0, $184 = 0.0, $185 = 0.0, $186 = 0.0, $187 = 0.0, $188 = 0.0;
 var $189 = 0.0, $19 = 0.0, $190 = 0.0, $191 = 0.0, $192 = 0.0, $193 = 0.0, $194 = 0.0, $195 = 0.0, $196 = 0.0, $197 = 0.0, $198 = 0.0, $199 = 0.0, $20 = 0, $200 = 0.0, $201 = 0.0, $202 = 0.0, $203 = 0.0, $204 = 0, $205 = 0.0, $206 = 0.0;
 var $207 = 0.0, $208 = 0.0, $209 = 0, $21 = 0.0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0.0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0;
 var $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0.0, $240 = 0, $241 = 0, $242 = 0;
 var $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0.0, $250 = 0, $251 = 0, $252 = 0, $253 = 0.0, $254 = 0.0, $255 = 0.0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0;
 var $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0.0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0;
 var $28 = 0.0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0;
 var $298 = 0, $299 = 0, $30 = 0.0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0.0, $310 = 0, $311 = 0, $312 = 0.0, $313 = 0, $314 = 0, $315 = 0;
 var $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0.0, $33 = 0.0, $330 = 0, $331 = 0, $332 = 0, $333 = 0;
 var $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0.0, $34 = 0.0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0.0, $350 = 0, $351 = 0;
 var $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0.0, $357 = 0, $358 = 0, $359 = 0, $36 = 0.0, $360 = 0, $361 = 0, $362 = 0.0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0;
 var $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0.0, $38 = 0.0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0;
 var $389 = 0, $39 = 0.0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0.0, $396 = 0, $397 = 0.0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0;
 var $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0.0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0.0, $420 = 0, $421 = 0, $422 = 0, $423 = 0;
 var $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $43 = 0.0, $44 = 0.0, $45 = 0.0, $46 = 0.0, $47 = 0.0, $48 = 0, $49 = 0.0, $5 = 0, $50 = 0.0, $51 = 0, $52 = 0.0, $53 = 0.0, $54 = 0.0, $55 = 0.0, $56 = 0.0;
 var $57 = 0, $58 = 0.0, $59 = 0.0, $6 = 0, $60 = 0, $61 = 0.0, $62 = 0.0, $63 = 0.0, $64 = 0.0, $65 = 0, $66 = 0.0, $67 = 0.0, $68 = 0.0, $69 = 0.0, $7 = 0, $70 = 0.0, $71 = 0.0, $72 = 0.0, $73 = 0.0, $74 = 0.0;
 var $75 = 0.0, $76 = 0.0, $77 = 0, $78 = 0.0, $79 = 0.0, $8 = 0, $80 = 0.0, $81 = 0.0, $82 = 0.0, $83 = 0, $84 = 0, $85 = 0.0, $86 = 0.0, $87 = 0.0, $88 = 0.0, $89 = 0.0, $9 = 0, $90 = 0.0, $91 = 0.0, $92 = 0.0;
 var $93 = 0.0, $94 = 0.0, $95 = 0.0, $96 = 0.0, $97 = 0.0, $98 = 0.0, $99 = 0.0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, $or$cond = 0, $or$cond103 = 0, $or$cond104 = 0, $or$cond105 = 0, $or$cond107 = 0, $or$cond109 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(144|0);
 $4 = sp + 112|0;
 $5 = sp + 104|0;
 $6 = sp + 96|0;
 $7 = sp;
 $8 = sp + 128|0;
 $9 = sp + 124|0;
 $10 = sp + 120|0;
 $11 = HEAP32[$0>>2]|0;
 $12 = ((($11)) + 28|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = ($13<<24>>24)==(0);
 if (!($14)) {
  $15 = ((($0)) + 184|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = ($16<<24>>24)==(0);
  if (!($17)) {
   STACKTOP = sp;return;
  }
 }
 $18 = +HEAPF32[$1>>2];
 $19 = $18;
 $20 = ((($1)) + 4|0);
 $21 = +HEAPF32[$20>>2];
 $22 = $21;
 $23 = ((($1)) + 8|0);
 $24 = +HEAPF32[$23>>2];
 $25 = $24;
 $26 = ((($0)) + 8|0);
 $27 = +HEAPF64[$26>>3];
 $28 = $27 - $19;
 $29 = ((($0)) + 16|0);
 $30 = +HEAPF64[$29>>3];
 $31 = $30 - $22;
 $32 = ((($0)) + 24|0);
 $33 = +HEAPF64[$32>>3];
 $34 = $33 - $25;
 $35 = +HEAPF32[$3>>2];
 $36 = $35 - $18;
 $37 = ((($3)) + 4|0);
 $38 = +HEAPF32[$37>>2];
 $39 = $38 - $21;
 $40 = ((($3)) + 8|0);
 $41 = +HEAPF32[$40>>2];
 $42 = $41 - $24;
 $43 = $36;
 $44 = $39;
 $45 = $42;
 $46 = +HEAPF32[$2>>2];
 $47 = $46 - $18;
 $48 = ((($2)) + 4|0);
 $49 = +HEAPF32[$48>>2];
 $50 = $49 - $21;
 $51 = ((($2)) + 8|0);
 $52 = +HEAPF32[$51>>2];
 $53 = $52 - $24;
 $54 = $47;
 $55 = $50;
 $56 = $53;
 $57 = ((($0)) + 80|0);
 $58 = +HEAPF64[$57>>3];
 $59 = $45 * $58;
 $60 = ((($0)) + 88|0);
 $61 = +HEAPF64[$60>>3];
 $62 = $44 * $61;
 $63 = $59 - $62;
 $64 = $43 * $61;
 $65 = ((($0)) + 72|0);
 $66 = +HEAPF64[$65>>3];
 $67 = $45 * $66;
 $68 = $64 - $67;
 $69 = $44 * $66;
 $70 = $43 * $58;
 $71 = $69 - $70;
 $72 = $54 * $63;
 $73 = $55 * $68;
 $74 = $72 + $73;
 $75 = $56 * $71;
 $76 = $75 + $74;
 $77 = $76 > 1.0E-10;
 if ($77) {
  $78 = $28 * $63;
  $79 = $31 * $68;
  $80 = $78 + $79;
  $81 = $34 * $71;
  $82 = $81 + $80;
  $83 = $82 < 0.0;
  $84 = $82 > $76;
  $or$cond = $83 | $84;
  if (!($or$cond)) {
   $85 = $31 * $56;
   $86 = $34 * $55;
   $87 = $85 - $86;
   $88 = $34 * $54;
   $89 = $28 * $56;
   $90 = $88 - $89;
   $91 = $28 * $55;
   $92 = $31 * $54;
   $93 = $91 - $92;
   $94 = $87;
   $95 = $90;
   $96 = $93;
   $97 = $66;
   $98 = $58;
   $99 = $61;
   $100 = $94 * $97;
   $101 = $95 * $98;
   $102 = $100 + $101;
   $103 = $96 * $99;
   $104 = $102 + $103;
   $105 = $104;
   $106 = $104 < 0.0;
   $107 = $105 > $76;
   $or$cond103 = $106 | $107;
   $108 = $82 + $105;
   $109 = $108 > $76;
   $or$cond107 = $or$cond103 | $109;
   if (!($or$cond107)) {
    $110 = 1.0 / $76;
    $111 = $36 * $94;
    $112 = $39 * $95;
    $113 = $111 + $112;
    $114 = $42 * $96;
    $115 = $114 + $113;
    $116 = $115;
    $117 = $116 * $110;
    $118 = $117 < 0.0;
    if (!($118)) {
     $119 = ((($0)) + 96|0);
     $120 = +HEAPF64[$119>>3];
     $121 = $117 > $120;
     if (!($121)) {
      $122 = $82 * $110;
      $123 = $110 * $105;
      $$sink = $117;$$sink303 = $123;$$sink304 = $122;
      label = 15;
     }
    }
   }
  }
 } else {
  $124 = $76 < -1.0E-10;
  if ($124) {
   $125 = $28 * $63;
   $126 = $31 * $68;
   $127 = $125 + $126;
   $128 = $34 * $71;
   $129 = $128 + $127;
   $130 = $129 > 0.0;
   $131 = $129 < $76;
   $or$cond104 = $130 | $131;
   if (!($or$cond104)) {
    $132 = $31 * $56;
    $133 = $34 * $55;
    $134 = $132 - $133;
    $135 = $34 * $54;
    $136 = $28 * $56;
    $137 = $135 - $136;
    $138 = $28 * $55;
    $139 = $31 * $54;
    $140 = $138 - $139;
    $141 = $134 * $66;
    $142 = $137 * $58;
    $143 = $141 + $142;
    $144 = $140 * $61;
    $145 = $143 + $144;
    $146 = $145 > 0.0;
    $147 = $145 < $76;
    $or$cond105 = $146 | $147;
    $148 = $129 + $145;
    $149 = $148 < $76;
    $or$cond109 = $or$cond105 | $149;
    if (!($or$cond109)) {
     $150 = 1.0 / $76;
     $151 = $43 * $134;
     $152 = $44 * $137;
     $153 = $151 + $152;
     $154 = $45 * $140;
     $155 = $154 + $153;
     $156 = $155 * $150;
     $157 = $156 < 0.0;
     if (!($157)) {
      $158 = ((($0)) + 96|0);
      $159 = +HEAPF64[$158>>3];
      $160 = $156 > $159;
      if (!($160)) {
       $161 = $129 * $150;
       $162 = $150 * $145;
       $$sink = $156;$$sink303 = $162;$$sink304 = $161;
       label = 15;
      }
     }
    }
   }
  }
 }
 L17: do {
  if ((label|0) == 15) {
   $163 = 1.0 - $$sink304;
   $164 = $163 - $$sink303;
   HEAPF64[$4>>3] = $164;
   HEAPF64[$5>>3] = $$sink304;
   HEAPF64[$6>>3] = $$sink303;
   $165 = ((($0)) + 104|0);
   $166 = +HEAPF64[$165>>3];
   $167 = $$sink * $166;
   $168 = $164;
   $169 = $168 * $18;
   $170 = $168 * $21;
   $171 = $168 * $24;
   $172 = $$sink304;
   $173 = $46 * $172;
   $174 = $172 * $49;
   $175 = $172 * $52;
   $176 = $169 + $173;
   $177 = $170 + $174;
   $178 = $171 + $175;
   $179 = $$sink303;
   $180 = $35 * $179;
   $181 = $179 * $38;
   $182 = $179 * $41;
   $183 = $176 + $180;
   $184 = $177 + $181;
   $185 = $178 + $182;
   $186 = $183;
   $187 = $184;
   $188 = $185;
   $189 = $45 * $55;
   $190 = $44 * $56;
   $191 = $189 - $190;
   $192 = $43 * $56;
   $193 = $45 * $54;
   $194 = $192 - $193;
   $195 = $44 * $54;
   $196 = $43 * $55;
   $197 = $195 - $196;
   $198 = $191 * $191;
   $199 = $194 * $194;
   $200 = $198 + $199;
   $201 = $197 * $197;
   $202 = $201 + $200;
   $203 = (+Math_sqrt((+$202)));
   $204 = $203 > 0.0;
   $205 = 1.0 / $203;
   $206 = $191 * $205;
   $207 = $194 * $205;
   $208 = $197 * $205;
   $$sroa$0133$0 = $204 ? $206 : $191;
   $$sroa$7$0 = $204 ? $207 : $194;
   $$sroa$11$0 = $204 ? $208 : $197;
   $209 = ((($7)) + 8|0);
   $210 = ((($7)) + 32|0);
   ;HEAP32[$209>>2]=0|0;HEAP32[$209+4>>2]=0|0;HEAP32[$209+8>>2]=0|0;HEAP32[$209+12>>2]=0|0;HEAP32[$209+16>>2]=0|0;
   dest=$210; stop=dest+64|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
   HEAPF64[$7>>3] = $167;
   $211 = ((($11)) + 16|0);
   $212 = HEAP32[$211>>2]|0;
   $213 = ((($212)) + 120|0);
   $214 = HEAP32[$213>>2]|0;
   $215 = ($214|0)==(0);
   if ($215) {
    $225 = $11;
   } else {
    $216 = ((($212)) + 112|0);
    $217 = HEAP32[$216>>2]|0;
    $218 = ((($217)) + 8|0);
    $219 = HEAP32[$218>>2]|0;
    $220 = ($219|0)==(0|0);
    if ($220) {
     $225 = $11;
    } else {
     $221 = ((($7)) + 24|0);
     HEAP32[$221>>2] = $219;
     $222 = ((($219)) + 8|0);
     $223 = HEAP32[$222>>2]|0;HEAP32[$222>>2] = (($223+1)|0);
     $$pre = HEAP32[$0>>2]|0;
     $225 = $$pre;
    }
   }
   $224 = ((($225)) + 16|0);
   $226 = HEAP32[$224>>2]|0;
   $227 = ((($226)) + 28|0);
   $228 = ((($7)) + 8|0);
   $229 = ($228|0)==($227|0);
   if ($229) {
    $236 = $225;
    label = 21;
   } else {
    $230 = HEAP32[$227>>2]|0;
    $231 = ((($226)) + 32|0);
    $232 = HEAP32[$231>>2]|0;
    __THREW__ = 0;
    invoke_viii(3566,($228|0),($230|0),($232|0));
    $233 = __THREW__; __THREW__ = 0;
    $234 = $233&1;
    if ($234) {
     label = 47;
    } else {
     $$pre311 = HEAP32[$0>>2]|0;
     $236 = $$pre311;
     label = 21;
    }
   }
   L26: do {
    if ((label|0) == 21) {
     $235 = ((($236)) + 20|0);
     $237 = HEAP32[$235>>2]|0;
     $238 = ((($7)) + 20|0);
     $239 = HEAP32[$238>>2]|0;
     $240 = ($239|0)==($237|0);
     if (!($240)) {
      HEAP32[$238>>2] = $237;
      $241 = ($237|0)==(0|0);
      if (!($241)) {
       $242 = ((($237)) + 8|0);
       $243 = HEAP32[$242>>2]|0;HEAP32[$242>>2] = (($243+1)|0);
      }
      $244 = ($239|0)==(0|0);
      if (!($244)) {
       $245 = ((($239)) + 8|0);
       $246 = HEAP32[$245>>2]|0;HEAP32[$245>>2] = (($246-1)|0);
       $247 = ($246|0)==(1);
       if ($247) {
        __THREW__ = 0;
        invoke_viii(3262,($239|0),1,1);
        $248 = __THREW__; __THREW__ = 0;
        $249 = $248&1;
        if ($249) {
         label = 47;
         break;
        }
       }
      }
     }
     $250 = ((($0)) + 4|0);
     $251 = HEAP32[$250>>2]|0;
     $252 = ((($7)) + 92|0);
     HEAP32[$252>>2] = $251;
     $$sroa$0165$0$$sroa_idx = ((($7)) + 32|0);
     HEAPF64[$$sroa$0165$0$$sroa_idx>>3] = $186;
     $$sroa$5168$0$$sroa_idx169 = ((($7)) + 40|0);
     HEAPF64[$$sroa$5168$0$$sroa_idx169>>3] = $187;
     $$sroa$6172$0$$sroa_idx173 = ((($7)) + 48|0);
     HEAPF64[$$sroa$6172$0$$sroa_idx173>>3] = $188;
     $253 = $$sroa$0133$0;
     $254 = $$sroa$7$0;
     $255 = $$sroa$11$0;
     $$sroa$0$0$$sroa_idx = ((($7)) + 56|0);
     HEAPF32[$$sroa$0$0$$sroa_idx>>2] = $253;
     $$sroa$5$0$$sroa_idx127 = ((($7)) + 60|0);
     HEAPF32[$$sroa$5$0$$sroa_idx127>>2] = $254;
     $$sroa$6$0$$sroa_idx130 = ((($7)) + 64|0);
     HEAPF32[$$sroa$6$0$$sroa_idx130>>2] = $255;
     $256 = HEAP32[$0>>2]|0;
     $257 = ((($256)) + 24|0);
     $258 = HEAP32[$257>>2]|0;
     $259 = ($258|0)==(0|0);
     L36: do {
      if (!($259)) {
       $260 = ((($258)) + 76|0);
       $261 = HEAP32[$260>>2]|0;
       $262 = ((($7)) + 68|0);
       $263 = ((($7)) + 76|0);
       $264 = HEAP32[$263>>2]|0;
       $265 = HEAP32[$262>>2]|0;
       $266 = (($264) - ($265))|0;
       $267 = $266 >> 2;
       $268 = ($267>>>0)<(3);
       if ($268) {
        $269 = ((($7)) + 72|0);
        $270 = HEAP32[$269>>2]|0;
        $271 = (($270) - ($265))|0;
        $272 = $271 >> 2;
        __THREW__ = 0;
        $273 = (invoke_ii(3276,12)|0);
        $274 = __THREW__; __THREW__ = 0;
        $275 = $274&1;
        if (!($275)) {
         $276 = (($273) + ($272<<2)|0);
         $277 = $276;
         $278 = ((($273)) + 12|0);
         $279 = $278;
         $280 = (0 - ($272))|0;
         $281 = (($276) + ($280<<2)|0);
         $282 = $281;
         $283 = ($271|0)>(0);
         if ($283) {
          $284 = $265;
          _memcpy(($281|0),($284|0),($271|0))|0;
         }
         HEAP32[$262>>2] = $282;
         HEAP32[$269>>2] = $277;
         HEAP32[$263>>2] = $279;
         $285 = ($265|0)==(0);
         if ($285) {
          label = 34;
         } else {
          $286 = $265;
          __ZdlPv($286);
          label = 34;
         }
        }
       } else {
        label = 34;
       }
       L45: do {
        if ((label|0) == 34) {
         $287 = ((($7)) + 80|0);
         $288 = ((($7)) + 88|0);
         $289 = HEAP32[$288>>2]|0;
         $290 = HEAP32[$287>>2]|0;
         $291 = (($289) - ($290))|0;
         $292 = $291 >> 3;
         $293 = ($292>>>0)<(3);
         if ($293) {
          $294 = ((($7)) + 84|0);
          $295 = HEAP32[$294>>2]|0;
          $296 = (($295) - ($290))|0;
          $297 = $296 >> 3;
          __THREW__ = 0;
          $298 = (invoke_ii(3276,24)|0);
          $299 = __THREW__; __THREW__ = 0;
          $300 = $299&1;
          if ($300) {
           break;
          }
          $301 = (($298) + ($297<<3)|0);
          $302 = $301;
          $303 = ((($298)) + 24|0);
          $304 = $303;
          $305 = (0 - ($297))|0;
          $306 = (($301) + ($305<<3)|0);
          $307 = $306;
          $308 = ($296|0)>(0);
          if ($308) {
           $309 = $290;
           _memcpy(($306|0),($309|0),($296|0))|0;
          }
          HEAP32[$287>>2] = $307;
          HEAP32[$294>>2] = $302;
          HEAP32[$288>>2] = $304;
          $310 = ($290|0)==(0);
          if (!($310)) {
           $311 = $290;
           __ZdlPv($311);
          }
         }
         $312 = +HEAPF64[$4>>3];
         $313 = $312 != 0.0;
         do {
          if ($313) {
           $314 = $1;
           $315 = $261;
           $316 = (($314) - ($315))|0;
           $317 = (($316|0) / 12)&-1;
           HEAP32[$8>>2] = $317;
           $318 = ((($7)) + 72|0);
           $319 = HEAP32[$318>>2]|0;
           $320 = HEAP32[$263>>2]|0;
           $321 = ($319|0)==($320|0);
           if ($321) {
            __THREW__ = 0;
            invoke_vii(3437,($262|0),($8|0));
            $323 = __THREW__; __THREW__ = 0;
            $324 = $323&1;
            if ($324) {
             $337 = ___cxa_find_matching_catch_2()|0;
             $338 = tempRet0;
             $$194 = $338;$$196 = $337;
             break L26;
            }
           } else {
            HEAP32[$319>>2] = $317;
            $322 = ((($319)) + 4|0);
            HEAP32[$318>>2] = $322;
           }
           $325 = ((($7)) + 84|0);
           $326 = HEAP32[$325>>2]|0;
           $327 = HEAP32[$288>>2]|0;
           $328 = ($326|0)==($327|0);
           if ($328) {
            __THREW__ = 0;
            invoke_vii(3567,($287|0),($4|0));
            $331 = __THREW__; __THREW__ = 0;
            $332 = $331&1;
            if ($332) {
             break L45;
            } else {
             break;
            }
           } else {
            $329 = +HEAPF64[$4>>3];
            HEAPF64[$326>>3] = $329;
            $330 = ((($326)) + 8|0);
            HEAP32[$325>>2] = $330;
            break;
           }
          }
         } while(0);
         $339 = +HEAPF64[$5>>3];
         $340 = $339 != 0.0;
         do {
          if ($340) {
           $341 = $2;
           $342 = $261;
           $343 = (($341) - ($342))|0;
           $344 = (($343|0) / 12)&-1;
           HEAP32[$9>>2] = $344;
           $345 = ((($7)) + 72|0);
           $346 = HEAP32[$345>>2]|0;
           $347 = HEAP32[$263>>2]|0;
           $348 = ($346|0)==($347|0);
           if ($348) {
            __THREW__ = 0;
            invoke_vii(3437,($262|0),($9|0));
            $350 = __THREW__; __THREW__ = 0;
            $351 = $350&1;
            if ($351) {
             $360 = ___cxa_find_matching_catch_2()|0;
             $361 = tempRet0;
             $$194 = $361;$$196 = $360;
             break L26;
            }
           } else {
            HEAP32[$346>>2] = $344;
            $349 = ((($346)) + 4|0);
            HEAP32[$345>>2] = $349;
           }
           $352 = ((($7)) + 84|0);
           $353 = HEAP32[$352>>2]|0;
           $354 = HEAP32[$288>>2]|0;
           $355 = ($353|0)==($354|0);
           if ($355) {
            __THREW__ = 0;
            invoke_vii(3567,($287|0),($5|0));
            $358 = __THREW__; __THREW__ = 0;
            $359 = $358&1;
            if ($359) {
             break L45;
            } else {
             break;
            }
           } else {
            $356 = +HEAPF64[$5>>3];
            HEAPF64[$353>>3] = $356;
            $357 = ((($353)) + 8|0);
            HEAP32[$352>>2] = $357;
            break;
           }
          }
         } while(0);
         $362 = +HEAPF64[$6>>3];
         $363 = $362 != 0.0;
         if (!($363)) {
          break L36;
         }
         $364 = $3;
         $365 = $261;
         $366 = (($364) - ($365))|0;
         $367 = (($366|0) / 12)&-1;
         HEAP32[$10>>2] = $367;
         $368 = ((($7)) + 72|0);
         $369 = HEAP32[$368>>2]|0;
         $370 = HEAP32[$263>>2]|0;
         $371 = ($369|0)==($370|0);
         if ($371) {
          __THREW__ = 0;
          invoke_vii(3437,($262|0),($10|0));
          $373 = __THREW__; __THREW__ = 0;
          $374 = $373&1;
          if ($374) {
           $383 = ___cxa_find_matching_catch_2()|0;
           $384 = tempRet0;
           $$194 = $384;$$196 = $383;
           break L26;
          }
         } else {
          HEAP32[$369>>2] = $367;
          $372 = ((($369)) + 4|0);
          HEAP32[$368>>2] = $372;
         }
         $375 = ((($7)) + 84|0);
         $376 = HEAP32[$375>>2]|0;
         $377 = HEAP32[$288>>2]|0;
         $378 = ($376|0)==($377|0);
         if ($378) {
          __THREW__ = 0;
          invoke_vii(3567,($287|0),($6|0));
          $381 = __THREW__; __THREW__ = 0;
          $382 = $381&1;
          if ($382) {
           break;
          } else {
           break L36;
          }
         } else {
          $379 = +HEAPF64[$6>>3];
          HEAPF64[$376>>3] = $379;
          $380 = ((($376)) + 8|0);
          HEAP32[$375>>2] = $380;
          break L36;
         }
        }
       } while(0);
       $335 = ___cxa_find_matching_catch_2()|0;
       $336 = tempRet0;
       $$194 = $336;$$196 = $335;
       break L26;
      }
     } while(0);
     $385 = HEAP32[$0>>2]|0;
     $386 = ((($385)) + 12|0);
     $387 = HEAP32[$386>>2]|0;
     $388 = ((($387)) + 28|0);
     $389 = HEAP32[$388>>2]|0;
     $390 = ($389|0)==(0|0);
     $$$i$i = $390 ? $387 : $389;
     $391 = ((($$$i$i)) + 80|0);
     $392 = ((($$$i$i)) + 84|0);
     $393 = HEAP32[$392>>2]|0;
     $394 = ($393|0)==(0|0);
     do {
      if ($394) {
       $$015$i$i$i$i = $392;$$030$i$i$i = $392;
      } else {
       $395 = +HEAPF64[$7>>3];
       $$0$i$i$i$i = $393;
       while(1) {
        $396 = ((($$0$i$i$i$i)) + 16|0);
        $397 = +HEAPF64[$396>>3];
        $398 = $395 < $397;
        if ($398) {
         $399 = HEAP32[$$0$i$i$i$i>>2]|0;
         $400 = ($399|0)==(0|0);
         if ($400) {
          label = 71;
          break;
         } else {
          $$0$be$in$i$i$i$i = $399;
         }
        } else {
         $401 = ((($$0$i$i$i$i)) + 4|0);
         $402 = HEAP32[$401>>2]|0;
         $403 = ($402|0)==(0|0);
         if ($403) {
          label = 74;
          break;
         } else {
          $$0$be$in$i$i$i$i = $402;
         }
        }
        $$0$i$i$i$i = $$0$be$in$i$i$i$i;
       }
       if ((label|0) == 71) {
        $$015$i$i$i$i = $$0$i$i$i$i;$$030$i$i$i = $$0$i$i$i$i;
        break;
       }
       else if ((label|0) == 74) {
        $$015$i$i$i$i = $401;$$030$i$i$i = $$0$i$i$i$i;
        break;
       }
      }
     } while(0);
     __THREW__ = 0;
     $404 = (invoke_ii(3276,112)|0);
     $405 = __THREW__; __THREW__ = 0;
     $406 = $405&1;
     if ($406) {
      label = 47;
     } else {
      $407 = ((($404)) + 16|0);
      __THREW__ = 0;
      invoke_vii(3315,($407|0),($7|0));
      $408 = __THREW__; __THREW__ = 0;
      $409 = $408&1;
      if ($409) {
       $410 = ___cxa_find_matching_catch_2()|0;
       $411 = tempRet0;
       __ZdlPv($404);
       $eh$lpad$body$index2Z2D = $411;$eh$lpad$body$indexZ2D = $410;
       label = 48;
       break;
      }
      HEAP32[$404>>2] = 0;
      $412 = ((($404)) + 4|0);
      HEAP32[$412>>2] = 0;
      $413 = ((($404)) + 8|0);
      HEAP32[$413>>2] = $$030$i$i$i;
      HEAP32[$$015$i$i$i$i>>2] = $404;
      $414 = HEAP32[$391>>2]|0;
      $415 = HEAP32[$414>>2]|0;
      $416 = ($415|0)==(0|0);
      if ($416) {
       $420 = $404;
      } else {
       $417 = $415;
       HEAP32[$391>>2] = $417;
       $$pre$i$i$i$i = HEAP32[$$015$i$i$i$i>>2]|0;
       $420 = $$pre$i$i$i$i;
      }
      $418 = ((($$$i$i)) + 84|0);
      $419 = HEAP32[$418>>2]|0;
      __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($419,$420);
      $421 = ((($$$i$i)) + 88|0);
      $422 = HEAP32[$421>>2]|0;
      $423 = (($422) + 1)|0;
      HEAP32[$421>>2] = $423;
      $424 = ((($0)) + 184|0);
      HEAP8[$424>>0] = 1;
      __ZN7osgUtil22LineSegmentIntersector12IntersectionD2Ev($7);
      break L17;
     }
    }
   } while(0);
   if ((label|0) == 47) {
    $333 = ___cxa_find_matching_catch_2()|0;
    $334 = tempRet0;
    $eh$lpad$body$index2Z2D = $334;$eh$lpad$body$indexZ2D = $333;
    label = 48;
   }
   if ((label|0) == 48) {
    $$194 = $eh$lpad$body$index2Z2D;$$196 = $eh$lpad$body$indexZ2D;
   }
   __THREW__ = 0;
   invoke_vi(3316,($7|0));
   $425 = __THREW__; __THREW__ = 0;
   $426 = $425&1;
   if ($426) {
    $427 = ___cxa_find_matching_catch_3(0|0)|0;
    $428 = tempRet0;
    ___clang_call_terminate($427);
    // unreachable;
   } else {
    ___resumeException($$196|0);
    // unreachable;
   }
  }
 } while(0);
 STACKTOP = sp;return;
}
function __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3dEdE5enterERKNS1_15BoundingBoxImplINS1_5Vec3fEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$sroa$4237$0$$sroa_idx238 = 0, $$sroa$4251$0$$sroa_idx252 = 0, $$sroa$5184$0$$sroa_idx185 = 0, $$sroa$5198$0$$sroa_idx199 = 0, $$sroa$5240$0$$sroa_idx241 = 0, $$sroa$5254$0$$sroa_idx255 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0.0, $103 = 0.0, $104 = 0, $105 = 0, $106 = 0.0, $107 = 0.0, $108 = 0, $109 = 0, $11 = 0.0, $110 = 0.0;
 var $111 = 0, $112 = 0.0, $113 = 0.0, $114 = 0, $115 = 0.0, $116 = 0.0, $117 = 0, $118 = 0.0, $119 = 0.0, $12 = 0.0, $120 = 0.0, $121 = 0.0, $122 = 0.0, $123 = 0, $124 = 0.0, $125 = 0.0, $126 = 0, $127 = 0.0, $128 = 0.0, $129 = 0;
 var $13 = 0, $130 = 0.0, $131 = 0.0, $132 = 0, $133 = 0.0, $134 = 0.0, $135 = 0, $136 = 0.0, $137 = 0.0, $138 = 0.0, $139 = 0.0, $14 = 0, $140 = 0.0, $141 = 0, $142 = 0.0, $143 = 0.0, $144 = 0, $145 = 0, $146 = 0.0, $147 = 0.0;
 var $148 = 0, $149 = 0, $15 = 0.0, $150 = 0.0, $151 = 0, $152 = 0.0, $153 = 0.0, $154 = 0, $155 = 0.0, $156 = 0.0, $157 = 0, $158 = 0.0, $159 = 0.0, $16 = 0.0, $160 = 0.0, $161 = 0.0, $162 = 0, $163 = 0.0, $164 = 0.0, $165 = 0;
 var $166 = 0.0, $167 = 0, $168 = 0.0, $169 = 0.0, $17 = 0, $170 = 0, $171 = 0.0, $172 = 0.0, $173 = 0, $174 = 0.0, $175 = 0.0, $176 = 0.0, $177 = 0.0, $178 = 0, $179 = 0.0, $18 = 0, $180 = 0.0, $181 = 0, $182 = 0.0, $183 = 0;
 var $184 = 0.0, $185 = 0, $186 = 0, $187 = 0.0, $188 = 0.0, $189 = 0, $19 = 0.0, $190 = 0, $191 = 0.0, $192 = 0.0, $193 = 0, $194 = 0, $195 = 0.0, $196 = 0, $197 = 0.0, $198 = 0.0, $199 = 0, $2 = 0, $20 = 0, $200 = 0.0;
 var $201 = 0.0, $202 = 0, $203 = 0.0, $204 = 0.0, $205 = 0.0, $206 = 0.0, $207 = 0.0, $208 = 0.0, $209 = 0.0, $21 = 0.0, $210 = 0, $211 = 0.0, $212 = 0.0, $213 = 0, $214 = 0.0, $215 = 0.0, $216 = 0, $217 = 0.0, $218 = 0.0, $219 = 0;
 var $22 = 0.0, $220 = 0.0, $221 = 0.0, $222 = 0.0, $223 = 0.0, $224 = 0.0, $225 = 0.0, $226 = 0.0, $227 = 0, $228 = 0, $229 = 0.0, $23 = 0, $230 = 0.0, $231 = 0, $232 = 0, $233 = 0.0, $234 = 0, $235 = 0.0, $236 = 0.0, $237 = 0;
 var $238 = 0.0, $239 = 0.0, $24 = 0.0, $240 = 0, $241 = 0.0, $242 = 0.0, $243 = 0.0, $244 = 0.0, $245 = 0.0, $246 = 0, $247 = 0.0, $248 = 0, $249 = 0.0, $25 = 0.0, $250 = 0.0, $251 = 0, $252 = 0.0, $253 = 0.0, $254 = 0, $255 = 0.0;
 var $256 = 0.0, $257 = 0.0, $258 = 0.0, $259 = 0.0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $27 = 0.0, $28 = 0.0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0.0, $32 = 0.0, $33 = 0, $34 = 0.0, $35 = 0.0;
 var $36 = 0, $37 = 0.0, $38 = 0.0, $39 = 0, $4 = 0, $40 = 0.0, $41 = 0.0, $42 = 0, $43 = 0.0, $44 = 0.0, $45 = 0, $46 = 0.0, $47 = 0.0, $48 = 0.0, $49 = 0, $5 = 0, $50 = 0.0, $51 = 0.0, $52 = 0, $53 = 0.0;
 var $54 = 0.0, $55 = 0, $56 = 0, $57 = 0.0, $58 = 0.0, $59 = 0, $6 = 0, $60 = 0, $61 = 0.0, $62 = 0, $63 = 0.0, $64 = 0.0, $65 = 0, $66 = 0.0, $67 = 0.0, $68 = 0, $69 = 0.0, $7 = 0.0, $70 = 0.0, $71 = 0.0;
 var $72 = 0, $73 = 0.0, $74 = 0.0, $75 = 0, $76 = 0.0, $77 = 0.0, $78 = 0, $79 = 0.0, $8 = 0, $80 = 0, $81 = 0.0, $82 = 0.0, $83 = 0, $84 = 0.0, $85 = 0.0, $86 = 0, $87 = 0.0, $88 = 0.0, $89 = 0.0, $9 = 0.0;
 var $90 = 0, $91 = 0.0, $92 = 0.0, $93 = 0, $94 = 0.0, $95 = 0.0, $96 = 0, $97 = 0.0, $98 = 0, $99 = 0.0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $2 = sp;
 $3 = ((($0)) + 56|0);
 $4 = ((($0)) + 60|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($5)) + -48|0);
 dest=$2; src=$6; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $7 = +HEAPF64[$2>>3];
 $8 = ((($2)) + 24|0);
 $9 = +HEAPF64[$8>>3];
 $10 = !($7 <= $9);
 $11 = +HEAPF32[$1>>2];
 $12 = $11;
 if ($10) {
  $55 = $7 < $12;
  if ($55) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $56 = ((($1)) + 12|0);
  $57 = +HEAPF32[$56>>2];
  $58 = $57;
  $59 = $9 > $58;
  if ($59) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $60 = $9 < $12;
  if ($60) {
   $61 = $12 - $7;
   $62 = ((($0)) + 112|0);
   $63 = +HEAPF64[$62>>3];
   $64 = $61 * $63;
   $65 = ((($0)) + 120|0);
   $66 = +HEAPF64[$65>>3];
   $67 = $61 * $66;
   $68 = ((($0)) + 128|0);
   $69 = +HEAPF64[$68>>3];
   $70 = $61 * $69;
   $71 = $7 + $64;
   $72 = ((($2)) + 8|0);
   $73 = +HEAPF64[$72>>3];
   $74 = $67 + $73;
   $75 = ((($2)) + 16|0);
   $76 = +HEAPF64[$75>>3];
   $77 = $70 + $76;
   HEAPF64[$8>>3] = $71;
   $$sroa$4237$0$$sroa_idx238 = ((($2)) + 32|0);
   HEAPF64[$$sroa$4237$0$$sroa_idx238>>3] = $74;
   $$sroa$5240$0$$sroa_idx241 = ((($2)) + 40|0);
   HEAPF64[$$sroa$5240$0$$sroa_idx241>>3] = $77;
  }
  $78 = $7 > $58;
  if ($78) {
   $79 = $58 - $7;
   $80 = ((($0)) + 112|0);
   $81 = +HEAPF64[$80>>3];
   $82 = $79 * $81;
   $83 = ((($0)) + 120|0);
   $84 = +HEAPF64[$83>>3];
   $85 = $79 * $84;
   $86 = ((($0)) + 128|0);
   $87 = +HEAPF64[$86>>3];
   $88 = $79 * $87;
   $89 = $7 + $82;
   $90 = ((($2)) + 8|0);
   $91 = +HEAPF64[$90>>3];
   $92 = $85 + $91;
   $93 = ((($2)) + 16|0);
   $94 = +HEAPF64[$93>>3];
   $95 = $88 + $94;
   HEAPF64[$2>>3] = $89;
   HEAPF64[$90>>3] = $92;
   HEAPF64[$93>>3] = $95;
   $121 = $89;
  } else {
   $121 = $7;
  }
 } else {
  $13 = $9 < $12;
  if ($13) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $14 = ((($1)) + 12|0);
  $15 = +HEAPF32[$14>>2];
  $16 = $15;
  $17 = $7 > $16;
  if ($17) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $18 = $7 < $12;
  if ($18) {
   $19 = $12 - $7;
   $20 = ((($0)) + 112|0);
   $21 = +HEAPF64[$20>>3];
   $22 = $19 * $21;
   $23 = ((($0)) + 120|0);
   $24 = +HEAPF64[$23>>3];
   $25 = $19 * $24;
   $26 = ((($0)) + 128|0);
   $27 = +HEAPF64[$26>>3];
   $28 = $19 * $27;
   $29 = $7 + $22;
   $30 = ((($2)) + 8|0);
   $31 = +HEAPF64[$30>>3];
   $32 = $25 + $31;
   $33 = ((($2)) + 16|0);
   $34 = +HEAPF64[$33>>3];
   $35 = $28 + $34;
   HEAPF64[$2>>3] = $29;
   HEAPF64[$30>>3] = $32;
   HEAPF64[$33>>3] = $35;
   $38 = $29;
  } else {
   $38 = $7;
  }
  $36 = $9 > $16;
  if ($36) {
   $37 = $16 - $38;
   $39 = ((($0)) + 112|0);
   $40 = +HEAPF64[$39>>3];
   $41 = $40 * $37;
   $42 = ((($0)) + 120|0);
   $43 = +HEAPF64[$42>>3];
   $44 = $37 * $43;
   $45 = ((($0)) + 128|0);
   $46 = +HEAPF64[$45>>3];
   $47 = $37 * $46;
   $48 = $38 + $41;
   $49 = ((($2)) + 8|0);
   $50 = +HEAPF64[$49>>3];
   $51 = $44 + $50;
   $52 = ((($2)) + 16|0);
   $53 = +HEAPF64[$52>>3];
   $54 = $47 + $53;
   HEAPF64[$8>>3] = $48;
   $$sroa$4251$0$$sroa_idx252 = ((($2)) + 32|0);
   HEAPF64[$$sroa$4251$0$$sroa_idx252>>3] = $51;
   $$sroa$5254$0$$sroa_idx255 = ((($2)) + 40|0);
   HEAPF64[$$sroa$5254$0$$sroa_idx255>>3] = $54;
   $121 = $38;
  } else {
   $121 = $38;
  }
 }
 $96 = ((($2)) + 8|0);
 $97 = +HEAPF64[$96>>3];
 $98 = ((($2)) + 32|0);
 $99 = +HEAPF64[$98>>3];
 $100 = !($97 <= $99);
 $101 = ((($1)) + 4|0);
 $102 = +HEAPF32[$101>>2];
 $103 = $102;
 if ($100) {
  $144 = $97 < $103;
  if ($144) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $145 = ((($1)) + 16|0);
  $146 = +HEAPF32[$145>>2];
  $147 = $146;
  $148 = $99 > $147;
  if ($148) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $149 = $99 < $103;
  if ($149) {
   $150 = $103 - $97;
   $151 = ((($0)) + 136|0);
   $152 = +HEAPF64[$151>>3];
   $153 = $150 * $152;
   $154 = ((($0)) + 144|0);
   $155 = +HEAPF64[$154>>3];
   $156 = $150 * $155;
   $157 = ((($0)) + 152|0);
   $158 = +HEAPF64[$157>>3];
   $159 = $150 * $158;
   $160 = $153 + $121;
   $161 = $97 + $156;
   $162 = ((($2)) + 16|0);
   $163 = +HEAPF64[$162>>3];
   $164 = $159 + $163;
   HEAPF64[$8>>3] = $160;
   HEAPF64[$98>>3] = $161;
   $$sroa$5184$0$$sroa_idx185 = ((($2)) + 40|0);
   HEAPF64[$$sroa$5184$0$$sroa_idx185>>3] = $164;
  }
  $165 = $97 > $147;
  if ($165) {
   $166 = $147 - $97;
   $167 = ((($0)) + 136|0);
   $168 = +HEAPF64[$167>>3];
   $169 = $166 * $168;
   $170 = ((($0)) + 144|0);
   $171 = +HEAPF64[$170>>3];
   $172 = $166 * $171;
   $173 = ((($0)) + 152|0);
   $174 = +HEAPF64[$173>>3];
   $175 = $166 * $174;
   $176 = $169 + $121;
   $177 = $97 + $172;
   $178 = ((($2)) + 16|0);
   $179 = +HEAPF64[$178>>3];
   $180 = $175 + $179;
   HEAPF64[$2>>3] = $176;
   HEAPF64[$96>>3] = $177;
   HEAPF64[$178>>3] = $180;
   $206 = $176;$208 = $177;
  } else {
   $206 = $121;$208 = $97;
  }
 } else {
  $104 = $99 < $103;
  if ($104) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $105 = ((($1)) + 16|0);
  $106 = +HEAPF32[$105>>2];
  $107 = $106;
  $108 = $97 > $107;
  if ($108) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $109 = $97 < $103;
  if ($109) {
   $110 = $103 - $97;
   $111 = ((($0)) + 136|0);
   $112 = +HEAPF64[$111>>3];
   $113 = $110 * $112;
   $114 = ((($0)) + 144|0);
   $115 = +HEAPF64[$114>>3];
   $116 = $110 * $115;
   $117 = ((($0)) + 152|0);
   $118 = +HEAPF64[$117>>3];
   $119 = $110 * $118;
   $120 = $113 + $121;
   $122 = $97 + $116;
   $123 = ((($2)) + 16|0);
   $124 = +HEAPF64[$123>>3];
   $125 = $119 + $124;
   HEAPF64[$2>>3] = $120;
   HEAPF64[$96>>3] = $122;
   HEAPF64[$123>>3] = $125;
   $128 = $122;$139 = $120;
  } else {
   $128 = $97;$139 = $121;
  }
  $126 = $99 > $107;
  if ($126) {
   $127 = $107 - $128;
   $129 = ((($0)) + 136|0);
   $130 = +HEAPF64[$129>>3];
   $131 = $130 * $127;
   $132 = ((($0)) + 144|0);
   $133 = +HEAPF64[$132>>3];
   $134 = $127 * $133;
   $135 = ((($0)) + 152|0);
   $136 = +HEAPF64[$135>>3];
   $137 = $127 * $136;
   $138 = $131 + $139;
   $140 = $128 + $134;
   $141 = ((($2)) + 16|0);
   $142 = +HEAPF64[$141>>3];
   $143 = $137 + $142;
   HEAPF64[$8>>3] = $138;
   HEAPF64[$98>>3] = $140;
   $$sroa$5198$0$$sroa_idx199 = ((($2)) + 40|0);
   HEAPF64[$$sroa$5198$0$$sroa_idx199>>3] = $143;
   $206 = $139;$208 = $128;
  } else {
   $206 = $139;$208 = $128;
  }
 }
 $181 = ((($2)) + 16|0);
 $182 = +HEAPF64[$181>>3];
 $183 = ((($2)) + 40|0);
 $184 = +HEAPF64[$183>>3];
 $185 = !($182 <= $184);
 $186 = ((($1)) + 8|0);
 $187 = +HEAPF32[$186>>2];
 $188 = $187;
 if ($185) {
  $227 = $182 < $188;
  if ($227) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $228 = ((($1)) + 20|0);
  $229 = +HEAPF32[$228>>2];
  $230 = $229;
  $231 = $184 > $230;
  if ($231) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $232 = $184 < $188;
  if ($232) {
   $233 = $188 - $182;
   $234 = ((($0)) + 160|0);
   $235 = +HEAPF64[$234>>3];
   $236 = $233 * $235;
   $237 = ((($0)) + 168|0);
   $238 = +HEAPF64[$237>>3];
   $239 = $233 * $238;
   $240 = ((($0)) + 176|0);
   $241 = +HEAPF64[$240>>3];
   $242 = $233 * $241;
   $243 = $236 + $206;
   $244 = $239 + $208;
   $245 = $182 + $242;
   HEAPF64[$8>>3] = $243;
   HEAPF64[$98>>3] = $244;
   HEAPF64[$183>>3] = $245;
  }
  $246 = $182 > $230;
  if ($246) {
   $247 = $230 - $182;
   $248 = ((($0)) + 160|0);
   $249 = +HEAPF64[$248>>3];
   $250 = $247 * $249;
   $251 = ((($0)) + 168|0);
   $252 = +HEAPF64[$251>>3];
   $253 = $247 * $252;
   $254 = ((($0)) + 176|0);
   $255 = +HEAPF64[$254>>3];
   $256 = $247 * $255;
   $257 = $250 + $206;
   $258 = $253 + $208;
   $259 = $182 + $256;
   HEAPF64[$2>>3] = $257;
   HEAPF64[$96>>3] = $258;
   HEAPF64[$181>>3] = $259;
  }
 } else {
  $189 = $184 < $188;
  if ($189) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $190 = ((($1)) + 20|0);
  $191 = +HEAPF32[$190>>2];
  $192 = $191;
  $193 = $182 > $192;
  if ($193) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $194 = $182 < $188;
  if ($194) {
   $195 = $188 - $182;
   $196 = ((($0)) + 160|0);
   $197 = +HEAPF64[$196>>3];
   $198 = $195 * $197;
   $199 = ((($0)) + 168|0);
   $200 = +HEAPF64[$199>>3];
   $201 = $195 * $200;
   $202 = ((($0)) + 176|0);
   $203 = +HEAPF64[$202>>3];
   $204 = $195 * $203;
   $205 = $198 + $206;
   $207 = $201 + $208;
   $209 = $182 + $204;
   HEAPF64[$2>>3] = $205;
   HEAPF64[$96>>3] = $207;
   HEAPF64[$181>>3] = $209;
   $212 = $209;$223 = $205;$225 = $207;
  } else {
   $212 = $182;$223 = $206;$225 = $208;
  }
  $210 = $184 > $192;
  if ($210) {
   $211 = $192 - $212;
   $213 = ((($0)) + 160|0);
   $214 = +HEAPF64[$213>>3];
   $215 = $214 * $211;
   $216 = ((($0)) + 168|0);
   $217 = +HEAPF64[$216>>3];
   $218 = $211 * $217;
   $219 = ((($0)) + 176|0);
   $220 = +HEAPF64[$219>>3];
   $221 = $211 * $220;
   $222 = $215 + $223;
   $224 = $218 + $225;
   $226 = $212 + $221;
   HEAPF64[$8>>3] = $222;
   HEAPF64[$98>>3] = $224;
   HEAPF64[$183>>3] = $226;
  }
 }
 $260 = ((($0)) + 64|0);
 $261 = HEAP32[$260>>2]|0;
 $262 = ($5|0)==($261|0);
 if ($262) {
  __ZNSt3__26vectorINS_4pairIN3osg5Vec3dES3_EENS_9allocatorIS4_EEE21__push_back_slow_pathIKS4_EEvRT_($3,$2);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 } else {
  dest=$5; src=$2; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  $263 = HEAP32[$4>>2]|0;
  $264 = ((($263)) + 48|0);
  HEAP32[$4>>2] = $264;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 return (0)|0;
}
function __ZNSt3__26vectorINS_4pairIN3osg5Vec3dES3_EENS_9allocatorIS4_EEE21__push_back_slow_pathIKS4_EEvRT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0;
 var sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = (($5|0) / 48)&-1;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(89478485);
 if ($8) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $9 = ((($0)) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) - ($4))|0;
 $12 = (($11|0) / 48)&-1;
 $13 = ($12>>>0)<(44739242);
 $14 = $12 << 1;
 $15 = ($14>>>0)<($7>>>0);
 $$sroa$speculated$i = $15 ? $7 : $14;
 $$sroa$speculated$$i = $13 ? $$sroa$speculated$i : 89478485;
 $16 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($16) {
   $26 = 0;
  } else {
   $17 = ($$sroa$speculated$$i>>>0)>(89478485);
   if (!($17)) {
    $23 = ($$sroa$speculated$$i*48)|0;
    $24 = (__Znwj($23)|0);
    $26 = $24;
    break;
   }
   $18 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($18|0),(204840|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if ($20) {
    $21 = ___cxa_find_matching_catch_2()|0;
    $22 = tempRet0;
    ___cxa_free_exception(($18|0));
    ___resumeException($21|0);
    // unreachable;
   } else {
    HEAP32[$18>>2] = (99824);
    ___cxa_throw(($18|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $25 = (($26) + (($6*48)|0)|0);
 $27 = (($26) + (($$sroa$speculated$$i*48)|0)|0);
 $28 = $27;
 dest=$25; src=$1; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $29 = ((($25)) + 48|0);
 $30 = $29;
 $31 = (($5|0) / -48)&-1;
 $32 = (($25) + (($31*48)|0)|0);
 $33 = $32;
 $34 = ($5|0)>(0);
 if ($34) {
  $35 = $4;
  _memcpy(($32|0),($35|0),($5|0))|0;
 }
 HEAP32[$0>>2] = $33;
 HEAP32[$2>>2] = $30;
 HEAP32[$9>>2] = $28;
 $36 = ($4|0)==(0);
 if ($36) {
  return;
 }
 $37 = $4;
 __ZdlPv($37);
 return;
}
function __ZN3osg24TemplatePrimitiveFunctorIN27LineSegmentIntersectorUtils16IntersectFunctorINS_5Vec3dEdEEED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i = 0, $scevgep5$i$i$i$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 64|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = ((($0)) + 68|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==($2|0);
  if (!($6)) {
   $scevgep$i$i$i$i = ((($5)) + -48|0);
   $7 = $scevgep$i$i$i$i;
   $8 = $2;
   $9 = (($7) - ($8))|0;
   $10 = (($9>>>0) / 48)&-1;
   $11 = $10 ^ -1;
   $scevgep5$i$i$i$i = (($5) + (($11*48)|0)|0);
   HEAP32[$4>>2] = $scevgep5$i$i$i$i;
  }
  __ZdlPv($2);
 }
 $12 = ((($0)) + 8|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  HEAP32[$12>>2] = 0;
  return;
 }
 $15 = ((($13)) + 8|0);
 $16 = HEAP32[$15>>2]|0;HEAP32[$15>>2] = (($16-1)|0);
 $17 = ($16|0)==(1);
 if (!($17)) {
  HEAP32[$12>>2] = 0;
  return;
 }
 __ZNK3osg10Referenced24signalObserversAndDeleteEbb($13,1,1);
 HEAP32[$12>>2] = 0;
 return;
}
function __ZN3osg24TemplatePrimitiveFunctorIN27LineSegmentIntersectorUtils16IntersectFunctorINS_5Vec3dEdEEED0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $scevgep$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 64|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = ((($0)) + 68|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==($2|0);
  if (!($6)) {
   $scevgep$i$i$i$i$i = ((($5)) + -48|0);
   $7 = $scevgep$i$i$i$i$i;
   $8 = $2;
   $9 = (($7) - ($8))|0;
   $10 = (($9>>>0) / 48)&-1;
   $11 = $10 ^ -1;
   $scevgep5$i$i$i$i$i = (($5) + (($11*48)|0)|0);
   HEAP32[$4>>2] = $scevgep5$i$i$i$i$i;
  }
  __ZdlPv($2);
 }
 $12 = ((($0)) + 8|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  __ZdlPv($0);
  return;
 }
 $15 = ((($13)) + 8|0);
 $16 = HEAP32[$15>>2]|0;HEAP32[$15>>2] = (($16-1)|0);
 $17 = ($16|0)==(1);
 if (!($17)) {
  __ZdlPv($0);
  return;
 }
 __THREW__ = 0;
 invoke_viii(3262,($13|0),1,1);
 $18 = __THREW__; __THREW__ = 0;
 $19 = $18&1;
 if ($19) {
  $20 = ___cxa_find_matching_catch_2()|0;
  $21 = tempRet0;
  __ZdlPv($0);
  ___resumeException($20|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZN3osg24TemplatePrimitiveFunctorIN27LineSegmentIntersectorUtils16IntersectFunctorINS_5Vec3dEdEEE14setVertexArrayEjPKNS_5Vec2fE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
 $5 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($4,115521,53)|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($6)) + -12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($5) + ($8)|0);
 __ZNKSt3__28ios_base6getlocEv($3,$9);
 __THREW__ = 0;
 $10 = (invoke_iii(3255,($3|0),(215188|0))|0);
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if (!($12)) {
  $13 = HEAP32[$10>>2]|0;
  $14 = ((($13)) + 28|0);
  $15 = HEAP32[$14>>2]|0;
  __THREW__ = 0;
  $16 = (invoke_iii($15|0,($10|0),10)|0);
  $17 = __THREW__; __THREW__ = 0;
  $18 = $17&1;
  if (!($18)) {
   __ZNSt3__26localeD2Ev($3);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($5,$16)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($5)|0);
   STACKTOP = sp;return;
  }
 }
 $19 = ___cxa_find_matching_catch_2()|0;
 $20 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($3|0));
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if ($22) {
  $23 = ___cxa_find_matching_catch_3(0|0)|0;
  $24 = tempRet0;
  ___clang_call_terminate($23);
  // unreachable;
 } else {
  ___resumeException($19|0);
  // unreachable;
 }
}
function __ZN3osg24TemplatePrimitiveFunctorIN27LineSegmentIntersectorUtils16IntersectFunctorINS_5Vec3dEdEEE14setVertexArrayEjPKNS_5Vec3fE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 196|0);
 HEAP32[$3>>2] = $1;
 $4 = ((($0)) + 200|0);
 HEAP32[$4>>2] = $2;
 return;
}
function __ZN3osg24TemplatePrimitiveFunctorIN27LineSegmentIntersectorUtils16IntersectFunctorINS_5Vec3dEdEEE14setVertexArrayEjPKNS_5Vec4fE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
 $5 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($4,115467,53)|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($6)) + -12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($5) + ($8)|0);
 __ZNKSt3__28ios_base6getlocEv($3,$9);
 __THREW__ = 0;
 $10 = (invoke_iii(3255,($3|0),(215188|0))|0);
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if (!($12)) {
  $13 = HEAP32[$10>>2]|0;
  $14 = ((($13)) + 28|0);
  $15 = HEAP32[$14>>2]|0;
  __THREW__ = 0;
  $16 = (invoke_iii($15|0,($10|0),10)|0);
  $17 = __THREW__; __THREW__ = 0;
  $18 = $17&1;
  if (!($18)) {
   __ZNSt3__26localeD2Ev($3);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($5,$16)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($5)|0);
   STACKTOP = sp;return;
  }
 }
 $19 = ___cxa_find_matching_catch_2()|0;
 $20 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($3|0));
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if ($22) {
  $23 = ___cxa_find_matching_catch_3(0|0)|0;
  $24 = tempRet0;
  ___clang_call_terminate($23);
  // unreachable;
 } else {
  ___resumeException($19|0);
  // unreachable;
 }
}
function __ZN3osg24TemplatePrimitiveFunctorIN27LineSegmentIntersectorUtils16IntersectFunctorINS_5Vec3dEdEEE14setVertexArrayEjPKNS_5Vec2dE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
 $5 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($4,115412,54)|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($6)) + -12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($5) + ($8)|0);
 __ZNKSt3__28ios_base6getlocEv($3,$9);
 __THREW__ = 0;
 $10 = (invoke_iii(3255,($3|0),(215188|0))|0);
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if (!($12)) {
  $13 = HEAP32[$10>>2]|0;
  $14 = ((($13)) + 28|0);
  $15 = HEAP32[$14>>2]|0;
  __THREW__ = 0;
  $16 = (invoke_iii($15|0,($10|0),10)|0);
  $17 = __THREW__; __THREW__ = 0;
  $18 = $17&1;
  if (!($18)) {
   __ZNSt3__26localeD2Ev($3);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($5,$16)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($5)|0);
   STACKTOP = sp;return;
  }
 }
 $19 = ___cxa_find_matching_catch_2()|0;
 $20 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($3|0));
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if ($22) {
  $23 = ___cxa_find_matching_catch_3(0|0)|0;
  $24 = tempRet0;
  ___clang_call_terminate($23);
  // unreachable;
 } else {
  ___resumeException($19|0);
  // unreachable;
 }
}
function __ZN3osg24TemplatePrimitiveFunctorIN27LineSegmentIntersectorUtils16IntersectFunctorINS_5Vec3dEdEEE14setVertexArrayEjPKS3_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
 $5 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($4,115357,54)|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($6)) + -12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($5) + ($8)|0);
 __ZNKSt3__28ios_base6getlocEv($3,$9);
 __THREW__ = 0;
 $10 = (invoke_iii(3255,($3|0),(215188|0))|0);
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if (!($12)) {
  $13 = HEAP32[$10>>2]|0;
  $14 = ((($13)) + 28|0);
  $15 = HEAP32[$14>>2]|0;
  __THREW__ = 0;
  $16 = (invoke_iii($15|0,($10|0),10)|0);
  $17 = __THREW__; __THREW__ = 0;
  $18 = $17&1;
  if (!($18)) {
   __ZNSt3__26localeD2Ev($3);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($5,$16)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($5)|0);
   STACKTOP = sp;return;
  }
 }
 $19 = ___cxa_find_matching_catch_2()|0;
 $20 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($3|0));
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if ($22) {
  $23 = ___cxa_find_matching_catch_3(0|0)|0;
  $24 = tempRet0;
  ___clang_call_terminate($23);
  // unreachable;
 } else {
  ___resumeException($19|0);
  // unreachable;
 }
}
function __ZN3osg24TemplatePrimitiveFunctorIN27LineSegmentIntersectorUtils16IntersectFunctorINS_5Vec3dEdEEE14setVertexArrayEjPKNS_5Vec4dE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
 $5 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($4,115302,54)|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($6)) + -12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($5) + ($8)|0);
 __ZNKSt3__28ios_base6getlocEv($3,$9);
 __THREW__ = 0;
 $10 = (invoke_iii(3255,($3|0),(215188|0))|0);
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if (!($12)) {
  $13 = HEAP32[$10>>2]|0;
  $14 = ((($13)) + 28|0);
  $15 = HEAP32[$14>>2]|0;
  __THREW__ = 0;
  $16 = (invoke_iii($15|0,($10|0),10)|0);
  $17 = __THREW__; __THREW__ = 0;
  $18 = $17&1;
  if (!($18)) {
   __ZNSt3__26localeD2Ev($3);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($5,$16)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($5)|0);
   STACKTOP = sp;return;
  }
 }
 $19 = ___cxa_find_matching_catch_2()|0;
 $20 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($3|0));
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if ($22) {
  $23 = ___cxa_find_matching_catch_3(0|0)|0;
  $24 = tempRet0;
  ___clang_call_terminate($23);
  // unreachable;
 } else {
  ___resumeException($19|0);
  // unreachable;
 }
}
function __ZN3osg24TemplatePrimitiveFunctorIN27LineSegmentIntersectorUtils16IntersectFunctorINS_5Vec3dEdEEE10drawArraysEjii($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0131154 = 0, $$0133156 = 0, $$0135155 = 0, $$0137159 = 0, $$0139158 = 0, $$0140165 = 0, $$0141164 = 0, $$0142162 = 0, $$0143161 = 0, $$pre$phiZ2D = 0, $$promoted = 0, $$promoted171 = 0, $$promoted175 = 0, $$promoted179 = 0, $$promoted183 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0;
 var $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0;
 var $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0;
 var $exitcond193 = 0, $or$cond = 0, $scevgep = 0, $scevgep194 = 0, $scevgep197 = 0, $scevgep199 = 0, $scevgep203 = 0, $scevgep205 = 0, $scevgep209 = 0, $scevgep211 = 0, $scevgep215 = 0, $scevgep217 = 0, $uglygep = 0, $uglygep196 = 0, $uglygep201 = 0, $uglygep201202 = 0, $uglygep207 = 0, $uglygep207208 = 0, $uglygep213 = 0, $uglygep213214 = 0;
 var $uglygep219 = 0, $uglygep219220 = 0, $umax = 0, $umax198 = 0, $umax204 = 0, $umax210 = 0, $umax216 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ((($0)) + 200|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5;
 $7 = ($5|0)==(0|0);
 $8 = ($3|0)==(0);
 $or$cond = $8 | $7;
 if ($or$cond) {
  return;
 }
 do {
  switch ($1|0) {
  case 4:  {
   $9 = (($3) + ($2))|0;
   $10 = (($5) + (($9*12)|0)|0);
   $11 = ($3|0)>(0);
   if (!($11)) {
    return;
   }
   $12 = (($5) + (($2*12)|0)|0);
   $13 = ((($0)) + 8|0);
   $14 = ((($0)) + 12|0);
   $$0131154 = $12;
   while(1) {
    $15 = ((($$0131154)) + 12|0);
    $16 = ((($$0131154)) + 24|0);
    __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3dEdE9intersectERKNS1_5Vec3fES6_S6_($13,$$0131154,$15,$16);
    $17 = HEAP32[$14>>2]|0;
    $18 = (($17) + 1)|0;
    HEAP32[$14>>2] = $18;
    $19 = ((($$0131154)) + 36|0);
    $20 = ($19>>>0)<($10>>>0);
    if ($20) {
     $$0131154 = $19;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 5:  {
   $21 = ($3|0)>(2);
   if (!($21)) {
    return;
   }
   $22 = (($5) + (($2*12)|0)|0);
   $23 = ((($0)) + 8|0);
   $24 = ((($0)) + 12|0);
   $$0133156 = $22;$$0135155 = 2;
   while(1) {
    $25 = $$0135155 & 1;
    $26 = ($25|0)==(0);
    if ($26) {
     $29 = ((($$0133156)) + 12|0);
     $30 = ((($$0133156)) + 24|0);
     __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3dEdE9intersectERKNS1_5Vec3fES6_S6_($23,$$0133156,$29,$30);
     $$pre$phiZ2D = $29;
    } else {
     $27 = ((($$0133156)) + 24|0);
     $28 = ((($$0133156)) + 12|0);
     __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3dEdE9intersectERKNS1_5Vec3fES6_S6_($23,$$0133156,$27,$28);
     $$pre$phiZ2D = $28;
    }
    $31 = HEAP32[$24>>2]|0;
    $32 = (($31) + 1)|0;
    HEAP32[$24>>2] = $32;
    $33 = (($$0135155) + 1)|0;
    $exitcond = ($33|0)==($3|0);
    if ($exitcond) {
     break;
    } else {
     $$0133156 = $$pre$phiZ2D;$$0135155 = $33;
    }
   }
   return;
   break;
  }
  case 7:  {
   $34 = ($3|0)>(3);
   if (!($34)) {
    return;
   }
   $35 = (($5) + (($2*12)|0)|0);
   $36 = ((($0)) + 8|0);
   $37 = ((($0)) + 12|0);
   $$0137159 = $35;$$0139158 = 3;
   while(1) {
    $38 = ((($$0137159)) + 12|0);
    $39 = ((($$0137159)) + 24|0);
    $40 = ((($$0137159)) + 36|0);
    __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3dEdE9intersectERKNS1_5Vec3fES6_S6_($36,$$0137159,$38,$40);
    __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3dEdE9intersectERKNS1_5Vec3fES6_S6_($36,$38,$39,$40);
    $41 = HEAP32[$37>>2]|0;
    $42 = (($41) + 1)|0;
    HEAP32[$37>>2] = $42;
    $43 = (($$0139158) + 4)|0;
    $44 = ((($$0137159)) + 48|0);
    $45 = ($43|0)<($3|0);
    if ($45) {
     $$0137159 = $44;$$0139158 = $43;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 8:  {
   $46 = ($3|0)>(3);
   if (!($46)) {
    return;
   }
   $47 = (($5) + (($2*12)|0)|0);
   $48 = ((($0)) + 8|0);
   $49 = ((($0)) + 12|0);
   $$0142162 = $47;$$0143161 = 3;
   while(1) {
    $50 = ((($$0142162)) + 12|0);
    $51 = ((($$0142162)) + 36|0);
    $52 = ((($$0142162)) + 24|0);
    __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3dEdE9intersectERKNS1_5Vec3fES6_S6_($48,$$0142162,$50,$52);
    __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3dEdE9intersectERKNS1_5Vec3fES6_S6_($48,$50,$51,$52);
    $53 = HEAP32[$49>>2]|0;
    $54 = (($53) + 1)|0;
    HEAP32[$49>>2] = $54;
    $55 = (($$0143161) + 2)|0;
    $56 = ($55|0)<($3|0);
    if ($56) {
     $$0142162 = $52;$$0143161 = $55;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 6: case 9:  {
   $57 = (($5) + (($2*12)|0)|0);
   $58 = ($3|0)>(2);
   if (!($58)) {
    return;
   }
   $59 = ((($57)) + 12|0);
   $60 = ((($0)) + 8|0);
   $61 = ((($0)) + 12|0);
   $$0140165 = 2;$$0141164 = $59;
   while(1) {
    $62 = ((($$0141164)) + 12|0);
    __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3dEdE9intersectERKNS1_5Vec3fES6_S6_($60,$57,$$0141164,$62);
    $63 = HEAP32[$61>>2]|0;
    $64 = (($63) + 1)|0;
    HEAP32[$61>>2] = $64;
    $65 = (($$0140165) + 1)|0;
    $exitcond193 = ($65|0)==($3|0);
    if ($exitcond193) {
     break;
    } else {
     $$0140165 = $65;$$0141164 = $62;
    }
   }
   return;
   break;
  }
  case 0:  {
   $66 = (($3) + ($2))|0;
   $67 = (($5) + (($66*12)|0)|0);
   $68 = ($3|0)>(0);
   if (!($68)) {
    return;
   }
   $69 = ((($0)) + 12|0);
   $$promoted = HEAP32[$69>>2]|0;
   $70 = (($2) + 1)|0;
   $scevgep = (($5) + (($70*12)|0)|0);
   $71 = ($scevgep>>>0)>($67>>>0);
   $umax = $71 ? $scevgep : $67;
   $72 = (0 - ($2))|0;
   $scevgep194 = (($umax) + (($72*12)|0)|0);
   $73 = $6 ^ -1;
   $uglygep = (($scevgep194) + ($73)|0);
   $uglygep196 = $uglygep;
   $74 = (($uglygep196>>>0) / 12)&-1;
   $75 = (($$promoted) + ($74))|0;
   $76 = (($75) + 1)|0;
   HEAP32[$69>>2] = $76;
   return;
   break;
  }
  case 1:  {
   $77 = (($2) + -1)|0;
   $78 = (($77) + ($3))|0;
   $79 = (($5) + (($78*12)|0)|0);
   $80 = ($78|0)>($2|0);
   if (!($80)) {
    return;
   }
   $81 = ((($0)) + 12|0);
   $$promoted171 = HEAP32[$81>>2]|0;
   $82 = (($2) + 2)|0;
   $scevgep197 = (($5) + (($82*12)|0)|0);
   $83 = ($79>>>0)>($scevgep197>>>0);
   $umax198 = $83 ? $79 : $scevgep197;
   $84 = (0 - ($2))|0;
   $scevgep199 = (($umax198) + (($84*12)|0)|0);
   $85 = $6 ^ -1;
   $uglygep201 = (($scevgep199) + ($85)|0);
   $uglygep201202 = $uglygep201;
   $86 = (($uglygep201202>>>0) / 24)&-1;
   $87 = (($$promoted171) + ($86))|0;
   $88 = (($87) + 1)|0;
   HEAP32[$81>>2] = $88;
   return;
   break;
  }
  case 3:  {
   $89 = (($2) + -1)|0;
   $90 = (($89) + ($3))|0;
   $91 = (($5) + (($90*12)|0)|0);
   $92 = ($90|0)>($2|0);
   if (!($92)) {
    return;
   }
   $93 = ((($0)) + 12|0);
   $$promoted175 = HEAP32[$93>>2]|0;
   $94 = (($2) + 1)|0;
   $scevgep203 = (($5) + (($94*12)|0)|0);
   $95 = ($91>>>0)>($scevgep203>>>0);
   $umax204 = $95 ? $91 : $scevgep203;
   $96 = (0 - ($2))|0;
   $scevgep205 = (($umax204) + (($96*12)|0)|0);
   $97 = $6 ^ -1;
   $uglygep207 = (($scevgep205) + ($97)|0);
   $uglygep207208 = $uglygep207;
   $98 = (($uglygep207208>>>0) / 12)&-1;
   $99 = (($$promoted175) + ($98))|0;
   $100 = (($99) + 1)|0;
   HEAP32[$93>>2] = $100;
   return;
   break;
  }
  case 11:  {
   $101 = (($2) + -2)|0;
   $102 = (($101) + ($3))|0;
   $103 = (($5) + (($102*12)|0)|0);
   $104 = (($2) + 1)|0;
   $105 = ($104|0)<($102|0);
   if (!($105)) {
    return;
   }
   $106 = ((($0)) + 12|0);
   $$promoted179 = HEAP32[$106>>2]|0;
   $107 = (($2) + 2)|0;
   $scevgep209 = (($5) + (($107*12)|0)|0);
   $108 = ($103>>>0)>($scevgep209>>>0);
   $umax210 = $108 ? $103 : $scevgep209;
   $109 = $2 ^ -1;
   $scevgep211 = (($umax210) + (($109*12)|0)|0);
   $110 = $6 ^ -1;
   $uglygep213 = (($scevgep211) + ($110)|0);
   $uglygep213214 = $uglygep213;
   $111 = (($uglygep213214>>>0) / 12)&-1;
   $112 = (($$promoted179) + ($111))|0;
   $113 = (($112) + 1)|0;
   HEAP32[$106>>2] = $113;
   return;
   break;
  }
  case 2:  {
   $114 = (($2) + -1)|0;
   $115 = (($114) + ($3))|0;
   $116 = (($5) + (($115*12)|0)|0);
   $117 = ($115|0)>($2|0);
   $118 = ((($0)) + 12|0);
   $$promoted183 = HEAP32[$118>>2]|0;
   if ($117) {
    $119 = (($2) + 1)|0;
    $scevgep215 = (($5) + (($119*12)|0)|0);
    $120 = ($116>>>0)>($scevgep215>>>0);
    $umax216 = $120 ? $116 : $scevgep215;
    $121 = (0 - ($2))|0;
    $scevgep217 = (($umax216) + (($121*12)|0)|0);
    $122 = $6 ^ -1;
    $uglygep219 = (($scevgep217) + ($122)|0);
    $uglygep219220 = $uglygep219;
    $123 = (($uglygep219220>>>0) / 12)&-1;
    $124 = (($$promoted183) + ($123))|0;
    $125 = (($124) + 1)|0;
    HEAP32[$118>>2] = $125;
    $127 = $125;
   } else {
    $127 = $$promoted183;
   }
   $126 = (($127) + 1)|0;
   HEAP32[$118>>2] = $126;
   return;
   break;
  }
  default: {
   return;
  }
  }
 } while(0);
}
function __ZN3osg24TemplatePrimitiveFunctorIN27LineSegmentIntersectorUtils16IntersectFunctorINS_5Vec3dEdEEE12drawElementsEjiPKh($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg24TemplatePrimitiveFunctorIN27LineSegmentIntersectorUtils16IntersectFunctorINS_5Vec3dEdEEE20drawElementsTemplateIhEEvjiPKT_($0,$1,$2,$3);
 return;
}
function __ZN3osg24TemplatePrimitiveFunctorIN27LineSegmentIntersectorUtils16IntersectFunctorINS_5Vec3dEdEEE12drawElementsEjiPKt($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg24TemplatePrimitiveFunctorIN27LineSegmentIntersectorUtils16IntersectFunctorINS_5Vec3dEdEEE20drawElementsTemplateItEEvjiPKT_($0,$1,$2,$3);
 return;
}
function __ZN3osg24TemplatePrimitiveFunctorIN27LineSegmentIntersectorUtils16IntersectFunctorINS_5Vec3dEdEEE12drawElementsEjiPKj($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg24TemplatePrimitiveFunctorIN27LineSegmentIntersectorUtils16IntersectFunctorINS_5Vec3dEdEEE20drawElementsTemplateIjEEvjiPKT_($0,$1,$2,$3);
 return;
}
function __ZN3osg24TemplatePrimitiveFunctorIN27LineSegmentIntersectorUtils16IntersectFunctorINS_5Vec3dEdEEE20drawElementsTemplateIjEEvjiPKT_($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0133158 = 0, $$0135160 = 0, $$0137159 = 0, $$0139163 = 0, $$0141162 = 0, $$0143166 = 0, $$0145165 = 0, $$pre223 = 0, $$promoted = 0, $$promoted175 = 0, $$promoted179 = 0, $$promoted184 = 0, $$promoted188 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $exitcond198 = 0, $exitcond198232 = 0, $or$cond = 0, $scevgep = 0, $scevgep201 = 0, $scevgep206 = 0, $scevgep211 = 0, $scevgep213 = 0, $scevgep217 = 0, $uglygep = 0, $uglygep200 = 0, $uglygep204 = 0, $uglygep204205 = 0;
 var $uglygep209 = 0, $uglygep209210 = 0, $uglygep215 = 0, $uglygep215216 = 0, $uglygep220 = 0, $uglygep220221 = 0, $umax = 0, $umax202 = 0, $umax207 = 0, $umax212 = 0, $umax218 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = $3;
 $5 = ($3|0)==(0|0);
 $6 = ($2|0)==(0);
 $or$cond = $6 | $5;
 if ($or$cond) {
  return;
 }
 do {
  switch ($1|0) {
  case 4:  {
   $19 = (($3) + ($2<<2)|0);
   $20 = ($2|0)>(0);
   if (!($20)) {
    return;
   }
   $21 = ((($0)) + 8|0);
   $22 = ((($0)) + 200|0);
   $23 = ((($0)) + 12|0);
   $$0133158 = $3;
   while(1) {
    $24 = HEAP32[$22>>2]|0;
    $25 = HEAP32[$$0133158>>2]|0;
    $26 = (($24) + (($25*12)|0)|0);
    $27 = ((($$0133158)) + 4|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = (($24) + (($28*12)|0)|0);
    $30 = ((($$0133158)) + 8|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = (($24) + (($31*12)|0)|0);
    __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3dEdE9intersectERKNS1_5Vec3fES6_S6_($21,$26,$29,$32);
    $33 = HEAP32[$23>>2]|0;
    $34 = (($33) + 1)|0;
    HEAP32[$23>>2] = $34;
    $35 = ((($$0133158)) + 12|0);
    $36 = ($35>>>0)<($19>>>0);
    if ($36) {
     $$0133158 = $35;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 5:  {
   $15 = ($2|0)>(2);
   if (!($15)) {
    return;
   }
   $16 = ((($0)) + 8|0);
   $17 = ((($0)) + 200|0);
   $18 = ((($0)) + 12|0);
   $$0135160 = $3;$$0137159 = 2;
   while(1) {
    $37 = $$0137159 & 1;
    $38 = ($37|0)==(0);
    $39 = HEAP32[$17>>2]|0;
    $40 = HEAP32[$$0135160>>2]|0;
    $41 = (($39) + (($40*12)|0)|0);
    $42 = ((($$0135160)) + 4|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = ((($$0135160)) + 8|0);
    $45 = HEAP32[$44>>2]|0;
    if ($38) {
     $48 = (($39) + (($43*12)|0)|0);
     $49 = (($39) + (($45*12)|0)|0);
     __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3dEdE9intersectERKNS1_5Vec3fES6_S6_($16,$41,$48,$49);
    } else {
     $46 = (($39) + (($45*12)|0)|0);
     $47 = (($39) + (($43*12)|0)|0);
     __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3dEdE9intersectERKNS1_5Vec3fES6_S6_($16,$41,$46,$47);
    }
    $50 = HEAP32[$18>>2]|0;
    $51 = (($50) + 1)|0;
    HEAP32[$18>>2] = $51;
    $52 = (($$0137159) + 1)|0;
    $exitcond = ($52|0)==($2|0);
    if ($exitcond) {
     break;
    } else {
     $$0135160 = $42;$$0137159 = $52;
    }
   }
   return;
   break;
  }
  case 7:  {
   $11 = ($2|0)>(3);
   if (!($11)) {
    return;
   }
   $12 = ((($0)) + 8|0);
   $13 = ((($0)) + 200|0);
   $14 = ((($0)) + 12|0);
   $$0139163 = $3;$$0141162 = 3;
   while(1) {
    $53 = HEAP32[$13>>2]|0;
    $54 = HEAP32[$$0139163>>2]|0;
    $55 = (($53) + (($54*12)|0)|0);
    $56 = ((($$0139163)) + 4|0);
    $57 = HEAP32[$56>>2]|0;
    $58 = (($53) + (($57*12)|0)|0);
    $59 = ((($$0139163)) + 8|0);
    $60 = HEAP32[$59>>2]|0;
    $61 = (($53) + (($60*12)|0)|0);
    $62 = ((($$0139163)) + 12|0);
    $63 = HEAP32[$62>>2]|0;
    $64 = (($53) + (($63*12)|0)|0);
    __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3dEdE9intersectERKNS1_5Vec3fES6_S6_($12,$55,$58,$64);
    __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3dEdE9intersectERKNS1_5Vec3fES6_S6_($12,$58,$61,$64);
    $65 = HEAP32[$14>>2]|0;
    $66 = (($65) + 1)|0;
    HEAP32[$14>>2] = $66;
    $67 = (($$0141162) + 4)|0;
    $68 = ((($$0139163)) + 16|0);
    $69 = ($67|0)<($2|0);
    if ($69) {
     $$0139163 = $68;$$0141162 = $67;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 8:  {
   $7 = ($2|0)>(3);
   if (!($7)) {
    return;
   }
   $8 = ((($0)) + 8|0);
   $9 = ((($0)) + 200|0);
   $10 = ((($0)) + 12|0);
   $$0143166 = $3;$$0145165 = 3;
   while(1) {
    $70 = HEAP32[$9>>2]|0;
    $71 = HEAP32[$$0143166>>2]|0;
    $72 = (($70) + (($71*12)|0)|0);
    $73 = ((($$0143166)) + 4|0);
    $74 = HEAP32[$73>>2]|0;
    $75 = (($70) + (($74*12)|0)|0);
    $76 = ((($$0143166)) + 12|0);
    $77 = HEAP32[$76>>2]|0;
    $78 = (($70) + (($77*12)|0)|0);
    $79 = ((($$0143166)) + 8|0);
    $80 = HEAP32[$79>>2]|0;
    $81 = (($70) + (($80*12)|0)|0);
    __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3dEdE9intersectERKNS1_5Vec3fES6_S6_($8,$72,$75,$81);
    __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3dEdE9intersectERKNS1_5Vec3fES6_S6_($8,$75,$78,$81);
    $82 = HEAP32[$10>>2]|0;
    $83 = (($82) + 1)|0;
    HEAP32[$10>>2] = $83;
    $84 = (($$0145165) + 2)|0;
    $85 = ($84|0)<($2|0);
    if ($85) {
     $$0143166 = $79;$$0145165 = $84;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 6: case 9:  {
   $86 = ((($0)) + 200|0);
   $87 = HEAP32[$86>>2]|0;
   $88 = HEAP32[$3>>2]|0;
   $89 = (($87) + (($88*12)|0)|0);
   $90 = ($2|0)>(2);
   if (!($90)) {
    return;
   }
   $91 = ((($3)) + 4|0);
   $92 = ((($0)) + 8|0);
   $93 = ((($0)) + 12|0);
   $94 = HEAP32[$91>>2]|0;
   $95 = (($87) + (($94*12)|0)|0);
   $96 = ((($3)) + 8|0);
   $97 = HEAP32[$96>>2]|0;
   $98 = (($87) + (($97*12)|0)|0);
   __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3dEdE9intersectERKNS1_5Vec3fES6_S6_($92,$89,$95,$98);
   $99 = HEAP32[$93>>2]|0;
   $100 = (($99) + 1)|0;
   HEAP32[$93>>2] = $100;
   $exitcond198232 = ($2|0)==(3);
   if ($exitcond198232) {
    return;
   } else {
    $102 = $96;$110 = 3;
   }
   while(1) {
    $$pre223 = HEAP32[$86>>2]|0;
    $101 = HEAP32[$102>>2]|0;
    $103 = (($$pre223) + (($101*12)|0)|0);
    $104 = ((($102)) + 4|0);
    $105 = HEAP32[$104>>2]|0;
    $106 = (($$pre223) + (($105*12)|0)|0);
    __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3dEdE9intersectERKNS1_5Vec3fES6_S6_($92,$89,$103,$106);
    $107 = HEAP32[$93>>2]|0;
    $108 = (($107) + 1)|0;
    HEAP32[$93>>2] = $108;
    $109 = (($110) + 1)|0;
    $exitcond198 = ($109|0)==($2|0);
    if ($exitcond198) {
     break;
    } else {
     $102 = $104;$110 = $109;
    }
   }
   return;
   break;
  }
  case 0:  {
   $111 = (($3) + ($2<<2)|0);
   $112 = ($2|0)>(0);
   if (!($112)) {
    return;
   }
   $113 = ((($0)) + 12|0);
   $$promoted = HEAP32[$113>>2]|0;
   $scevgep = ((($3)) + 4|0);
   $114 = ($111>>>0)>($scevgep>>>0);
   $umax = $114 ? $111 : $scevgep;
   $115 = $4 ^ -1;
   $uglygep = (($umax) + ($115)|0);
   $uglygep200 = $uglygep;
   $116 = $uglygep200 >>> 2;
   $117 = (($$promoted) + ($116))|0;
   $118 = (($117) + 1)|0;
   HEAP32[$113>>2] = $118;
   return;
   break;
  }
  case 1:  {
   $119 = (($2) + -1)|0;
   $120 = (($3) + ($119<<2)|0);
   $121 = ($2|0)>(1);
   if (!($121)) {
    return;
   }
   $122 = ((($0)) + 12|0);
   $$promoted175 = HEAP32[$122>>2]|0;
   $scevgep201 = ((($3)) + 8|0);
   $123 = ($120>>>0)>($scevgep201>>>0);
   $umax202 = $123 ? $120 : $scevgep201;
   $124 = $4 ^ -1;
   $uglygep204 = (($umax202) + ($124)|0);
   $uglygep204205 = $uglygep204;
   $125 = $uglygep204205 >>> 3;
   $126 = (($$promoted175) + ($125))|0;
   $127 = (($126) + 1)|0;
   HEAP32[$122>>2] = $127;
   return;
   break;
  }
  case 3:  {
   $128 = (($2) + -1)|0;
   $129 = (($3) + ($128<<2)|0);
   $130 = ($2|0)>(1);
   if (!($130)) {
    return;
   }
   $131 = ((($0)) + 12|0);
   $$promoted179 = HEAP32[$131>>2]|0;
   $scevgep206 = ((($3)) + 4|0);
   $132 = ($129>>>0)>($scevgep206>>>0);
   $umax207 = $132 ? $129 : $scevgep206;
   $133 = $4 ^ -1;
   $uglygep209 = (($umax207) + ($133)|0);
   $uglygep209210 = $uglygep209;
   $134 = $uglygep209210 >>> 2;
   $135 = (($$promoted179) + ($134))|0;
   $136 = (($135) + 1)|0;
   HEAP32[$131>>2] = $136;
   return;
   break;
  }
  case 11:  {
   $137 = (($2) + -2)|0;
   $138 = (($3) + ($137<<2)|0);
   $139 = ($137|0)>(1);
   if (!($139)) {
    return;
   }
   $140 = ((($0)) + 12|0);
   $$promoted184 = HEAP32[$140>>2]|0;
   $scevgep211 = ((($3)) + 8|0);
   $141 = ($138>>>0)>($scevgep211>>>0);
   $umax212 = $141 ? $138 : $scevgep211;
   $scevgep213 = ((($umax212)) + -4|0);
   $142 = $4 ^ -1;
   $uglygep215 = (($scevgep213) + ($142)|0);
   $uglygep215216 = $uglygep215;
   $143 = $uglygep215216 >>> 2;
   $144 = (($$promoted184) + ($143))|0;
   $145 = (($144) + 1)|0;
   HEAP32[$140>>2] = $145;
   return;
   break;
  }
  case 2:  {
   $146 = (($2) + -1)|0;
   $147 = (($3) + ($146<<2)|0);
   $148 = ($2|0)>(1);
   $149 = ((($0)) + 12|0);
   $$promoted188 = HEAP32[$149>>2]|0;
   if ($148) {
    $scevgep217 = ((($3)) + 4|0);
    $150 = ($147>>>0)>($scevgep217>>>0);
    $umax218 = $150 ? $147 : $scevgep217;
    $151 = $4 ^ -1;
    $uglygep220 = (($umax218) + ($151)|0);
    $uglygep220221 = $uglygep220;
    $152 = $uglygep220221 >>> 2;
    $153 = (($$promoted188) + ($152))|0;
    $154 = (($153) + 1)|0;
    HEAP32[$149>>2] = $154;
    $156 = $154;
   } else {
    $156 = $$promoted188;
   }
   $155 = (($156) + 1)|0;
   HEAP32[$149>>2] = $155;
   return;
   break;
  }
  default: {
   return;
  }
  }
 } while(0);
}
function __ZN3osg24TemplatePrimitiveFunctorIN27LineSegmentIntersectorUtils16IntersectFunctorINS_5Vec3dEdEEE20drawElementsTemplateItEEvjiPKT_($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0133158 = 0, $$0135160 = 0, $$0137159 = 0, $$0139163 = 0, $$0141162 = 0, $$0142169 = 0, $$0143166 = 0, $$0144168 = 0, $$0145165 = 0, $$pre223 = 0, $$promoted = 0, $$promoted175 = 0, $$promoted179 = 0, $$promoted184 = 0, $$promoted188 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0;
 var $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0;
 var $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0;
 var $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0;
 var $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $exitcond198 = 0, $or$cond = 0;
 var $scevgep = 0, $scevgep201 = 0, $scevgep206 = 0, $scevgep211 = 0, $scevgep213 = 0, $scevgep217 = 0, $uglygep = 0, $uglygep200 = 0, $uglygep204 = 0, $uglygep204205 = 0, $uglygep209 = 0, $uglygep209210 = 0, $uglygep215 = 0, $uglygep215216 = 0, $uglygep220 = 0, $uglygep220221 = 0, $umax = 0, $umax202 = 0, $umax207 = 0, $umax212 = 0;
 var $umax218 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = $3;
 $5 = ($3|0)==(0|0);
 $6 = ($2|0)==(0);
 $or$cond = $6 | $5;
 if ($or$cond) {
  return;
 }
 do {
  switch ($1|0) {
  case 4:  {
   $19 = (($3) + ($2<<1)|0);
   $20 = ($2|0)>(0);
   if (!($20)) {
    return;
   }
   $21 = ((($0)) + 8|0);
   $22 = ((($0)) + 200|0);
   $23 = ((($0)) + 12|0);
   $$0133158 = $3;
   while(1) {
    $24 = HEAP32[$22>>2]|0;
    $25 = HEAP16[$$0133158>>1]|0;
    $26 = $25&65535;
    $27 = (($24) + (($26*12)|0)|0);
    $28 = ((($$0133158)) + 2|0);
    $29 = HEAP16[$28>>1]|0;
    $30 = $29&65535;
    $31 = (($24) + (($30*12)|0)|0);
    $32 = ((($$0133158)) + 4|0);
    $33 = HEAP16[$32>>1]|0;
    $34 = $33&65535;
    $35 = (($24) + (($34*12)|0)|0);
    __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3dEdE9intersectERKNS1_5Vec3fES6_S6_($21,$27,$31,$35);
    $36 = HEAP32[$23>>2]|0;
    $37 = (($36) + 1)|0;
    HEAP32[$23>>2] = $37;
    $38 = ((($$0133158)) + 6|0);
    $39 = ($38>>>0)<($19>>>0);
    if ($39) {
     $$0133158 = $38;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 5:  {
   $15 = ($2|0)>(2);
   if (!($15)) {
    return;
   }
   $16 = ((($0)) + 8|0);
   $17 = ((($0)) + 200|0);
   $18 = ((($0)) + 12|0);
   $$0135160 = $3;$$0137159 = 2;
   while(1) {
    $40 = $$0137159 & 1;
    $41 = ($40|0)==(0);
    $42 = HEAP32[$17>>2]|0;
    $43 = HEAP16[$$0135160>>1]|0;
    $44 = $43&65535;
    $45 = (($42) + (($44*12)|0)|0);
    $46 = ((($$0135160)) + 2|0);
    $47 = HEAP16[$46>>1]|0;
    $48 = ((($$0135160)) + 4|0);
    $49 = HEAP16[$48>>1]|0;
    $50 = $47&65535;
    $51 = $49&65535;
    if ($41) {
     $54 = (($42) + (($50*12)|0)|0);
     $55 = (($42) + (($51*12)|0)|0);
     __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3dEdE9intersectERKNS1_5Vec3fES6_S6_($16,$45,$54,$55);
    } else {
     $52 = (($42) + (($51*12)|0)|0);
     $53 = (($42) + (($50*12)|0)|0);
     __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3dEdE9intersectERKNS1_5Vec3fES6_S6_($16,$45,$52,$53);
    }
    $56 = HEAP32[$18>>2]|0;
    $57 = (($56) + 1)|0;
    HEAP32[$18>>2] = $57;
    $58 = (($$0137159) + 1)|0;
    $exitcond = ($58|0)==($2|0);
    if ($exitcond) {
     break;
    } else {
     $$0135160 = $46;$$0137159 = $58;
    }
   }
   return;
   break;
  }
  case 7:  {
   $11 = ($2|0)>(3);
   if (!($11)) {
    return;
   }
   $12 = ((($0)) + 8|0);
   $13 = ((($0)) + 200|0);
   $14 = ((($0)) + 12|0);
   $$0139163 = $3;$$0141162 = 3;
   while(1) {
    $59 = HEAP32[$13>>2]|0;
    $60 = HEAP16[$$0139163>>1]|0;
    $61 = $60&65535;
    $62 = (($59) + (($61*12)|0)|0);
    $63 = ((($$0139163)) + 2|0);
    $64 = HEAP16[$63>>1]|0;
    $65 = $64&65535;
    $66 = (($59) + (($65*12)|0)|0);
    $67 = ((($$0139163)) + 4|0);
    $68 = HEAP16[$67>>1]|0;
    $69 = $68&65535;
    $70 = (($59) + (($69*12)|0)|0);
    $71 = ((($$0139163)) + 6|0);
    $72 = HEAP16[$71>>1]|0;
    $73 = $72&65535;
    $74 = (($59) + (($73*12)|0)|0);
    __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3dEdE9intersectERKNS1_5Vec3fES6_S6_($12,$62,$66,$74);
    __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3dEdE9intersectERKNS1_5Vec3fES6_S6_($12,$66,$70,$74);
    $75 = HEAP32[$14>>2]|0;
    $76 = (($75) + 1)|0;
    HEAP32[$14>>2] = $76;
    $77 = (($$0141162) + 4)|0;
    $78 = ((($$0139163)) + 8|0);
    $79 = ($77|0)<($2|0);
    if ($79) {
     $$0139163 = $78;$$0141162 = $77;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 8:  {
   $7 = ($2|0)>(3);
   if (!($7)) {
    return;
   }
   $8 = ((($0)) + 8|0);
   $9 = ((($0)) + 200|0);
   $10 = ((($0)) + 12|0);
   $$0143166 = $3;$$0145165 = 3;
   while(1) {
    $80 = HEAP32[$9>>2]|0;
    $81 = HEAP16[$$0143166>>1]|0;
    $82 = $81&65535;
    $83 = (($80) + (($82*12)|0)|0);
    $84 = ((($$0143166)) + 2|0);
    $85 = HEAP16[$84>>1]|0;
    $86 = $85&65535;
    $87 = (($80) + (($86*12)|0)|0);
    $88 = ((($$0143166)) + 6|0);
    $89 = HEAP16[$88>>1]|0;
    $90 = $89&65535;
    $91 = (($80) + (($90*12)|0)|0);
    $92 = ((($$0143166)) + 4|0);
    $93 = HEAP16[$92>>1]|0;
    $94 = $93&65535;
    $95 = (($80) + (($94*12)|0)|0);
    __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3dEdE9intersectERKNS1_5Vec3fES6_S6_($8,$83,$87,$95);
    __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3dEdE9intersectERKNS1_5Vec3fES6_S6_($8,$87,$91,$95);
    $96 = HEAP32[$10>>2]|0;
    $97 = (($96) + 1)|0;
    HEAP32[$10>>2] = $97;
    $98 = (($$0145165) + 2)|0;
    $99 = ($98|0)<($2|0);
    if ($99) {
     $$0143166 = $92;$$0145165 = $98;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 6: case 9:  {
   $100 = ((($0)) + 200|0);
   $101 = HEAP32[$100>>2]|0;
   $102 = HEAP16[$3>>1]|0;
   $103 = $102&65535;
   $104 = (($101) + (($103*12)|0)|0);
   $105 = ($2|0)>(2);
   if (!($105)) {
    return;
   }
   $106 = ((($3)) + 2|0);
   $107 = ((($0)) + 8|0);
   $108 = ((($0)) + 12|0);
   $$0142169 = 2;$$0144168 = $106;$112 = $101;
   while(1) {
    $109 = HEAP16[$$0144168>>1]|0;
    $110 = $109&65535;
    $111 = (($112) + (($110*12)|0)|0);
    $113 = ((($$0144168)) + 2|0);
    $114 = HEAP16[$113>>1]|0;
    $115 = $114&65535;
    $116 = (($112) + (($115*12)|0)|0);
    __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3dEdE9intersectERKNS1_5Vec3fES6_S6_($107,$104,$111,$116);
    $117 = HEAP32[$108>>2]|0;
    $118 = (($117) + 1)|0;
    HEAP32[$108>>2] = $118;
    $119 = (($$0142169) + 1)|0;
    $exitcond198 = ($119|0)==($2|0);
    if ($exitcond198) {
     break;
    }
    $$pre223 = HEAP32[$100>>2]|0;
    $$0142169 = $119;$$0144168 = $113;$112 = $$pre223;
   }
   return;
   break;
  }
  case 0:  {
   $120 = (($3) + ($2<<1)|0);
   $121 = ($2|0)>(0);
   if (!($121)) {
    return;
   }
   $122 = ((($0)) + 12|0);
   $$promoted = HEAP32[$122>>2]|0;
   $scevgep = ((($3)) + 2|0);
   $123 = ($120>>>0)>($scevgep>>>0);
   $umax = $123 ? $120 : $scevgep;
   $124 = $4 ^ -1;
   $uglygep = (($umax) + ($124)|0);
   $uglygep200 = $uglygep;
   $125 = $uglygep200 >>> 1;
   $126 = (($$promoted) + ($125))|0;
   $127 = (($126) + 1)|0;
   HEAP32[$122>>2] = $127;
   return;
   break;
  }
  case 1:  {
   $128 = (($2) + -1)|0;
   $129 = (($3) + ($128<<1)|0);
   $130 = ($2|0)>(1);
   if (!($130)) {
    return;
   }
   $131 = ((($0)) + 12|0);
   $$promoted175 = HEAP32[$131>>2]|0;
   $scevgep201 = ((($3)) + 4|0);
   $132 = ($129>>>0)>($scevgep201>>>0);
   $umax202 = $132 ? $129 : $scevgep201;
   $133 = $4 ^ -1;
   $uglygep204 = (($umax202) + ($133)|0);
   $uglygep204205 = $uglygep204;
   $134 = $uglygep204205 >>> 2;
   $135 = (($$promoted175) + ($134))|0;
   $136 = (($135) + 1)|0;
   HEAP32[$131>>2] = $136;
   return;
   break;
  }
  case 3:  {
   $137 = (($2) + -1)|0;
   $138 = (($3) + ($137<<1)|0);
   $139 = ($2|0)>(1);
   if (!($139)) {
    return;
   }
   $140 = ((($0)) + 12|0);
   $$promoted179 = HEAP32[$140>>2]|0;
   $scevgep206 = ((($3)) + 2|0);
   $141 = ($138>>>0)>($scevgep206>>>0);
   $umax207 = $141 ? $138 : $scevgep206;
   $142 = $4 ^ -1;
   $uglygep209 = (($umax207) + ($142)|0);
   $uglygep209210 = $uglygep209;
   $143 = $uglygep209210 >>> 1;
   $144 = (($$promoted179) + ($143))|0;
   $145 = (($144) + 1)|0;
   HEAP32[$140>>2] = $145;
   return;
   break;
  }
  case 11:  {
   $146 = (($2) + -2)|0;
   $147 = (($3) + ($146<<1)|0);
   $148 = ($146|0)>(1);
   if (!($148)) {
    return;
   }
   $149 = ((($0)) + 12|0);
   $$promoted184 = HEAP32[$149>>2]|0;
   $scevgep211 = ((($3)) + 4|0);
   $150 = ($147>>>0)>($scevgep211>>>0);
   $umax212 = $150 ? $147 : $scevgep211;
   $scevgep213 = ((($umax212)) + -2|0);
   $151 = $4 ^ -1;
   $uglygep215 = (($scevgep213) + ($151)|0);
   $uglygep215216 = $uglygep215;
   $152 = $uglygep215216 >>> 1;
   $153 = (($$promoted184) + ($152))|0;
   $154 = (($153) + 1)|0;
   HEAP32[$149>>2] = $154;
   return;
   break;
  }
  case 2:  {
   $155 = (($2) + -1)|0;
   $156 = (($3) + ($155<<1)|0);
   $157 = ($2|0)>(1);
   $158 = ((($0)) + 12|0);
   $$promoted188 = HEAP32[$158>>2]|0;
   if ($157) {
    $scevgep217 = ((($3)) + 2|0);
    $159 = ($156>>>0)>($scevgep217>>>0);
    $umax218 = $159 ? $156 : $scevgep217;
    $160 = $4 ^ -1;
    $uglygep220 = (($umax218) + ($160)|0);
    $uglygep220221 = $uglygep220;
    $161 = $uglygep220221 >>> 1;
    $162 = (($$promoted188) + ($161))|0;
    $163 = (($162) + 1)|0;
    HEAP32[$158>>2] = $163;
    $165 = $163;
   } else {
    $165 = $$promoted188;
   }
   $164 = (($165) + 1)|0;
   HEAP32[$158>>2] = $164;
   return;
   break;
  }
  default: {
   return;
  }
  }
 } while(0);
}
function __ZN3osg24TemplatePrimitiveFunctorIN27LineSegmentIntersectorUtils16IntersectFunctorINS_5Vec3dEdEEE20drawElementsTemplateIhEEvjiPKT_($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0133158 = 0, $$0135160 = 0, $$0137159 = 0, $$0139163 = 0, $$0141162 = 0, $$0142169 = 0, $$0143166 = 0, $$0144168 = 0, $$0145165 = 0, $$pre218 = 0, $$promoted = 0, $$promoted175 = 0, $$promoted179 = 0, $$promoted184 = 0, $$promoted188 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0;
 var $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0;
 var $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0;
 var $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $exitcond198 = 0, $or$cond = 0, $scevgep = 0, $scevgep199 = 0, $scevgep199200 = 0, $scevgep201 = 0, $scevgep203 = 0, $scevgep203204 = 0, $scevgep205 = 0, $scevgep207 = 0, $scevgep207208 = 0, $scevgep209 = 0, $scevgep211 = 0;
 var $scevgep211212 = 0, $scevgep213 = 0, $scevgep215 = 0, $scevgep215216 = 0, $umax = 0, $umax202 = 0, $umax206 = 0, $umax210 = 0, $umax214 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = $3;
 $5 = ($3|0)==(0|0);
 $6 = ($2|0)==(0);
 $or$cond = $6 | $5;
 if ($or$cond) {
  return;
 }
 do {
  switch ($1|0) {
  case 4:  {
   $19 = (($3) + ($2)|0);
   $20 = ($2|0)>(0);
   if (!($20)) {
    return;
   }
   $21 = ((($0)) + 8|0);
   $22 = ((($0)) + 200|0);
   $23 = ((($0)) + 12|0);
   $$0133158 = $3;
   while(1) {
    $24 = HEAP32[$22>>2]|0;
    $25 = HEAP8[$$0133158>>0]|0;
    $26 = $25&255;
    $27 = (($24) + (($26*12)|0)|0);
    $28 = ((($$0133158)) + 1|0);
    $29 = HEAP8[$28>>0]|0;
    $30 = $29&255;
    $31 = (($24) + (($30*12)|0)|0);
    $32 = ((($$0133158)) + 2|0);
    $33 = HEAP8[$32>>0]|0;
    $34 = $33&255;
    $35 = (($24) + (($34*12)|0)|0);
    __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3dEdE9intersectERKNS1_5Vec3fES6_S6_($21,$27,$31,$35);
    $36 = HEAP32[$23>>2]|0;
    $37 = (($36) + 1)|0;
    HEAP32[$23>>2] = $37;
    $38 = ((($$0133158)) + 3|0);
    $39 = ($38>>>0)<($19>>>0);
    if ($39) {
     $$0133158 = $38;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 5:  {
   $15 = ($2|0)>(2);
   if (!($15)) {
    return;
   }
   $16 = ((($0)) + 8|0);
   $17 = ((($0)) + 200|0);
   $18 = ((($0)) + 12|0);
   $$0135160 = $3;$$0137159 = 2;
   while(1) {
    $40 = $$0137159 & 1;
    $41 = ($40|0)==(0);
    $42 = HEAP32[$17>>2]|0;
    $43 = HEAP8[$$0135160>>0]|0;
    $44 = $43&255;
    $45 = (($42) + (($44*12)|0)|0);
    $46 = ((($$0135160)) + 1|0);
    $47 = HEAP8[$46>>0]|0;
    $48 = ((($$0135160)) + 2|0);
    $49 = HEAP8[$48>>0]|0;
    $50 = $47&255;
    $51 = $49&255;
    if ($41) {
     $54 = (($42) + (($50*12)|0)|0);
     $55 = (($42) + (($51*12)|0)|0);
     __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3dEdE9intersectERKNS1_5Vec3fES6_S6_($16,$45,$54,$55);
    } else {
     $52 = (($42) + (($51*12)|0)|0);
     $53 = (($42) + (($50*12)|0)|0);
     __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3dEdE9intersectERKNS1_5Vec3fES6_S6_($16,$45,$52,$53);
    }
    $56 = HEAP32[$18>>2]|0;
    $57 = (($56) + 1)|0;
    HEAP32[$18>>2] = $57;
    $58 = (($$0137159) + 1)|0;
    $exitcond = ($58|0)==($2|0);
    if ($exitcond) {
     break;
    } else {
     $$0135160 = $46;$$0137159 = $58;
    }
   }
   return;
   break;
  }
  case 7:  {
   $11 = ($2|0)>(3);
   if (!($11)) {
    return;
   }
   $12 = ((($0)) + 8|0);
   $13 = ((($0)) + 200|0);
   $14 = ((($0)) + 12|0);
   $$0139163 = $3;$$0141162 = 3;
   while(1) {
    $59 = HEAP32[$13>>2]|0;
    $60 = HEAP8[$$0139163>>0]|0;
    $61 = $60&255;
    $62 = (($59) + (($61*12)|0)|0);
    $63 = ((($$0139163)) + 1|0);
    $64 = HEAP8[$63>>0]|0;
    $65 = $64&255;
    $66 = (($59) + (($65*12)|0)|0);
    $67 = ((($$0139163)) + 2|0);
    $68 = HEAP8[$67>>0]|0;
    $69 = $68&255;
    $70 = (($59) + (($69*12)|0)|0);
    $71 = ((($$0139163)) + 3|0);
    $72 = HEAP8[$71>>0]|0;
    $73 = $72&255;
    $74 = (($59) + (($73*12)|0)|0);
    __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3dEdE9intersectERKNS1_5Vec3fES6_S6_($12,$62,$66,$74);
    __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3dEdE9intersectERKNS1_5Vec3fES6_S6_($12,$66,$70,$74);
    $75 = HEAP32[$14>>2]|0;
    $76 = (($75) + 1)|0;
    HEAP32[$14>>2] = $76;
    $77 = (($$0141162) + 4)|0;
    $78 = ((($$0139163)) + 4|0);
    $79 = ($77|0)<($2|0);
    if ($79) {
     $$0139163 = $78;$$0141162 = $77;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 8:  {
   $7 = ($2|0)>(3);
   if (!($7)) {
    return;
   }
   $8 = ((($0)) + 8|0);
   $9 = ((($0)) + 200|0);
   $10 = ((($0)) + 12|0);
   $$0143166 = $3;$$0145165 = 3;
   while(1) {
    $80 = HEAP32[$9>>2]|0;
    $81 = HEAP8[$$0143166>>0]|0;
    $82 = $81&255;
    $83 = (($80) + (($82*12)|0)|0);
    $84 = ((($$0143166)) + 1|0);
    $85 = HEAP8[$84>>0]|0;
    $86 = $85&255;
    $87 = (($80) + (($86*12)|0)|0);
    $88 = ((($$0143166)) + 3|0);
    $89 = HEAP8[$88>>0]|0;
    $90 = $89&255;
    $91 = (($80) + (($90*12)|0)|0);
    $92 = ((($$0143166)) + 2|0);
    $93 = HEAP8[$92>>0]|0;
    $94 = $93&255;
    $95 = (($80) + (($94*12)|0)|0);
    __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3dEdE9intersectERKNS1_5Vec3fES6_S6_($8,$83,$87,$95);
    __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3dEdE9intersectERKNS1_5Vec3fES6_S6_($8,$87,$91,$95);
    $96 = HEAP32[$10>>2]|0;
    $97 = (($96) + 1)|0;
    HEAP32[$10>>2] = $97;
    $98 = (($$0145165) + 2)|0;
    $99 = ($98|0)<($2|0);
    if ($99) {
     $$0143166 = $92;$$0145165 = $98;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 6: case 9:  {
   $100 = ((($0)) + 200|0);
   $101 = HEAP32[$100>>2]|0;
   $102 = HEAP8[$3>>0]|0;
   $103 = $102&255;
   $104 = (($101) + (($103*12)|0)|0);
   $105 = ($2|0)>(2);
   if (!($105)) {
    return;
   }
   $106 = ((($3)) + 1|0);
   $107 = ((($0)) + 8|0);
   $108 = ((($0)) + 12|0);
   $$0142169 = 2;$$0144168 = $106;$112 = $101;
   while(1) {
    $109 = HEAP8[$$0144168>>0]|0;
    $110 = $109&255;
    $111 = (($112) + (($110*12)|0)|0);
    $113 = ((($$0144168)) + 1|0);
    $114 = HEAP8[$113>>0]|0;
    $115 = $114&255;
    $116 = (($112) + (($115*12)|0)|0);
    __ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3dEdE9intersectERKNS1_5Vec3fES6_S6_($107,$104,$111,$116);
    $117 = HEAP32[$108>>2]|0;
    $118 = (($117) + 1)|0;
    HEAP32[$108>>2] = $118;
    $119 = (($$0142169) + 1)|0;
    $exitcond198 = ($119|0)==($2|0);
    if ($exitcond198) {
     break;
    }
    $$pre218 = HEAP32[$100>>2]|0;
    $$0142169 = $119;$$0144168 = $113;$112 = $$pre218;
   }
   return;
   break;
  }
  case 0:  {
   $120 = (($3) + ($2)|0);
   $121 = ($2|0)>(0);
   if (!($121)) {
    return;
   }
   $122 = ((($0)) + 12|0);
   $$promoted = HEAP32[$122>>2]|0;
   $scevgep = ((($3)) + 1|0);
   $123 = ($120>>>0)>($scevgep>>>0);
   $umax = $123 ? $120 : $scevgep;
   $124 = (($$promoted) - ($4))|0;
   $scevgep199 = (($umax) + ($124)|0);
   $scevgep199200 = $scevgep199;
   HEAP32[$122>>2] = $scevgep199200;
   return;
   break;
  }
  case 1:  {
   $125 = (($2) + -1)|0;
   $126 = (($3) + ($125)|0);
   $127 = ($2|0)>(1);
   if (!($127)) {
    return;
   }
   $128 = ((($0)) + 12|0);
   $$promoted175 = HEAP32[$128>>2]|0;
   $scevgep201 = ((($3)) + 2|0);
   $129 = ($126>>>0)>($scevgep201>>>0);
   $umax202 = $129 ? $126 : $scevgep201;
   $130 = $4 ^ -1;
   $scevgep203 = (($umax202) + ($130)|0);
   $scevgep203204 = $scevgep203;
   $131 = $scevgep203204 >>> 1;
   $132 = (($$promoted175) + ($131))|0;
   $133 = (($132) + 1)|0;
   HEAP32[$128>>2] = $133;
   return;
   break;
  }
  case 3:  {
   $134 = (($2) + -1)|0;
   $135 = (($3) + ($134)|0);
   $136 = ($2|0)>(1);
   if (!($136)) {
    return;
   }
   $137 = ((($0)) + 12|0);
   $$promoted179 = HEAP32[$137>>2]|0;
   $scevgep205 = ((($3)) + 1|0);
   $138 = ($135>>>0)>($scevgep205>>>0);
   $umax206 = $138 ? $135 : $scevgep205;
   $139 = (($$promoted179) - ($4))|0;
   $scevgep207 = (($umax206) + ($139)|0);
   $scevgep207208 = $scevgep207;
   HEAP32[$137>>2] = $scevgep207208;
   return;
   break;
  }
  case 11:  {
   $140 = (($2) + -2)|0;
   $141 = (($3) + ($140)|0);
   $142 = ($140|0)>(1);
   if (!($142)) {
    return;
   }
   $143 = ((($0)) + 12|0);
   $$promoted184 = HEAP32[$143>>2]|0;
   $scevgep209 = ((($3)) + 2|0);
   $144 = ($141>>>0)>($scevgep209>>>0);
   $umax210 = $144 ? $141 : $scevgep209;
   $145 = (($$promoted184) + -1)|0;
   $146 = (($145) - ($4))|0;
   $scevgep211 = (($umax210) + ($146)|0);
   $scevgep211212 = $scevgep211;
   HEAP32[$143>>2] = $scevgep211212;
   return;
   break;
  }
  case 2:  {
   $147 = (($2) + -1)|0;
   $148 = (($3) + ($147)|0);
   $149 = ($2|0)>(1);
   $150 = ((($0)) + 12|0);
   $$promoted188 = HEAP32[$150>>2]|0;
   if ($149) {
    $scevgep213 = ((($3)) + 1|0);
    $151 = ($148>>>0)>($scevgep213>>>0);
    $umax214 = $151 ? $148 : $scevgep213;
    $152 = (($$promoted188) - ($4))|0;
    $scevgep215 = (($umax214) + ($152)|0);
    $scevgep215216 = $scevgep215;
    HEAP32[$150>>2] = $scevgep215216;
    $154 = $scevgep215216;
   } else {
    $154 = $$promoted188;
   }
   $153 = (($154) + 1)|0;
   HEAP32[$150>>2] = $153;
   return;
   break;
  }
  default: {
   return;
  }
  }
 } while(0);
}
function __ZN27LineSegmentIntersectorUtils8SettingsD2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (48556);
 $1 = ((($0)) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  HEAP32[$1>>2] = 0;
  __ZN3osg10ReferencedD2Ev($0);
  return;
 }
 $4 = ((($2)) + 8|0);
 $5 = HEAP32[$4>>2]|0;HEAP32[$4>>2] = (($5-1)|0);
 $6 = ($5|0)==(1);
 if (!($6)) {
  HEAP32[$1>>2] = 0;
  __ZN3osg10ReferencedD2Ev($0);
  return;
 }
 __THREW__ = 0;
 invoke_viii(3262,($2|0),1,1);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if (!($8)) {
  HEAP32[$1>>2] = 0;
  __ZN3osg10ReferencedD2Ev($0);
  return;
 }
 $9 = ___cxa_find_matching_catch_2()|0;
 $10 = tempRet0;
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if ($12) {
  $13 = ___cxa_find_matching_catch_3(0|0)|0;
  $14 = tempRet0;
  ___clang_call_terminate($13);
  // unreachable;
 } else {
  ___resumeException($9|0);
  // unreachable;
 }
}
function __ZN27LineSegmentIntersectorUtils8SettingsD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (48556);
 $1 = ((($0)) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = ((($2)) + 8|0);
  $5 = HEAP32[$4>>2]|0;HEAP32[$4>>2] = (($5-1)|0);
  $6 = ($5|0)==(1);
  if ($6) {
   __THREW__ = 0;
   invoke_viii(3262,($2|0),1,1);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch_2()|0;
    $12 = tempRet0;
    __THREW__ = 0;
    invoke_vi(712,($0|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     $15 = ___cxa_find_matching_catch_3(0|0)|0;
     $16 = tempRet0;
     ___clang_call_terminate($15);
     // unreachable;
    } else {
     $eh$lpad$body$index2Z2D = $12;$eh$lpad$body$indexZ2D = $11;
     __ZdlPv($0);
     ___resumeException($eh$lpad$body$indexZ2D|0);
     // unreachable;
    }
   }
  }
 }
 HEAP32[$1>>2] = 0;
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if (!($10)) {
  __ZdlPv($0);
  return;
 }
 $17 = ___cxa_find_matching_catch_2()|0;
 $18 = tempRet0;
 $eh$lpad$body$index2Z2D = $18;$eh$lpad$body$indexZ2D = $17;
 __ZdlPv($0);
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
}
function __ZNK3osg8Drawable14getBoundingBoxEv($0) {
 $0 = $0|0;
 var $$pre = 0, $$pre$phiZ2D = 0, $$sink = 0.0, $$sink11 = 0.0, $$sink13 = 0.0, $$sink15 = 0.0, $1 = 0, $10 = 0, $100 = 0.0, $101 = 0.0, $102 = 0.0, $103 = 0.0, $104 = 0.0, $105 = 0.0, $106 = 0.0, $107 = 0.0, $108 = 0.0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0.0, $16 = 0.0, $17 = 0, $18 = 0, $19 = 0.0, $2 = 0, $20 = 0, $21 = 0.0, $22 = 0, $23 = 0, $24 = 0.0, $25 = 0, $26 = 0.0, $27 = 0, $28 = 0.0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0.0, $32 = 0, $33 = 0, $34 = 0.0, $35 = 0, $36 = 0, $37 = 0.0, $38 = 0, $39 = 0, $4 = 0, $40 = 0.0, $41 = 0, $42 = 0, $43 = 0.0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0.0, $5 = 0, $50 = 0.0, $51 = 0, $52 = 0, $53 = 0.0, $54 = 0, $55 = 0.0, $56 = 0, $57 = 0, $58 = 0.0, $59 = 0, $6 = 0, $60 = 0.0, $61 = 0, $62 = 0.0, $63 = 0, $64 = 0;
 var $65 = 0.0, $66 = 0, $67 = 0, $68 = 0.0, $69 = 0, $7 = 0, $70 = 0, $71 = 0.0, $72 = 0, $73 = 0, $74 = 0.0, $75 = 0, $76 = 0, $77 = 0.0, $78 = 0, $79 = 0, $8 = 0, $80 = 0.0, $81 = 0.0, $82 = 0;
 var $83 = 0, $84 = 0.0, $85 = 0, $86 = 0.0, $87 = 0, $88 = 0, $89 = 0.0, $9 = 0, $90 = 0, $91 = 0.0, $92 = 0, $93 = 0.0, $94 = 0.0, $95 = 0.0, $96 = 0.0, $97 = 0.0, $98 = 0.0, $99 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $1 = sp + 24|0;
 $2 = sp;
 $3 = ((($0)) + 68|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)==(0);
 if (!($5)) {
  $$pre = ((($0)) + 152|0);
  $$pre$phiZ2D = $$pre;
  STACKTOP = sp;return ($$pre$phiZ2D|0);
 }
 $6 = ((($0)) + 124|0);
 $7 = ((($0)) + 152|0);
 ;HEAP32[$7>>2]=HEAP32[$6>>2]|0;HEAP32[$7+4>>2]=HEAP32[$6+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[$6+8>>2]|0;HEAP32[$7+12>>2]=HEAP32[$6+12>>2]|0;HEAP32[$7+16>>2]=HEAP32[$6+16>>2]|0;HEAP32[$7+20>>2]=HEAP32[$6+20>>2]|0;
 $8 = ((($0)) + 148|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if ($10) {
  $45 = HEAP32[$0>>2]|0;
  $46 = ((($45)) + 204|0);
  $47 = HEAP32[$46>>2]|0;
  FUNCTION_TABLE_vii[$47 & 8191]($2,$0);
  $48 = ((($2)) + 12|0);
  $49 = +HEAPF32[$48>>2];
  $50 = +HEAPF32[$2>>2];
  $51 = !($49 >= $50);
  if (!($51)) {
   $52 = ((($2)) + 16|0);
   $53 = +HEAPF32[$52>>2];
   $54 = ((($2)) + 4|0);
   $55 = +HEAPF32[$54>>2];
   $56 = !($53 >= $55);
   if (!($56)) {
    $57 = ((($2)) + 20|0);
    $58 = +HEAPF32[$57>>2];
    $59 = ((($2)) + 8|0);
    $60 = +HEAPF32[$59>>2];
    $61 = !($58 >= $60);
    if (!($61)) {
     $62 = +HEAPF32[$7>>2];
     $63 = $50 < $62;
     if ($63) {
      HEAPF32[$7>>2] = $50;
     }
     $64 = ((($0)) + 164|0);
     $65 = +HEAPF32[$64>>2];
     $66 = $49 > $65;
     if ($66) {
      HEAPF32[$64>>2] = $49;
     }
     $67 = ((($0)) + 156|0);
     $68 = +HEAPF32[$67>>2];
     $69 = $55 < $68;
     if ($69) {
      HEAPF32[$67>>2] = $55;
     }
     $70 = ((($0)) + 168|0);
     $71 = +HEAPF32[$70>>2];
     $72 = $53 > $71;
     if ($72) {
      HEAPF32[$70>>2] = $53;
     }
     $73 = ((($0)) + 160|0);
     $74 = +HEAPF32[$73>>2];
     $75 = $60 < $74;
     if ($75) {
      HEAPF32[$73>>2] = $60;
     }
     $76 = ((($0)) + 172|0);
     $77 = +HEAPF32[$76>>2];
     $78 = $58 > $77;
     if ($78) {
      HEAPF32[$76>>2] = $58;
     }
    }
   }
  }
 } else {
  $11 = HEAP32[$9>>2]|0;
  $12 = ((($11)) + 140|0);
  $13 = HEAP32[$12>>2]|0;
  FUNCTION_TABLE_viii[$13 & 8191]($1,$9,$0);
  $14 = ((($1)) + 12|0);
  $15 = +HEAPF32[$14>>2];
  $16 = +HEAPF32[$1>>2];
  $17 = !($15 >= $16);
  if (!($17)) {
   $18 = ((($1)) + 16|0);
   $19 = +HEAPF32[$18>>2];
   $20 = ((($1)) + 4|0);
   $21 = +HEAPF32[$20>>2];
   $22 = !($19 >= $21);
   if (!($22)) {
    $23 = ((($1)) + 20|0);
    $24 = +HEAPF32[$23>>2];
    $25 = ((($1)) + 8|0);
    $26 = +HEAPF32[$25>>2];
    $27 = !($24 >= $26);
    if (!($27)) {
     $28 = +HEAPF32[$7>>2];
     $29 = $16 < $28;
     if ($29) {
      HEAPF32[$7>>2] = $16;
     }
     $30 = ((($0)) + 164|0);
     $31 = +HEAPF32[$30>>2];
     $32 = $15 > $31;
     if ($32) {
      HEAPF32[$30>>2] = $15;
     }
     $33 = ((($0)) + 156|0);
     $34 = +HEAPF32[$33>>2];
     $35 = $21 < $34;
     if ($35) {
      HEAPF32[$33>>2] = $21;
     }
     $36 = ((($0)) + 168|0);
     $37 = +HEAPF32[$36>>2];
     $38 = $19 > $37;
     if ($38) {
      HEAPF32[$36>>2] = $19;
     }
     $39 = ((($0)) + 160|0);
     $40 = +HEAPF32[$39>>2];
     $41 = $26 < $40;
     if ($41) {
      HEAPF32[$39>>2] = $26;
     }
     $42 = ((($0)) + 172|0);
     $43 = +HEAPF32[$42>>2];
     $44 = $24 > $43;
     if ($44) {
      HEAPF32[$42>>2] = $24;
     }
    }
   }
  }
 }
 $79 = ((($0)) + 164|0);
 $80 = +HEAPF32[$79>>2];
 $81 = +HEAPF32[$7>>2];
 $82 = !($80 >= $81);
 if ($82) {
  $$sink = -1.0;$$sink11 = 0.0;$$sink13 = 0.0;$$sink15 = 0.0;
 } else {
  $83 = ((($0)) + 168|0);
  $84 = +HEAPF32[$83>>2];
  $85 = ((($0)) + 156|0);
  $86 = +HEAPF32[$85>>2];
  $87 = !($84 >= $86);
  if ($87) {
   $$sink = -1.0;$$sink11 = 0.0;$$sink13 = 0.0;$$sink15 = 0.0;
  } else {
   $88 = ((($0)) + 172|0);
   $89 = +HEAPF32[$88>>2];
   $90 = ((($0)) + 160|0);
   $91 = +HEAPF32[$90>>2];
   $92 = !($89 >= $91);
   if ($92) {
    $$sink = -1.0;$$sink11 = 0.0;$$sink13 = 0.0;$$sink15 = 0.0;
   } else {
    $93 = $81 + $80;
    $94 = $86 + $84;
    $95 = $91 + $89;
    $96 = $93 * 0.5;
    $97 = $94 * 0.5;
    $98 = $95 * 0.5;
    $99 = $80 - $81;
    $100 = $84 - $86;
    $101 = $89 - $91;
    $102 = $99 * $99;
    $103 = $100 * $100;
    $104 = $102 + $103;
    $105 = $101 * $101;
    $106 = $104 + $105;
    $107 = $106 * 0.25;
    $108 = (+Math_sqrt((+$107)));
    $$sink = $108;$$sink11 = $98;$$sink13 = $97;$$sink15 = $96;
   }
  }
 }
 $109 = ((($0)) + 52|0);
 HEAPF32[$109>>2] = $$sink15;
 $110 = ((($0)) + 56|0);
 HEAPF32[$110>>2] = $$sink13;
 $111 = ((($0)) + 60|0);
 HEAPF32[$111>>2] = $$sink11;
 $112 = ((($0)) + 64|0);
 HEAPF32[$112>>2] = $$sink;
 HEAP8[$3>>0] = 1;
 $$pre$phiZ2D = $7;
 STACKTOP = sp;return ($$pre$phiZ2D|0);
}
function __ZN7osgUtil22LineSegmentIntersector16intersectAndClipERN3osg5Vec3dES3_RKNS1_15BoundingBoxImplINS1_5Vec3fEEE($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $$pre = 0.0, $$pre423 = 0.0, $$pre424 = 0.0, $$pre425 = 0.0, $$pre426 = 0.0, $$pre427 = 0.0, $10 = 0.0, $100 = 0.0, $101 = 0.0, $102 = 0.0, $103 = 0, $104 = 0, $105 = 0.0, $106 = 0, $107 = 0.0, $108 = 0.0, $109 = 0, $11 = 0.0, $110 = 0.0;
 var $111 = 0, $112 = 0.0, $113 = 0.0, $114 = 0.0, $115 = 0.0, $116 = 0.0, $117 = 0.0, $118 = 0.0, $119 = 0.0, $12 = 0, $120 = 0, $121 = 0.0, $122 = 0, $123 = 0.0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0.0, $129 = 0.0;
 var $13 = 0.0, $130 = 0.0, $131 = 0.0, $132 = 0, $133 = 0.0, $134 = 0.0, $135 = 0.0, $136 = 0, $137 = 0.0, $138 = 0, $139 = 0.0, $14 = 0.0, $140 = 0.0, $141 = 0.0, $142 = 0.0, $143 = 0.0, $144 = 0.0, $145 = 0.0, $146 = 0.0, $147 = 0;
 var $148 = 0.0, $149 = 0.0, $15 = 0, $150 = 0.0, $151 = 0.0, $152 = 0.0, $153 = 0.0, $154 = 0, $155 = 0.0, $156 = 0.0, $157 = 0.0, $158 = 0, $159 = 0.0, $16 = 0.0, $160 = 0, $161 = 0.0, $162 = 0.0, $163 = 0.0, $164 = 0.0, $165 = 0.0;
 var $166 = 0.0, $167 = 0.0, $168 = 0.0, $169 = 0, $17 = 0.0, $170 = 0, $171 = 0, $172 = 0.0, $173 = 0.0, $174 = 0.0, $175 = 0.0, $176 = 0, $177 = 0.0, $178 = 0.0, $179 = 0.0, $18 = 0, $180 = 0, $181 = 0.0, $182 = 0, $183 = 0.0;
 var $184 = 0.0, $185 = 0.0, $186 = 0.0, $187 = 0.0, $188 = 0.0, $189 = 0.0, $19 = 0.0, $190 = 0.0, $191 = 0, $192 = 0.0, $193 = 0.0, $194 = 0.0, $195 = 0.0, $196 = 0.0, $197 = 0.0, $198 = 0, $199 = 0.0, $20 = 0.0, $200 = 0.0, $201 = 0.0;
 var $202 = 0, $203 = 0.0, $204 = 0, $205 = 0.0, $206 = 0.0, $207 = 0.0, $208 = 0.0, $209 = 0.0, $21 = 0.0, $210 = 0.0, $211 = 0.0, $212 = 0.0, $213 = 0, $214 = 0.0, $215 = 0, $216 = 0.0, $217 = 0, $218 = 0, $219 = 0, $22 = 0.0;
 var $220 = 0, $221 = 0.0, $222 = 0.0, $223 = 0.0, $224 = 0.0, $225 = 0, $226 = 0.0, $227 = 0.0, $228 = 0.0, $229 = 0.0, $23 = 0, $230 = 0.0, $231 = 0.0, $232 = 0.0, $233 = 0.0, $234 = 0.0, $235 = 0.0, $236 = 0.0, $237 = 0.0, $238 = 0;
 var $239 = 0.0, $24 = 0, $240 = 0.0, $241 = 0.0, $242 = 0.0, $243 = 0.0, $244 = 0.0, $245 = 0, $246 = 0.0, $247 = 0.0, $248 = 0.0, $249 = 0.0, $25 = 0, $250 = 0.0, $251 = 0.0, $252 = 0.0, $253 = 0.0, $254 = 0.0, $255 = 0.0, $256 = 0.0;
 var $257 = 0.0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0.0, $262 = 0.0, $263 = 0.0, $264 = 0.0, $265 = 0, $266 = 0.0, $267 = 0.0, $268 = 0.0, $269 = 0.0, $27 = 0.0, $270 = 0.0, $271 = 0.0, $272 = 0.0, $273 = 0.0, $274 = 0.0;
 var $275 = 0.0, $276 = 0.0, $277 = 0.0, $278 = 0, $279 = 0.0, $28 = 0.0, $280 = 0.0, $281 = 0.0, $282 = 0.0, $283 = 0.0, $284 = 0.0, $285 = 0, $286 = 0.0, $287 = 0.0, $288 = 0.0, $289 = 0.0, $29 = 0.0, $290 = 0.0, $291 = 0.0, $292 = 0.0;
 var $293 = 0.0, $294 = 0.0, $295 = 0.0, $296 = 0.0, $297 = 0.0, $30 = 0.0, $31 = 0, $32 = 0, $33 = 0.0, $34 = 0, $35 = 0.0, $36 = 0.0, $37 = 0, $38 = 0.0, $39 = 0, $4 = 0.0, $40 = 0.0, $41 = 0.0, $42 = 0.0, $43 = 0.0;
 var $44 = 0.0, $45 = 0.0, $46 = 0.0, $47 = 0.0, $48 = 0, $49 = 0.0, $5 = 0.0, $50 = 0.0, $51 = 0.0, $52 = 0.0, $53 = 0.0, $54 = 0.0, $55 = 0, $56 = 0, $57 = 0.0, $58 = 0, $59 = 0.0, $6 = 0, $60 = 0.0, $61 = 0;
 var $62 = 0.0, $63 = 0, $64 = 0.0, $65 = 0.0, $66 = 0.0, $67 = 0.0, $68 = 0.0, $69 = 0.0, $7 = 0.0, $70 = 0.0, $71 = 0.0, $72 = 0, $73 = 0, $74 = 0, $75 = 0.0, $76 = 0.0, $77 = 0.0, $78 = 0.0, $79 = 0, $8 = 0.0;
 var $80 = 0, $81 = 0.0, $82 = 0, $83 = 0.0, $84 = 0.0, $85 = 0, $86 = 0.0, $87 = 0, $88 = 0.0, $89 = 0.0, $9 = 0, $90 = 0.0, $91 = 0.0, $92 = 0.0, $93 = 0.0, $94 = 0.0, $95 = 0.0, $96 = 0, $97 = 0.0, $98 = 0.0;
 var $99 = 0.0, $or$cond = 0, $or$cond418 = 0, $or$cond419 = 0, $or$cond420 = 0, $or$cond421 = 0, $or$cond422 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = +HEAPF32[$3>>2];
 $5 = $4;
 $6 = ((($3)) + 4|0);
 $7 = +HEAPF32[$6>>2];
 $8 = $7;
 $9 = ((($3)) + 8|0);
 $10 = +HEAPF32[$9>>2];
 $11 = $10;
 $12 = ((($3)) + 12|0);
 $13 = +HEAPF32[$12>>2];
 $14 = $13;
 $15 = ((($3)) + 16|0);
 $16 = +HEAPF32[$15>>2];
 $17 = $16;
 $18 = ((($3)) + 20|0);
 $19 = +HEAPF32[$18>>2];
 $20 = $19;
 $21 = +HEAPF64[$1>>3];
 $22 = +HEAPF64[$2>>3];
 $23 = !($21 <= $22);
 if ($23) {
  $72 = $21 < $5;
  $73 = $22 > $14;
  $or$cond418 = $72 | $73;
  if ($or$cond418) {
   $$0 = 0;
   return ($$0|0);
  }
  $74 = $22 < $5;
  if ($74) {
   $75 = $5 - $22;
   $76 = $21 - $22;
   $77 = $75 / $76;
   $78 = $77 + -1.0000000000000001E-5;
   $79 = $78 > 0.0;
   if ($79) {
    $80 = ((($1)) + 8|0);
    $81 = +HEAPF64[$80>>3];
    $82 = ((($2)) + 8|0);
    $83 = +HEAPF64[$82>>3];
    $84 = $81 - $83;
    $85 = ((($1)) + 16|0);
    $86 = +HEAPF64[$85>>3];
    $87 = ((($2)) + 16|0);
    $88 = +HEAPF64[$87>>3];
    $89 = $86 - $88;
    $90 = $76 * $78;
    $91 = $78 * $84;
    $92 = $78 * $89;
    $93 = $22 + $90;
    $94 = $83 + $91;
    $95 = $88 + $92;
    HEAPF64[$2>>3] = $93;
    HEAPF64[$82>>3] = $94;
    HEAPF64[$87>>3] = $95;
    $$pre423 = +HEAPF64[$1>>3];
    $97 = $$pre423;$99 = $93;
   } else {
    $97 = $21;$99 = $22;
   }
  } else {
   $97 = $21;$99 = $22;
  }
  $96 = $97 > $14;
  if ($96) {
   $98 = $14 - $99;
   $100 = $97 - $99;
   $101 = $98 / $100;
   $102 = $101 + 1.0000000000000001E-5;
   $103 = $102 < 1.0;
   if ($103) {
    $104 = ((($1)) + 8|0);
    $105 = +HEAPF64[$104>>3];
    $106 = ((($2)) + 8|0);
    $107 = +HEAPF64[$106>>3];
    $108 = $105 - $107;
    $109 = ((($1)) + 16|0);
    $110 = +HEAPF64[$109>>3];
    $111 = ((($2)) + 16|0);
    $112 = +HEAPF64[$111>>3];
    $113 = $110 - $112;
    $114 = $100 * $102;
    $115 = $102 * $108;
    $116 = $102 * $113;
    $117 = $99 + $114;
    $118 = $107 + $115;
    $119 = $112 + $116;
    HEAPF64[$1>>3] = $117;
    HEAPF64[$104>>3] = $118;
    HEAPF64[$109>>3] = $119;
   }
  }
 } else {
  $24 = $22 < $5;
  $25 = $21 > $14;
  $or$cond = $25 | $24;
  if ($or$cond) {
   $$0 = 0;
   return ($$0|0);
  }
  $26 = $21 < $5;
  if ($26) {
   $27 = $5 - $21;
   $28 = $22 - $21;
   $29 = $27 / $28;
   $30 = $29 + -1.0000000000000001E-5;
   $31 = $30 > 0.0;
   if ($31) {
    $32 = ((($2)) + 8|0);
    $33 = +HEAPF64[$32>>3];
    $34 = ((($1)) + 8|0);
    $35 = +HEAPF64[$34>>3];
    $36 = $33 - $35;
    $37 = ((($2)) + 16|0);
    $38 = +HEAPF64[$37>>3];
    $39 = ((($1)) + 16|0);
    $40 = +HEAPF64[$39>>3];
    $41 = $38 - $40;
    $42 = $28 * $30;
    $43 = $30 * $36;
    $44 = $30 * $41;
    $45 = $21 + $42;
    $46 = $35 + $43;
    $47 = $40 + $44;
    HEAPF64[$1>>3] = $45;
    HEAPF64[$34>>3] = $46;
    HEAPF64[$39>>3] = $47;
    $$pre = +HEAPF64[$2>>3];
    $49 = $$pre;$51 = $45;
   } else {
    $49 = $22;$51 = $21;
   }
  } else {
   $49 = $22;$51 = $21;
  }
  $48 = $49 > $14;
  if ($48) {
   $50 = $14 - $51;
   $52 = $49 - $51;
   $53 = $50 / $52;
   $54 = $53 + 1.0000000000000001E-5;
   $55 = $54 < 1.0;
   if ($55) {
    $56 = ((($2)) + 8|0);
    $57 = +HEAPF64[$56>>3];
    $58 = ((($1)) + 8|0);
    $59 = +HEAPF64[$58>>3];
    $60 = $57 - $59;
    $61 = ((($2)) + 16|0);
    $62 = +HEAPF64[$61>>3];
    $63 = ((($1)) + 16|0);
    $64 = +HEAPF64[$63>>3];
    $65 = $62 - $64;
    $66 = $52 * $54;
    $67 = $54 * $60;
    $68 = $54 * $65;
    $69 = $51 + $66;
    $70 = $59 + $67;
    $71 = $64 + $68;
    HEAPF64[$2>>3] = $69;
    HEAPF64[$56>>3] = $70;
    HEAPF64[$61>>3] = $71;
   }
  }
 }
 $120 = ((($1)) + 8|0);
 $121 = +HEAPF64[$120>>3];
 $122 = ((($2)) + 8|0);
 $123 = +HEAPF64[$122>>3];
 $124 = !($121 <= $123);
 if ($124) {
  $169 = $121 < $8;
  $170 = $123 > $17;
  $or$cond420 = $169 | $170;
  if ($or$cond420) {
   $$0 = 0;
   return ($$0|0);
  }
  $171 = $123 < $8;
  if ($171) {
   $172 = $8 - $123;
   $173 = $121 - $123;
   $174 = $172 / $173;
   $175 = $174 + -1.0000000000000001E-5;
   $176 = $175 > 0.0;
   if ($176) {
    $177 = +HEAPF64[$1>>3];
    $178 = +HEAPF64[$2>>3];
    $179 = $177 - $178;
    $180 = ((($1)) + 16|0);
    $181 = +HEAPF64[$180>>3];
    $182 = ((($2)) + 16|0);
    $183 = +HEAPF64[$182>>3];
    $184 = $181 - $183;
    $185 = $175 * $179;
    $186 = $173 * $175;
    $187 = $175 * $184;
    $188 = $178 + $185;
    $189 = $123 + $186;
    $190 = $183 + $187;
    HEAPF64[$2>>3] = $188;
    HEAPF64[$122>>3] = $189;
    HEAPF64[$182>>3] = $190;
    $$pre425 = +HEAPF64[$120>>3];
    $192 = $$pre425;$194 = $189;
   } else {
    $192 = $121;$194 = $123;
   }
  } else {
   $192 = $121;$194 = $123;
  }
  $191 = $192 > $17;
  if ($191) {
   $193 = $17 - $194;
   $195 = $192 - $194;
   $196 = $193 / $195;
   $197 = $196 + 1.0000000000000001E-5;
   $198 = $197 < 1.0;
   if ($198) {
    $199 = +HEAPF64[$1>>3];
    $200 = +HEAPF64[$2>>3];
    $201 = $199 - $200;
    $202 = ((($1)) + 16|0);
    $203 = +HEAPF64[$202>>3];
    $204 = ((($2)) + 16|0);
    $205 = +HEAPF64[$204>>3];
    $206 = $203 - $205;
    $207 = $197 * $201;
    $208 = $195 * $197;
    $209 = $197 * $206;
    $210 = $200 + $207;
    $211 = $194 + $208;
    $212 = $205 + $209;
    HEAPF64[$1>>3] = $210;
    HEAPF64[$120>>3] = $211;
    HEAPF64[$202>>3] = $212;
   }
  }
 } else {
  $125 = $123 < $8;
  $126 = $121 > $17;
  $or$cond419 = $126 | $125;
  if ($or$cond419) {
   $$0 = 0;
   return ($$0|0);
  }
  $127 = $121 < $8;
  if ($127) {
   $128 = $8 - $121;
   $129 = $123 - $121;
   $130 = $128 / $129;
   $131 = $130 + -1.0000000000000001E-5;
   $132 = $131 > 0.0;
   if ($132) {
    $133 = +HEAPF64[$2>>3];
    $134 = +HEAPF64[$1>>3];
    $135 = $133 - $134;
    $136 = ((($2)) + 16|0);
    $137 = +HEAPF64[$136>>3];
    $138 = ((($1)) + 16|0);
    $139 = +HEAPF64[$138>>3];
    $140 = $137 - $139;
    $141 = $131 * $135;
    $142 = $129 * $131;
    $143 = $131 * $140;
    $144 = $134 + $141;
    $145 = $121 + $142;
    $146 = $139 + $143;
    HEAPF64[$1>>3] = $144;
    HEAPF64[$120>>3] = $145;
    HEAPF64[$138>>3] = $146;
    $$pre424 = +HEAPF64[$122>>3];
    $148 = $$pre424;$150 = $145;
   } else {
    $148 = $123;$150 = $121;
   }
  } else {
   $148 = $123;$150 = $121;
  }
  $147 = $148 > $17;
  if ($147) {
   $149 = $17 - $150;
   $151 = $148 - $150;
   $152 = $149 / $151;
   $153 = $152 + 1.0000000000000001E-5;
   $154 = $153 < 1.0;
   if ($154) {
    $155 = +HEAPF64[$2>>3];
    $156 = +HEAPF64[$1>>3];
    $157 = $155 - $156;
    $158 = ((($2)) + 16|0);
    $159 = +HEAPF64[$158>>3];
    $160 = ((($1)) + 16|0);
    $161 = +HEAPF64[$160>>3];
    $162 = $159 - $161;
    $163 = $153 * $157;
    $164 = $151 * $153;
    $165 = $153 * $162;
    $166 = $156 + $163;
    $167 = $150 + $164;
    $168 = $161 + $165;
    HEAPF64[$2>>3] = $166;
    HEAPF64[$122>>3] = $167;
    HEAPF64[$158>>3] = $168;
   }
  }
 }
 $213 = ((($1)) + 16|0);
 $214 = +HEAPF64[$213>>3];
 $215 = ((($2)) + 16|0);
 $216 = +HEAPF64[$215>>3];
 $217 = !($214 <= $216);
 if ($217) {
  $258 = $214 < $11;
  $259 = $216 > $20;
  $or$cond422 = $258 | $259;
  if ($or$cond422) {
   $$0 = 0;
   return ($$0|0);
  }
  $260 = $216 < $11;
  if ($260) {
   $261 = $11 - $216;
   $262 = $214 - $216;
   $263 = $261 / $262;
   $264 = $263 + -1.0000000000000001E-5;
   $265 = $264 > 0.0;
   if ($265) {
    $266 = +HEAPF64[$1>>3];
    $267 = +HEAPF64[$2>>3];
    $268 = $266 - $267;
    $269 = +HEAPF64[$120>>3];
    $270 = +HEAPF64[$122>>3];
    $271 = $269 - $270;
    $272 = $264 * $268;
    $273 = $264 * $271;
    $274 = $262 * $264;
    $275 = $267 + $272;
    $276 = $270 + $273;
    $277 = $216 + $274;
    HEAPF64[$2>>3] = $275;
    HEAPF64[$122>>3] = $276;
    HEAPF64[$215>>3] = $277;
    $$pre427 = +HEAPF64[$213>>3];
    $279 = $$pre427;$281 = $277;
   } else {
    $279 = $214;$281 = $216;
   }
  } else {
   $279 = $214;$281 = $216;
  }
  $278 = $279 > $20;
  if (!($278)) {
   $$0 = 1;
   return ($$0|0);
  }
  $280 = $20 - $281;
  $282 = $279 - $281;
  $283 = $280 / $282;
  $284 = $283 + 1.0000000000000001E-5;
  $285 = $284 < 1.0;
  if (!($285)) {
   $$0 = 1;
   return ($$0|0);
  }
  $286 = +HEAPF64[$1>>3];
  $287 = +HEAPF64[$2>>3];
  $288 = $286 - $287;
  $289 = +HEAPF64[$120>>3];
  $290 = +HEAPF64[$122>>3];
  $291 = $289 - $290;
  $292 = $284 * $288;
  $293 = $284 * $291;
  $294 = $282 * $284;
  $295 = $287 + $292;
  $296 = $290 + $293;
  $297 = $281 + $294;
  HEAPF64[$1>>3] = $295;
  HEAPF64[$120>>3] = $296;
  HEAPF64[$213>>3] = $297;
  $$0 = 1;
  return ($$0|0);
 } else {
  $218 = $216 < $11;
  $219 = $214 > $20;
  $or$cond421 = $219 | $218;
  if ($or$cond421) {
   $$0 = 0;
   return ($$0|0);
  }
  $220 = $214 < $11;
  if ($220) {
   $221 = $11 - $214;
   $222 = $216 - $214;
   $223 = $221 / $222;
   $224 = $223 + -1.0000000000000001E-5;
   $225 = $224 > 0.0;
   if ($225) {
    $226 = +HEAPF64[$2>>3];
    $227 = +HEAPF64[$1>>3];
    $228 = $226 - $227;
    $229 = +HEAPF64[$122>>3];
    $230 = +HEAPF64[$120>>3];
    $231 = $229 - $230;
    $232 = $224 * $228;
    $233 = $224 * $231;
    $234 = $222 * $224;
    $235 = $227 + $232;
    $236 = $230 + $233;
    $237 = $214 + $234;
    HEAPF64[$1>>3] = $235;
    HEAPF64[$120>>3] = $236;
    HEAPF64[$213>>3] = $237;
    $$pre426 = +HEAPF64[$215>>3];
    $239 = $$pre426;$241 = $237;
   } else {
    $239 = $216;$241 = $214;
   }
  } else {
   $239 = $216;$241 = $214;
  }
  $238 = $239 > $20;
  if (!($238)) {
   $$0 = 1;
   return ($$0|0);
  }
  $240 = $20 - $241;
  $242 = $239 - $241;
  $243 = $240 / $242;
  $244 = $243 + 1.0000000000000001E-5;
  $245 = $244 < 1.0;
  if (!($245)) {
   $$0 = 1;
   return ($$0|0);
  }
  $246 = +HEAPF64[$2>>3];
  $247 = +HEAPF64[$1>>3];
  $248 = $246 - $247;
  $249 = +HEAPF64[$122>>3];
  $250 = +HEAPF64[$120>>3];
  $251 = $249 - $250;
  $252 = $244 * $248;
  $253 = $244 * $251;
  $254 = $242 * $244;
  $255 = $247 + $252;
  $256 = $250 + $253;
  $257 = $241 + $254;
  HEAPF64[$2>>3] = $255;
  HEAPF64[$122>>3] = $256;
  HEAPF64[$215>>3] = $257;
  $$0 = 1;
  return ($$0|0);
 }
 return (0)|0;
}
function __ZN7osgUtil22LineSegmentIntersector10intersectsERKN3osg18BoundingSphereImplINS1_5Vec3fEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$$i46 = 0, $$4 = 0, $10 = 0, $11 = 0.0, $12 = 0.0, $13 = 0, $14 = 0.0, $15 = 0.0, $16 = 0, $17 = 0.0, $18 = 0.0, $19 = 0, $2 = 0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0.0, $25 = 0.0, $26 = 0.0;
 var $27 = 0.0, $28 = 0.0, $29 = 0.0, $3 = 0.0, $30 = 0, $31 = 0, $32 = 0.0, $33 = 0.0, $34 = 0, $35 = 0.0, $36 = 0.0, $37 = 0, $38 = 0.0, $39 = 0.0, $4 = 0, $40 = 0.0, $41 = 0.0, $42 = 0.0, $43 = 0.0, $44 = 0.0;
 var $45 = 0.0, $46 = 0.0, $47 = 0.0, $48 = 0.0, $49 = 0.0, $5 = 0.0, $50 = 0.0, $51 = 0.0, $52 = 0.0, $53 = 0.0, $54 = 0.0, $55 = 0, $56 = 0.0, $57 = 0.0, $58 = 0.0, $59 = 0.0, $6 = 0.0, $60 = 0.0, $61 = 0.0, $62 = 0.0;
 var $63 = 0.0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0.0, $78 = 0.0, $79 = 0.0, $8 = 0.0, $80 = 0.0;
 var $81 = 0.0, $82 = 0, $83 = 0, $84 = 0, $85 = 0.0, $86 = 0, $9 = 0.0, $or$cond = 0, $or$cond3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 12|0);
 $3 = +HEAPF32[$2>>2];
 $4 = !($3 >= 0.0);
 if ($4) {
  $$4 = 1;
  return ($$4|0);
 }
 $5 = +HEAPF32[$1>>2];
 $6 = $5;
 $7 = ((($1)) + 4|0);
 $8 = +HEAPF32[$7>>2];
 $9 = $8;
 $10 = ((($1)) + 8|0);
 $11 = +HEAPF32[$10>>2];
 $12 = $11;
 $13 = ((($0)) + 32|0);
 $14 = +HEAPF64[$13>>3];
 $15 = $14 - $6;
 $16 = ((($0)) + 40|0);
 $17 = +HEAPF64[$16>>3];
 $18 = $17 - $9;
 $19 = ((($0)) + 48|0);
 $20 = +HEAPF64[$19>>3];
 $21 = $20 - $12;
 $22 = $15 * $15;
 $23 = $18 * $18;
 $24 = $22 + $23;
 $25 = $21 * $21;
 $26 = $24 + $25;
 $27 = $3 * $3;
 $28 = $27;
 $29 = $26 - $28;
 $30 = $29 < 0.0;
 if ($30) {
  $$4 = 1;
  return ($$4|0);
 }
 $31 = ((($0)) + 56|0);
 $32 = +HEAPF64[$31>>3];
 $33 = $32 - $14;
 $34 = ((($0)) + 64|0);
 $35 = +HEAPF64[$34>>3];
 $36 = $35 - $17;
 $37 = ((($0)) + 72|0);
 $38 = +HEAPF64[$37>>3];
 $39 = $38 - $20;
 $40 = $33 * $33;
 $41 = $36 * $36;
 $42 = $40 + $41;
 $43 = $39 * $39;
 $44 = $42 + $43;
 $45 = $15 * $33;
 $46 = $18 * $36;
 $47 = $45 + $46;
 $48 = $21 * $39;
 $49 = $47 + $48;
 $50 = $49 * 2.0;
 $51 = $50 * $50;
 $52 = $44 * 4.0;
 $53 = $29 * $52;
 $54 = $51 - $53;
 $55 = $54 < 0.0;
 if ($55) {
  $$4 = 0;
  return ($$4|0);
 }
 $56 = (+Math_sqrt((+$54)));
 $57 = $44 * 2.0;
 $58 = 1.0 / $57;
 $59 = -$50;
 $60 = $59 - $56;
 $61 = $58 * $60;
 $62 = $56 - $50;
 $63 = $58 * $62;
 $64 = $61 <= 0.0;
 $65 = $63 <= 0.0;
 $or$cond = $64 & $65;
 if ($or$cond) {
  $$4 = 0;
  return ($$4|0);
 }
 $66 = $61 >= 1.0;
 $67 = $63 >= 1.0;
 $or$cond3 = $66 & $67;
 if ($or$cond3) {
  $$4 = 0;
  return ($$4|0);
 }
 $68 = ((($0)) + 16|0);
 $69 = HEAP32[$68>>2]|0;
 $70 = ($69|0)==(3);
 if ($70) {
  $71 = ((($0)) + 28|0);
  $72 = HEAP32[$71>>2]|0;
  $73 = ($72|0)==(0|0);
  $$$i46 = $73 ? $0 : $72;
  $74 = ((($$$i46)) + 88|0);
  $75 = HEAP32[$74>>2]|0;
  $76 = ($75|0)==(0);
  if (!($76)) {
   $77 = (+Math_sqrt((+$26)));
   $78 = $3;
   $79 = $77 - $78;
   $80 = (+Math_sqrt((+$44)));
   $81 = $79 / $80;
   $82 = ((($$$i46)) + 80|0);
   $83 = HEAP32[$82>>2]|0;
   $84 = ((($83)) + 16|0);
   $85 = +HEAPF64[$84>>3];
   $86 = !($81 >= $85);
   if (!($86)) {
    $$4 = 0;
    return ($$4|0);
   }
  }
 }
 $$4 = 1;
 return ($$4|0);
}
function __ZN7osgUtil22LineSegmentIntersector17getTransformationERNS_19IntersectionVisitorENS_11Intersector15CoordinateFrameE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0.0, $114 = 0, $115 = 0.0, $116 = 0, $117 = 0;
 var $118 = 0.0, $119 = 0, $12 = 0, $120 = 0, $121 = 0.0, $122 = 0, $123 = 0, $124 = 0.0, $125 = 0, $126 = 0, $127 = 0.0, $128 = 0, $129 = 0, $13 = 0, $130 = 0.0, $131 = 0, $132 = 0, $133 = 0.0, $134 = 0, $135 = 0;
 var $136 = 0.0, $137 = 0, $138 = 0, $139 = 0.0, $14 = 0, $140 = 0, $141 = 0, $142 = 0.0, $143 = 0, $144 = 0, $145 = 0.0, $146 = 0, $147 = 0, $148 = 0.0, $149 = 0, $15 = 0, $150 = 0, $151 = 0.0, $152 = 0, $153 = 0;
 var $154 = 0.0, $155 = 0, $156 = 0, $157 = 0.0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0.0, $163 = 0, $164 = 0, $165 = 0.0, $166 = 0, $167 = 0, $168 = 0.0, $169 = 0, $17 = 0, $170 = 0, $171 = 0.0;
 var $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(128|0);
 $3 = sp;
 __ZN3osg7Matrixd12makeIdentityEv($3);
 L1: do {
  switch ($2|0) {
  case 0:  {
   $4 = ((($1)) + 84|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = ($5|0)==(0);
   if (!($6)) {
    $7 = ((($1)) + 76|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = ((($8)) + 8|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = ($10|0)==(0|0);
    if (!($11)) {
     $12 = ((($10)) + 32|0);
     __THREW__ = 0;
     invoke_vii(3546,($3|0),($12|0));
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break L1;
     }
    }
   }
   $15 = ((($1)) + 96|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ($16|0)==(0);
   if (!($17)) {
    $18 = ((($1)) + 88|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = ((($19)) + 8|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = ($21|0)==(0|0);
    if (!($22)) {
     $23 = ((($21)) + 32|0);
     __THREW__ = 0;
     invoke_vii(3546,($3|0),($23|0));
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if ($25) {
      break L1;
     }
    }
   }
   $26 = ((($1)) + 108|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = ($27|0)==(0);
   if (!($28)) {
    $29 = ((($1)) + 100|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = ((($30)) + 8|0);
    $32 = HEAP32[$31>>2]|0;
    $33 = ($32|0)==(0|0);
    if (!($33)) {
     $34 = ((($32)) + 32|0);
     __THREW__ = 0;
     invoke_vii(3546,($3|0),($34|0));
     $35 = __THREW__; __THREW__ = 0;
     $36 = $35&1;
     if ($36) {
      break L1;
     }
    }
   }
   $37 = ((($1)) + 120|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = ($38|0)==(0);
   if ($39) {
    label = 33;
   } else {
    $40 = ((($1)) + 112|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = ((($41)) + 8|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = ($43|0)==(0|0);
    if ($44) {
     label = 33;
    } else {
     $45 = ((($43)) + 32|0);
     __THREW__ = 0;
     invoke_vii(3546,($3|0),($45|0));
     $46 = __THREW__; __THREW__ = 0;
     $47 = $46&1;
     if (!($47)) {
      label = 33;
     }
    }
   }
   break;
  }
  case 1:  {
   $48 = ((($1)) + 96|0);
   $49 = HEAP32[$48>>2]|0;
   $50 = ($49|0)==(0);
   if (!($50)) {
    $51 = ((($1)) + 88|0);
    $52 = HEAP32[$51>>2]|0;
    $53 = ((($52)) + 8|0);
    $54 = HEAP32[$53>>2]|0;
    $55 = ($54|0)==(0|0);
    if (!($55)) {
     $56 = ((($54)) + 32|0);
     __THREW__ = 0;
     invoke_vii(3546,($3|0),($56|0));
     $57 = __THREW__; __THREW__ = 0;
     $58 = $57&1;
     if ($58) {
      break L1;
     }
    }
   }
   $59 = ((($1)) + 108|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = ($60|0)==(0);
   if (!($61)) {
    $62 = ((($1)) + 100|0);
    $63 = HEAP32[$62>>2]|0;
    $64 = ((($63)) + 8|0);
    $65 = HEAP32[$64>>2]|0;
    $66 = ($65|0)==(0|0);
    if (!($66)) {
     $67 = ((($65)) + 32|0);
     __THREW__ = 0;
     invoke_vii(3546,($3|0),($67|0));
     $68 = __THREW__; __THREW__ = 0;
     $69 = $68&1;
     if ($69) {
      break L1;
     }
    }
   }
   $70 = ((($1)) + 120|0);
   $71 = HEAP32[$70>>2]|0;
   $72 = ($71|0)==(0);
   if ($72) {
    label = 33;
   } else {
    $73 = ((($1)) + 112|0);
    $74 = HEAP32[$73>>2]|0;
    $75 = ((($74)) + 8|0);
    $76 = HEAP32[$75>>2]|0;
    $77 = ($76|0)==(0|0);
    if ($77) {
     label = 33;
    } else {
     $78 = ((($76)) + 32|0);
     __THREW__ = 0;
     invoke_vii(3546,($3|0),($78|0));
     $79 = __THREW__; __THREW__ = 0;
     $80 = $79&1;
     if (!($80)) {
      label = 33;
     }
    }
   }
   break;
  }
  case 2:  {
   $81 = ((($1)) + 108|0);
   $82 = HEAP32[$81>>2]|0;
   $83 = ($82|0)==(0);
   if (!($83)) {
    $84 = ((($1)) + 100|0);
    $85 = HEAP32[$84>>2]|0;
    $86 = ((($85)) + 8|0);
    $87 = HEAP32[$86>>2]|0;
    $88 = ($87|0)==(0|0);
    if (!($88)) {
     $89 = ((($87)) + 32|0);
     __THREW__ = 0;
     invoke_vii(3546,($3|0),($89|0));
     $90 = __THREW__; __THREW__ = 0;
     $91 = $90&1;
     if ($91) {
      break L1;
     }
    }
   }
   $92 = ((($1)) + 120|0);
   $93 = HEAP32[$92>>2]|0;
   $94 = ($93|0)==(0);
   if ($94) {
    label = 33;
   } else {
    $95 = ((($1)) + 112|0);
    $96 = HEAP32[$95>>2]|0;
    $97 = ((($96)) + 8|0);
    $98 = HEAP32[$97>>2]|0;
    $99 = ($98|0)==(0|0);
    if ($99) {
     label = 33;
    } else {
     $100 = ((($98)) + 32|0);
     __THREW__ = 0;
     invoke_vii(3546,($3|0),($100|0));
     $101 = __THREW__; __THREW__ = 0;
     $102 = $101&1;
     if (!($102)) {
      label = 33;
     }
    }
   }
   break;
  }
  case 3:  {
   $103 = ((($1)) + 120|0);
   $104 = HEAP32[$103>>2]|0;
   $105 = ($104|0)==(0);
   if ($105) {
    label = 33;
   } else {
    $106 = ((($1)) + 112|0);
    $107 = HEAP32[$106>>2]|0;
    $108 = ((($107)) + 8|0);
    $109 = HEAP32[$108>>2]|0;
    $110 = ($109|0)==(0|0);
    if ($110) {
     label = 33;
    } else {
     $111 = ((($109)) + 32|0);
     $112 = ($111|0)==($3|0);
     if ($112) {
      label = 33;
     } else {
      $113 = +HEAPF64[$111>>3];
      HEAPF64[$3>>3] = $113;
      $114 = ((($109)) + 40|0);
      $115 = +HEAPF64[$114>>3];
      $116 = ((($3)) + 8|0);
      HEAPF64[$116>>3] = $115;
      $117 = ((($109)) + 48|0);
      $118 = +HEAPF64[$117>>3];
      $119 = ((($3)) + 16|0);
      HEAPF64[$119>>3] = $118;
      $120 = ((($109)) + 56|0);
      $121 = +HEAPF64[$120>>3];
      $122 = ((($3)) + 24|0);
      HEAPF64[$122>>3] = $121;
      $123 = ((($109)) + 64|0);
      $124 = +HEAPF64[$123>>3];
      $125 = ((($3)) + 32|0);
      HEAPF64[$125>>3] = $124;
      $126 = ((($109)) + 72|0);
      $127 = +HEAPF64[$126>>3];
      $128 = ((($3)) + 40|0);
      HEAPF64[$128>>3] = $127;
      $129 = ((($109)) + 80|0);
      $130 = +HEAPF64[$129>>3];
      $131 = ((($3)) + 48|0);
      HEAPF64[$131>>3] = $130;
      $132 = ((($109)) + 88|0);
      $133 = +HEAPF64[$132>>3];
      $134 = ((($3)) + 56|0);
      HEAPF64[$134>>3] = $133;
      $135 = ((($109)) + 96|0);
      $136 = +HEAPF64[$135>>3];
      $137 = ((($3)) + 64|0);
      HEAPF64[$137>>3] = $136;
      $138 = ((($109)) + 104|0);
      $139 = +HEAPF64[$138>>3];
      $140 = ((($3)) + 72|0);
      HEAPF64[$140>>3] = $139;
      $141 = ((($109)) + 112|0);
      $142 = +HEAPF64[$141>>3];
      $143 = ((($3)) + 80|0);
      HEAPF64[$143>>3] = $142;
      $144 = ((($109)) + 120|0);
      $145 = +HEAPF64[$144>>3];
      $146 = ((($3)) + 88|0);
      HEAPF64[$146>>3] = $145;
      $147 = ((($109)) + 128|0);
      $148 = +HEAPF64[$147>>3];
      $149 = ((($3)) + 96|0);
      HEAPF64[$149>>3] = $148;
      $150 = ((($109)) + 136|0);
      $151 = +HEAPF64[$150>>3];
      $152 = ((($3)) + 104|0);
      HEAPF64[$152>>3] = $151;
      $153 = ((($109)) + 144|0);
      $154 = +HEAPF64[$153>>3];
      $155 = ((($3)) + 112|0);
      HEAPF64[$155>>3] = $154;
      $156 = ((($109)) + 152|0);
      $157 = +HEAPF64[$156>>3];
      $158 = ((($3)) + 120|0);
      HEAPF64[$158>>3] = $157;
      label = 33;
     }
    }
   }
   break;
  }
  default: {
   label = 33;
  }
  }
 } while(0);
 do {
  if ((label|0) == 33) {
   __THREW__ = 0;
   invoke_vi(3299,($0|0));
   $159 = __THREW__; __THREW__ = 0;
   $160 = $159&1;
   if (!($160)) {
    $161 = ((($3)) + 24|0);
    $162 = +HEAPF64[$161>>3];
    $163 = $162 == 0.0;
    if ($163) {
     $164 = ((($3)) + 56|0);
     $165 = +HEAPF64[$164>>3];
     $166 = $165 == 0.0;
     if ($166) {
      $167 = ((($3)) + 88|0);
      $168 = +HEAPF64[$167>>3];
      $169 = $168 == 0.0;
      if ($169) {
       $170 = ((($3)) + 120|0);
       $171 = +HEAPF64[$170>>3];
       $172 = $171 == 1.0;
       if ($172) {
        __THREW__ = 0;
        (invoke_iii(3303,($0|0),($3|0))|0);
        $173 = __THREW__; __THREW__ = 0;
        $174 = $173&1;
        if ($174) {
         break;
        }
        STACKTOP = sp;return;
       }
      }
     }
    }
    __THREW__ = 0;
    (invoke_iii(3304,($0|0),($3|0))|0);
    $175 = __THREW__; __THREW__ = 0;
    $176 = $175&1;
    if (!($176)) {
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $177 = ___cxa_find_matching_catch_2()|0;
 $178 = tempRet0;
 ___resumeException($177|0);
 // unreachable;
}
function __ZN7osgUtil22LineSegmentIntersectorC2ENS_11Intersector15CoordinateFrameERKN3osg5Vec3dES6_PS0_NS1_17IntersectionLimitE($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg10ReferencedC2Ev($0);
 $6 = ((($0)) + 12|0);
 HEAP32[$6>>2] = $1;
 $7 = ((($0)) + 16|0);
 HEAP32[$7>>2] = $5;
 $8 = ((($0)) + 20|0);
 HEAP32[$8>>2] = 0;
 $9 = ((($0)) + 24|0);
 HEAP32[$9>>2] = 0;
 HEAP32[$0>>2] = (48508);
 $10 = ((($0)) + 28|0);
 HEAP32[$10>>2] = $4;
 $11 = ((($0)) + 32|0);
 ;HEAP32[$11>>2]=HEAP32[$2>>2]|0;HEAP32[$11+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$11+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$11+12>>2]=HEAP32[$2+12>>2]|0;HEAP32[$11+16>>2]=HEAP32[$2+16>>2]|0;HEAP32[$11+20>>2]=HEAP32[$2+20>>2]|0;
 $12 = ((($0)) + 56|0);
 ;HEAP32[$12>>2]=HEAP32[$3>>2]|0;HEAP32[$12+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$12+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$12+12>>2]=HEAP32[$3+12>>2]|0;HEAP32[$12+16>>2]=HEAP32[$3+16>>2]|0;HEAP32[$12+20>>2]=HEAP32[$3+20>>2]|0;
 $13 = ((($0)) + 84|0);
 HEAP32[$13>>2] = 0;
 $14 = ((($0)) + 88|0);
 HEAP32[$14>>2] = 0;
 $15 = ((($0)) + 84|0);
 $16 = ((($0)) + 80|0);
 HEAP32[$16>>2] = $15;
 return;
}
function __ZN7osgUtil22LineSegmentIntersectorC2ENS_11Intersector15CoordinateFrameEdd($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = +$2;
 $3 = +$3;
 var $$sink = 0.0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 __ZN3osg10ReferencedC2Ev($0);
 $4 = ((($0)) + 12|0);
 HEAP32[$4>>2] = $1;
 $5 = ((($0)) + 16|0);
 HEAP32[$5>>2] = 0;
 $6 = ((($0)) + 20|0);
 HEAP32[$6>>2] = 0;
 $7 = ((($0)) + 24|0);
 HEAP32[$7>>2] = 0;
 HEAP32[$0>>2] = (48508);
 $8 = ((($0)) + 28|0);
 $9 = ((($0)) + 84|0);
 HEAP32[$9>>2] = 0;
 $10 = ((($0)) + 88|0);
 HEAP32[$10>>2] = 0;
 $11 = ((($0)) + 84|0);
 $12 = ((($0)) + 80|0);
 dest=$8; stop=dest+52|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAP32[$12>>2] = $11;
 switch ($1|0) {
 case 0:  {
  $$sink = 0.0;
  break;
 }
 case 1:  {
  $$sink = -1.0;
  break;
 }
 case 2:  {
  $$sink = 0.0;
  break;
 }
 case 3:  {
  $$sink = 0.0;
  break;
 }
 default: {
  return;
 }
 }
 $13 = ((($0)) + 32|0);
 HEAPF64[$13>>3] = $2;
 $14 = ((($0)) + 40|0);
 HEAPF64[$14>>3] = $3;
 $15 = ((($0)) + 48|0);
 HEAPF64[$15>>3] = $$sink;
 $16 = ((($0)) + 56|0);
 HEAPF64[$16>>3] = $2;
 $17 = ((($0)) + 64|0);
 HEAPF64[$17>>3] = $3;
 $18 = ((($0)) + 72|0);
 HEAPF64[$18>>3] = 1.0;
 return;
}
function __ZN7osgUtil20BaseOptimizerVisitorD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vii(3284,($0|0),((49204)|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  $3 = ((($0)) + 64|0);
  __ZN3osg6ObjectD2Ev($3);
  return;
 }
 $4 = ___cxa_find_matching_catch_2()|0;
 $5 = tempRet0;
 $6 = ((($0)) + 64|0);
 __THREW__ = 0;
 invoke_vi(388,($6|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch_3(0|0)|0;
  $10 = tempRet0;
  ___clang_call_terminate($9);
  // unreachable;
 } else {
  ___resumeException($4|0);
  // unreachable;
 }
}
function __ZN7osgUtil20BaseOptimizerVisitorD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vii(3284,($0|0),((49204)|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $6 = ___cxa_find_matching_catch_2()|0;
  $7 = tempRet0;
  $8 = ((($0)) + 64|0);
  __THREW__ = 0;
  invoke_vi(388,($8|0));
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if ($10) {
   $11 = ___cxa_find_matching_catch_3(0|0)|0;
   $12 = tempRet0;
   ___clang_call_terminate($11);
   // unreachable;
  } else {
   $eh$lpad$body$index2Z2D = $7;$eh$lpad$body$indexZ2D = $6;
   __ZdlPv($0);
   ___resumeException($eh$lpad$body$indexZ2D|0);
   // unreachable;
  }
 }
 $3 = ((($0)) + 64|0);
 __THREW__ = 0;
 invoke_vi(388,($3|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  __ZdlPv($0);
  return;
 }
 $13 = ___cxa_find_matching_catch_2()|0;
 $14 = tempRet0;
 $eh$lpad$body$index2Z2D = $14;$eh$lpad$body$indexZ2D = $13;
 __ZdlPv($0);
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
}
function __ZTv0_n16_N7osgUtil20BaseOptimizerVisitorD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __THREW__ = 0;
 invoke_vii(3284,($4|0),((49204)|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if (!($6)) {
  $14 = ((($4)) + 64|0);
  __ZN3osg6ObjectD2Ev($14);
  return;
 }
 $7 = ___cxa_find_matching_catch_2()|0;
 $8 = tempRet0;
 $9 = ((($4)) + 64|0);
 __THREW__ = 0;
 invoke_vi(388,($9|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if ($11) {
  $12 = ___cxa_find_matching_catch_3(0|0)|0;
  $13 = tempRet0;
  ___clang_call_terminate($12);
  // unreachable;
 } else {
  ___resumeException($7|0);
  // unreachable;
 }
}
function __ZTv0_n16_N7osgUtil20BaseOptimizerVisitorD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$i$index2Z2D = 0, $eh$lpad$body$i$indexZ2D = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __THREW__ = 0;
 invoke_vii(3284,($4|0),((49204)|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $10 = ___cxa_find_matching_catch_2()|0;
  $11 = tempRet0;
  $12 = ((($4)) + 64|0);
  __THREW__ = 0;
  invoke_vi(388,($12|0));
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if ($14) {
   $15 = ___cxa_find_matching_catch_3(0|0)|0;
   $16 = tempRet0;
   ___clang_call_terminate($15);
   // unreachable;
  } else {
   $eh$lpad$body$i$index2Z2D = $11;$eh$lpad$body$i$indexZ2D = $10;
   __ZdlPv($4);
   ___resumeException($eh$lpad$body$i$indexZ2D|0);
   // unreachable;
  }
 }
 $7 = ((($4)) + 64|0);
 __THREW__ = 0;
 invoke_vi(388,($7|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if (!($9)) {
  __ZdlPv($4);
  return;
 }
 $17 = ___cxa_find_matching_catch_2()|0;
 $18 = tempRet0;
 $eh$lpad$body$i$index2Z2D = $18;$eh$lpad$body$i$indexZ2D = $17;
 __ZdlPv($4);
 ___resumeException($eh$lpad$body$i$indexZ2D|0);
 // unreachable;
}
function __ZNSt3__26vectorIN3osg7ref_ptrINS1_4NodeEEENS_9allocatorIS4_EEE21__push_back_slow_pathIKS4_EEvRT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$06$i$i = 0, $$pre = 0, $$pre$i = 0, $$pre38 = 0, $$pre39 = 0, $$sroa$7$0 = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(1073741823);
 $9 = $4;
 $10 = $3;
 if ($8) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $11 = ((($0)) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) - ($4))|0;
 $14 = $13 >> 2;
 $15 = ($14>>>0)<(536870911);
 $16 = $13 >> 1;
 $17 = ($16>>>0)<($7>>>0);
 $$sroa$speculated$i = $17 ? $7 : $16;
 $$sroa$speculated$$i = $15 ? $$sroa$speculated$i : 1073741823;
 $18 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($18) {
   $28 = 0;
  } else {
   $19 = ($$sroa$speculated$$i>>>0)>(1073741823);
   if (!($19)) {
    $25 = $$sroa$speculated$$i << 2;
    $26 = (__Znwj($25)|0);
    $28 = $26;
    break;
   }
   $20 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($20|0),(204840|0));
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if ($22) {
    $23 = ___cxa_find_matching_catch_2()|0;
    $24 = tempRet0;
    ___cxa_free_exception(($20|0));
    ___resumeException($23|0);
    // unreachable;
   } else {
    HEAP32[$20>>2] = (99824);
    ___cxa_throw(($20|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $27 = (($28) + ($6<<2)|0);
 $29 = $27;
 $30 = (($28) + ($$sroa$speculated$$i<<2)|0);
 $31 = $30;
 $32 = HEAP32[$1>>2]|0;
 HEAP32[$27>>2] = $32;
 $33 = ($32|0)==(0|0);
 if ($33) {
  $38 = $10;$40 = $9;
 } else {
  $34 = ((($32)) + 8|0);
  $35 = HEAP32[$34>>2]|0;HEAP32[$34>>2] = (($35+1)|0);
  $$pre = HEAP32[$0>>2]|0;
  $$pre38 = HEAP32[$2>>2]|0;
  $38 = $$pre38;$40 = $$pre;
 }
 $36 = ((($27)) + 4|0);
 $37 = $36;
 $39 = ($38|0)==($40|0);
 if ($39) {
  $41 = $38;
  $53 = $29;$54 = $41;$56 = $38;
 } else {
  $$06$i$i = $38;$$sroa$7$0 = $29;$44 = $27;
  while(1) {
   $42 = ((($$06$i$i)) + -4|0);
   $43 = ((($44)) + -4|0);
   $45 = HEAP32[$42>>2]|0;
   HEAP32[$43>>2] = $45;
   $46 = ($45|0)==(0|0);
   if (!($46)) {
    $47 = ((($45)) + 8|0);
    $48 = HEAP32[$47>>2]|0;HEAP32[$47>>2] = (($48+1)|0);
   }
   $49 = $$sroa$7$0;
   $50 = ((($49)) + -4|0);
   $51 = $50;
   $52 = ($42|0)==($40|0);
   if ($52) {
    break;
   } else {
    $$06$i$i = $42;$$sroa$7$0 = $51;$44 = $50;
   }
  }
  $$pre$i = HEAP32[$0>>2]|0;
  $$pre39 = HEAP32[$2>>2]|0;
  $53 = $51;$54 = $$pre$i;$56 = $$pre39;
 }
 HEAP32[$0>>2] = $53;
 HEAP32[$2>>2] = $37;
 HEAP32[$11>>2] = $31;
 $55 = $54;
 $57 = ($56|0)==($55|0);
 L25: do {
  if (!($57)) {
   $59 = $56;
   while(1) {
    $58 = ((($59)) + -4|0);
    $60 = HEAP32[$58>>2]|0;
    $61 = ($60|0)==(0|0);
    if (!($61)) {
     $62 = ((($60)) + 8|0);
     $63 = HEAP32[$62>>2]|0;HEAP32[$62>>2] = (($63-1)|0);
     $64 = ($63|0)==(1);
     if ($64) {
      __THREW__ = 0;
      invoke_viii(3262,($60|0),1,1);
      $65 = __THREW__; __THREW__ = 0;
      $66 = $65&1;
      if ($66) {
       break;
      }
     }
    }
    HEAP32[$58>>2] = 0;
    $67 = ($58|0)==($55|0);
    if ($67) {
     break L25;
    } else {
     $59 = $58;
    }
   }
   $68 = ___cxa_find_matching_catch_2()|0;
   $69 = tempRet0;
   ___cxa_call_unexpected(($68|0));
   // unreachable;
  }
 } while(0);
 $70 = ($54|0)==(0);
 if ($70) {
  return;
 }
 $71 = $54;
 __ZdlPv($71);
 return;
}
function __ZNSt3__26vectorIN3osg7ref_ptrINS1_12PrimitiveSetEEENS_9allocatorIS4_EEE21__push_back_slow_pathIKS4_EEvRT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$06$i$i = 0, $$pre = 0, $$pre$i = 0, $$pre38 = 0, $$pre39 = 0, $$sroa$7$0 = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(1073741823);
 $9 = $4;
 $10 = $3;
 if ($8) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $11 = ((($0)) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) - ($4))|0;
 $14 = $13 >> 2;
 $15 = ($14>>>0)<(536870911);
 $16 = $13 >> 1;
 $17 = ($16>>>0)<($7>>>0);
 $$sroa$speculated$i = $17 ? $7 : $16;
 $$sroa$speculated$$i = $15 ? $$sroa$speculated$i : 1073741823;
 $18 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($18) {
   $28 = 0;
  } else {
   $19 = ($$sroa$speculated$$i>>>0)>(1073741823);
   if (!($19)) {
    $25 = $$sroa$speculated$$i << 2;
    $26 = (__Znwj($25)|0);
    $28 = $26;
    break;
   }
   $20 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($20|0),(204840|0));
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if ($22) {
    $23 = ___cxa_find_matching_catch_2()|0;
    $24 = tempRet0;
    ___cxa_free_exception(($20|0));
    ___resumeException($23|0);
    // unreachable;
   } else {
    HEAP32[$20>>2] = (99824);
    ___cxa_throw(($20|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $27 = (($28) + ($6<<2)|0);
 $29 = $27;
 $30 = (($28) + ($$sroa$speculated$$i<<2)|0);
 $31 = $30;
 $32 = HEAP32[$1>>2]|0;
 HEAP32[$27>>2] = $32;
 $33 = ($32|0)==(0|0);
 if ($33) {
  $38 = $10;$40 = $9;
 } else {
  $34 = ((($32)) + 8|0);
  $35 = HEAP32[$34>>2]|0;HEAP32[$34>>2] = (($35+1)|0);
  $$pre = HEAP32[$0>>2]|0;
  $$pre38 = HEAP32[$2>>2]|0;
  $38 = $$pre38;$40 = $$pre;
 }
 $36 = ((($27)) + 4|0);
 $37 = $36;
 $39 = ($38|0)==($40|0);
 if ($39) {
  $41 = $38;
  $53 = $29;$54 = $41;$56 = $38;
 } else {
  $$06$i$i = $38;$$sroa$7$0 = $29;$44 = $27;
  while(1) {
   $42 = ((($$06$i$i)) + -4|0);
   $43 = ((($44)) + -4|0);
   $45 = HEAP32[$42>>2]|0;
   HEAP32[$43>>2] = $45;
   $46 = ($45|0)==(0|0);
   if (!($46)) {
    $47 = ((($45)) + 8|0);
    $48 = HEAP32[$47>>2]|0;HEAP32[$47>>2] = (($48+1)|0);
   }
   $49 = $$sroa$7$0;
   $50 = ((($49)) + -4|0);
   $51 = $50;
   $52 = ($42|0)==($40|0);
   if ($52) {
    break;
   } else {
    $$06$i$i = $42;$$sroa$7$0 = $51;$44 = $50;
   }
  }
  $$pre$i = HEAP32[$0>>2]|0;
  $$pre39 = HEAP32[$2>>2]|0;
  $53 = $51;$54 = $$pre$i;$56 = $$pre39;
 }
 HEAP32[$0>>2] = $53;
 HEAP32[$2>>2] = $37;
 HEAP32[$11>>2] = $31;
 $55 = $54;
 $57 = ($56|0)==($55|0);
 L25: do {
  if (!($57)) {
   $59 = $56;
   while(1) {
    $58 = ((($59)) + -4|0);
    $60 = HEAP32[$58>>2]|0;
    $61 = ($60|0)==(0|0);
    if (!($61)) {
     $62 = ((($60)) + 8|0);
     $63 = HEAP32[$62>>2]|0;HEAP32[$62>>2] = (($63-1)|0);
     $64 = ($63|0)==(1);
     if ($64) {
      __THREW__ = 0;
      invoke_viii(3262,($60|0),1,1);
      $65 = __THREW__; __THREW__ = 0;
      $66 = $65&1;
      if ($66) {
       break;
      }
     }
    }
    HEAP32[$58>>2] = 0;
    $67 = ($58|0)==($55|0);
    if ($67) {
     break L25;
    } else {
     $59 = $58;
    }
   }
   $68 = ___cxa_find_matching_catch_2()|0;
   $69 = tempRet0;
   ___cxa_call_unexpected(($68|0));
   // unreachable;
  }
 } while(0);
 $70 = ($54|0)==(0);
 if ($70) {
  return;
 }
 $71 = $54;
 __ZdlPv($71);
 return;
}
function __ZN3osg12ArrayVisitorD2Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN3osg12ArrayVisitor5applyERNS_13TemplateArrayINS_5Vec2iELNS_5Array4TypeE15ELi2ELi5124EEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN3osg12ArrayVisitor5applyERNS_13TemplateArrayINS_5Vec3iELNS_5Array4TypeE16ELi3ELi5124EEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN3osg12ArrayVisitor5applyERNS_13TemplateArrayINS_5Vec4iELNS_5Array4TypeE17ELi4ELi5124EEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN3osg12ArrayVisitor5applyERNS_13TemplateArrayINS_6Vec2uiELNS_5Array4TypeE24ELi2ELi5125EEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN3osg12ArrayVisitor5applyERNS_13TemplateArrayINS_6Vec3uiELNS_5Array4TypeE25ELi3ELi5125EEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN3osg12ArrayVisitor5applyERNS_13TemplateArrayINS_6Vec4uiELNS_5Array4TypeE26ELi4ELi5125EEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN3osg12ArrayVisitor5applyERNS_13TemplateArrayINS_7MatrixfELNS_5Array4TypeE33ELi16ELi5126EEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN3osg12ArrayVisitor5applyERNS_13TemplateArrayINS_7MatrixdELNS_5Array4TypeE34ELi16ELi5130EEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN3osg12ArrayVisitor5applyERNS_18TemplateIndexArrayIyLNS_5Array4TypeE36ELi1ELi5135EEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN3osg12ArrayVisitor5applyERNS_18TemplateIndexArrayIxLNS_5Array4TypeE37ELi1ELi5134EEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZNSt3__26vectorIN3osg7MatrixdENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$06$i$i = 0, $$in = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0.0, $103 = 0, $104 = 0, $105 = 0.0, $106 = 0, $107 = 0, $108 = 0.0, $109 = 0, $11 = 0, $110 = 0, $111 = 0.0, $112 = 0, $113 = 0;
 var $114 = 0.0, $115 = 0, $116 = 0, $117 = 0.0, $118 = 0, $119 = 0, $12 = 0, $120 = 0.0, $121 = 0, $122 = 0, $123 = 0.0, $124 = 0, $125 = 0, $126 = 0.0, $127 = 0, $128 = 0, $129 = 0.0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0.0, $32 = 0, $33 = 0.0, $34 = 0, $35 = 0, $36 = 0.0, $37 = 0, $38 = 0, $39 = 0.0, $4 = 0, $40 = 0, $41 = 0, $42 = 0.0, $43 = 0, $44 = 0;
 var $45 = 0.0, $46 = 0, $47 = 0, $48 = 0.0, $49 = 0, $5 = 0, $50 = 0, $51 = 0.0, $52 = 0, $53 = 0, $54 = 0.0, $55 = 0, $56 = 0, $57 = 0.0, $58 = 0, $59 = 0, $6 = 0, $60 = 0.0, $61 = 0, $62 = 0;
 var $63 = 0.0, $64 = 0, $65 = 0, $66 = 0.0, $67 = 0, $68 = 0, $69 = 0.0, $7 = 0, $70 = 0, $71 = 0, $72 = 0.0, $73 = 0, $74 = 0, $75 = 0.0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0.0, $84 = 0, $85 = 0, $86 = 0, $87 = 0.0, $88 = 0, $89 = 0, $9 = 0, $90 = 0.0, $91 = 0, $92 = 0, $93 = 0.0, $94 = 0, $95 = 0, $96 = 0.0, $97 = 0, $98 = 0, $99 = 0.0;
 var $scevgep$i$i = 0, $scevgep9$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 7;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(33554431);
 $9 = $4;
 $10 = $3;
 if ($8) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $11 = ((($0)) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) - ($4))|0;
 $14 = $13 >> 7;
 $15 = ($14>>>0)<(16777215);
 $16 = $13 >> 6;
 $17 = ($16>>>0)<($7>>>0);
 $$sroa$speculated$i = $17 ? $7 : $16;
 $$sroa$speculated$$i = $15 ? $$sroa$speculated$i : 33554431;
 $18 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($18) {
   $28 = 0;
  } else {
   $19 = ($$sroa$speculated$$i>>>0)>(33554431);
   if (!($19)) {
    $25 = $$sroa$speculated$$i << 7;
    $26 = (__Znwj($25)|0);
    $28 = $26;
    break;
   }
   $20 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($20|0),(204840|0));
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if ($22) {
    $23 = ___cxa_find_matching_catch_2()|0;
    $24 = tempRet0;
    ___cxa_free_exception(($20|0));
    ___resumeException($23|0);
    // unreachable;
   } else {
    HEAP32[$20>>2] = (99824);
    ___cxa_throw(($20|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $27 = (($28) + ($6<<7)|0);
 $29 = (($28) + ($$sroa$speculated$$i<<7)|0);
 $30 = $29;
 $31 = +HEAPF64[$1>>3];
 HEAPF64[$27>>3] = $31;
 $32 = ((($1)) + 8|0);
 $33 = +HEAPF64[$32>>3];
 $34 = (((($28) + ($6<<7)|0)) + 8|0);
 HEAPF64[$34>>3] = $33;
 $35 = ((($1)) + 16|0);
 $36 = +HEAPF64[$35>>3];
 $37 = (((($28) + ($6<<7)|0)) + 16|0);
 HEAPF64[$37>>3] = $36;
 $38 = ((($1)) + 24|0);
 $39 = +HEAPF64[$38>>3];
 $40 = (((($28) + ($6<<7)|0)) + 24|0);
 HEAPF64[$40>>3] = $39;
 $41 = ((($1)) + 32|0);
 $42 = +HEAPF64[$41>>3];
 $43 = (((($28) + ($6<<7)|0)) + 32|0);
 HEAPF64[$43>>3] = $42;
 $44 = ((($1)) + 40|0);
 $45 = +HEAPF64[$44>>3];
 $46 = (((($28) + ($6<<7)|0)) + 40|0);
 HEAPF64[$46>>3] = $45;
 $47 = ((($1)) + 48|0);
 $48 = +HEAPF64[$47>>3];
 $49 = (((($28) + ($6<<7)|0)) + 48|0);
 HEAPF64[$49>>3] = $48;
 $50 = ((($1)) + 56|0);
 $51 = +HEAPF64[$50>>3];
 $52 = (((($28) + ($6<<7)|0)) + 56|0);
 HEAPF64[$52>>3] = $51;
 $53 = ((($1)) + 64|0);
 $54 = +HEAPF64[$53>>3];
 $55 = (((($28) + ($6<<7)|0)) + 64|0);
 HEAPF64[$55>>3] = $54;
 $56 = ((($1)) + 72|0);
 $57 = +HEAPF64[$56>>3];
 $58 = (((($28) + ($6<<7)|0)) + 72|0);
 HEAPF64[$58>>3] = $57;
 $59 = ((($1)) + 80|0);
 $60 = +HEAPF64[$59>>3];
 $61 = (((($28) + ($6<<7)|0)) + 80|0);
 HEAPF64[$61>>3] = $60;
 $62 = ((($1)) + 88|0);
 $63 = +HEAPF64[$62>>3];
 $64 = (((($28) + ($6<<7)|0)) + 88|0);
 HEAPF64[$64>>3] = $63;
 $65 = ((($1)) + 96|0);
 $66 = +HEAPF64[$65>>3];
 $67 = (((($28) + ($6<<7)|0)) + 96|0);
 HEAPF64[$67>>3] = $66;
 $68 = ((($1)) + 104|0);
 $69 = +HEAPF64[$68>>3];
 $70 = (((($28) + ($6<<7)|0)) + 104|0);
 HEAPF64[$70>>3] = $69;
 $71 = ((($1)) + 112|0);
 $72 = +HEAPF64[$71>>3];
 $73 = (((($28) + ($6<<7)|0)) + 112|0);
 HEAPF64[$73>>3] = $72;
 $74 = ((($1)) + 120|0);
 $75 = +HEAPF64[$74>>3];
 $76 = (((($28) + ($6<<7)|0)) + 120|0);
 HEAPF64[$76>>3] = $75;
 $77 = ((($27)) + 128|0);
 $78 = $77;
 $79 = ($10|0)==($9|0);
 if ($79) {
  $$in = $27;
 } else {
  $scevgep$i$i = ((($10)) + -128|0);
  $80 = $scevgep$i$i;
  $81 = (($80) - ($4))|0;
  $$06$i$i = $10;$85 = $27;
  while(1) {
   $82 = ((($$06$i$i)) + -128|0);
   $83 = +HEAPF64[$82>>3];
   $84 = ((($85)) + -128|0);
   HEAPF64[$84>>3] = $83;
   $86 = ((($$06$i$i)) + -120|0);
   $87 = +HEAPF64[$86>>3];
   $88 = ((($85)) + -120|0);
   HEAPF64[$88>>3] = $87;
   $89 = ((($$06$i$i)) + -112|0);
   $90 = +HEAPF64[$89>>3];
   $91 = ((($85)) + -112|0);
   HEAPF64[$91>>3] = $90;
   $92 = ((($$06$i$i)) + -104|0);
   $93 = +HEAPF64[$92>>3];
   $94 = ((($85)) + -104|0);
   HEAPF64[$94>>3] = $93;
   $95 = ((($$06$i$i)) + -96|0);
   $96 = +HEAPF64[$95>>3];
   $97 = ((($85)) + -96|0);
   HEAPF64[$97>>3] = $96;
   $98 = ((($$06$i$i)) + -88|0);
   $99 = +HEAPF64[$98>>3];
   $100 = ((($85)) + -88|0);
   HEAPF64[$100>>3] = $99;
   $101 = ((($$06$i$i)) + -80|0);
   $102 = +HEAPF64[$101>>3];
   $103 = ((($85)) + -80|0);
   HEAPF64[$103>>3] = $102;
   $104 = ((($$06$i$i)) + -72|0);
   $105 = +HEAPF64[$104>>3];
   $106 = ((($85)) + -72|0);
   HEAPF64[$106>>3] = $105;
   $107 = ((($$06$i$i)) + -64|0);
   $108 = +HEAPF64[$107>>3];
   $109 = ((($85)) + -64|0);
   HEAPF64[$109>>3] = $108;
   $110 = ((($$06$i$i)) + -56|0);
   $111 = +HEAPF64[$110>>3];
   $112 = ((($85)) + -56|0);
   HEAPF64[$112>>3] = $111;
   $113 = ((($$06$i$i)) + -48|0);
   $114 = +HEAPF64[$113>>3];
   $115 = ((($85)) + -48|0);
   HEAPF64[$115>>3] = $114;
   $116 = ((($$06$i$i)) + -40|0);
   $117 = +HEAPF64[$116>>3];
   $118 = ((($85)) + -40|0);
   HEAPF64[$118>>3] = $117;
   $119 = ((($$06$i$i)) + -32|0);
   $120 = +HEAPF64[$119>>3];
   $121 = ((($85)) + -32|0);
   HEAPF64[$121>>3] = $120;
   $122 = ((($$06$i$i)) + -24|0);
   $123 = +HEAPF64[$122>>3];
   $124 = ((($85)) + -24|0);
   HEAPF64[$124>>3] = $123;
   $125 = ((($$06$i$i)) + -16|0);
   $126 = +HEAPF64[$125>>3];
   $127 = ((($85)) + -16|0);
   HEAPF64[$127>>3] = $126;
   $128 = ((($$06$i$i)) + -8|0);
   $129 = +HEAPF64[$128>>3];
   $130 = ((($85)) + -8|0);
   HEAPF64[$130>>3] = $129;
   $131 = ((($85)) + -128|0);
   $132 = ($82|0)==($9|0);
   if ($132) {
    break;
   } else {
    $$06$i$i = $82;$85 = $131;
   }
  }
  $133 = $81 >>> 7;
  $134 = $133 ^ -1;
  $scevgep9$i$i = (($27) + ($134<<7)|0);
  $$in = $scevgep9$i$i;
 }
 $135 = $$in;
 HEAP32[$0>>2] = $135;
 HEAP32[$2>>2] = $78;
 HEAP32[$11>>2] = $30;
 $136 = ($4|0)==(0);
 if ($136) {
  return;
 }
 $137 = $4;
 __ZdlPv($137);
 return;
}
function __ZNKSt3__215basic_stringbufIcNS_11char_traitsIcEENS_9allocatorIcEEE3strEv($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$021$lcssa$i$i = 0, $$021$lcssa$i$i8 = 0, $$021$ph$i$i = 0, $$021$ph$i$i1 = 0, $$02122$i$i = 0, $$02122$i$i4 = 0, $$023$i$i = 0, $$023$i$i3 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $scevgep25$i$i = 0, $scevgep25$i$i6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 & 16;
 $5 = ($4|0)==(0);
 if (!($5)) {
  $6 = ((($1)) + 44|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ((($1)) + 24|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($7>>>0)<($9>>>0);
  if ($10) {
   HEAP32[$6>>2] = $9;
   $14 = $9;
  } else {
   $14 = $7;
  }
  $11 = ((($1)) + 20|0);
  $12 = HEAP32[$11>>2]|0;
  ;HEAP32[$0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;
  $13 = $12;
  $15 = $14;
  $16 = (($15) - ($13))|0;
  $17 = ($16>>>0)>(4294967279);
  if ($17) {
   __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv($0);
   // unreachable;
  }
  $18 = ($16>>>0)<(11);
  if ($18) {
   $19 = $16&255;
   $20 = ((($0)) + 11|0);
   HEAP8[$20>>0] = $19;
   $$021$ph$i$i1 = $0;
  } else {
   $21 = (($16) + 16)|0;
   $22 = $21 & -16;
   $23 = (__Znwj($22)|0);
   HEAP32[$0>>2] = $23;
   $24 = $22 | -2147483648;
   $25 = ((($0)) + 8|0);
   HEAP32[$25>>2] = $24;
   $26 = ((($0)) + 4|0);
   HEAP32[$26>>2] = $16;
   $$021$ph$i$i1 = $23;
  }
  $27 = ($12|0)==($14|0);
  if ($27) {
   $$021$lcssa$i$i8 = $$021$ph$i$i1;
  } else {
   $$02122$i$i4 = $$021$ph$i$i1;$$023$i$i3 = $12;
   while(1) {
    $28 = HEAP8[$$023$i$i3>>0]|0;
    HEAP8[$$02122$i$i4>>0] = $28;
    $29 = ((($$023$i$i3)) + 1|0);
    $30 = ((($$02122$i$i4)) + 1|0);
    $31 = ($29|0)==($14|0);
    if ($31) {
     break;
    } else {
     $$02122$i$i4 = $30;$$023$i$i3 = $29;
    }
   }
   $scevgep25$i$i6 = (($$021$ph$i$i1) + ($16)|0);
   $$021$lcssa$i$i8 = $scevgep25$i$i6;
  }
  HEAP8[$$021$lcssa$i$i8>>0] = 0;
  return;
 }
 $32 = $3 & 8;
 $33 = ($32|0)==(0);
 if ($33) {
  ;HEAP32[$0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;
  return;
 }
 $34 = ((($1)) + 8|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = ((($1)) + 16|0);
 $37 = HEAP32[$36>>2]|0;
 ;HEAP32[$0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;
 $38 = $35;
 $39 = $37;
 $40 = (($39) - ($38))|0;
 $41 = ($40>>>0)>(4294967279);
 if ($41) {
  __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $42 = ($40>>>0)<(11);
 if ($42) {
  $43 = $40&255;
  $44 = ((($0)) + 11|0);
  HEAP8[$44>>0] = $43;
  $$021$ph$i$i = $0;
 } else {
  $45 = (($40) + 16)|0;
  $46 = $45 & -16;
  $47 = (__Znwj($46)|0);
  HEAP32[$0>>2] = $47;
  $48 = $46 | -2147483648;
  $49 = ((($0)) + 8|0);
  HEAP32[$49>>2] = $48;
  $50 = ((($0)) + 4|0);
  HEAP32[$50>>2] = $40;
  $$021$ph$i$i = $47;
 }
 $51 = ($35|0)==($37|0);
 if ($51) {
  $$021$lcssa$i$i = $$021$ph$i$i;
 } else {
  $$02122$i$i = $$021$ph$i$i;$$023$i$i = $35;
  while(1) {
   $52 = HEAP8[$$023$i$i>>0]|0;
   HEAP8[$$02122$i$i>>0] = $52;
   $53 = ((($$023$i$i)) + 1|0);
   $54 = ((($$02122$i$i)) + 1|0);
   $55 = ($53|0)==($37|0);
   if ($55) {
    break;
   } else {
    $$02122$i$i = $54;$$023$i$i = $53;
   }
  }
  $scevgep25$i$i = (($$021$ph$i$i) + ($40)|0);
  $$021$lcssa$i$i = $scevgep25$i$i;
 }
 HEAP8[$$021$lcssa$i$i>>0] = 0;
 return;
}
function __ZNSt3__218basic_stringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = ((49228));
 $1 = ((($0)) + 64|0);
 HEAP32[$1>>2] = ((49268));
 $2 = ((($0)) + 8|0);
 HEAP32[$2>>2] = ((49248));
 $3 = ((($0)) + 12|0);
 HEAP32[$3>>2] = (37132);
 $4 = ((($0)) + 44|0);
 $5 = ((($4)) + 11|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = ($6<<24>>24)<(0);
 if ($7) {
  $8 = HEAP32[$4>>2]|0;
  __ZdlPv($8);
 }
 __THREW__ = 0;
 invoke_vi(2911,($3|0));
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 do {
  if ($10) {
   $13 = ___cxa_find_matching_catch_2()|0;
   $14 = tempRet0;
   __THREW__ = 0;
   invoke_vii(3568,($0|0),((49280)|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if ($16) {
    $17 = ___cxa_find_matching_catch_3(0|0)|0;
    $18 = tempRet0;
    ___clang_call_terminate($17);
    // unreachable;
   } else {
    $eh$lpad$body$index2Z2D = $14;$eh$lpad$body$indexZ2D = $13;
   }
  } else {
   __THREW__ = 0;
   invoke_vii(3568,($0|0),((49280)|0));
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if ($12) {
    $19 = ___cxa_find_matching_catch_2()|0;
    $20 = tempRet0;
    $eh$lpad$body$index2Z2D = $20;$eh$lpad$body$indexZ2D = $19;
    break;
   } else {
    __ZNSt3__29basic_iosIcNS_11char_traitsIcEEED2Ev($1);
    return;
   }
  }
 } while(0);
 __THREW__ = 0;
 invoke_vi(2907,($1|0));
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if ($22) {
  $23 = ___cxa_find_matching_catch_3(0|0)|0;
  $24 = tempRet0;
  ___clang_call_terminate($23);
  // unreachable;
 } else {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
}
function __ZNSt3__218basic_stringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1045,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZThn8_NSt3__218basic_stringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -8|0);
 __ZNSt3__218basic_stringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($1);
 return;
}
function __ZThn8_NSt3__218basic_stringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -8|0);
 __THREW__ = 0;
 invoke_vi(1045,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch_2()|0;
  $5 = tempRet0;
  __ZdlPv($1);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZdlPv($1);
  return;
 }
}
function __ZTv0_n12_NSt3__218basic_stringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __ZNSt3__218basic_stringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($4);
 return;
}
function __ZTv0_n12_NSt3__218basic_stringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __THREW__ = 0;
 invoke_vi(1045,($4|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $7 = ___cxa_find_matching_catch_2()|0;
  $8 = tempRet0;
  __ZdlPv($4);
  ___resumeException($7|0);
  // unreachable;
 } else {
  __ZdlPv($4);
  return;
 }
}
function __ZNSt3__26vectorIPN3osg8StateSetENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(1073741823);
 if ($8) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $9 = ((($0)) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) - ($4))|0;
 $12 = $11 >> 2;
 $13 = ($12>>>0)<(536870911);
 $14 = $11 >> 1;
 $15 = ($14>>>0)<($7>>>0);
 $$sroa$speculated$i = $15 ? $7 : $14;
 $$sroa$speculated$$i = $13 ? $$sroa$speculated$i : 1073741823;
 $16 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($16) {
   $26 = 0;
  } else {
   $17 = ($$sroa$speculated$$i>>>0)>(1073741823);
   if (!($17)) {
    $23 = $$sroa$speculated$$i << 2;
    $24 = (__Znwj($23)|0);
    $26 = $24;
    break;
   }
   $18 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($18|0),(204840|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if ($20) {
    $21 = ___cxa_find_matching_catch_2()|0;
    $22 = tempRet0;
    ___cxa_free_exception(($18|0));
    ___resumeException($21|0);
    // unreachable;
   } else {
    HEAP32[$18>>2] = (99824);
    ___cxa_throw(($18|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $25 = (($26) + ($6<<2)|0);
 $27 = (($26) + ($$sroa$speculated$$i<<2)|0);
 $28 = $27;
 $29 = HEAP32[$1>>2]|0;
 HEAP32[$25>>2] = $29;
 $30 = ((($25)) + 4|0);
 $31 = $30;
 $32 = (0 - ($6))|0;
 $33 = (($25) + ($32<<2)|0);
 $34 = $33;
 $35 = ($5|0)>(0);
 if ($35) {
  $36 = $4;
  _memcpy(($33|0),($36|0),($5|0))|0;
 }
 HEAP32[$0>>2] = $34;
 HEAP32[$2>>2] = $31;
 HEAP32[$9>>2] = $28;
 $37 = ($4|0)==(0);
 if ($37) {
  return;
 }
 $38 = $4;
 __ZdlPv($38);
 return;
}
function __ZN7osgUtil9Optimizer28StaticObjectDetectionVisitorD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vii(3284,($0|0),((48688)|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  $3 = ((($0)) + 64|0);
  __ZN3osg6ObjectD2Ev($3);
  return;
 }
 $4 = ___cxa_find_matching_catch_2()|0;
 $5 = tempRet0;
 $6 = ((($0)) + 64|0);
 __THREW__ = 0;
 invoke_vi(388,($6|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch_3(0|0)|0;
  $10 = tempRet0;
  ___clang_call_terminate($9);
  // unreachable;
 } else {
  ___resumeException($4|0);
  // unreachable;
 }
}
function __ZN7osgUtil9Optimizer28StaticObjectDetectionVisitorD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vii(3284,($0|0),((48688)|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $6 = ___cxa_find_matching_catch_2()|0;
  $7 = tempRet0;
  $8 = ((($0)) + 64|0);
  __THREW__ = 0;
  invoke_vi(388,($8|0));
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if ($10) {
   $11 = ___cxa_find_matching_catch_3(0|0)|0;
   $12 = tempRet0;
   ___clang_call_terminate($11);
   // unreachable;
  } else {
   $eh$lpad$body$index2Z2D = $7;$eh$lpad$body$indexZ2D = $6;
   __ZdlPv($0);
   ___resumeException($eh$lpad$body$indexZ2D|0);
   // unreachable;
  }
 }
 $3 = ((($0)) + 64|0);
 __THREW__ = 0;
 invoke_vi(388,($3|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  __ZdlPv($0);
  return;
 }
 $13 = ___cxa_find_matching_catch_2()|0;
 $14 = tempRet0;
 $eh$lpad$body$index2Z2D = $14;$eh$lpad$body$indexZ2D = $13;
 __ZdlPv($0);
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
}
function __ZN7osgUtil9Optimizer28StaticObjectDetectionVisitor5applyERN3osg8DrawableE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 120|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = HEAP32[$3>>2]|0;
  $6 = ((($5)) + 116|0);
  $7 = HEAP32[$6>>2]|0;
  FUNCTION_TABLE_vi[$7 & 8191]($3);
 }
 $8 = HEAP32[$1>>2]|0;
 $9 = ((($8)) + 116|0);
 $10 = HEAP32[$9>>2]|0;
 FUNCTION_TABLE_vi[$10 & 8191]($1);
 return;
}
function __ZN7osgUtil9Optimizer28StaticObjectDetectionVisitor5applyERN3osg4NodeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 120|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = HEAP32[$3>>2]|0;
  $6 = ((($5)) + 116|0);
  $7 = HEAP32[$6>>2]|0;
  FUNCTION_TABLE_vi[$7 & 8191]($3);
 }
 $8 = ((($0)) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 switch ($9|0) {
 case 1:  {
  $10 = HEAP32[$1>>2]|0;
  $11 = ((($10)) + 192|0);
  $12 = HEAP32[$11>>2]|0;
  FUNCTION_TABLE_vii[$12 & 8191]($1,$0);
  return;
  break;
 }
 case 0:  {
  return;
  break;
 }
 default: {
  $13 = HEAP32[$1>>2]|0;
  $14 = ((($13)) + 196|0);
  $15 = HEAP32[$14>>2]|0;
  FUNCTION_TABLE_vii[$15 & 8191]($1,$0);
  return;
 }
 }
}
function __ZTv0_n16_N7osgUtil9Optimizer28StaticObjectDetectionVisitorD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __THREW__ = 0;
 invoke_vii(3284,($4|0),((48688)|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if (!($6)) {
  $14 = ((($4)) + 64|0);
  __ZN3osg6ObjectD2Ev($14);
  return;
 }
 $7 = ___cxa_find_matching_catch_2()|0;
 $8 = tempRet0;
 $9 = ((($4)) + 64|0);
 __THREW__ = 0;
 invoke_vi(388,($9|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if ($11) {
  $12 = ___cxa_find_matching_catch_3(0|0)|0;
  $13 = tempRet0;
  ___clang_call_terminate($12);
  // unreachable;
 } else {
  ___resumeException($7|0);
  // unreachable;
 }
}
function __ZTv0_n16_N7osgUtil9Optimizer28StaticObjectDetectionVisitorD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$i$index2Z2D = 0, $eh$lpad$body$i$indexZ2D = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __THREW__ = 0;
 invoke_vii(3284,($4|0),((48688)|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $10 = ___cxa_find_matching_catch_2()|0;
  $11 = tempRet0;
  $12 = ((($4)) + 64|0);
  __THREW__ = 0;
  invoke_vi(388,($12|0));
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if ($14) {
   $15 = ___cxa_find_matching_catch_3(0|0)|0;
   $16 = tempRet0;
   ___clang_call_terminate($15);
   // unreachable;
  } else {
   $eh$lpad$body$i$index2Z2D = $11;$eh$lpad$body$i$indexZ2D = $10;
   __ZdlPv($4);
   ___resumeException($eh$lpad$body$i$indexZ2D|0);
   // unreachable;
  }
 }
 $7 = ((($4)) + 64|0);
 __THREW__ = 0;
 invoke_vi(388,($7|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if (!($9)) {
  __ZdlPv($4);
  return;
 }
 $17 = ___cxa_find_matching_catch_2()|0;
 $18 = tempRet0;
 $eh$lpad$body$i$index2Z2D = $18;$eh$lpad$body$i$indexZ2D = $17;
 __ZdlPv($4);
 ___resumeException($eh$lpad$body$i$indexZ2D|0);
 // unreachable;
}
function __GLOBAL__sub_I_Optimizer_cpp() {
 var $$0$i = 0, $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0;
 var label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $0 = sp + 12|0;
 $1 = sp;
 HEAPF32[51995] = 1.0;
 HEAPF32[(207984)>>2] = 0.0;
 HEAPF32[(207988)>>2] = 0.0;
 HEAPF32[51998] = 0.0;
 HEAPF32[(207996)>>2] = 1.0;
 HEAPF32[(208000)>>2] = 0.0;
 HEAPF32[52001] = 0.0;
 HEAPF32[(208008)>>2] = 0.0;
 HEAPF32[(208012)>>2] = 1.0;
 $2 = (__Znwj(32)|0);
 HEAP32[$0>>2] = $2;
 $3 = ((($0)) + 8|0);
 HEAP32[$3>>2] = -2147483616;
 $4 = ((($0)) + 4|0);
 HEAP32[$4>>2] = 31;
 dest=$2; src=112145; stop=dest+31|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $5 = ((($2)) + 31|0);
 HEAP8[$5>>0] = 0;
 ;HEAP32[$1>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;
 __THREW__ = 0;
 $6 = (invoke_ii(3276,528)|0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $25 = ___cxa_find_matching_catch_2()|0;
  $26 = tempRet0;
  $$0$i = $26;$$01$i = $25;
 } else {
  HEAP32[$1>>2] = $6;
  $9 = ((($1)) + 8|0);
  HEAP32[$9>>2] = -2147483120;
  $10 = ((($1)) + 4|0);
  HEAP32[$10>>2] = 515;
  _memcpy(($6|0),(112177|0),515)|0;
  $11 = ((($6)) + 515|0);
  HEAP8[$11>>0] = 0;
  __THREW__ = 0;
  $12 = (invoke_i(3459)|0);
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if (!($14)) {
   __THREW__ = 0;
   invoke_viiii(3460,($12|0),2,($0|0),($1|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    $17 = ((($1)) + 11|0);
    $18 = HEAP8[$17>>0]|0;
    $19 = ($18<<24>>24)<(0);
    if ($19) {
     $20 = HEAP32[$1>>2]|0;
     __ZdlPv($20);
    }
    $21 = ((($0)) + 11|0);
    $22 = HEAP8[$21>>0]|0;
    $23 = ($22<<24>>24)<(0);
    if (!($23)) {
     STACKTOP = sp;return;
    }
    $24 = HEAP32[$0>>2]|0;
    __ZdlPv($24);
    STACKTOP = sp;return;
   }
  }
  $27 = ___cxa_find_matching_catch_2()|0;
  $28 = tempRet0;
  $29 = ((($1)) + 11|0);
  $30 = HEAP8[$29>>0]|0;
  $31 = ($30<<24>>24)<(0);
  if ($31) {
   $32 = HEAP32[$1>>2]|0;
   __ZdlPv($32);
   $$0$i = $28;$$01$i = $27;
  } else {
   $$0$i = $28;$$01$i = $27;
  }
 }
 $33 = ((($0)) + 11|0);
 $34 = HEAP8[$33>>0]|0;
 $35 = ($34<<24>>24)<(0);
 if (!($35)) {
  ___resumeException($$01$i|0);
  // unreachable;
 }
 $36 = HEAP32[$0>>2]|0;
 __ZdlPv($36);
 ___resumeException($$01$i|0);
 // unreachable;
}
function __ZN7osgUtil14RayIntersectorD2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (49324);
 $1 = ((($0)) + 80|0);
 $2 = ((($0)) + 84|0);
 $3 = HEAP32[$2>>2]|0;
 __ZNSt3__26__treeIN7osgUtil14RayIntersector12IntersectionENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($1,$3);
 __ZN3osg10ReferencedD2Ev($0);
 return;
}
function __ZN7osgUtil14RayIntersectorD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (49324);
 $1 = ((($0)) + 80|0);
 $2 = ((($0)) + 84|0);
 $3 = HEAP32[$2>>2]|0;
 __ZNSt3__26__treeIN7osgUtil14RayIntersector12IntersectionENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($1,$3);
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch_2()|0;
  $7 = tempRet0;
  __ZdlPv($0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZN7osgUtil14RayIntersector5cloneERNS_19IntersectionVisitorE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$010$in = 0, $$05 = 0, $$4 = 0, $$49 = 0, $$sroa$020$0$$sroa_idx = 0, $$sroa$062$0$$sroa_idx = 0, $$sroa$523$0$$sroa_idx26 = 0, $$sroa$6$0$$sroa_idx29 = 0, $$sroa$665$0$$sroa_idx68 = 0, $$sroa$8$0$$sroa_idx71 = 0, $10 = 0, $100 = 0, $101 = 0.0, $102 = 0.0, $103 = 0, $104 = 0.0, $105 = 0.0, $106 = 0, $107 = 0.0;
 var $108 = 0.0, $109 = 0.0, $11 = 0, $110 = 0.0, $111 = 0.0, $112 = 0.0, $113 = 0.0, $114 = 0.0, $115 = 0.0, $116 = 0.0, $117 = 0.0, $118 = 0.0, $119 = 0.0, $12 = 0, $120 = 0.0, $121 = 0.0, $122 = 0.0, $123 = 0.0, $124 = 0.0, $125 = 0.0;
 var $126 = 0.0, $127 = 0.0, $128 = 0.0, $129 = 0.0, $13 = 0, $130 = 0.0, $131 = 0.0, $132 = 0.0, $133 = 0.0, $134 = 0.0, $135 = 0.0, $136 = 0.0, $137 = 0.0, $138 = 0.0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0.0;
 var $37 = 0, $38 = 0.0, $39 = 0.0, $4 = 0, $40 = 0, $41 = 0.0, $42 = 0, $43 = 0.0, $44 = 0.0, $45 = 0.0, $46 = 0, $47 = 0.0, $48 = 0, $49 = 0.0, $5 = 0, $50 = 0.0, $51 = 0.0, $52 = 0, $53 = 0.0, $54 = 0.0;
 var $55 = 0.0, $56 = 0.0, $57 = 0.0, $58 = 0, $59 = 0.0, $6 = 0, $60 = 0.0, $61 = 0.0, $62 = 0, $63 = 0.0, $64 = 0.0, $65 = 0.0, $66 = 0, $67 = 0.0, $68 = 0.0, $69 = 0.0, $7 = 0, $70 = 0, $71 = 0.0, $72 = 0.0;
 var $73 = 0, $74 = 0.0, $75 = 0.0, $76 = 0.0, $77 = 0, $78 = 0.0, $79 = 0.0, $8 = 0, $80 = 0.0, $81 = 0, $82 = 0.0, $83 = 0.0, $84 = 0.0, $85 = 0, $86 = 0.0, $87 = 0.0, $88 = 0, $89 = 0.0, $9 = 0, $90 = 0.0;
 var $91 = 0.0, $92 = 0, $93 = 0.0, $94 = 0.0, $95 = 0.0, $96 = 0, $97 = 0.0, $98 = 0.0, $99 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(128|0);
 $2 = sp;
 $3 = ((($0)) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(3);
 do {
  if ($5) {
   $6 = ((($1)) + 120|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($7|0)==(0);
   if (!($8)) {
    $9 = ((($1)) + 112|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = ((($10)) + 8|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ($12|0)==(0|0);
    if (!($13)) {
     break;
    }
   }
   $14 = (__Znwj(96)|0);
   $15 = ((($0)) + 16|0);
   $16 = HEAP32[$15>>2]|0;
   __THREW__ = 0;
   invoke_vi(3282,($14|0));
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if ($18) {
    $33 = ___cxa_find_matching_catch_2()|0;
    $34 = tempRet0;
    __ZdlPv($14);
    $$4 = $34;$$49 = $33;
    ___resumeException($$49|0);
    // unreachable;
   } else {
    $19 = ((($0)) + 56|0);
    $20 = ((($0)) + 32|0);
    $21 = ((($14)) + 12|0);
    HEAP32[$21>>2] = 3;
    $22 = ((($14)) + 16|0);
    HEAP32[$22>>2] = $16;
    $23 = ((($14)) + 20|0);
    HEAP32[$23>>2] = 0;
    $24 = ((($14)) + 24|0);
    HEAP32[$14>>2] = (49324);
    $25 = ((($14)) + 28|0);
    HEAP32[$25>>2] = $0;
    $26 = ((($14)) + 32|0);
    ;HEAP32[$26>>2]=HEAP32[$20>>2]|0;HEAP32[$26+4>>2]=HEAP32[$20+4>>2]|0;HEAP32[$26+8>>2]=HEAP32[$20+8>>2]|0;HEAP32[$26+12>>2]=HEAP32[$20+12>>2]|0;HEAP32[$26+16>>2]=HEAP32[$20+16>>2]|0;HEAP32[$26+20>>2]=HEAP32[$20+20>>2]|0;
    $27 = ((($14)) + 56|0);
    ;HEAP32[$27>>2]=HEAP32[$19>>2]|0;HEAP32[$27+4>>2]=HEAP32[$19+4>>2]|0;HEAP32[$27+8>>2]=HEAP32[$19+8>>2]|0;HEAP32[$27+12>>2]=HEAP32[$19+12>>2]|0;HEAP32[$27+16>>2]=HEAP32[$19+16>>2]|0;HEAP32[$27+20>>2]=HEAP32[$19+20>>2]|0;
    $28 = ((($14)) + 84|0);
    HEAP32[$28>>2] = 0;
    $29 = ((($14)) + 88|0);
    HEAP32[$29>>2] = 0;
    $30 = ((($14)) + 80|0);
    HEAP32[$30>>2] = $28;
    $31 = ((($0)) + 24|0);
    $32 = HEAP32[$31>>2]|0;
    HEAP32[$24>>2] = $32;
    $$010$in = $14;
    STACKTOP = sp;return ($$010$in|0);
   }
  }
 } while(0);
 __ZN7osgUtil22LineSegmentIntersector17getTransformationERNS_19IntersectionVisitorENS_11Intersector15CoordinateFrameE($2,$1,$4);
 $35 = ((($2)) + 24|0);
 $36 = +HEAPF64[$35>>3];
 $37 = ((($0)) + 32|0);
 $38 = +HEAPF64[$37>>3];
 $39 = $36 * $38;
 $40 = ((($2)) + 56|0);
 $41 = +HEAPF64[$40>>3];
 $42 = ((($0)) + 40|0);
 $43 = +HEAPF64[$42>>3];
 $44 = $41 * $43;
 $45 = $39 + $44;
 $46 = ((($2)) + 88|0);
 $47 = +HEAPF64[$46>>3];
 $48 = ((($0)) + 48|0);
 $49 = +HEAPF64[$48>>3];
 $50 = $47 * $49;
 $51 = $45 + $50;
 $52 = ((($2)) + 120|0);
 $53 = +HEAPF64[$52>>3];
 $54 = $53 + $51;
 $55 = 1.0 / $54;
 $56 = +HEAPF64[$2>>3];
 $57 = $38 * $56;
 $58 = ((($2)) + 32|0);
 $59 = +HEAPF64[$58>>3];
 $60 = $43 * $59;
 $61 = $57 + $60;
 $62 = ((($2)) + 64|0);
 $63 = +HEAPF64[$62>>3];
 $64 = $49 * $63;
 $65 = $61 + $64;
 $66 = ((($2)) + 96|0);
 $67 = +HEAPF64[$66>>3];
 $68 = $67 + $65;
 $69 = $55 * $68;
 $70 = ((($2)) + 8|0);
 $71 = +HEAPF64[$70>>3];
 $72 = $38 * $71;
 $73 = ((($2)) + 40|0);
 $74 = +HEAPF64[$73>>3];
 $75 = $43 * $74;
 $76 = $72 + $75;
 $77 = ((($2)) + 72|0);
 $78 = +HEAPF64[$77>>3];
 $79 = $49 * $78;
 $80 = $76 + $79;
 $81 = ((($2)) + 104|0);
 $82 = +HEAPF64[$81>>3];
 $83 = $82 + $80;
 $84 = $55 * $83;
 $85 = ((($2)) + 16|0);
 $86 = +HEAPF64[$85>>3];
 $87 = $38 * $86;
 $88 = ((($2)) + 48|0);
 $89 = +HEAPF64[$88>>3];
 $90 = $43 * $89;
 $91 = $87 + $90;
 $92 = ((($2)) + 80|0);
 $93 = +HEAPF64[$92>>3];
 $94 = $49 * $93;
 $95 = $91 + $94;
 $96 = ((($2)) + 112|0);
 $97 = +HEAPF64[$96>>3];
 $98 = $97 + $95;
 $99 = $55 * $98;
 $100 = ((($0)) + 56|0);
 $101 = +HEAPF64[$100>>3];
 $102 = $38 + $101;
 $103 = ((($0)) + 64|0);
 $104 = +HEAPF64[$103>>3];
 $105 = $43 + $104;
 $106 = ((($0)) + 72|0);
 $107 = +HEAPF64[$106>>3];
 $108 = $49 + $107;
 $109 = $56 * $102;
 $110 = $59 * $105;
 $111 = $109 + $110;
 $112 = $63 * $108;
 $113 = $111 + $112;
 $114 = $67 + $113;
 $115 = $71 * $102;
 $116 = $74 * $105;
 $117 = $115 + $116;
 $118 = $78 * $108;
 $119 = $117 + $118;
 $120 = $82 + $119;
 $121 = $86 * $102;
 $122 = $89 * $105;
 $123 = $121 + $122;
 $124 = $93 * $108;
 $125 = $123 + $124;
 $126 = $97 + $125;
 $127 = $36 * $102;
 $128 = $41 * $105;
 $129 = $127 + $128;
 $130 = $47 * $108;
 $131 = $129 + $130;
 $132 = $53 + $131;
 $133 = $69 * $132;
 $134 = $84 * $132;
 $135 = $99 * $132;
 $136 = $114 - $133;
 $137 = $120 - $134;
 $138 = $126 - $135;
 __THREW__ = 0;
 $139 = (invoke_ii(3276,96)|0);
 $140 = __THREW__; __THREW__ = 0;
 $141 = $140&1;
 do {
  if ($141) {
   $156 = ___cxa_find_matching_catch_2()|0;
   $157 = tempRet0;
   $$0 = $157;$$05 = $156;
  } else {
   $142 = ((($0)) + 16|0);
   $143 = HEAP32[$142>>2]|0;
   __THREW__ = 0;
   invoke_vi(3282,($139|0));
   $144 = __THREW__; __THREW__ = 0;
   $145 = $144&1;
   if ($145) {
    $158 = ___cxa_find_matching_catch_2()|0;
    $159 = tempRet0;
    __ZdlPv($139);
    $$0 = $159;$$05 = $158;
    break;
   }
   $146 = ((($139)) + 12|0);
   HEAP32[$146>>2] = 3;
   $147 = ((($139)) + 16|0);
   HEAP32[$147>>2] = $143;
   $148 = ((($139)) + 20|0);
   HEAP32[$148>>2] = 0;
   $149 = ((($139)) + 24|0);
   HEAP32[$139>>2] = (49324);
   $150 = ((($139)) + 28|0);
   HEAP32[$150>>2] = $0;
   $$sroa$062$0$$sroa_idx = ((($139)) + 32|0);
   HEAPF64[$$sroa$062$0$$sroa_idx>>3] = $69;
   $$sroa$665$0$$sroa_idx68 = ((($139)) + 40|0);
   HEAPF64[$$sroa$665$0$$sroa_idx68>>3] = $84;
   $$sroa$8$0$$sroa_idx71 = ((($139)) + 48|0);
   HEAPF64[$$sroa$8$0$$sroa_idx71>>3] = $99;
   $$sroa$020$0$$sroa_idx = ((($139)) + 56|0);
   HEAPF64[$$sroa$020$0$$sroa_idx>>3] = $136;
   $$sroa$523$0$$sroa_idx26 = ((($139)) + 64|0);
   HEAPF64[$$sroa$523$0$$sroa_idx26>>3] = $137;
   $$sroa$6$0$$sroa_idx29 = ((($139)) + 72|0);
   HEAPF64[$$sroa$6$0$$sroa_idx29>>3] = $138;
   $151 = ((($139)) + 84|0);
   HEAP32[$151>>2] = 0;
   $152 = ((($139)) + 88|0);
   HEAP32[$152>>2] = 0;
   $153 = ((($139)) + 80|0);
   HEAP32[$153>>2] = $151;
   $154 = ((($0)) + 24|0);
   $155 = HEAP32[$154>>2]|0;
   HEAP32[$149>>2] = $155;
   $$010$in = $139;
   STACKTOP = sp;return ($$010$in|0);
  }
 } while(0);
 $$4 = $$0;$$49 = $$05;
 ___resumeException($$49|0);
 // unreachable;
 return (0)|0;
}
function __ZN7osgUtil14RayIntersector5enterERKN3osg4NodeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0.0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(2);
 if ($4) {
  $5 = HEAP32[$0>>2]|0;
  $6 = ((($5)) + 32|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (FUNCTION_TABLE_ii[$7 & 8191]($0)|0);
  if ($8) {
   $$0 = 0;
   return ($$0|0);
  }
 }
 $9 = ((($1)) + 108|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0);
 if (!($11)) {
  $$0 = 1;
  return ($$0|0);
 }
 $12 = ((($1)) + 104|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = ($13<<24>>24)==(0);
 if ($14) {
  $$0 = 1;
  return ($$0|0);
 }
 $15 = (__ZNK3osg4Node8getBoundEv($1)|0);
 $16 = ((($15)) + 12|0);
 $17 = +HEAPF32[$16>>2];
 $18 = !($17 >= 0.0);
 if ($18) {
  $$0 = 1;
  return ($$0|0);
 }
 $19 = HEAP32[$0>>2]|0;
 $20 = ((($19)) + 44|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (__ZNK3osg4Node8getBoundEv($1)|0);
 $23 = (FUNCTION_TABLE_iii[$21 & 8191]($0,$22)|0);
 $$0 = $23;
 return ($$0|0);
}
function __ZN7osgUtil14RayIntersector5leaveEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN7osgUtil14RayIntersector9intersectERNS_19IntersectionVisitorEPN3osg8DrawableE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$$i = 0, $$$i$i = 0, $$0 = 0, $$0$be$in$i$i$i$i = 0, $$0$i$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i$i = 0, $$0$i$i$i$i$i$i$i = 0, $$0$i$i$i$i22 = 0, $$0$i$i$i$i24 = 0, $$0$i13$i$i$in$i$i = 0, $$015$i$i$i$i = 0, $$016 = 0, $$030$i$i$i = 0, $$034$i$i$i = 0, $$08$i$i$i$i$i$i = 0, $$1$i$i$i$i = 0, $$5 = 0, $$521 = 0;
 var $$pre$i = 0, $$pre$i$i$i$i = 0, $$pre$i$i$i$i25 = 0, $$pre$i$i$i$pre$i = 0, $$pre$i10$i$i$i = 0, $$pre28$i = 0, $$sroa$023$0$i$i$i$i = 0, $$sroa$035 = 0, $$sroa$035$0$$sroa$035$0$3858$pre = 0, $$sroa$035$0$$sroa$035$0$3959 = 0, $$sroa$035$0$$sroa$035$0$3959107 = 0, $$sroa$035$0$$sroa$035$0$4060 = 0, $$sroa$035$0$$sroa$035$0$83$cast = 0, $$sroa$09$0$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0.0;
 var $105 = 0.0, $106 = 0.0, $107 = 0, $108 = 0.0, $109 = 0, $11 = 0, $110 = 0.0, $111 = 0.0, $112 = 0, $113 = 0.0, $114 = 0, $115 = 0.0, $116 = 0.0, $117 = 0.0, $118 = 0.0, $119 = 0.0, $12 = 0, $120 = 0.0, $121 = 0.0, $122 = 0.0;
 var $123 = 0.0, $124 = 0.0, $125 = 0, $126 = 0.0, $127 = 0.0, $128 = 0, $129 = 0.0, $13 = 0, $130 = 0.0, $131 = 0.0, $132 = 0.0, $133 = 0.0, $134 = 0.0, $135 = 0.0, $136 = 0.0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0;
 var $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0.0, $154 = 0.0, $155 = 0.0, $156 = 0, $157 = 0, $158 = 0, $159 = 0;
 var $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0;
 var $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0;
 var $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0.0, $206 = 0, $207 = 0.0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0;
 var $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0;
 var $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0;
 var $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0;
 var $269 = 0, $27 = 0, $270 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0.0, $53 = 0.0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0.0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $eh$lpad$body$i$index2Z2D = 0, $eh$lpad$body$i$indexZ2D = 0, $eh$lpad$body$index7Z2D = 0, $eh$lpad$body$indexZ2D = 0, $eh$lpad$body27$index12Z2D = 0, $eh$lpad$body27$indexZ2D = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 256|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(256|0);
 $3 = sp + 216|0;
 $4 = sp + 192|0;
 $5 = sp + 96|0;
 $6 = sp + 244|0;
 $$sroa$035 = sp + 240|0;
 $7 = sp;
 $8 = ((($0)) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(2);
 if ($10) {
  $11 = HEAP32[$0>>2]|0;
  $12 = ((($11)) + 32|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (FUNCTION_TABLE_ii[$13 & 8191]($0)|0);
  if ($14) {
   STACKTOP = sp;return;
  }
 }
 $15 = ((($0)) + 32|0);
 ;HEAP32[$3>>2]=HEAP32[$15>>2]|0;HEAP32[$3+4>>2]=HEAP32[$15+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$15+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$15+12>>2]|0;HEAP32[$3+16>>2]=HEAP32[$15+16>>2]|0;HEAP32[$3+20>>2]=HEAP32[$15+20>>2]|0;
 ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;HEAP32[$4+12>>2]=0|0;HEAP32[$4+16>>2]=0|0;HEAP32[$4+20>>2]=0|0;
 $16 = ((($0)) + 56|0);
 $17 = (__ZNK3osg8Drawable14getBoundingBoxEv($2)|0);
 $18 = (__ZN7osgUtil14RayIntersector16intersectAndClipERN3osg5Vec3dERKS2_S3_RKNS1_15BoundingBoxImplINS1_5Vec3fEEE(0,$3,$16,$4,$17)|0);
 L5: do {
  if ($18) {
   $19 = ((($1)) + 69|0);
   $20 = HEAP8[$19>>0]|0;
   $21 = ($20<<24>>24)==(0);
   if ($21) {
    $22 = HEAP32[$8>>2]|0;
    __ZN7osgUtil22LineSegmentIntersectorC2ENS_11Intersector15CoordinateFrameERKN3osg5Vec3dES6_PS0_NS1_17IntersectionLimitE($5,3,$3,$4,0,$22);
    $23 = ((($0)) + 24|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = ((($5)) + 24|0);
    HEAP32[$25>>2] = $24;
    __THREW__ = 0;
    invoke_viiiii(1012,($5|0),($1|0),($2|0),($3|0),($4|0));
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    L8: do {
     if ($27) {
      $150 = ___cxa_find_matching_catch_2()|0;
      $151 = tempRet0;
      $eh$lpad$body$index7Z2D = $151;$eh$lpad$body$indexZ2D = $150;
      label = 40;
     } else {
      $28 = ((($5)) + 28|0);
      $29 = HEAP32[$28>>2]|0;
      $30 = ($29|0)==(0|0);
      $$$i = $30 ? $5 : $29;
      $31 = ((($6)) + 4|0);
      HEAP32[$31>>2] = 0;
      $32 = ((($6)) + 8|0);
      HEAP32[$32>>2] = 0;
      $33 = ((($6)) + 4|0);
      HEAP32[$6>>2] = $33;
      $34 = ((($$$i)) + 80|0);
      $35 = HEAP32[$34>>2]|0;
      $36 = ((($$$i)) + 84|0);
      $37 = ($35|0)==($36|0);
      do {
       if (!($37)) {
        $38 = $33;
        $$pre$i$i$i$i = 0;$$sroa$09$0$i = $35;$270 = 0;$41 = $33;
        while(1) {
         $39 = ((($$sroa$09$0$i)) + 16|0);
         $40 = ($33|0)==($41|0);
         do {
          if ($40) {
           $$sroa$023$0$i$i$i$i = $38;
           label = 13;
          } else {
           $42 = ($$pre$i$i$i$i|0)==(0|0);
           if ($42) {
            $$0$i$i$i$i$i$i = $33;
            while(1) {
             $46 = ((($$0$i$i$i$i$i$i)) + 8|0);
             $47 = HEAP32[$46>>2]|0;
             $48 = HEAP32[$47>>2]|0;
             $49 = ($48|0)==($$0$i$i$i$i$i$i|0);
             if ($49) {
              $$0$i$i$i$i$i$i = $47;
             } else {
              $$08$i$i$i$i$i$i = $47;
              break;
             }
            }
           } else {
            $$0$i$i$i$i$i$i$i = $$pre$i$i$i$i;
            while(1) {
             $43 = ((($$0$i$i$i$i$i$i$i)) + 4|0);
             $44 = HEAP32[$43>>2]|0;
             $45 = ($44|0)==(0|0);
             if ($45) {
              $$08$i$i$i$i$i$i = $$0$i$i$i$i$i$i$i;
              break;
             } else {
              $$0$i$i$i$i$i$i$i = $44;
             }
            }
           }
           $50 = $$08$i$i$i$i$i$i;
           $51 = ((($$08$i$i$i$i$i$i)) + 16|0);
           $52 = +HEAPF64[$39>>3];
           $53 = +HEAPF64[$51>>3];
           $54 = $52 < $53;
           if ($54) {
            if ($42) {
             $$034$i$i$i = $33;$$1$i$i$i$i = $33;
            } else {
             $$0$i13$i$i$in$i$i = $$pre$i$i$i$i;
             while(1) {
              $58 = ((($$0$i13$i$i$in$i$i)) + 16|0);
              $59 = +HEAPF64[$58>>3];
              $60 = $52 < $59;
              if ($60) {
               $61 = HEAP32[$$0$i13$i$i$in$i$i>>2]|0;
               $62 = ($61|0)==(0|0);
               if ($62) {
                label = 18;
                break;
               } else {
                $$0$i13$i$i$in$i$i = $61;
                continue;
               }
              } else {
               $63 = ((($$0$i13$i$i$in$i$i)) + 4|0);
               $64 = HEAP32[$63>>2]|0;
               $65 = ($64|0)==(0|0);
               if ($65) {
                label = 20;
                break;
               } else {
                $$0$i13$i$i$in$i$i = $64;
                continue;
               }
              }
             }
             if ((label|0) == 18) {
              label = 0;
              $$034$i$i$i = $$0$i13$i$i$in$i$i;$$1$i$i$i$i = $$0$i13$i$i$in$i$i;
              break;
             }
             else if ((label|0) == 20) {
              label = 0;
              $$034$i$i$i = $$0$i13$i$i$in$i$i;$$1$i$i$i$i = $63;
              break;
             }
            }
           } else {
            $$sroa$023$0$i$i$i$i = $50;
            label = 13;
           }
          }
         } while(0);
         if ((label|0) == 13) {
          label = 0;
          $55 = ($$pre$i$i$i$i|0)==(0|0);
          if ($55) {
           $$034$i$i$i = $33;$$1$i$i$i$i = $33;
          } else {
           $56 = $$sroa$023$0$i$i$i$i;
           $57 = ((($56)) + 4|0);
           $$034$i$i$i = $56;$$1$i$i$i$i = $57;
          }
         }
         __THREW__ = 0;
         $66 = (invoke_ii(3276,112)|0);
         $67 = __THREW__; __THREW__ = 0;
         $68 = $67&1;
         if ($68) {
          label = 33;
          break;
         }
         $69 = ((($66)) + 16|0);
         __THREW__ = 0;
         invoke_vii(3315,($69|0),($39|0));
         $70 = __THREW__; __THREW__ = 0;
         $71 = $70&1;
         if ($71) {
          label = 23;
          break;
         }
         HEAP32[$66>>2] = 0;
         $74 = ((($66)) + 4|0);
         HEAP32[$74>>2] = 0;
         $75 = ((($66)) + 8|0);
         HEAP32[$75>>2] = $$034$i$i$i;
         HEAP32[$$1$i$i$i$i>>2] = $66;
         $76 = HEAP32[$6>>2]|0;
         $77 = HEAP32[$76>>2]|0;
         $78 = ($77|0)==(0|0);
         if ($78) {
          $81 = $66;
         } else {
          $79 = $77;
          HEAP32[$6>>2] = $79;
          $$pre$i10$i$i$i = HEAP32[$$1$i$i$i$i>>2]|0;
          $81 = $$pre$i10$i$i$i;
         }
         $80 = HEAP32[$31>>2]|0;
         __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($80,$81);
         $82 = HEAP32[$32>>2]|0;
         $83 = (($82) + 1)|0;
         HEAP32[$32>>2] = $83;
         $84 = ((($$sroa$09$0$i)) + 4|0);
         $85 = HEAP32[$84>>2]|0;
         $86 = ($85|0)==(0|0);
         if ($86) {
          $87 = ((($$sroa$09$0$i)) + 8|0);
          $88 = HEAP32[$87>>2]|0;
          $89 = HEAP32[$88>>2]|0;
          $90 = ($89|0)==($$sroa$09$0$i|0);
          if ($90) {
           $$0$i$i$i$i = $88;
          } else {
           $94 = $87;
           while(1) {
            $93 = HEAP32[$94>>2]|0;
            $95 = ((($93)) + 8|0);
            $96 = HEAP32[$95>>2]|0;
            $97 = HEAP32[$96>>2]|0;
            $98 = ($97|0)==($93|0);
            if ($98) {
             $$0$i$i$i$i = $96;
             break;
            } else {
             $94 = $95;
            }
           }
          }
         } else {
          $$0$i$i$i$i$i = $85;
          while(1) {
           $91 = HEAP32[$$0$i$i$i$i$i>>2]|0;
           $92 = ($91|0)==(0|0);
           if ($92) {
            break;
           } else {
            $$0$i$i$i$i$i = $91;
           }
          }
          $$0$i$i$i$i = $$0$i$i$i$i$i;
         }
         $99 = ($$0$i$i$i$i|0)==($36|0);
         if ($99) {
          label = 35;
          break;
         }
         $$pre$i = HEAP32[$6>>2]|0;
         $$pre$i$i$i$pre$i = HEAP32[$33>>2]|0;
         $$pre$i$i$i$i = $$pre$i$i$i$pre$i;$$sroa$09$0$i = $$0$i$i$i$i;$270 = $$pre$i$i$i$pre$i;$41 = $$pre$i;
        }
        if ((label|0) == 23) {
         $72 = ___cxa_find_matching_catch_2()|0;
         $73 = tempRet0;
         __ZdlPv($66);
         $$pre28$i = HEAP32[$33>>2]|0;
         $102 = $$pre28$i;$eh$lpad$body$i$index2Z2D = $73;$eh$lpad$body$i$indexZ2D = $72;
        }
        else if ((label|0) == 33) {
         $100 = ___cxa_find_matching_catch_2()|0;
         $101 = tempRet0;
         $102 = $270;$eh$lpad$body$i$index2Z2D = $101;$eh$lpad$body$i$indexZ2D = $100;
        }
        else if ((label|0) == 35) {
         $103 = ($83|0)==(0);
         if ($103) {
          break;
         }
         $104 = +HEAPF64[$3>>3];
         $105 = +HEAPF64[$15>>3];
         $106 = $104 - $105;
         $107 = ((($3)) + 8|0);
         $108 = +HEAPF64[$107>>3];
         $109 = ((($0)) + 40|0);
         $110 = +HEAPF64[$109>>3];
         $111 = $108 - $110;
         $112 = ((($3)) + 16|0);
         $113 = +HEAPF64[$112>>3];
         $114 = ((($0)) + 48|0);
         $115 = +HEAPF64[$114>>3];
         $116 = $113 - $115;
         $117 = $106 * $106;
         $118 = $111 * $111;
         $119 = $117 + $118;
         $120 = $116 * $116;
         $121 = $119 + $120;
         $122 = (+Math_sqrt((+$121)));
         $123 = +HEAPF64[$4>>3];
         $124 = $123 - $104;
         $125 = ((($4)) + 8|0);
         $126 = +HEAPF64[$125>>3];
         $127 = $126 - $108;
         $128 = ((($4)) + 16|0);
         $129 = +HEAPF64[$128>>3];
         $130 = $129 - $113;
         $131 = $124 * $124;
         $132 = $127 * $127;
         $133 = $131 + $132;
         $134 = $130 * $130;
         $135 = $133 + $134;
         $136 = (+Math_sqrt((+$135)));
         $137 = HEAP32[$6>>2]|0;
         HEAP32[$$sroa$035>>2] = $137;
         $$sroa$035$0$$sroa$035$0$83$cast = $137;
         $138 = ($$sroa$035$0$$sroa$035$0$83$cast|0)==($33|0);
         L53: do {
          if (!($138)) {
           $139 = $137;
           $140 = ((($7)) + 8|0);
           $141 = ((($7)) + 32|0);
           $142 = ((($7)) + 24|0);
           $143 = ((($7)) + 8|0);
           $144 = ((($7)) + 20|0);
           $145 = ((($7)) + 92|0);
           $146 = ((($7)) + 56|0);
           $147 = ((($7)) + 68|0);
           $148 = ((($7)) + 80|0);
           $149 = ((($0)) + 28|0);
           $$sroa$035$0$$sroa$035$0$3959107 = $139;
           while(1) {
            ;HEAP32[$140>>2]=0|0;HEAP32[$140+4>>2]=0|0;HEAP32[$140+8>>2]=0|0;HEAP32[$140+12>>2]=0|0;HEAP32[$140+16>>2]=0|0;
            dest=$141; stop=dest+64|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
            $152 = ((($$sroa$035$0$$sroa$035$0$3959107)) + 16|0);
            $153 = +HEAPF64[$152>>3];
            $154 = $136 * $153;
            $155 = $122 + $154;
            HEAPF64[$7>>3] = $155;
            $156 = ((($$sroa$035$0$$sroa$035$0$3959107)) + 40|0);
            $157 = HEAP32[$156>>2]|0;
            $158 = ($157|0)==(0|0);
            if ($158) {
             $$sroa$035$0$$sroa$035$0$3959 = $$sroa$035$0$$sroa$035$0$3959107;
            } else {
             HEAP32[$142>>2] = $157;
             $159 = ((($157)) + 8|0);
             $160 = HEAP32[$159>>2]|0;HEAP32[$159>>2] = (($160+1)|0);
             $$sroa$035$0$$sroa$035$0$3858$pre = HEAP32[$$sroa$035>>2]|0;
             $$sroa$035$0$$sroa$035$0$3959 = $$sroa$035$0$$sroa$035$0$3858$pre;
            }
            $161 = ((($$sroa$035$0$$sroa$035$0$3959)) + 24|0);
            $162 = ($143|0)==($161|0);
            if (!($162)) {
             $163 = HEAP32[$161>>2]|0;
             $164 = ((($$sroa$035$0$$sroa$035$0$3959)) + 28|0);
             $165 = HEAP32[$164>>2]|0;
             __THREW__ = 0;
             invoke_viii(3566,($143|0),($163|0),($165|0));
             $166 = __THREW__; __THREW__ = 0;
             $167 = $166&1;
             if ($167) {
              label = 76;
              break;
             }
            }
            $168 = HEAP32[$144>>2]|0;
            $169 = ((($$sroa$035$0$$sroa$035$0$3959)) + 36|0);
            $170 = HEAP32[$169>>2]|0;
            $171 = ($168|0)==($170|0);
            if (!($171)) {
             HEAP32[$144>>2] = $170;
             $172 = ($170|0)==(0|0);
             if (!($172)) {
              $173 = ((($170)) + 8|0);
              $174 = HEAP32[$173>>2]|0;HEAP32[$173>>2] = (($174+1)|0);
             }
             $175 = ($168|0)==(0|0);
             if (!($175)) {
              $176 = ((($168)) + 8|0);
              $177 = HEAP32[$176>>2]|0;HEAP32[$176>>2] = (($177-1)|0);
              $178 = ($177|0)==(1);
              if ($178) {
               __THREW__ = 0;
               invoke_viii(3262,($168|0),1,1);
               $179 = __THREW__; __THREW__ = 0;
               $180 = $179&1;
               if ($180) {
                label = 76;
                break;
               }
              }
             }
            }
            $$sroa$035$0$$sroa$035$0$4060 = HEAP32[$$sroa$035>>2]|0;
            $181 = ((($$sroa$035$0$$sroa$035$0$4060)) + 108|0);
            $182 = HEAP32[$181>>2]|0;
            HEAP32[$145>>2] = $182;
            $183 = ((($$sroa$035$0$$sroa$035$0$4060)) + 48|0);
            ;HEAP32[$141>>2]=HEAP32[$183>>2]|0;HEAP32[$141+4>>2]=HEAP32[$183+4>>2]|0;HEAP32[$141+8>>2]=HEAP32[$183+8>>2]|0;HEAP32[$141+12>>2]=HEAP32[$183+12>>2]|0;HEAP32[$141+16>>2]=HEAP32[$183+16>>2]|0;HEAP32[$141+20>>2]=HEAP32[$183+20>>2]|0;
            $184 = ((($$sroa$035$0$$sroa$035$0$4060)) + 72|0);
            ;HEAP32[$146>>2]=HEAP32[$184>>2]|0;HEAP32[$146+4>>2]=HEAP32[$184+4>>2]|0;HEAP32[$146+8>>2]=HEAP32[$184+8>>2]|0;
            $185 = ((($$sroa$035$0$$sroa$035$0$4060)) + 84|0);
            $186 = ($147|0)==($185|0);
            if (!($186)) {
             $187 = HEAP32[$185>>2]|0;
             $188 = ((($$sroa$035$0$$sroa$035$0$4060)) + 88|0);
             $189 = HEAP32[$188>>2]|0;
             __THREW__ = 0;
             invoke_viii(3569,($147|0),($187|0),($189|0));
             $190 = __THREW__; __THREW__ = 0;
             $191 = $190&1;
             if ($191) {
              label = 76;
              break;
             }
            }
            $192 = ((($$sroa$035$0$$sroa$035$0$4060)) + 96|0);
            $193 = ($148|0)==($192|0);
            if (!($193)) {
             $194 = HEAP32[$192>>2]|0;
             $195 = ((($$sroa$035$0$$sroa$035$0$4060)) + 100|0);
             $196 = HEAP32[$195>>2]|0;
             __THREW__ = 0;
             invoke_viii(3570,($148|0),($194|0),($196|0));
             $197 = __THREW__; __THREW__ = 0;
             $198 = $197&1;
             if ($198) {
              label = 76;
              break;
             }
            }
            $199 = HEAP32[$149>>2]|0;
            $200 = ($199|0)==(0|0);
            $$$i$i = $200 ? $0 : $199;
            $201 = ((($$$i$i)) + 80|0);
            $202 = ((($$$i$i)) + 84|0);
            $203 = HEAP32[$202>>2]|0;
            $204 = ($203|0)==(0|0);
            do {
             if ($204) {
              $$015$i$i$i$i = $202;$$030$i$i$i = $202;
             } else {
              $205 = +HEAPF64[$7>>3];
              $$0$i$i$i$i24 = $203;
              while(1) {
               $206 = ((($$0$i$i$i$i24)) + 16|0);
               $207 = +HEAPF64[$206>>3];
               $208 = $205 < $207;
               if ($208) {
                $209 = HEAP32[$$0$i$i$i$i24>>2]|0;
                $210 = ($209|0)==(0|0);
                if ($210) {
                 label = 59;
                 break;
                } else {
                 $$0$be$in$i$i$i$i = $209;
                }
               } else {
                $211 = ((($$0$i$i$i$i24)) + 4|0);
                $212 = HEAP32[$211>>2]|0;
                $213 = ($212|0)==(0|0);
                if ($213) {
                 label = 62;
                 break;
                } else {
                 $$0$be$in$i$i$i$i = $212;
                }
               }
               $$0$i$i$i$i24 = $$0$be$in$i$i$i$i;
              }
              if ((label|0) == 59) {
               label = 0;
               $$015$i$i$i$i = $$0$i$i$i$i24;$$030$i$i$i = $$0$i$i$i$i24;
               break;
              }
              else if ((label|0) == 62) {
               label = 0;
               $$015$i$i$i$i = $211;$$030$i$i$i = $$0$i$i$i$i24;
               break;
              }
             }
            } while(0);
            __THREW__ = 0;
            $214 = (invoke_ii(3276,112)|0);
            $215 = __THREW__; __THREW__ = 0;
            $216 = $215&1;
            if ($216) {
             label = 76;
             break;
            }
            $217 = ((($214)) + 16|0);
            __THREW__ = 0;
            invoke_vii(3430,($217|0),($7|0));
            $218 = __THREW__; __THREW__ = 0;
            $219 = $218&1;
            if ($219) {
             label = 66;
             break;
            }
            HEAP32[$214>>2] = 0;
            $222 = ((($214)) + 4|0);
            HEAP32[$222>>2] = 0;
            $223 = ((($214)) + 8|0);
            HEAP32[$223>>2] = $$030$i$i$i;
            HEAP32[$$015$i$i$i$i>>2] = $214;
            $224 = HEAP32[$201>>2]|0;
            $225 = HEAP32[$224>>2]|0;
            $226 = ($225|0)==(0|0);
            if ($226) {
             $230 = $214;
            } else {
             $227 = $225;
             HEAP32[$201>>2] = $227;
             $$pre$i$i$i$i25 = HEAP32[$$015$i$i$i$i>>2]|0;
             $230 = $$pre$i$i$i$i25;
            }
            $228 = ((($$$i$i)) + 84|0);
            $229 = HEAP32[$228>>2]|0;
            __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($229,$230);
            $231 = ((($$$i$i)) + 88|0);
            $232 = HEAP32[$231>>2]|0;
            $233 = (($232) + 1)|0;
            HEAP32[$231>>2] = $233;
            __THREW__ = 0;
            invoke_vi(3432,($7|0));
            $234 = __THREW__; __THREW__ = 0;
            $235 = $234&1;
            if ($235) {
             label = 78;
             break;
            }
            $236 = ((($$sroa$035$0$$sroa$035$0$4060)) + 4|0);
            $237 = HEAP32[$236>>2]|0;
            $238 = ($237|0)==(0|0);
            do {
             if ($238) {
              $239 = ((($$sroa$035$0$$sroa$035$0$4060)) + 8|0);
              $240 = HEAP32[$239>>2]|0;
              $241 = HEAP32[$240>>2]|0;
              $242 = ($241|0)==($$sroa$035$0$$sroa$035$0$4060|0);
              if ($242) {
               $$0$i$i$i = $240;
               break;
              } else {
               $246 = $239;
              }
              while(1) {
               $245 = HEAP32[$246>>2]|0;
               $247 = ((($245)) + 8|0);
               $248 = HEAP32[$247>>2]|0;
               $249 = HEAP32[$248>>2]|0;
               $250 = ($249|0)==($245|0);
               if ($250) {
                $$0$i$i$i = $248;
                break;
               } else {
                $246 = $247;
               }
              }
             } else {
              $$0$i$i$i$i22 = $237;
              while(1) {
               $243 = HEAP32[$$0$i$i$i$i22>>2]|0;
               $244 = ($243|0)==(0|0);
               if ($244) {
                break;
               } else {
                $$0$i$i$i$i22 = $243;
               }
              }
              $$0$i$i$i = $$0$i$i$i$i22;
             }
            } while(0);
            HEAP32[$$sroa$035>>2] = $$0$i$i$i;
            $251 = ($$0$i$i$i|0)==($33|0);
            if ($251) {
             break L53;
            } else {
             $$sroa$035$0$$sroa$035$0$3959107 = $$0$i$i$i;
            }
           }
           if ((label|0) == 66) {
            $220 = ___cxa_find_matching_catch_2()|0;
            $221 = tempRet0;
            __ZdlPv($214);
            $eh$lpad$body27$index12Z2D = $221;$eh$lpad$body27$indexZ2D = $220;
            label = 77;
           }
           else if ((label|0) == 76) {
            $252 = ___cxa_find_matching_catch_2()|0;
            $253 = tempRet0;
            $eh$lpad$body27$index12Z2D = $253;$eh$lpad$body27$indexZ2D = $252;
            label = 77;
           }
           else if ((label|0) == 78) {
            $256 = ___cxa_find_matching_catch_2()|0;
            $257 = tempRet0;
            $$0 = $256;$$016 = $257;
           }
           if ((label|0) == 77) {
            __THREW__ = 0;
            invoke_vi(3432,($7|0));
            $254 = __THREW__; __THREW__ = 0;
            $255 = $254&1;
            if ($255) {
             $268 = ___cxa_find_matching_catch_3(0|0)|0;
             $269 = tempRet0;
             ___clang_call_terminate($268);
             // unreachable;
            } else {
             $$0 = $eh$lpad$body27$indexZ2D;$$016 = $eh$lpad$body27$index12Z2D;
            }
           }
           $262 = HEAP32[$33>>2]|0;
           __ZNSt3__26__treeIN7osgUtil22LineSegmentIntersector12IntersectionENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($6,$262);
           $$5 = $$0;$$521 = $$016;
           break L8;
          }
         } while(0);
         break;
        }
        __ZNSt3__26__treeIN7osgUtil22LineSegmentIntersector12IntersectionENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($6,$102);
        $eh$lpad$body$index7Z2D = $eh$lpad$body$i$index2Z2D;$eh$lpad$body$indexZ2D = $eh$lpad$body$i$indexZ2D;
        label = 40;
        break L8;
       }
      } while(0);
      $258 = HEAP32[$33>>2]|0;
      __ZNSt3__26__treeIN7osgUtil22LineSegmentIntersector12IntersectionENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($6,$258);
      HEAP32[$5>>2] = (48508);
      $259 = ((($5)) + 80|0);
      $260 = ((($5)) + 84|0);
      $261 = HEAP32[$260>>2]|0;
      __ZNSt3__26__treeIN7osgUtil22LineSegmentIntersector12IntersectionENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($259,$261);
      __ZN3osg10ReferencedD2Ev($5);
      break L5;
     }
    } while(0);
    if ((label|0) == 40) {
     $$5 = $eh$lpad$body$indexZ2D;$$521 = $eh$lpad$body$index7Z2D;
    }
    HEAP32[$5>>2] = (48508);
    $263 = ((($5)) + 80|0);
    $264 = ((($5)) + 84|0);
    $265 = HEAP32[$264>>2]|0;
    __ZNSt3__26__treeIN7osgUtil22LineSegmentIntersector12IntersectionENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($263,$265);
    __THREW__ = 0;
    invoke_vi(712,($5|0));
    $266 = __THREW__; __THREW__ = 0;
    $267 = $266&1;
    if ($267) {
     $268 = ___cxa_find_matching_catch_3(0|0)|0;
     $269 = tempRet0;
     ___clang_call_terminate($268);
     // unreachable;
    } else {
     ___resumeException($$5|0);
     // unreachable;
    }
   }
  }
 } while(0);
 STACKTOP = sp;return;
}
function __ZN7osgUtil14RayIntersector5resetEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 20|0);
 HEAP32[$1>>2] = 0;
 $2 = ((($0)) + 80|0);
 $3 = ((($0)) + 84|0);
 $4 = HEAP32[$3>>2]|0;
 __ZNSt3__26__treeIN7osgUtil14RayIntersector12IntersectionENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($2,$4);
 $5 = ((($0)) + 88|0);
 HEAP32[$5>>2] = 0;
 HEAP32[$2>>2] = $3;
 HEAP32[$3>>2] = 0;
 return;
}
function __ZN7osgUtil14RayIntersector21containsIntersectionsEv($0) {
 $0 = $0|0;
 var $$$i = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 $$$i = $3 ? $0 : $2;
 $4 = ((($$$i)) + 88|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)!=(0);
 return ($6|0);
}
function __ZN7osgUtil14RayIntersector8setStartERKN3osg5Vec3dE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 32|0);
 ;HEAP32[$2>>2]=HEAP32[$1>>2]|0;HEAP32[$2+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$1+12>>2]|0;HEAP32[$2+16>>2]=HEAP32[$1+16>>2]|0;HEAP32[$2+20>>2]=HEAP32[$1+20>>2]|0;
 return;
}
function __ZN7osgUtil14RayIntersector12setDirectionERKN3osg5Vec3dE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 56|0);
 ;HEAP32[$2>>2]=HEAP32[$1>>2]|0;HEAP32[$2+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$1+12>>2]|0;HEAP32[$2+16>>2]=HEAP32[$1+16>>2]|0;HEAP32[$2+20>>2]=HEAP32[$1+20>>2]|0;
 return;
}
function __ZN7osgUtil14RayIntersector10intersectsERKN3osg18BoundingSphereImplINS1_5Vec3fEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$$i41 = 0, $$4 = 0, $10 = 0, $11 = 0.0, $12 = 0.0, $13 = 0, $14 = 0.0, $15 = 0.0, $16 = 0, $17 = 0.0, $18 = 0.0, $19 = 0, $2 = 0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0.0, $25 = 0.0, $26 = 0.0;
 var $27 = 0.0, $28 = 0.0, $29 = 0.0, $3 = 0.0, $30 = 0, $31 = 0, $32 = 0.0, $33 = 0.0, $34 = 0, $35 = 0.0, $36 = 0.0, $37 = 0.0, $38 = 0, $39 = 0.0, $4 = 0, $40 = 0.0, $41 = 0.0, $42 = 0.0, $43 = 0.0, $44 = 0.0;
 var $45 = 0.0, $46 = 0.0, $47 = 0.0, $48 = 0.0, $49 = 0.0, $5 = 0.0, $50 = 0.0, $51 = 0.0, $52 = 0, $53 = 0.0, $54 = 0.0, $55 = 0.0, $56 = 0.0, $57 = 0.0, $58 = 0.0, $59 = 0.0, $6 = 0.0, $60 = 0.0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0.0, $73 = 0.0, $74 = 0.0, $75 = 0, $76 = 0, $77 = 0, $78 = 0.0, $79 = 0, $8 = 0.0, $9 = 0.0;
 var $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 12|0);
 $3 = +HEAPF32[$2>>2];
 $4 = !($3 >= 0.0);
 if ($4) {
  $$4 = 1;
  return ($$4|0);
 }
 $5 = +HEAPF32[$1>>2];
 $6 = $5;
 $7 = ((($1)) + 4|0);
 $8 = +HEAPF32[$7>>2];
 $9 = $8;
 $10 = ((($1)) + 8|0);
 $11 = +HEAPF32[$10>>2];
 $12 = $11;
 $13 = ((($0)) + 32|0);
 $14 = +HEAPF64[$13>>3];
 $15 = $14 - $6;
 $16 = ((($0)) + 40|0);
 $17 = +HEAPF64[$16>>3];
 $18 = $17 - $9;
 $19 = ((($0)) + 48|0);
 $20 = +HEAPF64[$19>>3];
 $21 = $20 - $12;
 $22 = $15 * $15;
 $23 = $18 * $18;
 $24 = $22 + $23;
 $25 = $21 * $21;
 $26 = $24 + $25;
 $27 = $3 * $3;
 $28 = $27;
 $29 = $26 - $28;
 $30 = $29 < 0.0;
 if ($30) {
  $$4 = 1;
  return ($$4|0);
 }
 $31 = ((($0)) + 56|0);
 $32 = +HEAPF64[$31>>3];
 $33 = $32 * $32;
 $34 = ((($0)) + 64|0);
 $35 = +HEAPF64[$34>>3];
 $36 = $35 * $35;
 $37 = $33 + $36;
 $38 = ((($0)) + 72|0);
 $39 = +HEAPF64[$38>>3];
 $40 = $39 * $39;
 $41 = $37 + $40;
 $42 = $15 * $32;
 $43 = $18 * $35;
 $44 = $42 + $43;
 $45 = $21 * $39;
 $46 = $44 + $45;
 $47 = $46 * 2.0;
 $48 = $47 * $47;
 $49 = $41 * 4.0;
 $50 = $29 * $49;
 $51 = $48 - $50;
 $52 = $51 < 0.0;
 if ($52) {
  $$4 = 0;
  return ($$4|0);
 }
 $53 = (+Math_sqrt((+$51)));
 $54 = $41 * 2.0;
 $55 = 1.0 / $54;
 $56 = -$47;
 $57 = $56 - $53;
 $58 = $55 * $57;
 $59 = $53 - $47;
 $60 = $55 * $59;
 $61 = $58 <= 0.0;
 $62 = $60 <= 0.0;
 $or$cond = $61 & $62;
 if ($or$cond) {
  $$4 = 0;
  return ($$4|0);
 }
 $63 = ((($0)) + 16|0);
 $64 = HEAP32[$63>>2]|0;
 $65 = ($64|0)==(3);
 if ($65) {
  $66 = ((($0)) + 28|0);
  $67 = HEAP32[$66>>2]|0;
  $68 = ($67|0)==(0|0);
  $$$i41 = $68 ? $0 : $67;
  $69 = ((($$$i41)) + 88|0);
  $70 = HEAP32[$69>>2]|0;
  $71 = ($70|0)==(0);
  if (!($71)) {
   $72 = (+Math_sqrt((+$26)));
   $73 = $3;
   $74 = $72 - $73;
   $75 = ((($$$i41)) + 80|0);
   $76 = HEAP32[$75>>2]|0;
   $77 = ((($76)) + 16|0);
   $78 = +HEAPF64[$77>>3];
   $79 = !($74 >= $78);
   if (!($79)) {
    $$4 = 0;
    return ($$4|0);
   }
  }
 }
 $$4 = 1;
 return ($$4|0);
}
function __ZNSt3__26__treeIN7osgUtil14RayIntersector12IntersectionENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 }
 $3 = HEAP32[$1>>2]|0;
 __ZNSt3__26__treeIN7osgUtil14RayIntersector12IntersectionENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($0,$3);
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 __ZNSt3__26__treeIN7osgUtil14RayIntersector12IntersectionENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($0,$5);
 $6 = ((($1)) + 16|0);
 __THREW__ = 0;
 invoke_vi(3432,($6|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch_2()|0;
  $10 = tempRet0;
  ___cxa_call_unexpected(($9|0));
  // unreachable;
 }
 __ZdlPv($1);
 return;
}
function __ZN7osgUtil14RayIntersector16intersectAndClipERN3osg5Vec3dERKS2_S3_RKNS1_15BoundingBoxImplINS1_5Vec3fEEE($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$083129 = 0, $$186 = 0.0, $$186$1 = 0.0, $$186$2 = 0.0, $$2 = 0, $$287 = 0.0, $$287$1 = 0.0, $$287$2 = 0.0, $$3 = 0.0, $$3$1 = 0.0, $$3$2 = 0.0, $$sroa$494$0$$sroa_idx95 = 0, $$sroa$5$0$$sroa_idx97 = 0, $10 = 0.0, $100 = 0.0, $101 = 0.0, $102 = 0.0, $103 = 0.0, $104 = 0.0, $105 = 0.0;
 var $106 = 0.0, $107 = 0.0, $108 = 0.0, $109 = 0.0, $11 = 0.0, $110 = 0.0, $111 = 0.0, $112 = 0.0, $113 = 0.0, $114 = 0, $115 = 0, $116 = 0.0, $117 = 0.0, $118 = 0.0, $119 = 0.0, $12 = 0, $120 = 0, $121 = 0, $122 = 0.0, $123 = 0.0;
 var $124 = 0.0, $125 = 0.0, $126 = 0, $127 = 0, $128 = 0.0, $129 = 0.0, $13 = 0, $130 = 0.0, $131 = 0.0, $132 = 0, $133 = 0, $14 = 0.0, $15 = 0.0, $16 = 0, $17 = 0, $18 = 0.0, $19 = 0.0, $20 = 0, $21 = 0.0, $22 = 0.0;
 var $23 = 0, $24 = 0, $25 = 0.0, $26 = 0.0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0.0, $34 = 0, $35 = 0, $36 = 0.0, $37 = 0, $38 = 0.0, $39 = 0, $40 = 0, $41 = 0, $42 = 0.0;
 var $43 = 0, $44 = 0.0, $45 = 0.0, $46 = 0.0, $47 = 0, $48 = 0.0, $49 = 0.0, $5 = 0, $50 = 0.0, $51 = 0.0, $52 = 0.0, $53 = 0.0, $54 = 0.0, $55 = 0.0, $56 = 0.0, $57 = 0.0, $58 = 0.0, $59 = 0.0, $6 = 0, $60 = 0;
 var $61 = 0.0, $62 = 0, $63 = 0, $64 = 0, $65 = 0.0, $66 = 0, $67 = 0.0, $68 = 0.0, $69 = 0.0, $7 = 0.0, $70 = 0, $71 = 0.0, $72 = 0.0, $73 = 0.0, $74 = 0.0, $75 = 0.0, $76 = 0.0, $77 = 0.0, $78 = 0.0, $79 = 0.0;
 var $8 = 0.0, $80 = 0.0, $81 = 0.0, $82 = 0.0, $83 = 0, $84 = 0, $85 = 0.0, $86 = 0, $87 = 0.0, $88 = 0.0, $89 = 0.0, $9 = 0, $90 = 0.0, $91 = 0, $92 = 0, $93 = 0.0, $94 = 0.0, $95 = 0.0, $96 = 0.0, $97 = 0;
 var $98 = 0.0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $5 = sp + 24|0;
 $6 = sp;
 $7 = +HEAPF32[$4>>2];
 $8 = $7;
 HEAPF64[$5>>3] = $8;
 $9 = ((($4)) + 4|0);
 $10 = +HEAPF32[$9>>2];
 $11 = $10;
 $12 = ((($5)) + 8|0);
 HEAPF64[$12>>3] = $11;
 $13 = ((($4)) + 8|0);
 $14 = +HEAPF32[$13>>2];
 $15 = $14;
 $16 = ((($5)) + 16|0);
 HEAPF64[$16>>3] = $15;
 $17 = ((($4)) + 12|0);
 $18 = +HEAPF32[$17>>2];
 $19 = $18;
 HEAPF64[$6>>3] = $19;
 $20 = ((($4)) + 16|0);
 $21 = +HEAPF32[$20>>2];
 $22 = $21;
 $23 = ((($6)) + 8|0);
 HEAPF64[$23>>3] = $22;
 $24 = ((($4)) + 20|0);
 $25 = +HEAPF32[$24>>2];
 $26 = $25;
 $27 = ((($6)) + 16|0);
 HEAPF64[$27>>3] = $26;
 $28 = ((($2)) + 8|0);
 $29 = ((($2)) + 16|0);
 $30 = ((($1)) + 8|0);
 $31 = ((($1)) + 16|0);
 $$083129 = 0;
 while(1) {
  $32 = (($2) + ($$083129<<3)|0);
  $33 = +HEAPF64[$32>>3];
  $34 = !($33 >= 0.0);
  $35 = (($1) + ($$083129<<3)|0);
  $36 = +HEAPF64[$35>>3];
  if ($34) {
   $60 = (($5) + ($$083129<<3)|0);
   $61 = +HEAPF64[$60>>3];
   $62 = $36 < $61;
   if ($62) {
    $$2 = 0;
    label = 20;
    break;
   }
   $63 = $33 < -9.9999999999999995E-7;
   if ($63) {
    $64 = (($6) + ($$083129<<3)|0);
    $65 = +HEAPF64[$64>>3];
    $66 = $36 > $65;
    if ($66) {
     $67 = $65 - $36;
     $68 = $67 / $33;
     $69 = $68 + -9.9999999999999995E-7;
     $70 = $69 > 0.0;
     if ($70) {
      $71 = +HEAPF64[$2>>3];
      $72 = $69 * $71;
      $73 = +HEAPF64[$28>>3];
      $74 = $69 * $73;
      $75 = +HEAPF64[$29>>3];
      $76 = $69 * $75;
      $77 = +HEAPF64[$1>>3];
      $78 = $72 + $77;
      $79 = +HEAPF64[$30>>3];
      $80 = $74 + $79;
      $81 = +HEAPF64[$31>>3];
      $82 = $76 + $81;
      HEAPF64[$1>>3] = $78;
      HEAPF64[$30>>3] = $80;
      HEAPF64[$31>>3] = $82;
     }
    }
   }
  } else {
   $37 = (($6) + ($$083129<<3)|0);
   $38 = +HEAPF64[$37>>3];
   $39 = $36 > $38;
   if ($39) {
    $$2 = 0;
    label = 20;
    break;
   }
   $40 = $33 > 9.9999999999999995E-7;
   if ($40) {
    $41 = (($5) + ($$083129<<3)|0);
    $42 = +HEAPF64[$41>>3];
    $43 = $36 < $42;
    if ($43) {
     $44 = $42 - $36;
     $45 = $44 / $33;
     $46 = $45 + -9.9999999999999995E-7;
     $47 = $46 > 0.0;
     if ($47) {
      $48 = +HEAPF64[$2>>3];
      $49 = $46 * $48;
      $50 = +HEAPF64[$28>>3];
      $51 = $46 * $50;
      $52 = +HEAPF64[$29>>3];
      $53 = $46 * $52;
      $54 = +HEAPF64[$1>>3];
      $55 = $49 + $54;
      $56 = +HEAPF64[$30>>3];
      $57 = $51 + $56;
      $58 = +HEAPF64[$31>>3];
      $59 = $53 + $58;
      HEAPF64[$1>>3] = $55;
      HEAPF64[$30>>3] = $57;
      HEAPF64[$31>>3] = $59;
     }
    }
   }
  }
  $83 = (($$083129) + 1)|0;
  $84 = ($83|0)<(3);
  if ($84) {
   $$083129 = $83;
  } else {
   label = 14;
   break;
  }
 }
 if ((label|0) == 14) {
  $85 = +HEAPF64[$2>>3];
  $86 = !($85 >= 9.9999999999999995E-7);
  if ($86) {
   $92 = !($85 <= -9.9999999999999995E-7);
   if ($92) {
    $$3 = inf;
   } else {
    $93 = +HEAPF64[$1>>3];
    $94 = $8 - $93;
    $95 = $94 / $85;
    $96 = $95 + 9.9999999999999995E-7;
    $97 = $96 < inf;
    $$287 = $97 ? $96 : inf;
    $$3 = $$287;
   }
  } else {
   $87 = +HEAPF64[$1>>3];
   $88 = $19 - $87;
   $89 = $88 / $85;
   $90 = $89 + 9.9999999999999995E-7;
   $91 = $90 < inf;
   $$186 = $91 ? $90 : inf;
   $$3 = $$186;
  }
  $98 = +HEAPF64[$28>>3];
  $99 = !($98 >= 9.9999999999999995E-7);
  if ($99) {
   $115 = !($98 <= -9.9999999999999995E-7);
   if ($115) {
    $$3$1 = $$3;
   } else {
    $116 = +HEAPF64[$30>>3];
    $117 = $11 - $116;
    $118 = $117 / $98;
    $119 = $118 + 9.9999999999999995E-7;
    $120 = $119 < $$3;
    $$287$1 = $120 ? $119 : $$3;
    $$3$1 = $$287$1;
   }
  } else {
   $110 = +HEAPF64[$30>>3];
   $111 = $22 - $110;
   $112 = $111 / $98;
   $113 = $112 + 9.9999999999999995E-7;
   $114 = $113 < $$3;
   $$186$1 = $114 ? $113 : $$3;
   $$3$1 = $$186$1;
  }
  $103 = +HEAPF64[$29>>3];
  $121 = !($103 >= 9.9999999999999995E-7);
  if ($121) {
   $127 = !($103 <= -9.9999999999999995E-7);
   if ($127) {
    $$3$2 = $$3$1;
   } else {
    $128 = +HEAPF64[$31>>3];
    $129 = $15 - $128;
    $130 = $129 / $103;
    $131 = $130 + 9.9999999999999995E-7;
    $132 = $131 < $$3$1;
    $$287$2 = $132 ? $131 : $$3$1;
    $$3$2 = $$287$2;
   }
  } else {
   $122 = +HEAPF64[$31>>3];
   $123 = $26 - $122;
   $124 = $123 / $103;
   $125 = $124 + 9.9999999999999995E-7;
   $126 = $125 < $$3$1;
   $$186$2 = $126 ? $125 : $$3$1;
   $$3$2 = $$186$2;
  }
  $133 = $$3$2 == inf;
  if ($133) {
   $$2 = 0;
   STACKTOP = sp;return ($$2|0);
  }
  $100 = $$3$2 * $85;
  $101 = $$3$2 * $98;
  $102 = $$3$2 * $103;
  $104 = +HEAPF64[$1>>3];
  $105 = $100 + $104;
  $106 = +HEAPF64[$30>>3];
  $107 = $101 + $106;
  $108 = +HEAPF64[$31>>3];
  $109 = $102 + $108;
  HEAPF64[$3>>3] = $105;
  $$sroa$494$0$$sroa_idx95 = ((($3)) + 8|0);
  HEAPF64[$$sroa$494$0$$sroa_idx95>>3] = $107;
  $$sroa$5$0$$sroa_idx97 = ((($3)) + 16|0);
  HEAPF64[$$sroa$5$0$$sroa_idx97>>3] = $109;
  $$2 = 1;
  STACKTOP = sp;return ($$2|0);
 }
 else if ((label|0) == 20) {
  STACKTOP = sp;return ($$2|0);
 }
 return (0)|0;
}
function __ZN7osgUtil14RayIntersectorC2ENS_11Intersector15CoordinateFrameEdd($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = +$2;
 $3 = +$3;
 var $$sroa$0$0$$sroa_idx = 0, $$sroa$0$0$$sroa_idx44 = 0, $$sroa$019$0$$sroa_idx = 0, $$sroa$027$0$$sroa_idx = 0, $$sroa$035$0$$sroa_idx = 0, $$sroa$052$0$$sroa_idx = 0, $$sroa$062$0$$sroa_idx = 0, $$sroa$072$0$$sroa_idx = 0, $$sroa$4$0$$sroa_idx16 = 0, $$sroa$4$0$$sroa_idx48 = 0, $$sroa$421$0$$sroa_idx23 = 0, $$sroa$429$0$$sroa_idx31 = 0, $$sroa$437$0$$sroa_idx39 = 0, $$sroa$5$0$$sroa_idx18 = 0, $$sroa$524$0$$sroa_idx26 = 0, $$sroa$532$0$$sroa_idx34 = 0, $$sroa$540$0$$sroa_idx42 = 0, $10 = 0, $11 = 0, $12 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 __ZN3osg10ReferencedC2Ev($0);
 $4 = ((($0)) + 12|0);
 HEAP32[$4>>2] = $1;
 $5 = ((($0)) + 16|0);
 HEAP32[$5>>2] = 0;
 $6 = ((($0)) + 20|0);
 HEAP32[$6>>2] = 0;
 $7 = ((($0)) + 24|0);
 HEAP32[$7>>2] = 0;
 HEAP32[$0>>2] = (49324);
 $8 = ((($0)) + 28|0);
 $9 = ((($0)) + 84|0);
 HEAP32[$9>>2] = 0;
 $10 = ((($0)) + 88|0);
 HEAP32[$10>>2] = 0;
 $11 = ((($0)) + 84|0);
 $12 = ((($0)) + 80|0);
 dest=$8; stop=dest+52|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAP32[$12>>2] = $11;
 switch ($1|0) {
 case 0:  {
  $$sroa$035$0$$sroa_idx = ((($0)) + 32|0);
  HEAPF64[$$sroa$035$0$$sroa_idx>>3] = $2;
  $$sroa$437$0$$sroa_idx39 = ((($0)) + 40|0);
  HEAPF64[$$sroa$437$0$$sroa_idx39>>3] = $3;
  $$sroa$540$0$$sroa_idx42 = ((($0)) + 48|0);
  HEAPF64[$$sroa$540$0$$sroa_idx42>>3] = 0.0;
  $$sroa$072$0$$sroa_idx = ((($0)) + 56|0);
  ;HEAP32[$$sroa$072$0$$sroa_idx>>2]=0|0;HEAP32[$$sroa$072$0$$sroa_idx+4>>2]=0|0;HEAP32[$$sroa$072$0$$sroa_idx+8>>2]=0|0;HEAP32[$$sroa$072$0$$sroa_idx+12>>2]=0|0;
  break;
 }
 case 1:  {
  $$sroa$027$0$$sroa_idx = ((($0)) + 32|0);
  HEAPF64[$$sroa$027$0$$sroa_idx>>3] = $2;
  $$sroa$429$0$$sroa_idx31 = ((($0)) + 40|0);
  HEAPF64[$$sroa$429$0$$sroa_idx31>>3] = $3;
  $$sroa$532$0$$sroa_idx34 = ((($0)) + 48|0);
  HEAPF64[$$sroa$532$0$$sroa_idx34>>3] = -1.0;
  $$sroa$062$0$$sroa_idx = ((($0)) + 56|0);
  ;HEAP32[$$sroa$062$0$$sroa_idx>>2]=0|0;HEAP32[$$sroa$062$0$$sroa_idx+4>>2]=0|0;HEAP32[$$sroa$062$0$$sroa_idx+8>>2]=0|0;HEAP32[$$sroa$062$0$$sroa_idx+12>>2]=0|0;
  break;
 }
 case 2:  {
  $$sroa$019$0$$sroa_idx = ((($0)) + 32|0);
  HEAPF64[$$sroa$019$0$$sroa_idx>>3] = $2;
  $$sroa$421$0$$sroa_idx23 = ((($0)) + 40|0);
  HEAPF64[$$sroa$421$0$$sroa_idx23>>3] = $3;
  $$sroa$524$0$$sroa_idx26 = ((($0)) + 48|0);
  HEAPF64[$$sroa$524$0$$sroa_idx26>>3] = 0.0;
  $$sroa$052$0$$sroa_idx = ((($0)) + 56|0);
  ;HEAP32[$$sroa$052$0$$sroa_idx>>2]=0|0;HEAP32[$$sroa$052$0$$sroa_idx+4>>2]=0|0;HEAP32[$$sroa$052$0$$sroa_idx+8>>2]=0|0;HEAP32[$$sroa$052$0$$sroa_idx+12>>2]=0|0;
  break;
 }
 case 3:  {
  $$sroa$0$0$$sroa_idx = ((($0)) + 32|0);
  HEAPF64[$$sroa$0$0$$sroa_idx>>3] = $2;
  $$sroa$4$0$$sroa_idx16 = ((($0)) + 40|0);
  HEAPF64[$$sroa$4$0$$sroa_idx16>>3] = $3;
  $$sroa$5$0$$sroa_idx18 = ((($0)) + 48|0);
  HEAPF64[$$sroa$5$0$$sroa_idx18>>3] = 0.0;
  $$sroa$0$0$$sroa_idx44 = ((($0)) + 56|0);
  ;HEAP32[$$sroa$0$0$$sroa_idx44>>2]=0|0;HEAP32[$$sroa$0$0$$sroa_idx44+4>>2]=0|0;HEAP32[$$sroa$0$0$$sroa_idx44+8>>2]=0|0;HEAP32[$$sroa$0$0$$sroa_idx44+12>>2]=0|0;
  break;
 }
 default: {
  return;
 }
 }
 $$sroa$4$0$$sroa_idx48 = ((($0)) + 72|0);
 HEAPF64[$$sroa$4$0$$sroa_idx48>>3] = 1.0;
 return;
}
function __ZNK7osgUtil14RayIntersector12Intersection16getTextureLookUpERN3osg5Vec3fE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$1 = 0, $$1163 = 0, $$1165 = 0, $$2$lcssa = 0, $$2166$lcssa = 0, $$2166207 = 0, $$2166208 = 0, $$2205 = 0, $$2209 = 0, $$4 = 0, $$4168 = 0, $$5 = 0, $$not = 0, $10 = 0, $100 = 0.0, $101 = 0.0, $102 = 0, $103 = 0.0, $104 = 0.0, $105 = 0.0;
 var $106 = 0, $107 = 0.0, $108 = 0.0, $109 = 0, $11 = 0, $110 = 0.0, $111 = 0.0, $112 = 0.0, $113 = 0, $114 = 0.0, $115 = 0.0, $116 = 0.0, $117 = 0, $118 = 0, $119 = 0.0, $12 = 0, $120 = 0.0, $121 = 0, $122 = 0.0, $123 = 0.0;
 var $124 = 0.0, $125 = 0, $126 = 0.0, $127 = 0.0, $128 = 0.0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0;
 var $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0.0, $167 = 0, $168 = 0.0, $169 = 0, $17 = 0, $170 = 0.0, $171 = 0, $172 = 0.0, $173 = 0.0, $174 = 0.0, $175 = 0, $176 = 0.0, $177 = 0.0, $178 = 0.0;
 var $179 = 0.0, $18 = 0, $180 = 0, $181 = 0.0, $182 = 0.0, $183 = 0.0, $184 = 0.0, $185 = 0, $186 = 0.0, $187 = 0.0, $188 = 0.0, $189 = 0.0, $19 = 0, $190 = 0, $191 = 0.0, $192 = 0.0, $193 = 0, $194 = 0.0, $195 = 0.0, $196 = 0.0;
 var $197 = 0, $198 = 0.0, $199 = 0.0, $2 = 0, $20 = 0, $200 = 0.0, $201 = 0, $202 = 0.0, $203 = 0.0, $204 = 0.0, $205 = 0.0, $206 = 0, $207 = 0.0, $208 = 0.0, $209 = 0, $21 = 0, $210 = 0.0, $211 = 0.0, $212 = 0.0, $213 = 0;
 var $214 = 0.0, $215 = 0.0, $216 = 0.0, $217 = 0, $218 = 0.0, $219 = 0.0, $22 = 0, $220 = 0.0, $221 = 0.0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0.0, $231 = 0.0;
 var $232 = 0.0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0.0, $238 = 0.0, $239 = 0.0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0.0, $245 = 0.0, $246 = 0.0, $247 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0.0, $35 = 0.0, $36 = 0, $37 = 0.0, $38 = 0.0, $39 = 0, $4 = 0, $40 = 0.0, $41 = 0.0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0.0, $57 = 0, $58 = 0.0, $59 = 0, $6 = 0, $60 = 0.0, $61 = 0.0, $62 = 0.0, $63 = 0.0;
 var $64 = 0.0, $65 = 0.0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0.0, $71 = 0.0, $72 = 0, $73 = 0.0, $74 = 0.0, $75 = 0.0, $76 = 0, $77 = 0.0, $78 = 0.0, $79 = 0.0, $8 = 0, $80 = 0, $81 = 0.0;
 var $82 = 0.0, $83 = 0, $84 = 0.0, $85 = 0.0, $86 = 0.0, $87 = 0, $88 = 0.0, $89 = 0.0, $9 = 0, $90 = 0.0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0.0, $97 = 0.0, $98 = 0, $99 = 0.0, $or$cond = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 20|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $$1 = 0;
  return ($$1|0);
 }
 $5 = HEAP32[$3>>2]|0;
 $6 = ((($5)) + 140|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_ii[$7 & 8191]($3)|0);
 $9 = ($8|0)==(0|0);
 if ($9) {
  $$1 = 0;
  return ($$1|0);
 }
 $10 = ((($8)) + 228|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0|0);
 if ($12) {
  $$1 = 0;
  return ($$1|0);
 }
 $13 = (___dynamic_cast($11,23016,5496,0)|0);
 $14 = ($13|0)==(0|0);
 if ($14) {
  $$1 = 0;
  return ($$1|0);
 }
 $15 = ((($0)) + 68|0);
 $16 = ((($0)) + 72|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = HEAP32[$15>>2]|0;
 $19 = (($17) - ($18))|0;
 $20 = ($19|0)==(12);
 $21 = $18;
 do {
  if ($20) {
   $22 = ((($0)) + 80|0);
   $23 = ((($0)) + 84|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = HEAP32[$22>>2]|0;
   $26 = (($24) - ($25))|0;
   $27 = ($26|0)==(24);
   $28 = $25;
   if ($27) {
    $29 = HEAP32[$21>>2]|0;
    $30 = ((($21)) + 4|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = ((($21)) + 8|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = +HEAPF64[$28>>3];
    $35 = $34;
    $36 = ((($28)) + 8|0);
    $37 = +HEAPF64[$36>>3];
    $38 = $37;
    $39 = ((($28)) + 16|0);
    $40 = +HEAPF64[$39>>3];
    $41 = $40;
    $42 = ((($8)) + 248|0);
    $43 = ((($8)) + 252|0);
    $44 = HEAP32[$43>>2]|0;
    $45 = HEAP32[$42>>2]|0;
    $46 = ($44|0)==($45|0);
    if ($46) {
     $$1 = 0;
     return ($$1|0);
    }
    $47 = (__ZN3osg8Geometry16getTexCoordArrayEj($8,0)|0);
    $48 = ($47|0)==(0|0);
    if ($48) {
     $$1 = 0;
     return ($$1|0);
    }
    $49 = (___dynamic_cast($47,23016,21080,0)|0);
    $50 = (___dynamic_cast($47,23016,5456,0)|0);
    $51 = (___dynamic_cast($47,23016,5496,0)|0);
    $52 = ($49|0)==(0|0);
    if (!($52)) {
     $53 = ((($49)) + 76|0);
     $54 = HEAP32[$53>>2]|0;
     $55 = (($54) + ($29<<2)|0);
     $56 = +HEAPF32[$55>>2];
     $57 = (($54) + ($31<<2)|0);
     $58 = +HEAPF32[$57>>2];
     $59 = (($54) + ($33<<2)|0);
     $60 = +HEAPF32[$59>>2];
     $61 = $35 * $56;
     $62 = $38 * $58;
     $63 = $61 + $62;
     $64 = $41 * $60;
     $65 = $63 + $64;
     HEAPF32[$1>>2] = $65;
     break;
    }
    $66 = ($50|0)==(0|0);
    if (!($66)) {
     $67 = ((($50)) + 76|0);
     $68 = HEAP32[$67>>2]|0;
     $69 = (($68) + ($29<<3)|0);
     $70 = +HEAPF32[$69>>2];
     $71 = $35 * $70;
     $72 = (($68) + ($31<<3)|0);
     $73 = +HEAPF32[$72>>2];
     $74 = $38 * $73;
     $75 = $71 + $74;
     $76 = (($68) + ($33<<3)|0);
     $77 = +HEAPF32[$76>>2];
     $78 = $41 * $77;
     $79 = $75 + $78;
     HEAPF32[$1>>2] = $79;
     $80 = (((($68) + ($29<<3)|0)) + 4|0);
     $81 = +HEAPF32[$80>>2];
     $82 = $35 * $81;
     $83 = (((($68) + ($31<<3)|0)) + 4|0);
     $84 = +HEAPF32[$83>>2];
     $85 = $38 * $84;
     $86 = $82 + $85;
     $87 = (((($68) + ($33<<3)|0)) + 4|0);
     $88 = +HEAPF32[$87>>2];
     $89 = $41 * $88;
     $90 = $86 + $89;
     $91 = ((($1)) + 4|0);
     HEAPF32[$91>>2] = $90;
     break;
    }
    $92 = ($51|0)==(0|0);
    if ($92) {
     $$1 = 0;
     return ($$1|0);
    } else {
     $93 = ((($51)) + 76|0);
     $94 = HEAP32[$93>>2]|0;
     $95 = (($94) + (($29*12)|0)|0);
     $96 = +HEAPF32[$95>>2];
     $97 = $35 * $96;
     $98 = (($94) + (($31*12)|0)|0);
     $99 = +HEAPF32[$98>>2];
     $100 = $38 * $99;
     $101 = $97 + $100;
     $102 = (($94) + (($33*12)|0)|0);
     $103 = +HEAPF32[$102>>2];
     $104 = $41 * $103;
     $105 = $101 + $104;
     HEAPF32[$1>>2] = $105;
     $106 = (((($94) + (($29*12)|0)|0)) + 4|0);
     $107 = +HEAPF32[$106>>2];
     $108 = $35 * $107;
     $109 = (((($94) + (($31*12)|0)|0)) + 4|0);
     $110 = +HEAPF32[$109>>2];
     $111 = $38 * $110;
     $112 = $108 + $111;
     $113 = (((($94) + (($33*12)|0)|0)) + 4|0);
     $114 = +HEAPF32[$113>>2];
     $115 = $41 * $114;
     $116 = $112 + $115;
     $117 = ((($1)) + 4|0);
     HEAPF32[$117>>2] = $116;
     $118 = (((($94) + (($29*12)|0)|0)) + 8|0);
     $119 = +HEAPF32[$118>>2];
     $120 = $35 * $119;
     $121 = (((($94) + (($31*12)|0)|0)) + 8|0);
     $122 = +HEAPF32[$121>>2];
     $123 = $38 * $122;
     $124 = $120 + $123;
     $125 = (((($94) + (($33*12)|0)|0)) + 8|0);
     $126 = +HEAPF32[$125>>2];
     $127 = $41 * $126;
     $128 = $124 + $127;
     $129 = ((($1)) + 8|0);
     HEAPF32[$129>>2] = $128;
     break;
    }
   }
  }
 } while(0);
 $130 = HEAP32[$2>>2]|0;
 $131 = ((($130)) + 120|0);
 $132 = HEAP32[$131>>2]|0;
 $133 = ($132|0)==(0|0);
 if ($133) {
  $$1163 = 0;$$1165 = 0;
 } else {
  $134 = (__ZN3osg8StateSet19getTextureAttributeEjNS_14StateAttribute4TypeE($132,0,19)|0);
  $135 = ($134|0)==(0|0);
  if ($135) {
   $247 = 0;
  } else {
   $136 = (___dynamic_cast($134,19768,26736,0)|0);
   $247 = $136;
  }
  $137 = HEAP32[$2>>2]|0;
  $138 = ((($137)) + 120|0);
  $139 = HEAP32[$138>>2]|0;
  $140 = (__ZN3osg8StateSet19getTextureAttributeEjNS_14StateAttribute4TypeE($139,0,0)|0);
  $141 = ($140|0)==(0|0);
  if ($141) {
   $$1163 = $247;$$1165 = 0;
  } else {
   $142 = (___dynamic_cast($140,19768,26864,0)|0);
   $$1163 = $247;$$1165 = $142;
  }
 }
 $143 = ((($0)) + 12|0);
 $144 = HEAP32[$143>>2]|0;
 $145 = ((($0)) + 8|0);
 $146 = HEAP32[$145>>2]|0;
 $147 = ($144|0)==($146|0);
 L39: do {
  if ($147) {
   $$2$lcssa = $$1163;$$2166$lcssa = $$1165;
   label = 22;
  } else {
   $$2166208 = $$1165;$$2209 = $$1163;$152 = $144;
   while(1) {
    $148 = ($$2209|0)!=(0|0);
    $$not = $148 ^ 1;
    $149 = ($$2166208|0)==(0|0);
    $or$cond = $149 | $$not;
    if (!($or$cond)) {
     $$2166207 = $$2166208;$$2205 = $$2209;
     break L39;
    }
    $151 = ((($152)) + -4|0);
    $153 = HEAP32[$151>>2]|0;
    $154 = ((($153)) + 120|0);
    $155 = HEAP32[$154>>2]|0;
    $156 = ($155|0)==(0|0);
    if ($156) {
     $$4168 = $$2166208;$$5 = $$2209;
    } else {
     if ($148) {
      $$4 = $$2209;
     } else {
      $157 = (__ZNK3osg8StateSet19getTextureAttributeEjNS_14StateAttribute4TypeE($155,0,19)|0);
      $158 = ($157|0)==(0|0);
      if ($158) {
       $$4 = 0;
      } else {
       $159 = (___dynamic_cast($157,19768,26736,0)|0);
       $$4 = $159;
      }
     }
     if ($149) {
      $160 = HEAP32[$154>>2]|0;
      $161 = (__ZNK3osg8StateSet19getTextureAttributeEjNS_14StateAttribute4TypeE($160,0,0)|0);
      $162 = ($161|0)==(0|0);
      if ($162) {
       $$4168 = 0;$$5 = $$4;
      } else {
       $163 = (___dynamic_cast($161,19768,26864,0)|0);
       $$4168 = $163;$$5 = $$4;
      }
     } else {
      $$4168 = $$2166208;$$5 = $$4;
     }
    }
    $164 = HEAP32[$145>>2]|0;
    $165 = ($151|0)==($164|0);
    if ($165) {
     $$2$lcssa = $$5;$$2166$lcssa = $$4168;
     label = 22;
     break;
    } else {
     $$2166208 = $$4168;$$2209 = $$5;$152 = $151;
    }
   }
  }
 } while(0);
 if ((label|0) == 22) {
  $150 = ($$2$lcssa|0)==(0|0);
  if ($150) {
   $$1 = $$2166$lcssa;
   return ($$1|0);
  } else {
   $$2166207 = $$2166$lcssa;$$2205 = $$2$lcssa;
  }
 }
 $166 = +HEAPF32[$1>>2];
 $167 = ((($1)) + 4|0);
 $168 = +HEAPF32[$167>>2];
 $169 = ((($1)) + 8|0);
 $170 = +HEAPF32[$169>>2];
 $171 = ((($$2205)) + 56|0);
 $172 = +HEAPF64[$171>>3];
 $173 = $166;
 $174 = $173 * $172;
 $175 = ((($$2205)) + 88|0);
 $176 = +HEAPF64[$175>>3];
 $177 = $168;
 $178 = $177 * $176;
 $179 = $174 + $178;
 $180 = ((($$2205)) + 120|0);
 $181 = +HEAPF64[$180>>3];
 $182 = $170;
 $183 = $182 * $181;
 $184 = $179 + $183;
 $185 = ((($$2205)) + 152|0);
 $186 = +HEAPF64[$185>>3];
 $187 = $186 * 0.0;
 $188 = $184 + $187;
 $189 = $188;
 $190 = ((($$2205)) + 64|0);
 $191 = +HEAPF64[$190>>3];
 $192 = $173 * $191;
 $193 = ((($$2205)) + 96|0);
 $194 = +HEAPF64[$193>>3];
 $195 = $177 * $194;
 $196 = $192 + $195;
 $197 = ((($$2205)) + 128|0);
 $198 = +HEAPF64[$197>>3];
 $199 = $182 * $198;
 $200 = $196 + $199;
 $201 = ((($$2205)) + 160|0);
 $202 = +HEAPF64[$201>>3];
 $203 = $202 * 0.0;
 $204 = $200 + $203;
 $205 = $204;
 $206 = ((($$2205)) + 72|0);
 $207 = +HEAPF64[$206>>3];
 $208 = $173 * $207;
 $209 = ((($$2205)) + 104|0);
 $210 = +HEAPF64[$209>>3];
 $211 = $177 * $210;
 $212 = $208 + $211;
 $213 = ((($$2205)) + 136|0);
 $214 = +HEAPF64[$213>>3];
 $215 = $182 * $214;
 $216 = $212 + $215;
 $217 = ((($$2205)) + 168|0);
 $218 = +HEAPF64[$217>>3];
 $219 = $218 * 0.0;
 $220 = $216 + $219;
 $221 = $220;
 HEAPF32[$1>>2] = $189;
 HEAPF32[$167>>2] = $205;
 HEAPF32[$169>>2] = $221;
 $222 = ($$2166207|0)==(0|0);
 if ($222) {
  $$1 = 0;
  return ($$1|0);
 }
 $223 = ((($$2205)) + 184|0);
 $224 = HEAP8[$223>>0]|0;
 $225 = ($224<<24>>24)==(0);
 if ($225) {
  $$1 = $$2166207;
  return ($$1|0);
 }
 $226 = HEAP32[$$2166207>>2]|0;
 $227 = ((($226)) + 184|0);
 $228 = HEAP32[$227>>2]|0;
 $229 = (FUNCTION_TABLE_ii[$228 & 8191]($$2166207)|0);
 $230 = (+($229|0));
 $231 = +HEAPF32[$1>>2];
 $232 = $231 * $230;
 HEAPF32[$1>>2] = $232;
 $233 = HEAP32[$$2166207>>2]|0;
 $234 = ((($233)) + 188|0);
 $235 = HEAP32[$234>>2]|0;
 $236 = (FUNCTION_TABLE_ii[$235 & 8191]($$2166207)|0);
 $237 = (+($236|0));
 $238 = +HEAPF32[$167>>2];
 $239 = $238 * $237;
 HEAPF32[$167>>2] = $239;
 $240 = HEAP32[$$2166207>>2]|0;
 $241 = ((($240)) + 192|0);
 $242 = HEAP32[$241>>2]|0;
 $243 = (FUNCTION_TABLE_ii[$242 & 8191]($$2166207)|0);
 $244 = (+($243|0));
 $245 = +HEAPF32[$169>>2];
 $246 = $245 * $244;
 HEAPF32[$169>>2] = $246;
 $$1 = $$2166207;
 return ($$1|0);
}
function __ZN7osgUtil9SceneViewD2Ev($0) {
 $0 = $0|0;
 var $$0 = 0, $$02 = 0, $$1 = 0, $$10 = 0, $$1019 = 0, $$11 = 0, $$110 = 0, $$1120 = 0, $$12 = 0, $$1221 = 0, $$13 = 0, $$1322 = 0, $$14 = 0, $$1423 = 0, $$15 = 0, $$1524 = 0, $$16 = 0, $$1625 = 0, $$17 = 0, $$1726 = 0;
 var $$18 = 0, $$1827 = 0, $$19 = 0, $$1928 = 0, $$2 = 0, $$20 = 0, $$2029 = 0, $$21 = 0, $$211 = 0, $$2130 = 0, $$22 = 0, $$2231 = 0, $$23 = 0, $$2332 = 0, $$3 = 0, $$312 = 0, $$4 = 0, $$413 = 0, $$5 = 0, $$514 = 0;
 var $$6 = 0, $$615 = 0, $$7 = 0, $$716 = 0, $$8 = 0, $$817 = 0, $$9 = 0, $$918 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0;
 var $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0;
 var $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0;
 var $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0;
 var $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0;
 var $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0;
 var $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0;
 var $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0;
 var $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0;
 var $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0;
 var $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0;
 var $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0;
 var $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0;
 var $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0;
 var $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0;
 var $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0;
 var $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0;
 var $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0;
 var $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (49380);
 $1 = ((($0)) + 32|0);
 HEAP32[$1>>2] = (49592);
 $2 = ((($0)) + 228|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  label = 4;
 } else {
  $5 = ((($3)) + 8|0);
  $6 = HEAP32[$5>>2]|0;HEAP32[$5>>2] = (($6-1)|0);
  $7 = ($6|0)==(1);
  if ($7) {
   __THREW__ = 0;
   invoke_viii(3262,($3|0),1,1);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if ($9) {
    $221 = ___cxa_find_matching_catch_2()|0;
    $222 = tempRet0;
    $223 = ((($0)) + 224|0);
    $224 = HEAP32[$223>>2]|0;
    $225 = ($224|0)==(0|0);
    if (!($225)) {
     $226 = ((($224)) + 8|0);
     $227 = HEAP32[$226>>2]|0;HEAP32[$226>>2] = (($227-1)|0);
     $228 = ($227|0)==(1);
     if ($228) {
      __THREW__ = 0;
      invoke_viii(3262,($224|0),1,1);
      $229 = __THREW__; __THREW__ = 0;
      $230 = $229&1;
      if ($230) {
       $484 = ___cxa_find_matching_catch_3(0|0)|0;
       $485 = tempRet0;
       ___clang_call_terminate($484);
       // unreachable;
      }
     }
    }
    HEAP32[$223>>2] = 0;
    $$0 = $222;$$02 = $221;
    label = 81;
   } else {
    label = 4;
   }
  } else {
   label = 4;
  }
 }
 L10: do {
  if ((label|0) == 4) {
   HEAP32[$2>>2] = 0;
   $10 = ((($0)) + 224|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = ($11|0)==(0|0);
   if (!($12)) {
    $13 = ((($11)) + 8|0);
    $14 = HEAP32[$13>>2]|0;HEAP32[$13>>2] = (($14-1)|0);
    $15 = ($14|0)==(1);
    if ($15) {
     __THREW__ = 0;
     invoke_viii(3262,($11|0),1,1);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      $231 = ___cxa_find_matching_catch_2()|0;
      $232 = tempRet0;
      $$0 = $232;$$02 = $231;
      label = 81;
      break;
     }
    }
   }
   HEAP32[$10>>2] = 0;
   $18 = ((($0)) + 220|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ($19|0)==(0|0);
   if (!($20)) {
    $21 = ((($19)) + 8|0);
    $22 = HEAP32[$21>>2]|0;HEAP32[$21>>2] = (($22-1)|0);
    $23 = ($22|0)==(1);
    if ($23) {
     __THREW__ = 0;
     invoke_viii(3262,($19|0),1,1);
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if ($25) {
      $233 = ___cxa_find_matching_catch_2()|0;
      $234 = tempRet0;
      $$1 = $234;$$110 = $233;
      label = 86;
      break;
     }
    }
   }
   HEAP32[$18>>2] = 0;
   $26 = ((($0)) + 216|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = ($27|0)==(0|0);
   if (!($28)) {
    $29 = ((($27)) + 8|0);
    $30 = HEAP32[$29>>2]|0;HEAP32[$29>>2] = (($30-1)|0);
    $31 = ($30|0)==(1);
    if ($31) {
     __THREW__ = 0;
     invoke_viii(3262,($27|0),1,1);
     $32 = __THREW__; __THREW__ = 0;
     $33 = $32&1;
     if ($33) {
      $243 = ___cxa_find_matching_catch_2()|0;
      $244 = tempRet0;
      $$2 = $244;$$211 = $243;
      label = 91;
      break;
     }
    }
   }
   HEAP32[$26>>2] = 0;
   $34 = ((($0)) + 212|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ($35|0)==(0|0);
   if (!($36)) {
    $37 = ((($35)) + 8|0);
    $38 = HEAP32[$37>>2]|0;HEAP32[$37>>2] = (($38-1)|0);
    $39 = ($38|0)==(1);
    if ($39) {
     __THREW__ = 0;
     invoke_viii(3262,($35|0),1,1);
     $40 = __THREW__; __THREW__ = 0;
     $41 = $40&1;
     if ($41) {
      $253 = ___cxa_find_matching_catch_2()|0;
      $254 = tempRet0;
      $$3 = $254;$$312 = $253;
      label = 96;
      break;
     }
    }
   }
   HEAP32[$34>>2] = 0;
   $42 = ((($0)) + 204|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = ($43|0)==(0|0);
   if (!($44)) {
    $45 = ((($43)) + 8|0);
    $46 = HEAP32[$45>>2]|0;HEAP32[$45>>2] = (($46-1)|0);
    $47 = ($46|0)==(1);
    if ($47) {
     __THREW__ = 0;
     invoke_viii(3262,($43|0),1,1);
     $48 = __THREW__; __THREW__ = 0;
     $49 = $48&1;
     if ($49) {
      $263 = ___cxa_find_matching_catch_2()|0;
      $264 = tempRet0;
      $$4 = $264;$$413 = $263;
      label = 101;
      break;
     }
    }
   }
   HEAP32[$42>>2] = 0;
   $50 = ((($0)) + 200|0);
   $51 = HEAP32[$50>>2]|0;
   $52 = ($51|0)==(0|0);
   if (!($52)) {
    $53 = ((($51)) + 8|0);
    $54 = HEAP32[$53>>2]|0;HEAP32[$53>>2] = (($54-1)|0);
    $55 = ($54|0)==(1);
    if ($55) {
     __THREW__ = 0;
     invoke_viii(3262,($51|0),1,1);
     $56 = __THREW__; __THREW__ = 0;
     $57 = $56&1;
     if ($57) {
      $273 = ___cxa_find_matching_catch_2()|0;
      $274 = tempRet0;
      $$5 = $274;$$514 = $273;
      label = 106;
      break;
     }
    }
   }
   HEAP32[$50>>2] = 0;
   $58 = ((($0)) + 196|0);
   $59 = HEAP32[$58>>2]|0;
   $60 = ($59|0)==(0|0);
   if (!($60)) {
    $61 = HEAP32[$59>>2]|0;
    $62 = ((($61)) + -12|0);
    $63 = HEAP32[$62>>2]|0;
    $64 = (($59) + ($63)|0);
    $65 = ((($64)) + 8|0);
    $66 = HEAP32[$65>>2]|0;HEAP32[$65>>2] = (($66-1)|0);
    $67 = ($66|0)==(1);
    if ($67) {
     __THREW__ = 0;
     invoke_viii(3262,($64|0),1,1);
     $68 = __THREW__; __THREW__ = 0;
     $69 = $68&1;
     if ($69) {
      $283 = ___cxa_find_matching_catch_2()|0;
      $284 = tempRet0;
      $$6 = $284;$$615 = $283;
      label = 111;
      break;
     }
    }
   }
   HEAP32[$58>>2] = 0;
   $70 = ((($0)) + 192|0);
   $71 = HEAP32[$70>>2]|0;
   $72 = ($71|0)==(0|0);
   if (!($72)) {
    $73 = ((($71)) + 8|0);
    $74 = HEAP32[$73>>2]|0;HEAP32[$73>>2] = (($74-1)|0);
    $75 = ($74|0)==(1);
    if ($75) {
     __THREW__ = 0;
     invoke_viii(3262,($71|0),1,1);
     $76 = __THREW__; __THREW__ = 0;
     $77 = $76&1;
     if ($77) {
      $297 = ___cxa_find_matching_catch_2()|0;
      $298 = tempRet0;
      $$7 = $298;$$716 = $297;
      label = 116;
      break;
     }
    }
   }
   HEAP32[$70>>2] = 0;
   $78 = ((($0)) + 188|0);
   $79 = HEAP32[$78>>2]|0;
   $80 = ($79|0)==(0|0);
   if (!($80)) {
    $81 = ((($79)) + 8|0);
    $82 = HEAP32[$81>>2]|0;HEAP32[$81>>2] = (($82-1)|0);
    $83 = ($82|0)==(1);
    if ($83) {
     __THREW__ = 0;
     invoke_viii(3262,($79|0),1,1);
     $84 = __THREW__; __THREW__ = 0;
     $85 = $84&1;
     if ($85) {
      $307 = ___cxa_find_matching_catch_2()|0;
      $308 = tempRet0;
      $$8 = $308;$$817 = $307;
      label = 121;
      break;
     }
    }
   }
   HEAP32[$78>>2] = 0;
   $86 = ((($0)) + 184|0);
   $87 = HEAP32[$86>>2]|0;
   $88 = ($87|0)==(0|0);
   if (!($88)) {
    $89 = ((($87)) + 8|0);
    $90 = HEAP32[$89>>2]|0;HEAP32[$89>>2] = (($90-1)|0);
    $91 = ($90|0)==(1);
    if ($91) {
     __THREW__ = 0;
     invoke_viii(3262,($87|0),1,1);
     $92 = __THREW__; __THREW__ = 0;
     $93 = $92&1;
     if ($93) {
      $317 = ___cxa_find_matching_catch_2()|0;
      $318 = tempRet0;
      $$9 = $318;$$918 = $317;
      label = 126;
      break;
     }
    }
   }
   HEAP32[$86>>2] = 0;
   $94 = ((($0)) + 180|0);
   $95 = HEAP32[$94>>2]|0;
   $96 = ($95|0)==(0|0);
   if (!($96)) {
    $97 = HEAP32[$95>>2]|0;
    $98 = ((($97)) + -12|0);
    $99 = HEAP32[$98>>2]|0;
    $100 = (($95) + ($99)|0);
    $101 = ((($100)) + 8|0);
    $102 = HEAP32[$101>>2]|0;HEAP32[$101>>2] = (($102-1)|0);
    $103 = ($102|0)==(1);
    if ($103) {
     __THREW__ = 0;
     invoke_viii(3262,($100|0),1,1);
     $104 = __THREW__; __THREW__ = 0;
     $105 = $104&1;
     if ($105) {
      $327 = ___cxa_find_matching_catch_2()|0;
      $328 = tempRet0;
      $$10 = $328;$$1019 = $327;
      label = 131;
      break;
     }
    }
   }
   HEAP32[$94>>2] = 0;
   $106 = ((($0)) + 176|0);
   $107 = HEAP32[$106>>2]|0;
   $108 = ($107|0)==(0|0);
   if (!($108)) {
    $109 = ((($107)) + 8|0);
    $110 = HEAP32[$109>>2]|0;HEAP32[$109>>2] = (($110-1)|0);
    $111 = ($110|0)==(1);
    if ($111) {
     __THREW__ = 0;
     invoke_viii(3262,($107|0),1,1);
     $112 = __THREW__; __THREW__ = 0;
     $113 = $112&1;
     if ($113) {
      $341 = ___cxa_find_matching_catch_2()|0;
      $342 = tempRet0;
      $$11 = $342;$$1120 = $341;
      label = 136;
      break;
     }
    }
   }
   HEAP32[$106>>2] = 0;
   $114 = ((($0)) + 172|0);
   $115 = HEAP32[$114>>2]|0;
   $116 = ($115|0)==(0|0);
   if (!($116)) {
    $117 = ((($115)) + 8|0);
    $118 = HEAP32[$117>>2]|0;HEAP32[$117>>2] = (($118-1)|0);
    $119 = ($118|0)==(1);
    if ($119) {
     __THREW__ = 0;
     invoke_viii(3262,($115|0),1,1);
     $120 = __THREW__; __THREW__ = 0;
     $121 = $120&1;
     if ($121) {
      $351 = ___cxa_find_matching_catch_2()|0;
      $352 = tempRet0;
      $$12 = $352;$$1221 = $351;
      label = 141;
      break;
     }
    }
   }
   HEAP32[$114>>2] = 0;
   $122 = ((($0)) + 168|0);
   $123 = HEAP32[$122>>2]|0;
   $124 = ($123|0)==(0|0);
   if (!($124)) {
    $125 = ((($123)) + 8|0);
    $126 = HEAP32[$125>>2]|0;HEAP32[$125>>2] = (($126-1)|0);
    $127 = ($126|0)==(1);
    if ($127) {
     __THREW__ = 0;
     invoke_viii(3262,($123|0),1,1);
     $128 = __THREW__; __THREW__ = 0;
     $129 = $128&1;
     if ($129) {
      $361 = ___cxa_find_matching_catch_2()|0;
      $362 = tempRet0;
      $$13 = $362;$$1322 = $361;
      label = 146;
      break;
     }
    }
   }
   HEAP32[$122>>2] = 0;
   $130 = ((($0)) + 164|0);
   $131 = HEAP32[$130>>2]|0;
   $132 = ($131|0)==(0|0);
   if (!($132)) {
    $133 = HEAP32[$131>>2]|0;
    $134 = ((($133)) + -12|0);
    $135 = HEAP32[$134>>2]|0;
    $136 = (($131) + ($135)|0);
    $137 = ((($136)) + 8|0);
    $138 = HEAP32[$137>>2]|0;HEAP32[$137>>2] = (($138-1)|0);
    $139 = ($138|0)==(1);
    if ($139) {
     __THREW__ = 0;
     invoke_viii(3262,($136|0),1,1);
     $140 = __THREW__; __THREW__ = 0;
     $141 = $140&1;
     if ($141) {
      $371 = ___cxa_find_matching_catch_2()|0;
      $372 = tempRet0;
      $$14 = $372;$$1423 = $371;
      label = 151;
      break;
     }
    }
   }
   HEAP32[$130>>2] = 0;
   $142 = ((($0)) + 160|0);
   $143 = HEAP32[$142>>2]|0;
   $144 = ($143|0)==(0|0);
   do {
    if (!($144)) {
     $145 = ((($143)) + 8|0);
     $146 = HEAP32[$145>>2]|0;HEAP32[$145>>2] = (($146-1)|0);
     $147 = ($146|0)==(1);
     if ($147) {
      __THREW__ = 0;
      invoke_viii(3262,($143|0),1,1);
      $148 = __THREW__; __THREW__ = 0;
      $149 = $148&1;
      if (!($149)) {
       break;
      }
      $385 = ___cxa_find_matching_catch_2()|0;
      $386 = tempRet0;
      $$15 = $386;$$1524 = $385;
      label = 156;
      break L10;
     }
    }
   } while(0);
   HEAP32[$142>>2] = 0;
   $150 = ((($0)) + 156|0);
   $151 = HEAP32[$150>>2]|0;
   $152 = ($151|0)==(0|0);
   do {
    if (!($152)) {
     $153 = ((($151)) + 8|0);
     $154 = HEAP32[$153>>2]|0;HEAP32[$153>>2] = (($154-1)|0);
     $155 = ($154|0)==(1);
     if (!($155)) {
      break;
     }
     __THREW__ = 0;
     invoke_viii(3262,($151|0),1,1);
     $156 = __THREW__; __THREW__ = 0;
     $157 = $156&1;
     if (!($157)) {
      break;
     }
     $395 = ___cxa_find_matching_catch_2()|0;
     $396 = tempRet0;
     $$16 = $396;$$1625 = $395;
     label = 161;
     break L10;
    }
   } while(0);
   HEAP32[$150>>2] = 0;
   $158 = ((($0)) + 152|0);
   $159 = HEAP32[$158>>2]|0;
   $160 = ($159|0)==(0|0);
   do {
    if (!($160)) {
     $161 = ((($159)) + 8|0);
     $162 = HEAP32[$161>>2]|0;HEAP32[$161>>2] = (($162-1)|0);
     $163 = ($162|0)==(1);
     if (!($163)) {
      break;
     }
     __THREW__ = 0;
     invoke_viii(3262,($159|0),1,1);
     $164 = __THREW__; __THREW__ = 0;
     $165 = $164&1;
     if (!($165)) {
      break;
     }
     $405 = ___cxa_find_matching_catch_2()|0;
     $406 = tempRet0;
     $$17 = $406;$$1726 = $405;
     label = 166;
     break L10;
    }
   } while(0);
   HEAP32[$158>>2] = 0;
   $166 = ((($0)) + 148|0);
   $167 = HEAP32[$166>>2]|0;
   $168 = ($167|0)==(0|0);
   do {
    if (!($168)) {
     $169 = HEAP32[$167>>2]|0;
     $170 = ((($169)) + -12|0);
     $171 = HEAP32[$170>>2]|0;
     $172 = (($167) + ($171)|0);
     $173 = ((($172)) + 8|0);
     $174 = HEAP32[$173>>2]|0;HEAP32[$173>>2] = (($174-1)|0);
     $175 = ($174|0)==(1);
     if (!($175)) {
      break;
     }
     __THREW__ = 0;
     invoke_viii(3262,($172|0),1,1);
     $176 = __THREW__; __THREW__ = 0;
     $177 = $176&1;
     if (!($177)) {
      break;
     }
     $415 = ___cxa_find_matching_catch_2()|0;
     $416 = tempRet0;
     $$18 = $416;$$1827 = $415;
     label = 171;
     break L10;
    }
   } while(0);
   HEAP32[$166>>2] = 0;
   $178 = ((($0)) + 144|0);
   $179 = HEAP32[$178>>2]|0;
   $180 = ($179|0)==(0|0);
   do {
    if (!($180)) {
     $181 = HEAP32[$179>>2]|0;
     $182 = ((($181)) + -12|0);
     $183 = HEAP32[$182>>2]|0;
     $184 = (($179) + ($183)|0);
     $185 = ((($184)) + 8|0);
     $186 = HEAP32[$185>>2]|0;HEAP32[$185>>2] = (($186-1)|0);
     $187 = ($186|0)==(1);
     if (!($187)) {
      break;
     }
     __THREW__ = 0;
     invoke_viii(3262,($184|0),1,1);
     $188 = __THREW__; __THREW__ = 0;
     $189 = $188&1;
     if (!($189)) {
      break;
     }
     $429 = ___cxa_find_matching_catch_2()|0;
     $430 = tempRet0;
     $$19 = $430;$$1928 = $429;
     label = 176;
     break L10;
    }
   } while(0);
   HEAP32[$178>>2] = 0;
   $190 = ((($0)) + 140|0);
   $191 = HEAP32[$190>>2]|0;
   $192 = ($191|0)==(0|0);
   do {
    if (!($192)) {
     $193 = HEAP32[$191>>2]|0;
     $194 = ((($193)) + -12|0);
     $195 = HEAP32[$194>>2]|0;
     $196 = (($191) + ($195)|0);
     $197 = ((($196)) + 8|0);
     $198 = HEAP32[$197>>2]|0;HEAP32[$197>>2] = (($198-1)|0);
     $199 = ($198|0)==(1);
     if (!($199)) {
      break;
     }
     __THREW__ = 0;
     invoke_viii(3262,($196|0),1,1);
     $200 = __THREW__; __THREW__ = 0;
     $201 = $200&1;
     if (!($201)) {
      break;
     }
     $443 = ___cxa_find_matching_catch_2()|0;
     $444 = tempRet0;
     $$20 = $444;$$2029 = $443;
     label = 181;
     break L10;
    }
   } while(0);
   HEAP32[$190>>2] = 0;
   $202 = ((($0)) + 100|0);
   __THREW__ = 0;
   invoke_vi(3504,($202|0));
   $203 = __THREW__; __THREW__ = 0;
   $204 = $203&1;
   if ($204) {
    $457 = ___cxa_find_matching_catch_2()|0;
    $458 = tempRet0;
    $$21 = $458;$$2130 = $457;
    label = 183;
    break;
   }
   $205 = ((($0)) + 96|0);
   $206 = HEAP32[$205>>2]|0;
   $207 = ($206|0)==(0|0);
   do {
    if (!($207)) {
     $208 = ((($206)) + 8|0);
     $209 = HEAP32[$208>>2]|0;HEAP32[$208>>2] = (($209-1)|0);
     $210 = ($209|0)==(1);
     if (!($210)) {
      break;
     }
     __THREW__ = 0;
     invoke_viii(3262,($206|0),1,1);
     $211 = __THREW__; __THREW__ = 0;
     $212 = $211&1;
     if (!($212)) {
      break;
     }
     $462 = ___cxa_find_matching_catch_2()|0;
     $463 = tempRet0;
     $$22 = $463;$$2231 = $462;
     label = 188;
     break L10;
    }
   } while(0);
   HEAP32[$205>>2] = 0;
   HEAP32[$1>>2] = (58232);
   $213 = ((($0)) + 60|0);
   $214 = HEAP32[$213>>2]|0;
   $215 = ($214|0)==(0|0);
   if ($215) {
    HEAP32[$213>>2] = 0;
    __ZN3osg6ObjectD2Ev($0);
    return;
   }
   $216 = ((($214)) + 8|0);
   $217 = HEAP32[$216>>2]|0;HEAP32[$216>>2] = (($217-1)|0);
   $218 = ($217|0)==(1);
   if (!($218)) {
    HEAP32[$213>>2] = 0;
    __ZN3osg6ObjectD2Ev($0);
    return;
   }
   __THREW__ = 0;
   invoke_viii(3262,($214|0),1,1);
   $219 = __THREW__; __THREW__ = 0;
   $220 = $219&1;
   if ($220) {
    $472 = ___cxa_find_matching_catch_2()|0;
    $473 = tempRet0;
    $$23 = $473;$$2332 = $472;
    break;
   } else {
    HEAP32[$213>>2] = 0;
    __ZN3osg6ObjectD2Ev($0);
    return;
   }
  }
 } while(0);
 if ((label|0) == 81) {
  $235 = ((($0)) + 220|0);
  $236 = HEAP32[$235>>2]|0;
  $237 = ($236|0)==(0|0);
  if (!($237)) {
   $238 = ((($236)) + 8|0);
   $239 = HEAP32[$238>>2]|0;HEAP32[$238>>2] = (($239-1)|0);
   $240 = ($239|0)==(1);
   if ($240) {
    __THREW__ = 0;
    invoke_viii(3262,($236|0),1,1);
    $241 = __THREW__; __THREW__ = 0;
    $242 = $241&1;
    if ($242) {
     $484 = ___cxa_find_matching_catch_3(0|0)|0;
     $485 = tempRet0;
     ___clang_call_terminate($484);
     // unreachable;
    }
   }
  }
  HEAP32[$235>>2] = 0;
  $$1 = $$0;$$110 = $$02;
  label = 86;
 }
 if ((label|0) == 86) {
  $245 = ((($0)) + 216|0);
  $246 = HEAP32[$245>>2]|0;
  $247 = ($246|0)==(0|0);
  if (!($247)) {
   $248 = ((($246)) + 8|0);
   $249 = HEAP32[$248>>2]|0;HEAP32[$248>>2] = (($249-1)|0);
   $250 = ($249|0)==(1);
   if ($250) {
    __THREW__ = 0;
    invoke_viii(3262,($246|0),1,1);
    $251 = __THREW__; __THREW__ = 0;
    $252 = $251&1;
    if ($252) {
     $484 = ___cxa_find_matching_catch_3(0|0)|0;
     $485 = tempRet0;
     ___clang_call_terminate($484);
     // unreachable;
    }
   }
  }
  HEAP32[$245>>2] = 0;
  $$2 = $$1;$$211 = $$110;
  label = 91;
 }
 if ((label|0) == 91) {
  $255 = ((($0)) + 212|0);
  $256 = HEAP32[$255>>2]|0;
  $257 = ($256|0)==(0|0);
  if (!($257)) {
   $258 = ((($256)) + 8|0);
   $259 = HEAP32[$258>>2]|0;HEAP32[$258>>2] = (($259-1)|0);
   $260 = ($259|0)==(1);
   if ($260) {
    __THREW__ = 0;
    invoke_viii(3262,($256|0),1,1);
    $261 = __THREW__; __THREW__ = 0;
    $262 = $261&1;
    if ($262) {
     $484 = ___cxa_find_matching_catch_3(0|0)|0;
     $485 = tempRet0;
     ___clang_call_terminate($484);
     // unreachable;
    }
   }
  }
  HEAP32[$255>>2] = 0;
  $$3 = $$2;$$312 = $$211;
  label = 96;
 }
 if ((label|0) == 96) {
  $265 = ((($0)) + 204|0);
  $266 = HEAP32[$265>>2]|0;
  $267 = ($266|0)==(0|0);
  if (!($267)) {
   $268 = ((($266)) + 8|0);
   $269 = HEAP32[$268>>2]|0;HEAP32[$268>>2] = (($269-1)|0);
   $270 = ($269|0)==(1);
   if ($270) {
    __THREW__ = 0;
    invoke_viii(3262,($266|0),1,1);
    $271 = __THREW__; __THREW__ = 0;
    $272 = $271&1;
    if ($272) {
     $484 = ___cxa_find_matching_catch_3(0|0)|0;
     $485 = tempRet0;
     ___clang_call_terminate($484);
     // unreachable;
    }
   }
  }
  HEAP32[$265>>2] = 0;
  $$4 = $$3;$$413 = $$312;
  label = 101;
 }
 if ((label|0) == 101) {
  $275 = ((($0)) + 200|0);
  $276 = HEAP32[$275>>2]|0;
  $277 = ($276|0)==(0|0);
  if (!($277)) {
   $278 = ((($276)) + 8|0);
   $279 = HEAP32[$278>>2]|0;HEAP32[$278>>2] = (($279-1)|0);
   $280 = ($279|0)==(1);
   if ($280) {
    __THREW__ = 0;
    invoke_viii(3262,($276|0),1,1);
    $281 = __THREW__; __THREW__ = 0;
    $282 = $281&1;
    if ($282) {
     $484 = ___cxa_find_matching_catch_3(0|0)|0;
     $485 = tempRet0;
     ___clang_call_terminate($484);
     // unreachable;
    }
   }
  }
  HEAP32[$275>>2] = 0;
  $$5 = $$4;$$514 = $$413;
  label = 106;
 }
 if ((label|0) == 106) {
  $285 = ((($0)) + 196|0);
  $286 = HEAP32[$285>>2]|0;
  $287 = ($286|0)==(0|0);
  if (!($287)) {
   $288 = HEAP32[$286>>2]|0;
   $289 = ((($288)) + -12|0);
   $290 = HEAP32[$289>>2]|0;
   $291 = (($286) + ($290)|0);
   $292 = ((($291)) + 8|0);
   $293 = HEAP32[$292>>2]|0;HEAP32[$292>>2] = (($293-1)|0);
   $294 = ($293|0)==(1);
   if ($294) {
    __THREW__ = 0;
    invoke_viii(3262,($291|0),1,1);
    $295 = __THREW__; __THREW__ = 0;
    $296 = $295&1;
    if ($296) {
     $484 = ___cxa_find_matching_catch_3(0|0)|0;
     $485 = tempRet0;
     ___clang_call_terminate($484);
     // unreachable;
    }
   }
  }
  HEAP32[$285>>2] = 0;
  $$6 = $$5;$$615 = $$514;
  label = 111;
 }
 if ((label|0) == 111) {
  $299 = ((($0)) + 192|0);
  $300 = HEAP32[$299>>2]|0;
  $301 = ($300|0)==(0|0);
  if (!($301)) {
   $302 = ((($300)) + 8|0);
   $303 = HEAP32[$302>>2]|0;HEAP32[$302>>2] = (($303-1)|0);
   $304 = ($303|0)==(1);
   if ($304) {
    __THREW__ = 0;
    invoke_viii(3262,($300|0),1,1);
    $305 = __THREW__; __THREW__ = 0;
    $306 = $305&1;
    if ($306) {
     $484 = ___cxa_find_matching_catch_3(0|0)|0;
     $485 = tempRet0;
     ___clang_call_terminate($484);
     // unreachable;
    }
   }
  }
  HEAP32[$299>>2] = 0;
  $$7 = $$6;$$716 = $$615;
  label = 116;
 }
 if ((label|0) == 116) {
  $309 = ((($0)) + 188|0);
  $310 = HEAP32[$309>>2]|0;
  $311 = ($310|0)==(0|0);
  if (!($311)) {
   $312 = ((($310)) + 8|0);
   $313 = HEAP32[$312>>2]|0;HEAP32[$312>>2] = (($313-1)|0);
   $314 = ($313|0)==(1);
   if ($314) {
    __THREW__ = 0;
    invoke_viii(3262,($310|0),1,1);
    $315 = __THREW__; __THREW__ = 0;
    $316 = $315&1;
    if ($316) {
     $484 = ___cxa_find_matching_catch_3(0|0)|0;
     $485 = tempRet0;
     ___clang_call_terminate($484);
     // unreachable;
    }
   }
  }
  HEAP32[$309>>2] = 0;
  $$8 = $$7;$$817 = $$716;
  label = 121;
 }
 if ((label|0) == 121) {
  $319 = ((($0)) + 184|0);
  $320 = HEAP32[$319>>2]|0;
  $321 = ($320|0)==(0|0);
  if (!($321)) {
   $322 = ((($320)) + 8|0);
   $323 = HEAP32[$322>>2]|0;HEAP32[$322>>2] = (($323-1)|0);
   $324 = ($323|0)==(1);
   if ($324) {
    __THREW__ = 0;
    invoke_viii(3262,($320|0),1,1);
    $325 = __THREW__; __THREW__ = 0;
    $326 = $325&1;
    if ($326) {
     $484 = ___cxa_find_matching_catch_3(0|0)|0;
     $485 = tempRet0;
     ___clang_call_terminate($484);
     // unreachable;
    }
   }
  }
  HEAP32[$319>>2] = 0;
  $$9 = $$8;$$918 = $$817;
  label = 126;
 }
 if ((label|0) == 126) {
  $329 = ((($0)) + 180|0);
  $330 = HEAP32[$329>>2]|0;
  $331 = ($330|0)==(0|0);
  if (!($331)) {
   $332 = HEAP32[$330>>2]|0;
   $333 = ((($332)) + -12|0);
   $334 = HEAP32[$333>>2]|0;
   $335 = (($330) + ($334)|0);
   $336 = ((($335)) + 8|0);
   $337 = HEAP32[$336>>2]|0;HEAP32[$336>>2] = (($337-1)|0);
   $338 = ($337|0)==(1);
   if ($338) {
    __THREW__ = 0;
    invoke_viii(3262,($335|0),1,1);
    $339 = __THREW__; __THREW__ = 0;
    $340 = $339&1;
    if ($340) {
     $484 = ___cxa_find_matching_catch_3(0|0)|0;
     $485 = tempRet0;
     ___clang_call_terminate($484);
     // unreachable;
    }
   }
  }
  HEAP32[$329>>2] = 0;
  $$10 = $$9;$$1019 = $$918;
  label = 131;
 }
 if ((label|0) == 131) {
  $343 = ((($0)) + 176|0);
  $344 = HEAP32[$343>>2]|0;
  $345 = ($344|0)==(0|0);
  if (!($345)) {
   $346 = ((($344)) + 8|0);
   $347 = HEAP32[$346>>2]|0;HEAP32[$346>>2] = (($347-1)|0);
   $348 = ($347|0)==(1);
   if ($348) {
    __THREW__ = 0;
    invoke_viii(3262,($344|0),1,1);
    $349 = __THREW__; __THREW__ = 0;
    $350 = $349&1;
    if ($350) {
     $484 = ___cxa_find_matching_catch_3(0|0)|0;
     $485 = tempRet0;
     ___clang_call_terminate($484);
     // unreachable;
    }
   }
  }
  HEAP32[$343>>2] = 0;
  $$11 = $$10;$$1120 = $$1019;
  label = 136;
 }
 if ((label|0) == 136) {
  $353 = ((($0)) + 172|0);
  $354 = HEAP32[$353>>2]|0;
  $355 = ($354|0)==(0|0);
  if (!($355)) {
   $356 = ((($354)) + 8|0);
   $357 = HEAP32[$356>>2]|0;HEAP32[$356>>2] = (($357-1)|0);
   $358 = ($357|0)==(1);
   if ($358) {
    __THREW__ = 0;
    invoke_viii(3262,($354|0),1,1);
    $359 = __THREW__; __THREW__ = 0;
    $360 = $359&1;
    if ($360) {
     $484 = ___cxa_find_matching_catch_3(0|0)|0;
     $485 = tempRet0;
     ___clang_call_terminate($484);
     // unreachable;
    }
   }
  }
  HEAP32[$353>>2] = 0;
  $$12 = $$11;$$1221 = $$1120;
  label = 141;
 }
 if ((label|0) == 141) {
  $363 = ((($0)) + 168|0);
  $364 = HEAP32[$363>>2]|0;
  $365 = ($364|0)==(0|0);
  if (!($365)) {
   $366 = ((($364)) + 8|0);
   $367 = HEAP32[$366>>2]|0;HEAP32[$366>>2] = (($367-1)|0);
   $368 = ($367|0)==(1);
   if ($368) {
    __THREW__ = 0;
    invoke_viii(3262,($364|0),1,1);
    $369 = __THREW__; __THREW__ = 0;
    $370 = $369&1;
    if ($370) {
     $484 = ___cxa_find_matching_catch_3(0|0)|0;
     $485 = tempRet0;
     ___clang_call_terminate($484);
     // unreachable;
    }
   }
  }
  HEAP32[$363>>2] = 0;
  $$13 = $$12;$$1322 = $$1221;
  label = 146;
 }
 if ((label|0) == 146) {
  $373 = ((($0)) + 164|0);
  $374 = HEAP32[$373>>2]|0;
  $375 = ($374|0)==(0|0);
  if (!($375)) {
   $376 = HEAP32[$374>>2]|0;
   $377 = ((($376)) + -12|0);
   $378 = HEAP32[$377>>2]|0;
   $379 = (($374) + ($378)|0);
   $380 = ((($379)) + 8|0);
   $381 = HEAP32[$380>>2]|0;HEAP32[$380>>2] = (($381-1)|0);
   $382 = ($381|0)==(1);
   if ($382) {
    __THREW__ = 0;
    invoke_viii(3262,($379|0),1,1);
    $383 = __THREW__; __THREW__ = 0;
    $384 = $383&1;
    if ($384) {
     $484 = ___cxa_find_matching_catch_3(0|0)|0;
     $485 = tempRet0;
     ___clang_call_terminate($484);
     // unreachable;
    }
   }
  }
  HEAP32[$373>>2] = 0;
  $$14 = $$13;$$1423 = $$1322;
  label = 151;
 }
 if ((label|0) == 151) {
  $387 = ((($0)) + 160|0);
  $388 = HEAP32[$387>>2]|0;
  $389 = ($388|0)==(0|0);
  if (!($389)) {
   $390 = ((($388)) + 8|0);
   $391 = HEAP32[$390>>2]|0;HEAP32[$390>>2] = (($391-1)|0);
   $392 = ($391|0)==(1);
   if ($392) {
    __THREW__ = 0;
    invoke_viii(3262,($388|0),1,1);
    $393 = __THREW__; __THREW__ = 0;
    $394 = $393&1;
    if ($394) {
     $484 = ___cxa_find_matching_catch_3(0|0)|0;
     $485 = tempRet0;
     ___clang_call_terminate($484);
     // unreachable;
    }
   }
  }
  HEAP32[$387>>2] = 0;
  $$15 = $$14;$$1524 = $$1423;
  label = 156;
 }
 if ((label|0) == 156) {
  $397 = ((($0)) + 156|0);
  $398 = HEAP32[$397>>2]|0;
  $399 = ($398|0)==(0|0);
  if (!($399)) {
   $400 = ((($398)) + 8|0);
   $401 = HEAP32[$400>>2]|0;HEAP32[$400>>2] = (($401-1)|0);
   $402 = ($401|0)==(1);
   if ($402) {
    __THREW__ = 0;
    invoke_viii(3262,($398|0),1,1);
    $403 = __THREW__; __THREW__ = 0;
    $404 = $403&1;
    if ($404) {
     $484 = ___cxa_find_matching_catch_3(0|0)|0;
     $485 = tempRet0;
     ___clang_call_terminate($484);
     // unreachable;
    }
   }
  }
  HEAP32[$397>>2] = 0;
  $$16 = $$15;$$1625 = $$1524;
  label = 161;
 }
 if ((label|0) == 161) {
  $407 = ((($0)) + 152|0);
  $408 = HEAP32[$407>>2]|0;
  $409 = ($408|0)==(0|0);
  if (!($409)) {
   $410 = ((($408)) + 8|0);
   $411 = HEAP32[$410>>2]|0;HEAP32[$410>>2] = (($411-1)|0);
   $412 = ($411|0)==(1);
   if ($412) {
    __THREW__ = 0;
    invoke_viii(3262,($408|0),1,1);
    $413 = __THREW__; __THREW__ = 0;
    $414 = $413&1;
    if ($414) {
     $484 = ___cxa_find_matching_catch_3(0|0)|0;
     $485 = tempRet0;
     ___clang_call_terminate($484);
     // unreachable;
    }
   }
  }
  HEAP32[$407>>2] = 0;
  $$17 = $$16;$$1726 = $$1625;
  label = 166;
 }
 if ((label|0) == 166) {
  $417 = ((($0)) + 148|0);
  $418 = HEAP32[$417>>2]|0;
  $419 = ($418|0)==(0|0);
  if (!($419)) {
   $420 = HEAP32[$418>>2]|0;
   $421 = ((($420)) + -12|0);
   $422 = HEAP32[$421>>2]|0;
   $423 = (($418) + ($422)|0);
   $424 = ((($423)) + 8|0);
   $425 = HEAP32[$424>>2]|0;HEAP32[$424>>2] = (($425-1)|0);
   $426 = ($425|0)==(1);
   if ($426) {
    __THREW__ = 0;
    invoke_viii(3262,($423|0),1,1);
    $427 = __THREW__; __THREW__ = 0;
    $428 = $427&1;
    if ($428) {
     $484 = ___cxa_find_matching_catch_3(0|0)|0;
     $485 = tempRet0;
     ___clang_call_terminate($484);
     // unreachable;
    }
   }
  }
  HEAP32[$417>>2] = 0;
  $$18 = $$17;$$1827 = $$1726;
  label = 171;
 }
 if ((label|0) == 171) {
  $431 = ((($0)) + 144|0);
  $432 = HEAP32[$431>>2]|0;
  $433 = ($432|0)==(0|0);
  if (!($433)) {
   $434 = HEAP32[$432>>2]|0;
   $435 = ((($434)) + -12|0);
   $436 = HEAP32[$435>>2]|0;
   $437 = (($432) + ($436)|0);
   $438 = ((($437)) + 8|0);
   $439 = HEAP32[$438>>2]|0;HEAP32[$438>>2] = (($439-1)|0);
   $440 = ($439|0)==(1);
   if ($440) {
    __THREW__ = 0;
    invoke_viii(3262,($437|0),1,1);
    $441 = __THREW__; __THREW__ = 0;
    $442 = $441&1;
    if ($442) {
     $484 = ___cxa_find_matching_catch_3(0|0)|0;
     $485 = tempRet0;
     ___clang_call_terminate($484);
     // unreachable;
    }
   }
  }
  HEAP32[$431>>2] = 0;
  $$19 = $$18;$$1928 = $$1827;
  label = 176;
 }
 if ((label|0) == 176) {
  $445 = ((($0)) + 140|0);
  $446 = HEAP32[$445>>2]|0;
  $447 = ($446|0)==(0|0);
  if (!($447)) {
   $448 = HEAP32[$446>>2]|0;
   $449 = ((($448)) + -12|0);
   $450 = HEAP32[$449>>2]|0;
   $451 = (($446) + ($450)|0);
   $452 = ((($451)) + 8|0);
   $453 = HEAP32[$452>>2]|0;HEAP32[$452>>2] = (($453-1)|0);
   $454 = ($453|0)==(1);
   if ($454) {
    __THREW__ = 0;
    invoke_viii(3262,($451|0),1,1);
    $455 = __THREW__; __THREW__ = 0;
    $456 = $455&1;
    if ($456) {
     $484 = ___cxa_find_matching_catch_3(0|0)|0;
     $485 = tempRet0;
     ___clang_call_terminate($484);
     // unreachable;
    }
   }
  }
  HEAP32[$445>>2] = 0;
  $$20 = $$19;$$2029 = $$1928;
  label = 181;
 }
 if ((label|0) == 181) {
  $459 = ((($0)) + 100|0);
  __THREW__ = 0;
  invoke_vi(3504,($459|0));
  $460 = __THREW__; __THREW__ = 0;
  $461 = $460&1;
  if ($461) {
   $484 = ___cxa_find_matching_catch_3(0|0)|0;
   $485 = tempRet0;
   ___clang_call_terminate($484);
   // unreachable;
  } else {
   $$21 = $$20;$$2130 = $$2029;
   label = 183;
  }
 }
 if ((label|0) == 183) {
  $464 = ((($0)) + 96|0);
  $465 = HEAP32[$464>>2]|0;
  $466 = ($465|0)==(0|0);
  if (!($466)) {
   $467 = ((($465)) + 8|0);
   $468 = HEAP32[$467>>2]|0;HEAP32[$467>>2] = (($468-1)|0);
   $469 = ($468|0)==(1);
   if ($469) {
    __THREW__ = 0;
    invoke_viii(3262,($465|0),1,1);
    $470 = __THREW__; __THREW__ = 0;
    $471 = $470&1;
    if ($471) {
     $484 = ___cxa_find_matching_catch_3(0|0)|0;
     $485 = tempRet0;
     ___clang_call_terminate($484);
     // unreachable;
    }
   }
  }
  HEAP32[$464>>2] = 0;
  $$22 = $$21;$$2231 = $$2130;
  label = 188;
 }
 if ((label|0) == 188) {
  HEAP32[$1>>2] = (58232);
  $474 = ((($0)) + 60|0);
  $475 = HEAP32[$474>>2]|0;
  $476 = ($475|0)==(0|0);
  if (!($476)) {
   $477 = ((($475)) + 8|0);
   $478 = HEAP32[$477>>2]|0;HEAP32[$477>>2] = (($478-1)|0);
   $479 = ($478|0)==(1);
   if ($479) {
    __THREW__ = 0;
    invoke_viii(3262,($475|0),1,1);
    $480 = __THREW__; __THREW__ = 0;
    $481 = $480&1;
    if ($481) {
     $484 = ___cxa_find_matching_catch_3(0|0)|0;
     $485 = tempRet0;
     ___clang_call_terminate($484);
     // unreachable;
    }
   }
  }
  HEAP32[$474>>2] = 0;
  $$23 = $$22;$$2332 = $$2231;
 }
 __THREW__ = 0;
 invoke_vi(388,($0|0));
 $482 = __THREW__; __THREW__ = 0;
 $483 = $482&1;
 if ($483) {
  $484 = ___cxa_find_matching_catch_3(0|0)|0;
  $485 = tempRet0;
  ___clang_call_terminate($484);
  // unreachable;
 } else {
  ___resumeException($$2332|0);
  // unreachable;
 }
}
function __ZN7osgUtil9SceneViewD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1072,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK7osgUtil9SceneView9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(296)|0);
 __THREW__ = 0;
 invoke_vii(3509,($1|0),(0|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch_2()|0;
  $5 = tempRet0;
  __ZdlPv($1);
  ___resumeException($4|0);
  // unreachable;
 } else {
  return ($1|0);
 }
 return (0)|0;
}
function __ZNK7osgUtil9SceneView5cloneERKN3osg6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(296)|0);
 __THREW__ = 0;
 invoke_viii(3571,($2|0),($0|0),($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch_2()|0;
  $6 = tempRet0;
  __ZdlPv($2);
  ___resumeException($5|0);
  // unreachable;
 } else {
  return ($2|0);
 }
 return (0)|0;
}
function __ZNK7osgUtil9SceneView12isSameKindAsEPKN3osg6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,21296,0)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK7osgUtil9SceneView11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (116801|0);
}
function __ZNK7osgUtil9SceneView9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (113488|0);
}
function __ZN7osgUtil9SceneView11setDefaultsEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + 144|0);
 $3 = HEAP32[$2>>2]|0;
 FUNCTION_TABLE_vii[$3 & 8191]($0,29);
 return;
}
function __ZN7osgUtil9SceneView11setDefaultsEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$014 = 0, $$sroa$0$0$$sroa_idx = 0, $$sroa$4$0$$sroa_idx19 = 0, $$sroa$5$0$$sroa_idx21 = 0, $$sroa$6$0$$sroa_idx23 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 32|0);
 __ZN3osg12CullSettings11setDefaultsEv($2);
 $3 = ((($0)) + 208|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($4)) + 304|0);
 __ZN3osg7Matrixd15makePerspectiveEdddd($5,50.0,1.3999999761581421,1.0,1.0E+4);
 $6 = HEAP32[$3>>2]|0;
 $7 = ((($6)) + 432|0);
 __ZN3osg7Matrixd12makeIdentityEv($7);
 $8 = ((($0)) + 216|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if ($10) {
  $11 = (__Znwj(160)|0);
  __THREW__ = 0;
  invoke_vi(3572,($11|0));
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if ($13) {
   $22 = ___cxa_find_matching_catch_2()|0;
   $23 = tempRet0;
   __ZdlPv($11);
   $$0 = $22;$$014 = $23;
   ___resumeException($$0|0);
   // unreachable;
  }
  $14 = HEAP32[$8>>2]|0;
  $15 = ($14|0)==($11|0);
  if (!($15)) {
   HEAP32[$8>>2] = $11;
   $16 = ((($11)) + 8|0);
   $17 = HEAP32[$16>>2]|0;HEAP32[$16>>2] = (($17+1)|0);
   $18 = ($14|0)==(0|0);
   if (!($18)) {
    $19 = ((($14)) + 8|0);
    $20 = HEAP32[$19>>2]|0;HEAP32[$19>>2] = (($20-1)|0);
    $21 = ($20|0)==(1);
    if ($21) {
     __ZNK3osg10Referenced24signalObserversAndDeleteEbb($14,1,1);
    }
   }
  }
 }
 $24 = $1 & 16;
 $25 = ($24|0)==(0);
 if (!($25)) {
  $26 = HEAP32[$8>>2]|0;
  __ZN3osg8StateSet5clearEv($26);
 }
 $27 = $1 & 3;
 $28 = ($27|0)==(0);
 if ($28) {
  $29 = ((($0)) + 240|0);
  HEAP32[$29>>2] = 0;
 }
 $30 = (__Znwj(896)|0);
 __THREW__ = 0;
 invoke_vi(3421,($30|0));
 $31 = __THREW__; __THREW__ = 0;
 $32 = $31&1;
 if ($32) {
  $96 = ___cxa_find_matching_catch_2()|0;
  $97 = tempRet0;
  __ZdlPv($30);
  $$0 = $96;$$014 = $97;
  ___resumeException($$0|0);
  // unreachable;
 }
 $33 = ((($0)) + 100|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)==($30|0);
 if (!($35)) {
  HEAP32[$33>>2] = $30;
  $36 = ((($30)) + 8|0);
  $37 = HEAP32[$36>>2]|0;HEAP32[$36>>2] = (($37+1)|0);
  $38 = ($34|0)==(0|0);
  if (!($38)) {
   $39 = ((($34)) + 8|0);
   $40 = HEAP32[$39>>2]|0;HEAP32[$39>>2] = (($40-1)|0);
   $41 = ($40|0)==(1);
   if ($41) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($34,1,1);
   }
  }
 }
 $42 = (__Znwj(64)|0);
 __THREW__ = 0;
 invoke_vii(3435,($42|0),0);
 $43 = __THREW__; __THREW__ = 0;
 $44 = $43&1;
 if ($44) {
  $98 = ___cxa_find_matching_catch_2()|0;
  $99 = tempRet0;
  __ZdlPv($42);
  $$0 = $98;$$014 = $99;
  ___resumeException($$0|0);
  // unreachable;
 }
 HEAP32[$42>>2] = (49620);
 $45 = ((($42)) + 12|0);
 HEAP32[$45>>2] = 0;
 $46 = ((($42)) + 16|0);
 HEAP32[$46>>2] = 0;
 $47 = ((($42)) + 20|0);
 HEAP32[$47>>2] = 0;
 $48 = ((($42)) + 28|0);
 HEAP32[$48>>2] = 0;
 $49 = ((($42)) + 32|0);
 HEAP32[$49>>2] = 0;
 $50 = ((($42)) + 24|0);
 HEAP32[$50>>2] = $48;
 $51 = ((($42)) + 36|0);
 ;HEAP32[$51>>2]=0|0;HEAP32[$51+4>>2]=0|0;HEAP32[$51+8>>2]=0|0;HEAP32[$51+12>>2]=0|0;HEAP32[$51+16>>2]=0|0;HEAP32[$51+20>>2]=0|0;HEAP8[$51+24>>0]=0|0;
 $52 = ((($0)) + 152|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = ($53|0)==($42|0);
 if (!($54)) {
  HEAP32[$52>>2] = $42;
  $55 = ((($42)) + 8|0);
  $56 = HEAP32[$55>>2]|0;HEAP32[$55>>2] = (($56+1)|0);
  $57 = ($53|0)==(0|0);
  if (!($57)) {
   $58 = ((($53)) + 8|0);
   $59 = HEAP32[$58>>2]|0;HEAP32[$58>>2] = (($59-1)|0);
   $60 = ($59|0)==(1);
   if ($60) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($53,1,1);
   }
  }
 }
 $61 = (__Znwj(424)|0);
 __THREW__ = 0;
 invoke_vi(3573,($61|0));
 $62 = __THREW__; __THREW__ = 0;
 $63 = $62&1;
 if ($63) {
  $100 = ___cxa_find_matching_catch_2()|0;
  $101 = tempRet0;
  __ZdlPv($61);
  $$0 = $100;$$014 = $101;
  ___resumeException($$0|0);
  // unreachable;
 }
 $64 = ((($0)) + 156|0);
 $65 = HEAP32[$64>>2]|0;
 $66 = ($65|0)==($61|0);
 if (!($66)) {
  HEAP32[$64>>2] = $61;
  $67 = ((($61)) + 8|0);
  $68 = HEAP32[$67>>2]|0;HEAP32[$67>>2] = (($68+1)|0);
  $69 = ($65|0)==(0|0);
  if (!($69)) {
   $70 = ((($65)) + 8|0);
   $71 = HEAP32[$70>>2]|0;HEAP32[$70>>2] = (($71-1)|0);
   $72 = ($71|0)==(1);
   if ($72) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($65,1,1);
   }
  }
 }
 $73 = $1 & 4;
 $74 = ($73|0)==(0);
 if (!($74)) {
  $75 = (__Znwj(156)|0);
  __THREW__ = 0;
  invoke_vii(3574,($75|0),268);
  $76 = __THREW__; __THREW__ = 0;
  $77 = $76&1;
  if ($77) {
   $102 = ___cxa_find_matching_catch_2()|0;
   $103 = tempRet0;
   __ZdlPv($75);
   $$0 = $102;$$014 = $103;
   ___resumeException($$0|0);
   // unreachable;
  }
  $78 = ((($75)) + 24|0);
  HEAP32[$78>>2] = -1;
  $79 = ((($0)) + 140|0);
  $80 = HEAP32[$79>>2]|0;
  $81 = ($80|0)==($75|0);
  if (!($81)) {
   HEAP32[$79>>2] = $75;
   $82 = HEAP32[$75>>2]|0;
   $83 = ((($82)) + -12|0);
   $84 = HEAP32[$83>>2]|0;
   $85 = (($75) + ($84)|0);
   $86 = ((($85)) + 8|0);
   $87 = HEAP32[$86>>2]|0;HEAP32[$86>>2] = (($87+1)|0);
   $88 = ($80|0)==(0|0);
   if (!($88)) {
    $89 = HEAP32[$80>>2]|0;
    $90 = ((($89)) + -12|0);
    $91 = HEAP32[$90>>2]|0;
    $92 = (($80) + ($91)|0);
    $93 = ((($92)) + 8|0);
    $94 = HEAP32[$93>>2]|0;HEAP32[$93>>2] = (($94-1)|0);
    $95 = ($94|0)==(1);
    if ($95) {
     __ZNK3osg10Referenced24signalObserversAndDeleteEbb($92,1,1);
    }
   }
  }
 }
 $104 = (__Znwj(88)|0);
 __THREW__ = 0;
 invoke_vi(3416,($104|0));
 $105 = __THREW__; __THREW__ = 0;
 $106 = $105&1;
 if ($106) {
  $179 = ___cxa_find_matching_catch_2()|0;
  $180 = tempRet0;
  __ZdlPv($104);
  $$0 = $179;$$014 = $180;
  ___resumeException($$0|0);
  // unreachable;
 }
 $107 = ((($0)) + 144|0);
 $108 = HEAP32[$107>>2]|0;
 $109 = ($108|0)==($104|0);
 if (!($109)) {
  HEAP32[$107>>2] = $104;
  $110 = HEAP32[$104>>2]|0;
  $111 = ((($110)) + -12|0);
  $112 = HEAP32[$111>>2]|0;
  $113 = (($104) + ($112)|0);
  $114 = ((($113)) + 8|0);
  $115 = HEAP32[$114>>2]|0;HEAP32[$114>>2] = (($115+1)|0);
  $116 = ($108|0)==(0|0);
  if (!($116)) {
   $117 = HEAP32[$108>>2]|0;
   $118 = ((($117)) + -12|0);
   $119 = HEAP32[$118>>2]|0;
   $120 = (($108) + ($119)|0);
   $121 = ((($120)) + 8|0);
   $122 = HEAP32[$121>>2]|0;HEAP32[$121>>2] = (($122-1)|0);
   $123 = ($122|0)==(1);
   if ($123) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($120,1,1);
   }
  }
 }
 $124 = (__ZN7osgUtil11CullVisitor6createEv()|0);
 $125 = ((($0)) + 148|0);
 $126 = HEAP32[$125>>2]|0;
 $127 = ($126|0)==($124|0);
 if (!($127)) {
  HEAP32[$125>>2] = $124;
  $128 = ($124|0)==(0|0);
  if (!($128)) {
   $129 = HEAP32[$124>>2]|0;
   $130 = ((($129)) + -12|0);
   $131 = HEAP32[$130>>2]|0;
   $132 = (($124) + ($131)|0);
   $133 = ((($132)) + 8|0);
   $134 = HEAP32[$133>>2]|0;HEAP32[$133>>2] = (($134+1)|0);
  }
  $135 = ($126|0)==(0|0);
  if (!($135)) {
   $136 = HEAP32[$126>>2]|0;
   $137 = ((($136)) + -12|0);
   $138 = HEAP32[$137>>2]|0;
   $139 = (($126) + ($138)|0);
   $140 = ((($139)) + 8|0);
   $141 = HEAP32[$140>>2]|0;HEAP32[$140>>2] = (($141-1)|0);
   $142 = ($141|0)==(1);
   if ($142) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($139,1,1);
   }
  }
 }
 $143 = HEAP32[$125>>2]|0;
 $144 = HEAP32[$52>>2]|0;
 $145 = ((($143)) + 372|0);
 $146 = HEAP32[$145>>2]|0;
 $147 = ($146|0)==($144|0);
 if (!($147)) {
  HEAP32[$145>>2] = $144;
  $148 = ($144|0)==(0|0);
  if (!($148)) {
   $149 = ((($144)) + 8|0);
   $150 = HEAP32[$149>>2]|0;HEAP32[$149>>2] = (($150+1)|0);
  }
  $151 = ($146|0)==(0|0);
  if (!($151)) {
   $152 = ((($146)) + 8|0);
   $153 = HEAP32[$152>>2]|0;HEAP32[$152>>2] = (($153-1)|0);
   $154 = ($153|0)==(1);
   if ($154) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($146,1,1);
   }
  }
 }
 $155 = ((($143)) + 376|0);
 HEAP32[$155>>2] = $144;
 $156 = HEAP32[$125>>2]|0;
 $157 = HEAP32[$64>>2]|0;
 $158 = ((($156)) + 380|0);
 $159 = HEAP32[$158>>2]|0;
 $160 = ($159|0)==($157|0);
 if (!($160)) {
  HEAP32[$158>>2] = $157;
  $161 = ($157|0)==(0|0);
  if (!($161)) {
   $162 = ((($157)) + 8|0);
   $163 = HEAP32[$162>>2]|0;HEAP32[$162>>2] = (($163+1)|0);
  }
  $164 = ($159|0)==(0|0);
  if (!($164)) {
   $165 = ((($159)) + 8|0);
   $166 = HEAP32[$165>>2]|0;HEAP32[$165>>2] = (($166-1)|0);
   $167 = ($166|0)==(1);
   if ($167) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($159,1,1);
   }
  }
 }
 $168 = ((($156)) + 384|0);
 HEAP32[$168>>2] = $157;
 $169 = $1 & 8;
 $170 = ($169|0)==(0);
 if ($170) {
  return;
 }
 $171 = HEAP32[$8>>2]|0;
 __ZN3osg8StateSet17setGlobalDefaultsEv($171);
 $172 = HEAP32[$3>>2]|0;
 $$sroa$0$0$$sroa_idx = ((($172)) + 240|0);
 HEAPF32[$$sroa$0$0$$sroa_idx>>2] = 0.20000000298023224;
 $$sroa$4$0$$sroa_idx19 = ((($172)) + 244|0);
 HEAPF32[$$sroa$4$0$$sroa_idx19>>2] = 0.20000000298023224;
 $$sroa$5$0$$sroa_idx21 = ((($172)) + 248|0);
 HEAPF32[$$sroa$5$0$$sroa_idx21>>2] = 0.40000000596046448;
 $$sroa$6$0$$sroa_idx23 = ((($172)) + 252|0);
 HEAPF32[$$sroa$6$0$$sroa_idx23>>2] = 1.0;
 $173 = ((($172)) + 152|0);
 $174 = HEAP32[$173>>2]|0;
 $175 = ($174|0)==(0);
 $176 = ((($172)) + 148|0);
 if (!($175)) {
  return;
 }
 $177 = HEAP32[$176>>2]|0;
 $178 = $177 & -8193;
 HEAP32[$176>>2] = $178;
 return;
}
function __ZNK7osgUtil9SceneView38computeLeftEyeProjectionImplementationERKN3osg7MatrixdE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0.0, $12 = 0, $13 = 0, $14 = 0.0, $15 = 0, $16 = 0, $17 = 0.0, $18 = 0, $19 = 0, $20 = 0.0, $21 = 0, $22 = 0, $23 = 0.0, $24 = 0, $25 = 0, $26 = 0.0, $27 = 0, $28 = 0, $29 = 0.0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0.0, $33 = 0, $34 = 0, $35 = 0.0, $36 = 0, $37 = 0, $38 = 0.0, $39 = 0, $4 = 0, $40 = 0, $41 = 0.0, $42 = 0, $43 = 0, $44 = 0.0, $45 = 0, $46 = 0, $47 = 0.0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0.0, $51 = 0, $52 = 0, $53 = 0.0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($1)) + 224|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  $9 = +HEAPF64[$2>>3];
  HEAPF64[$0>>3] = $9;
  $10 = ((($2)) + 8|0);
  $11 = +HEAPF64[$10>>3];
  $12 = ((($0)) + 8|0);
  HEAPF64[$12>>3] = $11;
  $13 = ((($2)) + 16|0);
  $14 = +HEAPF64[$13>>3];
  $15 = ((($0)) + 16|0);
  HEAPF64[$15>>3] = $14;
  $16 = ((($2)) + 24|0);
  $17 = +HEAPF64[$16>>3];
  $18 = ((($0)) + 24|0);
  HEAPF64[$18>>3] = $17;
  $19 = ((($2)) + 32|0);
  $20 = +HEAPF64[$19>>3];
  $21 = ((($0)) + 32|0);
  HEAPF64[$21>>3] = $20;
  $22 = ((($2)) + 40|0);
  $23 = +HEAPF64[$22>>3];
  $24 = ((($0)) + 40|0);
  HEAPF64[$24>>3] = $23;
  $25 = ((($2)) + 48|0);
  $26 = +HEAPF64[$25>>3];
  $27 = ((($0)) + 48|0);
  HEAPF64[$27>>3] = $26;
  $28 = ((($2)) + 56|0);
  $29 = +HEAPF64[$28>>3];
  $30 = ((($0)) + 56|0);
  HEAPF64[$30>>3] = $29;
  $31 = ((($2)) + 64|0);
  $32 = +HEAPF64[$31>>3];
  $33 = ((($0)) + 64|0);
  HEAPF64[$33>>3] = $32;
  $34 = ((($2)) + 72|0);
  $35 = +HEAPF64[$34>>3];
  $36 = ((($0)) + 72|0);
  HEAPF64[$36>>3] = $35;
  $37 = ((($2)) + 80|0);
  $38 = +HEAPF64[$37>>3];
  $39 = ((($0)) + 80|0);
  HEAPF64[$39>>3] = $38;
  $40 = ((($2)) + 88|0);
  $41 = +HEAPF64[$40>>3];
  $42 = ((($0)) + 88|0);
  HEAPF64[$42>>3] = $41;
  $43 = ((($2)) + 96|0);
  $44 = +HEAPF64[$43>>3];
  $45 = ((($0)) + 96|0);
  HEAPF64[$45>>3] = $44;
  $46 = ((($2)) + 104|0);
  $47 = +HEAPF64[$46>>3];
  $48 = ((($0)) + 104|0);
  HEAPF64[$48>>3] = $47;
  $49 = ((($2)) + 112|0);
  $50 = +HEAPF64[$49>>3];
  $51 = ((($0)) + 112|0);
  HEAPF64[$51>>3] = $50;
  $52 = ((($2)) + 120|0);
  $53 = +HEAPF64[$52>>3];
  $54 = ((($0)) + 120|0);
  HEAPF64[$54>>3] = $53;
  return;
 } else {
  $6 = HEAP32[$4>>2]|0;
  $7 = ((($6)) + 12|0);
  $8 = HEAP32[$7>>2]|0;
  FUNCTION_TABLE_viii[$8 & 8191]($0,$4,$2);
  return;
 }
}
function __ZNK7osgUtil9SceneView32computeLeftEyeViewImplementationERKN3osg7MatrixdE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0.0, $10 = 0, $11 = 0.0, $12 = 0, $13 = 0, $14 = 0.0, $15 = 0, $16 = 0, $17 = 0.0, $18 = 0, $19 = 0, $20 = 0.0, $21 = 0, $22 = 0, $23 = 0.0, $24 = 0, $25 = 0, $26 = 0.0, $27 = 0, $28 = 0;
 var $29 = 0.0, $3 = 0, $30 = 0, $31 = 0, $32 = 0.0, $33 = 0, $34 = 0, $35 = 0.0, $36 = 0, $37 = 0, $38 = 0.0, $39 = 0, $4 = 0, $40 = 0, $41 = 0.0, $42 = 0, $43 = 0, $44 = 0.0, $45 = 0, $46 = 0;
 var $47 = 0.0, $48 = 0, $49 = 0, $5 = 0, $50 = 0.0, $51 = 0, $52 = 0, $53 = 0.0, $54 = 0.0, $55 = 0, $56 = 0, $57 = 0, $58 = 0.0, $59 = 0.0, $6 = 0.0, $60 = 0, $61 = 0.0, $62 = 0.0, $63 = 0.0, $64 = 0.0;
 var $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0.0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($1)) + 224|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  $6 = +HEAPF64[$2>>3];
  HEAPF64[$0>>3] = $6;
  $7 = ((($2)) + 8|0);
  $8 = +HEAPF64[$7>>3];
  $9 = ((($0)) + 8|0);
  HEAPF64[$9>>3] = $8;
  $10 = ((($2)) + 16|0);
  $11 = +HEAPF64[$10>>3];
  $12 = ((($0)) + 16|0);
  HEAPF64[$12>>3] = $11;
  $13 = ((($2)) + 24|0);
  $14 = +HEAPF64[$13>>3];
  $15 = ((($0)) + 24|0);
  HEAPF64[$15>>3] = $14;
  $16 = ((($2)) + 32|0);
  $17 = +HEAPF64[$16>>3];
  $18 = ((($0)) + 32|0);
  HEAPF64[$18>>3] = $17;
  $19 = ((($2)) + 40|0);
  $20 = +HEAPF64[$19>>3];
  $21 = ((($0)) + 40|0);
  HEAPF64[$21>>3] = $20;
  $22 = ((($2)) + 48|0);
  $23 = +HEAPF64[$22>>3];
  $24 = ((($0)) + 48|0);
  HEAPF64[$24>>3] = $23;
  $25 = ((($2)) + 56|0);
  $26 = +HEAPF64[$25>>3];
  $27 = ((($0)) + 56|0);
  HEAPF64[$27>>3] = $26;
  $28 = ((($2)) + 64|0);
  $29 = +HEAPF64[$28>>3];
  $30 = ((($0)) + 64|0);
  HEAPF64[$30>>3] = $29;
  $31 = ((($2)) + 72|0);
  $32 = +HEAPF64[$31>>3];
  $33 = ((($0)) + 72|0);
  HEAPF64[$33>>3] = $32;
  $34 = ((($2)) + 80|0);
  $35 = +HEAPF64[$34>>3];
  $36 = ((($0)) + 80|0);
  HEAPF64[$36>>3] = $35;
  $37 = ((($2)) + 88|0);
  $38 = +HEAPF64[$37>>3];
  $39 = ((($0)) + 88|0);
  HEAPF64[$39>>3] = $38;
  $40 = ((($2)) + 96|0);
  $41 = +HEAPF64[$40>>3];
  $42 = ((($0)) + 96|0);
  HEAPF64[$42>>3] = $41;
  $43 = ((($2)) + 104|0);
  $44 = +HEAPF64[$43>>3];
  $45 = ((($0)) + 104|0);
  HEAPF64[$45>>3] = $44;
  $46 = ((($2)) + 112|0);
  $47 = +HEAPF64[$46>>3];
  $48 = ((($0)) + 112|0);
  HEAPF64[$48>>3] = $47;
  $49 = ((($2)) + 120|0);
  $50 = +HEAPF64[$49>>3];
  $51 = ((($0)) + 120|0);
  HEAPF64[$51>>3] = $50;
  return;
 }
 $52 = ((($4)) + 36|0);
 $53 = +HEAPF32[$52>>2];
 $54 = $53;
 $55 = ((($1)) + 232|0);
 $56 = HEAP32[$55>>2]|0;
 switch ($56|0) {
 case 0:  {
  $57 = ((($1)) + 236|0);
  $58 = +HEAPF32[$57>>2];
  $59 = $58;
  $$0 = $59;
  break;
 }
 case 1:  {
  $60 = ((($1)) + 236|0);
  $61 = +HEAPF32[$60>>2];
  $62 = $61;
  $63 = $54 * $62;
  $$0 = $63;
  break;
 }
 default: {
  $$0 = $54;
 }
 }
 $64 = $$0 / $54;
 $65 = HEAP32[$4>>2]|0;
 $66 = ((($65)) + 16|0);
 $67 = HEAP32[$66>>2]|0;
 FUNCTION_TABLE_viiid[$67 & 2047]($0,$4,$2,$64);
 return;
}
function __ZNK7osgUtil9SceneView39computeRightEyeProjectionImplementationERKN3osg7MatrixdE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0.0, $12 = 0, $13 = 0, $14 = 0.0, $15 = 0, $16 = 0, $17 = 0.0, $18 = 0, $19 = 0, $20 = 0.0, $21 = 0, $22 = 0, $23 = 0.0, $24 = 0, $25 = 0, $26 = 0.0, $27 = 0, $28 = 0, $29 = 0.0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0.0, $33 = 0, $34 = 0, $35 = 0.0, $36 = 0, $37 = 0, $38 = 0.0, $39 = 0, $4 = 0, $40 = 0, $41 = 0.0, $42 = 0, $43 = 0, $44 = 0.0, $45 = 0, $46 = 0, $47 = 0.0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0.0, $51 = 0, $52 = 0, $53 = 0.0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($1)) + 224|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  $9 = +HEAPF64[$2>>3];
  HEAPF64[$0>>3] = $9;
  $10 = ((($2)) + 8|0);
  $11 = +HEAPF64[$10>>3];
  $12 = ((($0)) + 8|0);
  HEAPF64[$12>>3] = $11;
  $13 = ((($2)) + 16|0);
  $14 = +HEAPF64[$13>>3];
  $15 = ((($0)) + 16|0);
  HEAPF64[$15>>3] = $14;
  $16 = ((($2)) + 24|0);
  $17 = +HEAPF64[$16>>3];
  $18 = ((($0)) + 24|0);
  HEAPF64[$18>>3] = $17;
  $19 = ((($2)) + 32|0);
  $20 = +HEAPF64[$19>>3];
  $21 = ((($0)) + 32|0);
  HEAPF64[$21>>3] = $20;
  $22 = ((($2)) + 40|0);
  $23 = +HEAPF64[$22>>3];
  $24 = ((($0)) + 40|0);
  HEAPF64[$24>>3] = $23;
  $25 = ((($2)) + 48|0);
  $26 = +HEAPF64[$25>>3];
  $27 = ((($0)) + 48|0);
  HEAPF64[$27>>3] = $26;
  $28 = ((($2)) + 56|0);
  $29 = +HEAPF64[$28>>3];
  $30 = ((($0)) + 56|0);
  HEAPF64[$30>>3] = $29;
  $31 = ((($2)) + 64|0);
  $32 = +HEAPF64[$31>>3];
  $33 = ((($0)) + 64|0);
  HEAPF64[$33>>3] = $32;
  $34 = ((($2)) + 72|0);
  $35 = +HEAPF64[$34>>3];
  $36 = ((($0)) + 72|0);
  HEAPF64[$36>>3] = $35;
  $37 = ((($2)) + 80|0);
  $38 = +HEAPF64[$37>>3];
  $39 = ((($0)) + 80|0);
  HEAPF64[$39>>3] = $38;
  $40 = ((($2)) + 88|0);
  $41 = +HEAPF64[$40>>3];
  $42 = ((($0)) + 88|0);
  HEAPF64[$42>>3] = $41;
  $43 = ((($2)) + 96|0);
  $44 = +HEAPF64[$43>>3];
  $45 = ((($0)) + 96|0);
  HEAPF64[$45>>3] = $44;
  $46 = ((($2)) + 104|0);
  $47 = +HEAPF64[$46>>3];
  $48 = ((($0)) + 104|0);
  HEAPF64[$48>>3] = $47;
  $49 = ((($2)) + 112|0);
  $50 = +HEAPF64[$49>>3];
  $51 = ((($0)) + 112|0);
  HEAPF64[$51>>3] = $50;
  $52 = ((($2)) + 120|0);
  $53 = +HEAPF64[$52>>3];
  $54 = ((($0)) + 120|0);
  HEAPF64[$54>>3] = $53;
  return;
 } else {
  $6 = HEAP32[$4>>2]|0;
  $7 = ((($6)) + 20|0);
  $8 = HEAP32[$7>>2]|0;
  FUNCTION_TABLE_viii[$8 & 8191]($0,$4,$2);
  return;
 }
}
function __ZNK7osgUtil9SceneView33computeRightEyeViewImplementationERKN3osg7MatrixdE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0.0, $10 = 0, $11 = 0.0, $12 = 0, $13 = 0, $14 = 0.0, $15 = 0, $16 = 0, $17 = 0.0, $18 = 0, $19 = 0, $20 = 0.0, $21 = 0, $22 = 0, $23 = 0.0, $24 = 0, $25 = 0, $26 = 0.0, $27 = 0, $28 = 0;
 var $29 = 0.0, $3 = 0, $30 = 0, $31 = 0, $32 = 0.0, $33 = 0, $34 = 0, $35 = 0.0, $36 = 0, $37 = 0, $38 = 0.0, $39 = 0, $4 = 0, $40 = 0, $41 = 0.0, $42 = 0, $43 = 0, $44 = 0.0, $45 = 0, $46 = 0;
 var $47 = 0.0, $48 = 0, $49 = 0, $5 = 0, $50 = 0.0, $51 = 0, $52 = 0, $53 = 0.0, $54 = 0.0, $55 = 0, $56 = 0, $57 = 0, $58 = 0.0, $59 = 0.0, $6 = 0.0, $60 = 0, $61 = 0.0, $62 = 0.0, $63 = 0.0, $64 = 0.0;
 var $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0.0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($1)) + 224|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  $6 = +HEAPF64[$2>>3];
  HEAPF64[$0>>3] = $6;
  $7 = ((($2)) + 8|0);
  $8 = +HEAPF64[$7>>3];
  $9 = ((($0)) + 8|0);
  HEAPF64[$9>>3] = $8;
  $10 = ((($2)) + 16|0);
  $11 = +HEAPF64[$10>>3];
  $12 = ((($0)) + 16|0);
  HEAPF64[$12>>3] = $11;
  $13 = ((($2)) + 24|0);
  $14 = +HEAPF64[$13>>3];
  $15 = ((($0)) + 24|0);
  HEAPF64[$15>>3] = $14;
  $16 = ((($2)) + 32|0);
  $17 = +HEAPF64[$16>>3];
  $18 = ((($0)) + 32|0);
  HEAPF64[$18>>3] = $17;
  $19 = ((($2)) + 40|0);
  $20 = +HEAPF64[$19>>3];
  $21 = ((($0)) + 40|0);
  HEAPF64[$21>>3] = $20;
  $22 = ((($2)) + 48|0);
  $23 = +HEAPF64[$22>>3];
  $24 = ((($0)) + 48|0);
  HEAPF64[$24>>3] = $23;
  $25 = ((($2)) + 56|0);
  $26 = +HEAPF64[$25>>3];
  $27 = ((($0)) + 56|0);
  HEAPF64[$27>>3] = $26;
  $28 = ((($2)) + 64|0);
  $29 = +HEAPF64[$28>>3];
  $30 = ((($0)) + 64|0);
  HEAPF64[$30>>3] = $29;
  $31 = ((($2)) + 72|0);
  $32 = +HEAPF64[$31>>3];
  $33 = ((($0)) + 72|0);
  HEAPF64[$33>>3] = $32;
  $34 = ((($2)) + 80|0);
  $35 = +HEAPF64[$34>>3];
  $36 = ((($0)) + 80|0);
  HEAPF64[$36>>3] = $35;
  $37 = ((($2)) + 88|0);
  $38 = +HEAPF64[$37>>3];
  $39 = ((($0)) + 88|0);
  HEAPF64[$39>>3] = $38;
  $40 = ((($2)) + 96|0);
  $41 = +HEAPF64[$40>>3];
  $42 = ((($0)) + 96|0);
  HEAPF64[$42>>3] = $41;
  $43 = ((($2)) + 104|0);
  $44 = +HEAPF64[$43>>3];
  $45 = ((($0)) + 104|0);
  HEAPF64[$45>>3] = $44;
  $46 = ((($2)) + 112|0);
  $47 = +HEAPF64[$46>>3];
  $48 = ((($0)) + 112|0);
  HEAPF64[$48>>3] = $47;
  $49 = ((($2)) + 120|0);
  $50 = +HEAPF64[$49>>3];
  $51 = ((($0)) + 120|0);
  HEAPF64[$51>>3] = $50;
  return;
 }
 $52 = ((($4)) + 36|0);
 $53 = +HEAPF32[$52>>2];
 $54 = $53;
 $55 = ((($1)) + 232|0);
 $56 = HEAP32[$55>>2]|0;
 switch ($56|0) {
 case 0:  {
  $57 = ((($1)) + 236|0);
  $58 = +HEAPF32[$57>>2];
  $59 = $58;
  $$0 = $59;
  break;
 }
 case 1:  {
  $60 = ((($1)) + 236|0);
  $61 = +HEAPF32[$60>>2];
  $62 = $61;
  $63 = $54 * $62;
  $$0 = $63;
  break;
 }
 default: {
  $$0 = $54;
 }
 }
 $64 = $$0 / $54;
 $65 = HEAP32[$4>>2]|0;
 $66 = ((($65)) + 24|0);
 $67 = HEAP32[$66>>2]|0;
 FUNCTION_TABLE_viiid[$67 & 2047]($0,$4,$2,$64);
 return;
}
function __ZN7osgUtil9SceneView19inheritCullSettingsERKN3osg12CullSettingsE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $3 = ((($2)) + 168|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 36|0);
 $6 = HEAP32[$5>>2]|0;
 FUNCTION_TABLE_viii[$4 & 8191]($0,$1,$6);
 return;
}
function __ZN7osgUtil9SceneView19inheritCullSettingsERKN3osg12CullSettingsEj($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$pr = 0, $$sink$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp$i = 0, $switch = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 204|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if (!($5)) {
  $6 = ((($4)) + 24|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)==(0|0);
  if (!($8)) {
   $9 = ((($0)) + 208|0);
   $10 = HEAP32[$9>>2]|0;
   $phitmp$i = ($10|0)==(0|0);
   if (!($phitmp$i)) {
    $11 = ((($10)) + 220|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ($12|0)==(0|0);
    if (!($13)) {
     $14 = $2 & 32768;
     $15 = ($14|0)==(0);
     if (!($15)) {
      $16 = ((($0)) + 240|0);
      $17 = ((($12)) + 8|0);
      $18 = HEAP32[$17>>2]|0;
      $switch = ($18>>>0)<(3);
      if ($switch) {
       $$pr = HEAP32[$16>>2]|0;
       $19 = ($18|0)==($$pr|0);
       if (!($19)) {
        $20 = ((($0)) + 228|0);
        $21 = HEAP32[$20>>2]|0;
        $22 = ($21|0)!=(0|0);
        $23 = ((($0)) + 216|0);
        $$sink$i = $22 ? $20 : $23;
        $24 = HEAP32[$$sink$i>>2]|0;
        $25 = ($$pr|0)==(0);
        if (!($25)) {
         __ZN3osg8StateSet10removeModeEj($24,2896);
         $26 = ((($0)) + 220|0);
         $27 = HEAP32[$26>>2]|0;
         $28 = ($27|0)==(0|0);
         if (!($28)) {
          __ZN3osg8StateSet21removeAssociatedModesEPKNS_14StateAttributeE($24,$27);
         }
        }
        HEAP32[$16>>2] = $18;
       }
      }
     }
     $29 = $2 & 65536;
     $30 = ($29|0)==(0);
     if (!($30)) {
      $31 = HEAP32[$9>>2]|0;
      $32 = ((($31)) + 220|0);
      $33 = HEAP32[$32>>2]|0;
      $34 = ((($33)) + 12|0);
      $35 = HEAP32[$34>>2]|0;
      $36 = ((($0)) + 220|0);
      $37 = HEAP32[$36>>2]|0;
      $38 = ($37|0)==($35|0);
      if (!($38)) {
       HEAP32[$36>>2] = $35;
       $39 = ($35|0)==(0|0);
       if (!($39)) {
        $40 = ((($35)) + 8|0);
        $41 = HEAP32[$40>>2]|0;HEAP32[$40>>2] = (($41+1)|0);
       }
       $42 = ($37|0)==(0|0);
       if (!($42)) {
        $43 = ((($37)) + 8|0);
        $44 = HEAP32[$43>>2]|0;HEAP32[$43>>2] = (($44-1)|0);
        $45 = ($44|0)==(1);
        if ($45) {
         __ZNK3osg10Referenced24signalObserversAndDeleteEbb($37,1,1);
        }
       }
      }
     }
    }
   }
  }
 }
 $46 = ((($0)) + 32|0);
 __ZN3osg12CullSettings19inheritCullSettingsERKS0_j($46,$1,$2);
 return;
}
function __ZN7osgUtil9SceneView4initEv($0) {
 $0 = $0|0;
 var $$pre = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 136|0);
 HEAP8[$1>>0] = 1;
 $2 = ((($0)) + 100|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + 124|0);
 $5 = HEAP32[$4>>2]|0;
 (__ZN3osg22isGLExtensionSupportedEjPKc($5,221531)|0);
 $6 = ((($0)) + 204|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if ($8) {
  return;
 }
 $9 = ((($7)) + 24|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  return;
 }
 $12 = ((($0)) + 208|0);
 $13 = HEAP32[$12>>2]|0;
 $phitmp$i = ($13|0)==(0|0);
 if ($phitmp$i) {
  return;
 }
 $14 = ((($0)) + 140|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0|0);
 if ($16) {
  return;
 }
 $17 = HEAP32[$15>>2]|0;
 $18 = ((($17)) + 76|0);
 $19 = HEAP32[$18>>2]|0;
 FUNCTION_TABLE_vi[$19 & 8191]($15);
 $20 = HEAP32[$14>>2]|0;
 $21 = ((($0)) + 200|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ((($20)) + 12|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)==($22|0);
 if (!($25)) {
  HEAP32[$23>>2] = $22;
  $26 = ($22|0)==(0|0);
  if (!($26)) {
   $27 = ((($22)) + 8|0);
   $28 = HEAP32[$27>>2]|0;HEAP32[$27>>2] = (($28+1)|0);
  }
  $29 = ($24|0)==(0|0);
  if (!($29)) {
   $30 = ((($24)) + 8|0);
   $31 = HEAP32[$30>>2]|0;HEAP32[$30>>2] = (($31-1)|0);
   $32 = ($31|0)==(1);
   if ($32) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($24,1,1);
   }
  }
 }
 $33 = HEAP32[$14>>2]|0;
 $34 = ($33|0)==(0|0);
 if (!($34)) {
  $35 = (___dynamic_cast($33,25968,19256,0)|0);
  $36 = ($35|0)==(0|0);
  if (!($36)) {
   $37 = HEAP32[$2>>2]|0;
   $38 = ((($35)) + 60|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = ($39|0)==($37|0);
   if (!($40)) {
    HEAP32[$38>>2] = $37;
    $41 = ($37|0)==(0|0);
    if (!($41)) {
     $42 = ((($37)) + 8|0);
     $43 = HEAP32[$42>>2]|0;HEAP32[$42>>2] = (($43+1)|0);
    }
    $44 = ($39|0)==(0|0);
    if (!($44)) {
     $45 = ((($39)) + 8|0);
     $46 = HEAP32[$45>>2]|0;HEAP32[$45>>2] = (($46-1)|0);
     $47 = ($46|0)==(1);
     if ($47) {
      __ZNK3osg10Referenced24signalObserversAndDeleteEbb($39,1,1);
     }
    }
   }
  }
 }
 $48 = HEAP32[$21>>2]|0;
 $49 = ($48|0)==(0|0);
 $$pre = HEAP32[$14>>2]|0;
 if (!($49)) {
  $50 = ((($48)) + 12|0);
  $51 = HEAP32[$50>>2]|0;
  $52 = ((($$pre)) + 8|0);
  HEAP32[$52>>2] = $51;
 }
 $53 = HEAP32[$12>>2]|0;
 $54 = HEAP32[$53>>2]|0;
 $55 = ((($54)) + 188|0);
 $56 = HEAP32[$55>>2]|0;
 FUNCTION_TABLE_vii[$56 & 8191]($53,$$pre);
 return;
}
function __ZN7osgUtil9SceneView6updateEv($0) {
 $0 = $0|0;
 var $$pr = 0, $$pre = 0, $1 = 0, $10 = 0, $100 = 0.0, $101 = 0.0, $102 = 0.0, $103 = 0.0, $104 = 0.0, $105 = 0.0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0.0, $111 = 0, $112 = 0, $113 = 0.0, $114 = 0;
 var $115 = 0.0, $116 = 0.0, $117 = 0.0, $118 = 0, $119 = 0.0, $12 = 0, $120 = 0, $121 = 0.0, $122 = 0.0, $123 = 0, $124 = 0.0, $125 = 0, $126 = 0.0, $127 = 0.0, $128 = 0.0, $129 = 0.0, $13 = 0, $130 = 0.0, $131 = 0.0, $132 = 0.0;
 var $133 = 0.0, $134 = 0.0, $135 = 0.0, $136 = 0.0, $137 = 0.0, $138 = 0, $139 = 0.0, $14 = 0, $140 = 0, $141 = 0.0, $142 = 0.0, $143 = 0.0, $144 = 0.0, $145 = 0.0, $146 = 0.0, $147 = 0.0, $148 = 0.0, $149 = 0.0, $15 = 0, $150 = 0.0;
 var $151 = 0.0, $152 = 0.0, $153 = 0.0, $154 = 0.0, $155 = 0.0, $156 = 0.0, $157 = 0.0, $158 = 0.0, $159 = 0.0, $16 = 0, $160 = 0.0, $161 = 0.0, $162 = 0.0, $163 = 0.0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0.0, $53 = 0, $54 = 0, $55 = 0.0, $56 = 0, $57 = 0.0, $58 = 0.0;
 var $59 = 0.0, $6 = 0, $60 = 0, $61 = 0.0, $62 = 0, $63 = 0.0, $64 = 0.0, $65 = 0, $66 = 0.0, $67 = 0, $68 = 0.0, $69 = 0.0, $7 = 0, $70 = 0.0, $71 = 0.0, $72 = 0.0, $73 = 0.0, $74 = 0.0, $75 = 0.0, $76 = 0.0;
 var $77 = 0.0, $78 = 0.0, $79 = 0.0, $8 = 0, $80 = 0, $81 = 0.0, $82 = 0, $83 = 0.0, $84 = 0.0, $85 = 0.0, $86 = 0.0, $87 = 0.0, $88 = 0.0, $89 = 0.0, $9 = 0, $90 = 0.0, $91 = 0.0, $92 = 0.0, $93 = 0.0, $94 = 0.0;
 var $95 = 0.0, $96 = 0.0, $97 = 0.0, $98 = 0.0, $99 = 0.0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $1 = sp + 16|0;
 $2 = sp;
 $3 = ((($0)) + 204|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $6 = ((($4)) + 24|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if ($8) {
  STACKTOP = sp;return;
 }
 $9 = ((($0)) + 208|0);
 $10 = HEAP32[$9>>2]|0;
 $phitmp$i = ($10|0)==(0|0);
 if ($phitmp$i) {
  STACKTOP = sp;return;
 }
 $11 = ((($0)) + 144|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0|0);
 if ($13) {
  STACKTOP = sp;return;
 }
 $14 = HEAP32[$12>>2]|0;
 $15 = ((($14)) + 76|0);
 $16 = HEAP32[$15>>2]|0;
 FUNCTION_TABLE_vi[$16 & 8191]($12);
 $17 = HEAP32[$11>>2]|0;
 $18 = ((($0)) + 200|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ((($17)) + 12|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==($19|0);
 if ($22) {
  $30 = $19;
 } else {
  HEAP32[$20>>2] = $19;
  $23 = ($19|0)==(0|0);
  if (!($23)) {
   $24 = ((($19)) + 8|0);
   $25 = HEAP32[$24>>2]|0;HEAP32[$24>>2] = (($25+1)|0);
  }
  $26 = ($21|0)==(0|0);
  if (!($26)) {
   $27 = ((($21)) + 8|0);
   $28 = HEAP32[$27>>2]|0;HEAP32[$27>>2] = (($28-1)|0);
   $29 = ($28|0)==(1);
   if ($29) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($21,1,1);
   }
  }
  $$pr = HEAP32[$18>>2]|0;
  $30 = $$pr;
 }
 $31 = ($30|0)==(0|0);
 $$pre = HEAP32[$11>>2]|0;
 if (!($31)) {
  $32 = ((($30)) + 12|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = ((($$pre)) + 8|0);
  HEAP32[$34>>2] = $33;
 }
 $35 = HEAP32[$9>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 $37 = ((($36)) + 188|0);
 $38 = HEAP32[$37>>2]|0;
 FUNCTION_TABLE_vii[$38 & 8191]($35,$$pre);
 $39 = HEAP32[$9>>2]|0;
 $40 = ((($39)) + 68|0);
 $41 = HEAP8[$40>>0]|0;
 $42 = ($41<<24>>24)==(0);
 if (!($42)) {
  STACKTOP = sp;return;
 }
 $43 = ((($39)) + 32|0);
 $44 = ((($39)) + 52|0);
 ;HEAP32[$44>>2]=HEAP32[$43>>2]|0;HEAP32[$44+4>>2]=HEAP32[$43+4>>2]|0;HEAP32[$44+8>>2]=HEAP32[$43+8>>2]|0;HEAP32[$44+12>>2]=HEAP32[$43+12>>2]|0;
 $45 = ((($39)) + 48|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = ($46|0)==(0|0);
 if ($47) {
  $106 = HEAP32[$39>>2]|0;
  $107 = ((($106)) + 200|0);
  $108 = HEAP32[$107>>2]|0;
  FUNCTION_TABLE_vii[$108 & 8191]($2,$39);
  $109 = ((($2)) + 12|0);
  $110 = +HEAPF32[$109>>2];
  $111 = !($110 >= 0.0);
  do {
   if (!($111)) {
    $112 = ((($39)) + 64|0);
    $113 = +HEAPF32[$112>>2];
    $114 = !($113 >= 0.0);
    if ($114) {
     ;HEAP32[$44>>2]=HEAP32[$2>>2]|0;HEAP32[$44+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$44+8>>2]=HEAP32[$2+8>>2]|0;
     HEAPF32[$112>>2] = $110;
     break;
    }
    $115 = +HEAPF32[$44>>2];
    $116 = +HEAPF32[$2>>2];
    $117 = $115 - $116;
    $118 = ((($39)) + 56|0);
    $119 = +HEAPF32[$118>>2];
    $120 = ((($2)) + 4|0);
    $121 = +HEAPF32[$120>>2];
    $122 = $119 - $121;
    $123 = ((($39)) + 60|0);
    $124 = +HEAPF32[$123>>2];
    $125 = ((($2)) + 8|0);
    $126 = +HEAPF32[$125>>2];
    $127 = $124 - $126;
    $128 = $117 * $117;
    $129 = $122 * $122;
    $130 = $128 + $129;
    $131 = $127 * $127;
    $132 = $130 + $131;
    $133 = (+Math_sqrt((+$132)));
    $134 = $133;
    $135 = $110;
    $136 = $135 + $134;
    $137 = $113;
    $138 = !($136 <= $137);
    if ($138) {
     $139 = $137 + $134;
     $140 = !($139 <= $135);
     if ($140) {
      $141 = $135 + $139;
      $142 = $141 * 0.5;
      $143 = $142 - $137;
      $144 = $143 / $134;
      $145 = $116 - $115;
      $146 = $145;
      $147 = $146 * $144;
      $148 = $115;
      $149 = $148 + $147;
      $150 = $149;
      HEAPF32[$44>>2] = $150;
      $151 = $121 - $119;
      $152 = $151;
      $153 = $144 * $152;
      $154 = $119;
      $155 = $154 + $153;
      $156 = $155;
      HEAPF32[$118>>2] = $156;
      $157 = $126 - $124;
      $158 = $157;
      $159 = $144 * $158;
      $160 = $124;
      $161 = $160 + $159;
      $162 = $161;
      HEAPF32[$123>>2] = $162;
      $163 = $142;
      HEAPF32[$112>>2] = $163;
      break;
     } else {
      ;HEAP32[$44>>2]=HEAP32[$2>>2]|0;HEAP32[$44+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$44+8>>2]=HEAP32[$2+8>>2]|0;
      HEAPF32[$112>>2] = $110;
      break;
     }
    }
   }
  } while(0);
 } else {
  $48 = HEAP32[$46>>2]|0;
  $49 = ((($48)) + 140|0);
  $50 = HEAP32[$49>>2]|0;
  FUNCTION_TABLE_viii[$50 & 8191]($1,$46,$39);
  $51 = ((($1)) + 12|0);
  $52 = +HEAPF32[$51>>2];
  $53 = !($52 >= 0.0);
  do {
   if (!($53)) {
    $54 = ((($39)) + 64|0);
    $55 = +HEAPF32[$54>>2];
    $56 = !($55 >= 0.0);
    if ($56) {
     ;HEAP32[$44>>2]=HEAP32[$1>>2]|0;HEAP32[$44+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$44+8>>2]=HEAP32[$1+8>>2]|0;
     HEAPF32[$54>>2] = $52;
     break;
    }
    $57 = +HEAPF32[$44>>2];
    $58 = +HEAPF32[$1>>2];
    $59 = $57 - $58;
    $60 = ((($39)) + 56|0);
    $61 = +HEAPF32[$60>>2];
    $62 = ((($1)) + 4|0);
    $63 = +HEAPF32[$62>>2];
    $64 = $61 - $63;
    $65 = ((($39)) + 60|0);
    $66 = +HEAPF32[$65>>2];
    $67 = ((($1)) + 8|0);
    $68 = +HEAPF32[$67>>2];
    $69 = $66 - $68;
    $70 = $59 * $59;
    $71 = $64 * $64;
    $72 = $70 + $71;
    $73 = $69 * $69;
    $74 = $72 + $73;
    $75 = (+Math_sqrt((+$74)));
    $76 = $75;
    $77 = $52;
    $78 = $77 + $76;
    $79 = $55;
    $80 = !($78 <= $79);
    if ($80) {
     $81 = $79 + $76;
     $82 = !($81 <= $77);
     if ($82) {
      $83 = $77 + $81;
      $84 = $83 * 0.5;
      $85 = $84 - $79;
      $86 = $85 / $76;
      $87 = $58 - $57;
      $88 = $87;
      $89 = $88 * $86;
      $90 = $57;
      $91 = $90 + $89;
      $92 = $91;
      HEAPF32[$44>>2] = $92;
      $93 = $63 - $61;
      $94 = $93;
      $95 = $86 * $94;
      $96 = $61;
      $97 = $96 + $95;
      $98 = $97;
      HEAPF32[$60>>2] = $98;
      $99 = $68 - $66;
      $100 = $99;
      $101 = $86 * $100;
      $102 = $66;
      $103 = $102 + $101;
      $104 = $103;
      HEAPF32[$65>>2] = $104;
      $105 = $84;
      HEAPF32[$54>>2] = $105;
      break;
     } else {
      ;HEAP32[$44>>2]=HEAP32[$1>>2]|0;HEAP32[$44+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$44+8>>2]=HEAP32[$1+8>>2]|0;
      HEAPF32[$54>>2] = $52;
      break;
     }
    }
   }
  } while(0);
 }
 HEAP8[$40>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN7osgUtil9SceneView4cullEv($0) {
 $0 = $0|0;
 var $$4 = 0, $$410 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0;
 var $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0;
 var $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0;
 var $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0;
 var $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0.0, $265 = 0, $266 = 0.0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0;
 var $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0;
 var $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0;
 var $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0.0, $325 = 0, $326 = 0.0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0;
 var $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0;
 var $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0;
 var $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0;
 var $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0;
 var $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0;
 var $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0;
 var $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0;
 var $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0;
 var $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0;
 var $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0;
 var $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0;
 var $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0;
 var $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0;
 var $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0;
 var $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0;
 var $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0;
 var $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0.0, $631 = 0, $632 = 0, $633 = 0.0, $634 = 0, $635 = 0.0, $636 = 0, $637 = 0.0;
 var $638 = 0, $639 = 0.0, $64 = 0, $640 = 0, $641 = 0.0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0;
 var $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0;
 var $674 = 0, $675 = 0.0, $676 = 0, $677 = 0.0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1120|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(1120|0);
 $1 = sp + 1080|0;
 $2 = sp + 1072|0;
 $3 = sp + 1064|0;
 $4 = sp + 1056|0;
 $5 = sp + 1116|0;
 $6 = sp + 1112|0;
 $7 = sp + 1108|0;
 $8 = sp + 1104|0;
 $9 = sp + 1048|0;
 $10 = sp + 1040|0;
 $11 = sp + 1032|0;
 $12 = sp + 1024|0;
 $13 = sp + 896|0;
 $14 = sp + 768|0;
 $15 = sp + 640|0;
 $16 = sp + 512|0;
 $17 = sp + 1096|0;
 $18 = sp + 1088|0;
 $19 = sp + 384|0;
 $20 = sp + 256|0;
 $21 = sp + 128|0;
 $22 = sp;
 $23 = ((($0)) + 284|0);
 HEAP32[$23>>2] = 0;
 $24 = ((($0)) + 208|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ((($25)) + 116|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ($27|0)==(0);
 if ($28) {
  STACKTOP = sp;return;
 }
 $29 = ((($25)) + 220|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ((($0)) + 104|0);
 HEAP32[$31>>2] = $30;
 __ZN7osgUtil9SceneView14updateUniformsEv($0);
 $32 = ((($0)) + 100|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ($33|0)==(0|0);
 if ($34) {
  $35 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
  do {
   if ($35) {
    $36 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
    $37 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($36,112961,94)|0);
    $38 = HEAP32[$37>>2]|0;
    $39 = ((($38)) + -12|0);
    $40 = HEAP32[$39>>2]|0;
    $41 = (($37) + ($40)|0);
    __ZNKSt3__28ios_base6getlocEv($8,$41);
    __THREW__ = 0;
    $42 = (invoke_iii(3255,($8|0),(215188|0))|0);
    $43 = __THREW__; __THREW__ = 0;
    $44 = $43&1;
    if (!($44)) {
     $45 = HEAP32[$42>>2]|0;
     $46 = ((($45)) + 28|0);
     $47 = HEAP32[$46>>2]|0;
     __THREW__ = 0;
     $48 = (invoke_iii($47|0,($42|0),10)|0);
     $49 = __THREW__; __THREW__ = 0;
     $50 = $49&1;
     if (!($50)) {
      __ZNSt3__26localeD2Ev($8);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($37,$48)|0);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($37)|0);
      break;
     }
    }
    $51 = ___cxa_find_matching_catch_2()|0;
    $52 = tempRet0;
    __THREW__ = 0;
    invoke_vi(3263,($8|0));
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if ($54) {
     $55 = ___cxa_find_matching_catch_3(0|0)|0;
     $56 = tempRet0;
     ___clang_call_terminate($55);
     // unreachable;
    } else {
     ___resumeException($51|0);
     // unreachable;
    }
   }
  } while(0);
  $57 = (__Znwj(896)|0);
  __THREW__ = 0;
  invoke_vi(3421,($57|0));
  $58 = __THREW__; __THREW__ = 0;
  $59 = $58&1;
  if ($59) {
   $68 = ___cxa_find_matching_catch_2()|0;
   $69 = tempRet0;
   __ZdlPv($57);
   $$4 = $68;$$410 = $69;
   ___resumeException($$4|0);
   // unreachable;
  }
  $60 = HEAP32[$32>>2]|0;
  $61 = ($60|0)==($57|0);
  if (!($61)) {
   HEAP32[$32>>2] = $57;
   $62 = ((($57)) + 8|0);
   $63 = HEAP32[$62>>2]|0;HEAP32[$62>>2] = (($63+1)|0);
   $64 = ($60|0)==(0|0);
   if (!($64)) {
    $65 = ((($60)) + 8|0);
    $66 = HEAP32[$65>>2]|0;HEAP32[$65>>2] = (($66-1)|0);
    $67 = ($66|0)==(1);
    if ($67) {
     __ZNK3osg10Referenced24signalObserversAndDeleteEbb($60,1,1);
    }
   }
  }
 }
 $70 = ((($0)) + 96|0);
 $71 = HEAP32[$70>>2]|0;
 $72 = ($71|0)==(0|0);
 if ($72) {
  $73 = (__Znwj(160)|0);
  __THREW__ = 0;
  invoke_vi(3572,($73|0));
  $74 = __THREW__; __THREW__ = 0;
  $75 = $74&1;
  if ($75) {
   $84 = ___cxa_find_matching_catch_2()|0;
   $85 = tempRet0;
   __ZdlPv($73);
   $$4 = $84;$$410 = $85;
   ___resumeException($$4|0);
   // unreachable;
  }
  $76 = HEAP32[$70>>2]|0;
  $77 = ($76|0)==($73|0);
  if (!($77)) {
   HEAP32[$70>>2] = $73;
   $78 = ((($73)) + 8|0);
   $79 = HEAP32[$78>>2]|0;HEAP32[$78>>2] = (($79+1)|0);
   $80 = ($76|0)==(0|0);
   if (!($80)) {
    $81 = ((($76)) + 8|0);
    $82 = HEAP32[$81>>2]|0;HEAP32[$81>>2] = (($82-1)|0);
    $83 = ($82|0)==(1);
    if ($83) {
     __ZNK3osg10Referenced24signalObserversAndDeleteEbb($76,1,1);
    }
   }
  }
 }
 $86 = ((($0)) + 148|0);
 $87 = HEAP32[$86>>2]|0;
 $88 = ($87|0)==(0|0);
 if ($88) {
  $89 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
  do {
   if ($89) {
    $90 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
    $91 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($90,113056,94)|0);
    $92 = HEAP32[$91>>2]|0;
    $93 = ((($92)) + -12|0);
    $94 = HEAP32[$93>>2]|0;
    $95 = (($91) + ($94)|0);
    __ZNKSt3__28ios_base6getlocEv($7,$95);
    __THREW__ = 0;
    $96 = (invoke_iii(3255,($7|0),(215188|0))|0);
    $97 = __THREW__; __THREW__ = 0;
    $98 = $97&1;
    if (!($98)) {
     $99 = HEAP32[$96>>2]|0;
     $100 = ((($99)) + 28|0);
     $101 = HEAP32[$100>>2]|0;
     __THREW__ = 0;
     $102 = (invoke_iii($101|0,($96|0),10)|0);
     $103 = __THREW__; __THREW__ = 0;
     $104 = $103&1;
     if (!($104)) {
      __ZNSt3__26localeD2Ev($7);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($91,$102)|0);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($91)|0);
      break;
     }
    }
    $105 = ___cxa_find_matching_catch_2()|0;
    $106 = tempRet0;
    __THREW__ = 0;
    invoke_vi(3263,($7|0));
    $107 = __THREW__; __THREW__ = 0;
    $108 = $107&1;
    if ($108) {
     $109 = ___cxa_find_matching_catch_3(0|0)|0;
     $110 = tempRet0;
     ___clang_call_terminate($109);
     // unreachable;
    } else {
     ___resumeException($105|0);
     // unreachable;
    }
   }
  } while(0);
  $111 = (__ZN7osgUtil11CullVisitor6createEv()|0);
  $112 = HEAP32[$86>>2]|0;
  $113 = ($112|0)==($111|0);
  if (!($113)) {
   HEAP32[$86>>2] = $111;
   $114 = ($111|0)==(0|0);
   if (!($114)) {
    $115 = HEAP32[$111>>2]|0;
    $116 = ((($115)) + -12|0);
    $117 = HEAP32[$116>>2]|0;
    $118 = (($111) + ($117)|0);
    $119 = ((($118)) + 8|0);
    $120 = HEAP32[$119>>2]|0;HEAP32[$119>>2] = (($120+1)|0);
   }
   $121 = ($112|0)==(0|0);
   if (!($121)) {
    $122 = HEAP32[$112>>2]|0;
    $123 = ((($122)) + -12|0);
    $124 = HEAP32[$123>>2]|0;
    $125 = (($112) + ($124)|0);
    $126 = ((($125)) + 8|0);
    $127 = HEAP32[$126>>2]|0;HEAP32[$126>>2] = (($127-1)|0);
    $128 = ($127|0)==(1);
    if ($128) {
     __ZNK3osg10Referenced24signalObserversAndDeleteEbb($125,1,1);
    }
   }
  }
 }
 $129 = ((($0)) + 152|0);
 $130 = HEAP32[$129>>2]|0;
 $131 = ($130|0)==(0|0);
 if ($131) {
  $132 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
  do {
   if ($132) {
    $133 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
    $134 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($133,113151,100)|0);
    $135 = HEAP32[$134>>2]|0;
    $136 = ((($135)) + -12|0);
    $137 = HEAP32[$136>>2]|0;
    $138 = (($134) + ($137)|0);
    __ZNKSt3__28ios_base6getlocEv($6,$138);
    __THREW__ = 0;
    $139 = (invoke_iii(3255,($6|0),(215188|0))|0);
    $140 = __THREW__; __THREW__ = 0;
    $141 = $140&1;
    if (!($141)) {
     $142 = HEAP32[$139>>2]|0;
     $143 = ((($142)) + 28|0);
     $144 = HEAP32[$143>>2]|0;
     __THREW__ = 0;
     $145 = (invoke_iii($144|0,($139|0),10)|0);
     $146 = __THREW__; __THREW__ = 0;
     $147 = $146&1;
     if (!($147)) {
      __ZNSt3__26localeD2Ev($6);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($134,$145)|0);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($134)|0);
      break;
     }
    }
    $148 = ___cxa_find_matching_catch_2()|0;
    $149 = tempRet0;
    __THREW__ = 0;
    invoke_vi(3263,($6|0));
    $150 = __THREW__; __THREW__ = 0;
    $151 = $150&1;
    if ($151) {
     $152 = ___cxa_find_matching_catch_3(0|0)|0;
     $153 = tempRet0;
     ___clang_call_terminate($152);
     // unreachable;
    } else {
     ___resumeException($148|0);
     // unreachable;
    }
   }
  } while(0);
  $154 = (__Znwj(64)|0);
  __THREW__ = 0;
  invoke_vii(3435,($154|0),0);
  $155 = __THREW__; __THREW__ = 0;
  $156 = $155&1;
  if ($156) {
   $172 = ___cxa_find_matching_catch_2()|0;
   $173 = tempRet0;
   __ZdlPv($154);
   $$4 = $172;$$410 = $173;
   ___resumeException($$4|0);
   // unreachable;
  }
  HEAP32[$154>>2] = (49620);
  $157 = ((($154)) + 12|0);
  HEAP32[$157>>2] = 0;
  $158 = ((($154)) + 16|0);
  HEAP32[$158>>2] = 0;
  $159 = ((($154)) + 20|0);
  HEAP32[$159>>2] = 0;
  $160 = ((($154)) + 28|0);
  HEAP32[$160>>2] = 0;
  $161 = ((($154)) + 32|0);
  HEAP32[$161>>2] = 0;
  $162 = ((($154)) + 24|0);
  HEAP32[$162>>2] = $160;
  $163 = ((($154)) + 36|0);
  ;HEAP32[$163>>2]=0|0;HEAP32[$163+4>>2]=0|0;HEAP32[$163+8>>2]=0|0;HEAP32[$163+12>>2]=0|0;HEAP32[$163+16>>2]=0|0;HEAP32[$163+20>>2]=0|0;HEAP8[$163+24>>0]=0|0;
  $164 = HEAP32[$129>>2]|0;
  $165 = ($164|0)==($154|0);
  if (!($165)) {
   HEAP32[$129>>2] = $154;
   $166 = ((($154)) + 8|0);
   $167 = HEAP32[$166>>2]|0;HEAP32[$166>>2] = (($167+1)|0);
   $168 = ($164|0)==(0|0);
   if (!($168)) {
    $169 = ((($164)) + 8|0);
    $170 = HEAP32[$169>>2]|0;HEAP32[$169>>2] = (($170-1)|0);
    $171 = ($170|0)==(1);
    if ($171) {
     __ZNK3osg10Referenced24signalObserversAndDeleteEbb($164,1,1);
    }
   }
  }
 }
 $174 = ((($0)) + 156|0);
 $175 = HEAP32[$174>>2]|0;
 $176 = ($175|0)==(0|0);
 if ($176) {
  $177 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
  do {
   if ($177) {
    $178 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
    $179 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($178,113252,106)|0);
    $180 = HEAP32[$179>>2]|0;
    $181 = ((($180)) + -12|0);
    $182 = HEAP32[$181>>2]|0;
    $183 = (($179) + ($182)|0);
    __ZNKSt3__28ios_base6getlocEv($5,$183);
    __THREW__ = 0;
    $184 = (invoke_iii(3255,($5|0),(215188|0))|0);
    $185 = __THREW__; __THREW__ = 0;
    $186 = $185&1;
    if (!($186)) {
     $187 = HEAP32[$184>>2]|0;
     $188 = ((($187)) + 28|0);
     $189 = HEAP32[$188>>2]|0;
     __THREW__ = 0;
     $190 = (invoke_iii($189|0,($184|0),10)|0);
     $191 = __THREW__; __THREW__ = 0;
     $192 = $191&1;
     if (!($192)) {
      __ZNSt3__26localeD2Ev($5);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($179,$190)|0);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($179)|0);
      break;
     }
    }
    $193 = ___cxa_find_matching_catch_2()|0;
    $194 = tempRet0;
    __THREW__ = 0;
    invoke_vi(3263,($5|0));
    $195 = __THREW__; __THREW__ = 0;
    $196 = $195&1;
    if ($196) {
     $197 = ___cxa_find_matching_catch_3(0|0)|0;
     $198 = tempRet0;
     ___clang_call_terminate($197);
     // unreachable;
    } else {
     ___resumeException($193|0);
     // unreachable;
    }
   }
  } while(0);
  $199 = (__Znwj(424)|0);
  __THREW__ = 0;
  invoke_vi(3573,($199|0));
  $200 = __THREW__; __THREW__ = 0;
  $201 = $200&1;
  if ($201) {
   $210 = ___cxa_find_matching_catch_2()|0;
   $211 = tempRet0;
   __ZdlPv($199);
   $$4 = $210;$$410 = $211;
   ___resumeException($$4|0);
   // unreachable;
  }
  $202 = HEAP32[$174>>2]|0;
  $203 = ($202|0)==($199|0);
  if (!($203)) {
   HEAP32[$174>>2] = $199;
   $204 = ((($199)) + 8|0);
   $205 = HEAP32[$204>>2]|0;HEAP32[$204>>2] = (($205+1)|0);
   $206 = ($202|0)==(0|0);
   if (!($206)) {
    $207 = ((($202)) + 8|0);
    $208 = HEAP32[$207>>2]|0;HEAP32[$207>>2] = (($208-1)|0);
    $209 = ($208|0)==(1);
    if ($209) {
     __ZNK3osg10Referenced24signalObserversAndDeleteEbb($202,1,1);
    }
   }
  }
 }
 $212 = ((($0)) + 224|0);
 $213 = HEAP32[$212>>2]|0;
 $214 = ($213|0)==(0|0);
 if (!($214)) {
  $215 = ((($213)) + 16|0);
  $216 = HEAP8[$215>>0]|0;
  $217 = ($216<<24>>24)==(0);
  if (!($217)) {
   $218 = ((($213)) + 20|0);
   $219 = HEAP32[$218>>2]|0;
   switch ($219|0) {
   case 4:  {
    $220 = HEAP32[$86>>2]|0;
    $221 = ((($0)) + 88|0);
    $222 = HEAP32[$221>>2]|0;
    $223 = ((($220)) + 20|0);
    HEAP32[$223>>2] = $222;
    $224 = HEAP32[$24>>2]|0;
    $225 = ((($224)) + 288|0);
    $226 = HEAP32[$225>>2]|0;
    __ZN7osgUtil9SceneView22computeLeftEyeViewportEPKN3osg8ViewportE($0,$226);
    $227 = HEAP32[$0>>2]|0;
    $228 = ((($227)) + 200|0);
    $229 = HEAP32[$228>>2]|0;
    $230 = HEAP32[$24>>2]|0;
    $231 = ((($230)) + 304|0);
    $232 = ((($0)) + 160|0);
    $233 = HEAP32[$232>>2]|0;
    $234 = ($233|0)==(0|0);
    if ($234) {
     $238 = ((($227)) + 148|0);
     $239 = HEAP32[$238>>2]|0;
     FUNCTION_TABLE_viii[$239 & 8191]($13,$0,$231);
    } else {
     $235 = HEAP32[$233>>2]|0;
     $236 = ((($235)) + 12|0);
     $237 = HEAP32[$236>>2]|0;
     FUNCTION_TABLE_viii[$237 & 8191]($13,$233,$231);
    }
    $240 = HEAP32[$24>>2]|0;
    $241 = ((($240)) + 432|0);
    $242 = HEAP32[$232>>2]|0;
    $243 = ($242|0)==(0|0);
    if ($243) {
     $249 = HEAP32[$0>>2]|0;
     $250 = ((($249)) + 152|0);
     $251 = HEAP32[$250>>2]|0;
     __THREW__ = 0;
     invoke_viii($251|0,($14|0),($0|0),($241|0));
     $252 = __THREW__; __THREW__ = 0;
     $253 = $252&1;
     if (!($253)) {
      label = 74;
     }
    } else {
     $244 = HEAP32[$242>>2]|0;
     $245 = ((($244)) + 16|0);
     $246 = HEAP32[$245>>2]|0;
     __THREW__ = 0;
     invoke_viii($246|0,($14|0),($242|0),($241|0));
     $247 = __THREW__; __THREW__ = 0;
     $248 = $247&1;
     if (!($248)) {
      label = 74;
     }
    }
    if ((label|0) == 74) {
     $254 = HEAP32[$86>>2]|0;
     $255 = HEAP32[$129>>2]|0;
     $256 = HEAP32[$174>>2]|0;
     $257 = ((($0)) + 176|0);
     $258 = HEAP32[$257>>2]|0;
     __THREW__ = 0;
     $259 = (invoke_iiiiiiii($229|0,($0|0),($13|0),($14|0),($254|0),($255|0),($256|0),($258|0))|0);
     $260 = __THREW__; __THREW__ = 0;
     $261 = $260&1;
     if (!($261)) {
      if (!($259)) {
       STACKTOP = sp;return;
      }
      $262 = HEAP32[$86>>2]|0;
      $263 = ((($262)) + 408|0);
      $264 = +HEAPF64[$263>>3];
      $265 = ((($262)) + 416|0);
      $266 = +HEAPF64[$265>>3];
      $267 = HEAP32[$24>>2]|0;
      $268 = ((($267)) + 304|0);
      HEAPF64[$3>>3] = $264;
      HEAPF64[$4>>3] = $266;
      $269 = ((($262)) + 84|0);
      $270 = HEAP32[$269>>2]|0;
      $271 = ($270|0)==(0|0);
      if ($271) {
       $275 = HEAP32[$262>>2]|0;
       $276 = ((($275)) + 212|0);
       $277 = HEAP32[$276>>2]|0;
       (FUNCTION_TABLE_iiiii[$277 & 8191]($262,$268,$3,$4)|0);
      } else {
       $272 = HEAP32[$270>>2]|0;
       $273 = ((($272)) + 16|0);
       $274 = HEAP32[$273>>2]|0;
       (FUNCTION_TABLE_iiiii[$274 & 8191]($270,$268,$3,$4)|0);
      }
      STACKTOP = sp;return;
     }
    }
    $278 = ___cxa_find_matching_catch_2()|0;
    $279 = tempRet0;
    $$4 = $278;$$410 = $279;
    ___resumeException($$4|0);
    // unreachable;
    break;
   }
   case 5:  {
    $280 = HEAP32[$86>>2]|0;
    $281 = ((($0)) + 92|0);
    $282 = HEAP32[$281>>2]|0;
    $283 = ((($280)) + 20|0);
    HEAP32[$283>>2] = $282;
    $284 = HEAP32[$24>>2]|0;
    $285 = ((($284)) + 288|0);
    $286 = HEAP32[$285>>2]|0;
    __ZN7osgUtil9SceneView23computeRightEyeViewportEPKN3osg8ViewportE($0,$286);
    $287 = HEAP32[$0>>2]|0;
    $288 = ((($287)) + 200|0);
    $289 = HEAP32[$288>>2]|0;
    $290 = HEAP32[$24>>2]|0;
    $291 = ((($290)) + 304|0);
    $292 = ((($0)) + 160|0);
    $293 = HEAP32[$292>>2]|0;
    $294 = ($293|0)==(0|0);
    if ($294) {
     $298 = ((($287)) + 156|0);
     $299 = HEAP32[$298>>2]|0;
     FUNCTION_TABLE_viii[$299 & 8191]($15,$0,$291);
    } else {
     $295 = HEAP32[$293>>2]|0;
     $296 = ((($295)) + 20|0);
     $297 = HEAP32[$296>>2]|0;
     FUNCTION_TABLE_viii[$297 & 8191]($15,$293,$291);
    }
    $300 = HEAP32[$24>>2]|0;
    $301 = ((($300)) + 432|0);
    $302 = HEAP32[$292>>2]|0;
    $303 = ($302|0)==(0|0);
    if ($303) {
     $309 = HEAP32[$0>>2]|0;
     $310 = ((($309)) + 160|0);
     $311 = HEAP32[$310>>2]|0;
     __THREW__ = 0;
     invoke_viii($311|0,($16|0),($0|0),($301|0));
     $312 = __THREW__; __THREW__ = 0;
     $313 = $312&1;
     if (!($313)) {
      label = 87;
     }
    } else {
     $304 = HEAP32[$302>>2]|0;
     $305 = ((($304)) + 24|0);
     $306 = HEAP32[$305>>2]|0;
     __THREW__ = 0;
     invoke_viii($306|0,($16|0),($302|0),($301|0));
     $307 = __THREW__; __THREW__ = 0;
     $308 = $307&1;
     if (!($308)) {
      label = 87;
     }
    }
    if ((label|0) == 87) {
     $314 = HEAP32[$86>>2]|0;
     $315 = HEAP32[$129>>2]|0;
     $316 = HEAP32[$174>>2]|0;
     $317 = ((($0)) + 192|0);
     $318 = HEAP32[$317>>2]|0;
     __THREW__ = 0;
     $319 = (invoke_iiiiiiii($289|0,($0|0),($15|0),($16|0),($314|0),($315|0),($316|0),($318|0))|0);
     $320 = __THREW__; __THREW__ = 0;
     $321 = $320&1;
     if (!($321)) {
      if (!($319)) {
       STACKTOP = sp;return;
      }
      $322 = HEAP32[$86>>2]|0;
      $323 = ((($322)) + 408|0);
      $324 = +HEAPF64[$323>>3];
      $325 = ((($322)) + 416|0);
      $326 = +HEAPF64[$325>>3];
      $327 = HEAP32[$24>>2]|0;
      $328 = ((($327)) + 304|0);
      HEAPF64[$1>>3] = $324;
      HEAPF64[$2>>3] = $326;
      $329 = ((($322)) + 84|0);
      $330 = HEAP32[$329>>2]|0;
      $331 = ($330|0)==(0|0);
      if ($331) {
       $335 = HEAP32[$322>>2]|0;
       $336 = ((($335)) + 212|0);
       $337 = HEAP32[$336>>2]|0;
       (FUNCTION_TABLE_iiiii[$337 & 8191]($322,$328,$1,$2)|0);
      } else {
       $332 = HEAP32[$330>>2]|0;
       $333 = ((($332)) + 16|0);
       $334 = HEAP32[$333>>2]|0;
       (FUNCTION_TABLE_iiiii[$334 & 8191]($330,$328,$1,$2)|0);
      }
      STACKTOP = sp;return;
     }
    }
    $338 = ___cxa_find_matching_catch_2()|0;
    $339 = tempRet0;
    $$4 = $338;$$410 = $339;
    ___resumeException($$4|0);
    // unreachable;
    break;
   }
   default: {
    $340 = ((($0)) + 164|0);
    $341 = HEAP32[$340>>2]|0;
    $342 = ($341|0)==(0|0);
    if ($342) {
     $343 = HEAP32[$86>>2]|0;
     $344 = HEAP32[$343>>2]|0;
     $345 = ((($344)) + 200|0);
     $346 = HEAP32[$345>>2]|0;
     $347 = (FUNCTION_TABLE_ii[$346 & 8191]($343)|0);
     $348 = HEAP32[$340>>2]|0;
     $349 = ($348|0)==($347|0);
     if (!($349)) {
      HEAP32[$340>>2] = $347;
      $350 = ($347|0)==(0|0);
      if (!($350)) {
       $351 = HEAP32[$347>>2]|0;
       $352 = ((($351)) + -12|0);
       $353 = HEAP32[$352>>2]|0;
       $354 = (($347) + ($353)|0);
       $355 = ((($354)) + 8|0);
       $356 = HEAP32[$355>>2]|0;HEAP32[$355>>2] = (($356+1)|0);
      }
      $357 = ($348|0)==(0|0);
      if (!($357)) {
       $358 = HEAP32[$348>>2]|0;
       $359 = ((($358)) + -12|0);
       $360 = HEAP32[$359>>2]|0;
       $361 = (($348) + ($360)|0);
       $362 = ((($361)) + 8|0);
       $363 = HEAP32[$362>>2]|0;HEAP32[$362>>2] = (($363-1)|0);
       $364 = ($363|0)==(1);
       if ($364) {
        __ZNK3osg10Referenced24signalObserversAndDeleteEbb($361,1,1);
       }
      }
     }
    }
    $365 = ((($0)) + 168|0);
    $366 = HEAP32[$365>>2]|0;
    $367 = ($366|0)==(0|0);
    if ($367) {
     $368 = (__Znwj(64)|0);
     __THREW__ = 0;
     invoke_vii(3435,($368|0),0);
     $369 = __THREW__; __THREW__ = 0;
     $370 = $369&1;
     if ($370) {
      $371 = ___cxa_find_matching_catch_2()|0;
      $372 = tempRet0;
      __ZdlPv($368);
      ___resumeException($371|0);
      // unreachable;
     }
     HEAP32[$368>>2] = (49620);
     $373 = ((($368)) + 12|0);
     HEAP32[$373>>2] = 0;
     $374 = ((($368)) + 16|0);
     HEAP32[$374>>2] = 0;
     $375 = ((($368)) + 20|0);
     HEAP32[$375>>2] = 0;
     $376 = ((($368)) + 28|0);
     HEAP32[$376>>2] = 0;
     $377 = ((($368)) + 32|0);
     HEAP32[$377>>2] = 0;
     $378 = ((($368)) + 24|0);
     HEAP32[$378>>2] = $376;
     $379 = ((($368)) + 36|0);
     ;HEAP32[$379>>2]=0|0;HEAP32[$379+4>>2]=0|0;HEAP32[$379+8>>2]=0|0;HEAP32[$379+12>>2]=0|0;HEAP32[$379+16>>2]=0|0;HEAP32[$379+20>>2]=0|0;HEAP8[$379+24>>0]=0|0;
     $380 = HEAP32[$365>>2]|0;
     $381 = ($380|0)==($368|0);
     if (!($381)) {
      HEAP32[$365>>2] = $368;
      $382 = ((($368)) + 8|0);
      $383 = HEAP32[$382>>2]|0;HEAP32[$382>>2] = (($383+1)|0);
      $384 = ($380|0)==(0|0);
      if (!($384)) {
       $385 = ((($380)) + 8|0);
       $386 = HEAP32[$385>>2]|0;HEAP32[$385>>2] = (($386-1)|0);
       $387 = ($386|0)==(1);
       if ($387) {
        __ZNK3osg10Referenced24signalObserversAndDeleteEbb($380,1,1);
       }
      }
     }
    }
    $388 = ((($0)) + 172|0);
    $389 = HEAP32[$388>>2]|0;
    $390 = ($389|0)==(0|0);
    L116: do {
     if ($390) {
      $391 = HEAP32[$174>>2]|0;
      HEAP32[$17>>2] = (58136);
      $392 = ((($17)) + 4|0);
      HEAP32[$392>>2] = 2147483647;
      __THREW__ = 0;
      $393 = (invoke_iii(3575,($391|0),($17|0))|0);
      $394 = __THREW__; __THREW__ = 0;
      $395 = $394&1;
      L118: do {
       if (!($395)) {
        $396 = HEAP32[$388>>2]|0;
        $397 = ($396|0)==($393|0);
        do {
         if (!($397)) {
          HEAP32[$388>>2] = $393;
          $398 = ($393|0)==(0|0);
          if (!($398)) {
           $399 = ((($393)) + 8|0);
           $400 = HEAP32[$399>>2]|0;HEAP32[$399>>2] = (($400+1)|0);
          }
          $401 = ($396|0)==(0|0);
          if (!($401)) {
           $402 = ((($396)) + 8|0);
           $403 = HEAP32[$402>>2]|0;HEAP32[$402>>2] = (($403-1)|0);
           $404 = ($403|0)==(1);
           if (!($404)) {
            break;
           }
           __THREW__ = 0;
           invoke_viii(3262,($396|0),1,1);
           $405 = __THREW__; __THREW__ = 0;
           $406 = $405&1;
           if ($406) {
            break L118;
           }
          }
         }
        } while(0);
        break L116;
       }
      } while(0);
      $407 = ___cxa_find_matching_catch_2()|0;
      $408 = tempRet0;
      $$4 = $407;$$410 = $408;
      ___resumeException($$4|0);
      // unreachable;
     }
    } while(0);
    $409 = ((($0)) + 180|0);
    $410 = HEAP32[$409>>2]|0;
    $411 = ($410|0)==(0|0);
    if ($411) {
     $412 = HEAP32[$86>>2]|0;
     $413 = HEAP32[$412>>2]|0;
     $414 = ((($413)) + 200|0);
     $415 = HEAP32[$414>>2]|0;
     $416 = (FUNCTION_TABLE_ii[$415 & 8191]($412)|0);
     $417 = HEAP32[$409>>2]|0;
     $418 = ($417|0)==($416|0);
     if (!($418)) {
      HEAP32[$409>>2] = $416;
      $419 = ($416|0)==(0|0);
      if (!($419)) {
       $420 = HEAP32[$416>>2]|0;
       $421 = ((($420)) + -12|0);
       $422 = HEAP32[$421>>2]|0;
       $423 = (($416) + ($422)|0);
       $424 = ((($423)) + 8|0);
       $425 = HEAP32[$424>>2]|0;HEAP32[$424>>2] = (($425+1)|0);
      }
      $426 = ($417|0)==(0|0);
      if (!($426)) {
       $427 = HEAP32[$417>>2]|0;
       $428 = ((($427)) + -12|0);
       $429 = HEAP32[$428>>2]|0;
       $430 = (($417) + ($429)|0);
       $431 = ((($430)) + 8|0);
       $432 = HEAP32[$431>>2]|0;HEAP32[$431>>2] = (($432-1)|0);
       $433 = ($432|0)==(1);
       if ($433) {
        __ZNK3osg10Referenced24signalObserversAndDeleteEbb($430,1,1);
       }
      }
     }
    }
    $434 = ((($0)) + 184|0);
    $435 = HEAP32[$434>>2]|0;
    $436 = ($435|0)==(0|0);
    if ($436) {
     $437 = (__Znwj(64)|0);
     __THREW__ = 0;
     invoke_vii(3435,($437|0),0);
     $438 = __THREW__; __THREW__ = 0;
     $439 = $438&1;
     if ($439) {
      $440 = ___cxa_find_matching_catch_2()|0;
      $441 = tempRet0;
      __ZdlPv($437);
      ___resumeException($440|0);
      // unreachable;
     }
     HEAP32[$437>>2] = (49620);
     $442 = ((($437)) + 12|0);
     HEAP32[$442>>2] = 0;
     $443 = ((($437)) + 16|0);
     HEAP32[$443>>2] = 0;
     $444 = ((($437)) + 20|0);
     HEAP32[$444>>2] = 0;
     $445 = ((($437)) + 28|0);
     HEAP32[$445>>2] = 0;
     $446 = ((($437)) + 32|0);
     HEAP32[$446>>2] = 0;
     $447 = ((($437)) + 24|0);
     HEAP32[$447>>2] = $445;
     $448 = ((($437)) + 36|0);
     ;HEAP32[$448>>2]=0|0;HEAP32[$448+4>>2]=0|0;HEAP32[$448+8>>2]=0|0;HEAP32[$448+12>>2]=0|0;HEAP32[$448+16>>2]=0|0;HEAP32[$448+20>>2]=0|0;HEAP8[$448+24>>0]=0|0;
     $449 = HEAP32[$434>>2]|0;
     $450 = ($449|0)==($437|0);
     if (!($450)) {
      HEAP32[$434>>2] = $437;
      $451 = ((($437)) + 8|0);
      $452 = HEAP32[$451>>2]|0;HEAP32[$451>>2] = (($452+1)|0);
      $453 = ($449|0)==(0|0);
      if (!($453)) {
       $454 = ((($449)) + 8|0);
       $455 = HEAP32[$454>>2]|0;HEAP32[$454>>2] = (($455-1)|0);
       $456 = ($455|0)==(1);
       if ($456) {
        __ZNK3osg10Referenced24signalObserversAndDeleteEbb($449,1,1);
       }
      }
     }
    }
    $457 = ((($0)) + 188|0);
    $458 = HEAP32[$457>>2]|0;
    $459 = ($458|0)==(0|0);
    L149: do {
     if ($459) {
      $460 = HEAP32[$174>>2]|0;
      HEAP32[$18>>2] = (58136);
      $461 = ((($18)) + 4|0);
      HEAP32[$461>>2] = 2147483647;
      __THREW__ = 0;
      $462 = (invoke_iii(3575,($460|0),($18|0))|0);
      $463 = __THREW__; __THREW__ = 0;
      $464 = $463&1;
      L151: do {
       if (!($464)) {
        $465 = HEAP32[$457>>2]|0;
        $466 = ($465|0)==($462|0);
        do {
         if (!($466)) {
          HEAP32[$457>>2] = $462;
          $467 = ($462|0)==(0|0);
          if (!($467)) {
           $468 = ((($462)) + 8|0);
           $469 = HEAP32[$468>>2]|0;HEAP32[$468>>2] = (($469+1)|0);
          }
          $470 = ($465|0)==(0|0);
          if ($470) {
           break;
          }
          $471 = ((($465)) + 8|0);
          $472 = HEAP32[$471>>2]|0;HEAP32[$471>>2] = (($472-1)|0);
          $473 = ($472|0)==(1);
          if (!($473)) {
           break;
          }
          __THREW__ = 0;
          invoke_viii(3262,($465|0),1,1);
          $474 = __THREW__; __THREW__ = 0;
          $475 = $474&1;
          if ($475) {
           break L151;
          }
         }
        } while(0);
        break L149;
       }
      } while(0);
      $476 = ___cxa_find_matching_catch_2()|0;
      $477 = tempRet0;
      $$4 = $476;$$410 = $477;
      ___resumeException($$4|0);
      // unreachable;
     }
    } while(0);
    $478 = HEAP32[$340>>2]|0;
    $479 = HEAP32[$86>>2]|0;
    $480 = ((($479)) + 40|0);
    $481 = HEAP32[$480>>2]|0;
    $482 = ((($478)) + 40|0);
    $483 = HEAP32[$482>>2]|0;
    $484 = ($483|0)==($481|0);
    do {
     if (!($484)) {
      HEAP32[$482>>2] = $481;
      $485 = ($481|0)==(0|0);
      if (!($485)) {
       $486 = ((($481)) + 8|0);
       $487 = HEAP32[$486>>2]|0;HEAP32[$486>>2] = (($487+1)|0);
      }
      $488 = ($483|0)==(0|0);
      if (!($488)) {
       $489 = ((($483)) + 8|0);
       $490 = HEAP32[$489>>2]|0;HEAP32[$489>>2] = (($490-1)|0);
       $491 = ($490|0)==(1);
       if (!($491)) {
        break;
       }
       __ZNK3osg10Referenced24signalObserversAndDeleteEbb($483,1,1);
      }
     }
    } while(0);
    $492 = HEAP32[$340>>2]|0;
    $493 = HEAP32[$86>>2]|0;
    $494 = ((($493)) + 84|0);
    $495 = HEAP32[$494>>2]|0;
    $496 = ((($492)) + 84|0);
    $497 = HEAP32[$496>>2]|0;
    $498 = ($497|0)==($495|0);
    do {
     if (!($498)) {
      HEAP32[$496>>2] = $495;
      $499 = ($495|0)==(0|0);
      if (!($499)) {
       $500 = ((($495)) + 8|0);
       $501 = HEAP32[$500>>2]|0;HEAP32[$500>>2] = (($501+1)|0);
      }
      $502 = ($497|0)==(0|0);
      if ($502) {
       break;
      }
      $503 = ((($497)) + 8|0);
      $504 = HEAP32[$503>>2]|0;HEAP32[$503>>2] = (($504-1)|0);
      $505 = ($504|0)==(1);
      if (!($505)) {
       break;
      }
      __ZNK3osg10Referenced24signalObserversAndDeleteEbb($497,1,1);
     }
    } while(0);
    $506 = ((($492)) + 64|0);
    $507 = HEAP32[$506>>2]|0;
    $508 = ($507|0)==(0);
    $509 = ((($492)) + 60|0);
    if ($508) {
     $510 = HEAP32[$509>>2]|0;
     $511 = $510 & -17;
     HEAP32[$509>>2] = $511;
    }
    $512 = HEAP32[$340>>2]|0;
    $513 = ((($0)) + 88|0);
    $514 = HEAP32[$513>>2]|0;
    $515 = ((($512)) + 20|0);
    HEAP32[$515>>2] = $514;
    $516 = HEAP32[$24>>2]|0;
    $517 = ((($516)) + 288|0);
    $518 = HEAP32[$517>>2]|0;
    __ZN7osgUtil9SceneView22computeLeftEyeViewportEPKN3osg8ViewportE($0,$518);
    $519 = HEAP32[$0>>2]|0;
    $520 = ((($519)) + 200|0);
    $521 = HEAP32[$520>>2]|0;
    $522 = HEAP32[$24>>2]|0;
    $523 = ((($522)) + 304|0);
    $524 = ((($0)) + 160|0);
    $525 = HEAP32[$524>>2]|0;
    $526 = ($525|0)==(0|0);
    if ($526) {
     $530 = ((($519)) + 148|0);
     $531 = HEAP32[$530>>2]|0;
     FUNCTION_TABLE_viii[$531 & 8191]($19,$0,$523);
    } else {
     $527 = HEAP32[$525>>2]|0;
     $528 = ((($527)) + 12|0);
     $529 = HEAP32[$528>>2]|0;
     FUNCTION_TABLE_viii[$529 & 8191]($19,$525,$523);
    }
    $532 = HEAP32[$24>>2]|0;
    $533 = ((($532)) + 432|0);
    $534 = HEAP32[$524>>2]|0;
    $535 = ($534|0)==(0|0);
    if ($535) {
     $541 = HEAP32[$0>>2]|0;
     $542 = ((($541)) + 152|0);
     $543 = HEAP32[$542>>2]|0;
     __THREW__ = 0;
     invoke_viii($543|0,($20|0),($0|0),($533|0));
     $544 = __THREW__; __THREW__ = 0;
     $545 = $544&1;
     if (!($545)) {
      label = 162;
     }
    } else {
     $536 = HEAP32[$534>>2]|0;
     $537 = ((($536)) + 16|0);
     $538 = HEAP32[$537>>2]|0;
     __THREW__ = 0;
     invoke_viii($538|0,($20|0),($534|0),($533|0));
     $539 = __THREW__; __THREW__ = 0;
     $540 = $539&1;
     if (!($540)) {
      label = 162;
     }
    }
    do {
     if ((label|0) == 162) {
      $546 = HEAP32[$340>>2]|0;
      $547 = HEAP32[$365>>2]|0;
      $548 = HEAP32[$388>>2]|0;
      $549 = ((($0)) + 176|0);
      $550 = HEAP32[$549>>2]|0;
      __THREW__ = 0;
      (invoke_iiiiiiii($521|0,($0|0),($19|0),($20|0),($546|0),($547|0),($548|0),($550|0))|0);
      $551 = __THREW__; __THREW__ = 0;
      $552 = $551&1;
      if ($552) {
       break;
      }
      $553 = HEAP32[$409>>2]|0;
      $554 = HEAP32[$86>>2]|0;
      $555 = ((($554)) + 40|0);
      $556 = HEAP32[$555>>2]|0;
      $557 = ((($553)) + 40|0);
      $558 = HEAP32[$557>>2]|0;
      $559 = ($558|0)==($556|0);
      do {
       if (!($559)) {
        HEAP32[$557>>2] = $556;
        $560 = ($556|0)==(0|0);
        if (!($560)) {
         $561 = ((($556)) + 8|0);
         $562 = HEAP32[$561>>2]|0;HEAP32[$561>>2] = (($562+1)|0);
        }
        $563 = ($558|0)==(0|0);
        if ($563) {
         break;
        }
        $564 = ((($558)) + 8|0);
        $565 = HEAP32[$564>>2]|0;HEAP32[$564>>2] = (($565-1)|0);
        $566 = ($565|0)==(1);
        if (!($566)) {
         break;
        }
        __ZNK3osg10Referenced24signalObserversAndDeleteEbb($558,1,1);
       }
      } while(0);
      $567 = HEAP32[$409>>2]|0;
      $568 = HEAP32[$86>>2]|0;
      $569 = ((($568)) + 84|0);
      $570 = HEAP32[$569>>2]|0;
      $571 = ((($567)) + 84|0);
      $572 = HEAP32[$571>>2]|0;
      $573 = ($572|0)==($570|0);
      do {
       if (!($573)) {
        HEAP32[$571>>2] = $570;
        $574 = ($570|0)==(0|0);
        if (!($574)) {
         $575 = ((($570)) + 8|0);
         $576 = HEAP32[$575>>2]|0;HEAP32[$575>>2] = (($576+1)|0);
        }
        $577 = ($572|0)==(0|0);
        if ($577) {
         break;
        }
        $578 = ((($572)) + 8|0);
        $579 = HEAP32[$578>>2]|0;HEAP32[$578>>2] = (($579-1)|0);
        $580 = ($579|0)==(1);
        if (!($580)) {
         break;
        }
        __ZNK3osg10Referenced24signalObserversAndDeleteEbb($572,1,1);
       }
      } while(0);
      $581 = ((($567)) + 64|0);
      $582 = HEAP32[$581>>2]|0;
      $583 = ($582|0)==(0);
      $584 = ((($567)) + 60|0);
      if ($583) {
       $585 = HEAP32[$584>>2]|0;
       $586 = $585 & -17;
       HEAP32[$584>>2] = $586;
      }
      $587 = HEAP32[$409>>2]|0;
      $588 = ((($0)) + 92|0);
      $589 = HEAP32[$588>>2]|0;
      $590 = ((($587)) + 20|0);
      HEAP32[$590>>2] = $589;
      $591 = HEAP32[$24>>2]|0;
      $592 = ((($591)) + 288|0);
      $593 = HEAP32[$592>>2]|0;
      __ZN7osgUtil9SceneView23computeRightEyeViewportEPKN3osg8ViewportE($0,$593);
      $594 = HEAP32[$0>>2]|0;
      $595 = ((($594)) + 200|0);
      $596 = HEAP32[$595>>2]|0;
      $597 = HEAP32[$24>>2]|0;
      $598 = ((($597)) + 304|0);
      $599 = HEAP32[$524>>2]|0;
      $600 = ($599|0)==(0|0);
      if ($600) {
       $604 = ((($594)) + 156|0);
       $605 = HEAP32[$604>>2]|0;
       FUNCTION_TABLE_viii[$605 & 8191]($21,$0,$598);
      } else {
       $601 = HEAP32[$599>>2]|0;
       $602 = ((($601)) + 20|0);
       $603 = HEAP32[$602>>2]|0;
       FUNCTION_TABLE_viii[$603 & 8191]($21,$599,$598);
      }
      $606 = HEAP32[$24>>2]|0;
      $607 = ((($606)) + 432|0);
      $608 = HEAP32[$524>>2]|0;
      $609 = ($608|0)==(0|0);
      if ($609) {
       $615 = HEAP32[$0>>2]|0;
       $616 = ((($615)) + 160|0);
       $617 = HEAP32[$616>>2]|0;
       __THREW__ = 0;
       invoke_viii($617|0,($22|0),($0|0),($607|0));
       $618 = __THREW__; __THREW__ = 0;
       $619 = $618&1;
       if (!($619)) {
        label = 183;
       }
      } else {
       $610 = HEAP32[$608>>2]|0;
       $611 = ((($610)) + 24|0);
       $612 = HEAP32[$611>>2]|0;
       __THREW__ = 0;
       invoke_viii($612|0,($22|0),($608|0),($607|0));
       $613 = __THREW__; __THREW__ = 0;
       $614 = $613&1;
       if (!($614)) {
        label = 183;
       }
      }
      do {
       if ((label|0) == 183) {
        $620 = HEAP32[$409>>2]|0;
        $621 = HEAP32[$434>>2]|0;
        $622 = HEAP32[$457>>2]|0;
        $623 = ((($0)) + 192|0);
        $624 = HEAP32[$623>>2]|0;
        __THREW__ = 0;
        $625 = (invoke_iiiiiiii($596|0,($0|0),($21|0),($22|0),($620|0),($621|0),($622|0),($624|0))|0);
        $626 = __THREW__; __THREW__ = 0;
        $627 = $626&1;
        if ($627) {
         break;
        }
        if (!($625)) {
         STACKTOP = sp;return;
        }
        $628 = HEAP32[$340>>2]|0;
        $629 = ((($628)) + 408|0);
        $630 = +HEAPF64[$629>>3];
        $631 = HEAP32[$409>>2]|0;
        $632 = ((($631)) + 408|0);
        $633 = +HEAPF64[$632>>3];
        $634 = $630 < $633;
        $635 = $634 ? $630 : $633;
        $636 = ((($628)) + 416|0);
        $637 = +HEAPF64[$636>>3];
        $638 = ((($631)) + 416|0);
        $639 = +HEAPF64[$638>>3];
        $640 = $637 > $639;
        $641 = $640 ? $637 : $639;
        $642 = HEAP32[$86>>2]|0;
        $643 = HEAP32[$24>>2]|0;
        $644 = ((($643)) + 304|0);
        HEAPF64[$9>>3] = $635;
        HEAPF64[$10>>3] = $641;
        $645 = ((($642)) + 84|0);
        $646 = HEAP32[$645>>2]|0;
        $647 = ($646|0)==(0|0);
        if ($647) {
         $651 = HEAP32[$642>>2]|0;
         $652 = ((($651)) + 212|0);
         $653 = HEAP32[$652>>2]|0;
         (FUNCTION_TABLE_iiiii[$653 & 8191]($642,$644,$9,$10)|0);
        } else {
         $648 = HEAP32[$646>>2]|0;
         $649 = ((($648)) + 16|0);
         $650 = HEAP32[$649>>2]|0;
         (FUNCTION_TABLE_iiiii[$650 & 8191]($646,$644,$9,$10)|0);
        }
        STACKTOP = sp;return;
       }
      } while(0);
      $656 = ___cxa_find_matching_catch_2()|0;
      $657 = tempRet0;
      $$4 = $656;$$410 = $657;
      ___resumeException($$4|0);
      // unreachable;
     }
    } while(0);
    $654 = ___cxa_find_matching_catch_2()|0;
    $655 = tempRet0;
    $$4 = $654;$$410 = $655;
    ___resumeException($$4|0);
    // unreachable;
   }
   }
  }
 }
 $658 = HEAP32[$86>>2]|0;
 $659 = ((($0)) + 84|0);
 $660 = HEAP32[$659>>2]|0;
 $661 = ((($658)) + 20|0);
 HEAP32[$661>>2] = $660;
 $662 = HEAP32[$0>>2]|0;
 $663 = ((($662)) + 200|0);
 $664 = HEAP32[$663>>2]|0;
 $665 = HEAP32[$24>>2]|0;
 $666 = ((($665)) + 304|0);
 $667 = ((($665)) + 432|0);
 $668 = HEAP32[$129>>2]|0;
 $669 = HEAP32[$174>>2]|0;
 $670 = ((($665)) + 288|0);
 $671 = HEAP32[$670>>2]|0;
 $672 = (FUNCTION_TABLE_iiiiiiii[$664 & 8191]($0,$666,$667,$658,$668,$669,$671)|0);
 if (!($672)) {
  STACKTOP = sp;return;
 }
 $673 = HEAP32[$86>>2]|0;
 $674 = ((($673)) + 408|0);
 $675 = +HEAPF64[$674>>3];
 $676 = ((($673)) + 416|0);
 $677 = +HEAPF64[$676>>3];
 $678 = HEAP32[$24>>2]|0;
 $679 = ((($678)) + 304|0);
 HEAPF64[$11>>3] = $675;
 HEAPF64[$12>>3] = $677;
 $680 = ((($673)) + 84|0);
 $681 = HEAP32[$680>>2]|0;
 $682 = ($681|0)==(0|0);
 if ($682) {
  $686 = HEAP32[$673>>2]|0;
  $687 = ((($686)) + 212|0);
  $688 = HEAP32[$687>>2]|0;
  (FUNCTION_TABLE_iiiii[$688 & 8191]($673,$679,$11,$12)|0);
 } else {
  $683 = HEAP32[$681>>2]|0;
  $684 = ((($683)) + 16|0);
  $685 = HEAP32[$684>>2]|0;
  (FUNCTION_TABLE_iiiii[$685 & 8191]($681,$679,$11,$12)|0);
 }
 STACKTOP = sp;return;
}
function __ZN7osgUtil9SceneView4drawEv($0) {
 $0 = $0|0;
 var $$0 = 0, $$0100 = 0, $$0101 = 0, $$091 = 0, $$092 = 0, $$094 = 0, $$098 = 0, $$099 = 0, $$2 = 0, $$297 = 0, $$pre = 0, $$pre$phiZ2D = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0;
 var $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0;
 var $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0;
 var $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0;
 var $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0;
 var $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0;
 var $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0;
 var $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0;
 var $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0;
 var $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0;
 var $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0.0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0.0, $337 = 0.0, $338 = 0.0, $339 = 0, $34 = 0;
 var $340 = 0.0, $341 = 0.0, $342 = 0, $343 = 0, $344 = 0.0, $345 = 0, $346 = 0, $347 = 0.0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0;
 var $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0;
 var $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0;
 var $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0;
 var $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0;
 var $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0.0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0.0, $444 = 0.0, $445 = 0.0, $446 = 0, $447 = 0.0, $448 = 0;
 var $449 = 0, $45 = 0, $450 = 0.0, $451 = 0.0, $452 = 0, $453 = 0, $454 = 0.0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0;
 var $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0;
 var $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0;
 var $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0;
 var $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0;
 var $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0;
 var $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0;
 var $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0;
 var $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0;
 var $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0;
 var $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $1 = sp + 16|0;
 $2 = sp + 12|0;
 $3 = sp;
 $4 = sp + 8|0;
 $5 = ((($0)) + 208|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($6)) + 116|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0);
 if ($9) {
  STACKTOP = sp;return;
 }
 $10 = ((($0)) + 100|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($0)) + 200|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($11)) + 160|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==($13|0);
 if (!($16)) {
  HEAP32[$14>>2] = $13;
  $17 = ($13|0)==(0|0);
  if (!($17)) {
   $18 = ((($13)) + 8|0);
   $19 = HEAP32[$18>>2]|0;HEAP32[$18>>2] = (($19+1)|0);
  }
  $20 = ($15|0)==(0|0);
  if (!($20)) {
   $21 = ((($15)) + 8|0);
   $22 = HEAP32[$21>>2]|0;HEAP32[$21>>2] = (($22-1)|0);
   $23 = ($22|0)==(1);
   if ($23) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($15,1,1);
   }
  }
 }
 $24 = ((($0)) + 224|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)==(0|0);
 if (!($26)) {
  $27 = ((($11)) + 336|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = ($28|0)==($25|0);
  if (!($29)) {
   HEAP32[$27>>2] = $25;
   $30 = ((($25)) + 8|0);
   $31 = HEAP32[$30>>2]|0;HEAP32[$30>>2] = (($31+1)|0);
   $32 = ($28|0)==(0|0);
   if (!($32)) {
    $33 = ((($28)) + 8|0);
    $34 = HEAP32[$33>>2]|0;HEAP32[$33>>2] = (($34-1)|0);
    $35 = ($34|0)==(1);
    if ($35) {
     __ZNK3osg10Referenced24signalObserversAndDeleteEbb($28,1,1);
    }
   }
  }
 }
 __ZN3osg5State24initializeExtensionProcsEv($11);
 $36 = ((($11)) + 124|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (__ZN3osg22getOrCreateContextDataEj($37)|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = ((($39)) + 12|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = HEAP32[$14>>2]|0;
 FUNCTION_TABLE_vii[$41 & 8191]($38,$42);
 $43 = ((($0)) + 136|0);
 $44 = HEAP8[$43>>0]|0;
 $45 = ($44<<24>>24)==(0);
 if ($45) {
  $46 = HEAP32[$0>>2]|0;
  $47 = ((($46)) + 172|0);
  $48 = HEAP32[$47>>2]|0;
  FUNCTION_TABLE_vi[$48 & 8191]($0);
 }
 $49 = ((($0)) + 246|0);
 $50 = HEAP8[$49>>0]|0;
 $51 = ($50<<24>>24)==(0);
 if (!($51)) {
  HEAPF64[$3>>3] = 0.0050000000000000001;
  $52 = HEAP32[$0>>2]|0;
  $53 = ((($52)) + 196|0);
  $54 = HEAP32[$53>>2]|0;
  FUNCTION_TABLE_vii[$54 & 8191]($0,$3);
 }
 $55 = ((($0)) + 245|0);
 $56 = HEAP8[$55>>0]|0;
 HEAP8[$49>>0] = $56;
 HEAP32[$4>>2] = 0;
 $57 = HEAP32[$24>>2]|0;
 $58 = ($57|0)==(0|0);
 L24: do {
  if ($58) {
   label = 140;
  } else {
   $59 = ((($57)) + 16|0);
   $60 = HEAP8[$59>>0]|0;
   $61 = ($60<<24>>24)==(0);
   if ($61) {
    label = 140;
   } else {
    $62 = ((($57)) + 20|0);
    $63 = HEAP32[$62>>2]|0;
    switch ($63|0) {
    case 0:  {
     $64 = ((($0)) + 96|0);
     $65 = HEAP32[$64>>2]|0;
     $66 = HEAP32[$5>>2]|0;
     $67 = ((($66)) + 288|0);
     $68 = HEAP32[$67>>2]|0;
     __ZN3osg8StateSet12setAttributeEPNS_14StateAttributeEj($65,$68,0);
     $69 = HEAP32[$64>>2]|0;
     $70 = (__ZN3osg8StateSet12getAttributeENS_14StateAttribute4TypeEj($69,25,0)|0);
     $71 = ($70|0)==(0|0);
     do {
      if ($71) {
       $76 = (__Znwj(60)|0);
       __THREW__ = 0;
       invoke_vi(3339,($76|0));
       $77 = __THREW__; __THREW__ = 0;
       $78 = $77&1;
       if (!($78)) {
        HEAP32[$76>>2] = (57196);
        $79 = ((($76)) + 56|0);
        HEAP32[$79>>2] = 16843009;
        $80 = HEAP32[$64>>2]|0;
        __ZN3osg8StateSet12setAttributeEPNS_14StateAttributeEj($80,$76,0);
        $$092 = $76;
        break;
       }
       $81 = ___cxa_find_matching_catch_2()|0;
       $82 = tempRet0;
       __ZdlPv($76);
       $$2 = $81;$$297 = $82;
       ___resumeException($$2|0);
       // unreachable;
      } else {
       $72 = ((($70)) + 56|0);
       HEAP8[$72>>0] = 1;
       $73 = ((($70)) + 57|0);
       HEAP8[$73>>0] = 1;
       $74 = ((($70)) + 58|0);
       HEAP8[$74>>0] = 1;
       $75 = ((($70)) + 59|0);
       HEAP8[$75>>0] = 1;
       $$092 = $70;
      }
     } while(0);
     $83 = ((($0)) + 172|0);
     $84 = HEAP32[$83>>2]|0;
     $85 = ((($84)) + 168|0);
     $86 = HEAP32[$85>>2]|0;
     $87 = ($86|0)==($$092|0);
     if (!($87)) {
      HEAP32[$85>>2] = $$092;
      $88 = ((($$092)) + 8|0);
      $89 = HEAP32[$88>>2]|0;HEAP32[$88>>2] = (($89+1)|0);
      $90 = ($86|0)==(0|0);
      if (!($90)) {
       $91 = ((($86)) + 8|0);
       $92 = HEAP32[$91>>2]|0;HEAP32[$91>>2] = (($92-1)|0);
       $93 = ($92|0)==(1);
       if ($93) {
        __ZNK3osg10Referenced24signalObserversAndDeleteEbb($86,1,1);
       }
      }
     }
     $94 = ((($0)) + 188|0);
     $95 = HEAP32[$94>>2]|0;
     $96 = ((($95)) + 168|0);
     $97 = HEAP32[$96>>2]|0;
     $98 = ($97|0)==($$092|0);
     if (!($98)) {
      HEAP32[$96>>2] = $$092;
      $99 = ($$092|0)==(0|0);
      if (!($99)) {
       $100 = ((($$092)) + 8|0);
       $101 = HEAP32[$100>>2]|0;HEAP32[$100>>2] = (($101+1)|0);
      }
      $102 = ($97|0)==(0|0);
      if (!($102)) {
       $103 = ((($97)) + 8|0);
       $104 = HEAP32[$103>>2]|0;HEAP32[$103>>2] = (($104-1)|0);
       $105 = ($104|0)==(1);
       if ($105) {
        __ZNK3osg10Referenced24signalObserversAndDeleteEbb($97,1,1);
       }
      }
     }
     $106 = HEAP32[$83>>2]|0;
     $107 = ((($106)) + 148|0);
     HEAP32[$107>>2] = 1026;
     $108 = ((($106)) + 152|0);
     HEAP8[$108>>0] = 1;
     $109 = ((($106)) + 156|0);
     HEAP32[$109>>2] = 1026;
     $110 = ((($106)) + 160|0);
     HEAP8[$110>>0] = 1;
     $111 = HEAP32[$94>>2]|0;
     $112 = ((($111)) + 148|0);
     HEAP32[$112>>2] = 1027;
     $113 = ((($111)) + 152|0);
     HEAP8[$113>>0] = 1;
     $114 = ((($111)) + 156|0);
     HEAP32[$114>>2] = 1027;
     $115 = ((($111)) + 160|0);
     HEAP8[$115>>0] = 1;
     $116 = HEAP32[$106>>2]|0;
     $117 = ((($116)) + 192|0);
     $118 = HEAP32[$117>>2]|0;
     FUNCTION_TABLE_viii[$118 & 8191]($106,$10,$4);
     $119 = HEAP32[$94>>2]|0;
     $120 = HEAP32[$119>>2]|0;
     $121 = ((($120)) + 192|0);
     $122 = HEAP32[$121>>2]|0;
     FUNCTION_TABLE_viii[$122 & 8191]($119,$10,$4);
     $123 = HEAP32[$83>>2]|0;
     $124 = HEAP32[$123>>2]|0;
     $125 = ((($124)) + 172|0);
     $126 = HEAP32[$125>>2]|0;
     FUNCTION_TABLE_viii[$126 & 8191]($123,$10,$4);
     $127 = HEAP32[$94>>2]|0;
     $128 = HEAP32[$127>>2]|0;
     $129 = ((($128)) + 172|0);
     $130 = HEAP32[$129>>2]|0;
     FUNCTION_TABLE_viii[$130 & 8191]($127,$10,$4);
     break L24;
     break;
    }
    case 1:  {
     $131 = HEAP32[$5>>2]|0;
     $132 = ((($131)) + 148|0);
     $133 = HEAP32[$132>>2]|0;
     $134 = $133 & 131072;
     $135 = ($134|0)==(0);
     if ($135) {
      $136 = ((($0)) + 172|0);
      $137 = HEAP32[$136>>2]|0;
      $138 = ((($131)) + 568|0);
      $139 = HEAP32[$138>>2]|0;
      $140 = ((($137)) + 148|0);
      HEAP32[$140>>2] = $139;
      $141 = ((($137)) + 152|0);
      HEAP8[$141>>0] = 1;
      $142 = ((($137)) + 156|0);
      HEAP32[$142>>2] = $139;
      $143 = ((($137)) + 160|0);
      HEAP8[$143>>0] = 1;
      $144 = ((($0)) + 188|0);
      $145 = HEAP32[$144>>2]|0;
      $146 = ((($145)) + 148|0);
      HEAP32[$146>>2] = $139;
      $147 = ((($145)) + 152|0);
      HEAP8[$147>>0] = 1;
      $148 = ((($145)) + 156|0);
      HEAP32[$148>>2] = $139;
      $149 = ((($145)) + 160|0);
      HEAP8[$149>>0] = 1;
     }
     $150 = ((($0)) + 96|0);
     $151 = HEAP32[$150>>2]|0;
     $152 = (__ZN3osg8StateSet12getAttributeENS_14StateAttribute4TypeEj($151,25,0)|0);
     $153 = ($152|0)==(0|0);
     do {
      if ($153) {
       $158 = (__Znwj(60)|0);
       __THREW__ = 0;
       invoke_vi(3339,($158|0));
       $159 = __THREW__; __THREW__ = 0;
       $160 = $159&1;
       if (!($160)) {
        HEAP32[$158>>2] = (57196);
        $161 = ((($158)) + 56|0);
        HEAP32[$161>>2] = 16843009;
        $162 = HEAP32[$150>>2]|0;
        __ZN3osg8StateSet12setAttributeEPNS_14StateAttributeEj($162,$158,0);
        $$098 = $158;
        break;
       }
       $163 = ___cxa_find_matching_catch_2()|0;
       $164 = tempRet0;
       __ZdlPv($158);
       $$2 = $163;$$297 = $164;
       ___resumeException($$2|0);
       // unreachable;
      } else {
       $154 = ((($152)) + 56|0);
       HEAP8[$154>>0] = 1;
       $155 = ((($152)) + 57|0);
       HEAP8[$155>>0] = 1;
       $156 = ((($152)) + 58|0);
       HEAP8[$156>>0] = 1;
       $157 = ((($152)) + 59|0);
       HEAP8[$157>>0] = 1;
       $$098 = $152;
      }
     } while(0);
     $165 = ((($0)) + 172|0);
     $166 = HEAP32[$165>>2]|0;
     $167 = ((($166)) + 168|0);
     $168 = HEAP32[$167>>2]|0;
     $169 = ($168|0)==($$098|0);
     if (!($169)) {
      HEAP32[$167>>2] = $$098;
      $170 = ((($$098)) + 8|0);
      $171 = HEAP32[$170>>2]|0;HEAP32[$170>>2] = (($171+1)|0);
      $172 = ($168|0)==(0|0);
      if (!($172)) {
       $173 = ((($168)) + 8|0);
       $174 = HEAP32[$173>>2]|0;HEAP32[$173>>2] = (($174-1)|0);
       $175 = ($174|0)==(1);
       if ($175) {
        __ZNK3osg10Referenced24signalObserversAndDeleteEbb($168,1,1);
       }
      }
     }
     $176 = ((($0)) + 188|0);
     $177 = HEAP32[$176>>2]|0;
     $178 = ((($177)) + 168|0);
     $179 = HEAP32[$178>>2]|0;
     $180 = ($179|0)==($$098|0);
     if (!($180)) {
      HEAP32[$178>>2] = $$098;
      $181 = ($$098|0)==(0|0);
      if (!($181)) {
       $182 = ((($$098)) + 8|0);
       $183 = HEAP32[$182>>2]|0;HEAP32[$182>>2] = (($183+1)|0);
      }
      $184 = ($179|0)==(0|0);
      if (!($184)) {
       $185 = ((($179)) + 8|0);
       $186 = HEAP32[$185>>2]|0;HEAP32[$185>>2] = (($186-1)|0);
       $187 = ($186|0)==(1);
       if ($187) {
        __ZNK3osg10Referenced24signalObserversAndDeleteEbb($179,1,1);
       }
      }
     }
     $188 = HEAP32[$150>>2]|0;
     $189 = HEAP32[$5>>2]|0;
     $190 = ((($189)) + 288|0);
     $191 = HEAP32[$190>>2]|0;
     __ZN3osg8StateSet12setAttributeEPNS_14StateAttributeEj($188,$191,0);
     $192 = HEAP32[$165>>2]|0;
     $193 = HEAP32[$192>>2]|0;
     $194 = ((($193)) + 192|0);
     $195 = HEAP32[$194>>2]|0;
     FUNCTION_TABLE_viii[$195 & 8191]($192,$10,$4);
     $196 = HEAP32[$176>>2]|0;
     $197 = HEAP32[$196>>2]|0;
     $198 = ((($197)) + 192|0);
     $199 = HEAP32[$198>>2]|0;
     FUNCTION_TABLE_viii[$199 & 8191]($196,$10,$4);
     $200 = HEAP32[$165>>2]|0;
     $201 = ((($200)) + 168|0);
     $202 = HEAP32[$201>>2]|0;
     $203 = ($202|0)==(0|0);
     if ($203) {
      $204 = (__Znwj(60)|0);
      __THREW__ = 0;
      invoke_vi(3576,($204|0));
      $205 = __THREW__; __THREW__ = 0;
      $206 = $205&1;
      if ($206) {
       $217 = ___cxa_find_matching_catch_2()|0;
       $218 = tempRet0;
       __ZdlPv($204);
       $$2 = $217;$$297 = $218;
       ___resumeException($$2|0);
       // unreachable;
      }
      $207 = HEAP32[$165>>2]|0;
      $208 = ((($207)) + 168|0);
      $209 = HEAP32[$208>>2]|0;
      $210 = ($209|0)==($204|0);
      if ($210) {
       $$0101 = $204;
      } else {
       HEAP32[$208>>2] = $204;
       $211 = ((($204)) + 8|0);
       $212 = HEAP32[$211>>2]|0;HEAP32[$211>>2] = (($212+1)|0);
       $213 = ($209|0)==(0|0);
       if ($213) {
        $$0101 = $204;
       } else {
        $214 = ((($209)) + 8|0);
        $215 = HEAP32[$214>>2]|0;HEAP32[$214>>2] = (($215-1)|0);
        $216 = ($215|0)==(1);
        if ($216) {
         __ZNK3osg10Referenced24signalObserversAndDeleteEbb($209,1,1);
         $$0101 = $204;
        } else {
         $$0101 = $204;
        }
       }
      }
     } else {
      $$0101 = $202;
     }
     $219 = ((($$0101)) + 56|0);
     HEAP8[$219>>0] = 1;
     $220 = ((($$0101)) + 57|0);
     HEAP8[$220>>0] = 0;
     $221 = ((($$0101)) + 58|0);
     HEAP8[$221>>0] = 0;
     $222 = ((($$0101)) + 59|0);
     HEAP8[$222>>0] = 1;
     $223 = HEAP32[$150>>2]|0;
     __ZN3osg8StateSet12setAttributeEPNS_14StateAttributeEj($223,$$0101,0);
     $224 = HEAP32[$165>>2]|0;
     $225 = HEAP32[$224>>2]|0;
     $226 = ((($225)) + 172|0);
     $227 = HEAP32[$226>>2]|0;
     FUNCTION_TABLE_viii[$227 & 8191]($224,$10,$4);
     $228 = HEAP32[$176>>2]|0;
     $229 = ((($228)) + 168|0);
     $230 = HEAP32[$229>>2]|0;
     $231 = ($230|0)==(0|0);
     if ($231) {
      $232 = (__Znwj(60)|0);
      __THREW__ = 0;
      invoke_vi(3576,($232|0));
      $233 = __THREW__; __THREW__ = 0;
      $234 = $233&1;
      if ($234) {
       $245 = ___cxa_find_matching_catch_2()|0;
       $246 = tempRet0;
       __ZdlPv($232);
       $$2 = $245;$$297 = $246;
       ___resumeException($$2|0);
       // unreachable;
      }
      $235 = HEAP32[$176>>2]|0;
      $236 = ((($235)) + 168|0);
      $237 = HEAP32[$236>>2]|0;
      $238 = ($237|0)==($232|0);
      if ($238) {
       $$0100 = $232;
      } else {
       HEAP32[$236>>2] = $232;
       $239 = ((($232)) + 8|0);
       $240 = HEAP32[$239>>2]|0;HEAP32[$239>>2] = (($240+1)|0);
       $241 = ($237|0)==(0|0);
       if ($241) {
        $$0100 = $232;
       } else {
        $242 = ((($237)) + 8|0);
        $243 = HEAP32[$242>>2]|0;HEAP32[$242>>2] = (($243-1)|0);
        $244 = ($243|0)==(1);
        if ($244) {
         __ZNK3osg10Referenced24signalObserversAndDeleteEbb($237,1,1);
         $$0100 = $232;
        } else {
         $$0100 = $232;
        }
       }
      }
     } else {
      $$0100 = $230;
     }
     $247 = ((($$0100)) + 56|0);
     HEAP8[$247>>0] = 0;
     $248 = ((($$0100)) + 57|0);
     HEAP8[$248>>0] = 1;
     $249 = ((($$0100)) + 58|0);
     HEAP8[$249>>0] = 1;
     $250 = ((($$0100)) + 59|0);
     HEAP8[$250>>0] = 1;
     $251 = HEAP32[$150>>2]|0;
     __ZN3osg8StateSet12setAttributeEPNS_14StateAttributeEj($251,$$0100,0);
     $252 = HEAP32[$176>>2]|0;
     $253 = HEAP32[$252>>2]|0;
     $254 = ((($253)) + 172|0);
     $255 = HEAP32[$254>>2]|0;
     FUNCTION_TABLE_viii[$255 & 8191]($252,$10,$4);
     break L24;
     break;
    }
    case 2:  {
     $256 = HEAP32[$5>>2]|0;
     $257 = ((($256)) + 148|0);
     $258 = HEAP32[$257>>2]|0;
     $259 = $258 & 131072;
     $260 = ($259|0)==(0);
     if ($260) {
      $261 = ((($0)) + 172|0);
      $262 = HEAP32[$261>>2]|0;
      $263 = ((($256)) + 568|0);
      $264 = HEAP32[$263>>2]|0;
      $265 = ((($262)) + 148|0);
      HEAP32[$265>>2] = $264;
      $266 = ((($262)) + 152|0);
      HEAP8[$266>>0] = 1;
      $267 = ((($262)) + 156|0);
      HEAP32[$267>>2] = $264;
      $268 = ((($262)) + 160|0);
      HEAP8[$268>>0] = 1;
      $269 = ((($0)) + 188|0);
      $270 = HEAP32[$269>>2]|0;
      $271 = ((($270)) + 148|0);
      HEAP32[$271>>2] = $264;
      $272 = ((($270)) + 152|0);
      HEAP8[$272>>0] = 1;
      $273 = ((($270)) + 156|0);
      HEAP32[$273>>2] = $264;
      $274 = ((($270)) + 160|0);
      HEAP8[$274>>0] = 1;
     }
     $275 = ((($0)) + 96|0);
     $276 = HEAP32[$275>>2]|0;
     $277 = (__ZN3osg8StateSet12getAttributeENS_14StateAttribute4TypeEj($276,25,0)|0);
     $278 = ($277|0)==(0|0);
     do {
      if ($278) {
       $283 = (__Znwj(60)|0);
       __THREW__ = 0;
       invoke_vi(3339,($283|0));
       $284 = __THREW__; __THREW__ = 0;
       $285 = $284&1;
       if (!($285)) {
        HEAP32[$283>>2] = (57196);
        $286 = ((($283)) + 56|0);
        HEAP32[$286>>2] = 16843009;
        $287 = HEAP32[$275>>2]|0;
        __ZN3osg8StateSet12setAttributeEPNS_14StateAttributeEj($287,$283,0);
        $$099 = $283;
        break;
       }
       $288 = ___cxa_find_matching_catch_2()|0;
       $289 = tempRet0;
       __ZdlPv($283);
       $$2 = $288;$$297 = $289;
       ___resumeException($$2|0);
       // unreachable;
      } else {
       $279 = ((($277)) + 56|0);
       HEAP8[$279>>0] = 1;
       $280 = ((($277)) + 57|0);
       HEAP8[$280>>0] = 1;
       $281 = ((($277)) + 58|0);
       HEAP8[$281>>0] = 1;
       $282 = ((($277)) + 59|0);
       HEAP8[$282>>0] = 1;
       $$099 = $277;
      }
     } while(0);
     $290 = ((($0)) + 172|0);
     $291 = HEAP32[$290>>2]|0;
     $292 = ((($291)) + 168|0);
     $293 = HEAP32[$292>>2]|0;
     $294 = ($293|0)==($$099|0);
     if (!($294)) {
      HEAP32[$292>>2] = $$099;
      $295 = ((($$099)) + 8|0);
      $296 = HEAP32[$295>>2]|0;HEAP32[$295>>2] = (($296+1)|0);
      $297 = ($293|0)==(0|0);
      if (!($297)) {
       $298 = ((($293)) + 8|0);
       $299 = HEAP32[$298>>2]|0;HEAP32[$298>>2] = (($299-1)|0);
       $300 = ($299|0)==(1);
       if ($300) {
        __ZNK3osg10Referenced24signalObserversAndDeleteEbb($293,1,1);
       }
      }
     }
     $301 = ((($0)) + 188|0);
     $302 = HEAP32[$301>>2]|0;
     $303 = ((($302)) + 168|0);
     $304 = HEAP32[$303>>2]|0;
     $305 = ($304|0)==($$099|0);
     if (!($305)) {
      HEAP32[$303>>2] = $$099;
      $306 = ($$099|0)==(0|0);
      if (!($306)) {
       $307 = ((($$099)) + 8|0);
       $308 = HEAP32[$307>>2]|0;HEAP32[$307>>2] = (($308+1)|0);
      }
      $309 = ($304|0)==(0|0);
      if (!($309)) {
       $310 = ((($304)) + 8|0);
       $311 = HEAP32[$310>>2]|0;HEAP32[$310>>2] = (($311-1)|0);
       $312 = ($311|0)==(1);
       if ($312) {
        __ZNK3osg10Referenced24signalObserversAndDeleteEbb($304,1,1);
       }
      }
     }
     $313 = HEAP32[$275>>2]|0;
     $314 = ((($0)) + 176|0);
     $315 = HEAP32[$314>>2]|0;
     __ZN3osg8StateSet12setAttributeEPNS_14StateAttributeEj($313,$315,0);
     $316 = HEAP32[$290>>2]|0;
     $317 = HEAP32[$316>>2]|0;
     $318 = ((($317)) + 192|0);
     $319 = HEAP32[$318>>2]|0;
     FUNCTION_TABLE_viii[$319 & 8191]($316,$10,$4);
     $320 = HEAP32[$275>>2]|0;
     $321 = ((($0)) + 192|0);
     $322 = HEAP32[$321>>2]|0;
     __ZN3osg8StateSet12setAttributeEPNS_14StateAttributeEj($320,$322,0);
     $323 = HEAP32[$301>>2]|0;
     $324 = HEAP32[$323>>2]|0;
     $325 = ((($324)) + 192|0);
     $326 = HEAP32[$325>>2]|0;
     FUNCTION_TABLE_viii[$326 & 8191]($323,$10,$4);
     $327 = HEAP32[$24>>2]|0;
     $328 = ((($327)) + 44|0);
     $329 = HEAP32[$328>>2]|0;
     $330 = ($329|0)>(0);
     if ($330) {
      $331 = (+($329|0));
      $332 = HEAP32[$5>>2]|0;
      $333 = ((($332)) + 288|0);
      $334 = HEAP32[$333>>2]|0;
      $335 = ((($334)) + 72|0);
      $336 = +HEAPF64[$335>>3];
      $337 = $336 - $331;
      $338 = $337 * 0.5;
      $339 = ((($334)) + 56|0);
      $340 = +HEAPF64[$339>>3];
      $341 = $340 + $338;
      $342 = (~~(($341)));
      $343 = ((($334)) + 64|0);
      $344 = +HEAPF64[$343>>3];
      $345 = (~~(($344)));
      $346 = ((($334)) + 80|0);
      $347 = +HEAPF64[$346>>3];
      $348 = (~~(($347)));
      $349 = HEAP32[$290>>2]|0;
      $350 = ((($349)) + 172|0);
      __ZN7osgUtil9SceneView9clearAreaEiiiiRKN3osg5Vec4fE($0,$342,$345,$329,$348,$350);
     }
     $351 = HEAP32[$275>>2]|0;
     $352 = HEAP32[$314>>2]|0;
     __ZN3osg8StateSet12setAttributeEPNS_14StateAttributeEj($351,$352,0);
     $353 = HEAP32[$290>>2]|0;
     $354 = HEAP32[$353>>2]|0;
     $355 = ((($354)) + 172|0);
     $356 = HEAP32[$355>>2]|0;
     FUNCTION_TABLE_viii[$356 & 8191]($353,$10,$4);
     $357 = HEAP32[$275>>2]|0;
     $358 = HEAP32[$321>>2]|0;
     __ZN3osg8StateSet12setAttributeEPNS_14StateAttributeEj($357,$358,0);
     $359 = HEAP32[$301>>2]|0;
     $360 = HEAP32[$359>>2]|0;
     $361 = ((($360)) + 172|0);
     $362 = HEAP32[$361>>2]|0;
     FUNCTION_TABLE_viii[$362 & 8191]($359,$10,$4);
     break L24;
     break;
    }
    case 3:  {
     $363 = HEAP32[$5>>2]|0;
     $364 = ((($363)) + 148|0);
     $365 = HEAP32[$364>>2]|0;
     $366 = $365 & 131072;
     $367 = ($366|0)==(0);
     if ($367) {
      $368 = ((($0)) + 172|0);
      $369 = HEAP32[$368>>2]|0;
      $370 = ((($363)) + 568|0);
      $371 = HEAP32[$370>>2]|0;
      $372 = ((($369)) + 148|0);
      HEAP32[$372>>2] = $371;
      $373 = ((($369)) + 152|0);
      HEAP8[$373>>0] = 1;
      $374 = ((($369)) + 156|0);
      HEAP32[$374>>2] = $371;
      $375 = ((($369)) + 160|0);
      HEAP8[$375>>0] = 1;
      $376 = ((($0)) + 188|0);
      $377 = HEAP32[$376>>2]|0;
      $378 = ((($377)) + 148|0);
      HEAP32[$378>>2] = $371;
      $379 = ((($377)) + 152|0);
      HEAP8[$379>>0] = 1;
      $380 = ((($377)) + 156|0);
      HEAP32[$380>>2] = $371;
      $381 = ((($377)) + 160|0);
      HEAP8[$381>>0] = 1;
     }
     $382 = ((($0)) + 96|0);
     $383 = HEAP32[$382>>2]|0;
     $384 = (__ZN3osg8StateSet12getAttributeENS_14StateAttribute4TypeEj($383,25,0)|0);
     $385 = ($384|0)==(0|0);
     do {
      if ($385) {
       $390 = (__Znwj(60)|0);
       __THREW__ = 0;
       invoke_vi(3339,($390|0));
       $391 = __THREW__; __THREW__ = 0;
       $392 = $391&1;
       if (!($392)) {
        HEAP32[$390>>2] = (57196);
        $393 = ((($390)) + 56|0);
        HEAP32[$393>>2] = 16843009;
        $394 = HEAP32[$382>>2]|0;
        __ZN3osg8StateSet12setAttributeEPNS_14StateAttributeEj($394,$390,0);
        $$094 = $390;
        break;
       }
       $395 = ___cxa_find_matching_catch_2()|0;
       $396 = tempRet0;
       __ZdlPv($390);
       $$2 = $395;$$297 = $396;
       ___resumeException($$2|0);
       // unreachable;
      } else {
       $386 = ((($384)) + 56|0);
       HEAP8[$386>>0] = 1;
       $387 = ((($384)) + 57|0);
       HEAP8[$387>>0] = 1;
       $388 = ((($384)) + 58|0);
       HEAP8[$388>>0] = 1;
       $389 = ((($384)) + 59|0);
       HEAP8[$389>>0] = 1;
       $$094 = $384;
      }
     } while(0);
     $397 = ((($0)) + 172|0);
     $398 = HEAP32[$397>>2]|0;
     $399 = ((($398)) + 168|0);
     $400 = HEAP32[$399>>2]|0;
     $401 = ($400|0)==($$094|0);
     if (!($401)) {
      HEAP32[$399>>2] = $$094;
      $402 = ((($$094)) + 8|0);
      $403 = HEAP32[$402>>2]|0;HEAP32[$402>>2] = (($403+1)|0);
      $404 = ($400|0)==(0|0);
      if (!($404)) {
       $405 = ((($400)) + 8|0);
       $406 = HEAP32[$405>>2]|0;HEAP32[$405>>2] = (($406-1)|0);
       $407 = ($406|0)==(1);
       if ($407) {
        __ZNK3osg10Referenced24signalObserversAndDeleteEbb($400,1,1);
       }
      }
     }
     $408 = ((($0)) + 188|0);
     $409 = HEAP32[$408>>2]|0;
     $410 = ((($409)) + 168|0);
     $411 = HEAP32[$410>>2]|0;
     $412 = ($411|0)==($$094|0);
     if (!($412)) {
      HEAP32[$410>>2] = $$094;
      $413 = ($$094|0)==(0|0);
      if (!($413)) {
       $414 = ((($$094)) + 8|0);
       $415 = HEAP32[$414>>2]|0;HEAP32[$414>>2] = (($415+1)|0);
      }
      $416 = ($411|0)==(0|0);
      if (!($416)) {
       $417 = ((($411)) + 8|0);
       $418 = HEAP32[$417>>2]|0;HEAP32[$417>>2] = (($418-1)|0);
       $419 = ($418|0)==(1);
       if ($419) {
        __ZNK3osg10Referenced24signalObserversAndDeleteEbb($411,1,1);
       }
      }
     }
     $420 = HEAP32[$382>>2]|0;
     $421 = ((($0)) + 176|0);
     $422 = HEAP32[$421>>2]|0;
     __ZN3osg8StateSet12setAttributeEPNS_14StateAttributeEj($420,$422,0);
     $423 = HEAP32[$397>>2]|0;
     $424 = HEAP32[$423>>2]|0;
     $425 = ((($424)) + 192|0);
     $426 = HEAP32[$425>>2]|0;
     FUNCTION_TABLE_viii[$426 & 8191]($423,$10,$4);
     $427 = HEAP32[$382>>2]|0;
     $428 = ((($0)) + 192|0);
     $429 = HEAP32[$428>>2]|0;
     __ZN3osg8StateSet12setAttributeEPNS_14StateAttributeEj($427,$429,0);
     $430 = HEAP32[$408>>2]|0;
     $431 = HEAP32[$430>>2]|0;
     $432 = ((($431)) + 192|0);
     $433 = HEAP32[$432>>2]|0;
     FUNCTION_TABLE_viii[$433 & 8191]($430,$10,$4);
     $434 = HEAP32[$24>>2]|0;
     $435 = ((($434)) + 52|0);
     $436 = HEAP32[$435>>2]|0;
     $437 = ($436|0)>(0);
     if ($437) {
      $438 = (+($436|0));
      $439 = HEAP32[$5>>2]|0;
      $440 = ((($439)) + 288|0);
      $441 = HEAP32[$440>>2]|0;
      $442 = ((($441)) + 80|0);
      $443 = +HEAPF64[$442>>3];
      $444 = $443 - $438;
      $445 = $444 * 0.5;
      $446 = ((($441)) + 56|0);
      $447 = +HEAPF64[$446>>3];
      $448 = (~~(($447)));
      $449 = ((($441)) + 64|0);
      $450 = +HEAPF64[$449>>3];
      $451 = $450 + $445;
      $452 = (~~(($451)));
      $453 = ((($441)) + 72|0);
      $454 = +HEAPF64[$453>>3];
      $455 = (~~(($454)));
      $456 = HEAP32[$397>>2]|0;
      $457 = ((($456)) + 172|0);
      __ZN7osgUtil9SceneView9clearAreaEiiiiRKN3osg5Vec4fE($0,$448,$452,$455,$436,$457);
     }
     $458 = HEAP32[$382>>2]|0;
     $459 = HEAP32[$421>>2]|0;
     __ZN3osg8StateSet12setAttributeEPNS_14StateAttributeEj($458,$459,0);
     $460 = HEAP32[$397>>2]|0;
     $461 = HEAP32[$460>>2]|0;
     $462 = ((($461)) + 172|0);
     $463 = HEAP32[$462>>2]|0;
     FUNCTION_TABLE_viii[$463 & 8191]($460,$10,$4);
     $464 = HEAP32[$382>>2]|0;
     $465 = HEAP32[$428>>2]|0;
     __ZN3osg8StateSet12setAttributeEPNS_14StateAttributeEj($464,$465,0);
     $466 = HEAP32[$408>>2]|0;
     $467 = HEAP32[$466>>2]|0;
     $468 = ((($467)) + 172|0);
     $469 = HEAP32[$468>>2]|0;
     FUNCTION_TABLE_viii[$469 & 8191]($466,$10,$4);
     break L24;
     break;
    }
    case 4: case 5:  {
     $470 = HEAP32[$5>>2]|0;
     $471 = ((($470)) + 148|0);
     $472 = HEAP32[$471>>2]|0;
     $473 = $472 & 131072;
     $474 = ($473|0)==(0);
     if ($474) {
      $475 = ((($0)) + 156|0);
      $476 = HEAP32[$475>>2]|0;
      $477 = ((($470)) + 568|0);
      $478 = HEAP32[$477>>2]|0;
      $479 = ((($476)) + 148|0);
      HEAP32[$479>>2] = $478;
      $480 = ((($476)) + 152|0);
      HEAP8[$480>>0] = 1;
      $481 = ((($476)) + 156|0);
      HEAP32[$481>>2] = $478;
      $482 = ((($476)) + 160|0);
      HEAP8[$482>>0] = 1;
     }
     $483 = ((($0)) + 96|0);
     $484 = HEAP32[$483>>2]|0;
     $485 = (__ZN3osg8StateSet12getAttributeENS_14StateAttribute4TypeEj($484,25,0)|0);
     $486 = ($485|0)==(0|0);
     do {
      if ($486) {
       $491 = (__Znwj(60)|0);
       __THREW__ = 0;
       invoke_vi(3339,($491|0));
       $492 = __THREW__; __THREW__ = 0;
       $493 = $492&1;
       if (!($493)) {
        HEAP32[$491>>2] = (57196);
        $494 = ((($491)) + 56|0);
        HEAP32[$494>>2] = 16843009;
        $495 = HEAP32[$483>>2]|0;
        __ZN3osg8StateSet12setAttributeEPNS_14StateAttributeEj($495,$491,0);
        $$091 = $491;
        break;
       }
       $496 = ___cxa_find_matching_catch_2()|0;
       $497 = tempRet0;
       __ZdlPv($491);
       $$2 = $496;$$297 = $497;
       ___resumeException($$2|0);
       // unreachable;
      } else {
       $487 = ((($485)) + 56|0);
       HEAP8[$487>>0] = 1;
       $488 = ((($485)) + 57|0);
       HEAP8[$488>>0] = 1;
       $489 = ((($485)) + 58|0);
       HEAP8[$489>>0] = 1;
       $490 = ((($485)) + 59|0);
       HEAP8[$490>>0] = 1;
       $$091 = $485;
      }
     } while(0);
     $498 = ((($0)) + 156|0);
     $499 = HEAP32[$498>>2]|0;
     $500 = ((($499)) + 168|0);
     $501 = HEAP32[$500>>2]|0;
     $502 = ($501|0)==($$091|0);
     if (!($502)) {
      HEAP32[$500>>2] = $$091;
      $503 = ((($$091)) + 8|0);
      $504 = HEAP32[$503>>2]|0;HEAP32[$503>>2] = (($504+1)|0);
      $505 = ($501|0)==(0|0);
      if (!($505)) {
       $506 = ((($501)) + 8|0);
       $507 = HEAP32[$506>>2]|0;HEAP32[$506>>2] = (($507-1)|0);
       $508 = ($507|0)==(1);
       if ($508) {
        __ZNK3osg10Referenced24signalObserversAndDeleteEbb($501,1,1);
       }
      }
     }
     $509 = HEAP32[$498>>2]|0;
     $510 = ((($509)) + 168|0);
     $511 = HEAP32[$510>>2]|0;
     $512 = ($511|0)==($$091|0);
     if (!($512)) {
      HEAP32[$510>>2] = $$091;
      $513 = ($$091|0)==(0|0);
      if (!($513)) {
       $514 = ((($$091)) + 8|0);
       $515 = HEAP32[$514>>2]|0;HEAP32[$514>>2] = (($515+1)|0);
      }
      $516 = ($511|0)==(0|0);
      if (!($516)) {
       $517 = ((($511)) + 8|0);
       $518 = HEAP32[$517>>2]|0;HEAP32[$517>>2] = (($518-1)|0);
       $519 = ($518|0)==(1);
       if ($519) {
        __ZNK3osg10Referenced24signalObserversAndDeleteEbb($511,1,1);
       }
      }
     }
     $520 = HEAP32[$483>>2]|0;
     $521 = HEAP32[$5>>2]|0;
     $522 = ((($521)) + 288|0);
     $523 = HEAP32[$522>>2]|0;
     __ZN3osg8StateSet12setAttributeEPNS_14StateAttributeEj($520,$523,0);
     $524 = HEAP32[$498>>2]|0;
     $525 = HEAP32[$524>>2]|0;
     $526 = ((($525)) + 192|0);
     $527 = HEAP32[$526>>2]|0;
     FUNCTION_TABLE_viii[$527 & 8191]($524,$10,$4);
     $528 = HEAP32[$498>>2]|0;
     $529 = HEAP32[$528>>2]|0;
     $530 = ((($529)) + 172|0);
     $531 = HEAP32[$530>>2]|0;
     FUNCTION_TABLE_viii[$531 & 8191]($528,$10,$4);
     break L24;
     break;
    }
    case 8: case 6: case 7:  {
     $532 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
     if (!($532)) {
      break L24;
     }
     $533 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
     $534 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($533,112784,109)|0);
     $535 = HEAP32[$534>>2]|0;
     $536 = ((($535)) + -12|0);
     $537 = HEAP32[$536>>2]|0;
     $538 = (($534) + ($537)|0);
     __ZNKSt3__28ios_base6getlocEv($1,$538);
     __THREW__ = 0;
     $539 = (invoke_iii(3255,($1|0),(215188|0))|0);
     $540 = __THREW__; __THREW__ = 0;
     $541 = $540&1;
     if (!($541)) {
      $542 = HEAP32[$539>>2]|0;
      $543 = ((($542)) + 28|0);
      $544 = HEAP32[$543>>2]|0;
      __THREW__ = 0;
      $545 = (invoke_iii($544|0,($539|0),10)|0);
      $546 = __THREW__; __THREW__ = 0;
      $547 = $546&1;
      if (!($547)) {
       __ZNSt3__26localeD2Ev($1);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($534,$545)|0);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($534)|0);
       break L24;
      }
     }
     $548 = ___cxa_find_matching_catch_2()|0;
     $549 = tempRet0;
     __THREW__ = 0;
     invoke_vi(3263,($1|0));
     $550 = __THREW__; __THREW__ = 0;
     $551 = $550&1;
     if ($551) {
      $552 = ___cxa_find_matching_catch_3(0|0)|0;
      $553 = tempRet0;
      ___clang_call_terminate($552);
      // unreachable;
     } else {
      ___resumeException($548|0);
      // unreachable;
     }
     break;
    }
    default: {
     $554 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
     if (!($554)) {
      break L24;
     }
     $555 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
     $556 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($555,112894,41)|0);
     $557 = HEAP32[$556>>2]|0;
     $558 = ((($557)) + -12|0);
     $559 = HEAP32[$558>>2]|0;
     $560 = (($556) + ($559)|0);
     __ZNKSt3__28ios_base6getlocEv($2,$560);
     __THREW__ = 0;
     $561 = (invoke_iii(3255,($2|0),(215188|0))|0);
     $562 = __THREW__; __THREW__ = 0;
     $563 = $562&1;
     if (!($563)) {
      $564 = HEAP32[$561>>2]|0;
      $565 = ((($564)) + 28|0);
      $566 = HEAP32[$565>>2]|0;
      __THREW__ = 0;
      $567 = (invoke_iii($566|0,($561|0),10)|0);
      $568 = __THREW__; __THREW__ = 0;
      $569 = $568&1;
      if (!($569)) {
       __ZNSt3__26localeD2Ev($2);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($556,$567)|0);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($556)|0);
       break L24;
      }
     }
     $570 = ___cxa_find_matching_catch_2()|0;
     $571 = tempRet0;
     __THREW__ = 0;
     invoke_vi(3263,($2|0));
     $572 = __THREW__; __THREW__ = 0;
     $573 = $572&1;
     if ($573) {
      $574 = ___cxa_find_matching_catch_3(0|0)|0;
      $575 = tempRet0;
      ___clang_call_terminate($574);
      // unreachable;
     } else {
      ___resumeException($570|0);
      // unreachable;
     }
    }
    }
   }
  }
 } while(0);
 if ((label|0) == 140) {
  $576 = HEAP32[$5>>2]|0;
  $577 = ((($576)) + 148|0);
  $578 = HEAP32[$577>>2]|0;
  $579 = $578 & 131072;
  $580 = ($579|0)==(0);
  if ($580) {
   $581 = ((($0)) + 156|0);
   $582 = HEAP32[$581>>2]|0;
   $583 = ((($576)) + 568|0);
   $584 = HEAP32[$583>>2]|0;
   $585 = ((($582)) + 148|0);
   HEAP32[$585>>2] = $584;
   $586 = ((($582)) + 152|0);
   HEAP8[$586>>0] = 1;
   $587 = ((($582)) + 156|0);
   HEAP32[$587>>2] = $584;
   $588 = ((($582)) + 160|0);
   HEAP8[$588>>0] = 1;
  }
  $589 = $578 & 262144;
  $590 = ($589|0)==(0);
  if ($590) {
   $591 = ((($0)) + 156|0);
   $592 = HEAP32[$591>>2]|0;
   $593 = ((($576)) + 572|0);
   $594 = HEAP32[$593>>2]|0;
   $595 = ((($592)) + 156|0);
   HEAP32[$595>>2] = $594;
   $596 = ((($592)) + 160|0);
   HEAP8[$596>>0] = 1;
  }
  $597 = ((($0)) + 96|0);
  $598 = HEAP32[$597>>2]|0;
  $599 = ((($576)) + 288|0);
  $600 = HEAP32[$599>>2]|0;
  __ZN3osg8StateSet12setAttributeEPNS_14StateAttributeEj($598,$600,0);
  $601 = ((($0)) + 288|0);
  $602 = HEAP8[$601>>0]|0;
  $603 = ($602<<24>>24)==(0);
  if ($603) {
   $$pre = ((($0)) + 156|0);
   $$pre$phiZ2D = $$pre;
  } else {
   $604 = HEAP32[$597>>2]|0;
   $605 = (__ZN3osg8StateSet12getAttributeENS_14StateAttribute4TypeEj($604,25,0)|0);
   $606 = ($605|0)==(0|0);
   do {
    if ($606) {
     $611 = (__Znwj(60)|0);
     __THREW__ = 0;
     invoke_vi(3339,($611|0));
     $612 = __THREW__; __THREW__ = 0;
     $613 = $612&1;
     if (!($613)) {
      HEAP32[$611>>2] = (57196);
      $614 = ((($611)) + 56|0);
      HEAP32[$614>>2] = 16843009;
      $615 = HEAP32[$597>>2]|0;
      __ZN3osg8StateSet12setAttributeEPNS_14StateAttributeEj($615,$611,0);
      $$0 = $611;
      break;
     }
     $616 = ___cxa_find_matching_catch_2()|0;
     $617 = tempRet0;
     __ZdlPv($611);
     $$2 = $616;$$297 = $617;
     ___resumeException($$2|0);
     // unreachable;
    } else {
     $607 = ((($605)) + 56|0);
     HEAP8[$607>>0] = 1;
     $608 = ((($605)) + 57|0);
     HEAP8[$608>>0] = 1;
     $609 = ((($605)) + 58|0);
     HEAP8[$609>>0] = 1;
     $610 = ((($605)) + 59|0);
     HEAP8[$610>>0] = 1;
     $$0 = $605;
    }
   } while(0);
   $618 = ((($0)) + 156|0);
   $619 = HEAP32[$618>>2]|0;
   $620 = ((($619)) + 168|0);
   $621 = HEAP32[$620>>2]|0;
   $622 = ($621|0)==($$0|0);
   if ($622) {
    $$pre$phiZ2D = $618;
   } else {
    HEAP32[$620>>2] = $$0;
    $623 = ((($$0)) + 8|0);
    $624 = HEAP32[$623>>2]|0;HEAP32[$623>>2] = (($624+1)|0);
    $625 = ($621|0)==(0|0);
    if ($625) {
     $$pre$phiZ2D = $618;
    } else {
     $626 = ((($621)) + 8|0);
     $627 = HEAP32[$626>>2]|0;HEAP32[$626>>2] = (($627-1)|0);
     $628 = ($627|0)==(1);
     if ($628) {
      __ZNK3osg10Referenced24signalObserversAndDeleteEbb($621,1,1);
      $$pre$phiZ2D = $618;
     } else {
      $$pre$phiZ2D = $618;
     }
    }
   }
  }
  $629 = HEAP32[$$pre$phiZ2D>>2]|0;
  $630 = HEAP32[$629>>2]|0;
  $631 = ((($630)) + 192|0);
  $632 = HEAP32[$631>>2]|0;
  FUNCTION_TABLE_viii[$632 & 8191]($629,$10,$4);
  $633 = HEAP32[$$pre$phiZ2D>>2]|0;
  $634 = HEAP32[$633>>2]|0;
  $635 = ((($634)) + 172|0);
  $636 = HEAP32[$635>>2]|0;
  FUNCTION_TABLE_viii[$636 & 8191]($633,$10,$4);
 }
 __ZN3osg5State15popAllStateSetsEv($11);
 __ZN3osg5State5applyEv($11);
 $637 = ((($11)) + 344|0);
 $638 = HEAP32[$637>>2]|0;
 $639 = ($638|0)==(0);
 if (!($639)) {
  $640 = (__ZNK3osg5State13checkGLErrorsEPKcS2_($11,112936,0)|0);
  if ($640) {
   HEAP32[$637>>2] = 2;
  }
 }
 STACKTOP = sp;return;
}
function __ZN7osgUtil9SceneView19releaseAllGLObjectsEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 204|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  return;
 }
 $4 = ((($2)) + 24|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  return;
 }
 $7 = ((($0)) + 208|0);
 $8 = HEAP32[$7>>2]|0;
 $phitmp$i = ($8|0)==(0|0);
 if ($phitmp$i) {
  return;
 }
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($9)) + 136|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($0)) + 100|0);
 $13 = HEAP32[$12>>2]|0;
 FUNCTION_TABLE_vii[$11 & 8191]($8,$13);
 return;
}
function __ZN7osgUtil9SceneView24flushAllDeletedGLObjectsEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 246|0);
 HEAP8[$1>>0] = 0;
 $2 = ((($0)) + 100|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + 124|0);
 $5 = HEAP32[$4>>2]|0;
 __ZN3osg24flushAllDeletedGLObjectsEj($5);
 return;
}
function __ZN7osgUtil9SceneView21flushDeletedGLObjectsERd($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0.0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 100|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 246|0);
 HEAP8[$4>>0] = 0;
 $5 = ((($3)) + 160|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $12 = 0.0;
 } else {
  $8 = ((($6)) + 16|0);
  $9 = +HEAPF64[$8>>3];
  $12 = $9;
 }
 $10 = ((($3)) + 124|0);
 $11 = HEAP32[$10>>2]|0;
 __ZN3osg21flushDeletedGLObjectsEjdRd($11,$12,$1);
 return;
}
function __ZN7osgUtil9SceneView9cullStageERKN3osg7MatrixdES4_PNS_11CullVisitorEPNS_10StateGraphEPNS_11RenderStageEPNS1_8ViewportE($0,$1,$2,$3,$4,$5,$6) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 var $$ = 0, $$$i$i = 0, $$0 = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i$i = 0, $$054 = 0, $$055 = 0, $$152 = 0, $$2 = 0, $$257 = 0, $$3 = 0, $$358 = 0, $$in2$i$i = 0, $$not = 0, $$pr = 0, $$pr$i$i = 0, $$pr150 = 0, $$pre = 0, $$pre$i = 0, $$pre$i100 = 0;
 var $$pre$i89 = 0, $$pre151 = 0, $$sink$i = 0, $$sink$i88 = 0, $$sink$i99 = 0, $10 = 0, $100 = 0, $101 = 0.0, $102 = 0, $103 = 0, $104 = 0.0, $105 = 0, $106 = 0, $107 = 0.0, $108 = 0, $109 = 0, $11 = 0, $110 = 0.0, $111 = 0, $112 = 0;
 var $113 = 0.0, $114 = 0, $115 = 0, $116 = 0.0, $117 = 0, $118 = 0, $119 = 0.0, $12 = 0, $120 = 0, $121 = 0, $122 = 0.0, $123 = 0, $124 = 0, $125 = 0.0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0;
 var $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0;
 var $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0.0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0;
 var $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0;
 var $259 = 0, $26 = 0.0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0;
 var $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0.0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0;
 var $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0;
 var $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0.0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0;
 var $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0;
 var $35 = 0.0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0;
 var $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0.0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0;
 var $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0;
 var $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0.0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0;
 var $422 = 0, $423 = 0, $424 = 0, $425 = 0.0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0.0;
 var $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0;
 var $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0.0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0;
 var $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0;
 var $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $50 = 0.0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0;
 var $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0.0, $530 = 0;
 var $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0;
 var $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0.0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0;
 var $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0;
 var $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0.0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0;
 var $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0.0, $620 = 0, $621 = 0;
 var $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0;
 var $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0.0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0;
 var $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0;
 var $677 = 0, $678 = 0, $679 = 0, $68 = 0.0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0;
 var $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0;
 var $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0;
 var $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0;
 var $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0;
 var $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0;
 var $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = 0.0, $800 = 0, $801 = 0;
 var $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0;
 var $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0.0, $830 = 0, $831 = 0, $832 = 0, $833 = 0, $834 = 0, $835 = 0, $836 = 0, $837 = 0, $838 = 0;
 var $839 = 0, $84 = 0, $840 = 0, $841 = 0, $85 = 0, $86 = 0.0, $87 = 0, $88 = 0, $89 = 0.0, $9 = 0, $90 = 0, $91 = 0, $92 = 0.0, $93 = 0, $94 = 0, $95 = 0.0, $96 = 0, $97 = 0, $98 = 0.0, $99 = 0;
 var $eh$lpad$body$index3Z2D = 0, $eh$lpad$body$indexZ2D = 0, $or$cond = 0, $or$cond$i = 0, $or$cond$i69 = 0, $or$cond$i73 = 0, $or$cond$i80 = 0, $or$cond$i85 = 0, $or$cond$i96 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $7 = sp;
 $8 = ((($0)) + 204|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if ($10) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $11 = ((($9)) + 24|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0|0);
 if ($13) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $14 = ((($0)) + 208|0);
 $15 = HEAP32[$14>>2]|0;
 $$not = ($15|0)!=(0|0);
 $16 = ($6|0)!=(0|0);
 $or$cond = $16 & $$not;
 if (!($or$cond)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $17 = (__Znwj(160)|0);
 __THREW__ = 0;
 invoke_vii(3435,($17|0),0);
 $18 = __THREW__; __THREW__ = 0;
 $19 = $18&1;
 if ($19) {
  $159 = ___cxa_find_matching_catch_2()|0;
  $160 = tempRet0;
  __ZdlPv($17);
  $$3 = $159;$$358 = $160;
  ___resumeException($$3|0);
  // unreachable;
 }
 $20 = ((($17)) + 12|0);
 ;HEAP32[$20>>2]=0|0;HEAP32[$20+4>>2]=0|0;HEAP32[$20+8>>2]=0|0;
 $21 = ((($17)) + 24|0);
 HEAP32[$21>>2] = 2;
 $22 = ((($17)) + 28|0);
 HEAP32[$22>>2] = 0;
 $23 = +HEAPF64[$1>>3];
 $24 = ((($17)) + 32|0);
 HEAPF64[$24>>3] = $23;
 $25 = ((($1)) + 8|0);
 $26 = +HEAPF64[$25>>3];
 $27 = ((($17)) + 40|0);
 HEAPF64[$27>>3] = $26;
 $28 = ((($1)) + 16|0);
 $29 = +HEAPF64[$28>>3];
 $30 = ((($17)) + 48|0);
 HEAPF64[$30>>3] = $29;
 $31 = ((($1)) + 24|0);
 $32 = +HEAPF64[$31>>3];
 $33 = ((($17)) + 56|0);
 HEAPF64[$33>>3] = $32;
 $34 = ((($1)) + 32|0);
 $35 = +HEAPF64[$34>>3];
 $36 = ((($17)) + 64|0);
 HEAPF64[$36>>3] = $35;
 $37 = ((($1)) + 40|0);
 $38 = +HEAPF64[$37>>3];
 $39 = ((($17)) + 72|0);
 HEAPF64[$39>>3] = $38;
 $40 = ((($1)) + 48|0);
 $41 = +HEAPF64[$40>>3];
 $42 = ((($17)) + 80|0);
 HEAPF64[$42>>3] = $41;
 $43 = ((($1)) + 56|0);
 $44 = +HEAPF64[$43>>3];
 $45 = ((($17)) + 88|0);
 HEAPF64[$45>>3] = $44;
 $46 = ((($1)) + 64|0);
 $47 = +HEAPF64[$46>>3];
 $48 = ((($17)) + 96|0);
 HEAPF64[$48>>3] = $47;
 $49 = ((($1)) + 72|0);
 $50 = +HEAPF64[$49>>3];
 $51 = ((($17)) + 104|0);
 HEAPF64[$51>>3] = $50;
 $52 = ((($1)) + 80|0);
 $53 = +HEAPF64[$52>>3];
 $54 = ((($17)) + 112|0);
 HEAPF64[$54>>3] = $53;
 $55 = ((($1)) + 88|0);
 $56 = +HEAPF64[$55>>3];
 $57 = ((($17)) + 120|0);
 HEAPF64[$57>>3] = $56;
 $58 = ((($1)) + 96|0);
 $59 = +HEAPF64[$58>>3];
 $60 = ((($17)) + 128|0);
 HEAPF64[$60>>3] = $59;
 $61 = ((($1)) + 104|0);
 $62 = +HEAPF64[$61>>3];
 $63 = ((($17)) + 136|0);
 HEAPF64[$63>>3] = $62;
 $64 = ((($1)) + 112|0);
 $65 = +HEAPF64[$64>>3];
 $66 = ((($17)) + 144|0);
 HEAPF64[$66>>3] = $65;
 $67 = ((($1)) + 120|0);
 $68 = +HEAPF64[$67>>3];
 $69 = ((($17)) + 152|0);
 HEAPF64[$69>>3] = $68;
 HEAP32[$17>>2] = (47588);
 $70 = ((($17)) + 8|0);
 $71 = HEAP32[$70>>2]|0;HEAP32[$70>>2] = (($71+1)|0);
 __THREW__ = 0;
 $72 = (invoke_ii(3276,160)|0);
 $73 = __THREW__; __THREW__ = 0;
 $74 = $73&1;
 L14: do {
  if ($74) {
   $161 = ___cxa_find_matching_catch_2()|0;
   $162 = tempRet0;
   $$2 = $161;$$257 = $162;
  } else {
   __THREW__ = 0;
   invoke_vii(3435,($72|0),0);
   $75 = __THREW__; __THREW__ = 0;
   $76 = $75&1;
   if ($76) {
    $163 = ___cxa_find_matching_catch_2()|0;
    $164 = tempRet0;
    __ZdlPv($72);
    $$2 = $163;$$257 = $164;
    break;
   }
   $77 = ((($72)) + 12|0);
   ;HEAP32[$77>>2]=0|0;HEAP32[$77+4>>2]=0|0;HEAP32[$77+8>>2]=0|0;
   $78 = ((($72)) + 24|0);
   HEAP32[$78>>2] = 2;
   $79 = ((($72)) + 28|0);
   HEAP32[$79>>2] = 0;
   $80 = +HEAPF64[$2>>3];
   $81 = ((($72)) + 32|0);
   HEAPF64[$81>>3] = $80;
   $82 = ((($2)) + 8|0);
   $83 = +HEAPF64[$82>>3];
   $84 = ((($72)) + 40|0);
   HEAPF64[$84>>3] = $83;
   $85 = ((($2)) + 16|0);
   $86 = +HEAPF64[$85>>3];
   $87 = ((($72)) + 48|0);
   HEAPF64[$87>>3] = $86;
   $88 = ((($2)) + 24|0);
   $89 = +HEAPF64[$88>>3];
   $90 = ((($72)) + 56|0);
   HEAPF64[$90>>3] = $89;
   $91 = ((($2)) + 32|0);
   $92 = +HEAPF64[$91>>3];
   $93 = ((($72)) + 64|0);
   HEAPF64[$93>>3] = $92;
   $94 = ((($2)) + 40|0);
   $95 = +HEAPF64[$94>>3];
   $96 = ((($72)) + 72|0);
   HEAPF64[$96>>3] = $95;
   $97 = ((($2)) + 48|0);
   $98 = +HEAPF64[$97>>3];
   $99 = ((($72)) + 80|0);
   HEAPF64[$99>>3] = $98;
   $100 = ((($2)) + 56|0);
   $101 = +HEAPF64[$100>>3];
   $102 = ((($72)) + 88|0);
   HEAPF64[$102>>3] = $101;
   $103 = ((($2)) + 64|0);
   $104 = +HEAPF64[$103>>3];
   $105 = ((($72)) + 96|0);
   HEAPF64[$105>>3] = $104;
   $106 = ((($2)) + 72|0);
   $107 = +HEAPF64[$106>>3];
   $108 = ((($72)) + 104|0);
   HEAPF64[$108>>3] = $107;
   $109 = ((($2)) + 80|0);
   $110 = +HEAPF64[$109>>3];
   $111 = ((($72)) + 112|0);
   HEAPF64[$111>>3] = $110;
   $112 = ((($2)) + 88|0);
   $113 = +HEAPF64[$112>>3];
   $114 = ((($72)) + 120|0);
   HEAPF64[$114>>3] = $113;
   $115 = ((($2)) + 96|0);
   $116 = +HEAPF64[$115>>3];
   $117 = ((($72)) + 128|0);
   HEAPF64[$117>>3] = $116;
   $118 = ((($2)) + 104|0);
   $119 = +HEAPF64[$118>>3];
   $120 = ((($72)) + 136|0);
   HEAPF64[$120>>3] = $119;
   $121 = ((($2)) + 112|0);
   $122 = +HEAPF64[$121>>3];
   $123 = ((($72)) + 144|0);
   HEAPF64[$123>>3] = $122;
   $124 = ((($2)) + 120|0);
   $125 = +HEAPF64[$124>>3];
   $126 = ((($72)) + 152|0);
   HEAPF64[$126>>3] = $125;
   HEAP32[$72>>2] = (47588);
   $127 = ((($72)) + 8|0);
   $128 = HEAP32[$127>>2]|0;HEAP32[$127>>2] = (($128+1)|0);
   $129 = HEAP32[$14>>2]|0;
   __THREW__ = 0;
   $130 = (invoke_ii(3577,($129|0))|0);
   $131 = __THREW__; __THREW__ = 0;
   $132 = $131&1;
   L20: do {
    if ($132) {
     label = 20;
    } else {
     L22: do {
      if ($130) {
       $133 = ((($0)) + 196|0);
       $134 = HEAP32[$133>>2]|0;
       $135 = ($134|0)==(0|0);
       if ($135) {
        __THREW__ = 0;
        $136 = (invoke_ii(3276,432)|0);
        $137 = __THREW__; __THREW__ = 0;
        $138 = $137&1;
        if ($138) {
         label = 20;
         break L20;
        }
        __THREW__ = 0;
        invoke_vi(3578,($136|0));
        $139 = __THREW__; __THREW__ = 0;
        $140 = $139&1;
        if ($140) {
         $169 = ___cxa_find_matching_catch_2()|0;
         $170 = tempRet0;
         __ZdlPv($136);
         $$054 = $169;$$055 = $170;
         break L20;
        }
        $141 = HEAP32[$133>>2]|0;
        $142 = ($141|0)==($136|0);
        if (!($142)) {
         HEAP32[$133>>2] = $136;
         $143 = HEAP32[$136>>2]|0;
         $144 = ((($143)) + -12|0);
         $145 = HEAP32[$144>>2]|0;
         $146 = (($136) + ($145)|0);
         $147 = ((($146)) + 8|0);
         $148 = HEAP32[$147>>2]|0;HEAP32[$147>>2] = (($148+1)|0);
         $149 = ($141|0)==(0|0);
         if (!($149)) {
          $150 = HEAP32[$141>>2]|0;
          $151 = ((($150)) + -12|0);
          $152 = HEAP32[$151>>2]|0;
          $153 = (($141) + ($152)|0);
          $154 = ((($153)) + 8|0);
          $155 = HEAP32[$154>>2]|0;HEAP32[$154>>2] = (($155-1)|0);
          $156 = ($155|0)==(1);
          if ($156) {
           __THREW__ = 0;
           invoke_viii(3262,($153|0),1,1);
           $157 = __THREW__; __THREW__ = 0;
           $158 = $157&1;
           if ($158) {
            label = 20;
            break L20;
           }
          }
         }
        }
       }
       $171 = HEAP32[$133>>2]|0;
       $172 = ((($171)) + 56|0);
       $173 = HEAP32[$172>>2]|0;
       $174 = ((($173)) + 12|0);
       $175 = HEAP32[$174>>2]|0;
       $176 = ((($0)) + 32|0);
       __THREW__ = 0;
       invoke_vii($175|0,($172|0),($176|0));
       $177 = __THREW__; __THREW__ = 0;
       $178 = $177&1;
       if ($178) {
        label = 20;
        break L20;
       }
       $179 = HEAP32[$133>>2]|0;
       $180 = HEAP32[$179>>2]|0;
       $181 = ((($180)) + 76|0);
       $182 = HEAP32[$181>>2]|0;
       __THREW__ = 0;
       invoke_vi($182|0,($179|0));
       $183 = __THREW__; __THREW__ = 0;
       $184 = $183&1;
       if ($184) {
        label = 20;
        break L20;
       }
       $185 = HEAP32[$133>>2]|0;
       $186 = ((($0)) + 200|0);
       $187 = HEAP32[$186>>2]|0;
       $188 = ((($185)) + 12|0);
       $189 = HEAP32[$188>>2]|0;
       $190 = ($189|0)==($187|0);
       if ($190) {
        $200 = $187;
       } else {
        HEAP32[$188>>2] = $187;
        $191 = ($187|0)==(0|0);
        if (!($191)) {
         $192 = ((($187)) + 8|0);
         $193 = HEAP32[$192>>2]|0;HEAP32[$192>>2] = (($193+1)|0);
        }
        $194 = ($189|0)==(0|0);
        if (!($194)) {
         $195 = ((($189)) + 8|0);
         $196 = HEAP32[$195>>2]|0;HEAP32[$195>>2] = (($196-1)|0);
         $197 = ($196|0)==(1);
         if ($197) {
          __THREW__ = 0;
          invoke_viii(3262,($189|0),1,1);
          $198 = __THREW__; __THREW__ = 0;
          $199 = $198&1;
          if ($199) {
           label = 20;
           break L20;
          }
         }
        }
        $$pr = HEAP32[$186>>2]|0;
        $200 = $$pr;
       }
       $201 = ($200|0)==(0|0);
       if ($201) {
        $$pre = HEAP32[$133>>2]|0;
        $207 = $$pre;
       } else {
        $202 = HEAP32[$133>>2]|0;
        $203 = ((($200)) + 12|0);
        $204 = HEAP32[$203>>2]|0;
        $205 = ((($202)) + 8|0);
        HEAP32[$205>>2] = $204;
        $207 = $202;
       }
       $206 = ((($207)) + 56|0);
       __THREW__ = 0;
       invoke_vii(3579,($206|0),($6|0));
       $208 = __THREW__; __THREW__ = 0;
       $209 = $208&1;
       if ($209) {
        label = 20;
        break L20;
       }
       $210 = HEAP32[$133>>2]|0;
       $211 = ((($210)) + 56|0);
       __THREW__ = 0;
       invoke_vii(3580,($211|0),($17|0));
       $212 = __THREW__; __THREW__ = 0;
       $213 = $212&1;
       if ($213) {
        label = 20;
        break L20;
       }
       $214 = HEAP32[$133>>2]|0;
       $215 = ((($214)) + 56|0);
       __THREW__ = 0;
       invoke_viii(3581,($215|0),($72|0),1);
       $216 = __THREW__; __THREW__ = 0;
       $217 = $216&1;
       if ($217) {
        label = 20;
        break L20;
       }
       $218 = HEAP32[$133>>2]|0;
       $219 = HEAP32[$14>>2]|0;
       $220 = ((($218)) + 16|0);
       $221 = HEAP32[$220>>2]|0;
       switch ($221|0) {
       case 1:  {
        $222 = HEAP32[$219>>2]|0;
        $223 = ((($222)) + 192|0);
        $224 = HEAP32[$223>>2]|0;
        __THREW__ = 0;
        invoke_vii($224|0,($219|0),($218|0));
        $225 = __THREW__; __THREW__ = 0;
        $226 = $225&1;
        if ($226) {
         label = 20;
         break L20;
        }
        break;
       }
       case 0:  {
        break;
       }
       default: {
        $227 = HEAP32[$219>>2]|0;
        $228 = ((($227)) + 196|0);
        $229 = HEAP32[$228>>2]|0;
        __THREW__ = 0;
        invoke_vii($229|0,($219|0),($218|0));
        $230 = __THREW__; __THREW__ = 0;
        $231 = $230&1;
        if ($231) {
         label = 20;
         break L20;
        }
       }
       }
       $232 = HEAP32[$133>>2]|0;
       $233 = ((($232)) + 56|0);
       __THREW__ = 0;
       invoke_vi(3582,($233|0));
       $234 = __THREW__; __THREW__ = 0;
       $235 = $234&1;
       if ($235) {
        label = 20;
        break L20;
       }
       $236 = HEAP32[$133>>2]|0;
       $237 = ((($236)) + 56|0);
       __THREW__ = 0;
       invoke_vi(3583,($237|0));
       $238 = __THREW__; __THREW__ = 0;
       $239 = $238&1;
       if ($239) {
        label = 20;
        break L20;
       }
       $240 = HEAP32[$133>>2]|0;
       $241 = ((($240)) + 56|0);
       __THREW__ = 0;
       invoke_vi(3584,($241|0));
       $242 = __THREW__; __THREW__ = 0;
       $243 = $242&1;
       if ($243) {
        label = 20;
        break L20;
       }
       $244 = HEAP32[$133>>2]|0;
       __THREW__ = 0;
       invoke_vi(3585,($244|0));
       $245 = __THREW__; __THREW__ = 0;
       $246 = $245&1;
       if ($246) {
        label = 20;
        break L20;
       }
       __THREW__ = 0;
       $247 = (invoke_ii(3265,5)|0);
       $248 = __THREW__; __THREW__ = 0;
       $249 = $248&1;
       if ($249) {
        label = 20;
        break L20;
       }
       L62: do {
        if ($247) {
         __THREW__ = 0;
         $250 = (invoke_ii(3266,5)|0);
         $251 = __THREW__; __THREW__ = 0;
         $252 = $251&1;
         if ($252) {
          label = 20;
          break L20;
         }
         __THREW__ = 0;
         $253 = (invoke_iiii(3267,($250|0),(112720|0),40)|0);
         $254 = __THREW__; __THREW__ = 0;
         $255 = $254&1;
         if ($255) {
          label = 20;
          break L20;
         }
         $256 = HEAP32[$133>>2]|0;
         $257 = ((($256)) + 392|0);
         $258 = HEAP32[$257>>2]|0;
         __THREW__ = 0;
         $259 = (invoke_iii(3417,($253|0),($258|0))|0);
         $260 = __THREW__; __THREW__ = 0;
         $261 = $260&1;
         if ($261) {
          label = 20;
          break L20;
         }
         $262 = HEAP32[$259>>2]|0;
         $263 = ((($262)) + -12|0);
         $264 = HEAP32[$263>>2]|0;
         $265 = (($259) + ($264)|0);
         __THREW__ = 0;
         invoke_vii(3257,($7|0),($265|0));
         $266 = __THREW__; __THREW__ = 0;
         $267 = $266&1;
         if ($267) {
          label = 20;
          break L20;
         }
         __THREW__ = 0;
         $268 = (invoke_iii(3255,($7|0),(215188|0))|0);
         $269 = __THREW__; __THREW__ = 0;
         $270 = $269&1;
         do {
          if (!($270)) {
           $271 = HEAP32[$268>>2]|0;
           $272 = ((($271)) + 28|0);
           $273 = HEAP32[$272>>2]|0;
           __THREW__ = 0;
           $274 = (invoke_iii($273|0,($268|0),10)|0);
           $275 = __THREW__; __THREW__ = 0;
           $276 = $275&1;
           if ($276) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3263,($7|0));
           $283 = __THREW__; __THREW__ = 0;
           $284 = $283&1;
           if ($284) {
            label = 20;
            break L20;
           }
           __THREW__ = 0;
           (invoke_iii(3268,($259|0),($274|0))|0);
           $285 = __THREW__; __THREW__ = 0;
           $286 = $285&1;
           if ($286) {
            label = 20;
            break L20;
           }
           __THREW__ = 0;
           (invoke_ii(3269,($259|0))|0);
           $287 = __THREW__; __THREW__ = 0;
           $288 = $287&1;
           if ($288) {
            label = 20;
            break L20;
           } else {
            break L62;
           }
          }
         } while(0);
         $277 = ___cxa_find_matching_catch_2()|0;
         $278 = tempRet0;
         __THREW__ = 0;
         invoke_vi(3263,($7|0));
         $279 = __THREW__; __THREW__ = 0;
         $280 = $279&1;
         if ($280) {
          $281 = ___cxa_find_matching_catch_3(0|0)|0;
          $282 = tempRet0;
          ___clang_call_terminate($281);
          // unreachable;
         } else {
          $eh$lpad$body$index3Z2D = $278;$eh$lpad$body$indexZ2D = $277;
          label = 21;
          break L20;
         }
        }
       } while(0);
       $289 = ((($3)) + 120|0);
       $290 = HEAP32[$289>>2]|0;
       $291 = ((($3)) + 124|0);
       while(1) {
        $292 = HEAP32[$291>>2]|0;
        $293 = ($292|0)==($290|0);
        if ($293) {
         break;
        }
        $294 = ((($292)) + -80|0);
        HEAP32[$291>>2] = $294;
        __THREW__ = 0;
        invoke_vi(3586,($294|0));
        $295 = __THREW__; __THREW__ = 0;
        $296 = $295&1;
        if ($296) {
         label = 62;
         break;
        }
       }
       if ((label|0) == 62) {
        $297 = ___cxa_find_matching_catch_2()|0;
        $298 = tempRet0;
        ___cxa_call_unexpected(($297|0));
        // unreachable;
       }
       $299 = HEAP32[$133>>2]|0;
       $300 = ((($299)) + 384|0);
       $301 = HEAP32[$300>>2]|0;
       $302 = ((($299)) + 388|0);
       $303 = ($301|0)==($302|0);
       if ($303) {
        break;
       }
       $304 = ((($3)) + 128|0);
       $$in2$i$i = $301;$307 = $290;
       while(1) {
        $305 = ((($$in2$i$i)) + 16|0);
        $306 = HEAP32[$304>>2]|0;
        $308 = ($307|0)==($306|0);
        if ($308) {
         __THREW__ = 0;
         invoke_vii(3588,($289|0),($305|0));
         $313 = __THREW__; __THREW__ = 0;
         $314 = $313&1;
         if ($314) {
          break;
         }
        } else {
         __THREW__ = 0;
         invoke_vii(3587,($307|0),($305|0));
         $309 = __THREW__; __THREW__ = 0;
         $310 = $309&1;
         if ($310) {
          break;
         }
         $311 = HEAP32[$291>>2]|0;
         $312 = ((($311)) + 80|0);
         HEAP32[$291>>2] = $312;
        }
        $315 = ((($$in2$i$i)) + 4|0);
        $316 = HEAP32[$315>>2]|0;
        $317 = ($316|0)==(0|0);
        do {
         if ($317) {
          $318 = ((($$in2$i$i)) + 8|0);
          $319 = HEAP32[$318>>2]|0;
          $320 = HEAP32[$319>>2]|0;
          $321 = ($320|0)==($$in2$i$i|0);
          if ($321) {
           $$0$i$i$i$i = $319;
           break;
          } else {
           $325 = $318;
          }
          while(1) {
           $324 = HEAP32[$325>>2]|0;
           $326 = ((($324)) + 8|0);
           $327 = HEAP32[$326>>2]|0;
           $328 = HEAP32[$327>>2]|0;
           $329 = ($328|0)==($324|0);
           if ($329) {
            $$0$i$i$i$i = $327;
            break;
           } else {
            $325 = $326;
           }
          }
         } else {
          $$0$i$i$i$i$i = $316;
          while(1) {
           $322 = HEAP32[$$0$i$i$i$i$i>>2]|0;
           $323 = ($322|0)==(0|0);
           if ($323) {
            break;
           } else {
            $$0$i$i$i$i$i = $322;
           }
          }
          $$0$i$i$i$i = $$0$i$i$i$i$i;
         }
        } while(0);
        $330 = ($$0$i$i$i$i|0)==($302|0);
        if ($330) {
         break L22;
        }
        $$pre151 = HEAP32[$291>>2]|0;
        $$in2$i$i = $$0$i$i$i$i;$307 = $$pre151;
       }
       $165 = ___cxa_find_matching_catch_2()|0;
       $166 = tempRet0;
       $eh$lpad$body$index3Z2D = $166;$eh$lpad$body$indexZ2D = $165;
       label = 21;
       break L20;
      }
     } while(0);
     $331 = HEAP32[$3>>2]|0;
     $332 = ((($331)) + 76|0);
     $333 = HEAP32[$332>>2]|0;
     __THREW__ = 0;
     invoke_vi($333|0,($3|0));
     $334 = __THREW__; __THREW__ = 0;
     $335 = $334&1;
     if ($335) {
      label = 20;
     } else {
      $336 = ((($0)) + 200|0);
      $337 = HEAP32[$336>>2]|0;
      $338 = ((($3)) + 12|0);
      $339 = HEAP32[$338>>2]|0;
      $340 = ($339|0)==($337|0);
      if ($340) {
       $350 = $337;
      } else {
       HEAP32[$338>>2] = $337;
       $341 = ($337|0)==(0|0);
       if (!($341)) {
        $342 = ((($337)) + 8|0);
        $343 = HEAP32[$342>>2]|0;HEAP32[$342>>2] = (($343+1)|0);
       }
       $344 = ($339|0)==(0|0);
       if (!($344)) {
        $345 = ((($339)) + 8|0);
        $346 = HEAP32[$345>>2]|0;HEAP32[$345>>2] = (($346-1)|0);
        $347 = ($346|0)==(1);
        if ($347) {
         __THREW__ = 0;
         invoke_viii(3262,($339|0),1,1);
         $348 = __THREW__; __THREW__ = 0;
         $349 = $348&1;
         if ($349) {
          label = 20;
          break;
         }
        }
       }
       $$pr150 = HEAP32[$336>>2]|0;
       $350 = $$pr150;
      }
      $351 = ($350|0)==(0|0);
      if (!($351)) {
       $352 = ((($350)) + 12|0);
       $353 = HEAP32[$352>>2]|0;
       $354 = ((($3)) + 8|0);
       HEAP32[$354>>2] = $353;
      }
      $355 = ((($3)) + 56|0);
      $356 = HEAP32[$355>>2]|0;
      $357 = ((($356)) + 12|0);
      $358 = HEAP32[$357>>2]|0;
      $359 = ((($0)) + 32|0);
      __THREW__ = 0;
      invoke_vii($358|0,($355|0),($359|0));
      $360 = __THREW__; __THREW__ = 0;
      $361 = $360&1;
      if ($361) {
       label = 20;
      } else {
       $362 = ((($3)) + 372|0);
       $363 = HEAP32[$362>>2]|0;
       $364 = ($363|0)==($4|0);
       if (!($364)) {
        HEAP32[$362>>2] = $4;
        $365 = ($4|0)==(0|0);
        if (!($365)) {
         $366 = ((($4)) + 8|0);
         $367 = HEAP32[$366>>2]|0;HEAP32[$366>>2] = (($367+1)|0);
        }
        $368 = ($363|0)==(0|0);
        if (!($368)) {
         $369 = ((($363)) + 8|0);
         $370 = HEAP32[$369>>2]|0;HEAP32[$369>>2] = (($370-1)|0);
         $371 = ($370|0)==(1);
         if ($371) {
          __THREW__ = 0;
          invoke_viii(3262,($363|0),1,1);
          $372 = __THREW__; __THREW__ = 0;
          $373 = $372&1;
          if ($373) {
           label = 20;
           break;
          }
         }
        }
       }
       $374 = ((($3)) + 376|0);
       HEAP32[$374>>2] = $4;
       $375 = ((($3)) + 380|0);
       $376 = HEAP32[$375>>2]|0;
       $377 = ($376|0)==($5|0);
       if (!($377)) {
        HEAP32[$375>>2] = $5;
        $378 = ($5|0)==(0|0);
        if (!($378)) {
         $379 = ((($5)) + 8|0);
         $380 = HEAP32[$379>>2]|0;HEAP32[$379>>2] = (($380+1)|0);
        }
        $381 = ($376|0)==(0|0);
        if (!($381)) {
         $382 = ((($376)) + 8|0);
         $383 = HEAP32[$382>>2]|0;HEAP32[$382>>2] = (($383-1)|0);
         $384 = ($383|0)==(1);
         if ($384) {
          __THREW__ = 0;
          invoke_viii(3262,($376|0),1,1);
          $385 = __THREW__; __THREW__ = 0;
          $386 = $385&1;
          if ($386) {
           label = 20;
           break;
          }
         }
        }
       }
       $387 = ((($3)) + 384|0);
       HEAP32[$387>>2] = $5;
       $388 = ((($0)) + 100|0);
       $389 = ((($3)) + 444|0);
       __THREW__ = 0;
       (invoke_iii(3589,($389|0),($388|0))|0);
       $390 = __THREW__; __THREW__ = 0;
       $391 = $390&1;
       if ($391) {
        label = 20;
       } else {
        $392 = HEAP32[$5>>2]|0;
        $393 = ((($392)) + 140|0);
        $394 = HEAP32[$393>>2]|0;
        __THREW__ = 0;
        invoke_vi($394|0,($5|0));
        $395 = __THREW__; __THREW__ = 0;
        $396 = $395&1;
        if ($396) {
         label = 20;
        } else {
         __THREW__ = 0;
         invoke_vi(3590,($4|0));
         $397 = __THREW__; __THREW__ = 0;
         $398 = $397&1;
         if ($398) {
          label = 20;
         } else {
          $399 = ((($5)) + 144|0);
          $400 = HEAP32[$399>>2]|0;
          $401 = ($400|0)==($72|0);
          do {
           if (!($401)) {
            HEAP32[$399>>2] = $72;
            $402 = HEAP32[$127>>2]|0;HEAP32[$127>>2] = (($402+1)|0);
            $403 = ($400|0)==(0|0);
            if ($403) {
             break;
            }
            $404 = ((($400)) + 8|0);
            $405 = HEAP32[$404>>2]|0;HEAP32[$404>>2] = (($405-1)|0);
            $406 = ($405|0)==(1);
            if (!($406)) {
             break;
            }
            __THREW__ = 0;
            invoke_viii(3262,($400|0),1,1);
            $407 = __THREW__; __THREW__ = 0;
            $408 = $407&1;
            if ($408) {
             label = 20;
             break L20;
            }
           }
          } while(0);
          $409 = ((($5)) + 140|0);
          $410 = HEAP32[$409>>2]|0;
          $411 = ($410|0)==($6|0);
          do {
           if (!($411)) {
            HEAP32[$409>>2] = $6;
            $412 = ((($6)) + 8|0);
            $413 = HEAP32[$412>>2]|0;HEAP32[$412>>2] = (($413+1)|0);
            $414 = ($410|0)==(0|0);
            if ($414) {
             break;
            }
            $415 = ((($410)) + 8|0);
            $416 = HEAP32[$415>>2]|0;HEAP32[$415>>2] = (($416-1)|0);
            $417 = ($416|0)==(1);
            if (!($417)) {
             break;
            }
            __THREW__ = 0;
            invoke_viii(3262,($410|0),1,1);
            $418 = __THREW__; __THREW__ = 0;
            $419 = $418&1;
            if ($419) {
             label = 20;
             break L20;
            }
           }
          } while(0);
          $420 = HEAP32[$14>>2]|0;
          $421 = ((($420)) + 240|0);
          $422 = ((($5)) + 172|0);
          ;HEAP32[$422>>2]=HEAP32[$421>>2]|0;HEAP32[$422+4>>2]=HEAP32[$421+4>>2]|0;HEAP32[$422+8>>2]=HEAP32[$421+8>>2]|0;HEAP32[$422+12>>2]=HEAP32[$421+12>>2]|0;
          $423 = HEAP32[$14>>2]|0;
          $424 = ((($423)) + 272|0);
          $425 = +HEAPF64[$424>>3];
          $426 = ((($5)) + 208|0);
          HEAPF64[$426>>3] = $425;
          $427 = ((($423)) + 256|0);
          $428 = ((($5)) + 188|0);
          ;HEAP32[$428>>2]=HEAP32[$427>>2]|0;HEAP32[$428+4>>2]=HEAP32[$427+4>>2]|0;HEAP32[$428+8>>2]=HEAP32[$427+8>>2]|0;HEAP32[$428+12>>2]=HEAP32[$427+12>>2]|0;
          $429 = HEAP32[$14>>2]|0;
          $430 = ((($429)) + 280|0);
          $431 = HEAP32[$430>>2]|0;
          $432 = ((($5)) + 216|0);
          HEAP32[$432>>2] = $431;
          $433 = ((($429)) + 236|0);
          $434 = HEAP32[$433>>2]|0;
          $435 = ((($5)) + 164|0);
          HEAP32[$435>>2] = $434;
          $436 = HEAP32[$8>>2]|0;
          $437 = ($436|0)==(0|0);
          if ($437) {
           $444 = 0;
          } else {
           $438 = ((($436)) + 24|0);
           $439 = HEAP32[$438>>2]|0;
           $440 = ($439|0)==(0|0);
           $$152 = $440 ? 0 : $429;
           $444 = $$152;
          }
          $441 = ((($5)) + 232|0);
          $442 = HEAP32[$441>>2]|0;
          $443 = ($442|0)==($444|0);
          if (!($443)) {
           $445 = ($444|0)==(0|0);
           if ($445) {
            $452 = 0;
           } else {
            __THREW__ = 0;
            $446 = (invoke_ii(3325,($444|0))|0);
            $447 = __THREW__; __THREW__ = 0;
            $448 = $447&1;
            if ($448) {
             label = 20;
             break;
            } else {
             $452 = $446;
            }
           }
           $449 = ((($5)) + 228|0);
           $450 = HEAP32[$449>>2]|0;
           $451 = ($450|0)==($452|0);
           if ($451) {
            $462 = $452;
           } else {
            HEAP32[$449>>2] = $452;
            $453 = ($452|0)==(0|0);
            if (!($453)) {
             $454 = ((($452)) + 8|0);
             $455 = HEAP32[$454>>2]|0;HEAP32[$454>>2] = (($455+1)|0);
            }
            $456 = ($450|0)==(0|0);
            do {
             if (!($456)) {
              $457 = ((($450)) + 8|0);
              $458 = HEAP32[$457>>2]|0;HEAP32[$457>>2] = (($458-1)|0);
              $459 = ($458|0)==(1);
              if (!($459)) {
               break;
              }
              __THREW__ = 0;
              invoke_viii(3262,($450|0),1,1);
              $460 = __THREW__; __THREW__ = 0;
              $461 = $460&1;
              if ($461) {
               label = 20;
               break L20;
              }
             }
            } while(0);
            $$pr$i$i = HEAP32[$449>>2]|0;
            $462 = $$pr$i$i;
           }
           $463 = ($462|0)==(0|0);
           if ($463) {
            $467 = 0;
           } else {
            $464 = ((($462)) + 24|0);
            $465 = HEAP32[$464>>2]|0;
            $466 = ($465|0)!=(0|0);
            $$$i$i = $466 ? $444 : 0;
            $467 = $$$i$i;
           }
           HEAP32[$441>>2] = $467;
           $468 = ((($5)) + 220|0);
           HEAP8[$468>>0] = 1;
          }
          $469 = ((($0)) + 216|0);
          $470 = HEAP32[$469>>2]|0;
          $471 = ($470|0)==(0|0);
          do {
           if (!($471)) {
            $472 = HEAP32[$374>>2]|0;
            __THREW__ = 0;
            $473 = (invoke_iii(3591,($472|0),($470|0))|0);
            $474 = __THREW__; __THREW__ = 0;
            $475 = $474&1;
            if ($475) {
             label = 20;
             break L20;
            }
            HEAP32[$374>>2] = $473;
            $476 = ((($470)) + 120|0);
            $477 = HEAP32[$476>>2]|0;
            $478 = ($477|0)==(0);
            if ($478) {
             break;
            }
            $479 = ((($470)) + 128|0);
            $480 = ((($479)) + 11|0);
            $481 = HEAP8[$480>>0]|0;
            $482 = ($481<<24>>24)<(0);
            if ($482) {
             $483 = ((($470)) + 132|0);
             $484 = HEAP32[$483>>2]|0;
             $486 = $484;
            } else {
             $485 = $481&255;
             $486 = $485;
            }
            $487 = ($486|0)==(0);
            do {
             if ($487) {
              $516 = $477;
             } else {
              $488 = ((($3)) + 440|0);
              $489 = HEAP32[$488>>2]|0;
              $490 = ($489|0)!=(0);
              $491 = $477 & 4;
              $492 = ($491|0)==(0);
              $or$cond$i96 = $492 & $490;
              if ($or$cond$i96) {
               $516 = $477;
               break;
              }
              $493 = ((($3)) + 392|0);
              $494 = HEAP32[$493>>2]|0;
              $495 = ((($3)) + 396|0);
              $496 = HEAP32[$495>>2]|0;
              $497 = ($494|0)==($496|0);
              if ($497) {
               $501 = ((($3)) + 388|0);
               __THREW__ = 0;
               invoke_vii(3592,($501|0),($387|0));
               $502 = __THREW__; __THREW__ = 0;
               $503 = $502&1;
               if ($503) {
                label = 20;
                break L20;
               }
              } else {
               $498 = HEAP32[$387>>2]|0;
               HEAP32[$494>>2] = $498;
               $499 = HEAP32[$493>>2]|0;
               $500 = ((($499)) + 4|0);
               HEAP32[$493>>2] = $500;
              }
              $504 = ((($470)) + 140|0);
              $505 = HEAP8[$504>>0]|0;
              $506 = ($505<<24>>24)==(0);
              $507 = HEAP32[$387>>2]|0;
              if ($506) {
               $508 = ((($507)) + 40|0);
               $509 = HEAP32[$508>>2]|0;
               $$sink$i99 = $509;
              } else {
               $$sink$i99 = $507;
              }
              $510 = ((($470)) + 124|0);
              $511 = HEAP32[$510>>2]|0;
              __THREW__ = 0;
              $512 = (invoke_iiii(3593,($$sink$i99|0),($511|0),($479|0))|0);
              $513 = __THREW__; __THREW__ = 0;
              $514 = $513&1;
              if ($514) {
               label = 20;
               break L20;
              }
              HEAP32[$387>>2] = $512;
              $$pre$i100 = HEAP32[$476>>2]|0;
              $516 = $$pre$i100;
             }
            } while(0);
            $515 = $516 & 2;
            $517 = ($515|0)==(0);
            if ($517) {
             break;
            }
            $518 = ((($3)) + 440|0);
            $519 = HEAP32[$518>>2]|0;
            $520 = (($519) + 1)|0;
            HEAP32[$518>>2] = $520;
           }
          } while(0);
          $521 = ((($0)) + 228|0);
          $522 = HEAP32[$521>>2]|0;
          $523 = ($522|0)==(0|0);
          do {
           if (!($523)) {
            $524 = HEAP32[$374>>2]|0;
            __THREW__ = 0;
            $525 = (invoke_iii(3591,($524|0),($522|0))|0);
            $526 = __THREW__; __THREW__ = 0;
            $527 = $526&1;
            if ($527) {
             label = 20;
             break L20;
            }
            HEAP32[$374>>2] = $525;
            $528 = ((($522)) + 120|0);
            $529 = HEAP32[$528>>2]|0;
            $530 = ($529|0)==(0);
            if ($530) {
             break;
            }
            $531 = ((($522)) + 128|0);
            $532 = ((($531)) + 11|0);
            $533 = HEAP8[$532>>0]|0;
            $534 = ($533<<24>>24)<(0);
            if ($534) {
             $535 = ((($522)) + 132|0);
             $536 = HEAP32[$535>>2]|0;
             $538 = $536;
            } else {
             $537 = $533&255;
             $538 = $537;
            }
            $539 = ($538|0)==(0);
            do {
             if ($539) {
              $568 = $529;
             } else {
              $540 = ((($3)) + 440|0);
              $541 = HEAP32[$540>>2]|0;
              $542 = ($541|0)!=(0);
              $543 = $529 & 4;
              $544 = ($543|0)==(0);
              $or$cond$i85 = $544 & $542;
              if ($or$cond$i85) {
               $568 = $529;
               break;
              }
              $545 = ((($3)) + 392|0);
              $546 = HEAP32[$545>>2]|0;
              $547 = ((($3)) + 396|0);
              $548 = HEAP32[$547>>2]|0;
              $549 = ($546|0)==($548|0);
              if ($549) {
               $553 = ((($3)) + 388|0);
               __THREW__ = 0;
               invoke_vii(3592,($553|0),($387|0));
               $554 = __THREW__; __THREW__ = 0;
               $555 = $554&1;
               if ($555) {
                label = 20;
                break L20;
               }
              } else {
               $550 = HEAP32[$387>>2]|0;
               HEAP32[$546>>2] = $550;
               $551 = HEAP32[$545>>2]|0;
               $552 = ((($551)) + 4|0);
               HEAP32[$545>>2] = $552;
              }
              $556 = ((($522)) + 140|0);
              $557 = HEAP8[$556>>0]|0;
              $558 = ($557<<24>>24)==(0);
              $559 = HEAP32[$387>>2]|0;
              if ($558) {
               $560 = ((($559)) + 40|0);
               $561 = HEAP32[$560>>2]|0;
               $$sink$i88 = $561;
              } else {
               $$sink$i88 = $559;
              }
              $562 = ((($522)) + 124|0);
              $563 = HEAP32[$562>>2]|0;
              __THREW__ = 0;
              $564 = (invoke_iiii(3593,($$sink$i88|0),($563|0),($531|0))|0);
              $565 = __THREW__; __THREW__ = 0;
              $566 = $565&1;
              if ($566) {
               label = 20;
               break L20;
              }
              HEAP32[$387>>2] = $564;
              $$pre$i89 = HEAP32[$528>>2]|0;
              $568 = $$pre$i89;
             }
            } while(0);
            $567 = $568 & 2;
            $569 = ($567|0)==(0);
            if ($569) {
             break;
            }
            $570 = ((($3)) + 440|0);
            $571 = HEAP32[$570>>2]|0;
            $572 = (($571) + 1)|0;
            HEAP32[$570>>2] = $572;
           }
          } while(0);
          $573 = ((($0)) + 96|0);
          $574 = HEAP32[$573>>2]|0;
          $575 = ($574|0)==(0|0);
          do {
           if (!($575)) {
            $576 = HEAP32[$374>>2]|0;
            __THREW__ = 0;
            $577 = (invoke_iii(3591,($576|0),($574|0))|0);
            $578 = __THREW__; __THREW__ = 0;
            $579 = $578&1;
            if ($579) {
             label = 20;
             break L20;
            }
            HEAP32[$374>>2] = $577;
            $580 = ((($574)) + 120|0);
            $581 = HEAP32[$580>>2]|0;
            $582 = ($581|0)==(0);
            if ($582) {
             break;
            }
            $583 = ((($574)) + 128|0);
            $584 = ((($583)) + 11|0);
            $585 = HEAP8[$584>>0]|0;
            $586 = ($585<<24>>24)<(0);
            if ($586) {
             $587 = ((($574)) + 132|0);
             $588 = HEAP32[$587>>2]|0;
             $590 = $588;
            } else {
             $589 = $585&255;
             $590 = $589;
            }
            $591 = ($590|0)==(0);
            do {
             if ($591) {
              $620 = $581;
             } else {
              $592 = ((($3)) + 440|0);
              $593 = HEAP32[$592>>2]|0;
              $594 = ($593|0)!=(0);
              $595 = $581 & 4;
              $596 = ($595|0)==(0);
              $or$cond$i80 = $596 & $594;
              if ($or$cond$i80) {
               $620 = $581;
               break;
              }
              $597 = ((($3)) + 392|0);
              $598 = HEAP32[$597>>2]|0;
              $599 = ((($3)) + 396|0);
              $600 = HEAP32[$599>>2]|0;
              $601 = ($598|0)==($600|0);
              if ($601) {
               $605 = ((($3)) + 388|0);
               __THREW__ = 0;
               invoke_vii(3592,($605|0),($387|0));
               $606 = __THREW__; __THREW__ = 0;
               $607 = $606&1;
               if ($607) {
                label = 20;
                break L20;
               }
              } else {
               $602 = HEAP32[$387>>2]|0;
               HEAP32[$598>>2] = $602;
               $603 = HEAP32[$597>>2]|0;
               $604 = ((($603)) + 4|0);
               HEAP32[$597>>2] = $604;
              }
              $608 = ((($574)) + 140|0);
              $609 = HEAP8[$608>>0]|0;
              $610 = ($609<<24>>24)==(0);
              $611 = HEAP32[$387>>2]|0;
              if ($610) {
               $612 = ((($611)) + 40|0);
               $613 = HEAP32[$612>>2]|0;
               $$sink$i = $613;
              } else {
               $$sink$i = $611;
              }
              $614 = ((($574)) + 124|0);
              $615 = HEAP32[$614>>2]|0;
              __THREW__ = 0;
              $616 = (invoke_iiii(3593,($$sink$i|0),($615|0),($583|0))|0);
              $617 = __THREW__; __THREW__ = 0;
              $618 = $617&1;
              if ($618) {
               label = 20;
               break L20;
              }
              HEAP32[$387>>2] = $616;
              $$pre$i = HEAP32[$580>>2]|0;
              $620 = $$pre$i;
             }
            } while(0);
            $619 = $620 & 2;
            $621 = ($619|0)==(0);
            if ($621) {
             break;
            }
            $622 = ((($3)) + 440|0);
            $623 = HEAP32[$622>>2]|0;
            $624 = (($623) + 1)|0;
            HEAP32[$622>>2] = $624;
           }
          } while(0);
          __THREW__ = 0;
          invoke_vii(3579,($355|0),($6|0));
          $625 = __THREW__; __THREW__ = 0;
          $626 = $625&1;
          if ($626) {
           label = 20;
           break;
          }
          __THREW__ = 0;
          invoke_vii(3580,($355|0),($17|0));
          $627 = __THREW__; __THREW__ = 0;
          $628 = $627&1;
          if ($628) {
           label = 20;
           break;
          }
          __THREW__ = 0;
          invoke_viii(3581,($355|0),($72|0),1);
          $629 = __THREW__; __THREW__ = 0;
          $630 = $629&1;
          if ($630) {
           label = 20;
           break;
          }
          $631 = HEAP32[$14>>2]|0;
          $632 = ((($631)) + 100|0);
          $633 = HEAP32[$632>>2]|0;
          $634 = ($633|0)==(0|0);
          L238: do {
           if ($634) {
            $654 = ((($3)) + 16|0);
            $655 = HEAP32[$654>>2]|0;
            switch ($655|0) {
            case 0:  {
             break L238;
             break;
            }
            case 1:  {
             $656 = HEAP32[$631>>2]|0;
             $657 = ((($656)) + 192|0);
             $658 = HEAP32[$657>>2]|0;
             __THREW__ = 0;
             invoke_vii($658|0,($631|0),($3|0));
             $659 = __THREW__; __THREW__ = 0;
             $660 = $659&1;
             if ($660) {
              label = 185;
              break L238;
             } else {
              break L238;
             }
             break;
            }
            default: {
             $661 = HEAP32[$631>>2]|0;
             $662 = ((($661)) + 196|0);
             $663 = HEAP32[$662>>2]|0;
             __THREW__ = 0;
             invoke_vii($663|0,($631|0),($3|0));
             $664 = __THREW__; __THREW__ = 0;
             $665 = $664&1;
             if ($665) {
              label = 185;
              break L238;
             } else {
              break L238;
             }
            }
            }
           } else {
            $635 = HEAP32[$633>>2]|0;
            $636 = ((($635)) + 92|0);
            $637 = HEAP32[$636>>2]|0;
            $638 = HEAP32[$8>>2]|0;
            $639 = ($638|0)==(0|0);
            if ($639) {
             $648 = 0;
            } else {
             $640 = ((($638)) + 24|0);
             $641 = HEAP32[$640>>2]|0;
             $642 = ($641|0)==(0|0);
             $$ = $642 ? 0 : $631;
             $648 = $$;
            }
            $643 = ($3|0)==(0|0);
            if ($643) {
             $649 = 0;
            } else {
             $644 = HEAP32[$3>>2]|0;
             $645 = ((($644)) + -12|0);
             $646 = HEAP32[$645>>2]|0;
             $647 = (($3) + ($646)|0);
             $649 = $647;
            }
            __THREW__ = 0;
            (invoke_iiii($637|0,($633|0),($648|0),($649|0))|0);
            $650 = __THREW__; __THREW__ = 0;
            $651 = $650&1;
            if ($651) {
             label = 185;
            }
           }
          } while(0);
          if ((label|0) == 185) {
           $652 = ___cxa_find_matching_catch_2()|0;
           $653 = tempRet0;
           $$054 = $652;$$055 = $653;
           break;
          }
          __THREW__ = 0;
          invoke_vi(3582,($355|0));
          $666 = __THREW__; __THREW__ = 0;
          $667 = $666&1;
          if ($667) {
           label = 20;
           break;
          }
          $668 = HEAP32[$3>>2]|0;
          $669 = ((($668)) + 204|0);
          $670 = HEAP32[$669>>2]|0;
          __THREW__ = 0;
          invoke_vi($670|0,($3|0));
          $671 = __THREW__; __THREW__ = 0;
          $672 = $671&1;
          if ($672) {
           label = 20;
           break;
          }
          __THREW__ = 0;
          invoke_vi(3584,($355|0));
          $673 = __THREW__; __THREW__ = 0;
          $674 = $673&1;
          if ($674) {
           label = 20;
           break;
          }
          $675 = HEAP32[$573>>2]|0;
          $676 = ($675|0)==(0|0);
          if (!($676)) {
           $677 = HEAP32[$374>>2]|0;
           $678 = ((($677)) + 16|0);
           $679 = HEAP32[$678>>2]|0;
           $680 = ((($679)) + 120|0);
           $681 = HEAP32[$680>>2]|0;
           $682 = $681 & 2;
           $683 = ($682|0)==(0);
           if (!($683)) {
            $684 = ((($3)) + 440|0);
            $685 = HEAP32[$684>>2]|0;
            $686 = (($685) + -1)|0;
            HEAP32[$684>>2] = $686;
           }
           $687 = ($681|0)==(0);
           do {
            if (!($687)) {
             $688 = ((($679)) + 128|0);
             $689 = ((($688)) + 11|0);
             $690 = HEAP8[$689>>0]|0;
             $691 = ($690<<24>>24)<(0);
             if ($691) {
              $692 = ((($679)) + 132|0);
              $693 = HEAP32[$692>>2]|0;
              $695 = $693;
             } else {
              $694 = $690&255;
              $695 = $694;
             }
             $696 = ($695|0)==(0);
             if ($696) {
              break;
             }
             $697 = ((($3)) + 440|0);
             $698 = HEAP32[$697>>2]|0;
             $699 = ($698|0)!=(0);
             $700 = $681 & 4;
             $701 = ($700|0)==(0);
             $or$cond$i73 = $701 & $699;
             if ($or$cond$i73) {
              break;
             }
             $702 = ((($3)) + 388|0);
             $703 = HEAP32[$702>>2]|0;
             $704 = ((($3)) + 392|0);
             $705 = HEAP32[$704>>2]|0;
             $706 = ($703|0)==($705|0);
             if ($706) {
              $707 = HEAP32[$387>>2]|0;
              $708 = ((($707)) + 40|0);
              $709 = HEAP32[$708>>2]|0;
              HEAP32[$387>>2] = $709;
              break;
             } else {
              $710 = ((($705)) + -4|0);
              $711 = HEAP32[$710>>2]|0;
              HEAP32[$387>>2] = $711;
              HEAP32[$704>>2] = $710;
              break;
             }
            }
           } while(0);
           $712 = ((($677)) + 12|0);
           $713 = HEAP32[$712>>2]|0;
           HEAP32[$374>>2] = $713;
          }
          $714 = HEAP32[$521>>2]|0;
          $715 = ($714|0)==(0|0);
          if (!($715)) {
           $716 = HEAP32[$374>>2]|0;
           $717 = ((($716)) + 16|0);
           $718 = HEAP32[$717>>2]|0;
           $719 = ((($718)) + 120|0);
           $720 = HEAP32[$719>>2]|0;
           $721 = $720 & 2;
           $722 = ($721|0)==(0);
           if (!($722)) {
            $723 = ((($3)) + 440|0);
            $724 = HEAP32[$723>>2]|0;
            $725 = (($724) + -1)|0;
            HEAP32[$723>>2] = $725;
           }
           $726 = ($720|0)==(0);
           do {
            if (!($726)) {
             $727 = ((($718)) + 128|0);
             $728 = ((($727)) + 11|0);
             $729 = HEAP8[$728>>0]|0;
             $730 = ($729<<24>>24)<(0);
             if ($730) {
              $731 = ((($718)) + 132|0);
              $732 = HEAP32[$731>>2]|0;
              $734 = $732;
             } else {
              $733 = $729&255;
              $734 = $733;
             }
             $735 = ($734|0)==(0);
             if ($735) {
              break;
             }
             $736 = ((($3)) + 440|0);
             $737 = HEAP32[$736>>2]|0;
             $738 = ($737|0)!=(0);
             $739 = $720 & 4;
             $740 = ($739|0)==(0);
             $or$cond$i69 = $740 & $738;
             if ($or$cond$i69) {
              break;
             }
             $741 = ((($3)) + 388|0);
             $742 = HEAP32[$741>>2]|0;
             $743 = ((($3)) + 392|0);
             $744 = HEAP32[$743>>2]|0;
             $745 = ($742|0)==($744|0);
             if ($745) {
              $746 = HEAP32[$387>>2]|0;
              $747 = ((($746)) + 40|0);
              $748 = HEAP32[$747>>2]|0;
              HEAP32[$387>>2] = $748;
              break;
             } else {
              $749 = ((($744)) + -4|0);
              $750 = HEAP32[$749>>2]|0;
              HEAP32[$387>>2] = $750;
              HEAP32[$743>>2] = $749;
              break;
             }
            }
           } while(0);
           $751 = ((($716)) + 12|0);
           $752 = HEAP32[$751>>2]|0;
           HEAP32[$374>>2] = $752;
          }
          $753 = HEAP32[$469>>2]|0;
          $754 = ($753|0)==(0|0);
          if (!($754)) {
           $755 = HEAP32[$374>>2]|0;
           $756 = ((($755)) + 16|0);
           $757 = HEAP32[$756>>2]|0;
           $758 = ((($757)) + 120|0);
           $759 = HEAP32[$758>>2]|0;
           $760 = $759 & 2;
           $761 = ($760|0)==(0);
           if (!($761)) {
            $762 = ((($3)) + 440|0);
            $763 = HEAP32[$762>>2]|0;
            $764 = (($763) + -1)|0;
            HEAP32[$762>>2] = $764;
           }
           $765 = ($759|0)==(0);
           do {
            if (!($765)) {
             $766 = ((($757)) + 128|0);
             $767 = ((($766)) + 11|0);
             $768 = HEAP8[$767>>0]|0;
             $769 = ($768<<24>>24)<(0);
             if ($769) {
              $770 = ((($757)) + 132|0);
              $771 = HEAP32[$770>>2]|0;
              $773 = $771;
             } else {
              $772 = $768&255;
              $773 = $772;
             }
             $774 = ($773|0)==(0);
             if ($774) {
              break;
             }
             $775 = ((($3)) + 440|0);
             $776 = HEAP32[$775>>2]|0;
             $777 = ($776|0)!=(0);
             $778 = $759 & 4;
             $779 = ($778|0)==(0);
             $or$cond$i = $779 & $777;
             if ($or$cond$i) {
              break;
             }
             $780 = ((($3)) + 388|0);
             $781 = HEAP32[$780>>2]|0;
             $782 = ((($3)) + 392|0);
             $783 = HEAP32[$782>>2]|0;
             $784 = ($781|0)==($783|0);
             if ($784) {
              $785 = HEAP32[$387>>2]|0;
              $786 = ((($785)) + 40|0);
              $787 = HEAP32[$786>>2]|0;
              HEAP32[$387>>2] = $787;
              break;
             } else {
              $788 = ((($783)) + -4|0);
              $789 = HEAP32[$788>>2]|0;
              HEAP32[$387>>2] = $789;
              HEAP32[$782>>2] = $788;
              break;
             }
            }
           } while(0);
           $790 = ((($755)) + 12|0);
           $791 = HEAP32[$790>>2]|0;
           HEAP32[$374>>2] = $791;
          }
          $792 = HEAP32[$5>>2]|0;
          $793 = ((($792)) + 144|0);
          $794 = HEAP32[$793>>2]|0;
          __THREW__ = 0;
          invoke_vi($794|0,($5|0));
          $795 = __THREW__; __THREW__ = 0;
          $796 = $795&1;
          if ($796) {
           label = 20;
           break;
          }
          __THREW__ = 0;
          invoke_vi(3594,($4|0));
          $797 = __THREW__; __THREW__ = 0;
          $798 = $797&1;
          if ($798) {
           label = 20;
           break;
          }
          $799 = HEAP32[$5>>2]|0;
          $800 = ((($799)) + 180|0);
          $801 = HEAP32[$800>>2]|0;
          __THREW__ = 0;
          $802 = (invoke_ii($801|0,($5|0))|0);
          $803 = __THREW__; __THREW__ = 0;
          $804 = $803&1;
          if ($804) {
           label = 20;
           break;
          }
          $805 = ((($0)) + 284|0);
          $806 = HEAP32[$805>>2]|0;
          $807 = (($806) + ($802))|0;
          HEAP32[$805>>2] = $807;
          $808 = ((($3)) + 68|0);
          $809 = HEAP32[$808>>2]|0;
          $810 = ($809|0)==(0);
          do {
           if ($810) {
            $841 = 0;
           } else {
            $811 = HEAP32[$14>>2]|0;
            $812 = HEAP32[$811>>2]|0;
            $813 = ((($812)) + 224|0);
            $814 = HEAP32[$813>>2]|0;
            __THREW__ = 0;
            $815 = (invoke_ii($814|0,($811|0))|0);
            $816 = __THREW__; __THREW__ = 0;
            $817 = $816&1;
            if ($817) {
             label = 20;
             break L20;
            }
            $818 = ($815|0)==(0);
            if ($818) {
             $841 = 0;
             break;
            }
            $819 = HEAP32[$14>>2]|0;
            $820 = ((($819)) + 124|0);
            $821 = HEAP32[$820>>2]|0;
            $822 = HEAP32[$821>>2]|0;
            $phitmp = ($822|0)!=(0|0);
            $841 = $phitmp;
           }
          } while(0);
          $823 = HEAP32[$127>>2]|0;HEAP32[$127>>2] = (($823-1)|0);
          $824 = ($823|0)==(1);
          do {
           if ($824) {
            __THREW__ = 0;
            invoke_viii(3262,($72|0),1,1);
            $825 = __THREW__; __THREW__ = 0;
            $826 = $825&1;
            if (!($826)) {
             break;
            }
            $829 = ___cxa_find_matching_catch_2()|0;
            $830 = tempRet0;
            $$2 = $829;$$257 = $830;
            break L14;
           }
          } while(0);
          $827 = HEAP32[$70>>2]|0;HEAP32[$70>>2] = (($827-1)|0);
          $828 = ($827|0)==(1);
          if (!($828)) {
           $$0 = $841;
           STACKTOP = sp;return ($$0|0);
          }
          __ZNK3osg10Referenced24signalObserversAndDeleteEbb($17,1,1);
          $$0 = $841;
          STACKTOP = sp;return ($$0|0);
         }
        }
       }
      }
     }
    }
   } while(0);
   if ((label|0) == 20) {
    $167 = ___cxa_find_matching_catch_2()|0;
    $168 = tempRet0;
    $eh$lpad$body$index3Z2D = $168;$eh$lpad$body$indexZ2D = $167;
    label = 21;
   }
   if ((label|0) == 21) {
    $$054 = $eh$lpad$body$indexZ2D;$$055 = $eh$lpad$body$index3Z2D;
   }
   $831 = HEAP32[$127>>2]|0;HEAP32[$127>>2] = (($831-1)|0);
   $832 = ($831|0)==(1);
   if ($832) {
    __THREW__ = 0;
    invoke_viii(3262,($72|0),1,1);
    $833 = __THREW__; __THREW__ = 0;
    $834 = $833&1;
    if ($834) {
     $839 = ___cxa_find_matching_catch_3(0|0)|0;
     $840 = tempRet0;
     ___clang_call_terminate($839);
     // unreachable;
    } else {
     $$2 = $$054;$$257 = $$055;
    }
   } else {
    $$2 = $$054;$$257 = $$055;
   }
  }
 } while(0);
 $835 = HEAP32[$70>>2]|0;HEAP32[$70>>2] = (($835-1)|0);
 $836 = ($835|0)==(1);
 if (!($836)) {
  $$3 = $$2;$$358 = $$257;
  ___resumeException($$3|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(3262,($17|0),1,1);
 $837 = __THREW__; __THREW__ = 0;
 $838 = $837&1;
 if ($838) {
  $839 = ___cxa_find_matching_catch_3(0|0)|0;
  $840 = tempRet0;
  ___clang_call_terminate($839);
  // unreachable;
 } else {
  $$3 = $$2;$$358 = $$257;
  ___resumeException($$3|0);
  // unreachable;
 }
 return (0)|0;
}
function __ZThn32_N7osgUtil9SceneViewD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -32|0);
 __ZN7osgUtil9SceneViewD2Ev($1);
 return;
}
function __ZThn32_N7osgUtil9SceneViewD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -32|0);
 __THREW__ = 0;
 invoke_vi(1072,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch_2()|0;
  $5 = tempRet0;
  __ZdlPv($1);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZdlPv($1);
  return;
 }
}
function __ZThn32_N7osgUtil9SceneView11setDefaultsEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -32|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 144|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 8191]($1,29);
 return;
}
function __ZThn32_N7osgUtil9SceneView19inheritCullSettingsERKN3osg12CullSettingsE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + -32|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + 168|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($2)) + 36|0);
 $7 = HEAP32[$6>>2]|0;
 FUNCTION_TABLE_viii[$5 & 8191]($2,$1,$7);
 return;
}
function __ZThn32_N7osgUtil9SceneView19inheritCullSettingsERKN3osg12CullSettingsEj($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + -32|0);
 __ZN7osgUtil9SceneView19inheritCullSettingsERKN3osg12CullSettingsEj($3,$1,$2);
 return;
}
function __ZN3osg20ShadowVolumeOccluderD2Ev($0) {
 $0 = $0|0;
 var $$1 = 0, $$13 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $12 = 0;
 var $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i14 = 0, $scevgep$i$i$i$i4 = 0;
 var $scevgep$i$i$i21 = 0, $scevgep$i$i$i3$i = 0, $scevgep$i$i$i3$i9 = 0, $scevgep5$i$i$i = 0, $scevgep5$i$i$i$i = 0, $scevgep5$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i15 = 0, $scevgep5$i$i$i$i5 = 0, $scevgep5$i$i$i22 = 0, $scevgep5$i$i$i4$i = 0, $scevgep5$i$i$i4$i10 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 68|0);
 __THREW__ = 0;
 invoke_vi(3595,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if ($3) {
   $56 = ___cxa_find_matching_catch_2()|0;
   $57 = tempRet0;
   $58 = ((($0)) + 56|0);
   $59 = HEAP32[$58>>2]|0;
   $60 = ($59|0)==(0|0);
   if (!($60)) {
    $61 = ((($0)) + 60|0);
    $62 = HEAP32[$61>>2]|0;
    $63 = ($62|0)==($59|0);
    if (!($63)) {
     $scevgep$i$i$i$i4 = ((($62)) + -12|0);
     $64 = $scevgep$i$i$i$i4;
     $65 = $59;
     $66 = (($64) - ($65))|0;
     $67 = (($66>>>0) / 12)&-1;
     $68 = $67 ^ -1;
     $scevgep5$i$i$i$i5 = (($62) + (($68*12)|0)|0);
     HEAP32[$61>>2] = $scevgep5$i$i$i$i5;
    }
    __ZdlPv($59);
   }
   $69 = ((($0)) + 44|0);
   $70 = HEAP32[$69>>2]|0;
   $71 = ($70|0)==(0|0);
   if (!($71)) {
    $72 = ((($0)) + 48|0);
    $73 = HEAP32[$72>>2]|0;
    $74 = ($73|0)==($70|0);
    if (!($74)) {
     $scevgep$i$i$i3$i9 = ((($73)) + -40|0);
     $75 = $scevgep$i$i$i3$i9;
     $76 = $70;
     $77 = (($75) - ($76))|0;
     $78 = (($77>>>0) / 40)&-1;
     $79 = $78 ^ -1;
     $scevgep5$i$i$i4$i10 = (($73) + (($79*40)|0)|0);
     HEAP32[$72>>2] = $scevgep5$i$i$i4$i10;
    }
    __ZdlPv($70);
   }
   $80 = ((($0)) + 24|0);
   $81 = HEAP32[$80>>2]|0;
   $82 = ($81|0)==(0|0);
   if (!($82)) {
    $83 = ((($0)) + 28|0);
    $84 = HEAP32[$83>>2]|0;
    $85 = ($84|0)==($81|0);
    if (!($85)) {
     $scevgep$i$i$i$i$i14 = ((($84)) + -4|0);
     $86 = $scevgep$i$i$i$i$i14;
     $87 = $81;
     $88 = (($86) - ($87))|0;
     $89 = $88 >>> 2;
     $90 = $89 ^ -1;
     $scevgep5$i$i$i$i$i15 = (($84) + ($90<<2)|0);
     HEAP32[$83>>2] = $scevgep5$i$i$i$i$i15;
    }
    __ZdlPv($81);
   }
   $93 = ((($0)) + 16|0);
   $94 = HEAP32[$93>>2]|0;
   $95 = ($94|0)==(0|0);
   if (!($95)) {
    $96 = ((($94)) + 8|0);
    $97 = HEAP32[$96>>2]|0;HEAP32[$96>>2] = (($97-1)|0);
    $98 = ($97|0)==(1);
    if ($98) {
     __THREW__ = 0;
     invoke_viii(3262,($94|0),1,1);
     $99 = __THREW__; __THREW__ = 0;
     $100 = $99&1;
     if ($100) {
      $112 = ___cxa_find_matching_catch_3(0|0)|0;
      $113 = tempRet0;
      ___clang_call_terminate($112);
      // unreachable;
     }
    }
   }
   HEAP32[$93>>2] = 0;
   $$1 = $57;$$13 = $56;
  } else {
   $4 = ((($0)) + 56|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = ($5|0)==(0|0);
   if (!($6)) {
    $7 = ((($0)) + 60|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = ($8|0)==($5|0);
    if (!($9)) {
     $scevgep$i$i$i$i = ((($8)) + -12|0);
     $10 = $scevgep$i$i$i$i;
     $11 = $5;
     $12 = (($10) - ($11))|0;
     $13 = (($12>>>0) / 12)&-1;
     $14 = $13 ^ -1;
     $scevgep5$i$i$i$i = (($8) + (($14*12)|0)|0);
     HEAP32[$7>>2] = $scevgep5$i$i$i$i;
    }
    __ZdlPv($5);
   }
   $15 = ((($0)) + 44|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ($16|0)==(0|0);
   if (!($17)) {
    $18 = ((($0)) + 48|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = ($19|0)==($16|0);
    if (!($20)) {
     $scevgep$i$i$i3$i = ((($19)) + -40|0);
     $21 = $scevgep$i$i$i3$i;
     $22 = $16;
     $23 = (($21) - ($22))|0;
     $24 = (($23>>>0) / 40)&-1;
     $25 = $24 ^ -1;
     $scevgep5$i$i$i4$i = (($19) + (($25*40)|0)|0);
     HEAP32[$18>>2] = $scevgep5$i$i$i4$i;
    }
    __ZdlPv($16);
   }
   $26 = ((($0)) + 24|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = ($27|0)==(0|0);
   if (!($28)) {
    $29 = ((($0)) + 28|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = ($30|0)==($27|0);
    if (!($31)) {
     $scevgep$i$i$i$i$i = ((($30)) + -4|0);
     $32 = $scevgep$i$i$i$i$i;
     $33 = $27;
     $34 = (($32) - ($33))|0;
     $35 = $34 >>> 2;
     $36 = $35 ^ -1;
     $scevgep5$i$i$i$i$i = (($30) + ($36<<2)|0);
     HEAP32[$29>>2] = $scevgep5$i$i$i$i$i;
    }
    __ZdlPv($27);
   }
   $37 = ((($0)) + 16|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = ($38|0)==(0|0);
   if (!($39)) {
    $40 = ((($38)) + 8|0);
    $41 = HEAP32[$40>>2]|0;HEAP32[$40>>2] = (($41-1)|0);
    $42 = ($41|0)==(1);
    if ($42) {
     __THREW__ = 0;
     invoke_viii(3262,($38|0),1,1);
     $43 = __THREW__; __THREW__ = 0;
     $44 = $43&1;
     if ($44) {
      $91 = ___cxa_find_matching_catch_2()|0;
      $92 = tempRet0;
      $$1 = $92;$$13 = $91;
      break;
     }
    }
   }
   HEAP32[$37>>2] = 0;
   $45 = ((($0)) + 4|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = ($46|0)==(0|0);
   if ($47) {
    return;
   }
   $48 = ((($0)) + 8|0);
   $49 = HEAP32[$48>>2]|0;
   $50 = ($49|0)==($46|0);
   if (!($50)) {
    $scevgep$i$i$i = ((($49)) + -4|0);
    $51 = $scevgep$i$i$i;
    $52 = $46;
    $53 = (($51) - ($52))|0;
    $54 = $53 >>> 2;
    $55 = $54 ^ -1;
    $scevgep5$i$i$i = (($49) + ($55<<2)|0);
    HEAP32[$48>>2] = $scevgep5$i$i$i;
   }
   __ZdlPv($46);
   return;
  }
 } while(0);
 $101 = ((($0)) + 4|0);
 $102 = HEAP32[$101>>2]|0;
 $103 = ($102|0)==(0|0);
 if ($103) {
  ___resumeException($$13|0);
  // unreachable;
 }
 $104 = ((($0)) + 8|0);
 $105 = HEAP32[$104>>2]|0;
 $106 = ($105|0)==($102|0);
 if (!($106)) {
  $scevgep$i$i$i21 = ((($105)) + -4|0);
  $107 = $scevgep$i$i$i21;
  $108 = $102;
  $109 = (($107) - ($108))|0;
  $110 = $109 >>> 2;
  $111 = $110 ^ -1;
  $scevgep5$i$i$i22 = (($105) + ($111<<2)|0);
  HEAP32[$104>>2] = $scevgep5$i$i$i22;
 }
 __ZdlPv($102);
 ___resumeException($$13|0);
 // unreachable;
}
function __ZN3osg20ShadowVolumeOccluderC2ERKS0_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$07 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i3$i = 0, $scevgep5$i$i$i = 0;
 var $scevgep5$i$i$i$i = 0, $scevgep5$i$i$i$i$i = 0, $scevgep5$i$i$i4$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $2;
 $3 = ((($0)) + 4|0);
 $4 = ((($1)) + 4|0);
 __ZNSt3__26vectorIPN3osg4NodeENS_9allocatorIS3_EEEC2ERKS6_($3,$4);
 $5 = ((($0)) + 16|0);
 $6 = ((($1)) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 HEAP32[$5>>2] = $7;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = ((($7)) + 8|0);
  $10 = HEAP32[$9>>2]|0;HEAP32[$9>>2] = (($10+1)|0);
 }
 $11 = ((($0)) + 20|0);
 $12 = ((($1)) + 20|0);
 __THREW__ = 0;
 invoke_vii(3596,($11|0),($12|0));
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 if ($14) {
  $19 = ___cxa_find_matching_catch_2()|0;
  $20 = tempRet0;
  $$0 = $20;$$07 = $19;
 } else {
  $15 = ((($0)) + 68|0);
  $16 = ((($1)) + 68|0);
  __THREW__ = 0;
  invoke_vii(3597,($15|0),($16|0));
  $17 = __THREW__; __THREW__ = 0;
  $18 = $17&1;
  if (!($18)) {
   return;
  }
  $21 = ___cxa_find_matching_catch_2()|0;
  $22 = tempRet0;
  $23 = ((($0)) + 56|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = ($24|0)==(0|0);
  if (!($25)) {
   $26 = ((($0)) + 60|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = ($27|0)==($24|0);
   if (!($28)) {
    $scevgep$i$i$i$i = ((($27)) + -12|0);
    $29 = $scevgep$i$i$i$i;
    $30 = $24;
    $31 = (($29) - ($30))|0;
    $32 = (($31>>>0) / 12)&-1;
    $33 = $32 ^ -1;
    $scevgep5$i$i$i$i = (($27) + (($33*12)|0)|0);
    HEAP32[$26>>2] = $scevgep5$i$i$i$i;
   }
   __ZdlPv($24);
  }
  $34 = ((($0)) + 44|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = ($35|0)==(0|0);
  if (!($36)) {
   $37 = ((($0)) + 48|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = ($38|0)==($35|0);
   if (!($39)) {
    $scevgep$i$i$i3$i = ((($38)) + -40|0);
    $40 = $scevgep$i$i$i3$i;
    $41 = $35;
    $42 = (($40) - ($41))|0;
    $43 = (($42>>>0) / 40)&-1;
    $44 = $43 ^ -1;
    $scevgep5$i$i$i4$i = (($38) + (($44*40)|0)|0);
    HEAP32[$37>>2] = $scevgep5$i$i$i4$i;
   }
   __ZdlPv($35);
  }
  $45 = ((($0)) + 24|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = ($46|0)==(0|0);
  if ($47) {
   $$0 = $22;$$07 = $21;
  } else {
   $48 = ((($0)) + 28|0);
   $49 = HEAP32[$48>>2]|0;
   $50 = ($49|0)==($46|0);
   if (!($50)) {
    $scevgep$i$i$i$i$i = ((($49)) + -4|0);
    $51 = $scevgep$i$i$i$i$i;
    $52 = $46;
    $53 = (($51) - ($52))|0;
    $54 = $53 >>> 2;
    $55 = $54 ^ -1;
    $scevgep5$i$i$i$i$i = (($49) + ($55<<2)|0);
    HEAP32[$48>>2] = $scevgep5$i$i$i$i$i;
   }
   __ZdlPv($46);
   $$0 = $22;$$07 = $21;
  }
 }
 $56 = HEAP32[$5>>2]|0;
 $57 = ($56|0)==(0|0);
 if (!($57)) {
  $58 = ((($56)) + 8|0);
  $59 = HEAP32[$58>>2]|0;HEAP32[$58>>2] = (($59-1)|0);
  $60 = ($59|0)==(1);
  if ($60) {
   __THREW__ = 0;
   invoke_viii(3262,($56|0),1,1);
   $61 = __THREW__; __THREW__ = 0;
   $62 = $61&1;
   if ($62) {
    $73 = ___cxa_find_matching_catch_3(0|0)|0;
    $74 = tempRet0;
    ___clang_call_terminate($73);
    // unreachable;
   }
  }
 }
 HEAP32[$5>>2] = 0;
 $63 = HEAP32[$3>>2]|0;
 $64 = ($63|0)==(0|0);
 if ($64) {
  ___resumeException($$07|0);
  // unreachable;
 }
 $65 = ((($0)) + 8|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = ($66|0)==($63|0);
 if (!($67)) {
  $scevgep$i$i$i = ((($66)) + -4|0);
  $68 = $scevgep$i$i$i;
  $69 = $63;
  $70 = (($68) - ($69))|0;
  $71 = $70 >>> 2;
  $72 = $71 ^ -1;
  $scevgep5$i$i$i = (($66) + ($72<<2)|0);
  HEAP32[$65>>2] = $scevgep5$i$i$i;
 }
 __ZdlPv($63);
 ___resumeException($$07|0);
 // unreachable;
}
function __ZNSt3__26vectorIN3osg20ShadowVolumeOccluderENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$06$i$i = 0, $$pre = 0, $$pre$i = 0, $$sroa$16$0 = 0, $$sroa$16$1 = 0, $$sroa$16$2 = 0, $$sroa$7$0 = 0, $$sroa$7$1 = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = (($5|0) / 80)&-1;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(53687091);
 if ($8) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $9 = ((($0)) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) - ($4))|0;
 $12 = (($11|0) / 80)&-1;
 $13 = ($12>>>0)<(26843545);
 $14 = $12 << 1;
 $15 = ($14>>>0)<($7>>>0);
 $$sroa$speculated$i = $15 ? $7 : $14;
 $$sroa$speculated$$i = $13 ? $$sroa$speculated$i : 53687091;
 $16 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($16) {
   $26 = 0;$73 = 0;
  } else {
   $17 = ($$sroa$speculated$$i>>>0)>(53687091);
   if (!($17)) {
    $23 = ($$sroa$speculated$$i*80)|0;
    $24 = (__Znwj($23)|0);
    $26 = $24;$73 = $24;
    break;
   }
   $18 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($18|0),(204840|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if ($20) {
    $21 = ___cxa_find_matching_catch_2()|0;
    $22 = tempRet0;
    ___cxa_free_exception(($18|0));
    ___resumeException($21|0);
    // unreachable;
   } else {
    HEAP32[$18>>2] = (99824);
    ___cxa_throw(($18|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $25 = (($26) + (($6*80)|0)|0);
 $27 = $25;
 $28 = (($26) + (($$sroa$speculated$$i*80)|0)|0);
 $29 = $28;
 __THREW__ = 0;
 invoke_vii(3587,($25|0),($1|0));
 $30 = __THREW__; __THREW__ = 0;
 $31 = $30&1;
 L13: do {
  if ($31) {
   $$sroa$16$1 = $27;$$sroa$7$1 = $27;
  } else {
   $32 = ((($25)) + 80|0);
   $33 = $32;
   $34 = HEAP32[$0>>2]|0;
   $35 = HEAP32[$2>>2]|0;
   $36 = ($35|0)==($34|0);
   if ($36) {
    $37 = $35;
    $38 = $34;
    $48 = $27;$49 = $38;$74 = $37;
   } else {
    $$06$i$i = $35;$$sroa$7$0 = $27;$40 = $25;
    while(1) {
     $39 = ((($40)) + -80|0);
     $41 = ((($$06$i$i)) + -80|0);
     __THREW__ = 0;
     invoke_vii(3587,($39|0),($41|0));
     $42 = __THREW__; __THREW__ = 0;
     $43 = $42&1;
     if ($43) {
      $$sroa$16$1 = $33;$$sroa$7$1 = $$sroa$7$0;
      break L13;
     }
     $44 = $$sroa$7$0;
     $45 = ((($44)) + -80|0);
     $46 = $45;
     $47 = ($41|0)==($34|0);
     if ($47) {
      break;
     } else {
      $$06$i$i = $41;$$sroa$7$0 = $46;$40 = $45;
     }
    }
    $$pre$i = HEAP32[$0>>2]|0;
    $$pre = HEAP32[$2>>2]|0;
    $48 = $46;$49 = $$pre$i;$74 = $$pre;
   }
   HEAP32[$0>>2] = $48;
   HEAP32[$2>>2] = $33;
   HEAP32[$9>>2] = $29;
   $50 = $49;
   $$sroa$16$0 = $74;
   while(1) {
    $51 = $$sroa$16$0;
    $52 = ($51|0)==($50|0);
    if ($52) {
     break;
    }
    $53 = ((($51)) + -80|0);
    $54 = $53;
    __THREW__ = 0;
    invoke_vi(3586,($53|0));
    $55 = __THREW__; __THREW__ = 0;
    $56 = $55&1;
    if ($56) {
     label = 18;
     break;
    } else {
     $$sroa$16$0 = $54;
    }
   }
   if ((label|0) == 18) {
    $57 = ___cxa_find_matching_catch_2()|0;
    $58 = tempRet0;
    ___cxa_call_unexpected(($57|0));
    // unreachable;
   }
   $59 = ($49|0)==(0);
   if ($59) {
    return;
   }
   $60 = $49;
   __ZdlPv($60);
   return;
  }
 } while(0);
 $61 = ___cxa_find_matching_catch_2()|0;
 $62 = tempRet0;
 $63 = $$sroa$7$1;
 $$sroa$16$2 = $$sroa$16$1;
 while(1) {
  $64 = $$sroa$16$2;
  $65 = ($64|0)==($63|0);
  if ($65) {
   break;
  }
  $66 = ((($64)) + -80|0);
  $67 = $66;
  __THREW__ = 0;
  invoke_vi(3586,($66|0));
  $68 = __THREW__; __THREW__ = 0;
  $69 = $68&1;
  if ($69) {
   label = 25;
   break;
  } else {
   $$sroa$16$2 = $67;
  }
 }
 if ((label|0) == 25) {
  $70 = ___cxa_find_matching_catch_2()|0;
  $71 = tempRet0;
  ___cxa_call_unexpected(($70|0));
  // unreachable;
 }
 $72 = ($26|0)==(0|0);
 if ($72) {
  ___resumeException($61|0);
  // unreachable;
 }
 __ZdlPv($73);
 ___resumeException($61|0);
 // unreachable;
}
function __ZN3osg10RenderInfoaSERKS0_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $3 = HEAP32[$1>>2]|0;
 $4 = ($2|0)==($3|0);
 if (!($4)) {
  HEAP32[$0>>2] = $3;
  $5 = ($3|0)==(0|0);
  if (!($5)) {
   $6 = ((($3)) + 8|0);
   $7 = HEAP32[$6>>2]|0;HEAP32[$6>>2] = (($7+1)|0);
  }
  $8 = ($2|0)==(0|0);
  if (!($8)) {
   $9 = ((($2)) + 8|0);
   $10 = HEAP32[$9>>2]|0;HEAP32[$9>>2] = (($10-1)|0);
   $11 = ($10|0)==(1);
   if ($11) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($2,1,1);
   }
  }
 }
 $12 = ((($1)) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($0)) + 4|0);
 HEAP32[$14>>2] = $13;
 $15 = ($0|0)==($1|0);
 if (!($15)) {
  $16 = ((($0)) + 8|0);
  $17 = ((($1)) + 8|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = ((($1)) + 12|0);
  $20 = HEAP32[$19>>2]|0;
  __ZNSt3__26vectorIPN3osg6CameraENS_9allocatorIS3_EEE6assignIPS3_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS3_NS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_($16,$18,$20);
  $21 = ((($0)) + 20|0);
  $22 = ((($1)) + 20|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = ((($1)) + 24|0);
  $25 = HEAP32[$24>>2]|0;
  __ZNSt3__26vectorIPN7osgUtil9RenderBinENS_9allocatorIS3_EEE6assignIPS3_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS3_NS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_($21,$23,$25);
 }
 $26 = ((($0)) + 32|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ((($1)) + 32|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ($27|0)==($29|0);
 if ($30) {
  return ($0|0);
 }
 HEAP32[$26>>2] = $29;
 $31 = ($29|0)==(0|0);
 if (!($31)) {
  $32 = ((($29)) + 8|0);
  $33 = HEAP32[$32>>2]|0;HEAP32[$32>>2] = (($33+1)|0);
 }
 $34 = ($27|0)==(0|0);
 if ($34) {
  return ($0|0);
 }
 $35 = ((($27)) + 8|0);
 $36 = HEAP32[$35>>2]|0;HEAP32[$35>>2] = (($36-1)|0);
 $37 = ($36|0)==(1);
 if (!($37)) {
  return ($0|0);
 }
 __ZNK3osg10Referenced24signalObserversAndDeleteEbb($27,1,1);
 return ($0|0);
}
function __ZN7osgUtil10StateGraph14find_or_insertEPKN3osg8StateSetE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$0$i$i = 0, $$0$ph$i$i = 0, $$0$ph$lcssa$i$i$i = 0, $$0$ph13$i$i$i = 0, $$014$i = 0, $$024$i$i = 0, $$025$i$i = 0, $$025$i53$i = 0, $$037$i = 0, $$03752$i = 0, $$07$ph12$i$i$i = 0, $$0710$i$i$i = 0, $$in$i$i = 0, $$pre$i = 0, $$pre$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $9 = 0, $storemerge$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = $1;
 $3 = ((($0)) + 24|0);
 $4 = ((($0)) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $$0$ph13$i$i$i = $4;$$07$ph12$i$i$i = $5;
  L2: while(1) {
   $$0710$i$i$i = $$07$ph12$i$i$i;
   while(1) {
    $7 = ((($$0710$i$i$i)) + 16|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = ($8>>>0)<($1>>>0);
    if (!($9)) {
     break;
    }
    $12 = ((($$0710$i$i$i)) + 4|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = ($13|0)==(0|0);
    if ($14) {
     $$0$ph$lcssa$i$i$i = $$0$ph13$i$i$i;
     break L2;
    } else {
     $$0710$i$i$i = $13;
    }
   }
   $10 = HEAP32[$$0710$i$i$i>>2]|0;
   $11 = ($10|0)==(0|0);
   if ($11) {
    $$0$ph$lcssa$i$i$i = $$0710$i$i$i;
    break;
   } else {
    $$0$ph13$i$i$i = $$0710$i$i$i;$$07$ph12$i$i$i = $10;
   }
  }
  $15 = ($$0$ph$lcssa$i$i$i|0)==($4|0);
  if (!($15)) {
   $16 = ((($$0$ph$lcssa$i$i$i)) + 16|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = ($17>>>0)>($1>>>0);
   if (!($18)) {
    $19 = ((($$0$ph$lcssa$i$i$i)) + 20|0);
    $20 = HEAP32[$19>>2]|0;
    $$0 = $20;
    return ($$0|0);
   }
  }
 }
 $21 = (__Znwj(64)|0);
 __THREW__ = 0;
 invoke_vii(3435,($21|0),0);
 $22 = __THREW__; __THREW__ = 0;
 $23 = $22&1;
 if ($23) {
  $85 = ___cxa_find_matching_catch_2()|0;
  $86 = tempRet0;
  __ZdlPv($21);
  ___resumeException($85|0);
  // unreachable;
 }
 HEAP32[$21>>2] = (49620);
 $24 = ((($21)) + 12|0);
 HEAP32[$24>>2] = $0;
 $25 = ((($21)) + 16|0);
 HEAP32[$25>>2] = $1;
 $26 = ($1|0)==(0|0);
 if ($26) {
  $35 = $0;
 } else {
  $27 = ((($1)) + 8|0);
  $28 = HEAP32[$27>>2]|0;HEAP32[$27>>2] = (($28+1)|0);
  $$pre$i = HEAP32[$24>>2]|0;
  $35 = $$pre$i;
 }
 $29 = ((($21)) + 20|0);
 HEAP32[$29>>2] = 0;
 $30 = ((($21)) + 28|0);
 HEAP32[$30>>2] = 0;
 $31 = ((($21)) + 32|0);
 HEAP32[$31>>2] = 0;
 $32 = ((($21)) + 24|0);
 HEAP32[$32>>2] = $30;
 $33 = ((($21)) + 36|0);
 $34 = ((($21)) + 60|0);
 $36 = ($35|0)==(0|0);
 ;HEAP32[$33>>2]=0|0;HEAP32[$33+4>>2]=0|0;HEAP32[$33+8>>2]=0|0;HEAP32[$33+12>>2]=0|0;HEAP32[$33+16>>2]=0|0;HEAP32[$33+20>>2]=0|0;HEAP8[$33+24>>0]=0|0;
 if ($36) {
  label = 14;
 } else {
  $37 = ((($35)) + 20|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = (($38) + 1)|0;
  HEAP32[$29>>2] = $39;
  $40 = ((($35)) + 60|0);
  $41 = HEAP8[$40>>0]|0;
  $42 = ($41<<24>>24)==(0);
  if ($42) {
   label = 14;
  } else {
   $storemerge$i = 1;
  }
 }
 if ((label|0) == 14) {
  $43 = ((($1)) + 24|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = ($44|0)==(0);
  $46 = $45&1;
  $storemerge$i = $46;
 }
 HEAP8[$34>>0] = $storemerge$i;
 $47 = HEAP32[$4>>2]|0;
 $48 = ($47|0)==(0|0);
 do {
  if ($48) {
   $$025$i$i = $4;$$037$i = $4;$59 = $47;
   label = 26;
  } else {
   $49 = ((($0)) + 28|0);
   $$0$i$i = $49;$$024$i$i = $47;$87 = $47;
   while(1) {
    $50 = ((($$024$i$i)) + 16|0);
    $51 = HEAP32[$50>>2]|0;
    $52 = ($51>>>0)>($1>>>0);
    if ($52) {
     $53 = HEAP32[$$024$i$i>>2]|0;
     $54 = ($53|0)==(0|0);
     if ($54) {
      label = 20;
      break;
     } else {
      $$0$ph$i$i = $$024$i$i;$$in$i$i = $53;
     }
    } else {
     $55 = ($51>>>0)<($1>>>0);
     if (!($55)) {
      label = 24;
      break;
     }
     $56 = ((($$024$i$i)) + 4|0);
     $57 = HEAP32[$56>>2]|0;
     $58 = ($57|0)==(0|0);
     if ($58) {
      label = 23;
      break;
     } else {
      $$0$ph$i$i = $56;$$in$i$i = $57;
     }
    }
    $$0$i$i = $$0$ph$i$i;$$024$i$i = $$in$i$i;$87 = $$in$i$i;
   }
   if ((label|0) == 20) {
    $$025$i53$i = $$024$i$i;$$03752$i = $$024$i$i;
    label = 27;
    break;
   }
   else if ((label|0) == 23) {
    $$025$i53$i = $56;$$03752$i = $$024$i$i;
    label = 27;
    break;
   }
   else if ((label|0) == 24) {
    $$025$i$i = $$0$i$i;$$037$i = $$024$i$i;$59 = $87;
    label = 26;
    break;
   }
  }
 } while(0);
 if ((label|0) == 26) {
  $60 = ($59|0)==(0|0);
  if ($60) {
   $$025$i53$i = $$025$i$i;$$03752$i = $$037$i;
   label = 27;
  } else {
   $$014$i = $59;
  }
 }
 if ((label|0) == 27) {
  $61 = (__Znwj(24)|0);
  $62 = ((($61)) + 16|0);
  HEAP32[$62>>2] = $2;
  $63 = ((($61)) + 20|0);
  HEAP32[$63>>2] = 0;
  HEAP32[$61>>2] = 0;
  $64 = ((($61)) + 4|0);
  HEAP32[$64>>2] = 0;
  $65 = ((($61)) + 8|0);
  HEAP32[$65>>2] = $$03752$i;
  HEAP32[$$025$i53$i>>2] = $61;
  $66 = HEAP32[$3>>2]|0;
  $67 = HEAP32[$66>>2]|0;
  $68 = ($67|0)==(0|0);
  if ($68) {
   $72 = $61;
  } else {
   $69 = $67;
   HEAP32[$3>>2] = $69;
   $$pre$i$i = HEAP32[$$025$i53$i>>2]|0;
   $72 = $$pre$i$i;
  }
  $70 = ((($0)) + 28|0);
  $71 = HEAP32[$70>>2]|0;
  __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($71,$72);
  $73 = ((($0)) + 32|0);
  $74 = HEAP32[$73>>2]|0;
  $75 = (($74) + 1)|0;
  HEAP32[$73>>2] = $75;
  $$014$i = $61;
 }
 $76 = ((($$014$i)) + 20|0);
 $77 = HEAP32[$76>>2]|0;
 $78 = ($77|0)==($21|0);
 if ($78) {
  $$0 = $21;
  return ($$0|0);
 }
 HEAP32[$76>>2] = $21;
 $79 = ((($21)) + 8|0);
 $80 = HEAP32[$79>>2]|0;HEAP32[$79>>2] = (($80+1)|0);
 $81 = ($77|0)==(0|0);
 if ($81) {
  $$0 = $21;
  return ($$0|0);
 }
 $82 = ((($77)) + 8|0);
 $83 = HEAP32[$82>>2]|0;HEAP32[$82>>2] = (($83-1)|0);
 $84 = ($83|0)==(1);
 if (!($84)) {
  $$0 = $21;
  return ($$0|0);
 }
 __ZNK3osg10Referenced24signalObserversAndDeleteEbb($77,1,1);
 $$0 = $21;
 return ($$0|0);
}
function __ZNSt3__26vectorIPN7osgUtil9RenderBinENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(1073741823);
 if ($8) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $9 = ((($0)) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) - ($4))|0;
 $12 = $11 >> 2;
 $13 = ($12>>>0)<(536870911);
 $14 = $11 >> 1;
 $15 = ($14>>>0)<($7>>>0);
 $$sroa$speculated$i = $15 ? $7 : $14;
 $$sroa$speculated$$i = $13 ? $$sroa$speculated$i : 1073741823;
 $16 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($16) {
   $26 = 0;
  } else {
   $17 = ($$sroa$speculated$$i>>>0)>(1073741823);
   if (!($17)) {
    $23 = $$sroa$speculated$$i << 2;
    $24 = (__Znwj($23)|0);
    $26 = $24;
    break;
   }
   $18 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($18|0),(204840|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if ($20) {
    $21 = ___cxa_find_matching_catch_2()|0;
    $22 = tempRet0;
    ___cxa_free_exception(($18|0));
    ___resumeException($21|0);
    // unreachable;
   } else {
    HEAP32[$18>>2] = (99824);
    ___cxa_throw(($18|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $25 = (($26) + ($6<<2)|0);
 $27 = (($26) + ($$sroa$speculated$$i<<2)|0);
 $28 = $27;
 $29 = HEAP32[$1>>2]|0;
 HEAP32[$25>>2] = $29;
 $30 = ((($25)) + 4|0);
 $31 = $30;
 $32 = (0 - ($6))|0;
 $33 = (($25) + ($32<<2)|0);
 $34 = $33;
 $35 = ($5|0)>(0);
 if ($35) {
  $36 = $4;
  _memcpy(($33|0),($36|0),($5|0))|0;
 }
 HEAP32[$0>>2] = $34;
 HEAP32[$2>>2] = $31;
 HEAP32[$9>>2] = $28;
 $37 = ($4|0)==(0);
 if ($37) {
  return;
 }
 $38 = $4;
 __ZdlPv($38);
 return;
}
function __ZN7osgUtil10StateGraphD2Ev($0) {
 $0 = $0|0;
 var $$2 = 0, $$24 = 0, $$pre$i = 0, $$pre$i9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (49620);
 $1 = ((($0)) + 56|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  label = 4;
 } else {
  $4 = ((($2)) + 8|0);
  $5 = HEAP32[$4>>2]|0;HEAP32[$4>>2] = (($5-1)|0);
  $6 = ($5|0)==(1);
  if ($6) {
   __THREW__ = 0;
   invoke_viii(3262,($2|0),1,1);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $40 = ___cxa_find_matching_catch_2()|0;
    $41 = tempRet0;
    $42 = ((($0)) + 36|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = ($43|0)==(0|0);
    if (!($44)) {
     $45 = ((($0)) + 40|0);
     $46 = HEAP32[$45>>2]|0;
     $47 = ($46|0)==($43|0);
     do {
      if ($47) {
       $61 = $43;
      } else {
       $49 = $46;
       while(1) {
        $48 = ((($49)) + -4|0);
        HEAP32[$45>>2] = $48;
        $50 = HEAP32[$48>>2]|0;
        $51 = ($50|0)==(0|0);
        if (!($51)) {
         $52 = ((($50)) + 8|0);
         $53 = HEAP32[$52>>2]|0;HEAP32[$52>>2] = (($53-1)|0);
         $54 = ($53|0)==(1);
         if ($54) {
          __THREW__ = 0;
          invoke_viii(3262,($50|0),1,1);
          $55 = __THREW__; __THREW__ = 0;
          $56 = $55&1;
          if ($56) {
           label = 23;
           break;
          }
         }
        }
        HEAP32[$48>>2] = 0;
        $57 = HEAP32[$45>>2]|0;
        $58 = ($57|0)==($43|0);
        if ($58) {
         label = 24;
         break;
        } else {
         $49 = $57;
        }
       }
       if ((label|0) == 23) {
        $59 = ___cxa_find_matching_catch_2()|0;
        $60 = tempRet0;
        ___cxa_call_unexpected(($59|0));
        // unreachable;
       }
       else if ((label|0) == 24) {
        $$pre$i9 = HEAP32[$42>>2]|0;
        $61 = $$pre$i9;
        break;
       }
      }
     } while(0);
     __ZdlPv($61);
    }
    $64 = ((($0)) + 24|0);
    $65 = ((($0)) + 28|0);
    $66 = HEAP32[$65>>2]|0;
    __ZNSt3__26__treeINS_12__value_typeIPKN3osg8StateSetENS2_7ref_ptrIN7osgUtil10StateGraphEEEEENS_19__map_value_compareIS5_SA_NS_4lessIS5_EELb1EEENS_9allocatorISA_EEE7destroyEPNS_11__tree_nodeISA_PvEE($64,$66);
    $67 = ((($0)) + 16|0);
    $68 = HEAP32[$67>>2]|0;
    $69 = ($68|0)==(0|0);
    if (!($69)) {
     $70 = ((($68)) + 8|0);
     $71 = HEAP32[$70>>2]|0;HEAP32[$70>>2] = (($71-1)|0);
     $72 = ($71|0)==(1);
     if ($72) {
      __THREW__ = 0;
      invoke_viii(3262,($68|0),1,1);
      $73 = __THREW__; __THREW__ = 0;
      $74 = $73&1;
      if ($74) {
       $77 = ___cxa_find_matching_catch_3(0|0)|0;
       $78 = tempRet0;
       ___clang_call_terminate($77);
       // unreachable;
      }
     }
    }
    HEAP32[$67>>2] = 0;
    $$2 = $41;$$24 = $40;
   } else {
    label = 4;
   }
  } else {
   label = 4;
  }
 }
 do {
  if ((label|0) == 4) {
   HEAP32[$1>>2] = 0;
   $9 = ((($0)) + 36|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($10|0)==(0|0);
   if (!($11)) {
    $12 = ((($0)) + 40|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = ($13|0)==($10|0);
    do {
     if ($14) {
      $28 = $10;
     } else {
      $16 = $13;
      while(1) {
       $15 = ((($16)) + -4|0);
       HEAP32[$12>>2] = $15;
       $17 = HEAP32[$15>>2]|0;
       $18 = ($17|0)==(0|0);
       if (!($18)) {
        $19 = ((($17)) + 8|0);
        $20 = HEAP32[$19>>2]|0;HEAP32[$19>>2] = (($20-1)|0);
        $21 = ($20|0)==(1);
        if ($21) {
         __THREW__ = 0;
         invoke_viii(3262,($17|0),1,1);
         $22 = __THREW__; __THREW__ = 0;
         $23 = $22&1;
         if ($23) {
          label = 10;
          break;
         }
        }
       }
       HEAP32[$15>>2] = 0;
       $24 = HEAP32[$12>>2]|0;
       $25 = ($24|0)==($10|0);
       if ($25) {
        label = 11;
        break;
       } else {
        $16 = $24;
       }
      }
      if ((label|0) == 10) {
       $26 = ___cxa_find_matching_catch_2()|0;
       $27 = tempRet0;
       ___cxa_call_unexpected(($26|0));
       // unreachable;
      }
      else if ((label|0) == 11) {
       $$pre$i = HEAP32[$9>>2]|0;
       $28 = $$pre$i;
       break;
      }
     }
    } while(0);
    __ZdlPv($28);
   }
   $29 = ((($0)) + 24|0);
   $30 = ((($0)) + 28|0);
   $31 = HEAP32[$30>>2]|0;
   __ZNSt3__26__treeINS_12__value_typeIPKN3osg8StateSetENS2_7ref_ptrIN7osgUtil10StateGraphEEEEENS_19__map_value_compareIS5_SA_NS_4lessIS5_EELb1EEENS_9allocatorISA_EEE7destroyEPNS_11__tree_nodeISA_PvEE($29,$31);
   $32 = ((($0)) + 16|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = ($33|0)==(0|0);
   if ($34) {
    HEAP32[$32>>2] = 0;
    __ZN3osg10ReferencedD2Ev($0);
    return;
   }
   $35 = ((($33)) + 8|0);
   $36 = HEAP32[$35>>2]|0;HEAP32[$35>>2] = (($36-1)|0);
   $37 = ($36|0)==(1);
   if (!($37)) {
    HEAP32[$32>>2] = 0;
    __ZN3osg10ReferencedD2Ev($0);
    return;
   }
   __THREW__ = 0;
   invoke_viii(3262,($33|0),1,1);
   $38 = __THREW__; __THREW__ = 0;
   $39 = $38&1;
   if ($39) {
    $62 = ___cxa_find_matching_catch_2()|0;
    $63 = tempRet0;
    $$2 = $63;$$24 = $62;
    break;
   } else {
    HEAP32[$32>>2] = 0;
    __ZN3osg10ReferencedD2Ev($0);
    return;
   }
  }
 } while(0);
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $75 = __THREW__; __THREW__ = 0;
 $76 = $75&1;
 if ($76) {
  $77 = ___cxa_find_matching_catch_3(0|0)|0;
  $78 = tempRet0;
  ___clang_call_terminate($77);
  // unreachable;
 } else {
  ___resumeException($$24|0);
  // unreachable;
 }
}
function __ZN7osgUtil10StateGraphD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1100,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNSt3__26__treeINS_12__value_typeIPKN3osg8StateSetENS2_7ref_ptrIN7osgUtil10StateGraphEEEEENS_19__map_value_compareIS5_SA_NS_4lessIS5_EELb1EEENS_9allocatorISA_EEE7destroyEPNS_11__tree_nodeISA_PvEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 }
 $3 = HEAP32[$1>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIPKN3osg8StateSetENS2_7ref_ptrIN7osgUtil10StateGraphEEEEENS_19__map_value_compareIS5_SA_NS_4lessIS5_EELb1EEENS_9allocatorISA_EEE7destroyEPNS_11__tree_nodeISA_PvEE($0,$3);
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIPKN3osg8StateSetENS2_7ref_ptrIN7osgUtil10StateGraphEEEEENS_19__map_value_compareIS5_SA_NS_4lessIS5_EELb1EEENS_9allocatorISA_EEE7destroyEPNS_11__tree_nodeISA_PvEE($0,$5);
 $6 = ((($1)) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = ((($7)) + 8|0);
  $10 = HEAP32[$9>>2]|0;HEAP32[$9>>2] = (($10-1)|0);
  $11 = ($10|0)==(1);
  if ($11) {
   __THREW__ = 0;
   invoke_viii(3262,($7|0),1,1);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if ($13) {
    $14 = ___cxa_find_matching_catch_2()|0;
    $15 = tempRet0;
    ___cxa_call_unexpected(($14|0));
    // unreachable;
   }
  }
 }
 __ZdlPv($1);
 return;
}
function __ZNSt3__26vectorIPN3osg6CameraENS_9allocatorIS3_EEE6assignIPS3_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS3_NS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$ = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $scevgep$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep5$i$i = 0, $scevgep5$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = $2;
 $4 = $1;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 $7 = ((($0)) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$0>>2]|0;
 $10 = (($8) - ($9))|0;
 $11 = $10 >> 2;
 $12 = ($6>>>0)>($11>>>0);
 $13 = $9;
 if (!($12)) {
  $14 = ((($0)) + 4|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (($15) - ($9))|0;
  $17 = $16 >> 2;
  $18 = ($6>>>0)>($17>>>0);
  $19 = (($1) + ($17<<2)|0);
  $$ = $18 ? $19 : $2;
  $20 = $$;
  $21 = (($20) - ($4))|0;
  $22 = $21 >> 2;
  $23 = ($22|0)==(0);
  if (!($23)) {
   $24 = $9;
   _memmove(($24|0),($1|0),($21|0))|0;
  }
  $25 = (($13) + ($22<<2)|0);
  if ($18) {
   $26 = (($3) - ($20))|0;
   $27 = ($26|0)>(0);
   if (!($27)) {
    return;
   }
   $28 = $26 >>> 2;
   $29 = HEAP32[$14>>2]|0;
   _memcpy(($29|0),($$|0),($26|0))|0;
   $30 = HEAP32[$14>>2]|0;
   $31 = (($30) + ($28<<2)|0);
   HEAP32[$14>>2] = $31;
   return;
  } else {
   $32 = HEAP32[$14>>2]|0;
   $33 = ($32|0)==($25|0);
   if ($33) {
    return;
   }
   $scevgep$i$i = ((($32)) + -4|0);
   $34 = $scevgep$i$i;
   $35 = $25;
   $36 = (($34) - ($35))|0;
   $37 = $36 >>> 2;
   $38 = $37 ^ -1;
   $scevgep5$i$i = (($32) + ($38<<2)|0);
   HEAP32[$14>>2] = $scevgep5$i$i;
   return;
  }
 }
 $39 = ($9|0)==(0);
 $40 = $9;
 if ($39) {
  $50 = $8;
 } else {
  $41 = ((($0)) + 4|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = ($42|0)==($13|0);
  if (!($43)) {
   $scevgep$i$i$i$i = ((($42)) + -4|0);
   $44 = $scevgep$i$i$i$i;
   $45 = (($44) - ($9))|0;
   $46 = $45 >>> 2;
   $47 = $46 ^ -1;
   $scevgep5$i$i$i$i = (($42) + ($47<<2)|0);
   HEAP32[$41>>2] = $scevgep5$i$i$i$i;
  }
  __ZdlPv($40);
  HEAP32[$7>>2] = 0;
  HEAP32[$41>>2] = 0;
  HEAP32[$0>>2] = 0;
  $50 = 0;
 }
 $48 = ($6>>>0)>(1073741823);
 if ($48) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $49 = $50 >> 2;
 $51 = ($49>>>0)<(536870911);
 $52 = $50 >> 1;
 $53 = ($52>>>0)<($6>>>0);
 $$sroa$speculated$i = $53 ? $6 : $52;
 $$sroa$speculated$$i = $51 ? $$sroa$speculated$i : 1073741823;
 $54 = ($$sroa$speculated$$i>>>0)>(1073741823);
 if ($54) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $55 = $$sroa$speculated$$i << 2;
 $56 = (__Znwj($55)|0);
 $57 = ((($0)) + 4|0);
 HEAP32[$57>>2] = $56;
 HEAP32[$0>>2] = $56;
 $58 = (($56) + ($$sroa$speculated$$i<<2)|0);
 HEAP32[$7>>2] = $58;
 $59 = ($5|0)>(0);
 if (!($59)) {
  return;
 }
 $60 = $5 >>> 2;
 _memcpy(($56|0),($1|0),($5|0))|0;
 $61 = (($56) + ($60<<2)|0);
 HEAP32[$57>>2] = $61;
 return;
}
function __ZNSt3__26vectorIPN7osgUtil9RenderBinENS_9allocatorIS3_EEE6assignIPS3_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS3_NS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$ = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $scevgep$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep5$i$i = 0, $scevgep5$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = $2;
 $4 = $1;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 $7 = ((($0)) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$0>>2]|0;
 $10 = (($8) - ($9))|0;
 $11 = $10 >> 2;
 $12 = ($6>>>0)>($11>>>0);
 $13 = $9;
 if (!($12)) {
  $14 = ((($0)) + 4|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (($15) - ($9))|0;
  $17 = $16 >> 2;
  $18 = ($6>>>0)>($17>>>0);
  $19 = (($1) + ($17<<2)|0);
  $$ = $18 ? $19 : $2;
  $20 = $$;
  $21 = (($20) - ($4))|0;
  $22 = $21 >> 2;
  $23 = ($22|0)==(0);
  if (!($23)) {
   $24 = $9;
   _memmove(($24|0),($1|0),($21|0))|0;
  }
  $25 = (($13) + ($22<<2)|0);
  if ($18) {
   $26 = (($3) - ($20))|0;
   $27 = ($26|0)>(0);
   if (!($27)) {
    return;
   }
   $28 = $26 >>> 2;
   $29 = HEAP32[$14>>2]|0;
   _memcpy(($29|0),($$|0),($26|0))|0;
   $30 = HEAP32[$14>>2]|0;
   $31 = (($30) + ($28<<2)|0);
   HEAP32[$14>>2] = $31;
   return;
  } else {
   $32 = HEAP32[$14>>2]|0;
   $33 = ($32|0)==($25|0);
   if ($33) {
    return;
   }
   $scevgep$i$i = ((($32)) + -4|0);
   $34 = $scevgep$i$i;
   $35 = $25;
   $36 = (($34) - ($35))|0;
   $37 = $36 >>> 2;
   $38 = $37 ^ -1;
   $scevgep5$i$i = (($32) + ($38<<2)|0);
   HEAP32[$14>>2] = $scevgep5$i$i;
   return;
  }
 }
 $39 = ($9|0)==(0);
 $40 = $9;
 if ($39) {
  $50 = $8;
 } else {
  $41 = ((($0)) + 4|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = ($42|0)==($13|0);
  if (!($43)) {
   $scevgep$i$i$i$i = ((($42)) + -4|0);
   $44 = $scevgep$i$i$i$i;
   $45 = (($44) - ($9))|0;
   $46 = $45 >>> 2;
   $47 = $46 ^ -1;
   $scevgep5$i$i$i$i = (($42) + ($47<<2)|0);
   HEAP32[$41>>2] = $scevgep5$i$i$i$i;
  }
  __ZdlPv($40);
  HEAP32[$7>>2] = 0;
  HEAP32[$41>>2] = 0;
  HEAP32[$0>>2] = 0;
  $50 = 0;
 }
 $48 = ($6>>>0)>(1073741823);
 if ($48) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $49 = $50 >> 2;
 $51 = ($49>>>0)<(536870911);
 $52 = $50 >> 1;
 $53 = ($52>>>0)<($6>>>0);
 $$sroa$speculated$i = $53 ? $6 : $52;
 $$sroa$speculated$$i = $51 ? $$sroa$speculated$i : 1073741823;
 $54 = ($$sroa$speculated$$i>>>0)>(1073741823);
 if ($54) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $55 = $$sroa$speculated$$i << 2;
 $56 = (__Znwj($55)|0);
 $57 = ((($0)) + 4|0);
 HEAP32[$57>>2] = $56;
 HEAP32[$0>>2] = $56;
 $58 = (($56) + ($$sroa$speculated$$i<<2)|0);
 HEAP32[$7>>2] = $58;
 $59 = ($5|0)>(0);
 if (!($59)) {
  return;
 }
 $60 = $5 >>> 2;
 _memcpy(($56|0),($1|0),($5|0))|0;
 $61 = (($56) + ($60<<2)|0);
 HEAP32[$57>>2] = $61;
 return;
}
function __ZN3osg8PolytopeC2ERKS0_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$06 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep5$i$i$i = 0, $scevgep5$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $2;
 $3 = ((($0)) + 4|0);
 $4 = ((($1)) + 4|0);
 __ZNSt3__26vectorIjNS_9allocatorIjEEEC2ERKS3_($3,$4);
 $5 = ((($0)) + 16|0);
 $6 = ((($1)) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 HEAP32[$5>>2] = $7;
 $8 = ((($0)) + 20|0);
 $9 = ((($1)) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 HEAP32[$8>>2] = $10;
 $11 = ((($0)) + 24|0);
 $12 = ((($1)) + 24|0);
 __THREW__ = 0;
 invoke_vii(3598,($11|0),($12|0));
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 if ($14) {
  $19 = ___cxa_find_matching_catch_2()|0;
  $20 = tempRet0;
  $$0 = $20;$$06 = $19;
 } else {
  $15 = ((($0)) + 36|0);
  $16 = ((($1)) + 36|0);
  __THREW__ = 0;
  invoke_vii(3467,($15|0),($16|0));
  $17 = __THREW__; __THREW__ = 0;
  $18 = $17&1;
  if (!($18)) {
   return;
  }
  $21 = ___cxa_find_matching_catch_2()|0;
  $22 = tempRet0;
  $23 = HEAP32[$11>>2]|0;
  $24 = ($23|0)==(0|0);
  if ($24) {
   $$0 = $22;$$06 = $21;
  } else {
   $25 = ((($0)) + 28|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = ($26|0)==($23|0);
   if (!($27)) {
    $scevgep$i$i$i = ((($26)) + -40|0);
    $28 = $scevgep$i$i$i;
    $29 = $23;
    $30 = (($28) - ($29))|0;
    $31 = (($30>>>0) / 40)&-1;
    $32 = $31 ^ -1;
    $scevgep5$i$i$i = (($26) + (($32*40)|0)|0);
    HEAP32[$25>>2] = $scevgep5$i$i$i;
   }
   __ZdlPv($23);
   $$0 = $22;$$06 = $21;
  }
 }
 $33 = ((($0)) + 4|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)==(0|0);
 if ($35) {
  ___resumeException($$06|0);
  // unreachable;
 }
 $36 = ((($0)) + 8|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = ($37|0)==($34|0);
 if (!($38)) {
  $scevgep$i$i$i$i = ((($37)) + -4|0);
  $39 = $scevgep$i$i$i$i;
  $40 = $34;
  $41 = (($39) - ($40))|0;
  $42 = $41 >>> 2;
  $43 = $42 ^ -1;
  $scevgep5$i$i$i$i = (($37) + ($43<<2)|0);
  HEAP32[$36>>2] = $scevgep5$i$i$i$i;
 }
 __ZdlPv($34);
 ___resumeException($$06|0);
 // unreachable;
}
function __ZNSt3__26vectorIN3osg8PolytopeENS_9allocatorIS2_EEEC2ERKS5_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$07$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = 0;
 $2 = ((($0)) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = ((($0)) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$1>>2]|0;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 48)&-1;
 $9 = ($7|0)==(0);
 if ($9) {
  return;
 }
 $10 = ($8>>>0)>(89478485);
 L4: do {
  if ($10) {
   __THREW__ = 0;
   invoke_vi(3307,($0|0));
   $11 = __THREW__; __THREW__ = 0;
  } else {
   __THREW__ = 0;
   $12 = (invoke_ii(3276,($7|0))|0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if (!($14)) {
    HEAP32[$2>>2] = $12;
    HEAP32[$0>>2] = $12;
    $15 = (($12) + (($8*48)|0)|0);
    $16 = ((($0)) + 8|0);
    HEAP32[$16>>2] = $15;
    $17 = HEAP32[$1>>2]|0;
    $18 = HEAP32[$4>>2]|0;
    $19 = ($17|0)==($18|0);
    if ($19) {
     return;
    }
    $$07$i$i = $17;$20 = $12;
    while(1) {
     __THREW__ = 0;
     invoke_vii(3596,($20|0),($$07$i$i|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break L4;
     }
     $23 = ((($$07$i$i)) + 48|0);
     $24 = HEAP32[$2>>2]|0;
     $25 = ((($24)) + 48|0);
     HEAP32[$2>>2] = $25;
     $26 = ($23|0)==($18|0);
     if ($26) {
      break;
     } else {
      $$07$i$i = $23;$20 = $25;
     }
    }
    return;
   }
  }
 } while(0);
 $27 = ___cxa_find_matching_catch_2()|0;
 $28 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3595,($0|0));
 $29 = __THREW__; __THREW__ = 0;
 $30 = $29&1;
 if ($30) {
  $31 = ___cxa_find_matching_catch_3(0|0)|0;
  $32 = tempRet0;
  ___clang_call_terminate($31);
  // unreachable;
 } else {
  ___resumeException($27|0);
  // unreachable;
 }
}
function __ZNSt3__213__vector_baseIN3osg8PolytopeENS_9allocatorIS2_EEED2Ev($0) {
 $0 = $0|0;
 var $$pre = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i$i$i = 0, $scevgep$i$i$i3$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i$i$i$i$i = 0, $scevgep5$i$i$i4$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 }
 $3 = ((($0)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==($1|0);
 if ($5) {
  $43 = $1;
 } else {
  $7 = $4;
  while(1) {
   $6 = ((($7)) + -48|0);
   HEAP32[$3>>2] = $6;
   $8 = ((($7)) + -12|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = ($9|0)==(0|0);
   if (!($10)) {
    $11 = ((($7)) + -8|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ($12|0)==($9|0);
    if (!($13)) {
     $scevgep$i$i$i$i$i$i$i$i = ((($12)) + -12|0);
     $14 = $scevgep$i$i$i$i$i$i$i$i;
     $15 = $9;
     $16 = (($14) - ($15))|0;
     $17 = (($16>>>0) / 12)&-1;
     $18 = $17 ^ -1;
     $scevgep5$i$i$i$i$i$i$i$i = (($12) + (($18*12)|0)|0);
     HEAP32[$11>>2] = $scevgep5$i$i$i$i$i$i$i$i;
    }
    __ZdlPv($9);
   }
   $19 = ((($7)) + -24|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = ($20|0)==(0|0);
   if (!($21)) {
    $22 = ((($7)) + -20|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = ($23|0)==($20|0);
    if (!($24)) {
     $scevgep$i$i$i3$i$i$i$i$i = ((($23)) + -40|0);
     $25 = $scevgep$i$i$i3$i$i$i$i$i;
     $26 = $20;
     $27 = (($25) - ($26))|0;
     $28 = (($27>>>0) / 40)&-1;
     $29 = $28 ^ -1;
     $scevgep5$i$i$i4$i$i$i$i$i = (($23) + (($29*40)|0)|0);
     HEAP32[$22>>2] = $scevgep5$i$i$i4$i$i$i$i$i;
    }
    __ZdlPv($20);
   }
   $30 = ((($7)) + -44|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = ($31|0)==(0|0);
   if (!($32)) {
    $35 = ((($7)) + -40|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = ($36|0)==($31|0);
    if (!($37)) {
     $scevgep$i$i$i$i$i$i$i$i$i = ((($36)) + -4|0);
     $38 = $scevgep$i$i$i$i$i$i$i$i$i;
     $39 = $31;
     $40 = (($38) - ($39))|0;
     $41 = $40 >>> 2;
     $42 = $41 ^ -1;
     $scevgep5$i$i$i$i$i$i$i$i$i = (($36) + ($42<<2)|0);
     HEAP32[$35>>2] = $scevgep5$i$i$i$i$i$i$i$i$i;
    }
    __ZdlPv($31);
   }
   $33 = HEAP32[$3>>2]|0;
   $34 = ($33|0)==($1|0);
   if ($34) {
    break;
   } else {
    $7 = $33;
   }
  }
  $$pre = HEAP32[$0>>2]|0;
  $43 = $$pre;
 }
 __ZdlPv($43);
 return;
}
function __ZNSt3__26vectorIN3osg5PlaneENS_9allocatorIS2_EEEC2ERKS5_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$07$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0.0, $21 = 0, $22 = 0, $23 = 0.0, $24 = 0, $25 = 0, $26 = 0.0, $27 = 0;
 var $28 = 0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i = 0, $scevgep5$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = 0;
 $2 = ((($0)) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = ((($0)) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$1>>2]|0;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 40)&-1;
 $9 = ($7|0)==(0);
 if ($9) {
  return;
 }
 $10 = ($8>>>0)>(107374182);
 if ($10) {
  __THREW__ = 0;
  invoke_vi(3307,($0|0));
  $11 = __THREW__; __THREW__ = 0;
 } else {
  __THREW__ = 0;
  $12 = (invoke_ii(3276,($7|0))|0);
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if (!($14)) {
   HEAP32[$2>>2] = $12;
   HEAP32[$0>>2] = $12;
   $15 = (($12) + (($8*40)|0)|0);
   $16 = ((($0)) + 8|0);
   HEAP32[$16>>2] = $15;
   $17 = HEAP32[$1>>2]|0;
   $18 = HEAP32[$4>>2]|0;
   $19 = ($17|0)==($18|0);
   if ($19) {
    return;
   }
   $$07$i$i = $17;$21 = $12;
   while(1) {
    $20 = +HEAPF64[$$07$i$i>>3];
    HEAPF64[$21>>3] = $20;
    $22 = ((($$07$i$i)) + 8|0);
    $23 = +HEAPF64[$22>>3];
    $24 = ((($21)) + 8|0);
    HEAPF64[$24>>3] = $23;
    $25 = ((($$07$i$i)) + 16|0);
    $26 = +HEAPF64[$25>>3];
    $27 = ((($21)) + 16|0);
    HEAPF64[$27>>3] = $26;
    $28 = ((($$07$i$i)) + 24|0);
    $29 = +HEAPF64[$28>>3];
    $30 = ((($21)) + 24|0);
    HEAPF64[$30>>3] = $29;
    $31 = $20 >= 0.0;
    $32 = $31&1;
    $33 = $23 >= 0.0;
    $34 = $33 ? 2 : 0;
    $35 = $34 | $32;
    $36 = $26 >= 0.0;
    $37 = $36 ? 4 : 0;
    $38 = $35 | $37;
    $39 = ((($21)) + 32|0);
    HEAP32[$39>>2] = $38;
    $40 = $38 ^ 7;
    $41 = ((($21)) + 36|0);
    HEAP32[$41>>2] = $40;
    $42 = ((($$07$i$i)) + 40|0);
    $43 = ((($21)) + 40|0);
    $44 = ($42|0)==($18|0);
    if ($44) {
     break;
    } else {
     $$07$i$i = $42;$21 = $43;
    }
   }
   HEAP32[$2>>2] = $43;
   return;
  }
 }
 $45 = ___cxa_find_matching_catch_2()|0;
 $46 = tempRet0;
 $47 = HEAP32[$0>>2]|0;
 $48 = ($47|0)==(0|0);
 if ($48) {
  ___resumeException($45|0);
  // unreachable;
 }
 $49 = HEAP32[$2>>2]|0;
 $50 = ($49|0)==($47|0);
 if (!($50)) {
  $scevgep$i$i$i = ((($49)) + -40|0);
  $51 = $scevgep$i$i$i;
  $52 = $47;
  $53 = (($51) - ($52))|0;
  $54 = (($53>>>0) / 40)&-1;
  $55 = $54 ^ -1;
  $scevgep5$i$i$i = (($49) + (($55*40)|0)|0);
  HEAP32[$2>>2] = $scevgep5$i$i$i;
 }
 __ZdlPv($47);
 ___resumeException($45|0);
 // unreachable;
}
function __ZN7osgUtil9SceneView9clearAreaEiiiiRKN3osg5Vec4fE($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$0 = 0, $$014 = 0, $10 = 0, $11 = 0.0, $12 = 0.0, $13 = 0.0, $14 = 0.0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0.0, $30 = 0, $31 = 0.0, $32 = 0, $33 = 0.0, $34 = 0, $35 = 0.0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $6 = (__Znwj(88)|0);
 __THREW__ = 0;
 invoke_vi(3599,($6|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $44 = ___cxa_find_matching_catch_2()|0;
  $45 = tempRet0;
  __ZdlPv($6);
  $$0 = $45;$$014 = $44;
  ___resumeException($$014|0);
  // unreachable;
 }
 $9 = ((($6)) + 8|0);
 $10 = HEAP32[$9>>2]|0;HEAP32[$9>>2] = (($10+1)|0);
 $11 = (+($1|0));
 $12 = (+($2|0));
 $13 = (+($3|0));
 $14 = (+($4|0));
 $15 = ((($6)) + 56|0);
 HEAPF64[$15>>3] = $11;
 $16 = ((($6)) + 64|0);
 HEAPF64[$16>>3] = $12;
 $17 = ((($6)) + 72|0);
 HEAPF64[$17>>3] = $13;
 $18 = ((($6)) + 80|0);
 HEAPF64[$18>>3] = $14;
 $19 = ((($0)) + 100|0);
 $20 = HEAP32[$19>>2]|0;
 __THREW__ = 0;
 (invoke_iii(3600,($20|0),($6|0))|0);
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if (!($22)) {
  __THREW__ = 0;
  invoke_viiii(3601,($1|0),($2|0),($3|0),($4|0));
  $23 = __THREW__; __THREW__ = 0;
  $24 = $23&1;
  if (!($24)) {
   __THREW__ = 0;
   invoke_vi(3602,3089);
   $25 = __THREW__; __THREW__ = 0;
   $26 = $25&1;
   if (!($26)) {
    __THREW__ = 0;
    invoke_viiii(3603,1,1,1,1);
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if (!($28)) {
     $29 = +HEAPF32[$5>>2];
     $30 = ((($5)) + 4|0);
     $31 = +HEAPF32[$30>>2];
     $32 = ((($5)) + 8|0);
     $33 = +HEAPF32[$32>>2];
     $34 = ((($5)) + 12|0);
     $35 = +HEAPF32[$34>>2];
     __THREW__ = 0;
     invoke_vdddd(3604,(+$29),(+$31),(+$33),(+$35));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      invoke_vi(3605,16384);
      $38 = __THREW__; __THREW__ = 0;
      $39 = $38&1;
      if (!($39)) {
       __THREW__ = 0;
       invoke_vi(3606,3089);
       $40 = __THREW__; __THREW__ = 0;
       $41 = $40&1;
       if (!($41)) {
        $42 = HEAP32[$9>>2]|0;HEAP32[$9>>2] = (($42-1)|0);
        $43 = ($42|0)==(1);
        if (!($43)) {
         return;
        }
        __ZNK3osg10Referenced24signalObserversAndDeleteEbb($6,1,1);
        return;
       }
      }
     }
    }
   }
  }
 }
 $46 = ___cxa_find_matching_catch_2()|0;
 $47 = tempRet0;
 $48 = HEAP32[$9>>2]|0;HEAP32[$9>>2] = (($48-1)|0);
 $49 = ($48|0)==(1);
 if ($49) {
  __THREW__ = 0;
  invoke_viii(3262,($6|0),1,1);
  $50 = __THREW__; __THREW__ = 0;
  $51 = $50&1;
  if ($51) {
   $52 = ___cxa_find_matching_catch_3(0|0)|0;
   $53 = tempRet0;
   ___clang_call_terminate($52);
   // unreachable;
  }
 }
 $$0 = $47;$$014 = $46;
 ___resumeException($$014|0);
 // unreachable;
}
function __ZN3osg5State14applyAttributeEPKNS_14StateAttributeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i = 0, $$0$i$i = 0, $$0$ph$i$i = 0, $$014$i = 0, $$024$i$i = 0, $$025$i$i = 0, $$025$i68$i = 0, $$052$i = 0, $$05267$i = 0, $$in$i$i = 0, $$pre$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 588|0);
 $3 = HEAP32[$1>>2]|0;
 $4 = ((($3)) + 148|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_ii[$5 & 8191]($1)|0);
 $7 = HEAP32[$1>>2]|0;
 $8 = ((($7)) + 152|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (FUNCTION_TABLE_ii[$9 & 8191]($1)|0);
 $11 = ((($0)) + 592|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0|0);
 do {
  if ($13) {
   $$025$i$i = $11;$$052$i = $11;$28 = $12;
   label = 14;
  } else {
   $14 = ((($0)) + 592|0);
   $$0$i$i = $14;$$024$i$i = $12;$86 = $12;
   L4: while(1) {
    $15 = ((($$024$i$i)) + 16|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = ($6|0)<($16|0);
    do {
     if ($17) {
      label = 7;
     } else {
      $18 = ($16|0)<($6|0);
      if (!($18)) {
       $19 = ((($$024$i$i)) + 20|0);
       $20 = HEAP32[$19>>2]|0;
       $21 = ($10>>>0)<($20>>>0);
       if ($21) {
        label = 7;
        break;
       }
       $24 = ($20>>>0)<($10>>>0);
       if (!($24)) {
        label = 12;
        break L4;
       }
      }
      $25 = ((($$024$i$i)) + 4|0);
      $26 = HEAP32[$25>>2]|0;
      $27 = ($26|0)==(0|0);
      if ($27) {
       label = 11;
       break L4;
      } else {
       $$0$ph$i$i = $25;$$in$i$i = $26;
      }
     }
    } while(0);
    if ((label|0) == 7) {
     label = 0;
     $22 = HEAP32[$$024$i$i>>2]|0;
     $23 = ($22|0)==(0|0);
     if ($23) {
      label = 8;
      break;
     } else {
      $$0$ph$i$i = $$024$i$i;$$in$i$i = $22;
     }
    }
    $$0$i$i = $$0$ph$i$i;$$024$i$i = $$in$i$i;$86 = $$in$i$i;
   }
   if ((label|0) == 8) {
    $$025$i68$i = $$024$i$i;$$05267$i = $$024$i$i;
    label = 15;
    break;
   }
   else if ((label|0) == 11) {
    $$025$i68$i = $25;$$05267$i = $$024$i$i;
    label = 15;
    break;
   }
   else if ((label|0) == 12) {
    $$025$i$i = $$0$i$i;$$052$i = $$024$i$i;$28 = $86;
    label = 14;
    break;
   }
  }
 } while(0);
 if ((label|0) == 14) {
  $29 = ($28|0)==(0|0);
  if ($29) {
   $$025$i68$i = $$025$i$i;$$05267$i = $$052$i;
   label = 15;
  } else {
   $$014$i = $28;
  }
 }
 if ((label|0) == 15) {
  $30 = (__Znwj(52)|0);
  $31 = ((($30)) + 16|0);
  $32 = $31;
  $33 = $32;
  HEAP32[$33>>2] = $6;
  $34 = (($32) + 4)|0;
  $35 = $34;
  HEAP32[$35>>2] = $10;
  $36 = ((($30)) + 24|0);
  HEAP8[$36>>0] = 0;
  $37 = ((($30)) + 28|0);
  ;HEAP32[$37>>2]=0|0;HEAP32[$37+4>>2]=0|0;HEAP32[$37+8>>2]=0|0;HEAP32[$37+12>>2]=0|0;HEAP32[$37+16>>2]=0|0;HEAP32[$37+20>>2]=0|0;
  HEAP32[$30>>2] = 0;
  $38 = ((($30)) + 4|0);
  HEAP32[$38>>2] = 0;
  $39 = ((($30)) + 8|0);
  HEAP32[$39>>2] = $$05267$i;
  HEAP32[$$025$i68$i>>2] = $30;
  $40 = HEAP32[$2>>2]|0;
  $41 = HEAP32[$40>>2]|0;
  $42 = ($41|0)==(0|0);
  if ($42) {
   $46 = $30;
  } else {
   $43 = $41;
   HEAP32[$2>>2] = $43;
   $$pre$i$i = HEAP32[$$025$i68$i>>2]|0;
   $46 = $$pre$i$i;
  }
  $44 = ((($0)) + 592|0);
  $45 = HEAP32[$44>>2]|0;
  __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($45,$46);
  $47 = ((($0)) + 596|0);
  $48 = HEAP32[$47>>2]|0;
  $49 = (($48) + 1)|0;
  HEAP32[$47>>2] = $49;
  $$014$i = $30;
 }
 $50 = ((($$014$i)) + 24|0);
 HEAP8[$50>>0] = 1;
 $51 = ((($$014$i)) + 28|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = ($52|0)==($1|0);
 if ($53) {
  $$0$i = 0;
  return ($$0$i|0);
 }
 $54 = ((($$014$i)) + 36|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = ($55|0)==(0|0);
 if ($56) {
  $57 = HEAP32[$1>>2]|0;
  $58 = ((($57)) + 12|0);
  $59 = HEAP32[$58>>2]|0;
  $60 = (FUNCTION_TABLE_ii[$59 & 8191]($1)|0);
  $61 = HEAP32[$60>>2]|0;
  $62 = ((($61)) + 56|0);
  $63 = HEAP32[$62>>2]|0;
  $64 = (FUNCTION_TABLE_ii[$63 & 8191]($60)|0);
  $65 = HEAP32[$54>>2]|0;
  $66 = ($65|0)==($64|0);
  if (!($66)) {
   HEAP32[$54>>2] = $64;
   $67 = ($64|0)==(0|0);
   if (!($67)) {
    $68 = ((($64)) + 8|0);
    $69 = HEAP32[$68>>2]|0;HEAP32[$68>>2] = (($69+1)|0);
   }
   $70 = ($65|0)==(0|0);
   if (!($70)) {
    $71 = ((($65)) + 8|0);
    $72 = HEAP32[$71>>2]|0;HEAP32[$71>>2] = (($72-1)|0);
    $73 = ($72|0)==(1);
    if ($73) {
     __ZNK3osg10Referenced24signalObserversAndDeleteEbb($65,1,1);
    }
   }
  }
 }
 HEAP32[$51>>2] = $1;
 $74 = HEAP32[$1>>2]|0;
 $75 = ((($74)) + 172|0);
 $76 = HEAP32[$75>>2]|0;
 FUNCTION_TABLE_vii[$76 & 8191]($1,$0);
 $77 = ((($1)) + 44|0);
 $78 = HEAP32[$77>>2]|0;
 $79 = ((($$014$i)) + 32|0);
 $80 = HEAP32[$79>>2]|0;
 $81 = ($80|0)==($78|0);
 if (!($81)) {
  HEAP32[$79>>2] = $78;
  $82 = ((($0)) + 137|0);
  HEAP8[$82>>0] = 1;
 }
 $83 = ((($0)) + 344|0);
 $84 = HEAP32[$83>>2]|0;
 $85 = ($84|0)==(2);
 if (!($85)) {
  $$0$i = 1;
  return ($$0$i|0);
 }
 (__ZNK3osg5State13checkGLErrorsEPKNS_14StateAttributeE($0,$1)|0);
 $$0$i = 1;
 return ($$0$i|0);
}
function __ZN7osgUtil9SceneView14updateUniformsEv($0) {
 $0 = $0|0;
 var $$0 = 0, $$031 = 0, $$pr = 0, $$pre = 0, $$pre69 = 0, $$pre71 = 0, $$pre72 = 0, $$pre75 = 0, $$pre76 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0.0, $135 = 0.0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0.0, $15 = 0, $150 = 0, $151 = 0, $152 = 0.0, $153 = 0.0, $154 = 0.0, $155 = 0.0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0;
 var $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0;
 var $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0;
 var $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0;
 var $217 = 0.0, $218 = 0, $219 = 0, $22 = 0, $220 = 0.0, $221 = 0, $222 = 0, $223 = 0.0, $224 = 0, $225 = 0, $226 = 0.0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0;
 var $235 = 0, $236 = 0, $237 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0.0, $75 = 0.0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0.0, $9 = 0, $90 = 0, $91 = 0, $92 = 0.0, $93 = 0.0;
 var $94 = 0.0, $95 = 0.0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(224|0);
 $1 = sp + 200|0;
 $2 = sp + 188|0;
 $3 = sp + 176|0;
 $4 = sp + 164|0;
 $5 = sp + 152|0;
 $6 = sp + 140|0;
 $7 = sp + 128|0;
 $8 = sp;
 $9 = ((($0)) + 96|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  $12 = (__Znwj(160)|0);
  __THREW__ = 0;
  invoke_vi(3572,($12|0));
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if ($14) {
   $23 = ___cxa_find_matching_catch_2()|0;
   $24 = tempRet0;
   __ZdlPv($12);
   $$0 = $23;$$031 = $24;
   ___resumeException($$0|0);
   // unreachable;
  }
  $15 = HEAP32[$9>>2]|0;
  $16 = ($15|0)==($12|0);
  if ($16) {
   $37 = $12;
  } else {
   HEAP32[$9>>2] = $12;
   $17 = ((($12)) + 8|0);
   $18 = HEAP32[$17>>2]|0;HEAP32[$17>>2] = (($18+1)|0);
   $19 = ($15|0)==(0|0);
   if (!($19)) {
    $20 = ((($15)) + 8|0);
    $21 = HEAP32[$20>>2]|0;HEAP32[$20>>2] = (($21-1)|0);
    $22 = ($21|0)==(1);
    if ($22) {
     __ZNK3osg10Referenced24signalObserversAndDeleteEbb($15,1,1);
    }
   }
   $$pr = HEAP32[$9>>2]|0;
   $25 = ($$pr|0)==(0|0);
   if ($25) {
    STACKTOP = sp;return;
   } else {
    $37 = $$pr;
   }
  }
 } else {
  $37 = $10;
 }
 $26 = ((($0)) + 248|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = $27 & 1;
 $29 = ($28|0)==(0);
 do {
  if ($29) {
   $55 = $27;
  } else {
   $30 = ((($0)) + 200|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = ($31|0)==(0|0);
   if ($32) {
    $55 = $27;
   } else {
    $33 = (__Znwj(16)|0);
    HEAP32[$1>>2] = $33;
    $34 = ((($1)) + 8|0);
    HEAP32[$34>>2] = -2147483632;
    $35 = ((($1)) + 4|0);
    HEAP32[$35>>2] = 15;
    dest=$33; src=113359; stop=dest+15|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
    $36 = ((($33)) + 15|0);
    HEAP8[$36>>0] = 0;
    __THREW__ = 0;
    $38 = (invoke_iiiii(3607,($37|0),($1|0),5125,1)|0);
    $39 = __THREW__; __THREW__ = 0;
    $40 = $39&1;
    if (!($40)) {
     $41 = ((($1)) + 11|0);
     $42 = HEAP8[$41>>0]|0;
     $43 = ($42<<24>>24)<(0);
     if ($43) {
      $44 = HEAP32[$1>>2]|0;
      __ZdlPv($44);
     }
     $45 = HEAP32[$30>>2]|0;
     $46 = ((($45)) + 12|0);
     $47 = HEAP32[$46>>2]|0;
     (__ZN3osg7Uniform3setEj($38,$47)|0);
     $$pre = HEAP32[$26>>2]|0;
     $55 = $$pre;
     break;
    }
    $48 = ___cxa_find_matching_catch_2()|0;
    $49 = tempRet0;
    $50 = ((($1)) + 11|0);
    $51 = HEAP8[$50>>0]|0;
    $52 = ($51<<24>>24)<(0);
    if ($52) {
     $53 = HEAP32[$1>>2]|0;
     __ZdlPv($53);
    }
    $$0 = $48;$$031 = $49;
    ___resumeException($$0|0);
    // unreachable;
   }
  }
 } while(0);
 $54 = $55 & 2;
 $56 = ($54|0)==(0);
 do {
  if ($56) {
   $83 = $55;
  } else {
   $57 = ((($0)) + 200|0);
   $58 = HEAP32[$57>>2]|0;
   $59 = ($58|0)==(0|0);
   if ($59) {
    $83 = $55;
   } else {
    $60 = HEAP32[$9>>2]|0;
    $61 = (__Znwj(16)|0);
    HEAP32[$2>>2] = $61;
    $62 = ((($2)) + 8|0);
    HEAP32[$62>>2] = -2147483632;
    $63 = ((($2)) + 4|0);
    HEAP32[$63>>2] = 13;
    dest=$61; src=113375; stop=dest+13|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
    $64 = ((($61)) + 13|0);
    HEAP8[$64>>0] = 0;
    __THREW__ = 0;
    $65 = (invoke_iiiii(3607,($60|0),($2|0),5126,1)|0);
    $66 = __THREW__; __THREW__ = 0;
    $67 = $66&1;
    if (!($67)) {
     $68 = ((($2)) + 11|0);
     $69 = HEAP8[$68>>0]|0;
     $70 = ($69<<24>>24)<(0);
     if ($70) {
      $71 = HEAP32[$2>>2]|0;
      __ZdlPv($71);
     }
     $72 = HEAP32[$57>>2]|0;
     $73 = ((($72)) + 16|0);
     $74 = +HEAPF64[$73>>3];
     $75 = $74;
     (__ZN3osg7Uniform3setEf($65,$75)|0);
     $$pre69 = HEAP32[$26>>2]|0;
     $83 = $$pre69;
     break;
    }
    $76 = ___cxa_find_matching_catch_2()|0;
    $77 = tempRet0;
    $78 = ((($2)) + 11|0);
    $79 = HEAP8[$78>>0]|0;
    $80 = ($79<<24>>24)<(0);
    if ($80) {
     $81 = HEAP32[$2>>2]|0;
     __ZdlPv($81);
    }
    $$0 = $76;$$031 = $77;
    ___resumeException($$0|0);
    // unreachable;
   }
  }
 } while(0);
 $82 = $83 & 4;
 $84 = ($82|0)==(0);
 do {
  if ($84) {
   $115 = $83;
  } else {
   $85 = ((($0)) + 200|0);
   $86 = HEAP32[$85>>2]|0;
   $87 = ($86|0)==(0|0);
   if ($87) {
    $115 = $83;
   } else {
    $88 = ((($0)) + 256|0);
    $89 = +HEAPF64[$88>>3];
    $90 = $89 != 0.0;
    $91 = ((($86)) + 16|0);
    $92 = +HEAPF64[$91>>3];
    $93 = $92 - $89;
    $94 = $93;
    $95 = $90 ? $94 : 0.0;
    HEAPF64[$88>>3] = $92;
    $96 = HEAP32[$9>>2]|0;
    $97 = (__Znwj(32)|0);
    HEAP32[$3>>2] = $97;
    $98 = ((($3)) + 8|0);
    HEAP32[$98>>2] = -2147483616;
    $99 = ((($3)) + 4|0);
    HEAP32[$99>>2] = 18;
    dest=$97; src=113389; stop=dest+18|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
    $100 = ((($97)) + 18|0);
    HEAP8[$100>>0] = 0;
    __THREW__ = 0;
    $101 = (invoke_iiiii(3607,($96|0),($3|0),5126,1)|0);
    $102 = __THREW__; __THREW__ = 0;
    $103 = $102&1;
    if (!($103)) {
     $104 = ((($3)) + 11|0);
     $105 = HEAP8[$104>>0]|0;
     $106 = ($105<<24>>24)<(0);
     if ($106) {
      $107 = HEAP32[$3>>2]|0;
      __ZdlPv($107);
     }
     (__ZN3osg7Uniform3setEf($101,$95)|0);
     $$pre71 = HEAP32[$26>>2]|0;
     $115 = $$pre71;
     break;
    }
    $108 = ___cxa_find_matching_catch_2()|0;
    $109 = tempRet0;
    $110 = ((($3)) + 11|0);
    $111 = HEAP8[$110>>0]|0;
    $112 = ($111<<24>>24)<(0);
    if ($112) {
     $113 = HEAP32[$3>>2]|0;
     __ZdlPv($113);
    }
    $$0 = $108;$$031 = $109;
    ___resumeException($$0|0);
    // unreachable;
   }
  }
 } while(0);
 $114 = $115 & 8;
 $116 = ($114|0)==(0);
 do {
  if ($116) {
   $143 = $115;
  } else {
   $117 = ((($0)) + 200|0);
   $118 = HEAP32[$117>>2]|0;
   $119 = ($118|0)==(0|0);
   if ($119) {
    $143 = $115;
   } else {
    $120 = HEAP32[$9>>2]|0;
    $121 = (__Znwj(32)|0);
    HEAP32[$4>>2] = $121;
    $122 = ((($4)) + 8|0);
    HEAP32[$122>>2] = -2147483616;
    $123 = ((($4)) + 4|0);
    HEAP32[$123>>2] = 18;
    dest=$121; src=113408; stop=dest+18|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
    $124 = ((($121)) + 18|0);
    HEAP8[$124>>0] = 0;
    __THREW__ = 0;
    $125 = (invoke_iiiii(3607,($120|0),($4|0),5126,1)|0);
    $126 = __THREW__; __THREW__ = 0;
    $127 = $126&1;
    if (!($127)) {
     $128 = ((($4)) + 11|0);
     $129 = HEAP8[$128>>0]|0;
     $130 = ($129<<24>>24)<(0);
     if ($130) {
      $131 = HEAP32[$4>>2]|0;
      __ZdlPv($131);
     }
     $132 = HEAP32[$117>>2]|0;
     $133 = ((($132)) + 24|0);
     $134 = +HEAPF64[$133>>3];
     $135 = $134;
     (__ZN3osg7Uniform3setEf($125,$135)|0);
     $$pre72 = HEAP32[$26>>2]|0;
     $143 = $$pre72;
     break;
    }
    $136 = ___cxa_find_matching_catch_2()|0;
    $137 = tempRet0;
    $138 = ((($4)) + 11|0);
    $139 = HEAP8[$138>>0]|0;
    $140 = ($139<<24>>24)<(0);
    if ($140) {
     $141 = HEAP32[$4>>2]|0;
     __ZdlPv($141);
    }
    $$0 = $136;$$031 = $137;
    ___resumeException($$0|0);
    // unreachable;
   }
  }
 } while(0);
 $142 = $143 & 16;
 $144 = ($142|0)==(0);
 do {
  if ($144) {
   $175 = $143;
  } else {
   $145 = ((($0)) + 200|0);
   $146 = HEAP32[$145>>2]|0;
   $147 = ($146|0)==(0|0);
   if ($147) {
    $175 = $143;
   } else {
    $148 = ((($0)) + 264|0);
    $149 = +HEAPF64[$148>>3];
    $150 = $149 != 0.0;
    $151 = ((($146)) + 24|0);
    $152 = +HEAPF64[$151>>3];
    $153 = $152 - $149;
    $154 = $153;
    $155 = $150 ? $154 : 0.0;
    HEAPF64[$148>>3] = $152;
    $156 = HEAP32[$9>>2]|0;
    $157 = (__Znwj(32)|0);
    HEAP32[$5>>2] = $157;
    $158 = ((($5)) + 8|0);
    HEAP32[$158>>2] = -2147483616;
    $159 = ((($5)) + 4|0);
    HEAP32[$159>>2] = 23;
    dest=$157; src=113427; stop=dest+23|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
    $160 = ((($157)) + 23|0);
    HEAP8[$160>>0] = 0;
    __THREW__ = 0;
    $161 = (invoke_iiiii(3607,($156|0),($5|0),5126,1)|0);
    $162 = __THREW__; __THREW__ = 0;
    $163 = $162&1;
    if (!($163)) {
     $164 = ((($5)) + 11|0);
     $165 = HEAP8[$164>>0]|0;
     $166 = ($165<<24>>24)<(0);
     if ($166) {
      $167 = HEAP32[$5>>2]|0;
      __ZdlPv($167);
     }
     (__ZN3osg7Uniform3setEf($161,$155)|0);
     $$pre75 = HEAP32[$26>>2]|0;
     $175 = $$pre75;
     break;
    }
    $168 = ___cxa_find_matching_catch_2()|0;
    $169 = tempRet0;
    $170 = ((($5)) + 11|0);
    $171 = HEAP8[$170>>0]|0;
    $172 = ($171<<24>>24)<(0);
    if ($172) {
     $173 = HEAP32[$5>>2]|0;
     __ZdlPv($173);
    }
    $$0 = $168;$$031 = $169;
    ___resumeException($$0|0);
    // unreachable;
   }
  }
 } while(0);
 $174 = $175 & 32;
 $176 = ($174|0)==(0);
 do {
  if ($176) {
   $199 = $175;
  } else {
   $177 = HEAP32[$9>>2]|0;
   $178 = (__Znwj(16)|0);
   HEAP32[$6>>2] = $178;
   $179 = ((($6)) + 8|0);
   HEAP32[$179>>2] = -2147483632;
   $180 = ((($6)) + 4|0);
   HEAP32[$180>>2] = 14;
   dest=$178; src=113451; stop=dest+14|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
   $181 = ((($178)) + 14|0);
   HEAP8[$181>>0] = 0;
   __THREW__ = 0;
   $182 = (invoke_iiiii(3607,($177|0),($6|0),35676,1)|0);
   $183 = __THREW__; __THREW__ = 0;
   $184 = $183&1;
   if (!($184)) {
    $185 = ((($6)) + 11|0);
    $186 = HEAP8[$185>>0]|0;
    $187 = ($186<<24>>24)<(0);
    if ($187) {
     $188 = HEAP32[$6>>2]|0;
     __ZdlPv($188);
    }
    $189 = ((($0)) + 208|0);
    $190 = HEAP32[$189>>2]|0;
    $191 = ((($190)) + 432|0);
    (__ZN3osg7Uniform3setERKNS_7MatrixdE($182,$191)|0);
    $$pre76 = HEAP32[$26>>2]|0;
    $199 = $$pre76;
    break;
   }
   $192 = ___cxa_find_matching_catch_2()|0;
   $193 = tempRet0;
   $194 = ((($6)) + 11|0);
   $195 = HEAP8[$194>>0]|0;
   $196 = ($195<<24>>24)<(0);
   if ($196) {
    $197 = HEAP32[$6>>2]|0;
    __ZdlPv($197);
   }
   $$0 = $192;$$031 = $193;
   ___resumeException($$0|0);
   // unreachable;
  }
 } while(0);
 $198 = $199 & 64;
 $200 = ($198|0)==(0);
 if ($200) {
  STACKTOP = sp;return;
 }
 $201 = HEAP32[$9>>2]|0;
 $202 = (__Znwj(32)|0);
 HEAP32[$7>>2] = $202;
 $203 = ((($7)) + 8|0);
 HEAP32[$203>>2] = -2147483616;
 $204 = ((($7)) + 4|0);
 HEAP32[$204>>2] = 21;
 dest=$202; src=113466; stop=dest+21|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $205 = ((($202)) + 21|0);
 HEAP8[$205>>0] = 0;
 __THREW__ = 0;
 $206 = (invoke_iiiii(3607,($201|0),($7|0),35676,1)|0);
 $207 = __THREW__; __THREW__ = 0;
 $208 = $207&1;
 if ($208) {
  $230 = ___cxa_find_matching_catch_2()|0;
  $231 = tempRet0;
  $232 = ((($7)) + 11|0);
  $233 = HEAP8[$232>>0]|0;
  $234 = ($233<<24>>24)<(0);
  if ($234) {
   $235 = HEAP32[$7>>2]|0;
   __ZdlPv($235);
  }
  $$0 = $230;$$031 = $231;
  ___resumeException($$0|0);
  // unreachable;
 }
 $209 = ((($7)) + 11|0);
 $210 = HEAP8[$209>>0]|0;
 $211 = ($210<<24>>24)<(0);
 if ($211) {
  $212 = HEAP32[$7>>2]|0;
  __ZdlPv($212);
 }
 $213 = ((($0)) + 208|0);
 $214 = HEAP32[$213>>2]|0;
 $215 = ((($214)) + 432|0);
 __ZN3osg7Matrixd12makeIdentityEv($8);
 $216 = ((($214)) + 456|0);
 $217 = +HEAPF64[$216>>3];
 $218 = $217 == 0.0;
 if ($218) {
  $219 = ((($214)) + 488|0);
  $220 = +HEAPF64[$219>>3];
  $221 = $220 == 0.0;
  if ($221) {
   $222 = ((($214)) + 520|0);
   $223 = +HEAPF64[$222>>3];
   $224 = $223 == 0.0;
   if ($224) {
    $225 = ((($214)) + 552|0);
    $226 = +HEAPF64[$225>>3];
    $227 = $226 == 1.0;
    if ($227) {
     (__ZN3osg7Matrixd10invert_4x3ERKS0_($8,$215)|0);
    } else {
     label = 71;
    }
   } else {
    label = 71;
   }
  } else {
   label = 71;
  }
 } else {
  label = 71;
 }
 if ((label|0) == 71) {
  (__ZN3osg7Matrixd10invert_4x4ERKS0_($8,$215)|0);
 }
 __THREW__ = 0;
 (invoke_iii(3608,($206|0),($8|0))|0);
 $228 = __THREW__; __THREW__ = 0;
 $229 = $228&1;
 if ($229) {
  $236 = ___cxa_find_matching_catch_2()|0;
  $237 = tempRet0;
  $$0 = $236;$$031 = $237;
  ___resumeException($$0|0);
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN7osgUtil9SceneView22computeLeftEyeViewportEPKN3osg8ViewportE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $100 = 0, $101 = 0.0, $102 = 0, $103 = 0.0, $104 = 0, $105 = 0.0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0.0, $114 = 0, $115 = 0, $116 = 0.0, $117 = 0;
 var $118 = 0, $119 = 0.0, $12 = 0, $120 = 0, $121 = 0, $122 = 0.0, $123 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0.0, $26 = 0, $27 = 0, $28 = 0.0, $29 = 0, $3 = 0, $30 = 0, $31 = 0.0, $32 = 0, $33 = 0, $34 = 0.0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0.0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0.0, $46 = 0.0, $47 = 0.0, $48 = 0, $49 = 0, $5 = 0, $50 = 0.0, $51 = 0, $52 = 0.0, $53 = 0, $54 = 0.0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0.0, $6 = 0, $60 = 0.0;
 var $61 = 0.0, $62 = 0, $63 = 0, $64 = 0.0, $65 = 0.0, $66 = 0, $67 = 0.0, $68 = 0, $69 = 0.0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0.0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0.0, $82 = 0.0, $83 = 0.0, $84 = 0.0, $85 = 0, $86 = 0, $87 = 0.0, $88 = 0, $89 = 0.0, $9 = 0, $90 = 0.0, $91 = 0, $92 = 0.0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0.0;
 var $98 = 0.0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 }
 $3 = ((($0)) + 176|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  $6 = (__Znwj(88)|0);
  __THREW__ = 0;
  invoke_vi(3599,($6|0));
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if ($8) {
   $17 = ___cxa_find_matching_catch_2()|0;
   $18 = tempRet0;
   __ZdlPv($6);
   ___resumeException($17|0);
   // unreachable;
  }
  $9 = HEAP32[$3>>2]|0;
  $10 = ($9|0)==($6|0);
  if (!($10)) {
   HEAP32[$3>>2] = $6;
   $11 = ((($6)) + 8|0);
   $12 = HEAP32[$11>>2]|0;HEAP32[$11>>2] = (($12+1)|0);
   $13 = ($9|0)==(0|0);
   if (!($13)) {
    $14 = ((($9)) + 8|0);
    $15 = HEAP32[$14>>2]|0;HEAP32[$14>>2] = (($15-1)|0);
    $16 = ($15|0)==(1);
    if ($16) {
     __ZNK3osg10Referenced24signalObserversAndDeleteEbb($9,1,1);
    }
   }
  }
 }
 $19 = ((($0)) + 224|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)==(0|0);
 if ($21) {
  $22 = HEAP32[$3>>2]|0;
  $23 = ($22|0)==($1|0);
  if ($23) {
   return;
  }
  $24 = ((($1)) + 56|0);
  $25 = +HEAPF64[$24>>3];
  $26 = ((($22)) + 56|0);
  HEAPF64[$26>>3] = $25;
  $27 = ((($1)) + 64|0);
  $28 = +HEAPF64[$27>>3];
  $29 = ((($22)) + 64|0);
  HEAPF64[$29>>3] = $28;
  $30 = ((($1)) + 72|0);
  $31 = +HEAPF64[$30>>3];
  $32 = ((($22)) + 72|0);
  HEAPF64[$32>>3] = $31;
  $33 = ((($1)) + 80|0);
  $34 = +HEAPF64[$33>>3];
  $35 = ((($22)) + 80|0);
  HEAPF64[$35>>3] = $34;
  return;
 }
 $36 = ((($20)) + 20|0);
 $37 = HEAP32[$36>>2]|0;
 switch ($37|0) {
 case 2:  {
  $38 = ((($20)) + 44|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = (+($39|0));
  $41 = ((($20)) + 40|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = ($42|0)==(0);
  $44 = ((($1)) + 72|0);
  $45 = +HEAPF64[$44>>3];
  if ($43) {
   $46 = $45 - $40;
   $47 = $46 * 0.5;
   $48 = HEAP32[$3>>2]|0;
   $49 = ((($1)) + 56|0);
   $50 = +HEAPF64[$49>>3];
   $51 = ((($1)) + 64|0);
   $52 = +HEAPF64[$51>>3];
   $53 = ((($1)) + 80|0);
   $54 = +HEAPF64[$53>>3];
   $55 = ((($48)) + 56|0);
   HEAPF64[$55>>3] = $50;
   $56 = ((($48)) + 64|0);
   HEAPF64[$56>>3] = $52;
   $57 = ((($48)) + 72|0);
   HEAPF64[$57>>3] = $47;
   $58 = ((($48)) + 80|0);
   HEAPF64[$58>>3] = $54;
   return;
  } else {
   $59 = $40 + $45;
   $60 = $59 * 0.5;
   $61 = $45 - $60;
   $62 = HEAP32[$3>>2]|0;
   $63 = ((($1)) + 56|0);
   $64 = +HEAPF64[$63>>3];
   $65 = $60 + $64;
   $66 = ((($1)) + 64|0);
   $67 = +HEAPF64[$66>>3];
   $68 = ((($1)) + 80|0);
   $69 = +HEAPF64[$68>>3];
   $70 = ((($62)) + 56|0);
   HEAPF64[$70>>3] = $65;
   $71 = ((($62)) + 64|0);
   HEAPF64[$71>>3] = $67;
   $72 = ((($62)) + 72|0);
   HEAPF64[$72>>3] = $61;
   $73 = ((($62)) + 80|0);
   HEAPF64[$73>>3] = $69;
   return;
  }
  break;
 }
 case 3:  {
  $74 = ((($20)) + 52|0);
  $75 = HEAP32[$74>>2]|0;
  $76 = (+($75|0));
  $77 = ((($20)) + 48|0);
  $78 = HEAP32[$77>>2]|0;
  $79 = ($78|0)==(0);
  $80 = ((($1)) + 80|0);
  $81 = +HEAPF64[$80>>3];
  if ($79) {
   $82 = $76 + $81;
   $83 = $82 * 0.5;
   $84 = $81 - $83;
   $85 = HEAP32[$3>>2]|0;
   $86 = ((($1)) + 56|0);
   $87 = +HEAPF64[$86>>3];
   $88 = ((($1)) + 64|0);
   $89 = +HEAPF64[$88>>3];
   $90 = $83 + $89;
   $91 = ((($1)) + 72|0);
   $92 = +HEAPF64[$91>>3];
   $93 = ((($85)) + 56|0);
   HEAPF64[$93>>3] = $87;
   $94 = ((($85)) + 64|0);
   HEAPF64[$94>>3] = $90;
   $95 = ((($85)) + 72|0);
   HEAPF64[$95>>3] = $92;
   $96 = ((($85)) + 80|0);
   HEAPF64[$96>>3] = $84;
   return;
  } else {
   $97 = $81 - $76;
   $98 = $97 * 0.5;
   $99 = HEAP32[$3>>2]|0;
   $100 = ((($1)) + 56|0);
   $101 = +HEAPF64[$100>>3];
   $102 = ((($1)) + 64|0);
   $103 = +HEAPF64[$102>>3];
   $104 = ((($1)) + 72|0);
   $105 = +HEAPF64[$104>>3];
   $106 = ((($99)) + 56|0);
   HEAPF64[$106>>3] = $101;
   $107 = ((($99)) + 64|0);
   HEAPF64[$107>>3] = $103;
   $108 = ((($99)) + 72|0);
   HEAPF64[$108>>3] = $105;
   $109 = ((($99)) + 80|0);
   HEAPF64[$109>>3] = $98;
   return;
  }
  break;
 }
 default: {
  $110 = HEAP32[$3>>2]|0;
  $111 = ($110|0)==($1|0);
  if ($111) {
   return;
  }
  $112 = ((($1)) + 56|0);
  $113 = +HEAPF64[$112>>3];
  $114 = ((($110)) + 56|0);
  HEAPF64[$114>>3] = $113;
  $115 = ((($1)) + 64|0);
  $116 = +HEAPF64[$115>>3];
  $117 = ((($110)) + 64|0);
  HEAPF64[$117>>3] = $116;
  $118 = ((($1)) + 72|0);
  $119 = +HEAPF64[$118>>3];
  $120 = ((($110)) + 72|0);
  HEAPF64[$120>>3] = $119;
  $121 = ((($1)) + 80|0);
  $122 = +HEAPF64[$121>>3];
  $123 = ((($110)) + 80|0);
  HEAPF64[$123>>3] = $122;
  return;
 }
 }
}
function __ZN7osgUtil9SceneView23computeRightEyeViewportEPKN3osg8ViewportE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $100 = 0, $101 = 0.0, $102 = 0, $103 = 0.0, $104 = 0, $105 = 0.0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0.0, $114 = 0, $115 = 0, $116 = 0.0, $117 = 0;
 var $118 = 0, $119 = 0.0, $12 = 0, $120 = 0, $121 = 0, $122 = 0.0, $123 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0.0, $26 = 0, $27 = 0, $28 = 0.0, $29 = 0, $3 = 0, $30 = 0, $31 = 0.0, $32 = 0, $33 = 0, $34 = 0.0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0.0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0.0, $46 = 0.0, $47 = 0.0, $48 = 0, $49 = 0, $5 = 0, $50 = 0.0, $51 = 0, $52 = 0.0, $53 = 0, $54 = 0.0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0.0, $6 = 0, $60 = 0.0;
 var $61 = 0.0, $62 = 0, $63 = 0, $64 = 0.0, $65 = 0.0, $66 = 0, $67 = 0.0, $68 = 0, $69 = 0.0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0.0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0.0, $82 = 0.0, $83 = 0.0, $84 = 0.0, $85 = 0, $86 = 0, $87 = 0.0, $88 = 0, $89 = 0.0, $9 = 0, $90 = 0.0, $91 = 0, $92 = 0.0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0.0;
 var $98 = 0.0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 }
 $3 = ((($0)) + 192|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  $6 = (__Znwj(88)|0);
  __THREW__ = 0;
  invoke_vi(3599,($6|0));
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if ($8) {
   $17 = ___cxa_find_matching_catch_2()|0;
   $18 = tempRet0;
   __ZdlPv($6);
   ___resumeException($17|0);
   // unreachable;
  }
  $9 = HEAP32[$3>>2]|0;
  $10 = ($9|0)==($6|0);
  if (!($10)) {
   HEAP32[$3>>2] = $6;
   $11 = ((($6)) + 8|0);
   $12 = HEAP32[$11>>2]|0;HEAP32[$11>>2] = (($12+1)|0);
   $13 = ($9|0)==(0|0);
   if (!($13)) {
    $14 = ((($9)) + 8|0);
    $15 = HEAP32[$14>>2]|0;HEAP32[$14>>2] = (($15-1)|0);
    $16 = ($15|0)==(1);
    if ($16) {
     __ZNK3osg10Referenced24signalObserversAndDeleteEbb($9,1,1);
    }
   }
  }
 }
 $19 = ((($0)) + 224|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)==(0|0);
 if ($21) {
  $22 = HEAP32[$3>>2]|0;
  $23 = ($22|0)==($1|0);
  if ($23) {
   return;
  }
  $24 = ((($1)) + 56|0);
  $25 = +HEAPF64[$24>>3];
  $26 = ((($22)) + 56|0);
  HEAPF64[$26>>3] = $25;
  $27 = ((($1)) + 64|0);
  $28 = +HEAPF64[$27>>3];
  $29 = ((($22)) + 64|0);
  HEAPF64[$29>>3] = $28;
  $30 = ((($1)) + 72|0);
  $31 = +HEAPF64[$30>>3];
  $32 = ((($22)) + 72|0);
  HEAPF64[$32>>3] = $31;
  $33 = ((($1)) + 80|0);
  $34 = +HEAPF64[$33>>3];
  $35 = ((($22)) + 80|0);
  HEAPF64[$35>>3] = $34;
  return;
 }
 $36 = ((($20)) + 20|0);
 $37 = HEAP32[$36>>2]|0;
 switch ($37|0) {
 case 2:  {
  $38 = ((($20)) + 44|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = (+($39|0));
  $41 = ((($20)) + 40|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = ($42|0)==(0);
  $44 = ((($1)) + 72|0);
  $45 = +HEAPF64[$44>>3];
  if ($43) {
   $59 = $40 + $45;
   $60 = $59 * 0.5;
   $61 = $45 - $60;
   $62 = HEAP32[$3>>2]|0;
   $63 = ((($1)) + 56|0);
   $64 = +HEAPF64[$63>>3];
   $65 = $60 + $64;
   $66 = ((($1)) + 64|0);
   $67 = +HEAPF64[$66>>3];
   $68 = ((($1)) + 80|0);
   $69 = +HEAPF64[$68>>3];
   $70 = ((($62)) + 56|0);
   HEAPF64[$70>>3] = $65;
   $71 = ((($62)) + 64|0);
   HEAPF64[$71>>3] = $67;
   $72 = ((($62)) + 72|0);
   HEAPF64[$72>>3] = $61;
   $73 = ((($62)) + 80|0);
   HEAPF64[$73>>3] = $69;
   return;
  } else {
   $46 = $45 - $40;
   $47 = $46 * 0.5;
   $48 = HEAP32[$3>>2]|0;
   $49 = ((($1)) + 56|0);
   $50 = +HEAPF64[$49>>3];
   $51 = ((($1)) + 64|0);
   $52 = +HEAPF64[$51>>3];
   $53 = ((($1)) + 80|0);
   $54 = +HEAPF64[$53>>3];
   $55 = ((($48)) + 56|0);
   HEAPF64[$55>>3] = $50;
   $56 = ((($48)) + 64|0);
   HEAPF64[$56>>3] = $52;
   $57 = ((($48)) + 72|0);
   HEAPF64[$57>>3] = $47;
   $58 = ((($48)) + 80|0);
   HEAPF64[$58>>3] = $54;
   return;
  }
  break;
 }
 case 3:  {
  $74 = ((($20)) + 52|0);
  $75 = HEAP32[$74>>2]|0;
  $76 = (+($75|0));
  $77 = ((($20)) + 48|0);
  $78 = HEAP32[$77>>2]|0;
  $79 = ($78|0)==(0);
  $80 = ((($1)) + 80|0);
  $81 = +HEAPF64[$80>>3];
  if ($79) {
   $97 = $81 - $76;
   $98 = $97 * 0.5;
   $99 = HEAP32[$3>>2]|0;
   $100 = ((($1)) + 56|0);
   $101 = +HEAPF64[$100>>3];
   $102 = ((($1)) + 64|0);
   $103 = +HEAPF64[$102>>3];
   $104 = ((($1)) + 72|0);
   $105 = +HEAPF64[$104>>3];
   $106 = ((($99)) + 56|0);
   HEAPF64[$106>>3] = $101;
   $107 = ((($99)) + 64|0);
   HEAPF64[$107>>3] = $103;
   $108 = ((($99)) + 72|0);
   HEAPF64[$108>>3] = $105;
   $109 = ((($99)) + 80|0);
   HEAPF64[$109>>3] = $98;
   return;
  } else {
   $82 = $76 + $81;
   $83 = $82 * 0.5;
   $84 = $81 - $83;
   $85 = HEAP32[$3>>2]|0;
   $86 = ((($1)) + 56|0);
   $87 = +HEAPF64[$86>>3];
   $88 = ((($1)) + 64|0);
   $89 = +HEAPF64[$88>>3];
   $90 = $83 + $89;
   $91 = ((($1)) + 72|0);
   $92 = +HEAPF64[$91>>3];
   $93 = ((($85)) + 56|0);
   HEAPF64[$93>>3] = $87;
   $94 = ((($85)) + 64|0);
   HEAPF64[$94>>3] = $90;
   $95 = ((($85)) + 72|0);
   HEAPF64[$95>>3] = $92;
   $96 = ((($85)) + 80|0);
   HEAPF64[$96>>3] = $84;
   return;
  }
  break;
 }
 default: {
  $110 = HEAP32[$3>>2]|0;
  $111 = ($110|0)==($1|0);
  if ($111) {
   return;
  }
  $112 = ((($1)) + 56|0);
  $113 = +HEAPF64[$112>>3];
  $114 = ((($110)) + 56|0);
  HEAPF64[$114>>3] = $113;
  $115 = ((($1)) + 64|0);
  $116 = +HEAPF64[$115>>3];
  $117 = ((($110)) + 64|0);
  HEAPF64[$117>>3] = $116;
  $118 = ((($1)) + 72|0);
  $119 = +HEAPF64[$118>>3];
  $120 = ((($110)) + 72|0);
  HEAPF64[$120>>3] = $119;
  $121 = ((($1)) + 80|0);
  $122 = +HEAPF64[$121>>3];
  $123 = ((($110)) + 80|0);
  HEAPF64[$123>>3] = $122;
  return;
 }
 }
}
function __ZN3osg5cloneIN7osgUtil11RenderStageEEEPT_PKS3_RKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp + 4|0;
 $3 = sp;
 $4 = ($0|0)==(0|0);
 if ($4) {
  $62 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
  if (!($62)) {
   $$1 = 0;
   STACKTOP = sp;return ($$1|0);
  }
  $63 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
  $64 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($63,166509,88)|0);
  $65 = HEAP32[$64>>2]|0;
  $66 = ((($65)) + -12|0);
  $67 = HEAP32[$66>>2]|0;
  $68 = (($64) + ($67)|0);
  __ZNKSt3__28ios_base6getlocEv($3,$68);
  __THREW__ = 0;
  $69 = (invoke_iii(3255,($3|0),(215188|0))|0);
  $70 = __THREW__; __THREW__ = 0;
  $71 = $70&1;
  if (!($71)) {
   $72 = HEAP32[$69>>2]|0;
   $73 = ((($72)) + 28|0);
   $74 = HEAP32[$73>>2]|0;
   __THREW__ = 0;
   $75 = (invoke_iii($74|0,($69|0),10)|0);
   $76 = __THREW__; __THREW__ = 0;
   $77 = $76&1;
   if (!($77)) {
    __ZNSt3__26localeD2Ev($3);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($64,$75)|0);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($64)|0);
    $$1 = 0;
    STACKTOP = sp;return ($$1|0);
   }
  }
  $78 = ___cxa_find_matching_catch_2()|0;
  $79 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3263,($3|0));
  $80 = __THREW__; __THREW__ = 0;
  $81 = $80&1;
  if ($81) {
   $82 = ___cxa_find_matching_catch_3(0|0)|0;
   $83 = tempRet0;
   ___clang_call_terminate($82);
   // unreachable;
  } else {
   ___resumeException($78|0);
   // unreachable;
  }
 }
 $5 = HEAP32[$0>>2]|0;
 $6 = ((($5)) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_iii[$7 & 8191]($0,$1)|0);
 $9 = ($8|0)==(0|0);
 if ($9) {
  label = 9;
 } else {
  $10 = ((($8)) + 8|0);
  $11 = HEAP32[$10>>2]|0;HEAP32[$10>>2] = (($11+1)|0);
  $12 = (___dynamic_cast($8,26112,22912,0)|0);
  $13 = ($12|0)==(0|0);
  if ($13) {
   label = 9;
  } else {
   __THREW__ = 0;
   (invoke_ii(3335,($8|0))|0);
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if ($15) {
    label = 5;
   } else {
    $$1 = $12;
    STACKTOP = sp;return ($$1|0);
   }
  }
 }
 L19: do {
  if ((label|0) == 9) {
   __THREW__ = 0;
   $23 = (invoke_ii(3265,2)|0);
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   if ($25) {
    label = 5;
   } else {
    do {
     if ($23) {
      __THREW__ = 0;
      $26 = (invoke_ii(3266,2)|0);
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       label = 5;
       break L19;
      }
      __THREW__ = 0;
      $29 = (invoke_iiii(3267,($26|0),(166420|0),88)|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 5;
       break L19;
      }
      $32 = HEAP32[$29>>2]|0;
      $33 = ((($32)) + -12|0);
      $34 = HEAP32[$33>>2]|0;
      $35 = (($29) + ($34)|0);
      __THREW__ = 0;
      invoke_vii(3257,($2|0),($35|0));
      $36 = __THREW__; __THREW__ = 0;
      $37 = $36&1;
      if ($37) {
       label = 5;
       break L19;
      }
      __THREW__ = 0;
      $38 = (invoke_iii(3255,($2|0),(215188|0))|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       $41 = HEAP32[$38>>2]|0;
       $42 = ((($41)) + 28|0);
       $43 = HEAP32[$42>>2]|0;
       __THREW__ = 0;
       $44 = (invoke_iii($43|0,($38|0),10)|0);
       $45 = __THREW__; __THREW__ = 0;
       $46 = $45&1;
       if (!($46)) {
        __THREW__ = 0;
        invoke_vi(3263,($2|0));
        $53 = __THREW__; __THREW__ = 0;
        $54 = $53&1;
        if ($54) {
         label = 5;
         break L19;
        }
        __THREW__ = 0;
        (invoke_iii(3268,($29|0),($44|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 5;
         break L19;
        }
        __THREW__ = 0;
        (invoke_ii(3269,($29|0))|0);
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 5;
         break L19;
        } else {
         break;
        }
       }
      }
      $47 = ___cxa_find_matching_catch_2()|0;
      $48 = tempRet0;
      __THREW__ = 0;
      invoke_vi(3263,($2|0));
      $49 = __THREW__; __THREW__ = 0;
      $50 = $49&1;
      if ($50) {
       $51 = ___cxa_find_matching_catch_3(0|0)|0;
       $52 = tempRet0;
       ___clang_call_terminate($51);
       // unreachable;
      } else {
       $eh$lpad$body$index2Z2D = $48;$eh$lpad$body$indexZ2D = $47;
       break L19;
      }
     }
    } while(0);
    if ($9) {
     $$1 = 0;
     STACKTOP = sp;return ($$1|0);
    }
    $59 = ((($8)) + 8|0);
    $60 = HEAP32[$59>>2]|0;HEAP32[$59>>2] = (($60-1)|0);
    $61 = ($60|0)==(1);
    if (!($61)) {
     $$1 = 0;
     STACKTOP = sp;return ($$1|0);
    }
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($8,1,1);
    $$1 = 0;
    STACKTOP = sp;return ($$1|0);
   }
  }
 } while(0);
 if ((label|0) == 5) {
  $16 = ___cxa_find_matching_catch_2()|0;
  $17 = tempRet0;
  $eh$lpad$body$index2Z2D = $17;$eh$lpad$body$indexZ2D = $16;
 }
 if ($9) {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 $18 = ((($8)) + 8|0);
 $19 = HEAP32[$18>>2]|0;HEAP32[$18>>2] = (($19-1)|0);
 $20 = ($19|0)==(1);
 if (!($20)) {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(3262,($8|0),1,1);
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if ($22) {
  $84 = ___cxa_find_matching_catch_3(0|0)|0;
  $85 = tempRet0;
  ___clang_call_terminate($84);
  // unreachable;
 } else {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 return (0)|0;
}
function __ZN7osgUtil9SceneViewC2ERKS0_RKN3osg6CopyOpE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$018 = 0, $$3 = 0, $$321 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0;
 var $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0;
 var $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0;
 var $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0;
 var $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0;
 var $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0;
 var $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0;
 var $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 __ZN3osg6ObjectC2ERKS0_RKNS_6CopyOpE($0,$1,$2);
 $3 = ((($0)) + 32|0);
 $4 = ((($1)) + 32|0);
 __THREW__ = 0;
 invoke_vii(3609,($3|0),($4|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 L1: do {
  if ($6) {
   $123 = ___cxa_find_matching_catch_2()|0;
   $124 = tempRet0;
   $$3 = $124;$$321 = $123;
   label = 106;
  } else {
   HEAP32[$0>>2] = (49380);
   HEAP32[$3>>2] = (49592);
   $7 = ((($0)) + 96|0);
   $8 = ((($0)) + 100|0);
   $9 = ((($0)) + 140|0);
   $10 = ((($0)) + 144|0);
   $11 = ((($0)) + 148|0);
   $12 = ((($0)) + 152|0);
   $13 = ((($0)) + 156|0);
   $14 = ((($0)) + 160|0);
   $15 = ((($0)) + 164|0);
   $16 = ((($0)) + 168|0);
   $17 = ((($0)) + 172|0);
   $18 = ((($0)) + 176|0);
   $19 = ((($0)) + 180|0);
   $20 = ((($0)) + 184|0);
   $21 = ((($0)) + 188|0);
   $22 = ((($0)) + 192|0);
   $23 = ((($0)) + 196|0);
   $24 = ((($0)) + 200|0);
   $25 = ((($0)) + 204|0);
   $26 = ((($0)) + 208|0);
   $27 = ((($0)) + 212|0);
   $28 = ((($0)) + 216|0);
   $29 = ((($0)) + 220|0);
   $30 = ((($0)) + 224|0);
   $31 = ((($0)) + 228|0);
   dest=$7; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
   dest=$9; stop=dest+92|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
   __THREW__ = 0;
   $32 = (invoke_ii(3276,72)|0);
   $33 = __THREW__; __THREW__ = 0;
   $34 = $33&1;
   do {
    if ($34) {
     label = 30;
    } else {
     __THREW__ = 0;
     invoke_vi(3298,($32|0));
     $35 = __THREW__; __THREW__ = 0;
     $36 = $35&1;
     if ($36) {
      $127 = ___cxa_find_matching_catch_2()|0;
      $128 = tempRet0;
      __ZdlPv($32);
      $$0 = $128;$$018 = $127;
      break;
     }
     $37 = HEAP32[$24>>2]|0;
     $38 = ($37|0)==($32|0);
     if (!($38)) {
      HEAP32[$24>>2] = $32;
      $39 = ((($32)) + 8|0);
      $40 = HEAP32[$39>>2]|0;HEAP32[$39>>2] = (($40+1)|0);
      $41 = ($37|0)==(0|0);
      if (!($41)) {
       $42 = ((($37)) + 8|0);
       $43 = HEAP32[$42>>2]|0;HEAP32[$42>>2] = (($43-1)|0);
       $44 = ($43|0)==(1);
       if ($44) {
        __THREW__ = 0;
        invoke_viii(3262,($37|0),1,1);
        $45 = __THREW__; __THREW__ = 0;
        $46 = $45&1;
        if ($46) {
         label = 30;
         break;
        }
       }
      }
     }
     $47 = HEAP32[$30>>2]|0;
     $48 = ((($1)) + 224|0);
     $49 = HEAP32[$48>>2]|0;
     $50 = ($47|0)==($49|0);
     if (!($50)) {
      HEAP32[$30>>2] = $49;
      $51 = ($49|0)==(0|0);
      if (!($51)) {
       $52 = ((($49)) + 8|0);
       $53 = HEAP32[$52>>2]|0;HEAP32[$52>>2] = (($53+1)|0);
      }
      $54 = ($47|0)==(0|0);
      if (!($54)) {
       $55 = ((($47)) + 8|0);
       $56 = HEAP32[$55>>2]|0;HEAP32[$55>>2] = (($56-1)|0);
       $57 = ($56|0)==(1);
       if ($57) {
        __THREW__ = 0;
        invoke_viii(3262,($47|0),1,1);
        $58 = __THREW__; __THREW__ = 0;
        $59 = $58&1;
        if ($59) {
         label = 30;
         break;
        }
       }
      }
     }
     $60 = ((($1)) + 232|0);
     $61 = HEAP32[$60>>2]|0;
     $62 = ((($0)) + 232|0);
     HEAP32[$62>>2] = $61;
     $63 = ((($1)) + 236|0);
     $64 = HEAP32[$63>>2]|0;
     $65 = ((($0)) + 236|0);
     HEAP32[$65>>2] = $64;
     $66 = ((($1)) + 240|0);
     $67 = HEAP32[$66>>2]|0;
     $68 = ((($0)) + 240|0);
     HEAP32[$68>>2] = $67;
     $69 = ((($1)) + 244|0);
     $70 = HEAP8[$69>>0]|0;
     $71 = ((($0)) + 244|0);
     HEAP8[$71>>0] = $70;
     $72 = ($1|0)==($0|0);
     if (!($72)) {
      $73 = HEAP32[$25>>2]|0;
      $74 = ((($1)) + 204|0);
      $75 = HEAP32[$74>>2]|0;
      $76 = ($73|0)==($75|0);
      if (!($76)) {
       HEAP32[$25>>2] = $75;
       $77 = ($75|0)==(0|0);
       if (!($77)) {
        $78 = ((($75)) + 8|0);
        $79 = HEAP32[$78>>2]|0;HEAP32[$78>>2] = (($79+1)|0);
       }
       $80 = ($73|0)==(0|0);
       if (!($80)) {
        $81 = ((($73)) + 8|0);
        $82 = HEAP32[$81>>2]|0;HEAP32[$81>>2] = (($82-1)|0);
        $83 = ($82|0)==(1);
        if ($83) {
         __THREW__ = 0;
         invoke_viii(3262,($73|0),1,1);
         $84 = __THREW__; __THREW__ = 0;
         $85 = $84&1;
         if ($85) {
          label = 30;
          break;
         }
        }
       }
      }
      $86 = ((($1)) + 208|0);
      $87 = HEAP32[$86>>2]|0;
      HEAP32[$26>>2] = $87;
     }
     $88 = HEAP32[$27>>2]|0;
     $89 = ((($1)) + 212|0);
     $90 = HEAP32[$89>>2]|0;
     $91 = ($88|0)==($90|0);
     if (!($91)) {
      HEAP32[$27>>2] = $90;
      $92 = ($90|0)==(0|0);
      if (!($92)) {
       $93 = ((($90)) + 8|0);
       $94 = HEAP32[$93>>2]|0;HEAP32[$93>>2] = (($94+1)|0);
      }
      $95 = ($88|0)==(0|0);
      if (!($95)) {
       $96 = ((($88)) + 8|0);
       $97 = HEAP32[$96>>2]|0;HEAP32[$96>>2] = (($97-1)|0);
       $98 = ($97|0)==(1);
       if ($98) {
        __THREW__ = 0;
        invoke_viii(3262,($88|0),1,1);
        $99 = __THREW__; __THREW__ = 0;
        $100 = $99&1;
        if ($100) {
         label = 30;
         break;
        }
       }
      }
     }
     $101 = ((($0)) + 136|0);
     HEAP8[$101>>0] = 0;
     $102 = ((($1)) + 245|0);
     $103 = HEAP8[$102>>0]|0;
     $104 = ((($0)) + 245|0);
     HEAP8[$104>>0] = $103;
     $105 = ((($0)) + 246|0);
     HEAP8[$105>>0] = 0;
     $106 = ((($1)) + 248|0);
     $107 = HEAP32[$106>>2]|0;
     $108 = ((($0)) + 248|0);
     HEAP32[$108>>2] = $107;
     $109 = ((($0)) + 256|0);
     $110 = ((($1)) + 272|0);
     ;HEAP32[$109>>2]=0|0;HEAP32[$109+4>>2]=0|0;HEAP32[$109+8>>2]=0|0;HEAP32[$109+12>>2]=0|0;
     $111 = HEAP8[$110>>0]|0;
     $112 = ((($0)) + 272|0);
     HEAP8[$112>>0] = $111;
     $113 = ((($1)) + 276|0);
     $114 = HEAP32[$113>>2]|0;
     $115 = ((($0)) + 276|0);
     HEAP32[$115>>2] = $114;
     $116 = ((($1)) + 280|0);
     $117 = HEAP32[$116>>2]|0;
     $118 = ((($0)) + 280|0);
     HEAP32[$118>>2] = $117;
     $119 = ((($0)) + 284|0);
     HEAP32[$119>>2] = 0;
     $120 = ((($1)) + 288|0);
     $121 = HEAP8[$120>>0]|0;
     $122 = ((($0)) + 288|0);
     HEAP8[$122>>0] = $121;
     return;
    }
   } while(0);
   if ((label|0) == 30) {
    $125 = ___cxa_find_matching_catch_2()|0;
    $126 = tempRet0;
    $$0 = $126;$$018 = $125;
   }
   $129 = HEAP32[$31>>2]|0;
   $130 = ($129|0)==(0|0);
   if (!($130)) {
    $131 = ((($129)) + 8|0);
    $132 = HEAP32[$131>>2]|0;HEAP32[$131>>2] = (($132-1)|0);
    $133 = ($132|0)==(1);
    if ($133) {
     __THREW__ = 0;
     invoke_viii(3262,($129|0),1,1);
     $134 = __THREW__; __THREW__ = 0;
     $135 = $134&1;
     if ($135) {
      break;
     }
    }
   }
   HEAP32[$31>>2] = 0;
   $136 = HEAP32[$30>>2]|0;
   $137 = ($136|0)==(0|0);
   if (!($137)) {
    $138 = ((($136)) + 8|0);
    $139 = HEAP32[$138>>2]|0;HEAP32[$138>>2] = (($139-1)|0);
    $140 = ($139|0)==(1);
    if ($140) {
     __THREW__ = 0;
     invoke_viii(3262,($136|0),1,1);
     $141 = __THREW__; __THREW__ = 0;
     $142 = $141&1;
     if ($142) {
      break;
     }
    }
   }
   HEAP32[$30>>2] = 0;
   $143 = HEAP32[$29>>2]|0;
   $144 = ($143|0)==(0|0);
   if (!($144)) {
    $145 = ((($143)) + 8|0);
    $146 = HEAP32[$145>>2]|0;HEAP32[$145>>2] = (($146-1)|0);
    $147 = ($146|0)==(1);
    if ($147) {
     __THREW__ = 0;
     invoke_viii(3262,($143|0),1,1);
     $148 = __THREW__; __THREW__ = 0;
     $149 = $148&1;
     if ($149) {
      break;
     }
    }
   }
   HEAP32[$29>>2] = 0;
   $150 = HEAP32[$28>>2]|0;
   $151 = ($150|0)==(0|0);
   if (!($151)) {
    $152 = ((($150)) + 8|0);
    $153 = HEAP32[$152>>2]|0;HEAP32[$152>>2] = (($153-1)|0);
    $154 = ($153|0)==(1);
    if ($154) {
     __THREW__ = 0;
     invoke_viii(3262,($150|0),1,1);
     $155 = __THREW__; __THREW__ = 0;
     $156 = $155&1;
     if ($156) {
      break;
     }
    }
   }
   HEAP32[$28>>2] = 0;
   $157 = HEAP32[$27>>2]|0;
   $158 = ($157|0)==(0|0);
   if (!($158)) {
    $159 = ((($157)) + 8|0);
    $160 = HEAP32[$159>>2]|0;HEAP32[$159>>2] = (($160-1)|0);
    $161 = ($160|0)==(1);
    if ($161) {
     __THREW__ = 0;
     invoke_viii(3262,($157|0),1,1);
     $162 = __THREW__; __THREW__ = 0;
     $163 = $162&1;
     if ($163) {
      break;
     }
    }
   }
   HEAP32[$27>>2] = 0;
   $164 = HEAP32[$25>>2]|0;
   $165 = ($164|0)==(0|0);
   if (!($165)) {
    $166 = ((($164)) + 8|0);
    $167 = HEAP32[$166>>2]|0;HEAP32[$166>>2] = (($167-1)|0);
    $168 = ($167|0)==(1);
    if ($168) {
     __THREW__ = 0;
     invoke_viii(3262,($164|0),1,1);
     $169 = __THREW__; __THREW__ = 0;
     $170 = $169&1;
     if ($170) {
      break;
     }
    }
   }
   HEAP32[$25>>2] = 0;
   $171 = HEAP32[$24>>2]|0;
   $172 = ($171|0)==(0|0);
   if (!($172)) {
    $173 = ((($171)) + 8|0);
    $174 = HEAP32[$173>>2]|0;HEAP32[$173>>2] = (($174-1)|0);
    $175 = ($174|0)==(1);
    if ($175) {
     __THREW__ = 0;
     invoke_viii(3262,($171|0),1,1);
     $176 = __THREW__; __THREW__ = 0;
     $177 = $176&1;
     if ($177) {
      break;
     }
    }
   }
   HEAP32[$24>>2] = 0;
   $178 = HEAP32[$23>>2]|0;
   $179 = ($178|0)==(0|0);
   if (!($179)) {
    $180 = HEAP32[$178>>2]|0;
    $181 = ((($180)) + -12|0);
    $182 = HEAP32[$181>>2]|0;
    $183 = (($178) + ($182)|0);
    $184 = ((($183)) + 8|0);
    $185 = HEAP32[$184>>2]|0;HEAP32[$184>>2] = (($185-1)|0);
    $186 = ($185|0)==(1);
    if ($186) {
     __THREW__ = 0;
     invoke_viii(3262,($183|0),1,1);
     $187 = __THREW__; __THREW__ = 0;
     $188 = $187&1;
     if ($188) {
      break;
     }
    }
   }
   HEAP32[$23>>2] = 0;
   $189 = HEAP32[$22>>2]|0;
   $190 = ($189|0)==(0|0);
   if (!($190)) {
    $191 = ((($189)) + 8|0);
    $192 = HEAP32[$191>>2]|0;HEAP32[$191>>2] = (($192-1)|0);
    $193 = ($192|0)==(1);
    if ($193) {
     __THREW__ = 0;
     invoke_viii(3262,($189|0),1,1);
     $194 = __THREW__; __THREW__ = 0;
     $195 = $194&1;
     if ($195) {
      break;
     }
    }
   }
   HEAP32[$22>>2] = 0;
   $196 = HEAP32[$21>>2]|0;
   $197 = ($196|0)==(0|0);
   if (!($197)) {
    $198 = ((($196)) + 8|0);
    $199 = HEAP32[$198>>2]|0;HEAP32[$198>>2] = (($199-1)|0);
    $200 = ($199|0)==(1);
    if ($200) {
     __THREW__ = 0;
     invoke_viii(3262,($196|0),1,1);
     $201 = __THREW__; __THREW__ = 0;
     $202 = $201&1;
     if ($202) {
      break;
     }
    }
   }
   HEAP32[$21>>2] = 0;
   $203 = HEAP32[$20>>2]|0;
   $204 = ($203|0)==(0|0);
   if (!($204)) {
    $205 = ((($203)) + 8|0);
    $206 = HEAP32[$205>>2]|0;HEAP32[$205>>2] = (($206-1)|0);
    $207 = ($206|0)==(1);
    if ($207) {
     __THREW__ = 0;
     invoke_viii(3262,($203|0),1,1);
     $208 = __THREW__; __THREW__ = 0;
     $209 = $208&1;
     if ($209) {
      break;
     }
    }
   }
   HEAP32[$20>>2] = 0;
   $210 = HEAP32[$19>>2]|0;
   $211 = ($210|0)==(0|0);
   if (!($211)) {
    $212 = HEAP32[$210>>2]|0;
    $213 = ((($212)) + -12|0);
    $214 = HEAP32[$213>>2]|0;
    $215 = (($210) + ($214)|0);
    $216 = ((($215)) + 8|0);
    $217 = HEAP32[$216>>2]|0;HEAP32[$216>>2] = (($217-1)|0);
    $218 = ($217|0)==(1);
    if ($218) {
     __THREW__ = 0;
     invoke_viii(3262,($215|0),1,1);
     $219 = __THREW__; __THREW__ = 0;
     $220 = $219&1;
     if ($220) {
      break;
     }
    }
   }
   HEAP32[$19>>2] = 0;
   $221 = HEAP32[$18>>2]|0;
   $222 = ($221|0)==(0|0);
   if (!($222)) {
    $223 = ((($221)) + 8|0);
    $224 = HEAP32[$223>>2]|0;HEAP32[$223>>2] = (($224-1)|0);
    $225 = ($224|0)==(1);
    if ($225) {
     __THREW__ = 0;
     invoke_viii(3262,($221|0),1,1);
     $226 = __THREW__; __THREW__ = 0;
     $227 = $226&1;
     if ($227) {
      break;
     }
    }
   }
   HEAP32[$18>>2] = 0;
   $228 = HEAP32[$17>>2]|0;
   $229 = ($228|0)==(0|0);
   if (!($229)) {
    $230 = ((($228)) + 8|0);
    $231 = HEAP32[$230>>2]|0;HEAP32[$230>>2] = (($231-1)|0);
    $232 = ($231|0)==(1);
    if ($232) {
     __THREW__ = 0;
     invoke_viii(3262,($228|0),1,1);
     $233 = __THREW__; __THREW__ = 0;
     $234 = $233&1;
     if ($234) {
      break;
     }
    }
   }
   HEAP32[$17>>2] = 0;
   $235 = HEAP32[$16>>2]|0;
   $236 = ($235|0)==(0|0);
   if (!($236)) {
    $237 = ((($235)) + 8|0);
    $238 = HEAP32[$237>>2]|0;HEAP32[$237>>2] = (($238-1)|0);
    $239 = ($238|0)==(1);
    if ($239) {
     __THREW__ = 0;
     invoke_viii(3262,($235|0),1,1);
     $240 = __THREW__; __THREW__ = 0;
     $241 = $240&1;
     if ($241) {
      break;
     }
    }
   }
   HEAP32[$16>>2] = 0;
   $242 = HEAP32[$15>>2]|0;
   $243 = ($242|0)==(0|0);
   do {
    if (!($243)) {
     $244 = HEAP32[$242>>2]|0;
     $245 = ((($244)) + -12|0);
     $246 = HEAP32[$245>>2]|0;
     $247 = (($242) + ($246)|0);
     $248 = ((($247)) + 8|0);
     $249 = HEAP32[$248>>2]|0;HEAP32[$248>>2] = (($249-1)|0);
     $250 = ($249|0)==(1);
     if (!($250)) {
      break;
     }
     __THREW__ = 0;
     invoke_viii(3262,($247|0),1,1);
     $251 = __THREW__; __THREW__ = 0;
     $252 = $251&1;
     if ($252) {
      break L1;
     }
    }
   } while(0);
   HEAP32[$15>>2] = 0;
   $253 = HEAP32[$14>>2]|0;
   $254 = ($253|0)==(0|0);
   do {
    if (!($254)) {
     $255 = ((($253)) + 8|0);
     $256 = HEAP32[$255>>2]|0;HEAP32[$255>>2] = (($256-1)|0);
     $257 = ($256|0)==(1);
     if (!($257)) {
      break;
     }
     __THREW__ = 0;
     invoke_viii(3262,($253|0),1,1);
     $258 = __THREW__; __THREW__ = 0;
     $259 = $258&1;
     if ($259) {
      break L1;
     }
    }
   } while(0);
   HEAP32[$14>>2] = 0;
   $260 = HEAP32[$13>>2]|0;
   $261 = ($260|0)==(0|0);
   do {
    if (!($261)) {
     $262 = ((($260)) + 8|0);
     $263 = HEAP32[$262>>2]|0;HEAP32[$262>>2] = (($263-1)|0);
     $264 = ($263|0)==(1);
     if (!($264)) {
      break;
     }
     __THREW__ = 0;
     invoke_viii(3262,($260|0),1,1);
     $265 = __THREW__; __THREW__ = 0;
     $266 = $265&1;
     if ($266) {
      break L1;
     }
    }
   } while(0);
   HEAP32[$13>>2] = 0;
   $267 = HEAP32[$12>>2]|0;
   $268 = ($267|0)==(0|0);
   do {
    if (!($268)) {
     $269 = ((($267)) + 8|0);
     $270 = HEAP32[$269>>2]|0;HEAP32[$269>>2] = (($270-1)|0);
     $271 = ($270|0)==(1);
     if (!($271)) {
      break;
     }
     __THREW__ = 0;
     invoke_viii(3262,($267|0),1,1);
     $272 = __THREW__; __THREW__ = 0;
     $273 = $272&1;
     if ($273) {
      break L1;
     }
    }
   } while(0);
   HEAP32[$12>>2] = 0;
   $274 = HEAP32[$11>>2]|0;
   $275 = ($274|0)==(0|0);
   do {
    if (!($275)) {
     $276 = HEAP32[$274>>2]|0;
     $277 = ((($276)) + -12|0);
     $278 = HEAP32[$277>>2]|0;
     $279 = (($274) + ($278)|0);
     $280 = ((($279)) + 8|0);
     $281 = HEAP32[$280>>2]|0;HEAP32[$280>>2] = (($281-1)|0);
     $282 = ($281|0)==(1);
     if (!($282)) {
      break;
     }
     __THREW__ = 0;
     invoke_viii(3262,($279|0),1,1);
     $283 = __THREW__; __THREW__ = 0;
     $284 = $283&1;
     if ($284) {
      break L1;
     }
    }
   } while(0);
   HEAP32[$11>>2] = 0;
   $285 = HEAP32[$10>>2]|0;
   $286 = ($285|0)==(0|0);
   do {
    if (!($286)) {
     $287 = HEAP32[$285>>2]|0;
     $288 = ((($287)) + -12|0);
     $289 = HEAP32[$288>>2]|0;
     $290 = (($285) + ($289)|0);
     $291 = ((($290)) + 8|0);
     $292 = HEAP32[$291>>2]|0;HEAP32[$291>>2] = (($292-1)|0);
     $293 = ($292|0)==(1);
     if (!($293)) {
      break;
     }
     __THREW__ = 0;
     invoke_viii(3262,($290|0),1,1);
     $294 = __THREW__; __THREW__ = 0;
     $295 = $294&1;
     if ($295) {
      break L1;
     }
    }
   } while(0);
   HEAP32[$10>>2] = 0;
   $296 = HEAP32[$9>>2]|0;
   $297 = ($296|0)==(0|0);
   do {
    if (!($297)) {
     $298 = HEAP32[$296>>2]|0;
     $299 = ((($298)) + -12|0);
     $300 = HEAP32[$299>>2]|0;
     $301 = (($296) + ($300)|0);
     $302 = ((($301)) + 8|0);
     $303 = HEAP32[$302>>2]|0;HEAP32[$302>>2] = (($303-1)|0);
     $304 = ($303|0)==(1);
     if (!($304)) {
      break;
     }
     __THREW__ = 0;
     invoke_viii(3262,($301|0),1,1);
     $305 = __THREW__; __THREW__ = 0;
     $306 = $305&1;
     if ($306) {
      break L1;
     }
    }
   } while(0);
   HEAP32[$9>>2] = 0;
   __THREW__ = 0;
   invoke_vi(3504,($8|0));
   $307 = __THREW__; __THREW__ = 0;
   $308 = $307&1;
   if ($308) {
    break;
   }
   $309 = HEAP32[$7>>2]|0;
   $310 = ($309|0)==(0|0);
   do {
    if (!($310)) {
     $311 = ((($309)) + 8|0);
     $312 = HEAP32[$311>>2]|0;HEAP32[$311>>2] = (($312-1)|0);
     $313 = ($312|0)==(1);
     if (!($313)) {
      break;
     }
     __THREW__ = 0;
     invoke_viii(3262,($309|0),1,1);
     $314 = __THREW__; __THREW__ = 0;
     $315 = $314&1;
     if ($315) {
      break L1;
     }
    }
   } while(0);
   HEAP32[$7>>2] = 0;
   HEAP32[$3>>2] = (58232);
   $316 = ((($0)) + 60|0);
   $317 = HEAP32[$316>>2]|0;
   $318 = ($317|0)==(0|0);
   do {
    if (!($318)) {
     $319 = ((($317)) + 8|0);
     $320 = HEAP32[$319>>2]|0;HEAP32[$319>>2] = (($320-1)|0);
     $321 = ($320|0)==(1);
     if (!($321)) {
      break;
     }
     __THREW__ = 0;
     invoke_viii(3262,($317|0),1,1);
     $322 = __THREW__; __THREW__ = 0;
     $323 = $322&1;
     if ($323) {
      break L1;
     }
    }
   } while(0);
   HEAP32[$316>>2] = 0;
   $$3 = $$0;$$321 = $$018;
   label = 106;
  }
 } while(0);
 if ((label|0) == 106) {
  __THREW__ = 0;
  invoke_vi(388,($0|0));
  $324 = __THREW__; __THREW__ = 0;
  $325 = $324&1;
  if (!($325)) {
   ___resumeException($$321|0);
   // unreachable;
  }
 }
 $326 = ___cxa_find_matching_catch_3(0|0)|0;
 $327 = tempRet0;
 ___clang_call_terminate($326);
 // unreachable;
}
function __ZN7osgUtil9SceneViewC2EPN3osg15DisplaySettingsE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$03 = 0, $$3 = 0, $$36 = 0, $$sroa$0$0$$sroa_idx = 0, $$sroa$5$0$$sroa_idx46 = 0, $$sroa$6$0$$sroa_idx49 = 0, $$sroa$7$0$$sroa_idx52 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0;
 var $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0;
 var $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0;
 var $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0;
 var $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0;
 var $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0;
 var $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0;
 var $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0;
 var $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0;
 var $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 __ZN3osg10ReferencedC2Ev($0);
 HEAP32[$0>>2] = (63412);
 $2 = ((($0)) + 12|0);
 ;HEAP32[$2>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;
 $3 = ((($0)) + 24|0);
 HEAP32[$3>>2] = 2;
 $4 = ((($0)) + 28|0);
 HEAP32[$4>>2] = 0;
 $5 = ((($0)) + 32|0);
 HEAP32[$5>>2] = (58232);
 $6 = ((($0)) + 60|0);
 HEAP32[$6>>2] = 0;
 $7 = HEAP32[(58240)>>2]|0;
 __THREW__ = 0;
 invoke_vi($7|0,($5|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 L1: do {
  if ($9) {
   label = 3;
  } else {
   __THREW__ = 0;
   invoke_vi(3610,($5|0));
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if ($11) {
    label = 3;
   } else {
    HEAP32[$0>>2] = (49380);
    HEAP32[$5>>2] = (49592);
    $23 = ((($0)) + 96|0);
    $24 = ((($0)) + 100|0);
    $25 = ((($0)) + 140|0);
    $26 = ((($0)) + 144|0);
    $27 = ((($0)) + 148|0);
    $28 = ((($0)) + 152|0);
    $29 = ((($0)) + 156|0);
    $30 = ((($0)) + 160|0);
    $31 = ((($0)) + 164|0);
    $32 = ((($0)) + 168|0);
    $33 = ((($0)) + 172|0);
    $34 = ((($0)) + 176|0);
    $35 = ((($0)) + 180|0);
    $36 = ((($0)) + 184|0);
    $37 = ((($0)) + 188|0);
    $38 = ((($0)) + 192|0);
    $39 = ((($0)) + 196|0);
    $40 = ((($0)) + 200|0);
    $41 = ((($0)) + 204|0);
    $42 = ((($0)) + 208|0);
    $43 = ((($0)) + 212|0);
    $44 = ((($0)) + 216|0);
    $45 = ((($0)) + 220|0);
    $46 = ((($0)) + 224|0);
    $47 = ((($0)) + 228|0);
    dest=$23; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
    dest=$25; stop=dest+92|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
    __THREW__ = 0;
    $48 = (invoke_ii(3276,72)|0);
    $49 = __THREW__; __THREW__ = 0;
    $50 = $49&1;
    do {
     if ($50) {
      label = 31;
     } else {
      __THREW__ = 0;
      invoke_vi(3298,($48|0));
      $51 = __THREW__; __THREW__ = 0;
      $52 = $51&1;
      if ($52) {
       $120 = ___cxa_find_matching_catch_2()|0;
       $121 = tempRet0;
       __ZdlPv($48);
       $$0 = $121;$$03 = $120;
       break;
      }
      $53 = HEAP32[$40>>2]|0;
      $54 = ($53|0)==($48|0);
      if (!($54)) {
       HEAP32[$40>>2] = $48;
       $55 = ((($48)) + 8|0);
       $56 = HEAP32[$55>>2]|0;HEAP32[$55>>2] = (($56+1)|0);
       $57 = ($53|0)==(0|0);
       if (!($57)) {
        $58 = ((($53)) + 8|0);
        $59 = HEAP32[$58>>2]|0;HEAP32[$58>>2] = (($59-1)|0);
        $60 = ($59|0)==(1);
        if ($60) {
         __THREW__ = 0;
         invoke_viii(3262,($53|0),1,1);
         $61 = __THREW__; __THREW__ = 0;
         $62 = $61&1;
         if ($62) {
          label = 31;
          break;
         }
        }
       }
      }
      $63 = HEAP32[$46>>2]|0;
      $64 = ($63|0)==($1|0);
      if (!($64)) {
       HEAP32[$46>>2] = $1;
       $65 = ($1|0)==(0|0);
       if (!($65)) {
        $66 = ((($1)) + 8|0);
        $67 = HEAP32[$66>>2]|0;HEAP32[$66>>2] = (($67+1)|0);
       }
       $68 = ($63|0)==(0|0);
       if (!($68)) {
        $69 = ((($63)) + 8|0);
        $70 = HEAP32[$69>>2]|0;HEAP32[$69>>2] = (($70-1)|0);
        $71 = ($70|0)==(1);
        if ($71) {
         __THREW__ = 0;
         invoke_viii(3262,($63|0),1,1);
         $72 = __THREW__; __THREW__ = 0;
         $73 = $72&1;
         if ($73) {
          label = 31;
          break;
         }
        }
       }
      }
      $74 = ((($0)) + 232|0);
      HEAP32[$74>>2] = 1;
      $75 = ((($0)) + 236|0);
      HEAPF32[$75>>2] = 1.0;
      $76 = ((($0)) + 240|0);
      HEAP32[$76>>2] = 0;
      $77 = ((($0)) + 244|0);
      HEAP8[$77>>0] = 0;
      __THREW__ = 0;
      $78 = (invoke_ii(3276,656)|0);
      $79 = __THREW__; __THREW__ = 0;
      $80 = $79&1;
      if ($80) {
       label = 31;
      } else {
       __THREW__ = 0;
       invoke_vi(3336,($78|0));
       $81 = __THREW__; __THREW__ = 0;
       $82 = $81&1;
       if ($82) {
        $122 = ___cxa_find_matching_catch_2()|0;
        $123 = tempRet0;
        __ZdlPv($78);
        $$0 = $123;$$03 = $122;
        break;
       }
       __THREW__ = 0;
       invoke_viii(3510,($0|0),($78|0),1);
       $83 = __THREW__; __THREW__ = 0;
       $84 = $83&1;
       if ($84) {
        label = 31;
       } else {
        $85 = HEAP32[$42>>2]|0;
        __THREW__ = 0;
        $86 = (invoke_ii(3276,88)|0);
        $87 = __THREW__; __THREW__ = 0;
        $88 = $87&1;
        if ($88) {
         label = 31;
        } else {
         __THREW__ = 0;
         invoke_vi(3599,($86|0));
         $89 = __THREW__; __THREW__ = 0;
         $90 = $89&1;
         if ($90) {
          $124 = ___cxa_find_matching_catch_2()|0;
          $125 = tempRet0;
          __ZdlPv($86);
          $$0 = $125;$$03 = $124;
          break;
         }
         __THREW__ = 0;
         invoke_vii(3340,($85|0),($86|0));
         $91 = __THREW__; __THREW__ = 0;
         $92 = $91&1;
         if ($92) {
          label = 31;
         } else {
          $93 = HEAP32[$42>>2]|0;
          $$sroa$0$0$$sroa_idx = ((($93)) + 240|0);
          HEAPF32[$$sroa$0$0$$sroa_idx>>2] = 0.20000000298023224;
          $$sroa$5$0$$sroa_idx46 = ((($93)) + 244|0);
          HEAPF32[$$sroa$5$0$$sroa_idx46>>2] = 0.20000000298023224;
          $$sroa$6$0$$sroa_idx49 = ((($93)) + 248|0);
          HEAPF32[$$sroa$6$0$$sroa_idx49>>2] = 0.40000000596046448;
          $$sroa$7$0$$sroa_idx52 = ((($93)) + 252|0);
          HEAPF32[$$sroa$7$0$$sroa_idx52>>2] = 1.0;
          $94 = ((($93)) + 152|0);
          $95 = HEAP32[$94>>2]|0;
          $96 = ($95|0)==(0);
          $97 = ((($93)) + 148|0);
          if ($96) {
           $98 = HEAP32[$97>>2]|0;
           $99 = $98 & -8193;
           HEAP32[$97>>2] = $99;
          }
          $100 = ((($0)) + 136|0);
          HEAP8[$100>>0] = 0;
          $101 = HEAP32[$42>>2]|0;
          $102 = ((($101)) + 568|0);
          HEAP32[$102>>2] = 1029;
          $103 = ((($101)) + 152|0);
          $104 = HEAP32[$103>>2]|0;
          $105 = ($104|0)==(0);
          $106 = ((($101)) + 148|0);
          if (!($105)) {
           $109 = ((($0)) + 245|0);
           HEAP8[$109>>0] = 1;
           $110 = ((($0)) + 246|0);
           HEAP8[$110>>0] = 0;
           $111 = ((($0)) + 248|0);
           HEAP32[$111>>2] = 127;
           $112 = ((($0)) + 256|0);
           $113 = ((($0)) + 272|0);
           ;HEAP32[$112>>2]=0|0;HEAP32[$112+4>>2]=0|0;HEAP32[$112+8>>2]=0|0;HEAP32[$112+12>>2]=0|0;
           HEAP8[$113>>0] = 1;
           $114 = ((($0)) + 276|0);
           HEAP32[$114>>2] = 0;
           $115 = ((($0)) + 280|0);
           HEAP32[$115>>2] = 0;
           $116 = ((($0)) + 284|0);
           HEAP32[$116>>2] = 0;
           $117 = ((($0)) + 288|0);
           HEAP8[$117>>0] = 1;
           return;
          }
          $107 = HEAP32[$106>>2]|0;
          $108 = $107 & -131073;
          HEAP32[$106>>2] = $108;
          $109 = ((($0)) + 245|0);
          HEAP8[$109>>0] = 1;
          $110 = ((($0)) + 246|0);
          HEAP8[$110>>0] = 0;
          $111 = ((($0)) + 248|0);
          HEAP32[$111>>2] = 127;
          $112 = ((($0)) + 256|0);
          $113 = ((($0)) + 272|0);
          ;HEAP32[$112>>2]=0|0;HEAP32[$112+4>>2]=0|0;HEAP32[$112+8>>2]=0|0;HEAP32[$112+12>>2]=0|0;
          HEAP8[$113>>0] = 1;
          $114 = ((($0)) + 276|0);
          HEAP32[$114>>2] = 0;
          $115 = ((($0)) + 280|0);
          HEAP32[$115>>2] = 0;
          $116 = ((($0)) + 284|0);
          HEAP32[$116>>2] = 0;
          $117 = ((($0)) + 288|0);
          HEAP8[$117>>0] = 1;
          return;
         }
        }
       }
      }
     }
    } while(0);
    if ((label|0) == 31) {
     $118 = ___cxa_find_matching_catch_2()|0;
     $119 = tempRet0;
     $$0 = $119;$$03 = $118;
    }
    $126 = HEAP32[$47>>2]|0;
    $127 = ($126|0)==(0|0);
    if (!($127)) {
     $128 = ((($126)) + 8|0);
     $129 = HEAP32[$128>>2]|0;HEAP32[$128>>2] = (($129-1)|0);
     $130 = ($129|0)==(1);
     if ($130) {
      __THREW__ = 0;
      invoke_viii(3262,($126|0),1,1);
      $131 = __THREW__; __THREW__ = 0;
      $132 = $131&1;
      if ($132) {
       break;
      }
     }
    }
    HEAP32[$47>>2] = 0;
    $133 = HEAP32[$46>>2]|0;
    $134 = ($133|0)==(0|0);
    if (!($134)) {
     $135 = ((($133)) + 8|0);
     $136 = HEAP32[$135>>2]|0;HEAP32[$135>>2] = (($136-1)|0);
     $137 = ($136|0)==(1);
     if ($137) {
      __THREW__ = 0;
      invoke_viii(3262,($133|0),1,1);
      $138 = __THREW__; __THREW__ = 0;
      $139 = $138&1;
      if ($139) {
       break;
      }
     }
    }
    HEAP32[$46>>2] = 0;
    $140 = HEAP32[$45>>2]|0;
    $141 = ($140|0)==(0|0);
    if (!($141)) {
     $142 = ((($140)) + 8|0);
     $143 = HEAP32[$142>>2]|0;HEAP32[$142>>2] = (($143-1)|0);
     $144 = ($143|0)==(1);
     if ($144) {
      __THREW__ = 0;
      invoke_viii(3262,($140|0),1,1);
      $145 = __THREW__; __THREW__ = 0;
      $146 = $145&1;
      if ($146) {
       break;
      }
     }
    }
    HEAP32[$45>>2] = 0;
    $147 = HEAP32[$44>>2]|0;
    $148 = ($147|0)==(0|0);
    if (!($148)) {
     $149 = ((($147)) + 8|0);
     $150 = HEAP32[$149>>2]|0;HEAP32[$149>>2] = (($150-1)|0);
     $151 = ($150|0)==(1);
     if ($151) {
      __THREW__ = 0;
      invoke_viii(3262,($147|0),1,1);
      $152 = __THREW__; __THREW__ = 0;
      $153 = $152&1;
      if ($153) {
       break;
      }
     }
    }
    HEAP32[$44>>2] = 0;
    $154 = HEAP32[$43>>2]|0;
    $155 = ($154|0)==(0|0);
    if (!($155)) {
     $156 = ((($154)) + 8|0);
     $157 = HEAP32[$156>>2]|0;HEAP32[$156>>2] = (($157-1)|0);
     $158 = ($157|0)==(1);
     if ($158) {
      __THREW__ = 0;
      invoke_viii(3262,($154|0),1,1);
      $159 = __THREW__; __THREW__ = 0;
      $160 = $159&1;
      if ($160) {
       break;
      }
     }
    }
    HEAP32[$43>>2] = 0;
    $161 = HEAP32[$41>>2]|0;
    $162 = ($161|0)==(0|0);
    if (!($162)) {
     $163 = ((($161)) + 8|0);
     $164 = HEAP32[$163>>2]|0;HEAP32[$163>>2] = (($164-1)|0);
     $165 = ($164|0)==(1);
     if ($165) {
      __THREW__ = 0;
      invoke_viii(3262,($161|0),1,1);
      $166 = __THREW__; __THREW__ = 0;
      $167 = $166&1;
      if ($167) {
       break;
      }
     }
    }
    HEAP32[$41>>2] = 0;
    $168 = HEAP32[$40>>2]|0;
    $169 = ($168|0)==(0|0);
    if (!($169)) {
     $170 = ((($168)) + 8|0);
     $171 = HEAP32[$170>>2]|0;HEAP32[$170>>2] = (($171-1)|0);
     $172 = ($171|0)==(1);
     if ($172) {
      __THREW__ = 0;
      invoke_viii(3262,($168|0),1,1);
      $173 = __THREW__; __THREW__ = 0;
      $174 = $173&1;
      if ($174) {
       break;
      }
     }
    }
    HEAP32[$40>>2] = 0;
    $175 = HEAP32[$39>>2]|0;
    $176 = ($175|0)==(0|0);
    if (!($176)) {
     $177 = HEAP32[$175>>2]|0;
     $178 = ((($177)) + -12|0);
     $179 = HEAP32[$178>>2]|0;
     $180 = (($175) + ($179)|0);
     $181 = ((($180)) + 8|0);
     $182 = HEAP32[$181>>2]|0;HEAP32[$181>>2] = (($182-1)|0);
     $183 = ($182|0)==(1);
     if ($183) {
      __THREW__ = 0;
      invoke_viii(3262,($180|0),1,1);
      $184 = __THREW__; __THREW__ = 0;
      $185 = $184&1;
      if ($185) {
       break;
      }
     }
    }
    HEAP32[$39>>2] = 0;
    $186 = HEAP32[$38>>2]|0;
    $187 = ($186|0)==(0|0);
    if (!($187)) {
     $188 = ((($186)) + 8|0);
     $189 = HEAP32[$188>>2]|0;HEAP32[$188>>2] = (($189-1)|0);
     $190 = ($189|0)==(1);
     if ($190) {
      __THREW__ = 0;
      invoke_viii(3262,($186|0),1,1);
      $191 = __THREW__; __THREW__ = 0;
      $192 = $191&1;
      if ($192) {
       break;
      }
     }
    }
    HEAP32[$38>>2] = 0;
    $193 = HEAP32[$37>>2]|0;
    $194 = ($193|0)==(0|0);
    if (!($194)) {
     $195 = ((($193)) + 8|0);
     $196 = HEAP32[$195>>2]|0;HEAP32[$195>>2] = (($196-1)|0);
     $197 = ($196|0)==(1);
     if ($197) {
      __THREW__ = 0;
      invoke_viii(3262,($193|0),1,1);
      $198 = __THREW__; __THREW__ = 0;
      $199 = $198&1;
      if ($199) {
       break;
      }
     }
    }
    HEAP32[$37>>2] = 0;
    $200 = HEAP32[$36>>2]|0;
    $201 = ($200|0)==(0|0);
    if (!($201)) {
     $202 = ((($200)) + 8|0);
     $203 = HEAP32[$202>>2]|0;HEAP32[$202>>2] = (($203-1)|0);
     $204 = ($203|0)==(1);
     if ($204) {
      __THREW__ = 0;
      invoke_viii(3262,($200|0),1,1);
      $205 = __THREW__; __THREW__ = 0;
      $206 = $205&1;
      if ($206) {
       break;
      }
     }
    }
    HEAP32[$36>>2] = 0;
    $207 = HEAP32[$35>>2]|0;
    $208 = ($207|0)==(0|0);
    if (!($208)) {
     $209 = HEAP32[$207>>2]|0;
     $210 = ((($209)) + -12|0);
     $211 = HEAP32[$210>>2]|0;
     $212 = (($207) + ($211)|0);
     $213 = ((($212)) + 8|0);
     $214 = HEAP32[$213>>2]|0;HEAP32[$213>>2] = (($214-1)|0);
     $215 = ($214|0)==(1);
     if ($215) {
      __THREW__ = 0;
      invoke_viii(3262,($212|0),1,1);
      $216 = __THREW__; __THREW__ = 0;
      $217 = $216&1;
      if ($217) {
       break;
      }
     }
    }
    HEAP32[$35>>2] = 0;
    $218 = HEAP32[$34>>2]|0;
    $219 = ($218|0)==(0|0);
    if (!($219)) {
     $220 = ((($218)) + 8|0);
     $221 = HEAP32[$220>>2]|0;HEAP32[$220>>2] = (($221-1)|0);
     $222 = ($221|0)==(1);
     if ($222) {
      __THREW__ = 0;
      invoke_viii(3262,($218|0),1,1);
      $223 = __THREW__; __THREW__ = 0;
      $224 = $223&1;
      if ($224) {
       break;
      }
     }
    }
    HEAP32[$34>>2] = 0;
    $225 = HEAP32[$33>>2]|0;
    $226 = ($225|0)==(0|0);
    if (!($226)) {
     $227 = ((($225)) + 8|0);
     $228 = HEAP32[$227>>2]|0;HEAP32[$227>>2] = (($228-1)|0);
     $229 = ($228|0)==(1);
     if ($229) {
      __THREW__ = 0;
      invoke_viii(3262,($225|0),1,1);
      $230 = __THREW__; __THREW__ = 0;
      $231 = $230&1;
      if ($231) {
       break;
      }
     }
    }
    HEAP32[$33>>2] = 0;
    $232 = HEAP32[$32>>2]|0;
    $233 = ($232|0)==(0|0);
    do {
     if (!($233)) {
      $234 = ((($232)) + 8|0);
      $235 = HEAP32[$234>>2]|0;HEAP32[$234>>2] = (($235-1)|0);
      $236 = ($235|0)==(1);
      if (!($236)) {
       break;
      }
      __THREW__ = 0;
      invoke_viii(3262,($232|0),1,1);
      $237 = __THREW__; __THREW__ = 0;
      $238 = $237&1;
      if ($238) {
       break L1;
      }
     }
    } while(0);
    HEAP32[$32>>2] = 0;
    $239 = HEAP32[$31>>2]|0;
    $240 = ($239|0)==(0|0);
    do {
     if (!($240)) {
      $241 = HEAP32[$239>>2]|0;
      $242 = ((($241)) + -12|0);
      $243 = HEAP32[$242>>2]|0;
      $244 = (($239) + ($243)|0);
      $245 = ((($244)) + 8|0);
      $246 = HEAP32[$245>>2]|0;HEAP32[$245>>2] = (($246-1)|0);
      $247 = ($246|0)==(1);
      if (!($247)) {
       break;
      }
      __THREW__ = 0;
      invoke_viii(3262,($244|0),1,1);
      $248 = __THREW__; __THREW__ = 0;
      $249 = $248&1;
      if ($249) {
       break L1;
      }
     }
    } while(0);
    HEAP32[$31>>2] = 0;
    $250 = HEAP32[$30>>2]|0;
    $251 = ($250|0)==(0|0);
    do {
     if (!($251)) {
      $252 = ((($250)) + 8|0);
      $253 = HEAP32[$252>>2]|0;HEAP32[$252>>2] = (($253-1)|0);
      $254 = ($253|0)==(1);
      if (!($254)) {
       break;
      }
      __THREW__ = 0;
      invoke_viii(3262,($250|0),1,1);
      $255 = __THREW__; __THREW__ = 0;
      $256 = $255&1;
      if ($256) {
       break L1;
      }
     }
    } while(0);
    HEAP32[$30>>2] = 0;
    $257 = HEAP32[$29>>2]|0;
    $258 = ($257|0)==(0|0);
    do {
     if (!($258)) {
      $259 = ((($257)) + 8|0);
      $260 = HEAP32[$259>>2]|0;HEAP32[$259>>2] = (($260-1)|0);
      $261 = ($260|0)==(1);
      if (!($261)) {
       break;
      }
      __THREW__ = 0;
      invoke_viii(3262,($257|0),1,1);
      $262 = __THREW__; __THREW__ = 0;
      $263 = $262&1;
      if ($263) {
       break L1;
      }
     }
    } while(0);
    HEAP32[$29>>2] = 0;
    $264 = HEAP32[$28>>2]|0;
    $265 = ($264|0)==(0|0);
    do {
     if (!($265)) {
      $266 = ((($264)) + 8|0);
      $267 = HEAP32[$266>>2]|0;HEAP32[$266>>2] = (($267-1)|0);
      $268 = ($267|0)==(1);
      if (!($268)) {
       break;
      }
      __THREW__ = 0;
      invoke_viii(3262,($264|0),1,1);
      $269 = __THREW__; __THREW__ = 0;
      $270 = $269&1;
      if ($270) {
       break L1;
      }
     }
    } while(0);
    HEAP32[$28>>2] = 0;
    $271 = HEAP32[$27>>2]|0;
    $272 = ($271|0)==(0|0);
    do {
     if (!($272)) {
      $273 = HEAP32[$271>>2]|0;
      $274 = ((($273)) + -12|0);
      $275 = HEAP32[$274>>2]|0;
      $276 = (($271) + ($275)|0);
      $277 = ((($276)) + 8|0);
      $278 = HEAP32[$277>>2]|0;HEAP32[$277>>2] = (($278-1)|0);
      $279 = ($278|0)==(1);
      if (!($279)) {
       break;
      }
      __THREW__ = 0;
      invoke_viii(3262,($276|0),1,1);
      $280 = __THREW__; __THREW__ = 0;
      $281 = $280&1;
      if ($281) {
       break L1;
      }
     }
    } while(0);
    HEAP32[$27>>2] = 0;
    $282 = HEAP32[$26>>2]|0;
    $283 = ($282|0)==(0|0);
    do {
     if (!($283)) {
      $284 = HEAP32[$282>>2]|0;
      $285 = ((($284)) + -12|0);
      $286 = HEAP32[$285>>2]|0;
      $287 = (($282) + ($286)|0);
      $288 = ((($287)) + 8|0);
      $289 = HEAP32[$288>>2]|0;HEAP32[$288>>2] = (($289-1)|0);
      $290 = ($289|0)==(1);
      if (!($290)) {
       break;
      }
      __THREW__ = 0;
      invoke_viii(3262,($287|0),1,1);
      $291 = __THREW__; __THREW__ = 0;
      $292 = $291&1;
      if ($292) {
       break L1;
      }
     }
    } while(0);
    HEAP32[$26>>2] = 0;
    $293 = HEAP32[$25>>2]|0;
    $294 = ($293|0)==(0|0);
    do {
     if (!($294)) {
      $295 = HEAP32[$293>>2]|0;
      $296 = ((($295)) + -12|0);
      $297 = HEAP32[$296>>2]|0;
      $298 = (($293) + ($297)|0);
      $299 = ((($298)) + 8|0);
      $300 = HEAP32[$299>>2]|0;HEAP32[$299>>2] = (($300-1)|0);
      $301 = ($300|0)==(1);
      if (!($301)) {
       break;
      }
      __THREW__ = 0;
      invoke_viii(3262,($298|0),1,1);
      $302 = __THREW__; __THREW__ = 0;
      $303 = $302&1;
      if ($303) {
       break L1;
      }
     }
    } while(0);
    HEAP32[$25>>2] = 0;
    __THREW__ = 0;
    invoke_vi(3504,($24|0));
    $304 = __THREW__; __THREW__ = 0;
    $305 = $304&1;
    if ($305) {
     break;
    }
    $306 = HEAP32[$23>>2]|0;
    $307 = ($306|0)==(0|0);
    do {
     if (!($307)) {
      $308 = ((($306)) + 8|0);
      $309 = HEAP32[$308>>2]|0;HEAP32[$308>>2] = (($309-1)|0);
      $310 = ($309|0)==(1);
      if (!($310)) {
       break;
      }
      __THREW__ = 0;
      invoke_viii(3262,($306|0),1,1);
      $311 = __THREW__; __THREW__ = 0;
      $312 = $311&1;
      if ($312) {
       break L1;
      }
     }
    } while(0);
    HEAP32[$23>>2] = 0;
    HEAP32[$5>>2] = (58232);
    $313 = HEAP32[$6>>2]|0;
    $314 = ($313|0)==(0|0);
    do {
     if (!($314)) {
      $315 = ((($313)) + 8|0);
      $316 = HEAP32[$315>>2]|0;HEAP32[$315>>2] = (($316-1)|0);
      $317 = ($316|0)==(1);
      if (!($317)) {
       break;
      }
      __THREW__ = 0;
      invoke_viii(3262,($313|0),1,1);
      $318 = __THREW__; __THREW__ = 0;
      $319 = $318&1;
      if ($319) {
       break L1;
      }
     }
    } while(0);
    HEAP32[$6>>2] = 0;
    $$3 = $$0;$$36 = $$03;
    label = 109;
   }
  }
 } while(0);
 if ((label|0) == 3) {
  $12 = ___cxa_find_matching_catch_2()|0;
  $13 = tempRet0;
  $14 = HEAP32[$6>>2]|0;
  $15 = ($14|0)==(0|0);
  if (!($15)) {
   $16 = ((($14)) + 8|0);
   $17 = HEAP32[$16>>2]|0;HEAP32[$16>>2] = (($17-1)|0);
   $18 = ($17|0)==(1);
   if ($18) {
    __THREW__ = 0;
    invoke_viii(3262,($14|0),1,1);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     $21 = ___cxa_find_matching_catch_3(0|0)|0;
     $22 = tempRet0;
     ___clang_call_terminate($21);
     // unreachable;
    }
   }
  }
  HEAP32[$6>>2] = 0;
  $$3 = $13;$$36 = $12;
  label = 109;
 }
 if ((label|0) == 109) {
  __THREW__ = 0;
  invoke_vi(388,($0|0));
  $320 = __THREW__; __THREW__ = 0;
  $321 = $320&1;
  if (!($321)) {
   ___resumeException($$36|0);
   // unreachable;
  }
 }
 $322 = ___cxa_find_matching_catch_3(0|0)|0;
 $323 = tempRet0;
 ___clang_call_terminate($322);
 // unreachable;
}
function __ZN7osgUtil9SceneView9setCameraEPN3osg6CameraEb($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$$i = 0, $$pr$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = ($1|0)==(0|0);
 do {
  if ($4) {
   $23 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
   if ($23) {
    $24 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
    $25 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($24,113498,68)|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = ((($26)) + -12|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = (($25) + ($28)|0);
    __ZNKSt3__28ios_base6getlocEv($3,$29);
    __THREW__ = 0;
    $30 = (invoke_iii(3255,($3|0),(215188|0))|0);
    $31 = __THREW__; __THREW__ = 0;
    $32 = $31&1;
    if (!($32)) {
     $33 = HEAP32[$30>>2]|0;
     $34 = ((($33)) + 28|0);
     $35 = HEAP32[$34>>2]|0;
     __THREW__ = 0;
     $36 = (invoke_iii($35|0,($30|0),10)|0);
     $37 = __THREW__; __THREW__ = 0;
     $38 = $37&1;
     if (!($38)) {
      __ZNSt3__26localeD2Ev($3);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($25,$36)|0);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($25)|0);
      break;
     }
    }
    $39 = ___cxa_find_matching_catch_2()|0;
    $40 = tempRet0;
    __THREW__ = 0;
    invoke_vi(3263,($3|0));
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     $43 = ___cxa_find_matching_catch_3(0|0)|0;
     $44 = tempRet0;
     ___clang_call_terminate($43);
     // unreachable;
    } else {
     ___resumeException($39|0);
     // unreachable;
    }
   }
  } else {
   $5 = (__ZNK3osg10Referenced22getOrCreateObserverSetEv($1)|0);
   $6 = ((($0)) + 204|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($7|0)==($5|0);
   if ($8) {
    $16 = $5;
   } else {
    HEAP32[$6>>2] = $5;
    $9 = ($5|0)==(0|0);
    if (!($9)) {
     $10 = ((($5)) + 8|0);
     $11 = HEAP32[$10>>2]|0;HEAP32[$10>>2] = (($11+1)|0);
    }
    $12 = ($7|0)==(0|0);
    if (!($12)) {
     $13 = ((($7)) + 8|0);
     $14 = HEAP32[$13>>2]|0;HEAP32[$13>>2] = (($14-1)|0);
     $15 = ($14|0)==(1);
     if ($15) {
      __ZNK3osg10Referenced24signalObserversAndDeleteEbb($7,1,1);
     }
    }
    $$pr$i = HEAP32[$6>>2]|0;
    $16 = $$pr$i;
   }
   $17 = ($16|0)==(0|0);
   if ($17) {
    $22 = 0;
   } else {
    $18 = ((($16)) + 24|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = ($19|0)!=(0|0);
    $$$i = $20 ? $1 : 0;
    $22 = $$$i;
   }
   $21 = ((($0)) + 208|0);
   HEAP32[$21>>2] = $22;
  }
 } while(0);
 if (!($2)) {
  $64 = ((($0)) + 212|0);
  $65 = HEAP32[$64>>2]|0;
  $66 = ($65|0)==(0|0);
  if ($66) {
   STACKTOP = sp;return;
  }
  HEAP32[$64>>2] = 0;
  $67 = ((($65)) + 8|0);
  $68 = HEAP32[$67>>2]|0;HEAP32[$67>>2] = (($68-1)|0);
  $69 = ($68|0)==(1);
  if (!($69)) {
   STACKTOP = sp;return;
  }
  __ZNK3osg10Referenced24signalObserversAndDeleteEbb($65,1,1);
  STACKTOP = sp;return;
 }
 $45 = ((($0)) + 204|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = ($46|0)==(0|0);
 if ($47) {
  $56 = 0;
 } else {
  $48 = ((($46)) + 24|0);
  $49 = HEAP32[$48>>2]|0;
  $50 = ($49|0)==(0|0);
  if ($50) {
   $56 = 0;
  } else {
   $51 = ((($0)) + 208|0);
   $52 = HEAP32[$51>>2]|0;
   $56 = $52;
  }
 }
 $53 = ((($0)) + 212|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = ($54|0)==($56|0);
 if ($55) {
  STACKTOP = sp;return;
 }
 HEAP32[$53>>2] = $56;
 $57 = ($56|0)==(0|0);
 if (!($57)) {
  $58 = ((($56)) + 8|0);
  $59 = HEAP32[$58>>2]|0;HEAP32[$58>>2] = (($59+1)|0);
 }
 $60 = ($54|0)==(0|0);
 if ($60) {
  STACKTOP = sp;return;
 }
 $61 = ((($54)) + 8|0);
 $62 = HEAP32[$61>>2]|0;HEAP32[$61>>2] = (($62-1)|0);
 $63 = ($62|0)==(1);
 if (!($63)) {
  STACKTOP = sp;return;
 }
 __ZNK3osg10Referenced24signalObserversAndDeleteEbb($54,1,1);
 STACKTOP = sp;return;
}
function __ZN7osgUtil9SceneView8getStatsERNS_10StatisticsE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 224|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = ((($3)) + 16|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if (!($7)) {
   $8 = ((($3)) + 20|0);
   $9 = HEAP32[$8>>2]|0;
   switch ($9|0) {
   case 8: case 6: case 7: case 3: case 2: case 1: case 0:  {
    $10 = ((($0)) + 172|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = (__ZNK7osgUtil11RenderStage8getStatsERNS_10StatisticsE($11,$1)|0);
    $13 = ((($0)) + 188|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = (__ZNK7osgUtil11RenderStage8getStatsERNS_10StatisticsE($14,$1)|0);
    $16 = $12 & $15;
    $$0 = $16;
    return ($$0|0);
    break;
   }
   default: {
    $17 = ((($0)) + 156|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = (__ZNK7osgUtil11RenderStage8getStatsERNS_10StatisticsE($18,$1)|0);
    $$0 = $19;
    return ($$0|0);
   }
   }
  }
 }
 $20 = ((($0)) + 156|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (__ZNK7osgUtil11RenderStage8getStatsERNS_10StatisticsE($21,$1)|0);
 $$0 = $22;
 return ($$0|0);
}
function __ZN7osgUtil9SceneView35collateReferencesToDependentCamerasEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 156|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  __ZN7osgUtil11RenderStage35collateReferencesToDependentCamerasEv($2);
 }
 $4 = ((($0)) + 172|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  __ZN7osgUtil11RenderStage35collateReferencesToDependentCamerasEv($5);
 }
 $7 = ((($0)) + 188|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if ($9) {
  return;
 }
 __ZN7osgUtil11RenderStage35collateReferencesToDependentCamerasEv($8);
 return;
}
function __ZN7osgUtil9SceneView33clearReferencesToDependentCamerasEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 156|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  __ZN7osgUtil11RenderStage33clearReferencesToDependentCamerasEv($2);
 }
 $4 = ((($0)) + 172|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  __ZN7osgUtil11RenderStage33clearReferencesToDependentCamerasEv($5);
 }
 $7 = ((($0)) + 188|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if ($9) {
  return;
 }
 __ZN7osgUtil11RenderStage33clearReferencesToDependentCamerasEv($8);
 return;
}
function __ZN7osgUtil16ShaderGenVisitorD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vii(3287,($0|0),(50128|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  $3 = ((($0)) + 68|0);
  __ZN3osg6ObjectD2Ev($3);
  return;
 }
 $4 = ___cxa_find_matching_catch_2()|0;
 $5 = tempRet0;
 $6 = ((($0)) + 68|0);
 __THREW__ = 0;
 invoke_vi(388,($6|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch_3(0|0)|0;
  $10 = tempRet0;
  ___clang_call_terminate($9);
  // unreachable;
 } else {
  ___resumeException($4|0);
  // unreachable;
 }
}
function __ZN7osgUtil16ShaderGenVisitorD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vii(3287,($0|0),(50128|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $6 = ___cxa_find_matching_catch_2()|0;
  $7 = tempRet0;
  $8 = ((($0)) + 68|0);
  __THREW__ = 0;
  invoke_vi(388,($8|0));
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if ($10) {
   $11 = ___cxa_find_matching_catch_3(0|0)|0;
   $12 = tempRet0;
   ___clang_call_terminate($11);
   // unreachable;
  } else {
   $eh$lpad$body$index2Z2D = $7;$eh$lpad$body$indexZ2D = $6;
   __ZdlPv($0);
   ___resumeException($eh$lpad$body$indexZ2D|0);
   // unreachable;
  }
 }
 $3 = ((($0)) + 68|0);
 __THREW__ = 0;
 invoke_vi(388,($3|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  __ZdlPv($0);
  return;
 }
 $13 = ___cxa_find_matching_catch_2()|0;
 $14 = tempRet0;
 $eh$lpad$body$index2Z2D = $14;$eh$lpad$body$indexZ2D = $13;
 __ZdlPv($0);
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
}
function __ZN7osgUtil16ShaderGenVisitor5resetEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 60|0);
 $2 = HEAP32[$1>>2]|0;
 __ZN3osg5State15popAllStateSetsEv($2);
 $3 = ((($0)) + 64|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  return;
 }
 $6 = HEAP32[$1>>2]|0;
 __ZN3osg5State12pushStateSetEPKNS_8StateSetE($6,$4);
 return;
}
function __ZN7osgUtil16ShaderGenVisitor5applyERN3osg8DrawableE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 120|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  __ZN7osgUtil16ShaderGenVisitor6updateEPN3osg8DrawableE($0,$1);
  return;
 } else {
  $5 = ((($0)) + 60|0);
  $6 = HEAP32[$5>>2]|0;
  __ZN3osg5State12pushStateSetEPKNS_8StateSetE($6,$3);
  __ZN7osgUtil16ShaderGenVisitor6updateEPN3osg8DrawableE($0,$1);
  $7 = HEAP32[$5>>2]|0;
  __ZN3osg5State11popStateSetEv($7);
  return;
 }
}
function __ZN7osgUtil16ShaderGenVisitor5applyERN3osg4NodeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 120|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = ((($0)) + 60|0);
  $6 = HEAP32[$5>>2]|0;
  __ZN3osg5State12pushStateSetEPKNS_8StateSetE($6,$3);
  $7 = ((($0)) + 16|0);
  $8 = HEAP32[$7>>2]|0;
  switch ($8|0) {
  case 1:  {
   $9 = HEAP32[$1>>2]|0;
   $10 = ((($9)) + 192|0);
   $11 = HEAP32[$10>>2]|0;
   FUNCTION_TABLE_vii[$11 & 8191]($1,$0);
   break;
  }
  case 0:  {
   break;
  }
  default: {
   $12 = HEAP32[$1>>2]|0;
   $13 = ((($12)) + 196|0);
   $14 = HEAP32[$13>>2]|0;
   FUNCTION_TABLE_vii[$14 & 8191]($1,$0);
  }
  }
  $15 = HEAP32[$5>>2]|0;
  __ZN3osg5State11popStateSetEv($15);
  return;
 }
 $16 = ((($0)) + 16|0);
 $17 = HEAP32[$16>>2]|0;
 switch ($17|0) {
 case 1:  {
  $18 = HEAP32[$1>>2]|0;
  $19 = ((($18)) + 192|0);
  $20 = HEAP32[$19>>2]|0;
  FUNCTION_TABLE_vii[$20 & 8191]($1,$0);
  return;
  break;
 }
 case 0:  {
  return;
  break;
 }
 default: {
  $21 = HEAP32[$1>>2]|0;
  $22 = ((($21)) + 196|0);
  $23 = HEAP32[$22>>2]|0;
  FUNCTION_TABLE_vii[$23 & 8191]($1,$0);
  return;
 }
 }
}
function __ZTv0_n16_N7osgUtil16ShaderGenVisitorD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __THREW__ = 0;
 invoke_vii(3287,($4|0),(50128|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if (!($6)) {
  $14 = ((($4)) + 68|0);
  __ZN3osg6ObjectD2Ev($14);
  return;
 }
 $7 = ___cxa_find_matching_catch_2()|0;
 $8 = tempRet0;
 $9 = ((($4)) + 68|0);
 __THREW__ = 0;
 invoke_vi(388,($9|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if ($11) {
  $12 = ___cxa_find_matching_catch_3(0|0)|0;
  $13 = tempRet0;
  ___clang_call_terminate($12);
  // unreachable;
 } else {
  ___resumeException($7|0);
  // unreachable;
 }
}
function __ZTv0_n16_N7osgUtil16ShaderGenVisitorD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$i$index2Z2D = 0, $eh$lpad$body$i$indexZ2D = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __THREW__ = 0;
 invoke_vii(3287,($4|0),(50128|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $10 = ___cxa_find_matching_catch_2()|0;
  $11 = tempRet0;
  $12 = ((($4)) + 68|0);
  __THREW__ = 0;
  invoke_vi(388,($12|0));
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if ($14) {
   $15 = ___cxa_find_matching_catch_3(0|0)|0;
   $16 = tempRet0;
   ___clang_call_terminate($15);
   // unreachable;
  } else {
   $eh$lpad$body$i$index2Z2D = $11;$eh$lpad$body$i$indexZ2D = $10;
   __ZdlPv($4);
   ___resumeException($eh$lpad$body$i$indexZ2D|0);
   // unreachable;
  }
 }
 $7 = ((($4)) + 68|0);
 __THREW__ = 0;
 invoke_vi(388,($7|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if (!($9)) {
  __ZdlPv($4);
  return;
 }
 $17 = ___cxa_find_matching_catch_2()|0;
 $18 = tempRet0;
 $eh$lpad$body$i$index2Z2D = $18;$eh$lpad$body$i$indexZ2D = $17;
 __ZdlPv($4);
 ___resumeException($eh$lpad$body$i$indexZ2D|0);
 // unreachable;
}
function __ZN7osgUtil16ShaderGenVisitor6updateEPN3osg8DrawableE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$ph$lcssa$i$i$i$i$i = 0, $$0$ph$lcssa$i$i$i$i$i44 = 0, $$0$ph$lcssa$i$i$i$i$i50 = 0, $$0$ph$lcssa$i$i$i$i$i56 = 0, $$0$ph$lcssa$i$i$i$i$i65 = 0, $$0$ph13$i$i$i$i$i = 0, $$0$ph13$i$i$i$i$i51 = 0, $$0$ph14$i$i$i$i$i = 0, $$0$ph14$i$i$i$i$i38 = 0, $$0$ph14$i$i$i$i$i59 = 0, $$07$ph12$i$i$i$i$i = 0, $$07$ph12$i$i$i$i$i52 = 0, $$07$ph13$i$i$i$i$i = 0, $$07$ph13$i$i$i$i$i39 = 0, $$07$ph13$i$i$i$i$i60 = 0, $$0710$i$i$i$i$i = 0, $$0710$i$i$i$i$i54 = 0, $$0711$i$i$i$i$i = 0, $$0711$i$i$i$i$i41 = 0, $$0711$i$i$i$i$i62 = 0;
 var $$1$$ = 0, $$3 = 0, $$70 = 0, $$ph = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 140|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_ii[$4 & 8191]($1)|0);
 $6 = ((($0)) + 60|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($7)) + 668|0);
 $9 = ((($7)) + 672|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$8>>2]|0;
 $12 = (($10) - ($11))|0;
 $13 = $12 >> 2;
 $14 = ((($0)) + 64|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)!=(0|0);
 $17 = $16&1;
 $18 = ($13|0)==($17|0);
 if ($18) {
  return;
 }
 $19 = ((($7)) + 592|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)==(0|0);
 do {
  if (!($21)) {
   $$0$ph14$i$i$i$i$i59 = $19;$$07$ph13$i$i$i$i$i60 = $20;
   L5: while(1) {
    $$0711$i$i$i$i$i62 = $$07$ph13$i$i$i$i$i60;
    while(1) {
     $22 = ((($$0711$i$i$i$i$i62)) + 16|0);
     $23 = HEAP32[$22>>2]|0;
     $24 = ($23|0)<(36);
     if (!($24)) {
      break;
     }
     $27 = ((($$0711$i$i$i$i$i62)) + 4|0);
     $28 = HEAP32[$27>>2]|0;
     $29 = ($28|0)==(0|0);
     if ($29) {
      $$0$ph$lcssa$i$i$i$i$i65 = $$0$ph14$i$i$i$i$i59;
      break L5;
     } else {
      $$0711$i$i$i$i$i62 = $28;
     }
    }
    $25 = HEAP32[$$0711$i$i$i$i$i62>>2]|0;
    $26 = ($25|0)==(0|0);
    if ($26) {
     $$0$ph$lcssa$i$i$i$i$i65 = $$0711$i$i$i$i$i62;
     break;
    } else {
     $$0$ph14$i$i$i$i$i59 = $$0711$i$i$i$i$i62;$$07$ph13$i$i$i$i$i60 = $25;
    }
   }
   $30 = ($$0$ph$lcssa$i$i$i$i$i65|0)==($19|0);
   if (!($30)) {
    $31 = ((($$0$ph$lcssa$i$i$i$i$i65)) + 16|0);
    $32 = HEAP32[$31>>2]|0;
    $33 = ($32|0)>(36);
    if (!($33)) {
     $34 = ($32|0)==(36);
     if ($34) {
      $35 = ((($$0$ph$lcssa$i$i$i$i$i65)) + 20|0);
      $36 = HEAP32[$35>>2]|0;
      $37 = ($36|0)==(0);
      if (!($37)) {
       break;
      }
     }
     $38 = ((($$0$ph$lcssa$i$i$i$i$i65)) + 40|0);
     $39 = ((($$0$ph$lcssa$i$i$i$i$i65)) + 44|0);
     $40 = HEAP32[$39>>2]|0;
     $41 = HEAP32[$38>>2]|0;
     $42 = ($40|0)==($41|0);
     if (!($42)) {
      $43 = $40;
      $44 = ((($43)) + -8|0);
      $45 = HEAP32[$44>>2]|0;
      $46 = ($45|0)==(0|0);
      if (!($46)) {
       return;
      }
     }
    }
   }
  }
 } while(0);
 $47 = ((($7)) + 580|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = ($48|0)==(0|0);
 if ($49) {
  $$70 = 0;$93 = 8;
 } else {
  $$0$ph13$i$i$i$i$i51 = $47;$$07$ph12$i$i$i$i$i52 = $48;
  L21: while(1) {
   $$0710$i$i$i$i$i54 = $$07$ph12$i$i$i$i$i52;
   while(1) {
    $50 = ((($$0710$i$i$i$i$i54)) + 16|0);
    $51 = HEAP32[$50>>2]|0;
    $52 = ($51>>>0)<(2896);
    if (!($52)) {
     break;
    }
    $55 = ((($$0710$i$i$i$i$i54)) + 4|0);
    $56 = HEAP32[$55>>2]|0;
    $57 = ($56|0)==(0|0);
    if ($57) {
     $$0$ph$lcssa$i$i$i$i$i56 = $$0$ph13$i$i$i$i$i51;
     break L21;
    } else {
     $$0710$i$i$i$i$i54 = $56;
    }
   }
   $53 = HEAP32[$$0710$i$i$i$i$i54>>2]|0;
   $54 = ($53|0)==(0|0);
   if ($54) {
    $$0$ph$lcssa$i$i$i$i$i56 = $$0710$i$i$i$i$i54;
    break;
   } else {
    $$0$ph13$i$i$i$i$i51 = $$0710$i$i$i$i$i54;$$07$ph12$i$i$i$i$i52 = $53;
   }
  }
  $58 = ($$0$ph$lcssa$i$i$i$i$i56|0)==($47|0);
  if ($58) {
   $$ph = 8;
  } else {
   $59 = ((($$0$ph$lcssa$i$i$i$i$i56)) + 16|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = ($60>>>0)>(2896);
   if ($61) {
    $$ph = 8;
   } else {
    $62 = ((($$0$ph$lcssa$i$i$i$i$i56)) + 24|0);
    $63 = ((($$0$ph$lcssa$i$i$i$i$i56)) + 28|0);
    $64 = HEAP32[$63>>2]|0;
    $65 = HEAP32[$62>>2]|0;
    $66 = ($64|0)==($65|0);
    if ($66) {
     $$ph = 8;
    } else {
     $67 = $64;
     $68 = ((($67)) + -4|0);
     $69 = HEAP32[$68>>2]|0;
     $$ph = $69;
    }
   }
  }
  $70 = $$ph << 1;
  $71 = $70 & 2;
  $$0$ph13$i$i$i$i$i = $47;$$07$ph12$i$i$i$i$i = $48;
  L33: while(1) {
   $$0710$i$i$i$i$i = $$07$ph12$i$i$i$i$i;
   while(1) {
    $72 = ((($$0710$i$i$i$i$i)) + 16|0);
    $73 = HEAP32[$72>>2]|0;
    $74 = ($73>>>0)<(2912);
    if (!($74)) {
     break;
    }
    $77 = ((($$0710$i$i$i$i$i)) + 4|0);
    $78 = HEAP32[$77>>2]|0;
    $79 = ($78|0)==(0|0);
    if ($79) {
     $$0$ph$lcssa$i$i$i$i$i50 = $$0$ph13$i$i$i$i$i;
     break L33;
    } else {
     $$0710$i$i$i$i$i = $78;
    }
   }
   $75 = HEAP32[$$0710$i$i$i$i$i>>2]|0;
   $76 = ($75|0)==(0|0);
   if ($76) {
    $$0$ph$lcssa$i$i$i$i$i50 = $$0710$i$i$i$i$i;
    break;
   } else {
    $$0$ph13$i$i$i$i$i = $$0710$i$i$i$i$i;$$07$ph12$i$i$i$i$i = $75;
   }
  }
  $80 = ($$0$ph$lcssa$i$i$i$i$i50|0)==($47|0);
  if ($80) {
   $$70 = $71;$93 = 8;
  } else {
   $81 = ((($$0$ph$lcssa$i$i$i$i$i50)) + 16|0);
   $82 = HEAP32[$81>>2]|0;
   $83 = ($82>>>0)>(2912);
   if ($83) {
    $$70 = $71;$93 = 8;
   } else {
    $84 = ((($$0$ph$lcssa$i$i$i$i$i50)) + 24|0);
    $85 = ((($$0$ph$lcssa$i$i$i$i$i50)) + 28|0);
    $86 = HEAP32[$85>>2]|0;
    $87 = HEAP32[$84>>2]|0;
    $88 = ($86|0)==($87|0);
    if ($88) {
     $$70 = $71;$93 = 8;
    } else {
     $89 = $86;
     $90 = ((($89)) + -4|0);
     $91 = HEAP32[$90>>2]|0;
     $$70 = $71;$93 = $91;
    }
   }
  }
 }
 $92 = $93 << 2;
 $94 = $92 & 4;
 $95 = $94 | $$70;
 $96 = ((($7)) + 652|0);
 $97 = ((($7)) + 656|0);
 $98 = HEAP32[$97>>2]|0;
 $99 = HEAP32[$96>>2]|0;
 $100 = ($98|0)==($99|0);
 do {
  if ($100) {
   label = 43;
  } else {
   $101 = $99;
   $102 = ((($101)) + 4|0);
   $103 = HEAP32[$102>>2]|0;
   $104 = ($103|0)==(0|0);
   if ($104) {
    label = 43;
   } else {
    $$0$ph14$i$i$i$i$i38 = $102;$$07$ph13$i$i$i$i$i39 = $103;
    L46: while(1) {
     $$0711$i$i$i$i$i41 = $$07$ph13$i$i$i$i$i39;
     while(1) {
      $105 = ((($$0711$i$i$i$i$i41)) + 16|0);
      $106 = HEAP32[$105>>2]|0;
      $107 = ($106|0)<(0);
      if (!($107)) {
       break;
      }
      $110 = ((($$0711$i$i$i$i$i41)) + 4|0);
      $111 = HEAP32[$110>>2]|0;
      $112 = ($111|0)==(0|0);
      if ($112) {
       $$0$ph$lcssa$i$i$i$i$i44 = $$0$ph14$i$i$i$i$i38;
       break L46;
      } else {
       $$0711$i$i$i$i$i41 = $111;
      }
     }
     $108 = HEAP32[$$0711$i$i$i$i$i41>>2]|0;
     $109 = ($108|0)==(0|0);
     if ($109) {
      $$0$ph$lcssa$i$i$i$i$i44 = $$0711$i$i$i$i$i41;
      break;
     } else {
      $$0$ph14$i$i$i$i$i38 = $$0711$i$i$i$i$i41;$$07$ph13$i$i$i$i$i39 = $108;
     }
    }
    $113 = ($$0$ph$lcssa$i$i$i$i$i44|0)==($102|0);
    if ($113) {
     label = 43;
    } else {
     $114 = ((($$0$ph$lcssa$i$i$i$i$i44)) + 16|0);
     $115 = HEAP32[$114>>2]|0;
     $116 = ($115|0)>(0);
     if ($116) {
      label = 43;
     } else {
      $117 = ($115|0)<(0);
      if (!($117)) {
       $118 = ((($$0$ph$lcssa$i$i$i$i$i44)) + 20|0);
       $119 = HEAP32[$118>>2]|0;
       $120 = ($119|0)==(0);
       if (!($120)) {
        label = 43;
        break;
       }
      }
      $121 = ((($$0$ph$lcssa$i$i$i$i$i44)) + 40|0);
      $122 = ((($$0$ph$lcssa$i$i$i$i$i44)) + 44|0);
      $123 = HEAP32[$122>>2]|0;
      $124 = HEAP32[$121>>2]|0;
      $125 = ($123|0)==($124|0);
      if ($125) {
       label = 43;
      } else {
       $126 = $123;
       $127 = ((($126)) + -8|0);
       $128 = HEAP32[$127>>2]|0;
       $phitmp = ($128|0)==(0|0);
       $129 = $95 | 8;
       if ($phitmp) {
        label = 43;
       } else {
        $164 = $129;
       }
      }
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 43) {
  $164 = $95;
 }
 $130 = (($98) - ($99))|0;
 $131 = (($130|0) / 12)&-1;
 $132 = ($131>>>0)>(1);
 do {
  if ($132) {
   $133 = $99;
   $134 = ((($133)) + 16|0);
   $135 = HEAP32[$134>>2]|0;
   $136 = ($135|0)==(0|0);
   if ($136) {
    $$3 = $164;
   } else {
    $$0$ph14$i$i$i$i$i = $134;$$07$ph13$i$i$i$i$i = $135;
    L64: while(1) {
     $$0711$i$i$i$i$i = $$07$ph13$i$i$i$i$i;
     while(1) {
      $137 = ((($$0711$i$i$i$i$i)) + 16|0);
      $138 = HEAP32[$137>>2]|0;
      $139 = ($138|0)<(0);
      if (!($139)) {
       break;
      }
      $142 = ((($$0711$i$i$i$i$i)) + 4|0);
      $143 = HEAP32[$142>>2]|0;
      $144 = ($143|0)==(0|0);
      if ($144) {
       $$0$ph$lcssa$i$i$i$i$i = $$0$ph14$i$i$i$i$i;
       break L64;
      } else {
       $$0711$i$i$i$i$i = $143;
      }
     }
     $140 = HEAP32[$$0711$i$i$i$i$i>>2]|0;
     $141 = ($140|0)==(0|0);
     if ($141) {
      $$0$ph$lcssa$i$i$i$i$i = $$0711$i$i$i$i$i;
      break;
     } else {
      $$0$ph14$i$i$i$i$i = $$0711$i$i$i$i$i;$$07$ph13$i$i$i$i$i = $140;
     }
    }
    $145 = ($$0$ph$lcssa$i$i$i$i$i|0)==($134|0);
    if ($145) {
     $$3 = $164;
    } else {
     $146 = ((($$0$ph$lcssa$i$i$i$i$i)) + 16|0);
     $147 = HEAP32[$146>>2]|0;
     $148 = ($147|0)>(0);
     if ($148) {
      $$3 = $164;
     } else {
      $149 = ($147|0)<(0);
      if (!($149)) {
       $150 = ((($$0$ph$lcssa$i$i$i$i$i)) + 20|0);
       $151 = HEAP32[$150>>2]|0;
       $152 = ($151|0)==(0);
       if (!($152)) {
        $$3 = $164;
        break;
       }
      }
      $153 = ((($$0$ph$lcssa$i$i$i$i$i)) + 40|0);
      $154 = ((($$0$ph$lcssa$i$i$i$i$i)) + 44|0);
      $155 = HEAP32[$154>>2]|0;
      $156 = HEAP32[$153>>2]|0;
      $157 = ($155|0)==($156|0);
      if ($157) {
       $$3 = $164;
      } else {
       $158 = $155;
       $159 = ((($158)) + -8|0);
       $160 = HEAP32[$159>>2]|0;
       $161 = ($160|0)!=(0|0);
       $162 = ($5|0)!=(0|0);
       $or$cond = $162 & $161;
       if ($or$cond) {
        $163 = $164 | 16;
        $165 = (__ZN3osg8Geometry20getVertexAttribArrayEj($5,6)|0);
        $166 = ($165|0)==(0|0);
        $$1$$ = $166 ? $164 : $163;
        $$3 = $$1$$;
       } else {
        $$3 = $164;
       }
      }
     }
    }
   }
  } else {
   $$3 = $164;
  }
 } while(0);
 $167 = ((($0)) + 56|0);
 $168 = HEAP32[$167>>2]|0;
 $169 = (__ZN7osgUtil14ShaderGenCache19getOrCreateStateSetEi($168,$$3)|0);
 $170 = HEAP32[$9>>2]|0;
 $171 = ((($170)) + -4|0);
 $172 = HEAP32[$171>>2]|0;
 $173 = (__ZN3osg8StateSet12getAttributeENS_14StateAttribute4TypeEj($169,36,0)|0);
 __ZN3osg8StateSet12setAttributeEPNS_14StateAttributeEj($172,$173,0);
 $174 = ((($169)) + 92|0);
 __ZN3osg8StateSet14setUniformListERNSt3__23mapINS1_12basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEENS1_4pairINS_7ref_ptrINS_7UniformEEEjEENS1_4lessIS8_EENS6_INS9_IKS8_SD_EEEEEE($172,$174);
 $175 = $$3 & 2;
 $176 = ($175|0)==(0);
 if (!($176)) {
  __ZN3osg8StateSet10removeModeEj($172,2896);
  __ZN3osg8StateSet10removeModeEj($172,16384);
 }
 $177 = $$3 & 4;
 $178 = ($177|0)==(0);
 if (!($178)) {
  __ZN3osg8StateSet10removeModeEj($172,2912);
 }
 $179 = $$3 & 8;
 $180 = ($179|0)==(0);
 if (!($180)) {
  __ZN3osg8StateSet17removeTextureModeEjj($172,0,3553);
 }
 $181 = $$3 & 16;
 $182 = ($181|0)==(0);
 if ($182) {
  return;
 }
 __ZN3osg8StateSet17removeTextureModeEjj($172,1,3553);
 return;
}
function __ZN7osgUtil14ShaderGenCache19getOrCreateStateSetEi($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$0$ph$lcssa$i$i$i = 0, $$0$ph13$i$i$i = 0, $$07 = 0, $$07$ph12$i$i$i = 0, $$0710$i$i$i = 0, $$08 = 0, $$1 = 0, $$19 = 0, $$2 = 0, $$210 = 0, $$byval_copy = 0, $$pre$i$i$i$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $11 = 0, $12 = 0;
 var $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $$byval_copy = sp + 20|0;
 $2 = sp + 16|0;
 $3 = sp + 12|0;
 $4 = sp + 8|0;
 $5 = sp;
 $6 = ((($0)) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($7)) + 8|0);
 $9 = HEAP32[$8>>2]|0;
 (FUNCTION_TABLE_ii[$9 & 8191]($6)|0);
 $10 = ((($0)) + 24|0);
 $11 = ((($0)) + 28|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0|0);
 if (!($13)) {
  $$0$ph13$i$i$i = $11;$$07$ph12$i$i$i = $12;
  L2: while(1) {
   $$0710$i$i$i = $$07$ph12$i$i$i;
   while(1) {
    $14 = ((($$0710$i$i$i)) + 16|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = ($15|0)<($1|0);
    if (!($16)) {
     break;
    }
    $19 = ((($$0710$i$i$i)) + 4|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = ($20|0)==(0|0);
    if ($21) {
     $$0$ph$lcssa$i$i$i = $$0$ph13$i$i$i;
     break L2;
    } else {
     $$0710$i$i$i = $20;
    }
   }
   $17 = HEAP32[$$0710$i$i$i>>2]|0;
   $18 = ($17|0)==(0|0);
   if ($18) {
    $$0$ph$lcssa$i$i$i = $$0710$i$i$i;
    break;
   } else {
    $$0$ph13$i$i$i = $$0710$i$i$i;$$07$ph12$i$i$i = $17;
   }
  }
  $22 = ($$0$ph$lcssa$i$i$i|0)==($11|0);
  if (!($22)) {
   $23 = ((($$0$ph$lcssa$i$i$i)) + 16|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = ($24|0)>($1|0);
   if (!($25)) {
    $92 = ((($$0$ph$lcssa$i$i$i)) + 20|0);
    $93 = HEAP32[$92>>2]|0;
    $$0 = $93;
    $94 = HEAP32[$6>>2]|0;
    $95 = ((($94)) + 12|0);
    $96 = HEAP32[$95>>2]|0;
    (FUNCTION_TABLE_ii[$96 & 8191]($6)|0);
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 __THREW__ = 0;
 $26 = (invoke_iii(3611,0,($1|0))|0);
 $27 = __THREW__; __THREW__ = 0;
 $28 = $27&1;
 if ($28) {
  $73 = ___cxa_find_matching_catch_2()|0;
  $74 = tempRet0;
  $$2 = $73;$$210 = $74;
 } else {
  $29 = $11;
  $30 = ((($26)) + 8|0);
  $31 = HEAP32[$30>>2]|0;HEAP32[$30>>2] = (($31+1)|0);
  HEAP32[$5>>2] = $1;
  $32 = ((($5)) + 4|0);
  HEAP32[$32>>2] = $26;
  $33 = HEAP32[$30>>2]|0;HEAP32[$30>>2] = (($33+1)|0);
  HEAP32[$4>>2] = $29;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy>>2]=HEAP32[$4>>2]|0;
  $34 = (invoke_iiiiii(3612,($10|0),($$byval_copy|0),($2|0),($3|0),($5|0))|0);
  $35 = __THREW__; __THREW__ = 0;
  $36 = $35&1;
  do {
   if ($36) {
    label = 26;
   } else {
    $37 = HEAP32[$34>>2]|0;
    $38 = ($37|0)==(0|0);
    if ($38) {
     __THREW__ = 0;
     $39 = (invoke_ii(3276,24)|0);
     $40 = __THREW__; __THREW__ = 0;
     $41 = $40&1;
     if ($41) {
      label = 26;
      break;
     }
     $42 = ((($39)) + 16|0);
     $43 = HEAP32[$5>>2]|0;
     HEAP32[$42>>2] = $43;
     $44 = ((($39)) + 20|0);
     $45 = HEAP32[$32>>2]|0;
     HEAP32[$44>>2] = $45;
     $46 = ($45|0)==(0|0);
     if (!($46)) {
      $47 = ((($45)) + 8|0);
      $48 = HEAP32[$47>>2]|0;HEAP32[$47>>2] = (($48+1)|0);
     }
     $49 = HEAP32[$2>>2]|0;
     HEAP32[$39>>2] = 0;
     $50 = ((($39)) + 4|0);
     HEAP32[$50>>2] = 0;
     $51 = ((($39)) + 8|0);
     HEAP32[$51>>2] = $49;
     HEAP32[$34>>2] = $39;
     $52 = HEAP32[$10>>2]|0;
     $53 = HEAP32[$52>>2]|0;
     $54 = ($53|0)==(0|0);
     if ($54) {
      $58 = $39;
     } else {
      $55 = $53;
      HEAP32[$10>>2] = $55;
      $$pre$i$i$i$i = HEAP32[$34>>2]|0;
      $58 = $$pre$i$i$i$i;
     }
     $56 = ((($0)) + 28|0);
     $57 = HEAP32[$56>>2]|0;
     __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($57,$58);
     $59 = ((($0)) + 32|0);
     $60 = HEAP32[$59>>2]|0;
     $61 = (($60) + 1)|0;
     HEAP32[$59>>2] = $61;
    }
    $62 = HEAP32[$32>>2]|0;
    $63 = ($62|0)==(0|0);
    if (!($63)) {
     $64 = ((($62)) + 8|0);
     $65 = HEAP32[$64>>2]|0;HEAP32[$64>>2] = (($65-1)|0);
     $66 = ($65|0)==(1);
     if ($66) {
      __THREW__ = 0;
      invoke_viii(3262,($62|0),1,1);
      $67 = __THREW__; __THREW__ = 0;
      $68 = $67&1;
      if ($68) {
       $77 = ___cxa_find_matching_catch_2()|0;
       $78 = tempRet0;
       $$07 = $77;$$08 = $78;
       label = 30;
       break;
      }
     }
    }
    HEAP32[$32>>2] = 0;
    $69 = HEAP32[$30>>2]|0;HEAP32[$30>>2] = (($69-1)|0);
    $70 = ($69|0)==(1);
    if ($70) {
     __THREW__ = 0;
     invoke_viii(3262,($26|0),1,1);
     $71 = __THREW__; __THREW__ = 0;
     $72 = $71&1;
     if ($72) {
      $75 = ___cxa_find_matching_catch_2()|0;
      $76 = tempRet0;
      $$1 = $75;$$19 = $76;
      break;
     }
    }
    $$0 = $26;
    $94 = HEAP32[$6>>2]|0;
    $95 = ((($94)) + 12|0);
    $96 = HEAP32[$95>>2]|0;
    (FUNCTION_TABLE_ii[$96 & 8191]($6)|0);
    STACKTOP = sp;return ($$0|0);
   }
  } while(0);
  if ((label|0) == 26) {
   $79 = ___cxa_find_matching_catch_2()|0;
   $80 = tempRet0;
   $81 = HEAP32[$32>>2]|0;
   $82 = ($81|0)==(0|0);
   if (!($82)) {
    $83 = ((($81)) + 8|0);
    $84 = HEAP32[$83>>2]|0;HEAP32[$83>>2] = (($84-1)|0);
    $85 = ($84|0)==(1);
    if ($85) {
     __THREW__ = 0;
     invoke_viii(3262,($81|0),1,1);
     $86 = __THREW__; __THREW__ = 0;
     $87 = $86&1;
     if ($87) {
      $102 = ___cxa_find_matching_catch_3(0|0)|0;
      $103 = tempRet0;
      ___clang_call_terminate($102);
      // unreachable;
     }
    }
   }
   HEAP32[$32>>2] = 0;
   $$07 = $79;$$08 = $80;
   label = 30;
  }
  if ((label|0) == 30) {
   $88 = HEAP32[$30>>2]|0;HEAP32[$30>>2] = (($88-1)|0);
   $89 = ($88|0)==(1);
   if ($89) {
    __THREW__ = 0;
    invoke_viii(3262,($26|0),1,1);
    $90 = __THREW__; __THREW__ = 0;
    $91 = $90&1;
    if ($91) {
     $102 = ___cxa_find_matching_catch_3(0|0)|0;
     $103 = tempRet0;
     ___clang_call_terminate($102);
     // unreachable;
    } else {
     $$1 = $$07;$$19 = $$08;
    }
   } else {
    $$1 = $$07;$$19 = $$08;
   }
  }
  $$2 = $$1;$$210 = $$19;
 }
 $97 = HEAP32[$6>>2]|0;
 $98 = ((($97)) + 12|0);
 $99 = HEAP32[$98>>2]|0;
 __THREW__ = 0;
 (invoke_ii($99|0,($6|0))|0);
 $100 = __THREW__; __THREW__ = 0;
 $101 = $100&1;
 if ($101) {
  $102 = ___cxa_find_matching_catch_3(0|0)|0;
  $103 = tempRet0;
  ___clang_call_terminate($102);
  // unreachable;
 } else {
  ___resumeException($$2|0);
  // unreachable;
 }
 return (0)|0;
}
function __ZN3osg8StateSet14setUniformListERNSt3__23mapINS1_12basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEENS1_4pairINS_7ref_ptrINS_7UniformEEEjEENS1_4lessIS8_EENS6_INS9_IKS8_SD_EEEEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i$i = 0, $$byval_copy = 0, $$pre$i$i$i$i$i$i = 0, $$sroa$07$0$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy = sp + 12|0;
 $2 = sp + 8|0;
 $3 = sp + 4|0;
 $4 = sp;
 $5 = ((($0)) + 92|0);
 $6 = ($5|0)==($1|0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = ((($0)) + 96|0);
 $8 = HEAP32[$7>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4pairIN3osg7ref_ptrINS9_7UniformEEEjEEEENS_19__map_value_compareIS7_SE_NS_4lessIS7_EELb1EEENS5_ISE_EEE7destroyEPNS_11__tree_nodeISE_PvEE($5,$8);
 $9 = ((($0)) + 100|0);
 HEAP32[$9>>2] = 0;
 HEAP32[$5>>2] = $7;
 HEAP32[$7>>2] = 0;
 $10 = HEAP32[$1>>2]|0;
 $11 = ((($1)) + 4|0);
 $12 = ($10|0)==($11|0);
 if ($12) {
  STACKTOP = sp;return;
 }
 $13 = $7;
 $14 = ((($0)) + 96|0);
 $$sroa$07$0$i = $10;
 while(1) {
  $15 = ((($$sroa$07$0$i)) + 16|0);
  HEAP32[$4>>2] = $13;
  ;HEAP32[$$byval_copy>>2]=HEAP32[$4>>2]|0;
  $16 = (__ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4pairIN3osg7ref_ptrINS9_7UniformEEEjEEEENS_19__map_value_compareIS7_SE_NS_4lessIS7_EELb1EEENS5_ISE_EEE12__find_equalIS7_EERPNS_16__tree_node_baseIPvEENS_21__tree_const_iteratorISE_PNS_11__tree_nodeISE_SN_EEiEERPNS_15__tree_end_nodeISP_EESQ_RKT_($5,$$byval_copy,$2,$3,$15)|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = ($17|0)==(0|0);
  if ($18) {
   $19 = (__Znwj(36)|0);
   $20 = ((($19)) + 16|0);
   __THREW__ = 0;
   invoke_vii(3457,($20|0),($15|0));
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if ($22) {
    label = 8;
    break;
   }
   $23 = ((($19)) + 28|0);
   $24 = ((($$sroa$07$0$i)) + 28|0);
   $25 = HEAP32[$24>>2]|0;
   HEAP32[$23>>2] = $25;
   $26 = ($25|0)==(0|0);
   if (!($26)) {
    $27 = ((($25)) + 8|0);
    $28 = HEAP32[$27>>2]|0;HEAP32[$27>>2] = (($28+1)|0);
   }
   $31 = ((($19)) + 32|0);
   $32 = ((($$sroa$07$0$i)) + 32|0);
   $33 = HEAP32[$32>>2]|0;
   HEAP32[$31>>2] = $33;
   $34 = HEAP32[$2>>2]|0;
   HEAP32[$19>>2] = 0;
   $35 = ((($19)) + 4|0);
   HEAP32[$35>>2] = 0;
   $36 = ((($19)) + 8|0);
   HEAP32[$36>>2] = $34;
   HEAP32[$16>>2] = $19;
   $37 = HEAP32[$5>>2]|0;
   $38 = HEAP32[$37>>2]|0;
   $39 = ($38|0)==(0|0);
   if ($39) {
    $42 = $19;
   } else {
    $40 = $38;
    HEAP32[$5>>2] = $40;
    $$pre$i$i$i$i$i$i = HEAP32[$16>>2]|0;
    $42 = $$pre$i$i$i$i$i$i;
   }
   $41 = HEAP32[$14>>2]|0;
   __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($41,$42);
   $43 = HEAP32[$9>>2]|0;
   $44 = (($43) + 1)|0;
   HEAP32[$9>>2] = $44;
  }
  $45 = ((($$sroa$07$0$i)) + 4|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = ($46|0)==(0|0);
  if ($47) {
   $48 = ((($$sroa$07$0$i)) + 8|0);
   $49 = HEAP32[$48>>2]|0;
   $50 = HEAP32[$49>>2]|0;
   $51 = ($50|0)==($$sroa$07$0$i|0);
   if ($51) {
    $$0$i$i$i$i$i = $49;
   } else {
    $55 = $48;
    while(1) {
     $54 = HEAP32[$55>>2]|0;
     $56 = ((($54)) + 8|0);
     $57 = HEAP32[$56>>2]|0;
     $58 = HEAP32[$57>>2]|0;
     $59 = ($58|0)==($54|0);
     if ($59) {
      $$0$i$i$i$i$i = $57;
      break;
     } else {
      $55 = $56;
     }
    }
   }
  } else {
   $$0$i$i$i$i$i$i = $46;
   while(1) {
    $52 = HEAP32[$$0$i$i$i$i$i$i>>2]|0;
    $53 = ($52|0)==(0|0);
    if ($53) {
     break;
    } else {
     $$0$i$i$i$i$i$i = $52;
    }
   }
   $$0$i$i$i$i$i = $$0$i$i$i$i$i$i;
  }
  $60 = ($$0$i$i$i$i$i|0)==($11|0);
  if ($60) {
   label = 18;
   break;
  } else {
   $$sroa$07$0$i = $$0$i$i$i$i$i;
  }
 }
 if ((label|0) == 8) {
  $29 = ___cxa_find_matching_catch_2()|0;
  $30 = tempRet0;
  __ZdlPv($19);
  ___resumeException($29|0);
  // unreachable;
 }
 else if ((label|0) == 18) {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4pairIN3osg7ref_ptrINS9_7UniformEEEjEEEENS_19__map_value_compareIS7_SE_NS_4lessIS7_EELb1EEENS5_ISE_EEE7destroyEPNS_11__tree_nodeISE_PvEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 }
 $3 = HEAP32[$1>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4pairIN3osg7ref_ptrINS9_7UniformEEEjEEEENS_19__map_value_compareIS7_SE_NS_4lessIS7_EELb1EEENS5_ISE_EEE7destroyEPNS_11__tree_nodeISE_PvEE($0,$3);
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4pairIN3osg7ref_ptrINS9_7UniformEEEjEEEENS_19__map_value_compareIS7_SE_NS_4lessIS7_EELb1EEENS5_ISE_EEE7destroyEPNS_11__tree_nodeISE_PvEE($0,$5);
 $6 = ((($1)) + 16|0);
 $7 = ((($1)) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if (!($9)) {
  $10 = ((($8)) + 8|0);
  $11 = HEAP32[$10>>2]|0;HEAP32[$10>>2] = (($11-1)|0);
  $12 = ($11|0)==(1);
  if ($12) {
   __THREW__ = 0;
   invoke_viii(3262,($8|0),1,1);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if ($14) {
    $19 = ___cxa_find_matching_catch_2()|0;
    $20 = tempRet0;
    $21 = ((($6)) + 11|0);
    $22 = HEAP8[$21>>0]|0;
    $23 = ($22<<24>>24)<(0);
    if (!($23)) {
     ___cxa_call_unexpected(($19|0));
     // unreachable;
    }
    $24 = HEAP32[$6>>2]|0;
    __ZdlPv($24);
    ___cxa_call_unexpected(($19|0));
    // unreachable;
   }
  }
 }
 HEAP32[$7>>2] = 0;
 $15 = ((($6)) + 11|0);
 $16 = HEAP8[$15>>0]|0;
 $17 = ($16<<24>>24)<(0);
 if ($17) {
  $18 = HEAP32[$6>>2]|0;
  __ZdlPv($18);
 }
 __ZdlPv($1);
 return;
}
function __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4pairIN3osg7ref_ptrINS9_7UniformEEEjEEEENS_19__map_value_compareIS7_SE_NS_4lessIS7_EELb1EEENS5_ISE_EEE12__find_equalIS7_EERPNS_16__tree_node_baseIPvEENS_21__tree_const_iteratorISE_PNS_11__tree_nodeISE_SN_EEiEERPNS_15__tree_end_nodeISP_EESQ_RKT_($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0$i$i = 0, $$0$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i$i = 0, $$08$i$i = 0, $$2 = 0, $$pre = 0, $$sroa$052$0 = 0, $$sroa$speculated$i$i$i$i$i = 0, $$sroa$speculated$i$i$i$i$i21 = 0, $$sroa$speculated$i$i$i$i$i26 = 0, $$sroa$speculated$i$i$i$i$i32 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = ((($0)) + 4|0);
 $6 = HEAP32[$1>>2]|0;
 $7 = ($6|0)==($5|0);
 $8 = $6;
 do {
  if (!($7)) {
   $9 = ((($6)) + 16|0);
   $10 = ((($9)) + 11|0);
   $11 = HEAP8[$10>>0]|0;
   $12 = ($11<<24>>24)<(0);
   $13 = ((($6)) + 20|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = $11&255;
   $16 = $12 ? $14 : $15;
   $17 = ((($4)) + 11|0);
   $18 = HEAP8[$17>>0]|0;
   $19 = ($18<<24>>24)<(0);
   $20 = ((($4)) + 4|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = $18&255;
   $23 = $19 ? $21 : $22;
   $24 = ($16>>>0)<($23>>>0);
   $$sroa$speculated$i$i$i$i$i32 = $24 ? $16 : $23;
   $25 = ($$sroa$speculated$i$i$i$i$i32|0)==(0);
   if ($25) {
    label = 4;
   } else {
    $26 = HEAP32[$4>>2]|0;
    $27 = $19 ? $26 : $4;
    $28 = HEAP32[$9>>2]|0;
    $29 = $12 ? $28 : $9;
    $30 = (_memcmp($27,$29,$$sroa$speculated$i$i$i$i$i32)|0);
    $31 = ($30|0)==(0);
    if ($31) {
     label = 4;
    } else {
     $33 = ($30|0)<(0);
     if ($33) {
      break;
     }
    }
   }
   if ((label|0) == 4) {
    $32 = ($23>>>0)<($16>>>0);
    if ($32) {
     break;
    }
   }
   $74 = ($23>>>0)<($16>>>0);
   $$sroa$speculated$i$i$i$i$i21 = $74 ? $23 : $16;
   $75 = ($$sroa$speculated$i$i$i$i$i21|0)==(0);
   if ($75) {
    label = 20;
   } else {
    $76 = HEAP32[$9>>2]|0;
    $77 = $12 ? $76 : $9;
    $78 = HEAP32[$4>>2]|0;
    $79 = $19 ? $78 : $4;
    $80 = (_memcmp($77,$79,$$sroa$speculated$i$i$i$i$i21)|0);
    $81 = ($80|0)==(0);
    if ($81) {
     label = 20;
    } else {
     $82 = ($80|0)<(0);
     if (!($82)) {
      label = 36;
     }
    }
   }
   if ((label|0) == 20) {
    if (!($24)) {
     label = 36;
    }
   }
   if ((label|0) == 36) {
    HEAP32[$2>>2] = $8;
    HEAP32[$3>>2] = $8;
    $$2 = $3;
    return ($$2|0);
   }
   $83 = ((($6)) + 4|0);
   $84 = HEAP32[$83>>2]|0;
   $85 = ($84|0)==(0|0);
   if ($85) {
    $86 = ((($6)) + 8|0);
    $87 = HEAP32[$86>>2]|0;
    $88 = HEAP32[$87>>2]|0;
    $89 = ($88|0)==($6|0);
    if ($89) {
     $$0$i$i$i$i$i = $87;
    } else {
     $93 = $86;
     while(1) {
      $92 = HEAP32[$93>>2]|0;
      $94 = ((($92)) + 8|0);
      $95 = HEAP32[$94>>2]|0;
      $96 = HEAP32[$95>>2]|0;
      $97 = ($96|0)==($92|0);
      if ($97) {
       $$0$i$i$i$i$i = $95;
       break;
      } else {
       $93 = $94;
      }
     }
    }
   } else {
    $$0$i$i$i$i$i$i = $84;
    while(1) {
     $90 = HEAP32[$$0$i$i$i$i$i$i>>2]|0;
     $91 = ($90|0)==(0|0);
     if ($91) {
      break;
     } else {
      $$0$i$i$i$i$i$i = $90;
     }
    }
    $$0$i$i$i$i$i = $$0$i$i$i$i$i$i;
   }
   $98 = ($$0$i$i$i$i$i|0)==($5|0);
   do {
    if (!($98)) {
     $99 = ((($$0$i$i$i$i$i)) + 16|0);
     $100 = ((($99)) + 11|0);
     $101 = HEAP8[$100>>0]|0;
     $102 = ($101<<24>>24)<(0);
     $103 = ((($$0$i$i$i$i$i)) + 20|0);
     $104 = HEAP32[$103>>2]|0;
     $105 = $101&255;
     $106 = $102 ? $104 : $105;
     $107 = ($106>>>0)<($23>>>0);
     $$sroa$speculated$i$i$i$i$i = $107 ? $106 : $23;
     $108 = ($$sroa$speculated$i$i$i$i$i|0)==(0);
     if ($108) {
      label = 30;
     } else {
      $109 = HEAP32[$4>>2]|0;
      $110 = $19 ? $109 : $4;
      $111 = HEAP32[$99>>2]|0;
      $112 = $102 ? $111 : $99;
      $113 = (_memcmp($110,$112,$$sroa$speculated$i$i$i$i$i)|0);
      $114 = ($113|0)==(0);
      if ($114) {
       label = 30;
      } else {
       $116 = ($113|0)<(0);
       if ($116) {
        break;
       }
      }
     }
     if ((label|0) == 30) {
      $115 = ($23>>>0)<($106>>>0);
      if ($115) {
       break;
      }
     }
     $120 = (__ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4pairIN3osg7ref_ptrINS9_7UniformEEEjEEEENS_19__map_value_compareIS7_SE_NS_4lessIS7_EELb1EEENS5_ISE_EEE12__find_equalIS7_EERPNS_16__tree_node_baseIPvEERPNS_15__tree_end_nodeISP_EERKT_($0,$2,$4)|0);
     $$2 = $120;
     return ($$2|0);
    }
   } while(0);
   $117 = ((($6)) + 4|0);
   $118 = HEAP32[$117>>2]|0;
   $119 = ($118|0)==(0|0);
   if ($119) {
    HEAP32[$2>>2] = $8;
    $$2 = $83;
    return ($$2|0);
   } else {
    HEAP32[$2>>2] = $$0$i$i$i$i$i;
    $$2 = $$0$i$i$i$i$i;
    return ($$2|0);
   }
  }
 } while(0);
 $34 = HEAP32[$0>>2]|0;
 $35 = ($6|0)==($34|0);
 $$pre = HEAP32[$6>>2]|0;
 do {
  if ($35) {
   $$sroa$052$0 = $8;
  } else {
   $36 = ($$pre|0)==(0|0);
   if ($36) {
    $$0$i$i = $6;
    while(1) {
     $40 = ((($$0$i$i)) + 8|0);
     $41 = HEAP32[$40>>2]|0;
     $42 = HEAP32[$41>>2]|0;
     $43 = ($42|0)==($$0$i$i|0);
     if ($43) {
      $$0$i$i = $41;
     } else {
      $$08$i$i = $41;
      break;
     }
    }
   } else {
    $$0$i$i$i = $$pre;
    while(1) {
     $37 = ((($$0$i$i$i)) + 4|0);
     $38 = HEAP32[$37>>2]|0;
     $39 = ($38|0)==(0|0);
     if ($39) {
      $$08$i$i = $$0$i$i$i;
      break;
     } else {
      $$0$i$i$i = $38;
     }
    }
   }
   $44 = $$08$i$i;
   $45 = ((($$08$i$i)) + 16|0);
   $46 = ((($4)) + 11|0);
   $47 = HEAP8[$46>>0]|0;
   $48 = ($47<<24>>24)<(0);
   $49 = ((($4)) + 4|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = $47&255;
   $52 = $48 ? $50 : $51;
   $53 = ((($45)) + 11|0);
   $54 = HEAP8[$53>>0]|0;
   $55 = ($54<<24>>24)<(0);
   $56 = ((($$08$i$i)) + 20|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = $54&255;
   $59 = $55 ? $57 : $58;
   $60 = ($52>>>0)<($59>>>0);
   $$sroa$speculated$i$i$i$i$i26 = $60 ? $52 : $59;
   $61 = ($$sroa$speculated$i$i$i$i$i26|0)==(0);
   if ($61) {
    label = 12;
   } else {
    $62 = HEAP32[$45>>2]|0;
    $63 = $55 ? $62 : $45;
    $64 = HEAP32[$4>>2]|0;
    $65 = $48 ? $64 : $4;
    $66 = (_memcmp($63,$65,$$sroa$speculated$i$i$i$i$i26)|0);
    $67 = ($66|0)==(0);
    if ($67) {
     label = 12;
    } else {
     $69 = ($66|0)<(0);
     if ($69) {
      $$sroa$052$0 = $44;
      break;
     }
    }
   }
   if ((label|0) == 12) {
    $68 = ($59>>>0)<($52>>>0);
    if ($68) {
     $$sroa$052$0 = $44;
     break;
    }
   }
   $73 = (__ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4pairIN3osg7ref_ptrINS9_7UniformEEEjEEEENS_19__map_value_compareIS7_SE_NS_4lessIS7_EELb1EEENS5_ISE_EEE12__find_equalIS7_EERPNS_16__tree_node_baseIPvEERPNS_15__tree_end_nodeISP_EERKT_($0,$2,$4)|0);
   $$2 = $73;
   return ($$2|0);
  }
 } while(0);
 $70 = ($$pre|0)==(0|0);
 if ($70) {
  HEAP32[$2>>2] = $6;
  $$2 = $6;
  return ($$2|0);
 } else {
  $71 = $$sroa$052$0;
  HEAP32[$2>>2] = $71;
  $72 = ((($71)) + 4|0);
  $$2 = $72;
  return ($$2|0);
 }
 return (0)|0;
}
function __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4pairIN3osg7ref_ptrINS9_7UniformEEEjEEEENS_19__map_value_compareIS7_SE_NS_4lessIS7_EELb1EEENS5_ISE_EEE12__find_equalIS7_EERPNS_16__tree_node_baseIPvEERPNS_15__tree_end_nodeISP_EERKT_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$0$ph = 0, $$024 = 0, $$025 = 0, $$in = 0, $$sroa$speculated$i$i$i$i$i = 0, $$sroa$speculated$i$i$i$i$i26 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  HEAP32[$1>>2] = $3;
  $$025 = $3;
  return ($$025|0);
 }
 $6 = ((($0)) + 4|0);
 $7 = ((($2)) + 11|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = ($8<<24>>24)<(0);
 $10 = ((($2)) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $8&255;
 $13 = $9 ? $11 : $12;
 $14 = HEAP32[$2>>2]|0;
 $15 = $9 ? $14 : $2;
 $$0 = $6;$$024 = $4;
 while(1) {
  $16 = ((($$024)) + 16|0);
  $17 = ((($16)) + 11|0);
  $18 = HEAP8[$17>>0]|0;
  $19 = ($18<<24>>24)<(0);
  $20 = ((($$024)) + 20|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = $18&255;
  $23 = $19 ? $21 : $22;
  $24 = ($23>>>0)<($13>>>0);
  $$sroa$speculated$i$i$i$i$i26 = $24 ? $23 : $13;
  $25 = ($$sroa$speculated$i$i$i$i$i26|0)==(0);
  if ($25) {
   label = 6;
  } else {
   $26 = HEAP32[$16>>2]|0;
   $27 = $19 ? $26 : $16;
   $28 = (_memcmp($15,$27,$$sroa$speculated$i$i$i$i$i26)|0);
   $29 = ($28|0)==(0);
   if ($29) {
    label = 6;
   } else {
    $31 = ($28|0)<(0);
    if ($31) {
     label = 8;
    } else {
     label = 10;
    }
   }
  }
  if ((label|0) == 6) {
   label = 0;
   $30 = ($13>>>0)<($23>>>0);
   if ($30) {
    label = 8;
   } else {
    label = 10;
   }
  }
  if ((label|0) == 8) {
   label = 0;
   $32 = HEAP32[$$024>>2]|0;
   $33 = ($32|0)==(0|0);
   if ($33) {
    label = 9;
    break;
   } else {
    $$0$ph = $$024;$$in = $32;
   }
  }
  else if ((label|0) == 10) {
   label = 0;
   $34 = ($13>>>0)<($23>>>0);
   $$sroa$speculated$i$i$i$i$i = $34 ? $13 : $23;
   $35 = ($$sroa$speculated$i$i$i$i$i|0)==(0);
   if ($35) {
    label = 12;
   } else {
    $36 = HEAP32[$16>>2]|0;
    $37 = $19 ? $36 : $16;
    $38 = (_memcmp($37,$15,$$sroa$speculated$i$i$i$i$i)|0);
    $39 = ($38|0)==(0);
    if ($39) {
     label = 12;
    } else {
     $40 = ($38|0)<(0);
     if (!($40)) {
      label = 16;
      break;
     }
    }
   }
   if ((label|0) == 12) {
    label = 0;
    if (!($24)) {
     label = 16;
     break;
    }
   }
   $41 = ((($$024)) + 4|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = ($42|0)==(0|0);
   if ($43) {
    label = 15;
    break;
   } else {
    $$0$ph = $41;$$in = $42;
   }
  }
  $$0 = $$0$ph;$$024 = $$in;
 }
 if ((label|0) == 9) {
  HEAP32[$1>>2] = $$024;
  $$025 = $$024;
  return ($$025|0);
 }
 else if ((label|0) == 15) {
  HEAP32[$1>>2] = $$024;
  $$025 = $41;
  return ($$025|0);
 }
 else if ((label|0) == 16) {
  HEAP32[$1>>2] = $$024;
  $$025 = $$0;
  return ($$025|0);
 }
 return (0)|0;
}
function __ZNK7osgUtil14ShaderGenCache14createStateSetEi($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$0$i = 0, $$0$i65 = 0, $$0$i65$sink = 0, $$0$i73 = 0, $$03$i = 0, $$03$i64 = 0, $$03$i64$sink = 0, $$03$i72 = 0, $$038 = 0, $$052 = 0, $$1 = 0, $$10 = 0, $$1048 = 0, $$11 = 0, $$1149 = 0, $$13 = 0, $$1351 = 0, $$139 = 0, $$4 = 0;
 var $$442 = 0, $$5 = 0, $$543 = 0, $$7 = 0, $$745 = 0, $$8 = 0, $$846 = 0, $$9 = 0, $$947 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0;
 var $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0;
 var $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0;
 var $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0;
 var $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0;
 var $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0;
 var $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0;
 var $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0;
 var $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0;
 var $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0;
 var $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0;
 var $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0;
 var $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0;
 var $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0;
 var $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0;
 var $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0;
 var $434 = 0, $435 = 0, $436 = 0, $437 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$i$index2Z2D = 0, $eh$lpad$body$i$indexZ2D = 0, $eh$lpad$body$i62$index7Z2D = 0, $eh$lpad$body$i62$indexZ2D = 0, $eh$lpad$body$i70$index12Z2D = 0, $eh$lpad$body$i70$indexZ2D = 0, $eh$lpad$body142$index18Z2D = 0, $eh$lpad$body142$indexZ2D = 0, $trunc = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 528|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(528|0);
 $2 = sp + 512|0;
 $3 = sp + 508|0;
 $4 = sp + 496|0;
 $5 = sp + 484|0;
 $6 = sp + 472|0;
 $7 = sp + 336|0;
 $8 = sp + 200|0;
 $9 = sp + 64|0;
 $10 = sp + 48|0;
 $11 = sp + 36|0;
 $12 = sp + 24|0;
 $13 = sp + 12|0;
 $14 = sp;
 $15 = (__Znwj(160)|0);
 __THREW__ = 0;
 invoke_vi(3572,($15|0));
 $16 = __THREW__; __THREW__ = 0;
 $17 = $16&1;
 if ($17) {
  $70 = ___cxa_find_matching_catch_2()|0;
  $71 = tempRet0;
  __ZdlPv($15);
  $$13 = $70;$$1351 = $71;
  ___resumeException($$13|0);
  // unreachable;
 }
 $18 = (__Znwj(172)|0);
 __THREW__ = 0;
 invoke_vi(3613,($18|0));
 $19 = __THREW__; __THREW__ = 0;
 $20 = $19&1;
 if ($20) {
  $72 = ___cxa_find_matching_catch_2()|0;
  $73 = tempRet0;
  __ZdlPv($18);
  $$13 = $72;$$1351 = $73;
  ___resumeException($$13|0);
  // unreachable;
 }
 __ZN3osg8StateSet12setAttributeEPNS_14StateAttributeEj($15,$18,0);
 $21 = ((($7)) + 56|0);
 $22 = ((($7)) + 4|0);
 HEAP32[$7>>2] = ((21372));
 HEAP32[$21>>2] = ((21392));
 $23 = ((($7)) + 56|0);
 __THREW__ = 0;
 invoke_vii(3368,($23|0),($22|0));
 $24 = __THREW__; __THREW__ = 0;
 $25 = $24&1;
 if ($25) {
  $52 = ___cxa_find_matching_catch_2()|0;
  $53 = tempRet0;
  $$0$i = $53;$$03$i = $52;
 } else {
  $26 = ((($7)) + 128|0);
  HEAP32[$26>>2] = 0;
  $27 = ((($7)) + 132|0);
  HEAP32[$27>>2] = -1;
  HEAP32[$7>>2] = (50156);
  HEAP32[$21>>2] = (50176);
  __THREW__ = 0;
  invoke_vi(3369,($22|0));
  $28 = __THREW__; __THREW__ = 0;
  $29 = $28&1;
  do {
   if ($29) {
    $54 = ___cxa_find_matching_catch_2()|0;
    $55 = tempRet0;
    $eh$lpad$body$i$index2Z2D = $55;$eh$lpad$body$i$indexZ2D = $54;
   } else {
    HEAP32[$22>>2] = (37132);
    $30 = ((($7)) + 36|0);
    $31 = ((($7)) + 52|0);
    ;HEAP32[$30>>2]=0|0;HEAP32[$30+4>>2]=0|0;HEAP32[$30+8>>2]=0|0;HEAP32[$30+12>>2]=0|0;
    HEAP32[$31>>2] = 16;
    ;HEAP32[$6>>2]=0|0;HEAP32[$6+4>>2]=0|0;HEAP32[$6+8>>2]=0|0;
    __THREW__ = 0;
    invoke_vii(3370,($22|0),($6|0));
    $32 = __THREW__; __THREW__ = 0;
    $33 = $32&1;
    if ($33) {
     $38 = ___cxa_find_matching_catch_2()|0;
     $39 = tempRet0;
     $40 = ((($6)) + 11|0);
     $41 = HEAP8[$40>>0]|0;
     $42 = ($41<<24>>24)<(0);
     if ($42) {
      $43 = HEAP32[$6>>2]|0;
      __ZdlPv($43);
     }
     $44 = ((($30)) + 11|0);
     $45 = HEAP8[$44>>0]|0;
     $46 = ($45<<24>>24)<(0);
     if ($46) {
      $47 = HEAP32[$30>>2]|0;
      __ZdlPv($47);
     }
     __THREW__ = 0;
     invoke_vi(2911,($22|0));
     $48 = __THREW__; __THREW__ = 0;
     $49 = $48&1;
     if (!($49)) {
      $eh$lpad$body$i$index2Z2D = $39;$eh$lpad$body$i$indexZ2D = $38;
      break;
     }
     $50 = ___cxa_find_matching_catch_3(0|0)|0;
     $51 = tempRet0;
     ___clang_call_terminate($50);
     // unreachable;
    }
    $34 = ((($6)) + 11|0);
    $35 = HEAP8[$34>>0]|0;
    $36 = ($35<<24>>24)<(0);
    if ($36) {
     $37 = HEAP32[$6>>2]|0;
     __ZdlPv($37);
    }
    __THREW__ = 0;
    (invoke_iiii(3267,($7|0),(113588|0),20)|0);
    $62 = __THREW__; __THREW__ = 0;
    $63 = $62&1;
    L28: do {
     if ($63) {
      label = 26;
     } else {
      __THREW__ = 0;
      (invoke_iiii(3267,($7|0),(113609|0),47)|0);
      $64 = __THREW__; __THREW__ = 0;
      $65 = $64&1;
      if ($65) {
       label = 26;
      } else {
       $66 = $1 & 16;
       $67 = $1 & 18;
       $trunc = $67&255;
       $trunc$clear = $trunc & 31;
       switch ($trunc$clear<<24>>24) {
       case 2:  {
        __THREW__ = 0;
        (invoke_iiii(3267,($7|0),(113657|0),24)|0);
        $68 = __THREW__; __THREW__ = 0;
        $69 = $68&1;
        if ($69) {
         label = 26;
         break L28;
        } else {
         label = 28;
        }
        break;
       }
       case 0:  {
        break;
       }
       default: {
        label = 28;
       }
       }
       if ((label|0) == 28) {
        __THREW__ = 0;
        (invoke_iiii(3267,($7|0),(113682|0),23)|0);
        $76 = __THREW__; __THREW__ = 0;
        $77 = $76&1;
        if ($77) {
         label = 26;
         break;
        }
       }
       $78 = $1 & 22;
       $79 = ($78|0)==(0);
       if (!($79)) {
        __THREW__ = 0;
        (invoke_iiii(3267,($7|0),(113706|0),22)|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 26;
         break;
        }
       }
       __THREW__ = 0;
       (invoke_iiii(3267,($7|0),(113729|0),26)|0);
       $82 = __THREW__; __THREW__ = 0;
       $83 = $82&1;
       if ($83) {
        label = 26;
       } else {
        $84 = ((($8)) + 56|0);
        $85 = ((($8)) + 4|0);
        HEAP32[$8>>2] = ((21372));
        HEAP32[$84>>2] = ((21392));
        $86 = ((($8)) + 56|0);
        __THREW__ = 0;
        invoke_vii(3368,($86|0),($85|0));
        $87 = __THREW__; __THREW__ = 0;
        $88 = $87&1;
        if ($88) {
         $115 = ___cxa_find_matching_catch_2()|0;
         $116 = tempRet0;
         $$0$i65 = $116;$$03$i64 = $115;
        } else {
         $89 = ((($8)) + 128|0);
         HEAP32[$89>>2] = 0;
         $90 = ((($8)) + 132|0);
         HEAP32[$90>>2] = -1;
         HEAP32[$8>>2] = (50156);
         HEAP32[$84>>2] = (50176);
         __THREW__ = 0;
         invoke_vi(3369,($85|0));
         $91 = __THREW__; __THREW__ = 0;
         $92 = $91&1;
         do {
          if ($92) {
           $117 = ___cxa_find_matching_catch_2()|0;
           $118 = tempRet0;
           $eh$lpad$body$i62$index7Z2D = $118;$eh$lpad$body$i62$indexZ2D = $117;
          } else {
           HEAP32[$85>>2] = (37132);
           $93 = ((($8)) + 36|0);
           $94 = ((($8)) + 52|0);
           ;HEAP32[$93>>2]=0|0;HEAP32[$93+4>>2]=0|0;HEAP32[$93+8>>2]=0|0;HEAP32[$93+12>>2]=0|0;
           HEAP32[$94>>2] = 16;
           ;HEAP32[$5>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;
           __THREW__ = 0;
           invoke_vii(3370,($85|0),($5|0));
           $95 = __THREW__; __THREW__ = 0;
           $96 = $95&1;
           if ($96) {
            $101 = ___cxa_find_matching_catch_2()|0;
            $102 = tempRet0;
            $103 = ((($5)) + 11|0);
            $104 = HEAP8[$103>>0]|0;
            $105 = ($104<<24>>24)<(0);
            if ($105) {
             $106 = HEAP32[$5>>2]|0;
             __ZdlPv($106);
            }
            $107 = ((($93)) + 11|0);
            $108 = HEAP8[$107>>0]|0;
            $109 = ($108<<24>>24)<(0);
            if ($109) {
             $110 = HEAP32[$93>>2]|0;
             __ZdlPv($110);
            }
            __THREW__ = 0;
            invoke_vi(2911,($85|0));
            $111 = __THREW__; __THREW__ = 0;
            $112 = $111&1;
            if (!($112)) {
             $eh$lpad$body$i62$index7Z2D = $102;$eh$lpad$body$i62$indexZ2D = $101;
             break;
            }
            $113 = ___cxa_find_matching_catch_3(0|0)|0;
            $114 = tempRet0;
            ___clang_call_terminate($113);
            // unreachable;
           }
           $97 = ((($5)) + 11|0);
           $98 = HEAP8[$97>>0]|0;
           $99 = ($98<<24>>24)<(0);
           if ($99) {
            $100 = HEAP32[$5>>2]|0;
            __ZdlPv($100);
           }
           $125 = ((($9)) + 56|0);
           $126 = ((($9)) + 4|0);
           HEAP32[$9>>2] = ((21372));
           HEAP32[$125>>2] = ((21392));
           $127 = ((($9)) + 56|0);
           __THREW__ = 0;
           invoke_vii(3368,($127|0),($126|0));
           $128 = __THREW__; __THREW__ = 0;
           $129 = $128&1;
           L59: do {
            if ($129) {
             $156 = ___cxa_find_matching_catch_2()|0;
             $157 = tempRet0;
             $$0$i73 = $157;$$03$i72 = $156;
             label = 62;
            } else {
             $130 = ((($9)) + 128|0);
             HEAP32[$130>>2] = 0;
             $131 = ((($9)) + 132|0);
             HEAP32[$131>>2] = -1;
             HEAP32[$9>>2] = (50156);
             HEAP32[$125>>2] = (50176);
             __THREW__ = 0;
             invoke_vi(3369,($126|0));
             $132 = __THREW__; __THREW__ = 0;
             $133 = $132&1;
             do {
              if ($133) {
               $158 = ___cxa_find_matching_catch_2()|0;
               $159 = tempRet0;
               $eh$lpad$body$i70$index12Z2D = $159;$eh$lpad$body$i70$indexZ2D = $158;
              } else {
               HEAP32[$126>>2] = (37132);
               $134 = ((($9)) + 36|0);
               $135 = ((($9)) + 52|0);
               ;HEAP32[$134>>2]=0|0;HEAP32[$134+4>>2]=0|0;HEAP32[$134+8>>2]=0|0;HEAP32[$134+12>>2]=0|0;
               HEAP32[$135>>2] = 16;
               ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;
               __THREW__ = 0;
               invoke_vii(3370,($126|0),($4|0));
               $136 = __THREW__; __THREW__ = 0;
               $137 = $136&1;
               if ($137) {
                $142 = ___cxa_find_matching_catch_2()|0;
                $143 = tempRet0;
                $144 = ((($4)) + 11|0);
                $145 = HEAP8[$144>>0]|0;
                $146 = ($145<<24>>24)<(0);
                if ($146) {
                 $147 = HEAP32[$4>>2]|0;
                 __ZdlPv($147);
                }
                $148 = ((($134)) + 11|0);
                $149 = HEAP8[$148>>0]|0;
                $150 = ($149<<24>>24)<(0);
                if ($150) {
                 $151 = HEAP32[$134>>2]|0;
                 __ZdlPv($151);
                }
                __THREW__ = 0;
                invoke_vi(2911,($126|0));
                $152 = __THREW__; __THREW__ = 0;
                $153 = $152&1;
                if (!($153)) {
                 $eh$lpad$body$i70$index12Z2D = $143;$eh$lpad$body$i70$indexZ2D = $142;
                 break;
                }
                $154 = ___cxa_find_matching_catch_3(0|0)|0;
                $155 = tempRet0;
                ___clang_call_terminate($154);
                // unreachable;
               }
               $138 = ((($4)) + 11|0);
               $139 = HEAP8[$138>>0]|0;
               $140 = ($139<<24>>24)<(0);
               if ($140) {
                $141 = HEAP32[$4>>2]|0;
                __ZdlPv($141);
               }
               __THREW__ = 0;
               invoke_vii(3615,($10|0),($22|0));
               $166 = __THREW__; __THREW__ = 0;
               $167 = $166&1;
               L78: do {
                if ($167) {
                 $209 = ___cxa_find_matching_catch_2()|0;
                 $210 = tempRet0;
                 $$0 = $209;$$038 = $210;
                 label = 80;
                } else {
                 $168 = ((($10)) + 11|0);
                 $169 = HEAP8[$168>>0]|0;
                 $170 = ($169<<24>>24)<(0);
                 $171 = HEAP32[$10>>2]|0;
                 $172 = $170 ? $171 : $10;
                 $173 = ((($10)) + 4|0);
                 $174 = HEAP32[$173>>2]|0;
                 $175 = $169&255;
                 $176 = $170 ? $174 : $175;
                 __THREW__ = 0;
                 (invoke_iiii(3267,($8|0),($172|0),($176|0))|0);
                 $177 = __THREW__; __THREW__ = 0;
                 $178 = $177&1;
                 if ($178) {
                  $211 = ___cxa_find_matching_catch_2()|0;
                  $212 = tempRet0;
                  $213 = HEAP8[$168>>0]|0;
                  $214 = ($213<<24>>24)<(0);
                  if (!($214)) {
                   $$0 = $211;$$038 = $212;
                   label = 80;
                   break;
                  }
                  $215 = HEAP32[$10>>2]|0;
                  __ZdlPv($215);
                  $$0 = $211;$$038 = $212;
                  label = 80;
                  break;
                 }
                 $179 = HEAP8[$168>>0]|0;
                 $180 = ($179<<24>>24)<(0);
                 if ($180) {
                  $181 = HEAP32[$10>>2]|0;
                  __ZdlPv($181);
                 }
                 __THREW__ = 0;
                 invoke_vii(3615,($11|0),($22|0));
                 $182 = __THREW__; __THREW__ = 0;
                 $183 = $182&1;
                 do {
                  if ($183) {
                   $216 = ___cxa_find_matching_catch_2()|0;
                   $217 = tempRet0;
                   $$1 = $216;$$139 = $217;
                  } else {
                   $184 = ((($11)) + 11|0);
                   $185 = HEAP8[$184>>0]|0;
                   $186 = ($185<<24>>24)<(0);
                   $187 = HEAP32[$11>>2]|0;
                   $188 = $186 ? $187 : $11;
                   $189 = ((($11)) + 4|0);
                   $190 = HEAP32[$189>>2]|0;
                   $191 = $185&255;
                   $192 = $186 ? $190 : $191;
                   __THREW__ = 0;
                   (invoke_iiii(3267,($9|0),($188|0),($192|0))|0);
                   $193 = __THREW__; __THREW__ = 0;
                   $194 = $193&1;
                   if ($194) {
                    $218 = ___cxa_find_matching_catch_2()|0;
                    $219 = tempRet0;
                    $220 = HEAP8[$184>>0]|0;
                    $221 = ($220<<24>>24)<(0);
                    if (!($221)) {
                     $$1 = $218;$$139 = $219;
                     break;
                    }
                    $222 = HEAP32[$11>>2]|0;
                    __ZdlPv($222);
                    $$1 = $218;$$139 = $219;
                    break;
                   }
                   $195 = HEAP8[$184>>0]|0;
                   $196 = ($195<<24>>24)<(0);
                   if ($196) {
                    $197 = HEAP32[$11>>2]|0;
                    __ZdlPv($197);
                   }
                   $198 = $1 & 8;
                   $199 = ($198|0)!=(0);
                   do {
                    if ($199) {
                     __THREW__ = 0;
                     $200 = (invoke_ii(3276,92)|0);
                     $201 = __THREW__; __THREW__ = 0;
                     $202 = $201&1;
                     if ($202) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_viii(3616,($200|0),(113756|0),0);
                     $203 = __THREW__; __THREW__ = 0;
                     $204 = $203&1;
                     if ($204) {
                      $225 = ___cxa_find_matching_catch_2()|0;
                      $226 = tempRet0;
                      __ZdlPv($200);
                      $$7 = $225;$$745 = $226;
                      label = 172;
                      break L78;
                     }
                     __THREW__ = 0;
                     invoke_viii(3617,($15|0),($200|0),1);
                     $205 = __THREW__; __THREW__ = 0;
                     $206 = $205&1;
                     if (!($206)) {
                      __THREW__ = 0;
                      (invoke_iiii(3267,($9|0),(113767|0),30)|0);
                      $207 = __THREW__; __THREW__ = 0;
                      $208 = $207&1;
                      if (!($208)) {
                       $$052 = 1;
                       label = 88;
                       break;
                      }
                     }
                     $227 = ___cxa_find_matching_catch_2()|0;
                     $228 = tempRet0;
                     $$7 = $227;$$745 = $228;
                     label = 172;
                     break L78;
                    } else {
                     $$052 = 0;
                     label = 88;
                    }
                   } while(0);
                   L107: do {
                    if ((label|0) == 88) {
                     $229 = ($66|0)!=(0);
                     L109: do {
                      if ($229) {
                       __THREW__ = 0;
                       $230 = (invoke_ii(3276,92)|0);
                       $231 = __THREW__; __THREW__ = 0;
                       $232 = $231&1;
                       if ($232) {
                        break L107;
                       }
                       __THREW__ = 0;
                       invoke_viii(3616,($230|0),(113798|0),($$052|0));
                       $233 = __THREW__; __THREW__ = 0;
                       $234 = $233&1;
                       if ($234) {
                        $249 = ___cxa_find_matching_catch_2()|0;
                        $250 = tempRet0;
                        __ZdlPv($230);
                        $$7 = $249;$$745 = $250;
                        label = 172;
                        break L78;
                       }
                       __THREW__ = 0;
                       invoke_viii(3617,($15|0),($230|0),1);
                       $235 = __THREW__; __THREW__ = 0;
                       $236 = $235&1;
                       do {
                        if (!($236)) {
                         __THREW__ = 0;
                         (invoke_iiii(3267,($9|0),(113808|0),29)|0);
                         $237 = __THREW__; __THREW__ = 0;
                         $238 = $237&1;
                         if ($238) {
                          break;
                         }
                         $239 = ((($12)) + 8|0);
                         HEAP32[$239>>2] = 0;
                         $240 = ((($12)) + 11|0);
                         HEAP8[$240>>0] = 7;
                         ;HEAP8[$12>>0]=HEAP8[113838>>0]|0;HEAP8[$12+1>>0]=HEAP8[113838+1>>0]|0;HEAP8[$12+2>>0]=HEAP8[113838+2>>0]|0;HEAP8[$12+3>>0]=HEAP8[113838+3>>0]|0;HEAP8[$12+4>>0]=HEAP8[113838+4>>0]|0;HEAP8[$12+5>>0]=HEAP8[113838+5>>0]|0;HEAP8[$12+6>>0]=HEAP8[113838+6>>0]|0;
                         $241 = ((($12)) + 7|0);
                         HEAP8[$241>>0] = 0;
                         __THREW__ = 0;
                         invoke_viii(3618,($18|0),($12|0),6);
                         $242 = __THREW__; __THREW__ = 0;
                         $243 = $242&1;
                         if ($243) {
                          $253 = ___cxa_find_matching_catch_2()|0;
                          $254 = tempRet0;
                          $255 = HEAP8[$240>>0]|0;
                          $256 = ($255<<24>>24)<(0);
                          if ($256) {
                           $257 = HEAP32[$12>>2]|0;
                           __ZdlPv($257);
                          }
                          $$7 = $253;$$745 = $254;
                          label = 172;
                          break L78;
                         } else {
                          $244 = HEAP8[$240>>0]|0;
                          $245 = ($244<<24>>24)<(0);
                          if ($245) {
                           $246 = HEAP32[$12>>2]|0;
                           __ZdlPv($246);
                          }
                          __THREW__ = 0;
                          (invoke_iiii(3267,($8|0),(113846|0),24)|0);
                          $247 = __THREW__; __THREW__ = 0;
                          $248 = $247&1;
                          if ($248) {
                           break;
                          } else {
                           break L109;
                          }
                         }
                        }
                       } while(0);
                       $251 = ___cxa_find_matching_catch_2()|0;
                       $252 = tempRet0;
                       $$7 = $251;$$745 = $252;
                       label = 172;
                       break L78;
                      }
                     } while(0);
                     __THREW__ = 0;
                     (invoke_iiii(3267,($8|0),(113871|0),45)|0);
                     $258 = __THREW__; __THREW__ = 0;
                     $259 = $258&1;
                     if ($259) {
                      break;
                     }
                     $260 = $1 & 24;
                     $261 = ($260|0)==(0);
                     if (!($261)) {
                      __THREW__ = 0;
                      (invoke_iiii(3267,($8|0),(113917|0),38)|0);
                      $262 = __THREW__; __THREW__ = 0;
                      $263 = $262&1;
                      if ($263) {
                       break;
                      }
                     }
                     if ($229) {
                      __THREW__ = 0;
                      (invoke_iiii(3267,($8|0),(113956|0),430)|0);
                      $264 = __THREW__; __THREW__ = 0;
                      $265 = $264&1;
                      if ($265) {
                       break;
                      }
                     } else {
                      __THREW__ = 0;
                      (invoke_iiii(3267,($8|0),(114387|0),26)|0);
                      $266 = __THREW__; __THREW__ = 0;
                      $267 = $266&1;
                      if ($267) {
                       break;
                      }
                     }
                     __THREW__ = 0;
                     (invoke_iiii(3267,($8|0),(114414|0),2)|0);
                     $268 = __THREW__; __THREW__ = 0;
                     $269 = $268&1;
                     if ($269) {
                      break;
                     }
                     __THREW__ = 0;
                     (invoke_iiii(3267,($9|0),(114417|0),15)|0);
                     $270 = __THREW__; __THREW__ = 0;
                     $271 = $270&1;
                     if ($271) {
                      break;
                     }
                     if ($199) {
                      __THREW__ = 0;
                      (invoke_iiii(3267,($9|0),(114433|0),70)|0);
                      $272 = __THREW__; __THREW__ = 0;
                      $273 = $272&1;
                      if ($273) {
                       break;
                      }
                     } else {
                      __THREW__ = 0;
                      (invoke_iiii(3267,($9|0),(114504|0),27)|0);
                      $274 = __THREW__; __THREW__ = 0;
                      $275 = $274&1;
                      if ($275) {
                       break;
                      }
                     }
                     if ($229) {
                      __THREW__ = 0;
                      (invoke_iiii(3267,($9|0),(114532|0),72)|0);
                      $276 = __THREW__; __THREW__ = 0;
                      $277 = $276&1;
                      if ($277) {
                       break;
                      }
                     }
                     __THREW__ = 0;
                     (invoke_iiii(3267,($9|0),(114605|0),21)|0);
                     $278 = __THREW__; __THREW__ = 0;
                     $279 = $278&1;
                     if ($279) {
                      break;
                     }
                     __THREW__ = 0;
                     (invoke_iiii(3267,($9|0),(114627|0),24)|0);
                     $280 = __THREW__; __THREW__ = 0;
                     $281 = $280&1;
                     if ($281) {
                      break;
                     }
                     __THREW__ = 0;
                     (invoke_iiii(3267,($9|0),(114414|0),2)|0);
                     $282 = __THREW__; __THREW__ = 0;
                     $283 = $282&1;
                     if ($283) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vii(3615,($13|0),($85|0));
                     $284 = __THREW__; __THREW__ = 0;
                     $285 = $284&1;
                     if ($285) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vii(3615,($14|0),($126|0));
                     $286 = __THREW__; __THREW__ = 0;
                     $287 = $286&1;
                     if ($287) {
                      $336 = ___cxa_find_matching_catch_2()|0;
                      $337 = tempRet0;
                      $$5 = $336;$$543 = $337;
                     } else {
                      __THREW__ = 0;
                      $288 = (invoke_ii(3265,5)|0);
                      $289 = __THREW__; __THREW__ = 0;
                      $290 = $289&1;
                      L153: do {
                       if ($290) {
                        label = 135;
                       } else {
                        L155: do {
                         if ($288) {
                          __THREW__ = 0;
                          $291 = (invoke_ii(3266,5)|0);
                          $292 = __THREW__; __THREW__ = 0;
                          $293 = $292&1;
                          if ($293) {
                           label = 135;
                           break L153;
                          }
                          __THREW__ = 0;
                          $294 = (invoke_iiii(3267,($291|0),(114652|0),30)|0);
                          $295 = __THREW__; __THREW__ = 0;
                          $296 = $295&1;
                          if ($296) {
                           label = 135;
                           break L153;
                          }
                          $297 = ((($13)) + 11|0);
                          $298 = HEAP8[$297>>0]|0;
                          $299 = ($298<<24>>24)<(0);
                          $300 = HEAP32[$13>>2]|0;
                          $301 = $299 ? $300 : $13;
                          $302 = ((($13)) + 4|0);
                          $303 = HEAP32[$302>>2]|0;
                          $304 = $298&255;
                          $305 = $299 ? $303 : $304;
                          __THREW__ = 0;
                          $306 = (invoke_iiii(3267,($294|0),($301|0),($305|0))|0);
                          $307 = __THREW__; __THREW__ = 0;
                          $308 = $307&1;
                          if ($308) {
                           label = 135;
                           break L153;
                          }
                          $309 = HEAP32[$306>>2]|0;
                          $310 = ((($309)) + -12|0);
                          $311 = HEAP32[$310>>2]|0;
                          $312 = (($306) + ($311)|0);
                          __THREW__ = 0;
                          invoke_vii(3257,($3|0),($312|0));
                          $313 = __THREW__; __THREW__ = 0;
                          $314 = $313&1;
                          if ($314) {
                           label = 135;
                           break L153;
                          }
                          __THREW__ = 0;
                          $315 = (invoke_iii(3255,($3|0),(215188|0))|0);
                          $316 = __THREW__; __THREW__ = 0;
                          $317 = $316&1;
                          do {
                           if (!($317)) {
                            $318 = HEAP32[$315>>2]|0;
                            $319 = ((($318)) + 28|0);
                            $320 = HEAP32[$319>>2]|0;
                            __THREW__ = 0;
                            $321 = (invoke_iii($320|0,($315|0),10)|0);
                            $322 = __THREW__; __THREW__ = 0;
                            $323 = $322&1;
                            if ($323) {
                             break;
                            }
                            __THREW__ = 0;
                            invoke_vi(3263,($3|0));
                            $324 = __THREW__; __THREW__ = 0;
                            $325 = $324&1;
                            if ($325) {
                             label = 135;
                             break L153;
                            }
                            __THREW__ = 0;
                            (invoke_iii(3268,($306|0),($321|0))|0);
                            $332 = __THREW__; __THREW__ = 0;
                            $333 = $332&1;
                            if ($333) {
                             label = 135;
                             break L153;
                            }
                            __THREW__ = 0;
                            (invoke_ii(3269,($306|0))|0);
                            $334 = __THREW__; __THREW__ = 0;
                            $335 = $334&1;
                            if ($335) {
                             label = 135;
                             break L153;
                            } else {
                             break L155;
                            }
                           }
                          } while(0);
                          $326 = ___cxa_find_matching_catch_2()|0;
                          $327 = tempRet0;
                          __THREW__ = 0;
                          invoke_vi(3263,($3|0));
                          $328 = __THREW__; __THREW__ = 0;
                          $329 = $328&1;
                          if ($329) {
                           $330 = ___cxa_find_matching_catch_3(0|0)|0;
                           $331 = tempRet0;
                           ___clang_call_terminate($330);
                           // unreachable;
                          } else {
                           $eh$lpad$body142$index18Z2D = $327;$eh$lpad$body142$indexZ2D = $326;
                           label = 136;
                           break L153;
                          }
                         }
                        } while(0);
                        __THREW__ = 0;
                        $340 = (invoke_ii(3265,5)|0);
                        $341 = __THREW__; __THREW__ = 0;
                        $342 = $341&1;
                        if ($342) {
                         label = 135;
                         break;
                        }
                        L172: do {
                         if ($340) {
                          __THREW__ = 0;
                          $343 = (invoke_ii(3266,5)|0);
                          $344 = __THREW__; __THREW__ = 0;
                          $345 = $344&1;
                          if ($345) {
                           label = 135;
                           break L153;
                          }
                          __THREW__ = 0;
                          $346 = (invoke_iiii(3267,($343|0),(114683|0),32)|0);
                          $347 = __THREW__; __THREW__ = 0;
                          $348 = $347&1;
                          if ($348) {
                           label = 135;
                           break L153;
                          }
                          $349 = ((($14)) + 11|0);
                          $350 = HEAP8[$349>>0]|0;
                          $351 = ($350<<24>>24)<(0);
                          $352 = HEAP32[$14>>2]|0;
                          $353 = $351 ? $352 : $14;
                          $354 = ((($14)) + 4|0);
                          $355 = HEAP32[$354>>2]|0;
                          $356 = $350&255;
                          $357 = $351 ? $355 : $356;
                          __THREW__ = 0;
                          $358 = (invoke_iiii(3267,($346|0),($353|0),($357|0))|0);
                          $359 = __THREW__; __THREW__ = 0;
                          $360 = $359&1;
                          if ($360) {
                           label = 135;
                           break L153;
                          }
                          $361 = HEAP32[$358>>2]|0;
                          $362 = ((($361)) + -12|0);
                          $363 = HEAP32[$362>>2]|0;
                          $364 = (($358) + ($363)|0);
                          __THREW__ = 0;
                          invoke_vii(3257,($2|0),($364|0));
                          $365 = __THREW__; __THREW__ = 0;
                          $366 = $365&1;
                          if ($366) {
                           label = 135;
                           break L153;
                          }
                          __THREW__ = 0;
                          $367 = (invoke_iii(3255,($2|0),(215188|0))|0);
                          $368 = __THREW__; __THREW__ = 0;
                          $369 = $368&1;
                          do {
                           if (!($369)) {
                            $370 = HEAP32[$367>>2]|0;
                            $371 = ((($370)) + 28|0);
                            $372 = HEAP32[$371>>2]|0;
                            __THREW__ = 0;
                            $373 = (invoke_iii($372|0,($367|0),10)|0);
                            $374 = __THREW__; __THREW__ = 0;
                            $375 = $374&1;
                            if ($375) {
                             break;
                            }
                            __THREW__ = 0;
                            invoke_vi(3263,($2|0));
                            $376 = __THREW__; __THREW__ = 0;
                            $377 = $376&1;
                            if ($377) {
                             label = 135;
                             break L153;
                            }
                            __THREW__ = 0;
                            (invoke_iii(3268,($358|0),($373|0))|0);
                            $384 = __THREW__; __THREW__ = 0;
                            $385 = $384&1;
                            if ($385) {
                             label = 135;
                             break L153;
                            }
                            __THREW__ = 0;
                            (invoke_ii(3269,($358|0))|0);
                            $386 = __THREW__; __THREW__ = 0;
                            $387 = $386&1;
                            if ($387) {
                             label = 135;
                             break L153;
                            } else {
                             break L172;
                            }
                           }
                          } while(0);
                          $378 = ___cxa_find_matching_catch_2()|0;
                          $379 = tempRet0;
                          __THREW__ = 0;
                          invoke_vi(3263,($2|0));
                          $380 = __THREW__; __THREW__ = 0;
                          $381 = $380&1;
                          if ($381) {
                           $382 = ___cxa_find_matching_catch_3(0|0)|0;
                           $383 = tempRet0;
                           ___clang_call_terminate($382);
                           // unreachable;
                          } else {
                           $eh$lpad$body142$index18Z2D = $379;$eh$lpad$body142$indexZ2D = $378;
                           label = 136;
                           break L153;
                          }
                         }
                        } while(0);
                        __THREW__ = 0;
                        $388 = (invoke_ii(3276,128)|0);
                        $389 = __THREW__; __THREW__ = 0;
                        $390 = $389&1;
                        if ($390) {
                         label = 135;
                         break;
                        }
                        __THREW__ = 0;
                        invoke_viii(3619,($388|0),35633,($13|0));
                        $391 = __THREW__; __THREW__ = 0;
                        $392 = $391&1;
                        if ($392) {
                         $412 = ___cxa_find_matching_catch_2()|0;
                         $413 = tempRet0;
                         __ZdlPv($388);
                         $$4 = $412;$$442 = $413;
                         break;
                        }
                        __THREW__ = 0;
                        (invoke_iii(3620,($18|0),($388|0))|0);
                        $393 = __THREW__; __THREW__ = 0;
                        $394 = $393&1;
                        if ($394) {
                         label = 135;
                         break;
                        }
                        __THREW__ = 0;
                        $395 = (invoke_ii(3276,128)|0);
                        $396 = __THREW__; __THREW__ = 0;
                        $397 = $396&1;
                        if ($397) {
                         label = 135;
                         break;
                        }
                        __THREW__ = 0;
                        invoke_viii(3619,($395|0),35632,($14|0));
                        $398 = __THREW__; __THREW__ = 0;
                        $399 = $398&1;
                        if ($399) {
                         $414 = ___cxa_find_matching_catch_2()|0;
                         $415 = tempRet0;
                         __ZdlPv($395);
                         $$4 = $414;$$442 = $415;
                         break;
                        }
                        __THREW__ = 0;
                        (invoke_iii(3620,($18|0),($395|0))|0);
                        $400 = __THREW__; __THREW__ = 0;
                        $401 = $400&1;
                        if ($401) {
                         label = 135;
                         break;
                        }
                        $402 = ((($14)) + 11|0);
                        $403 = HEAP8[$402>>0]|0;
                        $404 = ($403<<24>>24)<(0);
                        if ($404) {
                         $405 = HEAP32[$14>>2]|0;
                         __ZdlPv($405);
                        }
                        $406 = ((($13)) + 11|0);
                        $407 = HEAP8[$406>>0]|0;
                        $408 = ($407<<24>>24)<(0);
                        if ($408) {
                         $409 = HEAP32[$13>>2]|0;
                         __ZdlPv($409);
                        }
                        __THREW__ = 0;
                        invoke_vi(1113,($9|0));
                        $410 = __THREW__; __THREW__ = 0;
                        $411 = $410&1;
                        if ($411) {
                         $426 = ___cxa_find_matching_catch_2()|0;
                         $427 = tempRet0;
                         $$8 = $426;$$846 = $427;
                         break L78;
                        }
                        __THREW__ = 0;
                        invoke_vi(1113,($8|0));
                        $424 = __THREW__; __THREW__ = 0;
                        $425 = $424&1;
                        if ($425) {
                         $430 = ___cxa_find_matching_catch_2()|0;
                         $431 = tempRet0;
                         $$10 = $430;$$1048 = $431;
                         break L59;
                        } else {
                         __ZNSt3__219basic_ostringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($7);
                         STACKTOP = sp;return ($15|0);
                        }
                       }
                      } while(0);
                      if ((label|0) == 135) {
                       $338 = ___cxa_find_matching_catch_2()|0;
                       $339 = tempRet0;
                       $eh$lpad$body142$index18Z2D = $339;$eh$lpad$body142$indexZ2D = $338;
                       label = 136;
                      }
                      if ((label|0) == 136) {
                       $$4 = $eh$lpad$body142$indexZ2D;$$442 = $eh$lpad$body142$index18Z2D;
                      }
                      $416 = ((($14)) + 11|0);
                      $417 = HEAP8[$416>>0]|0;
                      $418 = ($417<<24>>24)<(0);
                      if ($418) {
                       $419 = HEAP32[$14>>2]|0;
                       __ZdlPv($419);
                      }
                      $$5 = $$4;$$543 = $$442;
                     }
                     $420 = ((($13)) + 11|0);
                     $421 = HEAP8[$420>>0]|0;
                     $422 = ($421<<24>>24)<(0);
                     if ($422) {
                      $423 = HEAP32[$13>>2]|0;
                      __ZdlPv($423);
                     }
                     $$7 = $$5;$$745 = $$543;
                     label = 172;
                     break L78;
                    }
                   } while(0);
                   $223 = ___cxa_find_matching_catch_2()|0;
                   $224 = tempRet0;
                   $$7 = $223;$$745 = $224;
                   label = 172;
                   break L78;
                  }
                 } while(0);
                 $$7 = $$1;$$745 = $$139;
                 label = 172;
                }
               } while(0);
               if ((label|0) == 80) {
                $$7 = $$0;$$745 = $$038;
                label = 172;
               }
               do {
                if ((label|0) == 172) {
                 __THREW__ = 0;
                 invoke_vi(1113,($9|0));
                 $428 = __THREW__; __THREW__ = 0;
                 $429 = $428&1;
                 if (!($429)) {
                  $$8 = $$7;$$846 = $$745;
                  break;
                 }
                 $436 = ___cxa_find_matching_catch_3(0|0)|0;
                 $437 = tempRet0;
                 ___clang_call_terminate($436);
                 // unreachable;
                }
               } while(0);
               $$9 = $$8;$$947 = $$846;
               label = 176;
               break L59;
              }
             } while(0);
             __THREW__ = 0;
             invoke_vii(3614,($9|0),((50188)|0));
             $160 = __THREW__; __THREW__ = 0;
             $161 = $160&1;
             if (!($161)) {
              $$0$i73 = $eh$lpad$body$i70$index12Z2D;$$03$i72 = $eh$lpad$body$i70$indexZ2D;
              label = 62;
              break;
             }
             $164 = ___cxa_find_matching_catch_3(0|0)|0;
             $165 = tempRet0;
             ___clang_call_terminate($164);
             // unreachable;
            }
           } while(0);
           do {
            if ((label|0) == 62) {
             __THREW__ = 0;
             invoke_vi(2907,($125|0));
             $162 = __THREW__; __THREW__ = 0;
             $163 = $162&1;
             if (!($163)) {
              $$9 = $$03$i72;$$947 = $$0$i73;
              label = 176;
              break;
             }
             $164 = ___cxa_find_matching_catch_3(0|0)|0;
             $165 = tempRet0;
             ___clang_call_terminate($164);
             // unreachable;
            }
           } while(0);
           do {
            if ((label|0) == 176) {
             __THREW__ = 0;
             invoke_vi(1113,($8|0));
             $432 = __THREW__; __THREW__ = 0;
             $433 = $432&1;
             if (!($433)) {
              $$10 = $$9;$$1048 = $$947;
              break;
             }
             $436 = ___cxa_find_matching_catch_3(0|0)|0;
             $437 = tempRet0;
             ___clang_call_terminate($436);
             // unreachable;
            }
           } while(0);
           $$11 = $$10;$$1149 = $$1048;
           break L28;
          }
         } while(0);
         __THREW__ = 0;
         invoke_vii(3614,($8|0),((50188)|0));
         $119 = __THREW__; __THREW__ = 0;
         $120 = $119&1;
         if ($120) {
          $123 = ___cxa_find_matching_catch_3(0|0)|0;
          $124 = tempRet0;
          ___clang_call_terminate($123);
          // unreachable;
         } else {
          $$0$i65 = $eh$lpad$body$i62$index7Z2D;$$03$i64 = $eh$lpad$body$i62$indexZ2D;
         }
        }
        __THREW__ = 0;
        invoke_vi(2907,($84|0));
        $121 = __THREW__; __THREW__ = 0;
        $122 = $121&1;
        if ($122) {
         $123 = ___cxa_find_matching_catch_3(0|0)|0;
         $124 = tempRet0;
         ___clang_call_terminate($123);
         // unreachable;
        } else {
         $$0$i65$sink = $$0$i65;$$03$i64$sink = $$03$i64;
         label = 27;
        }
       }
      }
     }
    } while(0);
    if ((label|0) == 26) {
     $74 = ___cxa_find_matching_catch_2()|0;
     $75 = tempRet0;
     $$0$i65$sink = $75;$$03$i64$sink = $74;
     label = 27;
    }
    if ((label|0) == 27) {
     $$11 = $$03$i64$sink;$$1149 = $$0$i65$sink;
    }
    __THREW__ = 0;
    invoke_vi(1113,($7|0));
    $434 = __THREW__; __THREW__ = 0;
    $435 = $434&1;
    if ($435) {
     $436 = ___cxa_find_matching_catch_3(0|0)|0;
     $437 = tempRet0;
     ___clang_call_terminate($436);
     // unreachable;
    }
    $$13 = $$11;$$1351 = $$1149;
    ___resumeException($$13|0);
    // unreachable;
   }
  } while(0);
  __THREW__ = 0;
  invoke_vii(3614,($7|0),((50188)|0));
  $56 = __THREW__; __THREW__ = 0;
  $57 = $56&1;
  if ($57) {
   $60 = ___cxa_find_matching_catch_3(0|0)|0;
   $61 = tempRet0;
   ___clang_call_terminate($60);
   // unreachable;
  } else {
   $$0$i = $eh$lpad$body$i$index2Z2D;$$03$i = $eh$lpad$body$i$indexZ2D;
  }
 }
 __THREW__ = 0;
 invoke_vi(2907,($21|0));
 $58 = __THREW__; __THREW__ = 0;
 $59 = $58&1;
 if ($59) {
  $60 = ___cxa_find_matching_catch_3(0|0)|0;
  $61 = tempRet0;
  ___clang_call_terminate($60);
  // unreachable;
 } else {
  ___resumeException($$03$i|0);
  // unreachable;
 }
 return (0)|0;
}
function __ZNSt3__26__treeINS_12__value_typeIiN3osg7ref_ptrINS2_8StateSetEEEEENS_19__map_value_compareIiS6_NS_4lessIiEELb1EEENS_9allocatorIS6_EEE12__find_equalIiEERPNS_16__tree_node_baseIPvEENS_21__tree_const_iteratorIS6_PNS_11__tree_nodeIS6_SG_EEiEERPNS_15__tree_end_nodeISI_EESJ_RKT_($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0$i = 0, $$0$i$i = 0, $$0$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i$i = 0, $$0$i26 = 0, $$0$ph$i = 0, $$0$ph$i23 = 0, $$024$i = 0, $$024$i25 = 0, $$08$i$i = 0, $$2 = 0, $$in$i = 0, $$in$i22 = 0, $$pre = 0, $$sroa$043$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = ((($0)) + 4|0);
 $6 = HEAP32[$1>>2]|0;
 $7 = ($6|0)==($5|0);
 $8 = $6;
 if (!($7)) {
  $9 = ((($6)) + 16|0);
  $10 = HEAP32[$4>>2]|0;
  $11 = HEAP32[$9>>2]|0;
  $12 = ($10|0)<($11|0);
  if (!($12)) {
   $43 = ($11|0)<($10|0);
   if (!($43)) {
    HEAP32[$2>>2] = $8;
    HEAP32[$3>>2] = $8;
    $$2 = $3;
    return ($$2|0);
   }
   $44 = ((($6)) + 4|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = ($45|0)==(0|0);
   if ($46) {
    $47 = ((($6)) + 8|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = HEAP32[$48>>2]|0;
    $50 = ($49|0)==($6|0);
    if ($50) {
     $$0$i$i$i$i$i = $48;
    } else {
     $54 = $47;
     while(1) {
      $53 = HEAP32[$54>>2]|0;
      $55 = ((($53)) + 8|0);
      $56 = HEAP32[$55>>2]|0;
      $57 = HEAP32[$56>>2]|0;
      $58 = ($57|0)==($53|0);
      if ($58) {
       $$0$i$i$i$i$i = $56;
       break;
      } else {
       $54 = $55;
      }
     }
    }
   } else {
    $$0$i$i$i$i$i$i = $45;
    while(1) {
     $51 = HEAP32[$$0$i$i$i$i$i$i>>2]|0;
     $52 = ($51|0)==(0|0);
     if ($52) {
      break;
     } else {
      $$0$i$i$i$i$i$i = $51;
     }
    }
    $$0$i$i$i$i$i = $$0$i$i$i$i$i$i;
   }
   $59 = ($$0$i$i$i$i$i|0)==($5|0);
   if (!($59)) {
    $60 = ((($$0$i$i$i$i$i)) + 16|0);
    $61 = HEAP32[$60>>2]|0;
    $62 = ($10|0)<($61|0);
    if (!($62)) {
     $66 = HEAP32[$5>>2]|0;
     $67 = ($66|0)==(0|0);
     if ($67) {
      HEAP32[$2>>2] = $5;
      $$2 = $5;
      return ($$2|0);
     }
     $68 = ((($0)) + 4|0);
     $$0$i = $68;$$024$i = $66;
     while(1) {
      $69 = ((($$024$i)) + 16|0);
      $70 = HEAP32[$69>>2]|0;
      $71 = ($10|0)<($70|0);
      if ($71) {
       $72 = HEAP32[$$024$i>>2]|0;
       $73 = ($72|0)==(0|0);
       if ($73) {
        label = 39;
        break;
       } else {
        $$0$ph$i = $$024$i;$$in$i = $72;
       }
      } else {
       $74 = ($70|0)<($10|0);
       if (!($74)) {
        label = 43;
        break;
       }
       $75 = ((($$024$i)) + 4|0);
       $76 = HEAP32[$75>>2]|0;
       $77 = ($76|0)==(0|0);
       if ($77) {
        label = 42;
        break;
       } else {
        $$0$ph$i = $75;$$in$i = $76;
       }
      }
      $$0$i = $$0$ph$i;$$024$i = $$in$i;
     }
     if ((label|0) == 39) {
      HEAP32[$2>>2] = $$024$i;
      $$2 = $$024$i;
      return ($$2|0);
     }
     else if ((label|0) == 42) {
      HEAP32[$2>>2] = $$024$i;
      $$2 = $75;
      return ($$2|0);
     }
     else if ((label|0) == 43) {
      HEAP32[$2>>2] = $$024$i;
      $$2 = $$0$i;
      return ($$2|0);
     }
    }
   }
   $63 = ((($6)) + 4|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = ($64|0)==(0|0);
   if ($65) {
    HEAP32[$2>>2] = $8;
    $$2 = $44;
    return ($$2|0);
   } else {
    HEAP32[$2>>2] = $$0$i$i$i$i$i;
    $$2 = $$0$i$i$i$i$i;
    return ($$2|0);
   }
  }
 }
 $13 = HEAP32[$0>>2]|0;
 $14 = ($6|0)==($13|0);
 $$pre = HEAP32[$6>>2]|0;
 if ($14) {
  $$sroa$043$0 = $8;
 } else {
  $15 = ($$pre|0)==(0|0);
  if ($15) {
   $$0$i$i = $6;
   while(1) {
    $19 = ((($$0$i$i)) + 8|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = HEAP32[$20>>2]|0;
    $22 = ($21|0)==($$0$i$i|0);
    if ($22) {
     $$0$i$i = $20;
    } else {
     $$08$i$i = $20;
     break;
    }
   }
  } else {
   $$0$i$i$i = $$pre;
   while(1) {
    $16 = ((($$0$i$i$i)) + 4|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = ($17|0)==(0|0);
    if ($18) {
     $$08$i$i = $$0$i$i$i;
     break;
    } else {
     $$0$i$i$i = $17;
    }
   }
  }
  $23 = $$08$i$i;
  $24 = ((($$08$i$i)) + 16|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = HEAP32[$4>>2]|0;
  $27 = ($25|0)<($26|0);
  if ($27) {
   $$sroa$043$0 = $23;
  } else {
   $31 = HEAP32[$5>>2]|0;
   $32 = ($31|0)==(0|0);
   if ($32) {
    HEAP32[$2>>2] = $5;
    $$2 = $5;
    return ($$2|0);
   }
   $33 = ((($0)) + 4|0);
   $$0$i26 = $33;$$024$i25 = $31;
   while(1) {
    $34 = ((($$024$i25)) + 16|0);
    $35 = HEAP32[$34>>2]|0;
    $36 = ($26|0)<($35|0);
    if ($36) {
     $37 = HEAP32[$$024$i25>>2]|0;
     $38 = ($37|0)==(0|0);
     if ($38) {
      label = 17;
      break;
     } else {
      $$0$ph$i23 = $$024$i25;$$in$i22 = $37;
     }
    } else {
     $39 = ($35|0)<($26|0);
     if (!($39)) {
      label = 21;
      break;
     }
     $40 = ((($$024$i25)) + 4|0);
     $41 = HEAP32[$40>>2]|0;
     $42 = ($41|0)==(0|0);
     if ($42) {
      label = 20;
      break;
     } else {
      $$0$ph$i23 = $40;$$in$i22 = $41;
     }
    }
    $$0$i26 = $$0$ph$i23;$$024$i25 = $$in$i22;
   }
   if ((label|0) == 17) {
    HEAP32[$2>>2] = $$024$i25;
    $$2 = $$024$i25;
    return ($$2|0);
   }
   else if ((label|0) == 20) {
    HEAP32[$2>>2] = $$024$i25;
    $$2 = $40;
    return ($$2|0);
   }
   else if ((label|0) == 21) {
    HEAP32[$2>>2] = $$024$i25;
    $$2 = $$0$i26;
    return ($$2|0);
   }
  }
 }
 $28 = ($$pre|0)==(0|0);
 if ($28) {
  HEAP32[$2>>2] = $6;
  $$2 = $6;
  return ($$2|0);
 } else {
  $29 = $$sroa$043$0;
  HEAP32[$2>>2] = $29;
  $30 = ((($29)) + 4|0);
  $$2 = $30;
  return ($$2|0);
 }
 return (0)|0;
}
function __ZNSt3__219basic_ostringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = ((50156));
 $1 = ((($0)) + 56|0);
 HEAP32[$1>>2] = ((50176));
 $2 = ((($0)) + 4|0);
 HEAP32[$2>>2] = (37132);
 $3 = ((($0)) + 36|0);
 $4 = ((($3)) + 11|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)<(0);
 if ($6) {
  $7 = HEAP32[$3>>2]|0;
  __ZdlPv($7);
 }
 __THREW__ = 0;
 invoke_vi(2911,($2|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 do {
  if ($9) {
   $12 = ___cxa_find_matching_catch_2()|0;
   $13 = tempRet0;
   __THREW__ = 0;
   invoke_vii(3614,($0|0),((50188)|0));
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if ($15) {
    $16 = ___cxa_find_matching_catch_3(0|0)|0;
    $17 = tempRet0;
    ___clang_call_terminate($16);
    // unreachable;
   } else {
    $eh$lpad$body$index2Z2D = $13;$eh$lpad$body$indexZ2D = $12;
   }
  } else {
   __THREW__ = 0;
   invoke_vii(3614,($0|0),((50188)|0));
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if ($11) {
    $18 = ___cxa_find_matching_catch_2()|0;
    $19 = tempRet0;
    $eh$lpad$body$index2Z2D = $19;$eh$lpad$body$indexZ2D = $18;
    break;
   } else {
    __ZNSt3__29basic_iosIcNS_11char_traitsIcEEED2Ev($1);
    return;
   }
  }
 } while(0);
 __THREW__ = 0;
 invoke_vi(2907,($1|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if ($21) {
  $22 = ___cxa_find_matching_catch_3(0|0)|0;
  $23 = tempRet0;
  ___clang_call_terminate($22);
  // unreachable;
 } else {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
}
function __ZNSt3__219basic_ostringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1113,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZTv0_n12_NSt3__219basic_ostringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __ZNSt3__219basic_ostringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($4);
 return;
}
function __ZTv0_n12_NSt3__219basic_ostringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __THREW__ = 0;
 invoke_vi(1113,($4|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $7 = ___cxa_find_matching_catch_2()|0;
  $8 = tempRet0;
  __ZdlPv($4);
  ___resumeException($7|0);
  // unreachable;
 } else {
  __ZdlPv($4);
  return;
 }
}
function __ZN7osgUtil7StateExD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1119,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZN7osgUtil14ShaderGenCacheD2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (50208);
 $1 = ((($0)) + 24|0);
 $2 = ((($0)) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIiN3osg7ref_ptrINS2_8StateSetEEEEENS_19__map_value_compareIiS6_NS_4lessIiEELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($1,$3);
 $4 = ((($0)) + 12|0);
 __THREW__ = 0;
 invoke_vi(707,($4|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if (!($6)) {
  __ZN3osg10ReferencedD2Ev($0);
  return;
 }
 $7 = ___cxa_find_matching_catch_2()|0;
 $8 = tempRet0;
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if ($10) {
  $11 = ___cxa_find_matching_catch_3(0|0)|0;
  $12 = tempRet0;
  ___clang_call_terminate($11);
  // unreachable;
 } else {
  ___resumeException($7|0);
  // unreachable;
 }
}
function __ZN7osgUtil14ShaderGenCacheD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (50208);
 $1 = ((($0)) + 24|0);
 $2 = ((($0)) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIiN3osg7ref_ptrINS2_8StateSetEEEEENS_19__map_value_compareIiS6_NS_4lessIiEELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($1,$3);
 $4 = ((($0)) + 12|0);
 __THREW__ = 0;
 invoke_vi(707,($4|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $9 = ___cxa_find_matching_catch_2()|0;
  $10 = tempRet0;
  __THREW__ = 0;
  invoke_vi(712,($0|0));
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if ($12) {
   $13 = ___cxa_find_matching_catch_3(0|0)|0;
   $14 = tempRet0;
   ___clang_call_terminate($13);
   // unreachable;
  } else {
   $eh$lpad$body$index2Z2D = $10;$eh$lpad$body$indexZ2D = $9;
   __ZdlPv($0);
   ___resumeException($eh$lpad$body$indexZ2D|0);
   // unreachable;
  }
 }
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if (!($8)) {
  __ZdlPv($0);
  return;
 }
 $15 = ___cxa_find_matching_catch_2()|0;
 $16 = tempRet0;
 $eh$lpad$body$index2Z2D = $16;$eh$lpad$body$indexZ2D = $15;
 __ZdlPv($0);
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
}
function __ZNSt3__26__treeINS_12__value_typeIiN3osg7ref_ptrINS2_8StateSetEEEEENS_19__map_value_compareIiS6_NS_4lessIiEELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 }
 $3 = HEAP32[$1>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIiN3osg7ref_ptrINS2_8StateSetEEEEENS_19__map_value_compareIiS6_NS_4lessIiEELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($0,$3);
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIiN3osg7ref_ptrINS2_8StateSetEEEEENS_19__map_value_compareIiS6_NS_4lessIiEELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($0,$5);
 $6 = ((($1)) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = ((($7)) + 8|0);
  $10 = HEAP32[$9>>2]|0;HEAP32[$9>>2] = (($10-1)|0);
  $11 = ($10|0)==(1);
  if ($11) {
   __THREW__ = 0;
   invoke_viii(3262,($7|0),1,1);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if ($13) {
    $14 = ___cxa_find_matching_catch_2()|0;
    $15 = tempRet0;
    ___cxa_call_unexpected(($14|0));
    // unreachable;
   }
  }
 }
 __ZdlPv($1);
 return;
}
function __ZN7osgUtil16ShaderGenVisitorC1Ev($0) {
 $0 = $0|0;
 var $$0 = 0, $$02 = 0, $$1 = 0, $$13 = 0, $$2 = 0, $$24 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 68|0);
 __ZN3osg10ReferencedC2Ev($1);
 HEAP32[$1>>2] = (63412);
 $2 = ((($0)) + 80|0);
 ;HEAP32[$2>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;
 $3 = ((($0)) + 92|0);
 HEAP32[$3>>2] = 2;
 $4 = ((($0)) + 96|0);
 HEAP32[$4>>2] = 0;
 __THREW__ = 0;
 invoke_viii(3283,($0|0),((50132)|0),2);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $36 = ___cxa_find_matching_catch_2()|0;
  $37 = tempRet0;
  $$2 = $37;$$24 = $36;
 } else {
  HEAP32[$0>>2] = (49644);
  HEAP32[$1>>2] = (49988);
  __THREW__ = 0;
  $7 = (invoke_ii(3276,36)|0);
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  L4: do {
   if ($9) {
    $38 = ___cxa_find_matching_catch_2()|0;
    $39 = tempRet0;
    $$1 = $39;$$13 = $38;
   } else {
    __THREW__ = 0;
    invoke_vi(3282,($7|0));
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    do {
     if ($11) {
      $40 = ___cxa_find_matching_catch_2()|0;
      $41 = tempRet0;
      $eh$lpad$body$index2Z2D = $41;$eh$lpad$body$indexZ2D = $40;
     } else {
      HEAP32[$7>>2] = (50208);
      $12 = ((($7)) + 12|0);
      __THREW__ = 0;
      invoke_vii(3507,($12|0),0);
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if ($14) {
       $15 = ___cxa_find_matching_catch_2()|0;
       $16 = tempRet0;
       __THREW__ = 0;
       invoke_vi(712,($7|0));
       $17 = __THREW__; __THREW__ = 0;
       $18 = $17&1;
       if (!($18)) {
        $eh$lpad$body$index2Z2D = $16;$eh$lpad$body$indexZ2D = $15;
        break;
       }
       $19 = ___cxa_find_matching_catch_3(0|0)|0;
       $20 = tempRet0;
       ___clang_call_terminate($19);
       // unreachable;
      }
      $21 = ((($7)) + 28|0);
      HEAP32[$21>>2] = 0;
      $22 = ((($7)) + 32|0);
      HEAP32[$22>>2] = 0;
      $23 = ((($7)) + 24|0);
      HEAP32[$23>>2] = $21;
      $24 = ((($0)) + 56|0);
      HEAP32[$24>>2] = $7;
      $25 = ((($7)) + 8|0);
      $26 = HEAP32[$25>>2]|0;HEAP32[$25>>2] = (($26+1)|0);
      __THREW__ = 0;
      $27 = (invoke_ii(3276,896)|0);
      $28 = __THREW__; __THREW__ = 0;
      $29 = $28&1;
      do {
       if ($29) {
        $42 = ___cxa_find_matching_catch_2()|0;
        $43 = tempRet0;
        $$0 = $43;$$02 = $42;
       } else {
        __THREW__ = 0;
        invoke_vi(3421,($27|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if ($31) {
         $44 = ___cxa_find_matching_catch_2()|0;
         $45 = tempRet0;
         __ZdlPv($27);
         $$0 = $45;$$02 = $44;
         break;
        } else {
         HEAP32[$27>>2] = (50228);
         $32 = ((($0)) + 60|0);
         HEAP32[$32>>2] = $27;
         $33 = ((($27)) + 8|0);
         $34 = HEAP32[$33>>2]|0;HEAP32[$33>>2] = (($34+1)|0);
         $35 = ((($0)) + 64|0);
         HEAP32[$35>>2] = 0;
         return;
        }
       }
      } while(0);
      $46 = HEAP32[$24>>2]|0;
      $47 = ($46|0)==(0|0);
      if (!($47)) {
       $48 = ((($46)) + 8|0);
       $49 = HEAP32[$48>>2]|0;HEAP32[$48>>2] = (($49-1)|0);
       $50 = ($49|0)==(1);
       if ($50) {
        __THREW__ = 0;
        invoke_viii(3262,($46|0),1,1);
        $51 = __THREW__; __THREW__ = 0;
        $52 = $51&1;
        if ($52) {
         $57 = ___cxa_find_matching_catch_3(0|0)|0;
         $58 = tempRet0;
         ___clang_call_terminate($57);
         // unreachable;
        }
       }
      }
      HEAP32[$24>>2] = 0;
      $$1 = $$0;$$13 = $$02;
      break L4;
     }
    } while(0);
    __ZdlPv($7);
    $$1 = $eh$lpad$body$index2Z2D;$$13 = $eh$lpad$body$indexZ2D;
   }
  } while(0);
  __THREW__ = 0;
  invoke_vii(3284,($0|0),((50132)|0));
  $53 = __THREW__; __THREW__ = 0;
  $54 = $53&1;
  if ($54) {
   $57 = ___cxa_find_matching_catch_3(0|0)|0;
   $58 = tempRet0;
   ___clang_call_terminate($57);
   // unreachable;
  } else {
   $$2 = $$1;$$24 = $$13;
  }
 }
 __THREW__ = 0;
 invoke_vi(388,($1|0));
 $55 = __THREW__; __THREW__ = 0;
 $56 = $55&1;
 if ($56) {
  $57 = ___cxa_find_matching_catch_3(0|0)|0;
  $58 = tempRet0;
  ___clang_call_terminate($57);
  // unreachable;
 } else {
  ___resumeException($$24|0);
  // unreachable;
 }
}
function __ZN7osgUtil10StateGraph5cleanEv($0) {
 $0 = $0|0;
 var $$0$i$i$i$i = 0, $$sroa$03$0$be = 0, $$sroa$03$07 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 36|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 40|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==($2|0);
 L1: do {
  if (!($5)) {
   $7 = $4;
   while(1) {
    $6 = ((($7)) + -4|0);
    HEAP32[$3>>2] = $6;
    $8 = HEAP32[$6>>2]|0;
    $9 = ($8|0)==(0|0);
    if (!($9)) {
     $10 = ((($8)) + 8|0);
     $11 = HEAP32[$10>>2]|0;HEAP32[$10>>2] = (($11-1)|0);
     $12 = ($11|0)==(1);
     if ($12) {
      __THREW__ = 0;
      invoke_viii(3262,($8|0),1,1);
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if ($14) {
       break;
      }
     }
    }
    HEAP32[$6>>2] = 0;
    $15 = HEAP32[$3>>2]|0;
    $16 = ($15|0)==($2|0);
    if ($16) {
     break L1;
    } else {
     $7 = $15;
    }
   }
   $17 = ___cxa_find_matching_catch_2()|0;
   $18 = tempRet0;
   ___cxa_call_unexpected(($17|0));
   // unreachable;
  }
 } while(0);
 $19 = ((($0)) + 24|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ((($0)) + 28|0);
 $22 = ($20|0)==($21|0);
 if ($22) {
  return;
 } else {
  $$sroa$03$07 = $20;
 }
 while(1) {
  $23 = ((($$sroa$03$07)) + 20|0);
  $24 = HEAP32[$23>>2]|0;
  __ZN7osgUtil10StateGraph5cleanEv($24);
  $25 = ((($$sroa$03$07)) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = ($26|0)==(0|0);
  if ($27) {
   $28 = ((($$sroa$03$07)) + 8|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = HEAP32[$29>>2]|0;
   $31 = ($30|0)==($$sroa$03$07|0);
   if ($31) {
    $$sroa$03$0$be = $29;
   } else {
    $36 = $28;
    while(1) {
     $35 = HEAP32[$36>>2]|0;
     $37 = ((($35)) + 8|0);
     $38 = HEAP32[$37>>2]|0;
     $39 = HEAP32[$38>>2]|0;
     $40 = ($39|0)==($35|0);
     if ($40) {
      $$sroa$03$0$be = $38;
      break;
     } else {
      $36 = $37;
     }
    }
   }
  } else {
   $$0$i$i$i$i = $26;
   while(1) {
    $33 = HEAP32[$$0$i$i$i$i>>2]|0;
    $34 = ($33|0)==(0|0);
    if ($34) {
     break;
    } else {
     $$0$i$i$i$i = $33;
    }
   }
   $$sroa$03$0$be = $$0$i$i$i$i;
  }
  $32 = ($$sroa$03$0$be|0)==($21|0);
  if ($32) {
   break;
  } else {
   $$sroa$03$07 = $$sroa$03$0$be;
  }
 }
 return;
}
function __ZN7osgUtil10StateGraph5pruneEv($0) {
 $0 = $0|0;
 var $$0$i$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i4 = 0, $$0$i$i$i$i8 = 0, $$0$i$i$i$i824 = 0, $$0$i$i$i$i825 = 0, $$0$i$i$i$i9 = 0, $$sroa$012$0$be = 0, $$sroa$012$021 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 28|0);
 $4 = ($2|0)==($3|0);
 if ($4) {
  return;
 }
 $5 = ((($0)) + 32|0);
 $6 = ((($0)) + 28|0);
 $$sroa$012$021 = $2;
 while(1) {
  $7 = ((($$sroa$012$021)) + 20|0);
  $8 = HEAP32[$7>>2]|0;
  __ZN7osgUtil10StateGraph5pruneEv($8);
  $9 = HEAP32[$7>>2]|0;
  $10 = ((($9)) + 36|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ((($9)) + 40|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($11|0)==($13|0);
  if ($14) {
   $15 = ((($9)) + 32|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ($16|0)==(0);
   if ($17) {
    $18 = ((($$sroa$012$021)) + 4|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = ($19|0)==(0|0);
    if ($20) {
     $21 = ((($$sroa$012$021)) + 8|0);
     $22 = HEAP32[$21>>2]|0;
     $23 = HEAP32[$22>>2]|0;
     $24 = ($23|0)==($$sroa$012$021|0);
     if ($24) {
      $$0$i$i$i$i825 = $22;
      label = 11;
     } else {
      $28 = $21;
      while(1) {
       $27 = HEAP32[$28>>2]|0;
       $29 = ((($27)) + 8|0);
       $30 = HEAP32[$29>>2]|0;
       $31 = HEAP32[$30>>2]|0;
       $32 = ($31|0)==($27|0);
       if ($32) {
        $$0$i$i$i$i8 = $30;
        label = 10;
        break;
       } else {
        $28 = $29;
       }
      }
     }
    } else {
     $$0$i$i$i$i$i4 = $19;
     while(1) {
      $25 = HEAP32[$$0$i$i$i$i$i4>>2]|0;
      $26 = ($25|0)==(0|0);
      if ($26) {
       break;
      } else {
       $$0$i$i$i$i$i4 = $25;
      }
     }
     $$0$i$i$i$i8 = $$0$i$i$i$i$i4;
     label = 10;
    }
    if ((label|0) == 10) {
     label = 0;
     if ($20) {
      $$0$i$i$i$i825 = $$0$i$i$i$i8;
      label = 11;
     } else {
      $$0$i$i$i$i$i = $19;
      while(1) {
       $37 = HEAP32[$$0$i$i$i$i$i>>2]|0;
       $38 = ($37|0)==(0|0);
       if ($38) {
        break;
       } else {
        $$0$i$i$i$i$i = $37;
       }
      }
      $$0$i$i$i$i = $$0$i$i$i$i$i;$$0$i$i$i$i824 = $$0$i$i$i$i8;
     }
    }
    if ((label|0) == 11) {
     label = 0;
     $33 = ((($$sroa$012$021)) + 8|0);
     $34 = HEAP32[$33>>2]|0;
     $35 = HEAP32[$34>>2]|0;
     $36 = ($35|0)==($$sroa$012$021|0);
     if ($36) {
      $$0$i$i$i$i = $34;$$0$i$i$i$i824 = $$0$i$i$i$i825;
     } else {
      $40 = $33;
      while(1) {
       $39 = HEAP32[$40>>2]|0;
       $41 = ((($39)) + 8|0);
       $42 = HEAP32[$41>>2]|0;
       $43 = HEAP32[$42>>2]|0;
       $44 = ($43|0)==($39|0);
       if ($44) {
        $$0$i$i$i$i = $42;$$0$i$i$i$i824 = $$0$i$i$i$i825;
        break;
       } else {
        $40 = $41;
       }
      }
     }
    }
    $45 = HEAP32[$1>>2]|0;
    $46 = ($45|0)==($$sroa$012$021|0);
    if ($46) {
     $47 = $$0$i$i$i$i;
     HEAP32[$1>>2] = $47;
    }
    $48 = HEAP32[$5>>2]|0;
    $49 = (($48) + -1)|0;
    HEAP32[$5>>2] = $49;
    $50 = HEAP32[$6>>2]|0;
    __ZNSt3__213__tree_removeIPNS_16__tree_node_baseIPvEEEEvT_S5_($50,$$sroa$012$021);
    $51 = HEAP32[$7>>2]|0;
    $52 = ($51|0)==(0|0);
    if (!($52)) {
     $53 = ((($51)) + 8|0);
     $54 = HEAP32[$53>>2]|0;HEAP32[$53>>2] = (($54-1)|0);
     $55 = ($54|0)==(1);
     if ($55) {
      __ZNK3osg10Referenced24signalObserversAndDeleteEbb($51,1,1);
     }
    }
    __ZdlPv($$sroa$012$021);
    $$sroa$012$0$be = $$0$i$i$i$i824;
   } else {
    label = 22;
   }
  } else {
   label = 22;
  }
  do {
   if ((label|0) == 22) {
    label = 0;
    $57 = ((($$sroa$012$021)) + 4|0);
    $58 = HEAP32[$57>>2]|0;
    $59 = ($58|0)==(0|0);
    if ($59) {
     $60 = ((($$sroa$012$021)) + 8|0);
     $61 = HEAP32[$60>>2]|0;
     $62 = HEAP32[$61>>2]|0;
     $63 = ($62|0)==($$sroa$012$021|0);
     if ($63) {
      $$sroa$012$0$be = $61;
      break;
     } else {
      $67 = $60;
     }
     while(1) {
      $66 = HEAP32[$67>>2]|0;
      $68 = ((($66)) + 8|0);
      $69 = HEAP32[$68>>2]|0;
      $70 = HEAP32[$69>>2]|0;
      $71 = ($70|0)==($66|0);
      if ($71) {
       $$sroa$012$0$be = $69;
       break;
      } else {
       $67 = $68;
      }
     }
    } else {
     $$0$i$i$i$i9 = $58;
     while(1) {
      $64 = HEAP32[$$0$i$i$i$i9>>2]|0;
      $65 = ($64|0)==(0|0);
      if ($65) {
       break;
      } else {
       $$0$i$i$i$i9 = $64;
      }
     }
     $$sroa$012$0$be = $$0$i$i$i$i9;
     break;
    }
   }
  } while(0);
  $56 = ($$sroa$012$0$be|0)==($3|0);
  if ($56) {
   break;
  } else {
   $$sroa$012$021 = $$sroa$012$0$be;
  }
 }
 return;
}
function __ZN7osgUtil10StatisticsD2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (50252);
 $1 = ((($0)) + 68|0);
 $2 = ((($0)) + 72|0);
 $3 = HEAP32[$2>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIjjEENS_19__map_value_compareIjS2_NS_4lessIjEELb1EEENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($1,$3);
 $4 = ((($0)) + 52|0);
 $5 = ((($0)) + 56|0);
 $6 = HEAP32[$5>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIjNS_4pairIjjEEEENS_19__map_value_compareIjS4_NS_4lessIjEELb1EEENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($4,$6);
 return;
}
function __ZN7osgUtil10StatisticsD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (50252);
 $1 = ((($0)) + 68|0);
 $2 = ((($0)) + 72|0);
 $3 = HEAP32[$2>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIjjEENS_19__map_value_compareIjS2_NS_4lessIjEELb1EEENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($1,$3);
 $4 = ((($0)) + 52|0);
 $5 = ((($0)) + 56|0);
 $6 = HEAP32[$5>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIjNS_4pairIjjEEEENS_19__map_value_compareIjS4_NS_4lessIjEELb1EEENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($4,$6);
 __ZdlPv($0);
 return;
}
function __ZN7osgUtil10Statistics14setVertexArrayEjPKN3osg5Vec2fE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 48|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + ($1))|0;
 HEAP32[$3>>2] = $5;
 return;
}
function __ZN7osgUtil10Statistics14setVertexArrayEjPKN3osg5Vec3fE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 48|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + ($1))|0;
 HEAP32[$3>>2] = $5;
 return;
}
function __ZN7osgUtil10Statistics14setVertexArrayEjPKN3osg5Vec4fE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 48|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + ($1))|0;
 HEAP32[$3>>2] = $5;
 return;
}
function __ZN7osgUtil10Statistics14setVertexArrayEjPKN3osg5Vec2dE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 48|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + ($1))|0;
 HEAP32[$3>>2] = $5;
 return;
}
function __ZN7osgUtil10Statistics14setVertexArrayEjPKN3osg5Vec3dE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 48|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + ($1))|0;
 HEAP32[$3>>2] = $5;
 return;
}
function __ZN7osgUtil10Statistics14setVertexArrayEjPKN3osg5Vec4dE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 48|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + ($1))|0;
 HEAP32[$3>>2] = $5;
 return;
}
function __ZN7osgUtil10Statistics10drawArraysEjii($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0$i = 0, $$0$i$i = 0, $$0$i$i10 = 0, $$0$ph$i$i = 0, $$0$ph$i$i7 = 0, $$014$i = 0, $$014$i16 = 0, $$024$i$i = 0, $$024$i$i9 = 0, $$025$i$i = 0, $$025$i$i12 = 0, $$025$i47$i = 0, $$025$i47$i13 = 0, $$034$i = 0, $$034$i11 = 0, $$03446$i = 0, $$03446$i14 = 0, $$in$i$i = 0, $$in$i$i6 = 0, $$pre$i$i = 0;
 var $$pre$i$i15 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ((($0)) + 52|0);
 $5 = ((($0)) + 56|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 do {
  if ($7) {
   $$025$i$i = $5;$$034$i = $5;$18 = $6;
   label = 12;
  } else {
   $8 = ((($0)) + 56|0);
   $$0$i$i = $8;$$024$i$i = $6;$83 = $6;
   while(1) {
    $9 = ((($$024$i$i)) + 16|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = ($10>>>0)>($1>>>0);
    if ($11) {
     $12 = HEAP32[$$024$i$i>>2]|0;
     $13 = ($12|0)==(0|0);
     if ($13) {
      label = 6;
      break;
     } else {
      $$0$ph$i$i = $$024$i$i;$$in$i$i = $12;
     }
    } else {
     $14 = ($10>>>0)<($1>>>0);
     if (!($14)) {
      label = 10;
      break;
     }
     $15 = ((($$024$i$i)) + 4|0);
     $16 = HEAP32[$15>>2]|0;
     $17 = ($16|0)==(0|0);
     if ($17) {
      label = 9;
      break;
     } else {
      $$0$ph$i$i = $15;$$in$i$i = $16;
     }
    }
    $$0$i$i = $$0$ph$i$i;$$024$i$i = $$in$i$i;$83 = $$in$i$i;
   }
   if ((label|0) == 6) {
    $$025$i47$i = $$024$i$i;$$03446$i = $$024$i$i;
    label = 13;
    break;
   }
   else if ((label|0) == 9) {
    $$025$i47$i = $15;$$03446$i = $$024$i$i;
    label = 13;
    break;
   }
   else if ((label|0) == 10) {
    $$025$i$i = $$0$i$i;$$034$i = $$024$i$i;$18 = $83;
    label = 12;
    break;
   }
  }
 } while(0);
 if ((label|0) == 12) {
  $19 = ($18|0)==(0|0);
  if ($19) {
   $$025$i47$i = $$025$i$i;$$03446$i = $$034$i;
   label = 13;
  } else {
   $$014$i = $18;
  }
 }
 if ((label|0) == 13) {
  $20 = (__Znwj(28)|0);
  $21 = ((($20)) + 16|0);
  HEAP32[$21>>2] = $1;
  $22 = ((($20)) + 20|0);
  HEAP32[$22>>2] = 0;
  $23 = ((($20)) + 24|0);
  HEAP32[$23>>2] = 0;
  HEAP32[$20>>2] = 0;
  $24 = ((($20)) + 4|0);
  HEAP32[$24>>2] = 0;
  $25 = ((($20)) + 8|0);
  HEAP32[$25>>2] = $$03446$i;
  HEAP32[$$025$i47$i>>2] = $20;
  $26 = HEAP32[$4>>2]|0;
  $27 = HEAP32[$26>>2]|0;
  $28 = ($27|0)==(0|0);
  if ($28) {
   $32 = $20;
  } else {
   $29 = $27;
   HEAP32[$4>>2] = $29;
   $$pre$i$i = HEAP32[$$025$i47$i>>2]|0;
   $32 = $$pre$i$i;
  }
  $30 = ((($0)) + 56|0);
  $31 = HEAP32[$30>>2]|0;
  __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($31,$32);
  $33 = ((($0)) + 60|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = (($34) + 1)|0;
  HEAP32[$33>>2] = $35;
  $$014$i = $20;
 }
 $36 = ((($$014$i)) + 20|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (($37) + 1)|0;
 HEAP32[$36>>2] = $38;
 $39 = ((($$014$i)) + 24|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = (($40) + ($3))|0;
 HEAP32[$39>>2] = $41;
 switch ($1|0) {
 case 9: case 2: case 0:  {
  $$0$i = $3;
  break;
 }
 case 1:  {
  $42 = (($3|0) / 2)&-1;
  $$0$i = $42;
  break;
 }
 case 3:  {
  $43 = (($3) + -1)|0;
  $$0$i = $43;
  break;
 }
 case 4:  {
  $44 = (($3|0) / 3)&-1;
  $$0$i = $44;
  break;
 }
 case 6: case 5:  {
  $45 = (($3) + -2)|0;
  $$0$i = $45;
  break;
 }
 case 7:  {
  $46 = (($3|0) / 4)&-1;
  $$0$i = $46;
  break;
 }
 case 8:  {
  $47 = (($3|0) / 2)&-1;
  $48 = (($47) + -1)|0;
  $$0$i = $48;
  break;
 }
 default: {
  $$0$i = 0;
 }
 }
 $49 = ((($0)) + 68|0);
 $50 = ((($0)) + 72|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = ($51|0)==(0|0);
 do {
  if ($52) {
   $$025$i$i12 = $50;$$034$i11 = $50;$63 = $51;
   label = 35;
  } else {
   $53 = ((($0)) + 72|0);
   $$0$i$i10 = $53;$$024$i$i9 = $51;$84 = $51;
   while(1) {
    $54 = ((($$024$i$i9)) + 16|0);
    $55 = HEAP32[$54>>2]|0;
    $56 = ($55>>>0)>($1>>>0);
    if ($56) {
     $57 = HEAP32[$$024$i$i9>>2]|0;
     $58 = ($57|0)==(0|0);
     if ($58) {
      label = 29;
      break;
     } else {
      $$0$ph$i$i7 = $$024$i$i9;$$in$i$i6 = $57;
     }
    } else {
     $59 = ($55>>>0)<($1>>>0);
     if (!($59)) {
      label = 33;
      break;
     }
     $60 = ((($$024$i$i9)) + 4|0);
     $61 = HEAP32[$60>>2]|0;
     $62 = ($61|0)==(0|0);
     if ($62) {
      label = 32;
      break;
     } else {
      $$0$ph$i$i7 = $60;$$in$i$i6 = $61;
     }
    }
    $$0$i$i10 = $$0$ph$i$i7;$$024$i$i9 = $$in$i$i6;$84 = $$in$i$i6;
   }
   if ((label|0) == 29) {
    $$025$i47$i13 = $$024$i$i9;$$03446$i14 = $$024$i$i9;
    break;
   }
   else if ((label|0) == 32) {
    $$025$i47$i13 = $60;$$03446$i14 = $$024$i$i9;
    break;
   }
   else if ((label|0) == 33) {
    $$025$i$i12 = $$0$i$i10;$$034$i11 = $$024$i$i9;$63 = $84;
    label = 35;
    break;
   }
  }
 } while(0);
 if ((label|0) == 35) {
  $64 = ($63|0)==(0|0);
  if ($64) {
   $$025$i47$i13 = $$025$i$i12;$$03446$i14 = $$034$i11;
  } else {
   $$014$i16 = $63;
   $80 = ((($$014$i16)) + 20|0);
   $81 = HEAP32[$80>>2]|0;
   $82 = (($81) + ($$0$i))|0;
   HEAP32[$80>>2] = $82;
   return;
  }
 }
 $65 = (__Znwj(24)|0);
 $66 = ((($65)) + 16|0);
 HEAP32[$66>>2] = $1;
 $67 = ((($65)) + 20|0);
 HEAP32[$67>>2] = 0;
 HEAP32[$65>>2] = 0;
 $68 = ((($65)) + 4|0);
 HEAP32[$68>>2] = 0;
 $69 = ((($65)) + 8|0);
 HEAP32[$69>>2] = $$03446$i14;
 HEAP32[$$025$i47$i13>>2] = $65;
 $70 = HEAP32[$49>>2]|0;
 $71 = HEAP32[$70>>2]|0;
 $72 = ($71|0)==(0|0);
 if ($72) {
  $76 = $65;
 } else {
  $73 = $71;
  HEAP32[$49>>2] = $73;
  $$pre$i$i15 = HEAP32[$$025$i47$i13>>2]|0;
  $76 = $$pre$i$i15;
 }
 $74 = ((($0)) + 72|0);
 $75 = HEAP32[$74>>2]|0;
 __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($75,$76);
 $77 = ((($0)) + 76|0);
 $78 = HEAP32[$77>>2]|0;
 $79 = (($78) + 1)|0;
 HEAP32[$77>>2] = $79;
 $$014$i16 = $65;
 $80 = ((($$014$i16)) + 20|0);
 $81 = HEAP32[$80>>2]|0;
 $82 = (($81) + ($$0$i))|0;
 HEAP32[$80>>2] = $82;
 return;
}
function __ZN7osgUtil10Statistics12drawElementsEjiPKh($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0$i = 0, $$0$i$i = 0, $$0$i$i10 = 0, $$0$ph$i$i = 0, $$0$ph$i$i7 = 0, $$014$i = 0, $$014$i16 = 0, $$024$i$i = 0, $$024$i$i9 = 0, $$025$i$i = 0, $$025$i$i12 = 0, $$025$i47$i = 0, $$025$i47$i13 = 0, $$034$i = 0, $$034$i11 = 0, $$03446$i = 0, $$03446$i14 = 0, $$in$i$i = 0, $$in$i$i6 = 0, $$pre$i$i = 0;
 var $$pre$i$i15 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ((($0)) + 52|0);
 $5 = ((($0)) + 56|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 do {
  if ($7) {
   $$025$i$i = $5;$$034$i = $5;$18 = $6;
   label = 12;
  } else {
   $8 = ((($0)) + 56|0);
   $$0$i$i = $8;$$024$i$i = $6;$83 = $6;
   while(1) {
    $9 = ((($$024$i$i)) + 16|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = ($10>>>0)>($1>>>0);
    if ($11) {
     $12 = HEAP32[$$024$i$i>>2]|0;
     $13 = ($12|0)==(0|0);
     if ($13) {
      label = 6;
      break;
     } else {
      $$0$ph$i$i = $$024$i$i;$$in$i$i = $12;
     }
    } else {
     $14 = ($10>>>0)<($1>>>0);
     if (!($14)) {
      label = 10;
      break;
     }
     $15 = ((($$024$i$i)) + 4|0);
     $16 = HEAP32[$15>>2]|0;
     $17 = ($16|0)==(0|0);
     if ($17) {
      label = 9;
      break;
     } else {
      $$0$ph$i$i = $15;$$in$i$i = $16;
     }
    }
    $$0$i$i = $$0$ph$i$i;$$024$i$i = $$in$i$i;$83 = $$in$i$i;
   }
   if ((label|0) == 6) {
    $$025$i47$i = $$024$i$i;$$03446$i = $$024$i$i;
    label = 13;
    break;
   }
   else if ((label|0) == 9) {
    $$025$i47$i = $15;$$03446$i = $$024$i$i;
    label = 13;
    break;
   }
   else if ((label|0) == 10) {
    $$025$i$i = $$0$i$i;$$034$i = $$024$i$i;$18 = $83;
    label = 12;
    break;
   }
  }
 } while(0);
 if ((label|0) == 12) {
  $19 = ($18|0)==(0|0);
  if ($19) {
   $$025$i47$i = $$025$i$i;$$03446$i = $$034$i;
   label = 13;
  } else {
   $$014$i = $18;
  }
 }
 if ((label|0) == 13) {
  $20 = (__Znwj(28)|0);
  $21 = ((($20)) + 16|0);
  HEAP32[$21>>2] = $1;
  $22 = ((($20)) + 20|0);
  HEAP32[$22>>2] = 0;
  $23 = ((($20)) + 24|0);
  HEAP32[$23>>2] = 0;
  HEAP32[$20>>2] = 0;
  $24 = ((($20)) + 4|0);
  HEAP32[$24>>2] = 0;
  $25 = ((($20)) + 8|0);
  HEAP32[$25>>2] = $$03446$i;
  HEAP32[$$025$i47$i>>2] = $20;
  $26 = HEAP32[$4>>2]|0;
  $27 = HEAP32[$26>>2]|0;
  $28 = ($27|0)==(0|0);
  if ($28) {
   $32 = $20;
  } else {
   $29 = $27;
   HEAP32[$4>>2] = $29;
   $$pre$i$i = HEAP32[$$025$i47$i>>2]|0;
   $32 = $$pre$i$i;
  }
  $30 = ((($0)) + 56|0);
  $31 = HEAP32[$30>>2]|0;
  __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($31,$32);
  $33 = ((($0)) + 60|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = (($34) + 1)|0;
  HEAP32[$33>>2] = $35;
  $$014$i = $20;
 }
 $36 = ((($$014$i)) + 20|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (($37) + 1)|0;
 HEAP32[$36>>2] = $38;
 $39 = ((($$014$i)) + 24|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = (($40) + ($2))|0;
 HEAP32[$39>>2] = $41;
 switch ($1|0) {
 case 9: case 2: case 0:  {
  $$0$i = $2;
  break;
 }
 case 1:  {
  $42 = (($2|0) / 2)&-1;
  $$0$i = $42;
  break;
 }
 case 3:  {
  $43 = (($2) + -1)|0;
  $$0$i = $43;
  break;
 }
 case 4:  {
  $44 = (($2|0) / 3)&-1;
  $$0$i = $44;
  break;
 }
 case 6: case 5:  {
  $45 = (($2) + -2)|0;
  $$0$i = $45;
  break;
 }
 case 7:  {
  $46 = (($2|0) / 4)&-1;
  $$0$i = $46;
  break;
 }
 case 8:  {
  $47 = (($2|0) / 2)&-1;
  $48 = (($47) + -1)|0;
  $$0$i = $48;
  break;
 }
 default: {
  $$0$i = 0;
 }
 }
 $49 = ((($0)) + 68|0);
 $50 = ((($0)) + 72|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = ($51|0)==(0|0);
 do {
  if ($52) {
   $$025$i$i12 = $50;$$034$i11 = $50;$63 = $51;
   label = 35;
  } else {
   $53 = ((($0)) + 72|0);
   $$0$i$i10 = $53;$$024$i$i9 = $51;$84 = $51;
   while(1) {
    $54 = ((($$024$i$i9)) + 16|0);
    $55 = HEAP32[$54>>2]|0;
    $56 = ($55>>>0)>($1>>>0);
    if ($56) {
     $57 = HEAP32[$$024$i$i9>>2]|0;
     $58 = ($57|0)==(0|0);
     if ($58) {
      label = 29;
      break;
     } else {
      $$0$ph$i$i7 = $$024$i$i9;$$in$i$i6 = $57;
     }
    } else {
     $59 = ($55>>>0)<($1>>>0);
     if (!($59)) {
      label = 33;
      break;
     }
     $60 = ((($$024$i$i9)) + 4|0);
     $61 = HEAP32[$60>>2]|0;
     $62 = ($61|0)==(0|0);
     if ($62) {
      label = 32;
      break;
     } else {
      $$0$ph$i$i7 = $60;$$in$i$i6 = $61;
     }
    }
    $$0$i$i10 = $$0$ph$i$i7;$$024$i$i9 = $$in$i$i6;$84 = $$in$i$i6;
   }
   if ((label|0) == 29) {
    $$025$i47$i13 = $$024$i$i9;$$03446$i14 = $$024$i$i9;
    break;
   }
   else if ((label|0) == 32) {
    $$025$i47$i13 = $60;$$03446$i14 = $$024$i$i9;
    break;
   }
   else if ((label|0) == 33) {
    $$025$i$i12 = $$0$i$i10;$$034$i11 = $$024$i$i9;$63 = $84;
    label = 35;
    break;
   }
  }
 } while(0);
 if ((label|0) == 35) {
  $64 = ($63|0)==(0|0);
  if ($64) {
   $$025$i47$i13 = $$025$i$i12;$$03446$i14 = $$034$i11;
  } else {
   $$014$i16 = $63;
   $80 = ((($$014$i16)) + 20|0);
   $81 = HEAP32[$80>>2]|0;
   $82 = (($81) + ($$0$i))|0;
   HEAP32[$80>>2] = $82;
   return;
  }
 }
 $65 = (__Znwj(24)|0);
 $66 = ((($65)) + 16|0);
 HEAP32[$66>>2] = $1;
 $67 = ((($65)) + 20|0);
 HEAP32[$67>>2] = 0;
 HEAP32[$65>>2] = 0;
 $68 = ((($65)) + 4|0);
 HEAP32[$68>>2] = 0;
 $69 = ((($65)) + 8|0);
 HEAP32[$69>>2] = $$03446$i14;
 HEAP32[$$025$i47$i13>>2] = $65;
 $70 = HEAP32[$49>>2]|0;
 $71 = HEAP32[$70>>2]|0;
 $72 = ($71|0)==(0|0);
 if ($72) {
  $76 = $65;
 } else {
  $73 = $71;
  HEAP32[$49>>2] = $73;
  $$pre$i$i15 = HEAP32[$$025$i47$i13>>2]|0;
  $76 = $$pre$i$i15;
 }
 $74 = ((($0)) + 72|0);
 $75 = HEAP32[$74>>2]|0;
 __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($75,$76);
 $77 = ((($0)) + 76|0);
 $78 = HEAP32[$77>>2]|0;
 $79 = (($78) + 1)|0;
 HEAP32[$77>>2] = $79;
 $$014$i16 = $65;
 $80 = ((($$014$i16)) + 20|0);
 $81 = HEAP32[$80>>2]|0;
 $82 = (($81) + ($$0$i))|0;
 HEAP32[$80>>2] = $82;
 return;
}
function __ZN7osgUtil10Statistics12drawElementsEjiPKt($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0$i = 0, $$0$i$i = 0, $$0$i$i10 = 0, $$0$ph$i$i = 0, $$0$ph$i$i7 = 0, $$014$i = 0, $$014$i16 = 0, $$024$i$i = 0, $$024$i$i9 = 0, $$025$i$i = 0, $$025$i$i12 = 0, $$025$i47$i = 0, $$025$i47$i13 = 0, $$034$i = 0, $$034$i11 = 0, $$03446$i = 0, $$03446$i14 = 0, $$in$i$i = 0, $$in$i$i6 = 0, $$pre$i$i = 0;
 var $$pre$i$i15 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ((($0)) + 52|0);
 $5 = ((($0)) + 56|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 do {
  if ($7) {
   $$025$i$i = $5;$$034$i = $5;$18 = $6;
   label = 12;
  } else {
   $8 = ((($0)) + 56|0);
   $$0$i$i = $8;$$024$i$i = $6;$83 = $6;
   while(1) {
    $9 = ((($$024$i$i)) + 16|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = ($10>>>0)>($1>>>0);
    if ($11) {
     $12 = HEAP32[$$024$i$i>>2]|0;
     $13 = ($12|0)==(0|0);
     if ($13) {
      label = 6;
      break;
     } else {
      $$0$ph$i$i = $$024$i$i;$$in$i$i = $12;
     }
    } else {
     $14 = ($10>>>0)<($1>>>0);
     if (!($14)) {
      label = 10;
      break;
     }
     $15 = ((($$024$i$i)) + 4|0);
     $16 = HEAP32[$15>>2]|0;
     $17 = ($16|0)==(0|0);
     if ($17) {
      label = 9;
      break;
     } else {
      $$0$ph$i$i = $15;$$in$i$i = $16;
     }
    }
    $$0$i$i = $$0$ph$i$i;$$024$i$i = $$in$i$i;$83 = $$in$i$i;
   }
   if ((label|0) == 6) {
    $$025$i47$i = $$024$i$i;$$03446$i = $$024$i$i;
    label = 13;
    break;
   }
   else if ((label|0) == 9) {
    $$025$i47$i = $15;$$03446$i = $$024$i$i;
    label = 13;
    break;
   }
   else if ((label|0) == 10) {
    $$025$i$i = $$0$i$i;$$034$i = $$024$i$i;$18 = $83;
    label = 12;
    break;
   }
  }
 } while(0);
 if ((label|0) == 12) {
  $19 = ($18|0)==(0|0);
  if ($19) {
   $$025$i47$i = $$025$i$i;$$03446$i = $$034$i;
   label = 13;
  } else {
   $$014$i = $18;
  }
 }
 if ((label|0) == 13) {
  $20 = (__Znwj(28)|0);
  $21 = ((($20)) + 16|0);
  HEAP32[$21>>2] = $1;
  $22 = ((($20)) + 20|0);
  HEAP32[$22>>2] = 0;
  $23 = ((($20)) + 24|0);
  HEAP32[$23>>2] = 0;
  HEAP32[$20>>2] = 0;
  $24 = ((($20)) + 4|0);
  HEAP32[$24>>2] = 0;
  $25 = ((($20)) + 8|0);
  HEAP32[$25>>2] = $$03446$i;
  HEAP32[$$025$i47$i>>2] = $20;
  $26 = HEAP32[$4>>2]|0;
  $27 = HEAP32[$26>>2]|0;
  $28 = ($27|0)==(0|0);
  if ($28) {
   $32 = $20;
  } else {
   $29 = $27;
   HEAP32[$4>>2] = $29;
   $$pre$i$i = HEAP32[$$025$i47$i>>2]|0;
   $32 = $$pre$i$i;
  }
  $30 = ((($0)) + 56|0);
  $31 = HEAP32[$30>>2]|0;
  __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($31,$32);
  $33 = ((($0)) + 60|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = (($34) + 1)|0;
  HEAP32[$33>>2] = $35;
  $$014$i = $20;
 }
 $36 = ((($$014$i)) + 20|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (($37) + 1)|0;
 HEAP32[$36>>2] = $38;
 $39 = ((($$014$i)) + 24|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = (($40) + ($2))|0;
 HEAP32[$39>>2] = $41;
 switch ($1|0) {
 case 9: case 2: case 0:  {
  $$0$i = $2;
  break;
 }
 case 1:  {
  $42 = (($2|0) / 2)&-1;
  $$0$i = $42;
  break;
 }
 case 3:  {
  $43 = (($2) + -1)|0;
  $$0$i = $43;
  break;
 }
 case 4:  {
  $44 = (($2|0) / 3)&-1;
  $$0$i = $44;
  break;
 }
 case 6: case 5:  {
  $45 = (($2) + -2)|0;
  $$0$i = $45;
  break;
 }
 case 7:  {
  $46 = (($2|0) / 4)&-1;
  $$0$i = $46;
  break;
 }
 case 8:  {
  $47 = (($2|0) / 2)&-1;
  $48 = (($47) + -1)|0;
  $$0$i = $48;
  break;
 }
 default: {
  $$0$i = 0;
 }
 }
 $49 = ((($0)) + 68|0);
 $50 = ((($0)) + 72|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = ($51|0)==(0|0);
 do {
  if ($52) {
   $$025$i$i12 = $50;$$034$i11 = $50;$63 = $51;
   label = 35;
  } else {
   $53 = ((($0)) + 72|0);
   $$0$i$i10 = $53;$$024$i$i9 = $51;$84 = $51;
   while(1) {
    $54 = ((($$024$i$i9)) + 16|0);
    $55 = HEAP32[$54>>2]|0;
    $56 = ($55>>>0)>($1>>>0);
    if ($56) {
     $57 = HEAP32[$$024$i$i9>>2]|0;
     $58 = ($57|0)==(0|0);
     if ($58) {
      label = 29;
      break;
     } else {
      $$0$ph$i$i7 = $$024$i$i9;$$in$i$i6 = $57;
     }
    } else {
     $59 = ($55>>>0)<($1>>>0);
     if (!($59)) {
      label = 33;
      break;
     }
     $60 = ((($$024$i$i9)) + 4|0);
     $61 = HEAP32[$60>>2]|0;
     $62 = ($61|0)==(0|0);
     if ($62) {
      label = 32;
      break;
     } else {
      $$0$ph$i$i7 = $60;$$in$i$i6 = $61;
     }
    }
    $$0$i$i10 = $$0$ph$i$i7;$$024$i$i9 = $$in$i$i6;$84 = $$in$i$i6;
   }
   if ((label|0) == 29) {
    $$025$i47$i13 = $$024$i$i9;$$03446$i14 = $$024$i$i9;
    break;
   }
   else if ((label|0) == 32) {
    $$025$i47$i13 = $60;$$03446$i14 = $$024$i$i9;
    break;
   }
   else if ((label|0) == 33) {
    $$025$i$i12 = $$0$i$i10;$$034$i11 = $$024$i$i9;$63 = $84;
    label = 35;
    break;
   }
  }
 } while(0);
 if ((label|0) == 35) {
  $64 = ($63|0)==(0|0);
  if ($64) {
   $$025$i47$i13 = $$025$i$i12;$$03446$i14 = $$034$i11;
  } else {
   $$014$i16 = $63;
   $80 = ((($$014$i16)) + 20|0);
   $81 = HEAP32[$80>>2]|0;
   $82 = (($81) + ($$0$i))|0;
   HEAP32[$80>>2] = $82;
   return;
  }
 }
 $65 = (__Znwj(24)|0);
 $66 = ((($65)) + 16|0);
 HEAP32[$66>>2] = $1;
 $67 = ((($65)) + 20|0);
 HEAP32[$67>>2] = 0;
 HEAP32[$65>>2] = 0;
 $68 = ((($65)) + 4|0);
 HEAP32[$68>>2] = 0;
 $69 = ((($65)) + 8|0);
 HEAP32[$69>>2] = $$03446$i14;
 HEAP32[$$025$i47$i13>>2] = $65;
 $70 = HEAP32[$49>>2]|0;
 $71 = HEAP32[$70>>2]|0;
 $72 = ($71|0)==(0|0);
 if ($72) {
  $76 = $65;
 } else {
  $73 = $71;
  HEAP32[$49>>2] = $73;
  $$pre$i$i15 = HEAP32[$$025$i47$i13>>2]|0;
  $76 = $$pre$i$i15;
 }
 $74 = ((($0)) + 72|0);
 $75 = HEAP32[$74>>2]|0;
 __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($75,$76);
 $77 = ((($0)) + 76|0);
 $78 = HEAP32[$77>>2]|0;
 $79 = (($78) + 1)|0;
 HEAP32[$77>>2] = $79;
 $$014$i16 = $65;
 $80 = ((($$014$i16)) + 20|0);
 $81 = HEAP32[$80>>2]|0;
 $82 = (($81) + ($$0$i))|0;
 HEAP32[$80>>2] = $82;
 return;
}
function __ZN7osgUtil10Statistics12drawElementsEjiPKj($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0$i = 0, $$0$i$i = 0, $$0$i$i10 = 0, $$0$ph$i$i = 0, $$0$ph$i$i7 = 0, $$014$i = 0, $$014$i16 = 0, $$024$i$i = 0, $$024$i$i9 = 0, $$025$i$i = 0, $$025$i$i12 = 0, $$025$i47$i = 0, $$025$i47$i13 = 0, $$034$i = 0, $$034$i11 = 0, $$03446$i = 0, $$03446$i14 = 0, $$in$i$i = 0, $$in$i$i6 = 0, $$pre$i$i = 0;
 var $$pre$i$i15 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ((($0)) + 52|0);
 $5 = ((($0)) + 56|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 do {
  if ($7) {
   $$025$i$i = $5;$$034$i = $5;$18 = $6;
   label = 12;
  } else {
   $8 = ((($0)) + 56|0);
   $$0$i$i = $8;$$024$i$i = $6;$83 = $6;
   while(1) {
    $9 = ((($$024$i$i)) + 16|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = ($10>>>0)>($1>>>0);
    if ($11) {
     $12 = HEAP32[$$024$i$i>>2]|0;
     $13 = ($12|0)==(0|0);
     if ($13) {
      label = 6;
      break;
     } else {
      $$0$ph$i$i = $$024$i$i;$$in$i$i = $12;
     }
    } else {
     $14 = ($10>>>0)<($1>>>0);
     if (!($14)) {
      label = 10;
      break;
     }
     $15 = ((($$024$i$i)) + 4|0);
     $16 = HEAP32[$15>>2]|0;
     $17 = ($16|0)==(0|0);
     if ($17) {
      label = 9;
      break;
     } else {
      $$0$ph$i$i = $15;$$in$i$i = $16;
     }
    }
    $$0$i$i = $$0$ph$i$i;$$024$i$i = $$in$i$i;$83 = $$in$i$i;
   }
   if ((label|0) == 6) {
    $$025$i47$i = $$024$i$i;$$03446$i = $$024$i$i;
    label = 13;
    break;
   }
   else if ((label|0) == 9) {
    $$025$i47$i = $15;$$03446$i = $$024$i$i;
    label = 13;
    break;
   }
   else if ((label|0) == 10) {
    $$025$i$i = $$0$i$i;$$034$i = $$024$i$i;$18 = $83;
    label = 12;
    break;
   }
  }
 } while(0);
 if ((label|0) == 12) {
  $19 = ($18|0)==(0|0);
  if ($19) {
   $$025$i47$i = $$025$i$i;$$03446$i = $$034$i;
   label = 13;
  } else {
   $$014$i = $18;
  }
 }
 if ((label|0) == 13) {
  $20 = (__Znwj(28)|0);
  $21 = ((($20)) + 16|0);
  HEAP32[$21>>2] = $1;
  $22 = ((($20)) + 20|0);
  HEAP32[$22>>2] = 0;
  $23 = ((($20)) + 24|0);
  HEAP32[$23>>2] = 0;
  HEAP32[$20>>2] = 0;
  $24 = ((($20)) + 4|0);
  HEAP32[$24>>2] = 0;
  $25 = ((($20)) + 8|0);
  HEAP32[$25>>2] = $$03446$i;
  HEAP32[$$025$i47$i>>2] = $20;
  $26 = HEAP32[$4>>2]|0;
  $27 = HEAP32[$26>>2]|0;
  $28 = ($27|0)==(0|0);
  if ($28) {
   $32 = $20;
  } else {
   $29 = $27;
   HEAP32[$4>>2] = $29;
   $$pre$i$i = HEAP32[$$025$i47$i>>2]|0;
   $32 = $$pre$i$i;
  }
  $30 = ((($0)) + 56|0);
  $31 = HEAP32[$30>>2]|0;
  __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($31,$32);
  $33 = ((($0)) + 60|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = (($34) + 1)|0;
  HEAP32[$33>>2] = $35;
  $$014$i = $20;
 }
 $36 = ((($$014$i)) + 20|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (($37) + 1)|0;
 HEAP32[$36>>2] = $38;
 $39 = ((($$014$i)) + 24|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = (($40) + ($2))|0;
 HEAP32[$39>>2] = $41;
 switch ($1|0) {
 case 9: case 2: case 0:  {
  $$0$i = $2;
  break;
 }
 case 1:  {
  $42 = (($2|0) / 2)&-1;
  $$0$i = $42;
  break;
 }
 case 3:  {
  $43 = (($2) + -1)|0;
  $$0$i = $43;
  break;
 }
 case 4:  {
  $44 = (($2|0) / 3)&-1;
  $$0$i = $44;
  break;
 }
 case 6: case 5:  {
  $45 = (($2) + -2)|0;
  $$0$i = $45;
  break;
 }
 case 7:  {
  $46 = (($2|0) / 4)&-1;
  $$0$i = $46;
  break;
 }
 case 8:  {
  $47 = (($2|0) / 2)&-1;
  $48 = (($47) + -1)|0;
  $$0$i = $48;
  break;
 }
 default: {
  $$0$i = 0;
 }
 }
 $49 = ((($0)) + 68|0);
 $50 = ((($0)) + 72|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = ($51|0)==(0|0);
 do {
  if ($52) {
   $$025$i$i12 = $50;$$034$i11 = $50;$63 = $51;
   label = 35;
  } else {
   $53 = ((($0)) + 72|0);
   $$0$i$i10 = $53;$$024$i$i9 = $51;$84 = $51;
   while(1) {
    $54 = ((($$024$i$i9)) + 16|0);
    $55 = HEAP32[$54>>2]|0;
    $56 = ($55>>>0)>($1>>>0);
    if ($56) {
     $57 = HEAP32[$$024$i$i9>>2]|0;
     $58 = ($57|0)==(0|0);
     if ($58) {
      label = 29;
      break;
     } else {
      $$0$ph$i$i7 = $$024$i$i9;$$in$i$i6 = $57;
     }
    } else {
     $59 = ($55>>>0)<($1>>>0);
     if (!($59)) {
      label = 33;
      break;
     }
     $60 = ((($$024$i$i9)) + 4|0);
     $61 = HEAP32[$60>>2]|0;
     $62 = ($61|0)==(0|0);
     if ($62) {
      label = 32;
      break;
     } else {
      $$0$ph$i$i7 = $60;$$in$i$i6 = $61;
     }
    }
    $$0$i$i10 = $$0$ph$i$i7;$$024$i$i9 = $$in$i$i6;$84 = $$in$i$i6;
   }
   if ((label|0) == 29) {
    $$025$i47$i13 = $$024$i$i9;$$03446$i14 = $$024$i$i9;
    break;
   }
   else if ((label|0) == 32) {
    $$025$i47$i13 = $60;$$03446$i14 = $$024$i$i9;
    break;
   }
   else if ((label|0) == 33) {
    $$025$i$i12 = $$0$i$i10;$$034$i11 = $$024$i$i9;$63 = $84;
    label = 35;
    break;
   }
  }
 } while(0);
 if ((label|0) == 35) {
  $64 = ($63|0)==(0|0);
  if ($64) {
   $$025$i47$i13 = $$025$i$i12;$$03446$i14 = $$034$i11;
  } else {
   $$014$i16 = $63;
   $80 = ((($$014$i16)) + 20|0);
   $81 = HEAP32[$80>>2]|0;
   $82 = (($81) + ($$0$i))|0;
   HEAP32[$80>>2] = $82;
   return;
  }
 }
 $65 = (__Znwj(24)|0);
 $66 = ((($65)) + 16|0);
 HEAP32[$66>>2] = $1;
 $67 = ((($65)) + 20|0);
 HEAP32[$67>>2] = 0;
 HEAP32[$65>>2] = 0;
 $68 = ((($65)) + 4|0);
 HEAP32[$68>>2] = 0;
 $69 = ((($65)) + 8|0);
 HEAP32[$69>>2] = $$03446$i14;
 HEAP32[$$025$i47$i13>>2] = $65;
 $70 = HEAP32[$49>>2]|0;
 $71 = HEAP32[$70>>2]|0;
 $72 = ($71|0)==(0|0);
 if ($72) {
  $76 = $65;
 } else {
  $73 = $71;
  HEAP32[$49>>2] = $73;
  $$pre$i$i15 = HEAP32[$$025$i47$i13>>2]|0;
  $76 = $$pre$i$i15;
 }
 $74 = ((($0)) + 72|0);
 $75 = HEAP32[$74>>2]|0;
 __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($75,$76);
 $77 = ((($0)) + 76|0);
 $78 = HEAP32[$77>>2]|0;
 $79 = (($78) + 1)|0;
 HEAP32[$77>>2] = $79;
 $$014$i16 = $65;
 $80 = ((($$014$i16)) + 20|0);
 $81 = HEAP32[$80>>2]|0;
 $82 = (($81) + ($$0$i))|0;
 HEAP32[$80>>2] = $82;
 return;
}
function __ZN7osgUtil10Statistics5beginEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i = 0, $$0$ph$i$i = 0, $$014$i = 0, $$024$i$i = 0, $$025$i$i = 0, $$025$i47$i = 0, $$034$i = 0, $$03446$i = 0, $$in$i$i = 0, $$pre$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 64|0);
 HEAP32[$2>>2] = $1;
 $3 = ((($0)) + 52|0);
 $4 = ((($0)) + 56|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 do {
  if ($6) {
   $$025$i$i = $4;$$034$i = $4;$17 = $5;
   label = 12;
  } else {
   $7 = ((($0)) + 56|0);
   $$0$i$i = $7;$$024$i$i = $5;$39 = $5;
   while(1) {
    $8 = ((($$024$i$i)) + 16|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = ($9>>>0)>($1>>>0);
    if ($10) {
     $11 = HEAP32[$$024$i$i>>2]|0;
     $12 = ($11|0)==(0|0);
     if ($12) {
      label = 6;
      break;
     } else {
      $$0$ph$i$i = $$024$i$i;$$in$i$i = $11;
     }
    } else {
     $13 = ($9>>>0)<($1>>>0);
     if (!($13)) {
      label = 10;
      break;
     }
     $14 = ((($$024$i$i)) + 4|0);
     $15 = HEAP32[$14>>2]|0;
     $16 = ($15|0)==(0|0);
     if ($16) {
      label = 9;
      break;
     } else {
      $$0$ph$i$i = $14;$$in$i$i = $15;
     }
    }
    $$0$i$i = $$0$ph$i$i;$$024$i$i = $$in$i$i;$39 = $$in$i$i;
   }
   if ((label|0) == 6) {
    $$025$i47$i = $$024$i$i;$$03446$i = $$024$i$i;
    break;
   }
   else if ((label|0) == 9) {
    $$025$i47$i = $14;$$03446$i = $$024$i$i;
    break;
   }
   else if ((label|0) == 10) {
    $$025$i$i = $$0$i$i;$$034$i = $$024$i$i;$17 = $39;
    label = 12;
    break;
   }
  }
 } while(0);
 if ((label|0) == 12) {
  $18 = ($17|0)==(0|0);
  if ($18) {
   $$025$i47$i = $$025$i$i;$$03446$i = $$034$i;
  } else {
   $$014$i = $17;
   $35 = ((($$014$i)) + 20|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 1)|0;
   HEAP32[$35>>2] = $37;
   $38 = ((($0)) + 84|0);
   HEAP32[$38>>2] = 0;
   return;
  }
 }
 $19 = (__Znwj(28)|0);
 $20 = ((($19)) + 16|0);
 HEAP32[$20>>2] = $1;
 $21 = ((($19)) + 20|0);
 HEAP32[$21>>2] = 0;
 $22 = ((($19)) + 24|0);
 HEAP32[$22>>2] = 0;
 HEAP32[$19>>2] = 0;
 $23 = ((($19)) + 4|0);
 HEAP32[$23>>2] = 0;
 $24 = ((($19)) + 8|0);
 HEAP32[$24>>2] = $$03446$i;
 HEAP32[$$025$i47$i>>2] = $19;
 $25 = HEAP32[$3>>2]|0;
 $26 = HEAP32[$25>>2]|0;
 $27 = ($26|0)==(0|0);
 if ($27) {
  $31 = $19;
 } else {
  $28 = $26;
  HEAP32[$3>>2] = $28;
  $$pre$i$i = HEAP32[$$025$i47$i>>2]|0;
  $31 = $$pre$i$i;
 }
 $29 = ((($0)) + 56|0);
 $30 = HEAP32[$29>>2]|0;
 __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($30,$31);
 $32 = ((($0)) + 60|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = (($33) + 1)|0;
 HEAP32[$32>>2] = $34;
 $$014$i = $19;
 $35 = ((($$014$i)) + 20|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = (($36) + 1)|0;
 HEAP32[$35>>2] = $37;
 $38 = ((($0)) + 84|0);
 HEAP32[$38>>2] = 0;
 return;
}
function __ZN7osgUtil10Statistics6vertexEfff($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = +$1;
 $2 = +$2;
 $3 = +$3;
 var $$0$i$i$i = 0, $$0$ph$i$i$i = 0, $$014$i$i = 0, $$024$i$i$i = 0, $$025$i$i$i = 0, $$025$i47$i$i = 0, $$034$i$i = 0, $$03446$i$i = 0, $$in$i$i$i = 0, $$pre$i = 0, $$pre$i$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ((($0)) + 52|0);
 $5 = ((($0)) + 64|0);
 $6 = ((($0)) + 56|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 do {
  if ($8) {
   $$025$i$i$i = $6;$$034$i$i = $6;$20 = $7;
   label = 12;
  } else {
   $9 = ((($0)) + 56|0);
   $10 = HEAP32[$5>>2]|0;
   $$0$i$i$i = $9;$$024$i$i$i = $7;$45 = $7;
   while(1) {
    $11 = ((($$024$i$i$i)) + 16|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ($10>>>0)<($12>>>0);
    if ($13) {
     $14 = HEAP32[$$024$i$i$i>>2]|0;
     $15 = ($14|0)==(0|0);
     if ($15) {
      label = 6;
      break;
     } else {
      $$0$ph$i$i$i = $$024$i$i$i;$$in$i$i$i = $14;
     }
    } else {
     $16 = ($12>>>0)<($10>>>0);
     if (!($16)) {
      label = 10;
      break;
     }
     $17 = ((($$024$i$i$i)) + 4|0);
     $18 = HEAP32[$17>>2]|0;
     $19 = ($18|0)==(0|0);
     if ($19) {
      label = 9;
      break;
     } else {
      $$0$ph$i$i$i = $17;$$in$i$i$i = $18;
     }
    }
    $$0$i$i$i = $$0$ph$i$i$i;$$024$i$i$i = $$in$i$i$i;$45 = $$in$i$i$i;
   }
   if ((label|0) == 6) {
    $$025$i47$i$i = $$024$i$i$i;$$03446$i$i = $$024$i$i$i;$24 = $10;
    break;
   }
   else if ((label|0) == 9) {
    $$025$i47$i$i = $17;$$03446$i$i = $$024$i$i$i;$24 = $10;
    break;
   }
   else if ((label|0) == 10) {
    $$025$i$i$i = $$0$i$i$i;$$034$i$i = $$024$i$i$i;$20 = $45;
    label = 12;
    break;
   }
  }
 } while(0);
 do {
  if ((label|0) == 12) {
   $21 = ($20|0)==(0|0);
   if ($21) {
    $$pre$i = HEAP32[$5>>2]|0;
    $$025$i47$i$i = $$025$i$i$i;$$03446$i$i = $$034$i$i;$24 = $$pre$i;
    break;
   } else {
    $$014$i$i = $20;
    $39 = ((($$014$i$i)) + 24|0);
    $40 = HEAP32[$39>>2]|0;
    $41 = (($40) + 1)|0;
    HEAP32[$39>>2] = $41;
    $42 = ((($0)) + 84|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = (($43) + 1)|0;
    HEAP32[$42>>2] = $44;
    return;
   }
  }
 } while(0);
 $22 = (__Znwj(28)|0);
 $23 = ((($22)) + 16|0);
 HEAP32[$23>>2] = $24;
 $25 = ((($22)) + 20|0);
 HEAP32[$25>>2] = 0;
 $26 = ((($22)) + 24|0);
 HEAP32[$26>>2] = 0;
 HEAP32[$22>>2] = 0;
 $27 = ((($22)) + 4|0);
 HEAP32[$27>>2] = 0;
 $28 = ((($22)) + 8|0);
 HEAP32[$28>>2] = $$03446$i$i;
 HEAP32[$$025$i47$i$i>>2] = $22;
 $29 = HEAP32[$4>>2]|0;
 $30 = HEAP32[$29>>2]|0;
 $31 = ($30|0)==(0|0);
 if ($31) {
  $35 = $22;
 } else {
  $32 = $30;
  HEAP32[$4>>2] = $32;
  $$pre$i$i$i = HEAP32[$$025$i47$i$i>>2]|0;
  $35 = $$pre$i$i$i;
 }
 $33 = ((($0)) + 56|0);
 $34 = HEAP32[$33>>2]|0;
 __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($34,$35);
 $36 = ((($0)) + 60|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (($37) + 1)|0;
 HEAP32[$36>>2] = $38;
 $$014$i$i = $22;
 $39 = ((($$014$i$i)) + 24|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = (($40) + 1)|0;
 HEAP32[$39>>2] = $41;
 $42 = ((($0)) + 84|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = (($43) + 1)|0;
 HEAP32[$42>>2] = $44;
 return;
}
function __ZN7osgUtil10Statistics6vertexERKN3osg5Vec3fE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i$i = 0, $$0$ph$i$i$i = 0, $$014$i$i = 0, $$024$i$i$i = 0, $$025$i$i$i = 0, $$025$i47$i$i = 0, $$034$i$i = 0, $$03446$i$i = 0, $$in$i$i$i = 0, $$pre$i = 0, $$pre$i$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 52|0);
 $3 = ((($0)) + 64|0);
 $4 = ((($0)) + 56|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 do {
  if ($6) {
   $$025$i$i$i = $4;$$034$i$i = $4;$18 = $5;
   label = 12;
  } else {
   $7 = ((($0)) + 56|0);
   $8 = HEAP32[$3>>2]|0;
   $$0$i$i$i = $7;$$024$i$i$i = $5;$43 = $5;
   while(1) {
    $9 = ((($$024$i$i$i)) + 16|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = ($8>>>0)<($10>>>0);
    if ($11) {
     $12 = HEAP32[$$024$i$i$i>>2]|0;
     $13 = ($12|0)==(0|0);
     if ($13) {
      label = 6;
      break;
     } else {
      $$0$ph$i$i$i = $$024$i$i$i;$$in$i$i$i = $12;
     }
    } else {
     $14 = ($10>>>0)<($8>>>0);
     if (!($14)) {
      label = 10;
      break;
     }
     $15 = ((($$024$i$i$i)) + 4|0);
     $16 = HEAP32[$15>>2]|0;
     $17 = ($16|0)==(0|0);
     if ($17) {
      label = 9;
      break;
     } else {
      $$0$ph$i$i$i = $15;$$in$i$i$i = $16;
     }
    }
    $$0$i$i$i = $$0$ph$i$i$i;$$024$i$i$i = $$in$i$i$i;$43 = $$in$i$i$i;
   }
   if ((label|0) == 6) {
    $$025$i47$i$i = $$024$i$i$i;$$03446$i$i = $$024$i$i$i;$22 = $8;
    break;
   }
   else if ((label|0) == 9) {
    $$025$i47$i$i = $15;$$03446$i$i = $$024$i$i$i;$22 = $8;
    break;
   }
   else if ((label|0) == 10) {
    $$025$i$i$i = $$0$i$i$i;$$034$i$i = $$024$i$i$i;$18 = $43;
    label = 12;
    break;
   }
  }
 } while(0);
 do {
  if ((label|0) == 12) {
   $19 = ($18|0)==(0|0);
   if ($19) {
    $$pre$i = HEAP32[$3>>2]|0;
    $$025$i47$i$i = $$025$i$i$i;$$03446$i$i = $$034$i$i;$22 = $$pre$i;
    break;
   } else {
    $$014$i$i = $18;
    $37 = ((($$014$i$i)) + 24|0);
    $38 = HEAP32[$37>>2]|0;
    $39 = (($38) + 1)|0;
    HEAP32[$37>>2] = $39;
    $40 = ((($0)) + 84|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = (($41) + 1)|0;
    HEAP32[$40>>2] = $42;
    return;
   }
  }
 } while(0);
 $20 = (__Znwj(28)|0);
 $21 = ((($20)) + 16|0);
 HEAP32[$21>>2] = $22;
 $23 = ((($20)) + 20|0);
 HEAP32[$23>>2] = 0;
 $24 = ((($20)) + 24|0);
 HEAP32[$24>>2] = 0;
 HEAP32[$20>>2] = 0;
 $25 = ((($20)) + 4|0);
 HEAP32[$25>>2] = 0;
 $26 = ((($20)) + 8|0);
 HEAP32[$26>>2] = $$03446$i$i;
 HEAP32[$$025$i47$i$i>>2] = $20;
 $27 = HEAP32[$2>>2]|0;
 $28 = HEAP32[$27>>2]|0;
 $29 = ($28|0)==(0|0);
 if ($29) {
  $33 = $20;
 } else {
  $30 = $28;
  HEAP32[$2>>2] = $30;
  $$pre$i$i$i = HEAP32[$$025$i47$i$i>>2]|0;
  $33 = $$pre$i$i$i;
 }
 $31 = ((($0)) + 56|0);
 $32 = HEAP32[$31>>2]|0;
 __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($32,$33);
 $34 = ((($0)) + 60|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (($35) + 1)|0;
 HEAP32[$34>>2] = $36;
 $$014$i$i = $20;
 $37 = ((($$014$i$i)) + 24|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (($38) + 1)|0;
 HEAP32[$37>>2] = $39;
 $40 = ((($0)) + 84|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = (($41) + 1)|0;
 HEAP32[$40>>2] = $42;
 return;
}
function __ZN7osgUtil10Statistics6vertexERKN3osg5Vec2fE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i$i = 0, $$0$ph$i$i$i = 0, $$014$i$i = 0, $$024$i$i$i = 0, $$025$i$i$i = 0, $$025$i47$i$i = 0, $$034$i$i = 0, $$03446$i$i = 0, $$in$i$i$i = 0, $$pre$i = 0, $$pre$i$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 52|0);
 $3 = ((($0)) + 64|0);
 $4 = ((($0)) + 56|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 do {
  if ($6) {
   $$025$i$i$i = $4;$$034$i$i = $4;$18 = $5;
   label = 12;
  } else {
   $7 = ((($0)) + 56|0);
   $8 = HEAP32[$3>>2]|0;
   $$0$i$i$i = $7;$$024$i$i$i = $5;$43 = $5;
   while(1) {
    $9 = ((($$024$i$i$i)) + 16|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = ($8>>>0)<($10>>>0);
    if ($11) {
     $12 = HEAP32[$$024$i$i$i>>2]|0;
     $13 = ($12|0)==(0|0);
     if ($13) {
      label = 6;
      break;
     } else {
      $$0$ph$i$i$i = $$024$i$i$i;$$in$i$i$i = $12;
     }
    } else {
     $14 = ($10>>>0)<($8>>>0);
     if (!($14)) {
      label = 10;
      break;
     }
     $15 = ((($$024$i$i$i)) + 4|0);
     $16 = HEAP32[$15>>2]|0;
     $17 = ($16|0)==(0|0);
     if ($17) {
      label = 9;
      break;
     } else {
      $$0$ph$i$i$i = $15;$$in$i$i$i = $16;
     }
    }
    $$0$i$i$i = $$0$ph$i$i$i;$$024$i$i$i = $$in$i$i$i;$43 = $$in$i$i$i;
   }
   if ((label|0) == 6) {
    $$025$i47$i$i = $$024$i$i$i;$$03446$i$i = $$024$i$i$i;$22 = $8;
    break;
   }
   else if ((label|0) == 9) {
    $$025$i47$i$i = $15;$$03446$i$i = $$024$i$i$i;$22 = $8;
    break;
   }
   else if ((label|0) == 10) {
    $$025$i$i$i = $$0$i$i$i;$$034$i$i = $$024$i$i$i;$18 = $43;
    label = 12;
    break;
   }
  }
 } while(0);
 do {
  if ((label|0) == 12) {
   $19 = ($18|0)==(0|0);
   if ($19) {
    $$pre$i = HEAP32[$3>>2]|0;
    $$025$i47$i$i = $$025$i$i$i;$$03446$i$i = $$034$i$i;$22 = $$pre$i;
    break;
   } else {
    $$014$i$i = $18;
    $37 = ((($$014$i$i)) + 24|0);
    $38 = HEAP32[$37>>2]|0;
    $39 = (($38) + 1)|0;
    HEAP32[$37>>2] = $39;
    $40 = ((($0)) + 84|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = (($41) + 1)|0;
    HEAP32[$40>>2] = $42;
    return;
   }
  }
 } while(0);
 $20 = (__Znwj(28)|0);
 $21 = ((($20)) + 16|0);
 HEAP32[$21>>2] = $22;
 $23 = ((($20)) + 20|0);
 HEAP32[$23>>2] = 0;
 $24 = ((($20)) + 24|0);
 HEAP32[$24>>2] = 0;
 HEAP32[$20>>2] = 0;
 $25 = ((($20)) + 4|0);
 HEAP32[$25>>2] = 0;
 $26 = ((($20)) + 8|0);
 HEAP32[$26>>2] = $$03446$i$i;
 HEAP32[$$025$i47$i$i>>2] = $20;
 $27 = HEAP32[$2>>2]|0;
 $28 = HEAP32[$27>>2]|0;
 $29 = ($28|0)==(0|0);
 if ($29) {
  $33 = $20;
 } else {
  $30 = $28;
  HEAP32[$2>>2] = $30;
  $$pre$i$i$i = HEAP32[$$025$i47$i$i>>2]|0;
  $33 = $$pre$i$i$i;
 }
 $31 = ((($0)) + 56|0);
 $32 = HEAP32[$31>>2]|0;
 __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($32,$33);
 $34 = ((($0)) + 60|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (($35) + 1)|0;
 HEAP32[$34>>2] = $36;
 $$014$i$i = $20;
 $37 = ((($$014$i$i)) + 24|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (($38) + 1)|0;
 HEAP32[$37>>2] = $39;
 $40 = ((($0)) + 84|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = (($41) + 1)|0;
 HEAP32[$40>>2] = $42;
 return;
}
function __ZN7osgUtil10Statistics6vertexERKN3osg5Vec4fE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i$i = 0, $$0$ph$i$i$i = 0, $$014$i$i = 0, $$024$i$i$i = 0, $$025$i$i$i = 0, $$025$i47$i$i = 0, $$034$i$i = 0, $$03446$i$i = 0, $$in$i$i$i = 0, $$pre$i = 0, $$pre$i$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 52|0);
 $3 = ((($0)) + 64|0);
 $4 = ((($0)) + 56|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 do {
  if ($6) {
   $$025$i$i$i = $4;$$034$i$i = $4;$18 = $5;
   label = 12;
  } else {
   $7 = ((($0)) + 56|0);
   $8 = HEAP32[$3>>2]|0;
   $$0$i$i$i = $7;$$024$i$i$i = $5;$43 = $5;
   while(1) {
    $9 = ((($$024$i$i$i)) + 16|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = ($8>>>0)<($10>>>0);
    if ($11) {
     $12 = HEAP32[$$024$i$i$i>>2]|0;
     $13 = ($12|0)==(0|0);
     if ($13) {
      label = 6;
      break;
     } else {
      $$0$ph$i$i$i = $$024$i$i$i;$$in$i$i$i = $12;
     }
    } else {
     $14 = ($10>>>0)<($8>>>0);
     if (!($14)) {
      label = 10;
      break;
     }
     $15 = ((($$024$i$i$i)) + 4|0);
     $16 = HEAP32[$15>>2]|0;
     $17 = ($16|0)==(0|0);
     if ($17) {
      label = 9;
      break;
     } else {
      $$0$ph$i$i$i = $15;$$in$i$i$i = $16;
     }
    }
    $$0$i$i$i = $$0$ph$i$i$i;$$024$i$i$i = $$in$i$i$i;$43 = $$in$i$i$i;
   }
   if ((label|0) == 6) {
    $$025$i47$i$i = $$024$i$i$i;$$03446$i$i = $$024$i$i$i;$22 = $8;
    break;
   }
   else if ((label|0) == 9) {
    $$025$i47$i$i = $15;$$03446$i$i = $$024$i$i$i;$22 = $8;
    break;
   }
   else if ((label|0) == 10) {
    $$025$i$i$i = $$0$i$i$i;$$034$i$i = $$024$i$i$i;$18 = $43;
    label = 12;
    break;
   }
  }
 } while(0);
 do {
  if ((label|0) == 12) {
   $19 = ($18|0)==(0|0);
   if ($19) {
    $$pre$i = HEAP32[$3>>2]|0;
    $$025$i47$i$i = $$025$i$i$i;$$03446$i$i = $$034$i$i;$22 = $$pre$i;
    break;
   } else {
    $$014$i$i = $18;
    $37 = ((($$014$i$i)) + 24|0);
    $38 = HEAP32[$37>>2]|0;
    $39 = (($38) + 1)|0;
    HEAP32[$37>>2] = $39;
    $40 = ((($0)) + 84|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = (($41) + 1)|0;
    HEAP32[$40>>2] = $42;
    return;
   }
  }
 } while(0);
 $20 = (__Znwj(28)|0);
 $21 = ((($20)) + 16|0);
 HEAP32[$21>>2] = $22;
 $23 = ((($20)) + 20|0);
 HEAP32[$23>>2] = 0;
 $24 = ((($20)) + 24|0);
 HEAP32[$24>>2] = 0;
 HEAP32[$20>>2] = 0;
 $25 = ((($20)) + 4|0);
 HEAP32[$25>>2] = 0;
 $26 = ((($20)) + 8|0);
 HEAP32[$26>>2] = $$03446$i$i;
 HEAP32[$$025$i47$i$i>>2] = $20;
 $27 = HEAP32[$2>>2]|0;
 $28 = HEAP32[$27>>2]|0;
 $29 = ($28|0)==(0|0);
 if ($29) {
  $33 = $20;
 } else {
  $30 = $28;
  HEAP32[$2>>2] = $30;
  $$pre$i$i$i = HEAP32[$$025$i47$i$i>>2]|0;
  $33 = $$pre$i$i$i;
 }
 $31 = ((($0)) + 56|0);
 $32 = HEAP32[$31>>2]|0;
 __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($32,$33);
 $34 = ((($0)) + 60|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (($35) + 1)|0;
 HEAP32[$34>>2] = $36;
 $$014$i$i = $20;
 $37 = ((($$014$i$i)) + 24|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (($38) + 1)|0;
 HEAP32[$37>>2] = $39;
 $40 = ((($0)) + 84|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = (($41) + 1)|0;
 HEAP32[$40>>2] = $42;
 return;
}
function __ZN7osgUtil10Statistics6vertexEff($0,$1,$2) {
 $0 = $0|0;
 $1 = +$1;
 $2 = +$2;
 var $$0$i$i$i = 0, $$0$ph$i$i$i = 0, $$014$i$i = 0, $$024$i$i$i = 0, $$025$i$i$i = 0, $$025$i47$i$i = 0, $$034$i$i = 0, $$03446$i$i = 0, $$in$i$i$i = 0, $$pre$i = 0, $$pre$i$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 52|0);
 $4 = ((($0)) + 64|0);
 $5 = ((($0)) + 56|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 do {
  if ($7) {
   $$025$i$i$i = $5;$$034$i$i = $5;$19 = $6;
   label = 12;
  } else {
   $8 = ((($0)) + 56|0);
   $9 = HEAP32[$4>>2]|0;
   $$0$i$i$i = $8;$$024$i$i$i = $6;$44 = $6;
   while(1) {
    $10 = ((($$024$i$i$i)) + 16|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($9>>>0)<($11>>>0);
    if ($12) {
     $13 = HEAP32[$$024$i$i$i>>2]|0;
     $14 = ($13|0)==(0|0);
     if ($14) {
      label = 6;
      break;
     } else {
      $$0$ph$i$i$i = $$024$i$i$i;$$in$i$i$i = $13;
     }
    } else {
     $15 = ($11>>>0)<($9>>>0);
     if (!($15)) {
      label = 10;
      break;
     }
     $16 = ((($$024$i$i$i)) + 4|0);
     $17 = HEAP32[$16>>2]|0;
     $18 = ($17|0)==(0|0);
     if ($18) {
      label = 9;
      break;
     } else {
      $$0$ph$i$i$i = $16;$$in$i$i$i = $17;
     }
    }
    $$0$i$i$i = $$0$ph$i$i$i;$$024$i$i$i = $$in$i$i$i;$44 = $$in$i$i$i;
   }
   if ((label|0) == 6) {
    $$025$i47$i$i = $$024$i$i$i;$$03446$i$i = $$024$i$i$i;$23 = $9;
    break;
   }
   else if ((label|0) == 9) {
    $$025$i47$i$i = $16;$$03446$i$i = $$024$i$i$i;$23 = $9;
    break;
   }
   else if ((label|0) == 10) {
    $$025$i$i$i = $$0$i$i$i;$$034$i$i = $$024$i$i$i;$19 = $44;
    label = 12;
    break;
   }
  }
 } while(0);
 do {
  if ((label|0) == 12) {
   $20 = ($19|0)==(0|0);
   if ($20) {
    $$pre$i = HEAP32[$4>>2]|0;
    $$025$i47$i$i = $$025$i$i$i;$$03446$i$i = $$034$i$i;$23 = $$pre$i;
    break;
   } else {
    $$014$i$i = $19;
    $38 = ((($$014$i$i)) + 24|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = (($39) + 1)|0;
    HEAP32[$38>>2] = $40;
    $41 = ((($0)) + 84|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = (($42) + 1)|0;
    HEAP32[$41>>2] = $43;
    return;
   }
  }
 } while(0);
 $21 = (__Znwj(28)|0);
 $22 = ((($21)) + 16|0);
 HEAP32[$22>>2] = $23;
 $24 = ((($21)) + 20|0);
 HEAP32[$24>>2] = 0;
 $25 = ((($21)) + 24|0);
 HEAP32[$25>>2] = 0;
 HEAP32[$21>>2] = 0;
 $26 = ((($21)) + 4|0);
 HEAP32[$26>>2] = 0;
 $27 = ((($21)) + 8|0);
 HEAP32[$27>>2] = $$03446$i$i;
 HEAP32[$$025$i47$i$i>>2] = $21;
 $28 = HEAP32[$3>>2]|0;
 $29 = HEAP32[$28>>2]|0;
 $30 = ($29|0)==(0|0);
 if ($30) {
  $34 = $21;
 } else {
  $31 = $29;
  HEAP32[$3>>2] = $31;
  $$pre$i$i$i = HEAP32[$$025$i47$i$i>>2]|0;
  $34 = $$pre$i$i$i;
 }
 $32 = ((($0)) + 56|0);
 $33 = HEAP32[$32>>2]|0;
 __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($33,$34);
 $35 = ((($0)) + 60|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = (($36) + 1)|0;
 HEAP32[$35>>2] = $37;
 $$014$i$i = $21;
 $38 = ((($$014$i$i)) + 24|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($39) + 1)|0;
 HEAP32[$38>>2] = $40;
 $41 = ((($0)) + 84|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = (($42) + 1)|0;
 HEAP32[$41>>2] = $43;
 return;
}
function __ZN7osgUtil10Statistics6vertexEffff($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = +$1;
 $2 = +$2;
 $3 = +$3;
 $4 = +$4;
 var $$0$i$i$i = 0, $$0$ph$i$i$i = 0, $$014$i$i = 0, $$024$i$i$i = 0, $$025$i$i$i = 0, $$025$i47$i$i = 0, $$034$i$i = 0, $$03446$i$i = 0, $$in$i$i$i = 0, $$pre$i = 0, $$pre$i$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = ((($0)) + 52|0);
 $6 = ((($0)) + 64|0);
 $7 = ((($0)) + 56|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 do {
  if ($9) {
   $$025$i$i$i = $7;$$034$i$i = $7;$21 = $8;
   label = 12;
  } else {
   $10 = ((($0)) + 56|0);
   $11 = HEAP32[$6>>2]|0;
   $$0$i$i$i = $10;$$024$i$i$i = $8;$46 = $8;
   while(1) {
    $12 = ((($$024$i$i$i)) + 16|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = ($11>>>0)<($13>>>0);
    if ($14) {
     $15 = HEAP32[$$024$i$i$i>>2]|0;
     $16 = ($15|0)==(0|0);
     if ($16) {
      label = 6;
      break;
     } else {
      $$0$ph$i$i$i = $$024$i$i$i;$$in$i$i$i = $15;
     }
    } else {
     $17 = ($13>>>0)<($11>>>0);
     if (!($17)) {
      label = 10;
      break;
     }
     $18 = ((($$024$i$i$i)) + 4|0);
     $19 = HEAP32[$18>>2]|0;
     $20 = ($19|0)==(0|0);
     if ($20) {
      label = 9;
      break;
     } else {
      $$0$ph$i$i$i = $18;$$in$i$i$i = $19;
     }
    }
    $$0$i$i$i = $$0$ph$i$i$i;$$024$i$i$i = $$in$i$i$i;$46 = $$in$i$i$i;
   }
   if ((label|0) == 6) {
    $$025$i47$i$i = $$024$i$i$i;$$03446$i$i = $$024$i$i$i;$25 = $11;
    break;
   }
   else if ((label|0) == 9) {
    $$025$i47$i$i = $18;$$03446$i$i = $$024$i$i$i;$25 = $11;
    break;
   }
   else if ((label|0) == 10) {
    $$025$i$i$i = $$0$i$i$i;$$034$i$i = $$024$i$i$i;$21 = $46;
    label = 12;
    break;
   }
  }
 } while(0);
 do {
  if ((label|0) == 12) {
   $22 = ($21|0)==(0|0);
   if ($22) {
    $$pre$i = HEAP32[$6>>2]|0;
    $$025$i47$i$i = $$025$i$i$i;$$03446$i$i = $$034$i$i;$25 = $$pre$i;
    break;
   } else {
    $$014$i$i = $21;
    $40 = ((($$014$i$i)) + 24|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = (($41) + 1)|0;
    HEAP32[$40>>2] = $42;
    $43 = ((($0)) + 84|0);
    $44 = HEAP32[$43>>2]|0;
    $45 = (($44) + 1)|0;
    HEAP32[$43>>2] = $45;
    return;
   }
  }
 } while(0);
 $23 = (__Znwj(28)|0);
 $24 = ((($23)) + 16|0);
 HEAP32[$24>>2] = $25;
 $26 = ((($23)) + 20|0);
 HEAP32[$26>>2] = 0;
 $27 = ((($23)) + 24|0);
 HEAP32[$27>>2] = 0;
 HEAP32[$23>>2] = 0;
 $28 = ((($23)) + 4|0);
 HEAP32[$28>>2] = 0;
 $29 = ((($23)) + 8|0);
 HEAP32[$29>>2] = $$03446$i$i;
 HEAP32[$$025$i47$i$i>>2] = $23;
 $30 = HEAP32[$5>>2]|0;
 $31 = HEAP32[$30>>2]|0;
 $32 = ($31|0)==(0|0);
 if ($32) {
  $36 = $23;
 } else {
  $33 = $31;
  HEAP32[$5>>2] = $33;
  $$pre$i$i$i = HEAP32[$$025$i47$i$i>>2]|0;
  $36 = $$pre$i$i$i;
 }
 $34 = ((($0)) + 56|0);
 $35 = HEAP32[$34>>2]|0;
 __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($35,$36);
 $37 = ((($0)) + 60|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (($38) + 1)|0;
 HEAP32[$37>>2] = $39;
 $$014$i$i = $23;
 $40 = ((($$014$i$i)) + 24|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = (($41) + 1)|0;
 HEAP32[$40>>2] = $42;
 $43 = ((($0)) + 84|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = (($44) + 1)|0;
 HEAP32[$43>>2] = $45;
 return;
}
function __ZN7osgUtil10Statistics3endEv($0) {
 $0 = $0|0;
 var $$0$i = 0, $$0$i$i = 0, $$0$ph$i$i = 0, $$014$i = 0, $$024$i$i = 0, $$025$i$i = 0, $$025$i47$i = 0, $$034$i = 0, $$03446$i = 0, $$in$i$i = 0, $$pre$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 64|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 84|0);
 $4 = HEAP32[$3>>2]|0;
 switch ($2|0) {
 case 9: case 2: case 0:  {
  $$0$i = $4;
  break;
 }
 case 1:  {
  $5 = (($4|0) / 2)&-1;
  $$0$i = $5;
  break;
 }
 case 3:  {
  $6 = (($4) + -1)|0;
  $$0$i = $6;
  break;
 }
 case 4:  {
  $7 = (($4|0) / 3)&-1;
  $$0$i = $7;
  break;
 }
 case 6: case 5:  {
  $8 = (($4) + -2)|0;
  $$0$i = $8;
  break;
 }
 case 7:  {
  $9 = (($4|0) / 4)&-1;
  $$0$i = $9;
  break;
 }
 case 8:  {
  $10 = (($4|0) / 2)&-1;
  $11 = (($10) + -1)|0;
  $$0$i = $11;
  break;
 }
 default: {
  $$0$i = 0;
 }
 }
 $12 = ((($0)) + 68|0);
 $13 = ((($0)) + 72|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(0|0);
 do {
  if ($15) {
   $$025$i$i = $13;$$034$i = $13;$26 = $14;
   label = 20;
  } else {
   $16 = ((($0)) + 72|0);
   $$0$i$i = $16;$$024$i$i = $14;$50 = $14;
   while(1) {
    $17 = ((($$024$i$i)) + 16|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = ($2>>>0)<($18>>>0);
    if ($19) {
     $20 = HEAP32[$$024$i$i>>2]|0;
     $21 = ($20|0)==(0|0);
     if ($21) {
      label = 14;
      break;
     } else {
      $$0$ph$i$i = $$024$i$i;$$in$i$i = $20;
     }
    } else {
     $22 = ($18>>>0)<($2>>>0);
     if (!($22)) {
      label = 18;
      break;
     }
     $23 = ((($$024$i$i)) + 4|0);
     $24 = HEAP32[$23>>2]|0;
     $25 = ($24|0)==(0|0);
     if ($25) {
      label = 17;
      break;
     } else {
      $$0$ph$i$i = $23;$$in$i$i = $24;
     }
    }
    $$0$i$i = $$0$ph$i$i;$$024$i$i = $$in$i$i;$50 = $$in$i$i;
   }
   if ((label|0) == 14) {
    $$025$i47$i = $$024$i$i;$$03446$i = $$024$i$i;
    break;
   }
   else if ((label|0) == 17) {
    $$025$i47$i = $23;$$03446$i = $$024$i$i;
    break;
   }
   else if ((label|0) == 18) {
    $$025$i$i = $$0$i$i;$$034$i = $$024$i$i;$26 = $50;
    label = 20;
    break;
   }
  }
 } while(0);
 if ((label|0) == 20) {
  $27 = ($26|0)==(0|0);
  if ($27) {
   $$025$i47$i = $$025$i$i;$$03446$i = $$034$i;
  } else {
   $$014$i = $26;
   $43 = ((($$014$i)) + 20|0);
   $44 = HEAP32[$43>>2]|0;
   $45 = (($44) + ($$0$i))|0;
   HEAP32[$43>>2] = $45;
   $46 = HEAP32[$3>>2]|0;
   $47 = ((($0)) + 48|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = (($48) + ($46))|0;
   HEAP32[$47>>2] = $49;
   return;
  }
 }
 $28 = (__Znwj(24)|0);
 $29 = ((($28)) + 16|0);
 HEAP32[$29>>2] = $2;
 $30 = ((($28)) + 20|0);
 HEAP32[$30>>2] = 0;
 HEAP32[$28>>2] = 0;
 $31 = ((($28)) + 4|0);
 HEAP32[$31>>2] = 0;
 $32 = ((($28)) + 8|0);
 HEAP32[$32>>2] = $$03446$i;
 HEAP32[$$025$i47$i>>2] = $28;
 $33 = HEAP32[$12>>2]|0;
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)==(0|0);
 if ($35) {
  $39 = $28;
 } else {
  $36 = $34;
  HEAP32[$12>>2] = $36;
  $$pre$i$i = HEAP32[$$025$i47$i>>2]|0;
  $39 = $$pre$i$i;
 }
 $37 = ((($0)) + 72|0);
 $38 = HEAP32[$37>>2]|0;
 __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($38,$39);
 $40 = ((($0)) + 76|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = (($41) + 1)|0;
 HEAP32[$40>>2] = $42;
 $$014$i = $28;
 $43 = ((($$014$i)) + 20|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = (($44) + ($$0$i))|0;
 HEAP32[$43>>2] = $45;
 $46 = HEAP32[$3>>2]|0;
 $47 = ((($0)) + 48|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (($48) + ($46))|0;
 HEAP32[$47>>2] = $49;
 return;
}
function __ZN7osgUtil12StatsVisitorD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vii(3453,($0|0),(50840|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  $3 = ((($0)) + 376|0);
  __ZN3osg6ObjectD2Ev($3);
  return;
 }
 $4 = ___cxa_find_matching_catch_2()|0;
 $5 = tempRet0;
 $6 = ((($0)) + 376|0);
 __THREW__ = 0;
 invoke_vi(388,($6|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch_3(0|0)|0;
  $10 = tempRet0;
  ___clang_call_terminate($9);
  // unreachable;
 } else {
  ___resumeException($4|0);
  // unreachable;
 }
}
function __ZN7osgUtil12StatsVisitorD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vii(3453,($0|0),(50840|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $6 = ___cxa_find_matching_catch_2()|0;
  $7 = tempRet0;
  $8 = ((($0)) + 376|0);
  __THREW__ = 0;
  invoke_vi(388,($8|0));
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if ($10) {
   $11 = ___cxa_find_matching_catch_3(0|0)|0;
   $12 = tempRet0;
   ___clang_call_terminate($11);
   // unreachable;
  } else {
   $eh$lpad$body$index2Z2D = $7;$eh$lpad$body$indexZ2D = $6;
   __ZdlPv($0);
   ___resumeException($eh$lpad$body$indexZ2D|0);
   // unreachable;
  }
 }
 $3 = ((($0)) + 376|0);
 __THREW__ = 0;
 invoke_vi(388,($3|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  __ZdlPv($0);
  return;
 }
 $13 = ___cxa_find_matching_catch_2()|0;
 $14 = tempRet0;
 $eh$lpad$body$index2Z2D = $14;$eh$lpad$body$indexZ2D = $13;
 __ZdlPv($0);
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
}
function __ZNK7osgUtil12StatsVisitor11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (116801|0);
}
function __ZNK7osgUtil12StatsVisitor9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (114884|0);
}
function __ZN7osgUtil12StatsVisitor5resetEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0;
 var $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 56|0);
 $2 = ((($0)) + 92|0);
 $3 = ((($0)) + 96|0);
 dest=$1; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $4 = HEAP32[$3>>2]|0;
 __ZNSt3__26__treeIPN3osg4NodeENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($2,$4);
 $5 = ((($0)) + 100|0);
 HEAP32[$5>>2] = 0;
 HEAP32[$2>>2] = $3;
 HEAP32[$3>>2] = 0;
 $6 = ((($0)) + 104|0);
 $7 = ((($0)) + 108|0);
 $8 = HEAP32[$7>>2]|0;
 __ZNSt3__26__treeIPN3osg4NodeENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($6,$8);
 $9 = ((($0)) + 112|0);
 HEAP32[$9>>2] = 0;
 HEAP32[$6>>2] = $7;
 HEAP32[$7>>2] = 0;
 $10 = ((($0)) + 116|0);
 $11 = ((($0)) + 120|0);
 $12 = HEAP32[$11>>2]|0;
 __ZNSt3__26__treeIPN3osg4NodeENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($10,$12);
 $13 = ((($0)) + 124|0);
 HEAP32[$13>>2] = 0;
 HEAP32[$10>>2] = $11;
 HEAP32[$11>>2] = 0;
 $14 = ((($0)) + 128|0);
 $15 = ((($0)) + 132|0);
 $16 = HEAP32[$15>>2]|0;
 __ZNSt3__26__treeIPN3osg4NodeENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($14,$16);
 $17 = ((($0)) + 136|0);
 HEAP32[$17>>2] = 0;
 HEAP32[$14>>2] = $15;
 HEAP32[$15>>2] = 0;
 $18 = ((($0)) + 140|0);
 $19 = ((($0)) + 144|0);
 $20 = HEAP32[$19>>2]|0;
 __ZNSt3__26__treeIPN3osg4NodeENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($18,$20);
 $21 = ((($0)) + 148|0);
 HEAP32[$21>>2] = 0;
 HEAP32[$18>>2] = $19;
 HEAP32[$19>>2] = 0;
 $22 = ((($0)) + 152|0);
 $23 = ((($0)) + 156|0);
 $24 = HEAP32[$23>>2]|0;
 __ZNSt3__26__treeIPN3osg8DrawableENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($22,$24);
 $25 = ((($0)) + 160|0);
 HEAP32[$25>>2] = 0;
 HEAP32[$22>>2] = $23;
 HEAP32[$23>>2] = 0;
 $26 = ((($0)) + 164|0);
 $27 = ((($0)) + 168|0);
 $28 = HEAP32[$27>>2]|0;
 __ZNSt3__26__treeIPN3osg8DrawableENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($26,$28);
 $29 = ((($0)) + 172|0);
 HEAP32[$29>>2] = 0;
 HEAP32[$26>>2] = $27;
 HEAP32[$27>>2] = 0;
 $30 = ((($0)) + 176|0);
 $31 = ((($0)) + 180|0);
 $32 = HEAP32[$31>>2]|0;
 __ZNSt3__26__treeIPN3osg8DrawableENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($30,$32);
 $33 = ((($0)) + 184|0);
 HEAP32[$33>>2] = 0;
 HEAP32[$30>>2] = $31;
 HEAP32[$31>>2] = 0;
 $34 = ((($0)) + 188|0);
 $35 = ((($0)) + 192|0);
 $36 = HEAP32[$35>>2]|0;
 __ZNSt3__26__treeIPN3osg8StateSetENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($34,$36);
 $37 = ((($0)) + 196|0);
 HEAP32[$37>>2] = 0;
 HEAP32[$34>>2] = $35;
 HEAP32[$35>>2] = 0;
 $38 = ((($0)) + 204|0);
 $39 = ((($0)) + 252|0);
 $40 = ((($0)) + 256|0);
 dest=$38; stop=dest+48|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $41 = HEAP32[$40>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIjNS_4pairIjjEEEENS_19__map_value_compareIjS4_NS_4lessIjEELb1EEENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($39,$41);
 $42 = ((($0)) + 260|0);
 HEAP32[$42>>2] = 0;
 HEAP32[$39>>2] = $40;
 HEAP32[$40>>2] = 0;
 $43 = ((($0)) + 264|0);
 HEAP32[$43>>2] = 0;
 $44 = ((($0)) + 268|0);
 $45 = ((($0)) + 272|0);
 $46 = HEAP32[$45>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIjjEENS_19__map_value_compareIjS2_NS_4lessIjEELb1EEENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($44,$46);
 $47 = ((($0)) + 276|0);
 HEAP32[$47>>2] = 0;
 HEAP32[$44>>2] = $45;
 HEAP32[$45>>2] = 0;
 $48 = ((($0)) + 280|0);
 HEAP32[$48>>2] = 0;
 $49 = ((($0)) + 284|0);
 HEAP32[$49>>2] = 0;
 $50 = ((($0)) + 292|0);
 $51 = ((($0)) + 340|0);
 $52 = ((($0)) + 344|0);
 dest=$50; stop=dest+48|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $53 = HEAP32[$52>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIjNS_4pairIjjEEEENS_19__map_value_compareIjS4_NS_4lessIjEELb1EEENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($51,$53);
 $54 = ((($0)) + 348|0);
 HEAP32[$54>>2] = 0;
 HEAP32[$51>>2] = $52;
 HEAP32[$52>>2] = 0;
 $55 = ((($0)) + 352|0);
 HEAP32[$55>>2] = 0;
 $56 = ((($0)) + 356|0);
 $57 = ((($0)) + 360|0);
 $58 = HEAP32[$57>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIjjEENS_19__map_value_compareIjS2_NS_4lessIjEELb1EEENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($56,$58);
 $59 = ((($0)) + 364|0);
 HEAP32[$59>>2] = 0;
 HEAP32[$56>>2] = $57;
 HEAP32[$57>>2] = 0;
 $60 = ((($0)) + 368|0);
 HEAP32[$60>>2] = 0;
 $61 = ((($0)) + 372|0);
 HEAP32[$61>>2] = 0;
 return;
}
function __ZN7osgUtil12StatsVisitor5applyERN3osg8DrawableE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i$i$i = 0, $$0$i$i$i$i15 = 0, $$0$i$i$i$i30 = 0, $$0$ph$i$i$i$i = 0, $$0$ph$i$i$i$i12 = 0, $$0$ph$i$i$i$i27 = 0, $$024$i$i$i$i = 0, $$024$i$i$i$i14 = 0, $$024$i$i$i$i29 = 0, $$025$i$i$i$i = 0, $$025$i$i$i$i17 = 0, $$025$i$i$i$i32 = 0, $$036$i$i$i = 0, $$036$i$i$i16 = 0, $$036$i$i$i31 = 0, $$in$i$i$i$i = 0, $$in$i$i$i$i11 = 0, $$in$i$i$i$i26 = 0, $$pre$i$i$i$i = 0, $$pre$i$i$i$i20 = 0;
 var $$pre$i$i$i$i35 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0;
 var $117 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 120|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = HEAP32[$0>>2]|0;
  $6 = ((($5)) + 200|0);
  $7 = HEAP32[$6>>2]|0;
  FUNCTION_TABLE_vii[$7 & 8191]($0,$3);
 }
 $8 = ((($0)) + 76|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 1)|0;
 HEAP32[$8>>2] = $10;
 $11 = HEAP32[$1>>2]|0;
 $12 = ((($11)) + 264|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($0)) + 288|0);
 FUNCTION_TABLE_vii[$13 & 8191]($1,$14);
 $15 = ((($0)) + 152|0);
 $16 = $1;
 $17 = ((($0)) + 156|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ($18|0)==(0|0);
 do {
  if ($19) {
   $$025$i$i$i$i17 = $17;$$036$i$i$i16 = $17;
  } else {
   $20 = ((($0)) + 156|0);
   $$0$i$i$i$i15 = $20;$$024$i$i$i$i14 = $18;
   while(1) {
    $21 = ((($$024$i$i$i$i14)) + 16|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = ($22>>>0)>($1>>>0);
    if ($23) {
     $24 = HEAP32[$$024$i$i$i$i14>>2]|0;
     $25 = ($24|0)==(0|0);
     if ($25) {
      label = 8;
      break;
     } else {
      $$0$ph$i$i$i$i12 = $$024$i$i$i$i14;$$in$i$i$i$i11 = $24;
     }
    } else {
     $26 = ($22>>>0)<($1>>>0);
     if (!($26)) {
      label = 12;
      break;
     }
     $27 = ((($$024$i$i$i$i14)) + 4|0);
     $28 = HEAP32[$27>>2]|0;
     $29 = ($28|0)==(0|0);
     if ($29) {
      label = 11;
      break;
     } else {
      $$0$ph$i$i$i$i12 = $27;$$in$i$i$i$i11 = $28;
     }
    }
    $$0$i$i$i$i15 = $$0$ph$i$i$i$i12;$$024$i$i$i$i14 = $$in$i$i$i$i11;
   }
   if ((label|0) == 8) {
    $$025$i$i$i$i17 = $$024$i$i$i$i14;$$036$i$i$i16 = $$024$i$i$i$i14;
    break;
   }
   else if ((label|0) == 11) {
    $$025$i$i$i$i17 = $27;$$036$i$i$i16 = $$024$i$i$i$i14;
    break;
   }
   else if ((label|0) == 12) {
    $$025$i$i$i$i17 = $$0$i$i$i$i15;$$036$i$i$i16 = $$024$i$i$i$i14;
    break;
   }
  }
 } while(0);
 $30 = HEAP32[$$025$i$i$i$i17>>2]|0;
 $31 = ($30|0)==(0|0);
 if ($31) {
  $32 = (__Znwj(20)|0);
  $33 = ((($32)) + 16|0);
  HEAP32[$33>>2] = $16;
  HEAP32[$32>>2] = 0;
  $34 = ((($32)) + 4|0);
  HEAP32[$34>>2] = 0;
  $35 = ((($32)) + 8|0);
  HEAP32[$35>>2] = $$036$i$i$i16;
  HEAP32[$$025$i$i$i$i17>>2] = $32;
  $36 = HEAP32[$15>>2]|0;
  $37 = HEAP32[$36>>2]|0;
  $38 = ($37|0)==(0|0);
  if ($38) {
   $42 = $32;
  } else {
   $39 = $37;
   HEAP32[$15>>2] = $39;
   $$pre$i$i$i$i20 = HEAP32[$$025$i$i$i$i17>>2]|0;
   $42 = $$pre$i$i$i$i20;
  }
  $40 = ((($0)) + 156|0);
  $41 = HEAP32[$40>>2]|0;
  __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($41,$42);
  $43 = ((($0)) + 160|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = (($44) + 1)|0;
  HEAP32[$43>>2] = $45;
 }
 $46 = HEAP32[$1>>2]|0;
 $47 = ((($46)) + 140|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (FUNCTION_TABLE_ii[$48 & 8191]($1)|0);
 $50 = ($49|0)==(0|0);
 if ($50) {
  return;
 }
 $51 = ((($0)) + 80|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = (($52) + 1)|0;
 HEAP32[$51>>2] = $53;
 $54 = ((($0)) + 164|0);
 $55 = $49;
 $56 = ((($0)) + 168|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = ($57|0)==(0|0);
 do {
  if ($58) {
   $$025$i$i$i$i32 = $56;$$036$i$i$i31 = $56;
  } else {
   $59 = ((($0)) + 168|0);
   $$0$i$i$i$i30 = $59;$$024$i$i$i$i29 = $57;
   while(1) {
    $60 = ((($$024$i$i$i$i29)) + 16|0);
    $61 = HEAP32[$60>>2]|0;
    $62 = ($49>>>0)<($61>>>0);
    if ($62) {
     $63 = HEAP32[$$024$i$i$i$i29>>2]|0;
     $64 = ($63|0)==(0|0);
     if ($64) {
      label = 24;
      break;
     } else {
      $$0$ph$i$i$i$i27 = $$024$i$i$i$i29;$$in$i$i$i$i26 = $63;
     }
    } else {
     $65 = ($61>>>0)<($49>>>0);
     if (!($65)) {
      label = 28;
      break;
     }
     $66 = ((($$024$i$i$i$i29)) + 4|0);
     $67 = HEAP32[$66>>2]|0;
     $68 = ($67|0)==(0|0);
     if ($68) {
      label = 27;
      break;
     } else {
      $$0$ph$i$i$i$i27 = $66;$$in$i$i$i$i26 = $67;
     }
    }
    $$0$i$i$i$i30 = $$0$ph$i$i$i$i27;$$024$i$i$i$i29 = $$in$i$i$i$i26;
   }
   if ((label|0) == 24) {
    $$025$i$i$i$i32 = $$024$i$i$i$i29;$$036$i$i$i31 = $$024$i$i$i$i29;
    break;
   }
   else if ((label|0) == 27) {
    $$025$i$i$i$i32 = $66;$$036$i$i$i31 = $$024$i$i$i$i29;
    break;
   }
   else if ((label|0) == 28) {
    $$025$i$i$i$i32 = $$0$i$i$i$i30;$$036$i$i$i31 = $$024$i$i$i$i29;
    break;
   }
  }
 } while(0);
 $69 = HEAP32[$$025$i$i$i$i32>>2]|0;
 $70 = ($69|0)==(0|0);
 if ($70) {
  $71 = (__Znwj(20)|0);
  $72 = ((($71)) + 16|0);
  HEAP32[$72>>2] = $55;
  HEAP32[$71>>2] = 0;
  $73 = ((($71)) + 4|0);
  HEAP32[$73>>2] = 0;
  $74 = ((($71)) + 8|0);
  HEAP32[$74>>2] = $$036$i$i$i31;
  HEAP32[$$025$i$i$i$i32>>2] = $71;
  $75 = HEAP32[$54>>2]|0;
  $76 = HEAP32[$75>>2]|0;
  $77 = ($76|0)==(0|0);
  if ($77) {
   $81 = $71;
  } else {
   $78 = $76;
   HEAP32[$54>>2] = $78;
   $$pre$i$i$i$i35 = HEAP32[$$025$i$i$i$i32>>2]|0;
   $81 = $$pre$i$i$i$i35;
  }
  $79 = ((($0)) + 168|0);
  $80 = HEAP32[$79>>2]|0;
  __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($80,$81);
  $82 = ((($0)) + 172|0);
  $83 = HEAP32[$82>>2]|0;
  $84 = (($83) + 1)|0;
  HEAP32[$82>>2] = $84;
 }
 $85 = ((($0)) + 84|0);
 $86 = HEAP32[$85>>2]|0;
 $87 = (($86) + 1)|0;
 HEAP32[$85>>2] = $87;
 $88 = ((($0)) + 176|0);
 $89 = ((($0)) + 180|0);
 $90 = HEAP32[$89>>2]|0;
 $91 = ($90|0)==(0|0);
 do {
  if ($91) {
   $$025$i$i$i$i = $89;$$036$i$i$i = $89;
  } else {
   $92 = ((($0)) + 180|0);
   $$0$i$i$i$i = $92;$$024$i$i$i$i = $90;
   while(1) {
    $93 = ((($$024$i$i$i$i)) + 16|0);
    $94 = HEAP32[$93>>2]|0;
    $95 = ($49>>>0)<($94>>>0);
    if ($95) {
     $96 = HEAP32[$$024$i$i$i$i>>2]|0;
     $97 = ($96|0)==(0|0);
     if ($97) {
      label = 39;
      break;
     } else {
      $$0$ph$i$i$i$i = $$024$i$i$i$i;$$in$i$i$i$i = $96;
     }
    } else {
     $98 = ($94>>>0)<($49>>>0);
     if (!($98)) {
      label = 43;
      break;
     }
     $99 = ((($$024$i$i$i$i)) + 4|0);
     $100 = HEAP32[$99>>2]|0;
     $101 = ($100|0)==(0|0);
     if ($101) {
      label = 42;
      break;
     } else {
      $$0$ph$i$i$i$i = $99;$$in$i$i$i$i = $100;
     }
    }
    $$0$i$i$i$i = $$0$ph$i$i$i$i;$$024$i$i$i$i = $$in$i$i$i$i;
   }
   if ((label|0) == 39) {
    $$025$i$i$i$i = $$024$i$i$i$i;$$036$i$i$i = $$024$i$i$i$i;
    break;
   }
   else if ((label|0) == 42) {
    $$025$i$i$i$i = $99;$$036$i$i$i = $$024$i$i$i$i;
    break;
   }
   else if ((label|0) == 43) {
    $$025$i$i$i$i = $$0$i$i$i$i;$$036$i$i$i = $$024$i$i$i$i;
    break;
   }
  }
 } while(0);
 $102 = HEAP32[$$025$i$i$i$i>>2]|0;
 $103 = ($102|0)==(0|0);
 if (!($103)) {
  return;
 }
 $104 = (__Znwj(20)|0);
 $105 = ((($104)) + 16|0);
 HEAP32[$105>>2] = $55;
 HEAP32[$104>>2] = 0;
 $106 = ((($104)) + 4|0);
 HEAP32[$106>>2] = 0;
 $107 = ((($104)) + 8|0);
 HEAP32[$107>>2] = $$036$i$i$i;
 HEAP32[$$025$i$i$i$i>>2] = $104;
 $108 = HEAP32[$88>>2]|0;
 $109 = HEAP32[$108>>2]|0;
 $110 = ($109|0)==(0|0);
 if ($110) {
  $114 = $104;
 } else {
  $111 = $109;
  HEAP32[$88>>2] = $111;
  $$pre$i$i$i$i = HEAP32[$$025$i$i$i$i>>2]|0;
  $114 = $$pre$i$i$i$i;
 }
 $112 = ((($0)) + 180|0);
 $113 = HEAP32[$112>>2]|0;
 __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($113,$114);
 $115 = ((($0)) + 184|0);
 $116 = HEAP32[$115>>2]|0;
 $117 = (($116) + 1)|0;
 HEAP32[$115>>2] = $117;
 return;
}
function __ZN7osgUtil12StatsVisitor5applyERN3osg4NodeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 120|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = HEAP32[$0>>2]|0;
  $6 = ((($5)) + 200|0);
  $7 = HEAP32[$6>>2]|0;
  FUNCTION_TABLE_vii[$7 & 8191]($0,$3);
 }
 $8 = ((($0)) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 switch ($9|0) {
 case 1:  {
  $10 = HEAP32[$1>>2]|0;
  $11 = ((($10)) + 192|0);
  $12 = HEAP32[$11>>2]|0;
  FUNCTION_TABLE_vii[$12 & 8191]($1,$0);
  return;
  break;
 }
 case 0:  {
  return;
  break;
 }
 default: {
  $13 = HEAP32[$1>>2]|0;
  $14 = ((($13)) + 196|0);
  $15 = HEAP32[$14>>2]|0;
  FUNCTION_TABLE_vii[$15 & 8191]($1,$0);
  return;
 }
 }
}
function __ZN7osgUtil12StatsVisitor5applyERN3osg5GeodeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i$i$i = 0, $$0$ph$i$i$i$i = 0, $$024$i$i$i$i = 0, $$025$i$i$i$i = 0, $$036$i$i$i = 0, $$in$i$i$i$i = 0, $$pre$i$i$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 120|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = HEAP32[$0>>2]|0;
  $6 = ((($5)) + 200|0);
  $7 = HEAP32[$6>>2]|0;
  FUNCTION_TABLE_vii[$7 & 8191]($0,$3);
 }
 $8 = ((($0)) + 72|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 1)|0;
 HEAP32[$8>>2] = $10;
 $11 = ((($0)) + 140|0);
 $12 = $1;
 $13 = ((($0)) + 144|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(0|0);
 do {
  if ($15) {
   $$025$i$i$i$i = $13;$$036$i$i$i = $13;
  } else {
   $16 = ((($0)) + 144|0);
   $$0$i$i$i$i = $16;$$024$i$i$i$i = $14;
   while(1) {
    $17 = ((($$024$i$i$i$i)) + 16|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = ($1>>>0)<($18>>>0);
    if ($19) {
     $20 = HEAP32[$$024$i$i$i$i>>2]|0;
     $21 = ($20|0)==(0|0);
     if ($21) {
      label = 8;
      break;
     } else {
      $$0$ph$i$i$i$i = $$024$i$i$i$i;$$in$i$i$i$i = $20;
     }
    } else {
     $22 = ($18>>>0)<($1>>>0);
     if (!($22)) {
      label = 12;
      break;
     }
     $23 = ((($$024$i$i$i$i)) + 4|0);
     $24 = HEAP32[$23>>2]|0;
     $25 = ($24|0)==(0|0);
     if ($25) {
      label = 11;
      break;
     } else {
      $$0$ph$i$i$i$i = $23;$$in$i$i$i$i = $24;
     }
    }
    $$0$i$i$i$i = $$0$ph$i$i$i$i;$$024$i$i$i$i = $$in$i$i$i$i;
   }
   if ((label|0) == 8) {
    $$025$i$i$i$i = $$024$i$i$i$i;$$036$i$i$i = $$024$i$i$i$i;
    break;
   }
   else if ((label|0) == 11) {
    $$025$i$i$i$i = $23;$$036$i$i$i = $$024$i$i$i$i;
    break;
   }
   else if ((label|0) == 12) {
    $$025$i$i$i$i = $$0$i$i$i$i;$$036$i$i$i = $$024$i$i$i$i;
    break;
   }
  }
 } while(0);
 $26 = HEAP32[$$025$i$i$i$i>>2]|0;
 $27 = ($26|0)==(0|0);
 if ($27) {
  $28 = (__Znwj(20)|0);
  $29 = ((($28)) + 16|0);
  HEAP32[$29>>2] = $12;
  HEAP32[$28>>2] = 0;
  $30 = ((($28)) + 4|0);
  HEAP32[$30>>2] = 0;
  $31 = ((($28)) + 8|0);
  HEAP32[$31>>2] = $$036$i$i$i;
  HEAP32[$$025$i$i$i$i>>2] = $28;
  $32 = HEAP32[$11>>2]|0;
  $33 = HEAP32[$32>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $38 = $28;
  } else {
   $35 = $33;
   HEAP32[$11>>2] = $35;
   $$pre$i$i$i$i = HEAP32[$$025$i$i$i$i>>2]|0;
   $38 = $$pre$i$i$i$i;
  }
  $36 = ((($0)) + 144|0);
  $37 = HEAP32[$36>>2]|0;
  __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($37,$38);
  $39 = ((($0)) + 148|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = (($40) + 1)|0;
  HEAP32[$39>>2] = $41;
 }
 $42 = ((($0)) + 16|0);
 $43 = HEAP32[$42>>2]|0;
 switch ($43|0) {
 case 1:  {
  $44 = HEAP32[$1>>2]|0;
  $45 = ((($44)) + 192|0);
  $46 = HEAP32[$45>>2]|0;
  FUNCTION_TABLE_vii[$46 & 8191]($1,$0);
  return;
  break;
 }
 case 0:  {
  return;
  break;
 }
 default: {
  $47 = HEAP32[$1>>2]|0;
  $48 = ((($47)) + 196|0);
  $49 = HEAP32[$48>>2]|0;
  FUNCTION_TABLE_vii[$49 & 8191]($1,$0);
  return;
 }
 }
}
function __ZN7osgUtil12StatsVisitor5applyERN3osg5GroupE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i$i$i = 0, $$0$ph$i$i$i$i = 0, $$024$i$i$i$i = 0, $$025$i$i$i$i = 0, $$036$i$i$i = 0, $$in$i$i$i$i = 0, $$pre$i$i$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 120|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = HEAP32[$0>>2]|0;
  $6 = ((($5)) + 200|0);
  $7 = HEAP32[$6>>2]|0;
  FUNCTION_TABLE_vii[$7 & 8191]($0,$3);
 }
 $8 = ((($0)) + 56|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 1)|0;
 HEAP32[$8>>2] = $10;
 $11 = ((($0)) + 92|0);
 $12 = $1;
 $13 = ((($0)) + 96|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(0|0);
 do {
  if ($15) {
   $$025$i$i$i$i = $13;$$036$i$i$i = $13;
  } else {
   $16 = ((($0)) + 96|0);
   $$0$i$i$i$i = $16;$$024$i$i$i$i = $14;
   while(1) {
    $17 = ((($$024$i$i$i$i)) + 16|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = ($1>>>0)<($18>>>0);
    if ($19) {
     $20 = HEAP32[$$024$i$i$i$i>>2]|0;
     $21 = ($20|0)==(0|0);
     if ($21) {
      label = 8;
      break;
     } else {
      $$0$ph$i$i$i$i = $$024$i$i$i$i;$$in$i$i$i$i = $20;
     }
    } else {
     $22 = ($18>>>0)<($1>>>0);
     if (!($22)) {
      label = 12;
      break;
     }
     $23 = ((($$024$i$i$i$i)) + 4|0);
     $24 = HEAP32[$23>>2]|0;
     $25 = ($24|0)==(0|0);
     if ($25) {
      label = 11;
      break;
     } else {
      $$0$ph$i$i$i$i = $23;$$in$i$i$i$i = $24;
     }
    }
    $$0$i$i$i$i = $$0$ph$i$i$i$i;$$024$i$i$i$i = $$in$i$i$i$i;
   }
   if ((label|0) == 8) {
    $$025$i$i$i$i = $$024$i$i$i$i;$$036$i$i$i = $$024$i$i$i$i;
    break;
   }
   else if ((label|0) == 11) {
    $$025$i$i$i$i = $23;$$036$i$i$i = $$024$i$i$i$i;
    break;
   }
   else if ((label|0) == 12) {
    $$025$i$i$i$i = $$0$i$i$i$i;$$036$i$i$i = $$024$i$i$i$i;
    break;
   }
  }
 } while(0);
 $26 = HEAP32[$$025$i$i$i$i>>2]|0;
 $27 = ($26|0)==(0|0);
 if ($27) {
  $28 = (__Znwj(20)|0);
  $29 = ((($28)) + 16|0);
  HEAP32[$29>>2] = $12;
  HEAP32[$28>>2] = 0;
  $30 = ((($28)) + 4|0);
  HEAP32[$30>>2] = 0;
  $31 = ((($28)) + 8|0);
  HEAP32[$31>>2] = $$036$i$i$i;
  HEAP32[$$025$i$i$i$i>>2] = $28;
  $32 = HEAP32[$11>>2]|0;
  $33 = HEAP32[$32>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $38 = $28;
  } else {
   $35 = $33;
   HEAP32[$11>>2] = $35;
   $$pre$i$i$i$i = HEAP32[$$025$i$i$i$i>>2]|0;
   $38 = $$pre$i$i$i$i;
  }
  $36 = ((($0)) + 96|0);
  $37 = HEAP32[$36>>2]|0;
  __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($37,$38);
  $39 = ((($0)) + 100|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = (($40) + 1)|0;
  HEAP32[$39>>2] = $41;
 }
 $42 = ((($0)) + 16|0);
 $43 = HEAP32[$42>>2]|0;
 switch ($43|0) {
 case 1:  {
  $44 = HEAP32[$1>>2]|0;
  $45 = ((($44)) + 192|0);
  $46 = HEAP32[$45>>2]|0;
  FUNCTION_TABLE_vii[$46 & 8191]($1,$0);
  return;
  break;
 }
 case 0:  {
  return;
  break;
 }
 default: {
  $47 = HEAP32[$1>>2]|0;
  $48 = ((($47)) + 196|0);
  $49 = HEAP32[$48>>2]|0;
  FUNCTION_TABLE_vii[$49 & 8191]($1,$0);
  return;
 }
 }
}
function __ZN7osgUtil12StatsVisitor5applyERN3osg9TransformE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i$i$i = 0, $$0$ph$i$i$i$i = 0, $$024$i$i$i$i = 0, $$025$i$i$i$i = 0, $$036$i$i$i = 0, $$in$i$i$i$i = 0, $$pre$i$i$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 120|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = HEAP32[$0>>2]|0;
  $6 = ((($5)) + 200|0);
  $7 = HEAP32[$6>>2]|0;
  FUNCTION_TABLE_vii[$7 & 8191]($0,$3);
 }
 $8 = ((($0)) + 68|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 1)|0;
 HEAP32[$8>>2] = $10;
 $11 = ((($0)) + 104|0);
 $12 = $1;
 $13 = ((($0)) + 108|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(0|0);
 do {
  if ($15) {
   $$025$i$i$i$i = $13;$$036$i$i$i = $13;
  } else {
   $16 = ((($0)) + 108|0);
   $$0$i$i$i$i = $16;$$024$i$i$i$i = $14;
   while(1) {
    $17 = ((($$024$i$i$i$i)) + 16|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = ($1>>>0)<($18>>>0);
    if ($19) {
     $20 = HEAP32[$$024$i$i$i$i>>2]|0;
     $21 = ($20|0)==(0|0);
     if ($21) {
      label = 8;
      break;
     } else {
      $$0$ph$i$i$i$i = $$024$i$i$i$i;$$in$i$i$i$i = $20;
     }
    } else {
     $22 = ($18>>>0)<($1>>>0);
     if (!($22)) {
      label = 12;
      break;
     }
     $23 = ((($$024$i$i$i$i)) + 4|0);
     $24 = HEAP32[$23>>2]|0;
     $25 = ($24|0)==(0|0);
     if ($25) {
      label = 11;
      break;
     } else {
      $$0$ph$i$i$i$i = $23;$$in$i$i$i$i = $24;
     }
    }
    $$0$i$i$i$i = $$0$ph$i$i$i$i;$$024$i$i$i$i = $$in$i$i$i$i;
   }
   if ((label|0) == 8) {
    $$025$i$i$i$i = $$024$i$i$i$i;$$036$i$i$i = $$024$i$i$i$i;
    break;
   }
   else if ((label|0) == 11) {
    $$025$i$i$i$i = $23;$$036$i$i$i = $$024$i$i$i$i;
    break;
   }
   else if ((label|0) == 12) {
    $$025$i$i$i$i = $$0$i$i$i$i;$$036$i$i$i = $$024$i$i$i$i;
    break;
   }
  }
 } while(0);
 $26 = HEAP32[$$025$i$i$i$i>>2]|0;
 $27 = ($26|0)==(0|0);
 if ($27) {
  $28 = (__Znwj(20)|0);
  $29 = ((($28)) + 16|0);
  HEAP32[$29>>2] = $12;
  HEAP32[$28>>2] = 0;
  $30 = ((($28)) + 4|0);
  HEAP32[$30>>2] = 0;
  $31 = ((($28)) + 8|0);
  HEAP32[$31>>2] = $$036$i$i$i;
  HEAP32[$$025$i$i$i$i>>2] = $28;
  $32 = HEAP32[$11>>2]|0;
  $33 = HEAP32[$32>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $38 = $28;
  } else {
   $35 = $33;
   HEAP32[$11>>2] = $35;
   $$pre$i$i$i$i = HEAP32[$$025$i$i$i$i>>2]|0;
   $38 = $$pre$i$i$i$i;
  }
  $36 = ((($0)) + 108|0);
  $37 = HEAP32[$36>>2]|0;
  __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($37,$38);
  $39 = ((($0)) + 112|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = (($40) + 1)|0;
  HEAP32[$39>>2] = $41;
 }
 $42 = ((($0)) + 16|0);
 $43 = HEAP32[$42>>2]|0;
 switch ($43|0) {
 case 1:  {
  $44 = HEAP32[$1>>2]|0;
  $45 = ((($44)) + 192|0);
  $46 = HEAP32[$45>>2]|0;
  FUNCTION_TABLE_vii[$46 & 8191]($1,$0);
  return;
  break;
 }
 case 0:  {
  return;
  break;
 }
 default: {
  $47 = HEAP32[$1>>2]|0;
  $48 = ((($47)) + 196|0);
  $49 = HEAP32[$48>>2]|0;
  FUNCTION_TABLE_vii[$49 & 8191]($1,$0);
  return;
 }
 }
}
function __ZN7osgUtil12StatsVisitor5applyERN3osg6SwitchE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i$i$i = 0, $$0$ph$i$i$i$i = 0, $$024$i$i$i$i = 0, $$025$i$i$i$i = 0, $$036$i$i$i = 0, $$in$i$i$i$i = 0, $$pre$i$i$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 120|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = HEAP32[$0>>2]|0;
  $6 = ((($5)) + 200|0);
  $7 = HEAP32[$6>>2]|0;
  FUNCTION_TABLE_vii[$7 & 8191]($0,$3);
 }
 $8 = ((($0)) + 60|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 1)|0;
 HEAP32[$8>>2] = $10;
 $11 = ((($0)) + 128|0);
 $12 = $1;
 $13 = ((($0)) + 132|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(0|0);
 do {
  if ($15) {
   $$025$i$i$i$i = $13;$$036$i$i$i = $13;
  } else {
   $16 = ((($0)) + 132|0);
   $$0$i$i$i$i = $16;$$024$i$i$i$i = $14;
   while(1) {
    $17 = ((($$024$i$i$i$i)) + 16|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = ($1>>>0)<($18>>>0);
    if ($19) {
     $20 = HEAP32[$$024$i$i$i$i>>2]|0;
     $21 = ($20|0)==(0|0);
     if ($21) {
      label = 8;
      break;
     } else {
      $$0$ph$i$i$i$i = $$024$i$i$i$i;$$in$i$i$i$i = $20;
     }
    } else {
     $22 = ($18>>>0)<($1>>>0);
     if (!($22)) {
      label = 12;
      break;
     }
     $23 = ((($$024$i$i$i$i)) + 4|0);
     $24 = HEAP32[$23>>2]|0;
     $25 = ($24|0)==(0|0);
     if ($25) {
      label = 11;
      break;
     } else {
      $$0$ph$i$i$i$i = $23;$$in$i$i$i$i = $24;
     }
    }
    $$0$i$i$i$i = $$0$ph$i$i$i$i;$$024$i$i$i$i = $$in$i$i$i$i;
   }
   if ((label|0) == 8) {
    $$025$i$i$i$i = $$024$i$i$i$i;$$036$i$i$i = $$024$i$i$i$i;
    break;
   }
   else if ((label|0) == 11) {
    $$025$i$i$i$i = $23;$$036$i$i$i = $$024$i$i$i$i;
    break;
   }
   else if ((label|0) == 12) {
    $$025$i$i$i$i = $$0$i$i$i$i;$$036$i$i$i = $$024$i$i$i$i;
    break;
   }
  }
 } while(0);
 $26 = HEAP32[$$025$i$i$i$i>>2]|0;
 $27 = ($26|0)==(0|0);
 if ($27) {
  $28 = (__Znwj(20)|0);
  $29 = ((($28)) + 16|0);
  HEAP32[$29>>2] = $12;
  HEAP32[$28>>2] = 0;
  $30 = ((($28)) + 4|0);
  HEAP32[$30>>2] = 0;
  $31 = ((($28)) + 8|0);
  HEAP32[$31>>2] = $$036$i$i$i;
  HEAP32[$$025$i$i$i$i>>2] = $28;
  $32 = HEAP32[$11>>2]|0;
  $33 = HEAP32[$32>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $38 = $28;
  } else {
   $35 = $33;
   HEAP32[$11>>2] = $35;
   $$pre$i$i$i$i = HEAP32[$$025$i$i$i$i>>2]|0;
   $38 = $$pre$i$i$i$i;
  }
  $36 = ((($0)) + 132|0);
  $37 = HEAP32[$36>>2]|0;
  __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($37,$38);
  $39 = ((($0)) + 136|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = (($40) + 1)|0;
  HEAP32[$39>>2] = $41;
 }
 $42 = ((($0)) + 16|0);
 $43 = HEAP32[$42>>2]|0;
 switch ($43|0) {
 case 1:  {
  $44 = HEAP32[$1>>2]|0;
  $45 = ((($44)) + 192|0);
  $46 = HEAP32[$45>>2]|0;
  FUNCTION_TABLE_vii[$46 & 8191]($1,$0);
  return;
  break;
 }
 case 0:  {
  return;
  break;
 }
 default: {
  $47 = HEAP32[$1>>2]|0;
  $48 = ((($47)) + 196|0);
  $49 = HEAP32[$48>>2]|0;
  FUNCTION_TABLE_vii[$49 & 8191]($1,$0);
  return;
 }
 }
}
function __ZN7osgUtil12StatsVisitor5applyERN3osg3LODE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i$i$i = 0, $$0$ph$i$i$i$i = 0, $$024$i$i$i$i = 0, $$025$i$i$i$i = 0, $$036$i$i$i = 0, $$in$i$i$i$i = 0, $$pre$i$i$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 120|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = HEAP32[$0>>2]|0;
  $6 = ((($5)) + 200|0);
  $7 = HEAP32[$6>>2]|0;
  FUNCTION_TABLE_vii[$7 & 8191]($0,$3);
 }
 $8 = ((($0)) + 64|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 1)|0;
 HEAP32[$8>>2] = $10;
 $11 = ((($0)) + 116|0);
 $12 = $1;
 $13 = ((($0)) + 120|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(0|0);
 do {
  if ($15) {
   $$025$i$i$i$i = $13;$$036$i$i$i = $13;
  } else {
   $16 = ((($0)) + 120|0);
   $$0$i$i$i$i = $16;$$024$i$i$i$i = $14;
   while(1) {
    $17 = ((($$024$i$i$i$i)) + 16|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = ($1>>>0)<($18>>>0);
    if ($19) {
     $20 = HEAP32[$$024$i$i$i$i>>2]|0;
     $21 = ($20|0)==(0|0);
     if ($21) {
      label = 8;
      break;
     } else {
      $$0$ph$i$i$i$i = $$024$i$i$i$i;$$in$i$i$i$i = $20;
     }
    } else {
     $22 = ($18>>>0)<($1>>>0);
     if (!($22)) {
      label = 12;
      break;
     }
     $23 = ((($$024$i$i$i$i)) + 4|0);
     $24 = HEAP32[$23>>2]|0;
     $25 = ($24|0)==(0|0);
     if ($25) {
      label = 11;
      break;
     } else {
      $$0$ph$i$i$i$i = $23;$$in$i$i$i$i = $24;
     }
    }
    $$0$i$i$i$i = $$0$ph$i$i$i$i;$$024$i$i$i$i = $$in$i$i$i$i;
   }
   if ((label|0) == 8) {
    $$025$i$i$i$i = $$024$i$i$i$i;$$036$i$i$i = $$024$i$i$i$i;
    break;
   }
   else if ((label|0) == 11) {
    $$025$i$i$i$i = $23;$$036$i$i$i = $$024$i$i$i$i;
    break;
   }
   else if ((label|0) == 12) {
    $$025$i$i$i$i = $$0$i$i$i$i;$$036$i$i$i = $$024$i$i$i$i;
    break;
   }
  }
 } while(0);
 $26 = HEAP32[$$025$i$i$i$i>>2]|0;
 $27 = ($26|0)==(0|0);
 if ($27) {
  $28 = (__Znwj(20)|0);
  $29 = ((($28)) + 16|0);
  HEAP32[$29>>2] = $12;
  HEAP32[$28>>2] = 0;
  $30 = ((($28)) + 4|0);
  HEAP32[$30>>2] = 0;
  $31 = ((($28)) + 8|0);
  HEAP32[$31>>2] = $$036$i$i$i;
  HEAP32[$$025$i$i$i$i>>2] = $28;
  $32 = HEAP32[$11>>2]|0;
  $33 = HEAP32[$32>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $38 = $28;
  } else {
   $35 = $33;
   HEAP32[$11>>2] = $35;
   $$pre$i$i$i$i = HEAP32[$$025$i$i$i$i>>2]|0;
   $38 = $$pre$i$i$i$i;
  }
  $36 = ((($0)) + 120|0);
  $37 = HEAP32[$36>>2]|0;
  __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($37,$38);
  $39 = ((($0)) + 124|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = (($40) + 1)|0;
  HEAP32[$39>>2] = $41;
 }
 $42 = ((($0)) + 16|0);
 $43 = HEAP32[$42>>2]|0;
 switch ($43|0) {
 case 1:  {
  $44 = HEAP32[$1>>2]|0;
  $45 = ((($44)) + 192|0);
  $46 = HEAP32[$45>>2]|0;
  FUNCTION_TABLE_vii[$46 & 8191]($1,$0);
  return;
  break;
 }
 case 0:  {
  return;
  break;
 }
 default: {
  $47 = HEAP32[$1>>2]|0;
  $48 = ((($47)) + 196|0);
  $49 = HEAP32[$48>>2]|0;
  FUNCTION_TABLE_vii[$49 & 8191]($1,$0);
  return;
 }
 }
}
function __ZN7osgUtil12StatsVisitor5applyERN3osg8StateSetE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i$i$i = 0, $$0$ph$i$i$i$i = 0, $$024$i$i$i$i = 0, $$025$i$i$i$i = 0, $$036$i$i$i = 0, $$in$i$i$i$i = 0, $$pre$i$i$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 88|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 1)|0;
 HEAP32[$2>>2] = $4;
 $5 = ((($0)) + 188|0);
 $6 = $1;
 $7 = ((($0)) + 192|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 do {
  if ($9) {
   $$025$i$i$i$i = $7;$$036$i$i$i = $7;
  } else {
   $10 = ((($0)) + 192|0);
   $$0$i$i$i$i = $10;$$024$i$i$i$i = $8;
   while(1) {
    $11 = ((($$024$i$i$i$i)) + 16|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ($12>>>0)>($1>>>0);
    if ($13) {
     $14 = HEAP32[$$024$i$i$i$i>>2]|0;
     $15 = ($14|0)==(0|0);
     if ($15) {
      label = 6;
      break;
     } else {
      $$0$ph$i$i$i$i = $$024$i$i$i$i;$$in$i$i$i$i = $14;
     }
    } else {
     $16 = ($12>>>0)<($1>>>0);
     if (!($16)) {
      label = 10;
      break;
     }
     $17 = ((($$024$i$i$i$i)) + 4|0);
     $18 = HEAP32[$17>>2]|0;
     $19 = ($18|0)==(0|0);
     if ($19) {
      label = 9;
      break;
     } else {
      $$0$ph$i$i$i$i = $17;$$in$i$i$i$i = $18;
     }
    }
    $$0$i$i$i$i = $$0$ph$i$i$i$i;$$024$i$i$i$i = $$in$i$i$i$i;
   }
   if ((label|0) == 6) {
    $$025$i$i$i$i = $$024$i$i$i$i;$$036$i$i$i = $$024$i$i$i$i;
    break;
   }
   else if ((label|0) == 9) {
    $$025$i$i$i$i = $17;$$036$i$i$i = $$024$i$i$i$i;
    break;
   }
   else if ((label|0) == 10) {
    $$025$i$i$i$i = $$0$i$i$i$i;$$036$i$i$i = $$024$i$i$i$i;
    break;
   }
  }
 } while(0);
 $20 = HEAP32[$$025$i$i$i$i>>2]|0;
 $21 = ($20|0)==(0|0);
 if (!($21)) {
  return;
 }
 $22 = (__Znwj(20)|0);
 $23 = ((($22)) + 16|0);
 HEAP32[$23>>2] = $6;
 HEAP32[$22>>2] = 0;
 $24 = ((($22)) + 4|0);
 HEAP32[$24>>2] = 0;
 $25 = ((($22)) + 8|0);
 HEAP32[$25>>2] = $$036$i$i$i;
 HEAP32[$$025$i$i$i$i>>2] = $22;
 $26 = HEAP32[$5>>2]|0;
 $27 = HEAP32[$26>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  $32 = $22;
 } else {
  $29 = $27;
  HEAP32[$5>>2] = $29;
  $$pre$i$i$i$i = HEAP32[$$025$i$i$i$i>>2]|0;
  $32 = $$pre$i$i$i$i;
 }
 $30 = ((($0)) + 192|0);
 $31 = HEAP32[$30>>2]|0;
 __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($31,$32);
 $33 = ((($0)) + 196|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = (($34) + 1)|0;
 HEAP32[$33>>2] = $35;
 return;
}
function __ZN7osgUtil12StatsVisitor12totalUpStatsEv($0) {
 $0 = $0|0;
 var $$0$i$i$i = 0, $$sroa$02$0$be = 0, $$sroa$02$06 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 204|0);
 $2 = ((($0)) + 252|0);
 $3 = ((($0)) + 256|0);
 dest=$1; stop=dest+48|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $4 = HEAP32[$3>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIjNS_4pairIjjEEEENS_19__map_value_compareIjS4_NS_4lessIjEELb1EEENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($2,$4);
 $5 = ((($0)) + 260|0);
 HEAP32[$5>>2] = 0;
 HEAP32[$2>>2] = $3;
 HEAP32[$3>>2] = 0;
 $6 = ((($0)) + 264|0);
 HEAP32[$6>>2] = 0;
 $7 = ((($0)) + 268|0);
 $8 = ((($0)) + 272|0);
 $9 = HEAP32[$8>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIjjEENS_19__map_value_compareIjS2_NS_4lessIjEELb1EEENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($7,$9);
 $10 = ((($0)) + 276|0);
 HEAP32[$10>>2] = 0;
 HEAP32[$7>>2] = $8;
 HEAP32[$8>>2] = 0;
 $11 = ((($0)) + 280|0);
 HEAP32[$11>>2] = 0;
 $12 = ((($0)) + 284|0);
 HEAP32[$12>>2] = 0;
 $13 = ((($0)) + 152|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ((($0)) + 156|0);
 $16 = ($14|0)==($15|0);
 if ($16) {
  return;
 }
 $17 = ((($0)) + 200|0);
 $$sroa$02$06 = $14;
 while(1) {
  $18 = ((($$sroa$02$06)) + 16|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = HEAP32[$19>>2]|0;
  $21 = ((($20)) + 264|0);
  $22 = HEAP32[$21>>2]|0;
  FUNCTION_TABLE_vii[$22 & 8191]($19,$17);
  $23 = ((($$sroa$02$06)) + 4|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = ($24|0)==(0|0);
  if ($25) {
   $26 = ((($$sroa$02$06)) + 8|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = HEAP32[$27>>2]|0;
   $29 = ($28|0)==($$sroa$02$06|0);
   if ($29) {
    $$sroa$02$0$be = $27;
   } else {
    $34 = $26;
    while(1) {
     $33 = HEAP32[$34>>2]|0;
     $35 = ((($33)) + 8|0);
     $36 = HEAP32[$35>>2]|0;
     $37 = HEAP32[$36>>2]|0;
     $38 = ($37|0)==($33|0);
     if ($38) {
      $$sroa$02$0$be = $36;
      break;
     } else {
      $34 = $35;
     }
    }
   }
  } else {
   $$0$i$i$i = $24;
   while(1) {
    $31 = HEAP32[$$0$i$i$i>>2]|0;
    $32 = ($31|0)==(0|0);
    if ($32) {
     break;
    } else {
     $$0$i$i$i = $31;
    }
   }
   $$sroa$02$0$be = $$0$i$i$i;
  }
  $30 = ($$sroa$02$0$be|0)==($15|0);
  if ($30) {
   break;
  } else {
   $$sroa$02$06 = $$sroa$02$0$be;
  }
 }
 return;
}
function __ZN7osgUtil12StatsVisitor5printERNSt3__213basic_ostreamIcNS1_11char_traitsIcEEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$$0 = 0, $$$048 = 0, $$$052 = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i57 = 0, $$0$i$i$i64 = 0, $$0$i$i$i67 = 0, $$0$lcssa = 0, $$0220 = 0, $$048$lcssa = 0, $$048224 = 0, $$050$lcssa = 0, $$050223 = 0, $$052$lcssa = 0, $$052222 = 0, $$054$lcssa = 0, $$054234 = 0, $$055$lcssa = 0, $$055230 = 0, $$149 = 0;
 var $$151 = 0, $$sroa$0193$0$be = 0, $$sroa$0193$0219 = 0, $$sroa$0199$0$be = 0, $$sroa$0199$0221 = 0, $$sroa$0209$0$be = 0, $$sroa$0209$0233 = 0, $$sroa$0209$1$be = 0, $$sroa$0209$1229 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0;
 var $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0;
 var $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0;
 var $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0;
 var $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0;
 var $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0;
 var $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0;
 var $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0;
 var $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0;
 var $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0;
 var $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0;
 var $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0;
 var $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0;
 var $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0;
 var $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0;
 var $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0;
 var $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0;
 var $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0;
 var $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0;
 var $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0;
 var $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0;
 var $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0;
 var $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0;
 var $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0;
 var $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0;
 var $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0;
 var $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0;
 var $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0;
 var $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0;
 var $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0;
 var $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0;
 var $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0;
 var $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0;
 var $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0;
 var $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0;
 var $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(80|0);
 $2 = sp + 64|0;
 $3 = sp + 60|0;
 $4 = sp + 56|0;
 $5 = sp + 52|0;
 $6 = sp + 48|0;
 $7 = sp + 44|0;
 $8 = sp + 40|0;
 $9 = sp + 36|0;
 $10 = sp + 32|0;
 $11 = sp + 28|0;
 $12 = sp + 24|0;
 $13 = sp + 20|0;
 $14 = sp + 16|0;
 $15 = sp + 12|0;
 $16 = sp + 8|0;
 $17 = sp + 4|0;
 $18 = sp;
 $19 = ((($0)) + 268|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ((($0)) + 272|0);
 $22 = ($20|0)==($21|0);
 if ($22) {
  $$054$lcssa = 0;
 } else {
  $$054234 = 0;$$sroa$0209$0233 = $20;
  while(1) {
   $23 = ((($$sroa$0209$0233)) + 20|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = (($24) + ($$054234))|0;
   $26 = ((($$sroa$0209$0233)) + 4|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = ($27|0)==(0|0);
   if ($28) {
    $29 = ((($$sroa$0209$0233)) + 8|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = HEAP32[$30>>2]|0;
    $32 = ($31|0)==($$sroa$0209$0233|0);
    if ($32) {
     $$sroa$0209$0$be = $30;
    } else {
     $37 = $29;
     while(1) {
      $36 = HEAP32[$37>>2]|0;
      $38 = ((($36)) + 8|0);
      $39 = HEAP32[$38>>2]|0;
      $40 = HEAP32[$39>>2]|0;
      $41 = ($40|0)==($36|0);
      if ($41) {
       $$sroa$0209$0$be = $39;
       break;
      } else {
       $37 = $38;
      }
     }
    }
   } else {
    $$0$i$i$i$i = $27;
    while(1) {
     $34 = HEAP32[$$0$i$i$i$i>>2]|0;
     $35 = ($34|0)==(0|0);
     if ($35) {
      break;
     } else {
      $$0$i$i$i$i = $34;
     }
    }
    $$sroa$0209$0$be = $$0$i$i$i$i;
   }
   $33 = ($$sroa$0209$0$be|0)==($21|0);
   if ($33) {
    $$054$lcssa = $25;
    break;
   } else {
    $$054234 = $25;$$sroa$0209$0233 = $$sroa$0209$0$be;
   }
  }
 }
 $42 = ((($0)) + 356|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = ((($0)) + 360|0);
 $45 = ($43|0)==($44|0);
 if ($45) {
  $$055$lcssa = 0;
 } else {
  $$055230 = 0;$$sroa$0209$1229 = $43;
  while(1) {
   $46 = ((($$sroa$0209$1229)) + 20|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = (($47) + ($$055230))|0;
   $49 = ((($$sroa$0209$1229)) + 4|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = ($50|0)==(0|0);
   if ($51) {
    $52 = ((($$sroa$0209$1229)) + 8|0);
    $53 = HEAP32[$52>>2]|0;
    $54 = HEAP32[$53>>2]|0;
    $55 = ($54|0)==($$sroa$0209$1229|0);
    if ($55) {
     $$sroa$0209$1$be = $53;
    } else {
     $60 = $52;
     while(1) {
      $59 = HEAP32[$60>>2]|0;
      $61 = ((($59)) + 8|0);
      $62 = HEAP32[$61>>2]|0;
      $63 = HEAP32[$62>>2]|0;
      $64 = ($63|0)==($59|0);
      if ($64) {
       $$sroa$0209$1$be = $62;
       break;
      } else {
       $60 = $61;
      }
     }
    }
   } else {
    $$0$i$i$i$i57 = $50;
    while(1) {
     $57 = HEAP32[$$0$i$i$i$i57>>2]|0;
     $58 = ($57|0)==(0|0);
     if ($58) {
      break;
     } else {
      $$0$i$i$i$i57 = $57;
     }
    }
    $$sroa$0209$1$be = $$0$i$i$i$i57;
   }
   $56 = ($$sroa$0209$1$be|0)==($44|0);
   if ($56) {
    $$055$lcssa = $48;
    break;
   } else {
    $$055230 = $48;$$sroa$0209$1229 = $$sroa$0209$1$be;
   }
  }
 }
 $65 = ((($0)) + 188|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = ((($0)) + 192|0);
 $68 = ($66|0)==($67|0);
 if ($68) {
  $$048$lcssa = 0;$$050$lcssa = 0;$$052$lcssa = 0;
 } else {
  $$048224 = 0;$$050223 = 0;$$052222 = 0;$$sroa$0199$0221 = $66;
  while(1) {
   $73 = ((($$sroa$0199$0221)) + 16|0);
   $74 = HEAP32[$73>>2]|0;
   $75 = ((($74)) + 24|0);
   $76 = HEAP32[$75>>2]|0;
   $77 = ($76|0)==(0);
   $78 = $77&1;
   $$$052 = (($78) + ($$052222))|0;
   $79 = ((($74)) + 120|0);
   $80 = HEAP32[$79>>2]|0;
   $81 = ($80|0)==(0);
   if ($81) {
    $$149 = $$048224;$$151 = $$050223;
   } else {
    $82 = ((($74)) + 124|0);
    $83 = (($$050223) + 1)|0;
    $84 = HEAP32[$82>>2]|0;
    $85 = ($84|0)==(10);
    $86 = $85&1;
    $$$048 = (($86) + ($$048224))|0;
    $$149 = $$$048;$$151 = $83;
   }
   $87 = ((($$sroa$0199$0221)) + 4|0);
   $88 = HEAP32[$87>>2]|0;
   $89 = ($88|0)==(0|0);
   if ($89) {
    $90 = ((($$sroa$0199$0221)) + 8|0);
    $91 = HEAP32[$90>>2]|0;
    $92 = HEAP32[$91>>2]|0;
    $93 = ($92|0)==($$sroa$0199$0221|0);
    if ($93) {
     $$sroa$0199$0$be = $91;
    } else {
     $98 = $90;
     while(1) {
      $97 = HEAP32[$98>>2]|0;
      $99 = ((($97)) + 8|0);
      $100 = HEAP32[$99>>2]|0;
      $101 = HEAP32[$100>>2]|0;
      $102 = ($101|0)==($97|0);
      if ($102) {
       $$sroa$0199$0$be = $100;
       break;
      } else {
       $98 = $99;
      }
     }
    }
   } else {
    $$0$i$i$i64 = $88;
    while(1) {
     $95 = HEAP32[$$0$i$i$i64>>2]|0;
     $96 = ($95|0)==(0|0);
     if ($96) {
      break;
     } else {
      $$0$i$i$i64 = $95;
     }
    }
    $$sroa$0199$0$be = $$0$i$i$i64;
   }
   $94 = ($$sroa$0199$0$be|0)==($67|0);
   if ($94) {
    $$048$lcssa = $$149;$$050$lcssa = $$151;$$052$lcssa = $$$052;
    break;
   } else {
    $$048224 = $$149;$$050223 = $$151;$$052222 = $$$052;$$sroa$0199$0221 = $$sroa$0199$0$be;
   }
  }
 }
 $69 = ((($0)) + 152|0);
 $70 = HEAP32[$69>>2]|0;
 $71 = ((($0)) + 156|0);
 $72 = ($70|0)==($71|0);
 if ($72) {
  $$0$lcssa = 0;
 } else {
  $$0220 = 0;$$sroa$0193$0219 = $70;
  while(1) {
   $127 = ((($$sroa$0193$0219)) + 16|0);
   $128 = HEAP32[$127>>2]|0;
   $129 = ((($128)) + 24|0);
   $130 = HEAP32[$129>>2]|0;
   $131 = ($130|0)==(0);
   $132 = $131&1;
   $$$0 = (($132) + ($$0220))|0;
   $133 = ((($$sroa$0193$0219)) + 4|0);
   $134 = HEAP32[$133>>2]|0;
   $135 = ($134|0)==(0|0);
   if ($135) {
    $136 = ((($$sroa$0193$0219)) + 8|0);
    $137 = HEAP32[$136>>2]|0;
    $138 = HEAP32[$137>>2]|0;
    $139 = ($138|0)==($$sroa$0193$0219|0);
    if ($139) {
     $$sroa$0193$0$be = $137;
    } else {
     $144 = $136;
     while(1) {
      $143 = HEAP32[$144>>2]|0;
      $145 = ((($143)) + 8|0);
      $146 = HEAP32[$145>>2]|0;
      $147 = HEAP32[$146>>2]|0;
      $148 = ($147|0)==($143|0);
      if ($148) {
       $$sroa$0193$0$be = $146;
       break;
      } else {
       $144 = $145;
      }
     }
    }
   } else {
    $$0$i$i$i67 = $134;
    while(1) {
     $141 = HEAP32[$$0$i$i$i67>>2]|0;
     $142 = ($141|0)==(0|0);
     if ($142) {
      break;
     } else {
      $$0$i$i$i67 = $141;
     }
    }
    $$sroa$0193$0$be = $$0$i$i$i67;
   }
   $140 = ($$sroa$0193$0$be|0)==($71|0);
   if ($140) {
    $$0$lcssa = $$$0;
    break;
   } else {
    $$0220 = $$$0;$$sroa$0193$0219 = $$sroa$0193$0$be;
   }
  }
 }
 $103 = $$0$lcssa | $$052$lcssa;
 $104 = ($103|0)==(0);
 $105 = HEAP32[$1>>2]|0;
 $106 = ((($105)) + -12|0);
 $107 = HEAP32[$106>>2]|0;
 $108 = (($1) + ($107)|0);
 $109 = ((($108)) + 12|0);
 HEAP32[$109>>2] = 12;
 $110 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($1,114897,11)|0);
 $111 = HEAP32[$110>>2]|0;
 $112 = ((($111)) + -12|0);
 $113 = HEAP32[$112>>2]|0;
 $114 = (($110) + ($113)|0);
 $115 = ((($114)) + 12|0);
 HEAP32[$115>>2] = 10;
 $116 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($110,114909,6)|0);
 $117 = HEAP32[$116>>2]|0;
 $118 = ((($117)) + -12|0);
 $119 = HEAP32[$118>>2]|0;
 $120 = (($116) + ($119)|0);
 $121 = ((($120)) + 12|0);
 HEAP32[$121>>2] = 10;
 $122 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($116,114916,9)|0);
 $123 = HEAP32[$122>>2]|0;
 $124 = ((($123)) + -12|0);
 $125 = HEAP32[$124>>2]|0;
 $126 = (($122) + ($125)|0);
 do {
  if ($104) {
   __ZNKSt3__28ios_base6getlocEv($13,$126);
   __THREW__ = 0;
   $213 = (invoke_iii(3255,($13|0),(215188|0))|0);
   $214 = __THREW__; __THREW__ = 0;
   $215 = $214&1;
   if (!($215)) {
    $216 = HEAP32[$213>>2]|0;
    $217 = ((($216)) + 28|0);
    $218 = HEAP32[$217>>2]|0;
    __THREW__ = 0;
    $219 = (invoke_iii($218|0,($213|0),10)|0);
    $220 = __THREW__; __THREW__ = 0;
    $221 = $220&1;
    if (!($221)) {
     __ZNSt3__26localeD2Ev($13);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($122,$219)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($122)|0);
     $228 = HEAP32[$1>>2]|0;
     $229 = ((($228)) + -12|0);
     $230 = HEAP32[$229>>2]|0;
     $231 = (($1) + ($230)|0);
     $232 = ((($231)) + 12|0);
     HEAP32[$232>>2] = 12;
     $233 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($1,114934,11)|0);
     $234 = HEAP32[$233>>2]|0;
     $235 = ((($234)) + -12|0);
     $236 = HEAP32[$235>>2]|0;
     $237 = (($233) + ($236)|0);
     $238 = ((($237)) + 12|0);
     HEAP32[$238>>2] = 10;
     $239 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($233,114946,6)|0);
     $240 = HEAP32[$239>>2]|0;
     $241 = ((($240)) + -12|0);
     $242 = HEAP32[$241>>2]|0;
     $243 = (($239) + ($242)|0);
     $244 = ((($243)) + 12|0);
     HEAP32[$244>>2] = 10;
     $245 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($239,114953,9)|0);
     $246 = HEAP32[$245>>2]|0;
     $247 = ((($246)) + -12|0);
     $248 = HEAP32[$247>>2]|0;
     $249 = (($245) + ($248)|0);
     __ZNKSt3__28ios_base6getlocEv($12,$249);
     __THREW__ = 0;
     $250 = (invoke_iii(3255,($12|0),(215188|0))|0);
     $251 = __THREW__; __THREW__ = 0;
     $252 = $251&1;
     if (!($252)) {
      $253 = HEAP32[$250>>2]|0;
      $254 = ((($253)) + 28|0);
      $255 = HEAP32[$254>>2]|0;
      __THREW__ = 0;
      $256 = (invoke_iii($255|0,($250|0),10)|0);
      $257 = __THREW__; __THREW__ = 0;
      $258 = $257&1;
      if (!($258)) {
       __ZNSt3__26localeD2Ev($12);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($245,$256)|0);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($245)|0);
       break;
      }
     }
     $259 = ___cxa_find_matching_catch_2()|0;
     $260 = tempRet0;
     __THREW__ = 0;
     invoke_vi(3263,($12|0));
     $261 = __THREW__; __THREW__ = 0;
     $262 = $261&1;
     if ($262) {
      $263 = ___cxa_find_matching_catch_3(0|0)|0;
      $264 = tempRet0;
      ___clang_call_terminate($263);
      // unreachable;
     } else {
      ___resumeException($259|0);
      // unreachable;
     }
    }
   }
   $222 = ___cxa_find_matching_catch_2()|0;
   $223 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($13|0));
   $224 = __THREW__; __THREW__ = 0;
   $225 = $224&1;
   if ($225) {
    $226 = ___cxa_find_matching_catch_3(0|0)|0;
    $227 = tempRet0;
    ___clang_call_terminate($226);
    // unreachable;
   } else {
    ___resumeException($222|0);
    // unreachable;
   }
  } else {
   $149 = ((($126)) + 12|0);
   HEAP32[$149>>2] = 10;
   $150 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($122,114926,7)|0);
   $151 = HEAP32[$150>>2]|0;
   $152 = ((($151)) + -12|0);
   $153 = HEAP32[$152>>2]|0;
   $154 = (($150) + ($153)|0);
   __ZNKSt3__28ios_base6getlocEv($15,$154);
   __THREW__ = 0;
   $155 = (invoke_iii(3255,($15|0),(215188|0))|0);
   $156 = __THREW__; __THREW__ = 0;
   $157 = $156&1;
   if (!($157)) {
    $158 = HEAP32[$155>>2]|0;
    $159 = ((($158)) + 28|0);
    $160 = HEAP32[$159>>2]|0;
    __THREW__ = 0;
    $161 = (invoke_iii($160|0,($155|0),10)|0);
    $162 = __THREW__; __THREW__ = 0;
    $163 = $162&1;
    if (!($163)) {
     __ZNSt3__26localeD2Ev($15);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($150,$161)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($150)|0);
     $170 = HEAP32[$1>>2]|0;
     $171 = ((($170)) + -12|0);
     $172 = HEAP32[$171>>2]|0;
     $173 = (($1) + ($172)|0);
     $174 = ((($173)) + 12|0);
     HEAP32[$174>>2] = 12;
     $175 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($1,114934,11)|0);
     $176 = HEAP32[$175>>2]|0;
     $177 = ((($176)) + -12|0);
     $178 = HEAP32[$177>>2]|0;
     $179 = (($175) + ($178)|0);
     $180 = ((($179)) + 12|0);
     HEAP32[$180>>2] = 10;
     $181 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($175,114946,6)|0);
     $182 = HEAP32[$181>>2]|0;
     $183 = ((($182)) + -12|0);
     $184 = HEAP32[$183>>2]|0;
     $185 = (($181) + ($184)|0);
     $186 = ((($185)) + 12|0);
     HEAP32[$186>>2] = 10;
     $187 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($181,114953,9)|0);
     $188 = HEAP32[$187>>2]|0;
     $189 = ((($188)) + -12|0);
     $190 = HEAP32[$189>>2]|0;
     $191 = (($187) + ($190)|0);
     $192 = ((($191)) + 12|0);
     HEAP32[$192>>2] = 10;
     $193 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($187,114953,9)|0);
     $194 = HEAP32[$193>>2]|0;
     $195 = ((($194)) + -12|0);
     $196 = HEAP32[$195>>2]|0;
     $197 = (($193) + ($196)|0);
     __ZNKSt3__28ios_base6getlocEv($14,$197);
     __THREW__ = 0;
     $198 = (invoke_iii(3255,($14|0),(215188|0))|0);
     $199 = __THREW__; __THREW__ = 0;
     $200 = $199&1;
     if (!($200)) {
      $201 = HEAP32[$198>>2]|0;
      $202 = ((($201)) + 28|0);
      $203 = HEAP32[$202>>2]|0;
      __THREW__ = 0;
      $204 = (invoke_iii($203|0,($198|0),10)|0);
      $205 = __THREW__; __THREW__ = 0;
      $206 = $205&1;
      if (!($206)) {
       __ZNSt3__26localeD2Ev($14);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($193,$204)|0);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($193)|0);
       break;
      }
     }
     $207 = ___cxa_find_matching_catch_2()|0;
     $208 = tempRet0;
     __THREW__ = 0;
     invoke_vi(3263,($14|0));
     $209 = __THREW__; __THREW__ = 0;
     $210 = $209&1;
     if ($210) {
      $211 = ___cxa_find_matching_catch_3(0|0)|0;
      $212 = tempRet0;
      ___clang_call_terminate($211);
      // unreachable;
     } else {
      ___resumeException($207|0);
      // unreachable;
     }
    }
   }
   $164 = ___cxa_find_matching_catch_2()|0;
   $165 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($15|0));
   $166 = __THREW__; __THREW__ = 0;
   $167 = $166&1;
   if ($167) {
    $168 = ___cxa_find_matching_catch_3(0|0)|0;
    $169 = tempRet0;
    ___clang_call_terminate($168);
    // unreachable;
   } else {
    ___resumeException($164|0);
    // unreachable;
   }
  }
 } while(0);
 $265 = HEAP32[$1>>2]|0;
 $266 = ((($265)) + -12|0);
 $267 = HEAP32[$266>>2]|0;
 $268 = (($1) + ($267)|0);
 $269 = ((($268)) + 12|0);
 HEAP32[$269>>2] = 12;
 $270 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($1,114963,11)|0);
 $271 = HEAP32[$270>>2]|0;
 $272 = ((($271)) + -12|0);
 $273 = HEAP32[$272>>2]|0;
 $274 = (($270) + ($273)|0);
 $275 = ((($274)) + 12|0);
 HEAP32[$275>>2] = 10;
 $276 = ((($0)) + 196|0);
 $277 = HEAP32[$276>>2]|0;
 $278 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($270,$277)|0);
 $279 = HEAP32[$278>>2]|0;
 $280 = ((($279)) + -12|0);
 $281 = HEAP32[$280>>2]|0;
 $282 = (($278) + ($281)|0);
 $283 = ((($282)) + 12|0);
 HEAP32[$283>>2] = 10;
 $284 = ((($0)) + 88|0);
 $285 = HEAP32[$284>>2]|0;
 $286 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($278,$285)|0);
 $287 = HEAP32[$286>>2]|0;
 $288 = ((($287)) + -12|0);
 $289 = HEAP32[$288>>2]|0;
 $290 = (($286) + ($289)|0);
 $291 = ((($290)) + 12|0);
 HEAP32[$291>>2] = 10;
 $292 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($286,$$052$lcssa)|0);
 $293 = HEAP32[$292>>2]|0;
 $294 = ((($293)) + -12|0);
 $295 = HEAP32[$294>>2]|0;
 $296 = (($292) + ($295)|0);
 __ZNKSt3__28ios_base6getlocEv($11,$296);
 __THREW__ = 0;
 $297 = (invoke_iii(3255,($11|0),(215188|0))|0);
 $298 = __THREW__; __THREW__ = 0;
 $299 = $298&1;
 if (!($299)) {
  $300 = HEAP32[$297>>2]|0;
  $301 = ((($300)) + 28|0);
  $302 = HEAP32[$301>>2]|0;
  __THREW__ = 0;
  $303 = (invoke_iii($302|0,($297|0),10)|0);
  $304 = __THREW__; __THREW__ = 0;
  $305 = $304&1;
  if (!($305)) {
   __ZNSt3__26localeD2Ev($11);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($292,$303)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($292)|0);
   $312 = ($$048$lcssa|0)==(0);
   do {
    if (!($312)) {
     $313 = HEAP32[$1>>2]|0;
     $314 = ((($313)) + -12|0);
     $315 = HEAP32[$314>>2]|0;
     $316 = (($1) + ($315)|0);
     $317 = ((($316)) + 12|0);
     HEAP32[$317>>2] = 12;
     $318 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($1,114975,11)|0);
     $319 = HEAP32[$318>>2]|0;
     $320 = ((($319)) + -12|0);
     $321 = HEAP32[$320>>2]|0;
     $322 = (($318) + ($321)|0);
     $323 = ((($322)) + 12|0);
     HEAP32[$323>>2] = 10;
     $324 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($318,$$048$lcssa)|0);
     $325 = HEAP32[$324>>2]|0;
     $326 = ((($325)) + -12|0);
     $327 = HEAP32[$326>>2]|0;
     $328 = (($324) + ($327)|0);
     __ZNKSt3__28ios_base6getlocEv($10,$328);
     __THREW__ = 0;
     $329 = (invoke_iii(3255,($10|0),(215188|0))|0);
     $330 = __THREW__; __THREW__ = 0;
     $331 = $330&1;
     if (!($331)) {
      $332 = HEAP32[$329>>2]|0;
      $333 = ((($332)) + 28|0);
      $334 = HEAP32[$333>>2]|0;
      __THREW__ = 0;
      $335 = (invoke_iii($334|0,($329|0),10)|0);
      $336 = __THREW__; __THREW__ = 0;
      $337 = $336&1;
      if (!($337)) {
       __ZNSt3__26localeD2Ev($10);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($324,$335)|0);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($324)|0);
       break;
      }
     }
     $338 = ___cxa_find_matching_catch_2()|0;
     $339 = tempRet0;
     __THREW__ = 0;
     invoke_vi(3263,($10|0));
     $340 = __THREW__; __THREW__ = 0;
     $341 = $340&1;
     if ($341) {
      $342 = ___cxa_find_matching_catch_3(0|0)|0;
      $343 = tempRet0;
      ___clang_call_terminate($342);
      // unreachable;
     } else {
      ___resumeException($338|0);
      // unreachable;
     }
    }
   } while(0);
   $344 = ($$050$lcssa|0)==(0);
   do {
    if (!($344)) {
     $345 = HEAP32[$1>>2]|0;
     $346 = ((($345)) + -12|0);
     $347 = HEAP32[$346>>2]|0;
     $348 = (($1) + ($347)|0);
     $349 = ((($348)) + 12|0);
     HEAP32[$349>>2] = 12;
     $350 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($1,114987,11)|0);
     $351 = HEAP32[$350>>2]|0;
     $352 = ((($351)) + -12|0);
     $353 = HEAP32[$352>>2]|0;
     $354 = (($350) + ($353)|0);
     $355 = ((($354)) + 12|0);
     HEAP32[$355>>2] = 10;
     $356 = (($$050$lcssa) - ($$048$lcssa))|0;
     $357 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($350,$356)|0);
     $358 = HEAP32[$357>>2]|0;
     $359 = ((($358)) + -12|0);
     $360 = HEAP32[$359>>2]|0;
     $361 = (($357) + ($360)|0);
     __ZNKSt3__28ios_base6getlocEv($9,$361);
     __THREW__ = 0;
     $362 = (invoke_iii(3255,($9|0),(215188|0))|0);
     $363 = __THREW__; __THREW__ = 0;
     $364 = $363&1;
     if (!($364)) {
      $365 = HEAP32[$362>>2]|0;
      $366 = ((($365)) + 28|0);
      $367 = HEAP32[$366>>2]|0;
      __THREW__ = 0;
      $368 = (invoke_iii($367|0,($362|0),10)|0);
      $369 = __THREW__; __THREW__ = 0;
      $370 = $369&1;
      if (!($370)) {
       __ZNSt3__26localeD2Ev($9);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($357,$368)|0);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($357)|0);
       break;
      }
     }
     $371 = ___cxa_find_matching_catch_2()|0;
     $372 = tempRet0;
     __THREW__ = 0;
     invoke_vi(3263,($9|0));
     $373 = __THREW__; __THREW__ = 0;
     $374 = $373&1;
     if ($374) {
      $375 = ___cxa_find_matching_catch_3(0|0)|0;
      $376 = tempRet0;
      ___clang_call_terminate($375);
      // unreachable;
     } else {
      ___resumeException($371|0);
      // unreachable;
     }
    }
   } while(0);
   $377 = HEAP32[$1>>2]|0;
   $378 = ((($377)) + -12|0);
   $379 = HEAP32[$378>>2]|0;
   $380 = (($1) + ($379)|0);
   $381 = ((($380)) + 12|0);
   HEAP32[$381>>2] = 12;
   $382 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($1,114999,11)|0);
   $383 = HEAP32[$382>>2]|0;
   $384 = ((($383)) + -12|0);
   $385 = HEAP32[$384>>2]|0;
   $386 = (($382) + ($385)|0);
   $387 = ((($386)) + 12|0);
   HEAP32[$387>>2] = 10;
   $388 = ((($0)) + 100|0);
   $389 = HEAP32[$388>>2]|0;
   $390 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($382,$389)|0);
   $391 = HEAP32[$390>>2]|0;
   $392 = ((($391)) + -12|0);
   $393 = HEAP32[$392>>2]|0;
   $394 = (($390) + ($393)|0);
   $395 = ((($394)) + 12|0);
   HEAP32[$395>>2] = 10;
   $396 = ((($0)) + 56|0);
   $397 = HEAP32[$396>>2]|0;
   $398 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($390,$397)|0);
   $399 = HEAP32[$398>>2]|0;
   $400 = ((($399)) + -12|0);
   $401 = HEAP32[$400>>2]|0;
   $402 = (($398) + ($401)|0);
   __ZNKSt3__28ios_base6getlocEv($8,$402);
   __THREW__ = 0;
   $403 = (invoke_iii(3255,($8|0),(215188|0))|0);
   $404 = __THREW__; __THREW__ = 0;
   $405 = $404&1;
   if (!($405)) {
    $406 = HEAP32[$403>>2]|0;
    $407 = ((($406)) + 28|0);
    $408 = HEAP32[$407>>2]|0;
    __THREW__ = 0;
    $409 = (invoke_iii($408|0,($403|0),10)|0);
    $410 = __THREW__; __THREW__ = 0;
    $411 = $410&1;
    if (!($411)) {
     __ZNSt3__26localeD2Ev($8);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($398,$409)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($398)|0);
     $418 = HEAP32[$1>>2]|0;
     $419 = ((($418)) + -12|0);
     $420 = HEAP32[$419>>2]|0;
     $421 = (($1) + ($420)|0);
     $422 = ((($421)) + 12|0);
     HEAP32[$422>>2] = 12;
     $423 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($1,115011,11)|0);
     $424 = HEAP32[$423>>2]|0;
     $425 = ((($424)) + -12|0);
     $426 = HEAP32[$425>>2]|0;
     $427 = (($423) + ($426)|0);
     $428 = ((($427)) + 12|0);
     HEAP32[$428>>2] = 10;
     $429 = ((($0)) + 112|0);
     $430 = HEAP32[$429>>2]|0;
     $431 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($423,$430)|0);
     $432 = HEAP32[$431>>2]|0;
     $433 = ((($432)) + -12|0);
     $434 = HEAP32[$433>>2]|0;
     $435 = (($431) + ($434)|0);
     $436 = ((($435)) + 12|0);
     HEAP32[$436>>2] = 10;
     $437 = ((($0)) + 68|0);
     $438 = HEAP32[$437>>2]|0;
     $439 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($431,$438)|0);
     $440 = HEAP32[$439>>2]|0;
     $441 = ((($440)) + -12|0);
     $442 = HEAP32[$441>>2]|0;
     $443 = (($439) + ($442)|0);
     __ZNKSt3__28ios_base6getlocEv($7,$443);
     __THREW__ = 0;
     $444 = (invoke_iii(3255,($7|0),(215188|0))|0);
     $445 = __THREW__; __THREW__ = 0;
     $446 = $445&1;
     if (!($446)) {
      $447 = HEAP32[$444>>2]|0;
      $448 = ((($447)) + 28|0);
      $449 = HEAP32[$448>>2]|0;
      __THREW__ = 0;
      $450 = (invoke_iii($449|0,($444|0),10)|0);
      $451 = __THREW__; __THREW__ = 0;
      $452 = $451&1;
      if (!($452)) {
       __ZNSt3__26localeD2Ev($7);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($439,$450)|0);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($439)|0);
       $459 = HEAP32[$1>>2]|0;
       $460 = ((($459)) + -12|0);
       $461 = HEAP32[$460>>2]|0;
       $462 = (($1) + ($461)|0);
       $463 = ((($462)) + 12|0);
       HEAP32[$463>>2] = 12;
       $464 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($1,115023,11)|0);
       $465 = HEAP32[$464>>2]|0;
       $466 = ((($465)) + -12|0);
       $467 = HEAP32[$466>>2]|0;
       $468 = (($464) + ($467)|0);
       $469 = ((($468)) + 12|0);
       HEAP32[$469>>2] = 10;
       $470 = ((($0)) + 124|0);
       $471 = HEAP32[$470>>2]|0;
       $472 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($464,$471)|0);
       $473 = HEAP32[$472>>2]|0;
       $474 = ((($473)) + -12|0);
       $475 = HEAP32[$474>>2]|0;
       $476 = (($472) + ($475)|0);
       $477 = ((($476)) + 12|0);
       HEAP32[$477>>2] = 10;
       $478 = ((($0)) + 64|0);
       $479 = HEAP32[$478>>2]|0;
       $480 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($472,$479)|0);
       $481 = HEAP32[$480>>2]|0;
       $482 = ((($481)) + -12|0);
       $483 = HEAP32[$482>>2]|0;
       $484 = (($480) + ($483)|0);
       __ZNKSt3__28ios_base6getlocEv($6,$484);
       __THREW__ = 0;
       $485 = (invoke_iii(3255,($6|0),(215188|0))|0);
       $486 = __THREW__; __THREW__ = 0;
       $487 = $486&1;
       if (!($487)) {
        $488 = HEAP32[$485>>2]|0;
        $489 = ((($488)) + 28|0);
        $490 = HEAP32[$489>>2]|0;
        __THREW__ = 0;
        $491 = (invoke_iii($490|0,($485|0),10)|0);
        $492 = __THREW__; __THREW__ = 0;
        $493 = $492&1;
        if (!($493)) {
         __ZNSt3__26localeD2Ev($6);
         (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($480,$491)|0);
         (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($480)|0);
         $500 = HEAP32[$1>>2]|0;
         $501 = ((($500)) + -12|0);
         $502 = HEAP32[$501>>2]|0;
         $503 = (($1) + ($502)|0);
         $504 = ((($503)) + 12|0);
         HEAP32[$504>>2] = 12;
         $505 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($1,115035,11)|0);
         $506 = HEAP32[$505>>2]|0;
         $507 = ((($506)) + -12|0);
         $508 = HEAP32[$507>>2]|0;
         $509 = (($505) + ($508)|0);
         $510 = ((($509)) + 12|0);
         HEAP32[$510>>2] = 10;
         $511 = ((($0)) + 136|0);
         $512 = HEAP32[$511>>2]|0;
         $513 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($505,$512)|0);
         $514 = HEAP32[$513>>2]|0;
         $515 = ((($514)) + -12|0);
         $516 = HEAP32[$515>>2]|0;
         $517 = (($513) + ($516)|0);
         $518 = ((($517)) + 12|0);
         HEAP32[$518>>2] = 10;
         $519 = ((($0)) + 60|0);
         $520 = HEAP32[$519>>2]|0;
         $521 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($513,$520)|0);
         $522 = HEAP32[$521>>2]|0;
         $523 = ((($522)) + -12|0);
         $524 = HEAP32[$523>>2]|0;
         $525 = (($521) + ($524)|0);
         __ZNKSt3__28ios_base6getlocEv($5,$525);
         __THREW__ = 0;
         $526 = (invoke_iii(3255,($5|0),(215188|0))|0);
         $527 = __THREW__; __THREW__ = 0;
         $528 = $527&1;
         do {
          if (!($528)) {
           $529 = HEAP32[$526>>2]|0;
           $530 = ((($529)) + 28|0);
           $531 = HEAP32[$530>>2]|0;
           __THREW__ = 0;
           $532 = (invoke_iii($531|0,($526|0),10)|0);
           $533 = __THREW__; __THREW__ = 0;
           $534 = $533&1;
           if ($534) {
            break;
           }
           __ZNSt3__26localeD2Ev($5);
           (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($521,$532)|0);
           (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($521)|0);
           $541 = HEAP32[$1>>2]|0;
           $542 = ((($541)) + -12|0);
           $543 = HEAP32[$542>>2]|0;
           $544 = (($1) + ($543)|0);
           $545 = ((($544)) + 12|0);
           HEAP32[$545>>2] = 12;
           $546 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($1,115047,11)|0);
           $547 = HEAP32[$546>>2]|0;
           $548 = ((($547)) + -12|0);
           $549 = HEAP32[$548>>2]|0;
           $550 = (($546) + ($549)|0);
           $551 = ((($550)) + 12|0);
           HEAP32[$551>>2] = 10;
           $552 = ((($0)) + 148|0);
           $553 = HEAP32[$552>>2]|0;
           $554 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($546,$553)|0);
           $555 = HEAP32[$554>>2]|0;
           $556 = ((($555)) + -12|0);
           $557 = HEAP32[$556>>2]|0;
           $558 = (($554) + ($557)|0);
           $559 = ((($558)) + 12|0);
           HEAP32[$559>>2] = 10;
           $560 = ((($0)) + 72|0);
           $561 = HEAP32[$560>>2]|0;
           $562 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($554,$561)|0);
           $563 = HEAP32[$562>>2]|0;
           $564 = ((($563)) + -12|0);
           $565 = HEAP32[$564>>2]|0;
           $566 = (($562) + ($565)|0);
           __ZNKSt3__28ios_base6getlocEv($4,$566);
           __THREW__ = 0;
           $567 = (invoke_iii(3255,($4|0),(215188|0))|0);
           $568 = __THREW__; __THREW__ = 0;
           $569 = $568&1;
           do {
            if (!($569)) {
             $570 = HEAP32[$567>>2]|0;
             $571 = ((($570)) + 28|0);
             $572 = HEAP32[$571>>2]|0;
             __THREW__ = 0;
             $573 = (invoke_iii($572|0,($567|0),10)|0);
             $574 = __THREW__; __THREW__ = 0;
             $575 = $574&1;
             if ($575) {
              break;
             }
             __ZNSt3__26localeD2Ev($4);
             (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($562,$573)|0);
             (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($562)|0);
             $582 = HEAP32[$1>>2]|0;
             $583 = ((($582)) + -12|0);
             $584 = HEAP32[$583>>2]|0;
             $585 = (($1) + ($584)|0);
             $586 = ((($585)) + 12|0);
             HEAP32[$586>>2] = 12;
             $587 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($1,115059,11)|0);
             $588 = HEAP32[$587>>2]|0;
             $589 = ((($588)) + -12|0);
             $590 = HEAP32[$589>>2]|0;
             $591 = (($587) + ($590)|0);
             $592 = ((($591)) + 12|0);
             HEAP32[$592>>2] = 10;
             $593 = ((($0)) + 160|0);
             $594 = HEAP32[$593>>2]|0;
             $595 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($587,$594)|0);
             $596 = HEAP32[$595>>2]|0;
             $597 = ((($596)) + -12|0);
             $598 = HEAP32[$597>>2]|0;
             $599 = (($595) + ($598)|0);
             $600 = ((($599)) + 12|0);
             HEAP32[$600>>2] = 10;
             $601 = ((($0)) + 76|0);
             $602 = HEAP32[$601>>2]|0;
             $603 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($595,$602)|0);
             $604 = HEAP32[$603>>2]|0;
             $605 = ((($604)) + -12|0);
             $606 = HEAP32[$605>>2]|0;
             $607 = (($603) + ($606)|0);
             $608 = ((($607)) + 12|0);
             HEAP32[$608>>2] = 10;
             $609 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($603,$$0$lcssa)|0);
             $610 = HEAP32[$609>>2]|0;
             $611 = ((($610)) + -12|0);
             $612 = HEAP32[$611>>2]|0;
             $613 = (($609) + ($612)|0);
             __ZNKSt3__28ios_base6getlocEv($3,$613);
             __THREW__ = 0;
             $614 = (invoke_iii(3255,($3|0),(215188|0))|0);
             $615 = __THREW__; __THREW__ = 0;
             $616 = $615&1;
             do {
              if (!($616)) {
               $617 = HEAP32[$614>>2]|0;
               $618 = ((($617)) + 28|0);
               $619 = HEAP32[$618>>2]|0;
               __THREW__ = 0;
               $620 = (invoke_iii($619|0,($614|0),10)|0);
               $621 = __THREW__; __THREW__ = 0;
               $622 = $621&1;
               if ($622) {
                break;
               }
               __ZNSt3__26localeD2Ev($3);
               (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($609,$620)|0);
               (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($609)|0);
               $629 = HEAP32[$1>>2]|0;
               $630 = ((($629)) + -12|0);
               $631 = HEAP32[$630>>2]|0;
               $632 = (($1) + ($631)|0);
               $633 = ((($632)) + 12|0);
               HEAP32[$633>>2] = 12;
               $634 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($1,115071,11)|0);
               $635 = HEAP32[$634>>2]|0;
               $636 = ((($635)) + -12|0);
               $637 = HEAP32[$636>>2]|0;
               $638 = (($634) + ($637)|0);
               $639 = ((($638)) + 12|0);
               HEAP32[$639>>2] = 10;
               $640 = ((($0)) + 172|0);
               $641 = HEAP32[$640>>2]|0;
               $642 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($634,$641)|0);
               $643 = HEAP32[$642>>2]|0;
               $644 = ((($643)) + -12|0);
               $645 = HEAP32[$644>>2]|0;
               $646 = (($642) + ($645)|0);
               $647 = ((($646)) + 12|0);
               HEAP32[$647>>2] = 10;
               $648 = ((($0)) + 80|0);
               $649 = HEAP32[$648>>2]|0;
               $650 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($642,$649)|0);
               $651 = HEAP32[$650>>2]|0;
               $652 = ((($651)) + -12|0);
               $653 = HEAP32[$652>>2]|0;
               $654 = (($650) + ($653)|0);
               __ZNKSt3__28ios_base6getlocEv($2,$654);
               __THREW__ = 0;
               $655 = (invoke_iii(3255,($2|0),(215188|0))|0);
               $656 = __THREW__; __THREW__ = 0;
               $657 = $656&1;
               do {
                if (!($657)) {
                 $658 = HEAP32[$655>>2]|0;
                 $659 = ((($658)) + 28|0);
                 $660 = HEAP32[$659>>2]|0;
                 __THREW__ = 0;
                 $661 = (invoke_iii($660|0,($655|0),10)|0);
                 $662 = __THREW__; __THREW__ = 0;
                 $663 = $662&1;
                 if ($663) {
                  break;
                 }
                 __ZNSt3__26localeD2Ev($2);
                 (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($650,$661)|0);
                 (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($650)|0);
                 $670 = HEAP32[$1>>2]|0;
                 $671 = ((($670)) + -12|0);
                 $672 = HEAP32[$671>>2]|0;
                 $673 = (($1) + ($672)|0);
                 $674 = ((($673)) + 12|0);
                 HEAP32[$674>>2] = 12;
                 $675 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($1,115083,11)|0);
                 $676 = HEAP32[$675>>2]|0;
                 $677 = ((($676)) + -12|0);
                 $678 = HEAP32[$677>>2]|0;
                 $679 = (($675) + ($678)|0);
                 $680 = ((($679)) + 12|0);
                 HEAP32[$680>>2] = 10;
                 $681 = ((($0)) + 184|0);
                 $682 = HEAP32[$681>>2]|0;
                 $683 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($675,$682)|0);
                 $684 = HEAP32[$683>>2]|0;
                 $685 = ((($684)) + -12|0);
                 $686 = HEAP32[$685>>2]|0;
                 $687 = (($683) + ($686)|0);
                 $688 = ((($687)) + 12|0);
                 HEAP32[$688>>2] = 10;
                 $689 = ((($0)) + 84|0);
                 $690 = HEAP32[$689>>2]|0;
                 $691 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($683,$690)|0);
                 $692 = HEAP32[$691>>2]|0;
                 $693 = ((($692)) + -12|0);
                 $694 = HEAP32[$693>>2]|0;
                 $695 = (($691) + ($694)|0);
                 __ZNKSt3__28ios_base6getlocEv($16,$695);
                 __THREW__ = 0;
                 $696 = (invoke_iii(3255,($16|0),(215188|0))|0);
                 $697 = __THREW__; __THREW__ = 0;
                 $698 = $697&1;
                 do {
                  if (!($698)) {
                   $699 = HEAP32[$696>>2]|0;
                   $700 = ((($699)) + 28|0);
                   $701 = HEAP32[$700>>2]|0;
                   __THREW__ = 0;
                   $702 = (invoke_iii($701|0,($696|0),10)|0);
                   $703 = __THREW__; __THREW__ = 0;
                   $704 = $703&1;
                   if ($704) {
                    break;
                   }
                   __ZNSt3__26localeD2Ev($16);
                   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($691,$702)|0);
                   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($691)|0);
                   $711 = HEAP32[$1>>2]|0;
                   $712 = ((($711)) + -12|0);
                   $713 = HEAP32[$712>>2]|0;
                   $714 = (($1) + ($713)|0);
                   $715 = ((($714)) + 12|0);
                   HEAP32[$715>>2] = 12;
                   $716 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($1,115095,11)|0);
                   $717 = HEAP32[$716>>2]|0;
                   $718 = ((($717)) + -12|0);
                   $719 = HEAP32[$718>>2]|0;
                   $720 = (($716) + ($719)|0);
                   $721 = ((($720)) + 12|0);
                   HEAP32[$721>>2] = 10;
                   $722 = ((($0)) + 248|0);
                   $723 = HEAP32[$722>>2]|0;
                   $724 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($716,$723)|0);
                   $725 = HEAP32[$724>>2]|0;
                   $726 = ((($725)) + -12|0);
                   $727 = HEAP32[$726>>2]|0;
                   $728 = (($724) + ($727)|0);
                   $729 = ((($728)) + 12|0);
                   HEAP32[$729>>2] = 10;
                   $730 = ((($0)) + 336|0);
                   $731 = HEAP32[$730>>2]|0;
                   $732 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($724,$731)|0);
                   $733 = HEAP32[$732>>2]|0;
                   $734 = ((($733)) + -12|0);
                   $735 = HEAP32[$734>>2]|0;
                   $736 = (($732) + ($735)|0);
                   __ZNKSt3__28ios_base6getlocEv($17,$736);
                   __THREW__ = 0;
                   $737 = (invoke_iii(3255,($17|0),(215188|0))|0);
                   $738 = __THREW__; __THREW__ = 0;
                   $739 = $738&1;
                   do {
                    if (!($739)) {
                     $740 = HEAP32[$737>>2]|0;
                     $741 = ((($740)) + 28|0);
                     $742 = HEAP32[$741>>2]|0;
                     __THREW__ = 0;
                     $743 = (invoke_iii($742|0,($737|0),10)|0);
                     $744 = __THREW__; __THREW__ = 0;
                     $745 = $744&1;
                     if ($745) {
                      break;
                     }
                     __ZNSt3__26localeD2Ev($17);
                     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($732,$743)|0);
                     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($732)|0);
                     $752 = HEAP32[$1>>2]|0;
                     $753 = ((($752)) + -12|0);
                     $754 = HEAP32[$753>>2]|0;
                     $755 = (($1) + ($754)|0);
                     $756 = ((($755)) + 12|0);
                     HEAP32[$756>>2] = 12;
                     $757 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($1,115107,11)|0);
                     $758 = HEAP32[$757>>2]|0;
                     $759 = ((($758)) + -12|0);
                     $760 = HEAP32[$759>>2]|0;
                     $761 = (($757) + ($760)|0);
                     $762 = ((($761)) + 12|0);
                     HEAP32[$762>>2] = 10;
                     $763 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($757,$$054$lcssa)|0);
                     $764 = HEAP32[$763>>2]|0;
                     $765 = ((($764)) + -12|0);
                     $766 = HEAP32[$765>>2]|0;
                     $767 = (($763) + ($766)|0);
                     $768 = ((($767)) + 12|0);
                     HEAP32[$768>>2] = 10;
                     $769 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($763,$$055$lcssa)|0);
                     $770 = HEAP32[$769>>2]|0;
                     $771 = ((($770)) + -12|0);
                     $772 = HEAP32[$771>>2]|0;
                     $773 = (($769) + ($772)|0);
                     __ZNKSt3__28ios_base6getlocEv($18,$773);
                     __THREW__ = 0;
                     $774 = (invoke_iii(3255,($18|0),(215188|0))|0);
                     $775 = __THREW__; __THREW__ = 0;
                     $776 = $775&1;
                     do {
                      if (!($776)) {
                       $777 = HEAP32[$774>>2]|0;
                       $778 = ((($777)) + 28|0);
                       $779 = HEAP32[$778>>2]|0;
                       __THREW__ = 0;
                       $780 = (invoke_iii($779|0,($774|0),10)|0);
                       $781 = __THREW__; __THREW__ = 0;
                       $782 = $781&1;
                       if ($782) {
                        break;
                       }
                       __ZNSt3__26localeD2Ev($18);
                       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($769,$780)|0);
                       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($769)|0);
                       STACKTOP = sp;return;
                      }
                     } while(0);
                     $783 = ___cxa_find_matching_catch_2()|0;
                     $784 = tempRet0;
                     __THREW__ = 0;
                     invoke_vi(3263,($18|0));
                     $785 = __THREW__; __THREW__ = 0;
                     $786 = $785&1;
                     if ($786) {
                      $787 = ___cxa_find_matching_catch_3(0|0)|0;
                      $788 = tempRet0;
                      ___clang_call_terminate($787);
                      // unreachable;
                     } else {
                      ___resumeException($783|0);
                      // unreachable;
                     }
                    }
                   } while(0);
                   $746 = ___cxa_find_matching_catch_2()|0;
                   $747 = tempRet0;
                   __THREW__ = 0;
                   invoke_vi(3263,($17|0));
                   $748 = __THREW__; __THREW__ = 0;
                   $749 = $748&1;
                   if ($749) {
                    $750 = ___cxa_find_matching_catch_3(0|0)|0;
                    $751 = tempRet0;
                    ___clang_call_terminate($750);
                    // unreachable;
                   } else {
                    ___resumeException($746|0);
                    // unreachable;
                   }
                  }
                 } while(0);
                 $705 = ___cxa_find_matching_catch_2()|0;
                 $706 = tempRet0;
                 __THREW__ = 0;
                 invoke_vi(3263,($16|0));
                 $707 = __THREW__; __THREW__ = 0;
                 $708 = $707&1;
                 if ($708) {
                  $709 = ___cxa_find_matching_catch_3(0|0)|0;
                  $710 = tempRet0;
                  ___clang_call_terminate($709);
                  // unreachable;
                 } else {
                  ___resumeException($705|0);
                  // unreachable;
                 }
                }
               } while(0);
               $664 = ___cxa_find_matching_catch_2()|0;
               $665 = tempRet0;
               __THREW__ = 0;
               invoke_vi(3263,($2|0));
               $666 = __THREW__; __THREW__ = 0;
               $667 = $666&1;
               if ($667) {
                $668 = ___cxa_find_matching_catch_3(0|0)|0;
                $669 = tempRet0;
                ___clang_call_terminate($668);
                // unreachable;
               } else {
                ___resumeException($664|0);
                // unreachable;
               }
              }
             } while(0);
             $623 = ___cxa_find_matching_catch_2()|0;
             $624 = tempRet0;
             __THREW__ = 0;
             invoke_vi(3263,($3|0));
             $625 = __THREW__; __THREW__ = 0;
             $626 = $625&1;
             if ($626) {
              $627 = ___cxa_find_matching_catch_3(0|0)|0;
              $628 = tempRet0;
              ___clang_call_terminate($627);
              // unreachable;
             } else {
              ___resumeException($623|0);
              // unreachable;
             }
            }
           } while(0);
           $576 = ___cxa_find_matching_catch_2()|0;
           $577 = tempRet0;
           __THREW__ = 0;
           invoke_vi(3263,($4|0));
           $578 = __THREW__; __THREW__ = 0;
           $579 = $578&1;
           if ($579) {
            $580 = ___cxa_find_matching_catch_3(0|0)|0;
            $581 = tempRet0;
            ___clang_call_terminate($580);
            // unreachable;
           } else {
            ___resumeException($576|0);
            // unreachable;
           }
          }
         } while(0);
         $535 = ___cxa_find_matching_catch_2()|0;
         $536 = tempRet0;
         __THREW__ = 0;
         invoke_vi(3263,($5|0));
         $537 = __THREW__; __THREW__ = 0;
         $538 = $537&1;
         if ($538) {
          $539 = ___cxa_find_matching_catch_3(0|0)|0;
          $540 = tempRet0;
          ___clang_call_terminate($539);
          // unreachable;
         } else {
          ___resumeException($535|0);
          // unreachable;
         }
        }
       }
       $494 = ___cxa_find_matching_catch_2()|0;
       $495 = tempRet0;
       __THREW__ = 0;
       invoke_vi(3263,($6|0));
       $496 = __THREW__; __THREW__ = 0;
       $497 = $496&1;
       if ($497) {
        $498 = ___cxa_find_matching_catch_3(0|0)|0;
        $499 = tempRet0;
        ___clang_call_terminate($498);
        // unreachable;
       } else {
        ___resumeException($494|0);
        // unreachable;
       }
      }
     }
     $453 = ___cxa_find_matching_catch_2()|0;
     $454 = tempRet0;
     __THREW__ = 0;
     invoke_vi(3263,($7|0));
     $455 = __THREW__; __THREW__ = 0;
     $456 = $455&1;
     if ($456) {
      $457 = ___cxa_find_matching_catch_3(0|0)|0;
      $458 = tempRet0;
      ___clang_call_terminate($457);
      // unreachable;
     } else {
      ___resumeException($453|0);
      // unreachable;
     }
    }
   }
   $412 = ___cxa_find_matching_catch_2()|0;
   $413 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($8|0));
   $414 = __THREW__; __THREW__ = 0;
   $415 = $414&1;
   if ($415) {
    $416 = ___cxa_find_matching_catch_3(0|0)|0;
    $417 = tempRet0;
    ___clang_call_terminate($416);
    // unreachable;
   } else {
    ___resumeException($412|0);
    // unreachable;
   }
  }
 }
 $306 = ___cxa_find_matching_catch_2()|0;
 $307 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($11|0));
 $308 = __THREW__; __THREW__ = 0;
 $309 = $308&1;
 if ($309) {
  $310 = ___cxa_find_matching_catch_3(0|0)|0;
  $311 = tempRet0;
  ___clang_call_terminate($310);
  // unreachable;
 } else {
  ___resumeException($306|0);
  // unreachable;
 }
}
function __ZTv0_n16_N7osgUtil12StatsVisitorD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __THREW__ = 0;
 invoke_vii(3453,($4|0),(50840|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if (!($6)) {
  $14 = ((($4)) + 376|0);
  __ZN3osg6ObjectD2Ev($14);
  return;
 }
 $7 = ___cxa_find_matching_catch_2()|0;
 $8 = tempRet0;
 $9 = ((($4)) + 376|0);
 __THREW__ = 0;
 invoke_vi(388,($9|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if ($11) {
  $12 = ___cxa_find_matching_catch_3(0|0)|0;
  $13 = tempRet0;
  ___clang_call_terminate($12);
  // unreachable;
 } else {
  ___resumeException($7|0);
  // unreachable;
 }
}
function __ZTv0_n16_N7osgUtil12StatsVisitorD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$i$index2Z2D = 0, $eh$lpad$body$i$indexZ2D = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __THREW__ = 0;
 invoke_vii(3453,($4|0),(50840|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $10 = ___cxa_find_matching_catch_2()|0;
  $11 = tempRet0;
  $12 = ((($4)) + 376|0);
  __THREW__ = 0;
  invoke_vi(388,($12|0));
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if ($14) {
   $15 = ___cxa_find_matching_catch_3(0|0)|0;
   $16 = tempRet0;
   ___clang_call_terminate($15);
   // unreachable;
  } else {
   $eh$lpad$body$i$index2Z2D = $11;$eh$lpad$body$i$indexZ2D = $10;
   __ZdlPv($4);
   ___resumeException($eh$lpad$body$i$indexZ2D|0);
   // unreachable;
  }
 }
 $7 = ((($4)) + 376|0);
 __THREW__ = 0;
 invoke_vi(388,($7|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if (!($9)) {
  __ZdlPv($4);
  return;
 }
 $17 = ___cxa_find_matching_catch_2()|0;
 $18 = tempRet0;
 $eh$lpad$body$i$index2Z2D = $18;$eh$lpad$body$i$indexZ2D = $17;
 __ZdlPv($4);
 ___resumeException($eh$lpad$body$i$indexZ2D|0);
 // unreachable;
}
function __ZTv0_n32_NK7osgUtil12StatsVisitor11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (116801|0);
}
function __ZTv0_n36_NK7osgUtil12StatsVisitor9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (114884|0);
}
function __ZN7osgUtil10StatisticsC2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (50252);
 $1 = ((($0)) + 52|0);
 $2 = ((($0)) + 56|0);
 HEAP32[$2>>2] = 0;
 $3 = ((($0)) + 60|0);
 HEAP32[$3>>2] = 0;
 $4 = ((($0)) + 56|0);
 HEAP32[$1>>2] = $4;
 $5 = ((($0)) + 68|0);
 $6 = ((($0)) + 72|0);
 HEAP32[$6>>2] = 0;
 $7 = ((($0)) + 76|0);
 HEAP32[$7>>2] = 0;
 $8 = ((($0)) + 72|0);
 HEAP32[$5>>2] = $8;
 $9 = ((($0)) + 4|0);
 dest=$9; stop=dest+48|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 __ZNSt3__26__treeINS_12__value_typeIjNS_4pairIjjEEEENS_19__map_value_compareIjS4_NS_4lessIjEELb1EEENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($1,0);
 HEAP32[$3>>2] = 0;
 HEAP32[$1>>2] = $4;
 HEAP32[$4>>2] = 0;
 $10 = ((($0)) + 64|0);
 HEAP32[$10>>2] = 0;
 $11 = HEAP32[$8>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIjjEENS_19__map_value_compareIjS2_NS_4lessIjEELb1EEENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($5,$11);
 HEAP32[$7>>2] = 0;
 HEAP32[$5>>2] = $8;
 HEAP32[$8>>2] = 0;
 $12 = ((($0)) + 80|0);
 HEAP32[$12>>2] = 0;
 $13 = ((($0)) + 84|0);
 HEAP32[$13>>2] = 0;
 return;
}
function __ZN7osgUtil12StatsVisitorC1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 376|0);
 __ZN3osg10ReferencedC2Ev($1);
 HEAP32[$1>>2] = (63412);
 $2 = ((($0)) + 388|0);
 ;HEAP32[$2>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;
 $3 = ((($0)) + 400|0);
 HEAP32[$3>>2] = 2;
 $4 = ((($0)) + 404|0);
 HEAP32[$4>>2] = 0;
 __THREW__ = 0;
 invoke_viii(3283,($0|0),((50844)|0),2);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if (!($6)) {
  HEAP32[$0>>2] = (50344);
  HEAP32[$1>>2] = (50700);
  $7 = ((($0)) + 56|0);
  $8 = ((($0)) + 96|0);
  HEAP32[$8>>2] = 0;
  $9 = ((($0)) + 100|0);
  HEAP32[$9>>2] = 0;
  $10 = ((($0)) + 96|0);
  $11 = ((($0)) + 92|0);
  dest=$7; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
  HEAP32[$11>>2] = $10;
  $12 = ((($0)) + 108|0);
  HEAP32[$12>>2] = 0;
  $13 = ((($0)) + 112|0);
  HEAP32[$13>>2] = 0;
  $14 = ((($0)) + 108|0);
  $15 = ((($0)) + 104|0);
  HEAP32[$15>>2] = $14;
  $16 = ((($0)) + 120|0);
  HEAP32[$16>>2] = 0;
  $17 = ((($0)) + 124|0);
  HEAP32[$17>>2] = 0;
  $18 = ((($0)) + 120|0);
  $19 = ((($0)) + 116|0);
  HEAP32[$19>>2] = $18;
  $20 = ((($0)) + 132|0);
  HEAP32[$20>>2] = 0;
  $21 = ((($0)) + 136|0);
  HEAP32[$21>>2] = 0;
  $22 = ((($0)) + 132|0);
  $23 = ((($0)) + 128|0);
  HEAP32[$23>>2] = $22;
  $24 = ((($0)) + 144|0);
  HEAP32[$24>>2] = 0;
  $25 = ((($0)) + 148|0);
  HEAP32[$25>>2] = 0;
  $26 = ((($0)) + 144|0);
  $27 = ((($0)) + 140|0);
  HEAP32[$27>>2] = $26;
  $28 = ((($0)) + 156|0);
  HEAP32[$28>>2] = 0;
  $29 = ((($0)) + 160|0);
  HEAP32[$29>>2] = 0;
  $30 = ((($0)) + 156|0);
  $31 = ((($0)) + 152|0);
  HEAP32[$31>>2] = $30;
  $32 = ((($0)) + 168|0);
  HEAP32[$32>>2] = 0;
  $33 = ((($0)) + 172|0);
  HEAP32[$33>>2] = 0;
  $34 = ((($0)) + 168|0);
  $35 = ((($0)) + 164|0);
  HEAP32[$35>>2] = $34;
  $36 = ((($0)) + 180|0);
  HEAP32[$36>>2] = 0;
  $37 = ((($0)) + 184|0);
  HEAP32[$37>>2] = 0;
  $38 = ((($0)) + 180|0);
  $39 = ((($0)) + 176|0);
  HEAP32[$39>>2] = $38;
  $40 = ((($0)) + 192|0);
  HEAP32[$40>>2] = 0;
  $41 = ((($0)) + 196|0);
  HEAP32[$41>>2] = 0;
  $42 = ((($0)) + 192|0);
  $43 = ((($0)) + 188|0);
  HEAP32[$43>>2] = $42;
  $44 = ((($0)) + 200|0);
  HEAP32[$44>>2] = (50252);
  $45 = ((($0)) + 260|0);
  $46 = ((($0)) + 256|0);
  $47 = ((($0)) + 252|0);
  $48 = ((($0)) + 268|0);
  $49 = ((($0)) + 272|0);
  HEAP32[$49>>2] = 0;
  $50 = ((($0)) + 276|0);
  HEAP32[$50>>2] = 0;
  $51 = ((($0)) + 272|0);
  HEAP32[$48>>2] = $51;
  $52 = ((($0)) + 204|0);
  dest=$52; stop=dest+48|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
  HEAP32[$45>>2] = 0;
  HEAP32[$47>>2] = $46;
  HEAP32[$46>>2] = 0;
  $53 = ((($0)) + 264|0);
  HEAP32[$53>>2] = 0;
  __ZNSt3__26__treeINS_12__value_typeIjjEENS_19__map_value_compareIjS2_NS_4lessIjEELb1EEENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($48,0);
  HEAP32[$50>>2] = 0;
  HEAP32[$48>>2] = $51;
  HEAP32[$51>>2] = 0;
  $54 = ((($0)) + 280|0);
  HEAP32[$54>>2] = 0;
  $55 = ((($0)) + 284|0);
  HEAP32[$55>>2] = 0;
  $56 = ((($0)) + 288|0);
  HEAP32[$56>>2] = (50252);
  $57 = ((($0)) + 348|0);
  $58 = ((($0)) + 344|0);
  $59 = ((($0)) + 340|0);
  $60 = ((($0)) + 356|0);
  $61 = ((($0)) + 360|0);
  HEAP32[$61>>2] = 0;
  $62 = ((($0)) + 364|0);
  HEAP32[$62>>2] = 0;
  $63 = ((($0)) + 360|0);
  HEAP32[$60>>2] = $63;
  $64 = ((($0)) + 292|0);
  dest=$64; stop=dest+48|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
  HEAP32[$57>>2] = 0;
  HEAP32[$59>>2] = $58;
  HEAP32[$58>>2] = 0;
  $65 = ((($0)) + 352|0);
  HEAP32[$65>>2] = 0;
  __ZNSt3__26__treeINS_12__value_typeIjjEENS_19__map_value_compareIjS2_NS_4lessIjEELb1EEENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($60,0);
  HEAP32[$62>>2] = 0;
  HEAP32[$60>>2] = $63;
  HEAP32[$63>>2] = 0;
  $66 = ((($0)) + 368|0);
  HEAP32[$66>>2] = 0;
  $67 = ((($0)) + 372|0);
  HEAP32[$67>>2] = 0;
  return;
 }
 $68 = ___cxa_find_matching_catch_2()|0;
 $69 = tempRet0;
 __THREW__ = 0;
 invoke_vi(388,($1|0));
 $70 = __THREW__; __THREW__ = 0;
 $71 = $70&1;
 if ($71) {
  $72 = ___cxa_find_matching_catch_3(0|0)|0;
  $73 = tempRet0;
  ___clang_call_terminate($72);
  // unreachable;
 } else {
  ___resumeException($68|0);
  // unreachable;
 }
}
function __ZN3osg12ArrayVisitor5applyERNS_5ArrayE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN3osg12ArrayVisitor5applyERNS_13TemplateArrayINS_5Vec2bELNS_5Array4TypeE9ELi2ELi5120EEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN3osg12ArrayVisitor5applyERNS_13TemplateArrayINS_5Vec3bELNS_5Array4TypeE10ELi3ELi5120EEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN3osg12ArrayVisitor5applyERNS_13TemplateArrayINS_5Vec4bELNS_5Array4TypeE11ELi4ELi5120EEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN3osg12ArrayVisitor5applyERNS_13TemplateArrayINS_5Vec2sELNS_5Array4TypeE12ELi2ELi5122EEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN3osg12ArrayVisitor5applyERNS_13TemplateArrayINS_5Vec3sELNS_5Array4TypeE13ELi3ELi5122EEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN3osg12ArrayVisitor5applyERNS_13TemplateArrayINS_5Vec4sELNS_5Array4TypeE14ELi4ELi5122EEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN3osg12ArrayVisitor5applyERNS_13TemplateArrayINS_6Vec2ubELNS_5Array4TypeE18ELi2ELi5121EEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN3osg12ArrayVisitor5applyERNS_13TemplateArrayINS_6Vec3ubELNS_5Array4TypeE19ELi3ELi5121EEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN3osg12ArrayVisitor5applyERNS_13TemplateArrayINS_6Vec2usELNS_5Array4TypeE21ELi2ELi5123EEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN3osg12ArrayVisitor5applyERNS_13TemplateArrayINS_6Vec3usELNS_5Array4TypeE22ELi3ELi5123EEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN3osg12ArrayVisitor5applyERNS_13TemplateArrayINS_6Vec4usELNS_5Array4TypeE23ELi4ELi5123EEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZNSt3__26vectorIfNS_9allocatorIfEEE21__push_back_slow_pathIKfEEvRT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(1073741823);
 if ($8) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $9 = ((($0)) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) - ($4))|0;
 $12 = $11 >> 2;
 $13 = ($12>>>0)<(536870911);
 $14 = $11 >> 1;
 $15 = ($14>>>0)<($7>>>0);
 $$sroa$speculated$i = $15 ? $7 : $14;
 $$sroa$speculated$$i = $13 ? $$sroa$speculated$i : 1073741823;
 $16 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($16) {
   $26 = 0;
  } else {
   $17 = ($$sroa$speculated$$i>>>0)>(1073741823);
   if (!($17)) {
    $23 = $$sroa$speculated$$i << 2;
    $24 = (__Znwj($23)|0);
    $26 = $24;
    break;
   }
   $18 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($18|0),(204840|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if ($20) {
    $21 = ___cxa_find_matching_catch_2()|0;
    $22 = tempRet0;
    ___cxa_free_exception(($18|0));
    ___resumeException($21|0);
    // unreachable;
   } else {
    HEAP32[$18>>2] = (99824);
    ___cxa_throw(($18|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $25 = (($26) + ($6<<2)|0);
 $27 = (($26) + ($$sroa$speculated$$i<<2)|0);
 $28 = $27;
 $29 = HEAP32[$1>>2]|0;
 HEAP32[$25>>2] = $29;
 $30 = ((($25)) + 4|0);
 $31 = $30;
 $32 = (0 - ($6))|0;
 $33 = (($25) + ($32<<2)|0);
 $34 = $33;
 $35 = ($5|0)>(0);
 if ($35) {
  $36 = $4;
  _memcpy(($33|0),($36|0),($5|0))|0;
 }
 HEAP32[$0>>2] = $34;
 HEAP32[$2>>2] = $31;
 HEAP32[$9>>2] = $28;
 $37 = ($4|0)==(0);
 if ($37) {
  return;
 }
 $38 = $4;
 __ZdlPv($38);
 return;
}
function __ZNSt3__26vectorIiNS_9allocatorIiEEE21__push_back_slow_pathIKiEEvRT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(1073741823);
 if ($8) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $9 = ((($0)) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) - ($4))|0;
 $12 = $11 >> 2;
 $13 = ($12>>>0)<(536870911);
 $14 = $11 >> 1;
 $15 = ($14>>>0)<($7>>>0);
 $$sroa$speculated$i = $15 ? $7 : $14;
 $$sroa$speculated$$i = $13 ? $$sroa$speculated$i : 1073741823;
 $16 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($16) {
   $26 = 0;
  } else {
   $17 = ($$sroa$speculated$$i>>>0)>(1073741823);
   if (!($17)) {
    $23 = $$sroa$speculated$$i << 2;
    $24 = (__Znwj($23)|0);
    $26 = $24;
    break;
   }
   $18 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($18|0),(204840|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if ($20) {
    $21 = ___cxa_find_matching_catch_2()|0;
    $22 = tempRet0;
    ___cxa_free_exception(($18|0));
    ___resumeException($21|0);
    // unreachable;
   } else {
    HEAP32[$18>>2] = (99824);
    ___cxa_throw(($18|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $25 = (($26) + ($6<<2)|0);
 $27 = (($26) + ($$sroa$speculated$$i<<2)|0);
 $28 = $27;
 $29 = HEAP32[$1>>2]|0;
 HEAP32[$25>>2] = $29;
 $30 = ((($25)) + 4|0);
 $31 = $30;
 $32 = (0 - ($6))|0;
 $33 = (($25) + ($32<<2)|0);
 $34 = $33;
 $35 = ($5|0)>(0);
 if ($35) {
  $36 = $4;
  _memcpy(($33|0),($36|0),($5|0))|0;
 }
 HEAP32[$0>>2] = $34;
 HEAP32[$2>>2] = $31;
 HEAP32[$9>>2] = $28;
 $37 = ($4|0)==(0);
 if ($37) {
  return;
 }
 $38 = $4;
 __ZdlPv($38);
 return;
}
function __ZNSt3__26vectorIjNS_9allocatorIjEEE7reserveEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 $7 = ($6>>>0)<($1>>>0);
 if (!($7)) {
  return;
 }
 $8 = ((($0)) + 4|0);
 $9 = ($1>>>0)>(1073741823);
 if ($9) {
  $10 = (___cxa_allocate_exception(8)|0);
  __THREW__ = 0;
  invoke_vii(3366,($10|0),(204840|0));
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if ($12) {
   $13 = ___cxa_find_matching_catch_2()|0;
   $14 = tempRet0;
   ___cxa_free_exception(($10|0));
   ___resumeException($13|0);
   // unreachable;
  } else {
   HEAP32[$10>>2] = (99824);
   ___cxa_throw(($10|0),(34608|0),(3230|0));
   // unreachable;
  }
 }
 $15 = HEAP32[$8>>2]|0;
 $16 = (($15) - ($4))|0;
 $17 = $16 >> 2;
 $18 = $1 << 2;
 $19 = (__Znwj($18)|0);
 $20 = (($19) + ($17<<2)|0);
 $21 = $20;
 $22 = (($19) + ($1<<2)|0);
 $23 = $22;
 $24 = (0 - ($17))|0;
 $25 = (($20) + ($24<<2)|0);
 $26 = $25;
 $27 = ($16|0)>(0);
 if ($27) {
  $28 = $4;
  _memcpy(($25|0),($28|0),($16|0))|0;
 }
 HEAP32[$0>>2] = $26;
 HEAP32[$8>>2] = $21;
 HEAP32[$2>>2] = $23;
 $29 = ($4|0)==(0);
 if ($29) {
  return;
 }
 $30 = $4;
 __ZdlPv($30);
 return;
}
function __ZNSt3__26vectorItNS_9allocatorItEEE7reserveEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 1;
 $7 = ($6>>>0)<($1>>>0);
 if (!($7)) {
  return;
 }
 $8 = ((($0)) + 4|0);
 $9 = ($1|0)<(0);
 if ($9) {
  $10 = (___cxa_allocate_exception(8)|0);
  __THREW__ = 0;
  invoke_vii(3366,($10|0),(204840|0));
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if ($12) {
   $13 = ___cxa_find_matching_catch_2()|0;
   $14 = tempRet0;
   ___cxa_free_exception(($10|0));
   ___resumeException($13|0);
   // unreachable;
  } else {
   HEAP32[$10>>2] = (99824);
   ___cxa_throw(($10|0),(34608|0),(3230|0));
   // unreachable;
  }
 }
 $15 = HEAP32[$8>>2]|0;
 $16 = (($15) - ($4))|0;
 $17 = $16 >> 1;
 $18 = $1 << 1;
 $19 = (__Znwj($18)|0);
 $20 = (($19) + ($17<<1)|0);
 $21 = $20;
 $22 = (($19) + ($1<<1)|0);
 $23 = $22;
 $24 = (0 - ($17))|0;
 $25 = (($20) + ($24<<1)|0);
 $26 = $25;
 $27 = ($16|0)>(0);
 if ($27) {
  $28 = $4;
  _memcpy(($25|0),($28|0),($16|0))|0;
 }
 HEAP32[$0>>2] = $26;
 HEAP32[$8>>2] = $21;
 HEAP32[$2>>2] = $23;
 $29 = ($4|0)==(0);
 if ($29) {
  return;
 }
 $30 = $4;
 __ZdlPv($30);
 return;
}
function __ZN7osgUtil13UpdateVisitorD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vii(3284,($0|0),((51356)|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  $3 = ((($0)) + 56|0);
  __ZN3osg6ObjectD2Ev($3);
  return;
 }
 $4 = ___cxa_find_matching_catch_2()|0;
 $5 = tempRet0;
 $6 = ((($0)) + 56|0);
 __THREW__ = 0;
 invoke_vi(388,($6|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch_3(0|0)|0;
  $10 = tempRet0;
  ___clang_call_terminate($9);
  // unreachable;
 } else {
  ___resumeException($4|0);
  // unreachable;
 }
}
function __ZN7osgUtil13UpdateVisitorD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vii(3284,($0|0),((51356)|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $6 = ___cxa_find_matching_catch_2()|0;
  $7 = tempRet0;
  $8 = ((($0)) + 56|0);
  __THREW__ = 0;
  invoke_vi(388,($8|0));
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if ($10) {
   $11 = ___cxa_find_matching_catch_3(0|0)|0;
   $12 = tempRet0;
   ___clang_call_terminate($11);
   // unreachable;
  } else {
   $eh$lpad$body$index2Z2D = $7;$eh$lpad$body$indexZ2D = $6;
   __ZdlPv($0);
   ___resumeException($eh$lpad$body$indexZ2D|0);
   // unreachable;
  }
 }
 $3 = ((($0)) + 56|0);
 __THREW__ = 0;
 invoke_vi(388,($3|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  __ZdlPv($0);
  return;
 }
 $13 = ___cxa_find_matching_catch_2()|0;
 $14 = tempRet0;
 $eh$lpad$body$index2Z2D = $14;$eh$lpad$body$indexZ2D = $13;
 __ZdlPv($0);
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
}
function __ZNK7osgUtil13UpdateVisitor11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (116801|0);
}
function __ZNK7osgUtil13UpdateVisitor9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (115174|0);
}
function __ZN7osgUtil13UpdateVisitor15asUpdateVisitorEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ($0|0);
}
function __ZNK7osgUtil13UpdateVisitor15asUpdateVisitorEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ($0|0);
}
function __ZN7osgUtil13UpdateVisitor5resetEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN7osgUtil13UpdateVisitor5applyERN3osg8DrawableE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 84|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 do {
  if (!($4)) {
   $5 = HEAP32[$3>>2]|0;
   $6 = ((($5)) + 60|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = (FUNCTION_TABLE_ii[$7 & 8191]($3)|0);
   $9 = HEAP32[$3>>2]|0;
   $10 = ((($9)) + 36|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (FUNCTION_TABLE_ii[$11 & 8191]($3)|0);
   $13 = ($8|0)!=(0|0);
   if ($13) {
    $14 = HEAP32[$8>>2]|0;
    $15 = ((($14)) + 32|0);
    $16 = HEAP32[$15>>2]|0;
    FUNCTION_TABLE_viii[$16 & 8191]($8,$0,$1);
   }
   $17 = ($12|0)==(0|0);
   if (!($17)) {
    $18 = HEAP32[$12>>2]|0;
    $19 = ((($18)) + 32|0);
    $20 = HEAP32[$19>>2]|0;
    FUNCTION_TABLE_viii[$20 & 8191]($12,$1,$0);
    break;
   }
   if (!($13)) {
    $21 = HEAP32[$3>>2]|0;
    $22 = ((($21)) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = HEAP32[$0>>2]|0;
    $25 = ((($24)) + -12|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = (($0) + ($26)|0);
    (FUNCTION_TABLE_iiii[$23 & 8191]($3,$1,$27)|0);
   }
  }
 } while(0);
 $28 = ((($1)) + 120|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ($29|0)==(0|0);
 if ($30) {
  return;
 }
 $31 = ((($29)) + 144|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = ($32|0)==(0|0);
 if ($33) {
  $34 = ((($29)) + 148|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = ($35|0)==(0);
  if ($36) {
   return;
  }
 }
 __ZN3osg8StateSet18runUpdateCallbacksEPNS_11NodeVisitorE($29,$0);
 return;
}
function __ZN7osgUtil13UpdateVisitor5applyERN3osg4NodeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 120|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 do {
  if (!($4)) {
   $5 = ((($3)) + 144|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($6|0)==(0|0);
   if ($7) {
    $8 = ((($3)) + 148|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = ($9|0)==(0);
    if ($10) {
     break;
    }
   }
   __ZN3osg8StateSet18runUpdateCallbacksEPNS_11NodeVisitorE($3,$0);
  }
 } while(0);
 $11 = ((($1)) + 84|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0|0);
 if (!($13)) {
  $14 = HEAP32[$12>>2]|0;
  $15 = ((($14)) + 92|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = HEAP32[$0>>2]|0;
  $18 = ((($17)) + -12|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = (($0) + ($19)|0);
  (FUNCTION_TABLE_iiii[$16 & 8191]($12,$1,$20)|0);
  return;
 }
 $21 = ((($1)) + 88|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  return;
 }
 $24 = ((($0)) + 16|0);
 $25 = HEAP32[$24>>2]|0;
 switch ($25|0) {
 case 1:  {
  $26 = HEAP32[$1>>2]|0;
  $27 = ((($26)) + 192|0);
  $28 = HEAP32[$27>>2]|0;
  FUNCTION_TABLE_vii[$28 & 8191]($1,$0);
  return;
  break;
 }
 case 0:  {
  return;
  break;
 }
 default: {
  $29 = HEAP32[$1>>2]|0;
  $30 = ((($29)) + 196|0);
  $31 = HEAP32[$30>>2]|0;
  FUNCTION_TABLE_vii[$31 & 8191]($1,$0);
  return;
 }
 }
}
function __ZN7osgUtil13UpdateVisitor5applyERN3osg5GeodeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 120|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 do {
  if (!($4)) {
   $5 = ((($3)) + 144|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($6|0)==(0|0);
   if ($7) {
    $8 = ((($3)) + 148|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = ($9|0)==(0);
    if ($10) {
     break;
    }
   }
   __ZN3osg8StateSet18runUpdateCallbacksEPNS_11NodeVisitorE($3,$0);
  }
 } while(0);
 $11 = ((($1)) + 84|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0|0);
 if (!($13)) {
  $14 = HEAP32[$12>>2]|0;
  $15 = ((($14)) + 92|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = HEAP32[$0>>2]|0;
  $18 = ((($17)) + -12|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = (($0) + ($19)|0);
  (FUNCTION_TABLE_iiii[$16 & 8191]($12,$1,$20)|0);
  return;
 }
 $21 = ((($1)) + 88|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  return;
 }
 $24 = ((($0)) + 16|0);
 $25 = HEAP32[$24>>2]|0;
 switch ($25|0) {
 case 1:  {
  $26 = HEAP32[$1>>2]|0;
  $27 = ((($26)) + 192|0);
  $28 = HEAP32[$27>>2]|0;
  FUNCTION_TABLE_vii[$28 & 8191]($1,$0);
  return;
  break;
 }
 case 0:  {
  return;
  break;
 }
 default: {
  $29 = HEAP32[$1>>2]|0;
  $30 = ((($29)) + 196|0);
  $31 = HEAP32[$30>>2]|0;
  FUNCTION_TABLE_vii[$31 & 8191]($1,$0);
  return;
 }
 }
}
function __ZN7osgUtil13UpdateVisitor5applyERN3osg9BillboardE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 120|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 do {
  if (!($4)) {
   $5 = ((($3)) + 144|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($6|0)==(0|0);
   if ($7) {
    $8 = ((($3)) + 148|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = ($9|0)==(0);
    if ($10) {
     break;
    }
   }
   __ZN3osg8StateSet18runUpdateCallbacksEPNS_11NodeVisitorE($3,$0);
  }
 } while(0);
 $11 = ((($1)) + 84|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0|0);
 if (!($13)) {
  $14 = HEAP32[$12>>2]|0;
  $15 = ((($14)) + 92|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = HEAP32[$0>>2]|0;
  $18 = ((($17)) + -12|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = (($0) + ($19)|0);
  (FUNCTION_TABLE_iiii[$16 & 8191]($12,$1,$20)|0);
  return;
 }
 $21 = ((($1)) + 88|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  return;
 }
 $24 = ((($0)) + 16|0);
 $25 = HEAP32[$24>>2]|0;
 switch ($25|0) {
 case 1:  {
  $26 = HEAP32[$1>>2]|0;
  $27 = ((($26)) + 192|0);
  $28 = HEAP32[$27>>2]|0;
  FUNCTION_TABLE_vii[$28 & 8191]($1,$0);
  return;
  break;
 }
 case 0:  {
  return;
  break;
 }
 default: {
  $29 = HEAP32[$1>>2]|0;
  $30 = ((($29)) + 196|0);
  $31 = HEAP32[$30>>2]|0;
  FUNCTION_TABLE_vii[$31 & 8191]($1,$0);
  return;
 }
 }
}
function __ZN7osgUtil13UpdateVisitor5applyERN3osg5GroupE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 120|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 do {
  if (!($4)) {
   $5 = ((($3)) + 144|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($6|0)==(0|0);
   if ($7) {
    $8 = ((($3)) + 148|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = ($9|0)==(0);
    if ($10) {
     break;
    }
   }
   __ZN3osg8StateSet18runUpdateCallbacksEPNS_11NodeVisitorE($3,$0);
  }
 } while(0);
 $11 = ((($1)) + 84|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0|0);
 if (!($13)) {
  $14 = HEAP32[$12>>2]|0;
  $15 = ((($14)) + 92|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = HEAP32[$0>>2]|0;
  $18 = ((($17)) + -12|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = (($0) + ($19)|0);
  (FUNCTION_TABLE_iiii[$16 & 8191]($12,$1,$20)|0);
  return;
 }
 $21 = ((($1)) + 88|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  return;
 }
 $24 = ((($0)) + 16|0);
 $25 = HEAP32[$24>>2]|0;
 switch ($25|0) {
 case 1:  {
  $26 = HEAP32[$1>>2]|0;
  $27 = ((($26)) + 192|0);
  $28 = HEAP32[$27>>2]|0;
  FUNCTION_TABLE_vii[$28 & 8191]($1,$0);
  return;
  break;
 }
 case 0:  {
  return;
  break;
 }
 default: {
  $29 = HEAP32[$1>>2]|0;
  $30 = ((($29)) + 196|0);
  $31 = HEAP32[$30>>2]|0;
  FUNCTION_TABLE_vii[$31 & 8191]($1,$0);
  return;
 }
 }
}
function __ZN7osgUtil13UpdateVisitor5applyERN3osg10ProjectionE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 120|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 do {
  if (!($4)) {
   $5 = ((($3)) + 144|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($6|0)==(0|0);
   if ($7) {
    $8 = ((($3)) + 148|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = ($9|0)==(0);
    if ($10) {
     break;
    }
   }
   __ZN3osg8StateSet18runUpdateCallbacksEPNS_11NodeVisitorE($3,$0);
  }
 } while(0);
 $11 = ((($1)) + 84|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0|0);
 if (!($13)) {
  $14 = HEAP32[$12>>2]|0;
  $15 = ((($14)) + 92|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = HEAP32[$0>>2]|0;
  $18 = ((($17)) + -12|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = (($0) + ($19)|0);
  (FUNCTION_TABLE_iiii[$16 & 8191]($12,$1,$20)|0);
  return;
 }
 $21 = ((($1)) + 88|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  return;
 }
 $24 = ((($0)) + 16|0);
 $25 = HEAP32[$24>>2]|0;
 switch ($25|0) {
 case 1:  {
  $26 = HEAP32[$1>>2]|0;
  $27 = ((($26)) + 192|0);
  $28 = HEAP32[$27>>2]|0;
  FUNCTION_TABLE_vii[$28 & 8191]($1,$0);
  return;
  break;
 }
 case 0:  {
  return;
  break;
 }
 default: {
  $29 = HEAP32[$1>>2]|0;
  $30 = ((($29)) + 196|0);
  $31 = HEAP32[$30>>2]|0;
  FUNCTION_TABLE_vii[$31 & 8191]($1,$0);
  return;
 }
 }
}
function __ZN7osgUtil13UpdateVisitor5applyERN3osg11LightSourceE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 120|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 do {
  if (!($4)) {
   $5 = ((($3)) + 144|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($6|0)==(0|0);
   if ($7) {
    $8 = ((($3)) + 148|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = ($9|0)==(0);
    if ($10) {
     break;
    }
   }
   __ZN3osg8StateSet18runUpdateCallbacksEPNS_11NodeVisitorE($3,$0);
  }
 } while(0);
 $11 = ((($1)) + 84|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0|0);
 if (!($13)) {
  $14 = HEAP32[$12>>2]|0;
  $15 = ((($14)) + 92|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = HEAP32[$0>>2]|0;
  $18 = ((($17)) + -12|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = (($0) + ($19)|0);
  (FUNCTION_TABLE_iiii[$16 & 8191]($12,$1,$20)|0);
  return;
 }
 $21 = ((($1)) + 88|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  return;
 }
 $24 = ((($0)) + 16|0);
 $25 = HEAP32[$24>>2]|0;
 switch ($25|0) {
 case 1:  {
  $26 = HEAP32[$1>>2]|0;
  $27 = ((($26)) + 192|0);
  $28 = HEAP32[$27>>2]|0;
  FUNCTION_TABLE_vii[$28 & 8191]($1,$0);
  return;
  break;
 }
 case 0:  {
  return;
  break;
 }
 default: {
  $29 = HEAP32[$1>>2]|0;
  $30 = ((($29)) + 196|0);
  $31 = HEAP32[$30>>2]|0;
  FUNCTION_TABLE_vii[$31 & 8191]($1,$0);
  return;
 }
 }
}
function __ZN7osgUtil13UpdateVisitor5applyERN3osg9TransformE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 120|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 do {
  if (!($4)) {
   $5 = ((($3)) + 144|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($6|0)==(0|0);
   if ($7) {
    $8 = ((($3)) + 148|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = ($9|0)==(0);
    if ($10) {
     break;
    }
   }
   __ZN3osg8StateSet18runUpdateCallbacksEPNS_11NodeVisitorE($3,$0);
  }
 } while(0);
 $11 = ((($1)) + 84|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0|0);
 if (!($13)) {
  $14 = HEAP32[$12>>2]|0;
  $15 = ((($14)) + 92|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = HEAP32[$0>>2]|0;
  $18 = ((($17)) + -12|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = (($0) + ($19)|0);
  (FUNCTION_TABLE_iiii[$16 & 8191]($12,$1,$20)|0);
  return;
 }
 $21 = ((($1)) + 88|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  return;
 }
 $24 = ((($0)) + 16|0);
 $25 = HEAP32[$24>>2]|0;
 switch ($25|0) {
 case 1:  {
  $26 = HEAP32[$1>>2]|0;
  $27 = ((($26)) + 192|0);
  $28 = HEAP32[$27>>2]|0;
  FUNCTION_TABLE_vii[$28 & 8191]($1,$0);
  return;
  break;
 }
 case 0:  {
  return;
  break;
 }
 default: {
  $29 = HEAP32[$1>>2]|0;
  $30 = ((($29)) + 196|0);
  $31 = HEAP32[$30>>2]|0;
  FUNCTION_TABLE_vii[$31 & 8191]($1,$0);
  return;
 }
 }
}
function __ZN7osgUtil13UpdateVisitor5applyERN3osg6SwitchE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 120|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 do {
  if (!($4)) {
   $5 = ((($3)) + 144|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($6|0)==(0|0);
   if ($7) {
    $8 = ((($3)) + 148|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = ($9|0)==(0);
    if ($10) {
     break;
    }
   }
   __ZN3osg8StateSet18runUpdateCallbacksEPNS_11NodeVisitorE($3,$0);
  }
 } while(0);
 $11 = ((($1)) + 84|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0|0);
 if (!($13)) {
  $14 = HEAP32[$12>>2]|0;
  $15 = ((($14)) + 92|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = HEAP32[$0>>2]|0;
  $18 = ((($17)) + -12|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = (($0) + ($19)|0);
  (FUNCTION_TABLE_iiii[$16 & 8191]($12,$1,$20)|0);
  return;
 }
 $21 = ((($1)) + 88|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  return;
 }
 $24 = ((($0)) + 16|0);
 $25 = HEAP32[$24>>2]|0;
 switch ($25|0) {
 case 1:  {
  $26 = HEAP32[$1>>2]|0;
  $27 = ((($26)) + 192|0);
  $28 = HEAP32[$27>>2]|0;
  FUNCTION_TABLE_vii[$28 & 8191]($1,$0);
  return;
  break;
 }
 case 0:  {
  return;
  break;
 }
 default: {
  $29 = HEAP32[$1>>2]|0;
  $30 = ((($29)) + 196|0);
  $31 = HEAP32[$30>>2]|0;
  FUNCTION_TABLE_vii[$31 & 8191]($1,$0);
  return;
 }
 }
}
function __ZN7osgUtil13UpdateVisitor5applyERN3osg3LODE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 120|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 do {
  if (!($4)) {
   $5 = ((($3)) + 144|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($6|0)==(0|0);
   if ($7) {
    $8 = ((($3)) + 148|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = ($9|0)==(0);
    if ($10) {
     break;
    }
   }
   __ZN3osg8StateSet18runUpdateCallbacksEPNS_11NodeVisitorE($3,$0);
  }
 } while(0);
 $11 = ((($1)) + 84|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0|0);
 if (!($13)) {
  $14 = HEAP32[$12>>2]|0;
  $15 = ((($14)) + 92|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = HEAP32[$0>>2]|0;
  $18 = ((($17)) + -12|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = (($0) + ($19)|0);
  (FUNCTION_TABLE_iiii[$16 & 8191]($12,$1,$20)|0);
  return;
 }
 $21 = ((($1)) + 88|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  return;
 }
 $24 = ((($0)) + 16|0);
 $25 = HEAP32[$24>>2]|0;
 switch ($25|0) {
 case 1:  {
  $26 = HEAP32[$1>>2]|0;
  $27 = ((($26)) + 192|0);
  $28 = HEAP32[$27>>2]|0;
  FUNCTION_TABLE_vii[$28 & 8191]($1,$0);
  return;
  break;
 }
 case 0:  {
  return;
  break;
 }
 default: {
  $29 = HEAP32[$1>>2]|0;
  $30 = ((($29)) + 196|0);
  $31 = HEAP32[$30>>2]|0;
  FUNCTION_TABLE_vii[$31 & 8191]($1,$0);
  return;
 }
 }
}
function __ZN7osgUtil13UpdateVisitor5applyERN3osg12OccluderNodeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 120|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 do {
  if (!($4)) {
   $5 = ((($3)) + 144|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($6|0)==(0|0);
   if ($7) {
    $8 = ((($3)) + 148|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = ($9|0)==(0);
    if ($10) {
     break;
    }
   }
   __ZN3osg8StateSet18runUpdateCallbacksEPNS_11NodeVisitorE($3,$0);
  }
 } while(0);
 $11 = ((($1)) + 84|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0|0);
 if (!($13)) {
  $14 = HEAP32[$12>>2]|0;
  $15 = ((($14)) + 92|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = HEAP32[$0>>2]|0;
  $18 = ((($17)) + -12|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = (($0) + ($19)|0);
  (FUNCTION_TABLE_iiii[$16 & 8191]($12,$1,$20)|0);
  return;
 }
 $21 = ((($1)) + 88|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  return;
 }
 $24 = ((($0)) + 16|0);
 $25 = HEAP32[$24>>2]|0;
 switch ($25|0) {
 case 1:  {
  $26 = HEAP32[$1>>2]|0;
  $27 = ((($26)) + 192|0);
  $28 = HEAP32[$27>>2]|0;
  FUNCTION_TABLE_vii[$28 & 8191]($1,$0);
  return;
  break;
 }
 case 0:  {
  return;
  break;
 }
 default: {
  $29 = HEAP32[$1>>2]|0;
  $30 = ((($29)) + 196|0);
  $31 = HEAP32[$30>>2]|0;
  FUNCTION_TABLE_vii[$31 & 8191]($1,$0);
  return;
 }
 }
}
function __ZTv0_n16_N7osgUtil13UpdateVisitorD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __THREW__ = 0;
 invoke_vii(3284,($4|0),((51356)|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if (!($6)) {
  $14 = ((($4)) + 56|0);
  __ZN3osg6ObjectD2Ev($14);
  return;
 }
 $7 = ___cxa_find_matching_catch_2()|0;
 $8 = tempRet0;
 $9 = ((($4)) + 56|0);
 __THREW__ = 0;
 invoke_vi(388,($9|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if ($11) {
  $12 = ___cxa_find_matching_catch_3(0|0)|0;
  $13 = tempRet0;
  ___clang_call_terminate($12);
  // unreachable;
 } else {
  ___resumeException($7|0);
  // unreachable;
 }
}
function __ZTv0_n16_N7osgUtil13UpdateVisitorD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$i$index2Z2D = 0, $eh$lpad$body$i$indexZ2D = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __THREW__ = 0;
 invoke_vii(3284,($4|0),((51356)|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $10 = ___cxa_find_matching_catch_2()|0;
  $11 = tempRet0;
  $12 = ((($4)) + 56|0);
  __THREW__ = 0;
  invoke_vi(388,($12|0));
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if ($14) {
   $15 = ___cxa_find_matching_catch_3(0|0)|0;
   $16 = tempRet0;
   ___clang_call_terminate($15);
   // unreachable;
  } else {
   $eh$lpad$body$i$index2Z2D = $11;$eh$lpad$body$i$indexZ2D = $10;
   __ZdlPv($4);
   ___resumeException($eh$lpad$body$i$indexZ2D|0);
   // unreachable;
  }
 }
 $7 = ((($4)) + 56|0);
 __THREW__ = 0;
 invoke_vi(388,($7|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if (!($9)) {
  __ZdlPv($4);
  return;
 }
 $17 = ___cxa_find_matching_catch_2()|0;
 $18 = tempRet0;
 $eh$lpad$body$i$index2Z2D = $18;$eh$lpad$body$i$indexZ2D = $17;
 __ZdlPv($4);
 ___resumeException($eh$lpad$body$i$indexZ2D|0);
 // unreachable;
}
function __ZTv0_n32_NK7osgUtil13UpdateVisitor11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (116801|0);
}
function __ZTv0_n36_NK7osgUtil13UpdateVisitor9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (115174|0);
}
function __ZN7osgUtil13UpdateVisitorC1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 56|0);
 __ZN3osg10ReferencedC2Ev($1);
 HEAP32[$1>>2] = (63412);
 $2 = ((($0)) + 68|0);
 ;HEAP32[$2>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;
 $3 = ((($0)) + 80|0);
 HEAP32[$3>>2] = 2;
 $4 = ((($0)) + 84|0);
 HEAP32[$4>>2] = 0;
 __THREW__ = 0;
 invoke_viiii(3522,($0|0),((51356)|0),1,2);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if (!($6)) {
  HEAP32[$0>>2] = (50868);
  HEAP32[$1>>2] = (51212);
  return;
 }
 $7 = ___cxa_find_matching_catch_2()|0;
 $8 = tempRet0;
 __THREW__ = 0;
 invoke_vi(388,($1|0));
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if ($10) {
  $11 = ___cxa_find_matching_catch_3(0|0)|0;
  $12 = tempRet0;
  ___clang_call_terminate($11);
  // unreachable;
 } else {
  ___resumeException($7|0);
  // unreachable;
 }
}
function __ZN7osgUtil11CullVisitorD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vii(3621,($0|0),(51908|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  $3 = ((($0)) + 508|0);
  __ZN3osg6ObjectD2Ev($3);
  return;
 }
 $4 = ___cxa_find_matching_catch_2()|0;
 $5 = tempRet0;
 $6 = ((($0)) + 508|0);
 __THREW__ = 0;
 invoke_vi(388,($6|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch_3(0|0)|0;
  $10 = tempRet0;
  ___clang_call_terminate($9);
  // unreachable;
 } else {
  ___resumeException($4|0);
  // unreachable;
 }
}
function __ZN7osgUtil11CullVisitorD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vii(3621,($0|0),(51908|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $6 = ___cxa_find_matching_catch_2()|0;
  $7 = tempRet0;
  $8 = ((($0)) + 508|0);
  __THREW__ = 0;
  invoke_vi(388,($8|0));
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if ($10) {
   $11 = ___cxa_find_matching_catch_3(0|0)|0;
   $12 = tempRet0;
   ___clang_call_terminate($11);
   // unreachable;
  } else {
   $eh$lpad$body$index2Z2D = $7;$eh$lpad$body$indexZ2D = $6;
   __ZdlPv($0);
   ___resumeException($eh$lpad$body$indexZ2D|0);
   // unreachable;
  }
 }
 $3 = ((($0)) + 508|0);
 __THREW__ = 0;
 invoke_vi(388,($3|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  __ZdlPv($0);
  return;
 }
 $13 = ___cxa_find_matching_catch_2()|0;
 $14 = tempRet0;
 $eh$lpad$body$index2Z2D = $14;$eh$lpad$body$indexZ2D = $13;
 __ZdlPv($0);
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
}
function __ZNK7osgUtil11CullVisitor11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (116801|0);
}
function __ZNK7osgUtil11CullVisitor9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (115214|0);
}
function __ZN7osgUtil11CullVisitor13asCullVisitorEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ($0|0);
}
function __ZNK7osgUtil11CullVisitor13asCullVisitorEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ($0|0);
}
function __ZN7osgUtil11CullVisitor11asCullStackEv($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 56|0);
 return ($1|0);
}
function __ZNK7osgUtil11CullVisitor11asCullStackEv($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 56|0);
 return ($1|0);
}
function __ZN7osgUtil11CullVisitor5resetEv($0) {
 $0 = $0|0;
 var $$sroa$03$011 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i = 0, $scevgep5$i$i$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 56|0);
 __ZN3osg9CullStack5resetEv($1);
 $2 = ((($0)) + 388|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 392|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==($3|0);
 if (!($6)) {
  $scevgep$i$i$i = ((($5)) + -4|0);
  $7 = $scevgep$i$i$i;
  $8 = $3;
  $9 = (($7) - ($8))|0;
  $10 = $9 >>> 2;
  $11 = $10 ^ -1;
  $scevgep5$i$i$i = (($5) + ($11<<2)|0);
  HEAP32[$4>>2] = $scevgep5$i$i$i;
 }
 $12 = ((($0)) + 440|0);
 HEAP32[$12>>2] = 0;
 $13 = ((($0)) + 400|0);
 HEAP32[$13>>2] = 0;
 $14 = ((($0)) + 408|0);
 HEAPF64[$14>>3] = 3.4028234663852886E+38;
 $15 = ((($0)) + 416|0);
 HEAPF64[$15>>3] = -3.4028234663852886E+38;
 $16 = ((($0)) + 348|0);
 HEAP32[$16>>2] = 3;
 $17 = ((($0)) + 344|0);
 HEAP32[$17>>2] = 4;
 $18 = ((($0)) + 424|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ((($0)) + 436|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($19) + ($21<<2)|0);
 $23 = ($21|0)==(0);
 if (!($23)) {
  $$sroa$03$011 = $19;
  while(1) {
   $32 = HEAP32[$$sroa$03$011>>2]|0;
   $33 = ((($32)) + 12|0);
   HEAP32[$33>>2] = 0;
   $34 = ((($32)) + 16|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ($35|0)==(0|0);
   if (!($36)) {
    HEAP32[$34>>2] = 0;
    $37 = ((($35)) + 8|0);
    $38 = HEAP32[$37>>2]|0;HEAP32[$37>>2] = (($38-1)|0);
    $39 = ($38|0)==(1);
    if ($39) {
     __ZNK3osg10Referenced24signalObserversAndDeleteEbb($35,1,1);
    }
   }
   $40 = ((($32)) + 20|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = ($41|0)==(0|0);
   if (!($42)) {
    HEAP32[$40>>2] = 0;
    $43 = ((($41)) + 8|0);
    $44 = HEAP32[$43>>2]|0;HEAP32[$43>>2] = (($44-1)|0);
    $45 = ($44|0)==(1);
    if ($45) {
     __ZNK3osg10Referenced24signalObserversAndDeleteEbb($41,1,1);
    }
   }
   $46 = ((($32)) + 24|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = ($47|0)==(0|0);
   if (!($48)) {
    HEAP32[$46>>2] = 0;
    $49 = ((($47)) + 8|0);
    $50 = HEAP32[$49>>2]|0;HEAP32[$49>>2] = (($50-1)|0);
    $51 = ($50|0)==(1);
    if ($51) {
     __ZNK3osg10Referenced24signalObserversAndDeleteEbb($47,1,1);
    }
   }
   $52 = ((($32)) + 28|0);
   HEAPF32[$52>>2] = 0.0;
   $53 = ((($32)) + 32|0);
   HEAP8[$53>>0] = 0;
   $54 = ((($32)) + 36|0);
   HEAP32[$54>>2] = 0;
   $55 = ((($$sroa$03$011)) + 4|0);
   $56 = ($55|0)==($22|0);
   if ($56) {
    break;
   } else {
    $$sroa$03$011 = $55;
   }
  }
 }
 HEAP32[$20>>2] = 0;
 $24 = ((($0)) + 480|0);
 $25 = ((($0)) + 484|0);
 $26 = HEAP32[$25>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIdN7osgUtil11CullVisitor21MatrixPlanesDrawablesEEENS_19__map_value_compareIdS5_NS_4lessIdEELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($24,$26);
 $27 = ((($0)) + 488|0);
 HEAP32[$27>>2] = 0;
 HEAP32[$24>>2] = $25;
 HEAP32[$25>>2] = 0;
 $28 = ((($0)) + 492|0);
 $29 = ((($0)) + 496|0);
 $30 = HEAP32[$29>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIdN7osgUtil11CullVisitor21MatrixPlanesDrawablesEEENS_19__map_value_compareIdS5_NS_4lessIdEELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($28,$30);
 $31 = ((($0)) + 500|0);
 HEAP32[$31>>2] = 0;
 HEAP32[$28>>2] = $29;
 HEAP32[$29>>2] = 0;
 return;
}
function __ZNK7osgUtil11CullVisitor11getEyePointEv($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 240|0);
 ;HEAP32[$0>>2]=HEAP32[$2>>2]|0;HEAP32[$0+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$2+8>>2]|0;
 return;
}
function __ZNK7osgUtil11CullVisitor12getViewPointEv($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 268|0);
 ;HEAP32[$0>>2]=HEAP32[$2>>2]|0;HEAP32[$0+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$2+8>>2]|0;
 return;
}
function __ZNK7osgUtil11CullVisitor21getDistanceToEyePointERKN3osg5Vec3fEb($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0.0, $10 = 0.0, $11 = 0.0, $12 = 0, $13 = 0.0, $14 = 0, $15 = 0.0, $16 = 0.0, $17 = 0.0, $18 = 0.0, $19 = 0.0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0, $24 = 0.0, $25 = 0.0, $3 = 0.0, $4 = 0, $5 = 0.0;
 var $6 = 0.0, $7 = 0, $8 = 0.0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = +HEAPF32[$1>>2];
 $4 = ((($0)) + 240|0);
 $5 = +HEAPF32[$4>>2];
 $6 = $3 - $5;
 $7 = ((($1)) + 4|0);
 $8 = +HEAPF32[$7>>2];
 $9 = ((($0)) + 244|0);
 $10 = +HEAPF32[$9>>2];
 $11 = $8 - $10;
 $12 = ((($1)) + 8|0);
 $13 = +HEAPF32[$12>>2];
 $14 = ((($0)) + 248|0);
 $15 = +HEAPF32[$14>>2];
 $16 = $13 - $15;
 $17 = $6 * $6;
 $18 = $11 * $11;
 $19 = $17 + $18;
 $20 = $16 * $16;
 $21 = $19 + $20;
 $22 = (+Math_sqrt((+$21)));
 if (!($2)) {
  $$0 = $22;
  return (+$$0);
 }
 $23 = ((($0)) + 76|0);
 $24 = +HEAPF32[$23>>2];
 $25 = $22 * $24;
 $$0 = $25;
 return (+$$0);
}
function __ZNK7osgUtil11CullVisitor23getDistanceFromEyePointERKN3osg5Vec3fEb($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0.0, $10 = 0, $11 = 0.0, $12 = 0.0, $13 = 0, $14 = 0.0, $15 = 0.0, $16 = 0.0, $17 = 0, $18 = 0.0, $19 = 0.0, $20 = 0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0, $25 = 0.0, $26 = 0.0, $27 = 0.0, $28 = 0.0;
 var $29 = 0, $3 = 0, $30 = 0.0, $31 = 0.0, $4 = 0, $5 = 0.0, $6 = 0.0, $7 = 0, $8 = 0.0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 152|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = +HEAPF32[$1>>2];
 $6 = $5;
 $7 = ((($4)) + 48|0);
 $8 = +HEAPF64[$7>>3];
 $9 = $6 * $8;
 $10 = ((($1)) + 4|0);
 $11 = +HEAPF32[$10>>2];
 $12 = $11;
 $13 = ((($4)) + 80|0);
 $14 = +HEAPF64[$13>>3];
 $15 = $12 * $14;
 $16 = $9 + $15;
 $17 = ((($1)) + 8|0);
 $18 = +HEAPF32[$17>>2];
 $19 = $18;
 $20 = ((($4)) + 112|0);
 $21 = +HEAPF64[$20>>3];
 $22 = $19 * $21;
 $23 = $16 + $22;
 $24 = ((($4)) + 144|0);
 $25 = +HEAPF64[$24>>3];
 $26 = $25 + $23;
 $27 = $26;
 $28 = -$27;
 if (!($2)) {
  $$0 = $28;
  return (+$$0);
 }
 $29 = ((($0)) + 76|0);
 $30 = +HEAPF32[$29>>2];
 $31 = $30 * $28;
 $$0 = $31;
 return (+$$0);
}
function __ZNK7osgUtil11CullVisitor22getDistanceToViewPointERKN3osg5Vec3fEb($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0.0, $10 = 0.0, $11 = 0.0, $12 = 0, $13 = 0.0, $14 = 0, $15 = 0.0, $16 = 0.0, $17 = 0.0, $18 = 0.0, $19 = 0.0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0, $24 = 0.0, $25 = 0.0, $3 = 0.0, $4 = 0, $5 = 0.0;
 var $6 = 0.0, $7 = 0, $8 = 0.0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = +HEAPF32[$1>>2];
 $4 = ((($0)) + 268|0);
 $5 = +HEAPF32[$4>>2];
 $6 = $3 - $5;
 $7 = ((($1)) + 4|0);
 $8 = +HEAPF32[$7>>2];
 $9 = ((($0)) + 272|0);
 $10 = +HEAPF32[$9>>2];
 $11 = $8 - $10;
 $12 = ((($1)) + 8|0);
 $13 = +HEAPF32[$12>>2];
 $14 = ((($0)) + 276|0);
 $15 = +HEAPF32[$14>>2];
 $16 = $13 - $15;
 $17 = $6 * $6;
 $18 = $11 * $11;
 $19 = $17 + $18;
 $20 = $16 * $16;
 $21 = $19 + $20;
 $22 = (+Math_sqrt((+$21)));
 if (!($2)) {
  $$0 = $22;
  return (+$$0);
 }
 $23 = ((($0)) + 76|0);
 $24 = +HEAPF32[$23>>2];
 $25 = $22 * $24;
 $$0 = $25;
 return (+$$0);
}
function __ZN7osgUtil11CullVisitor5applyERN3osg8DrawableE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0101 = 0, $$01527$i = 0, $$057 = 0, $$1106 = 0, $$2 = 0, $$3 = 0, $$pre = 0, $$pre$i = 0, $$pre$i67 = 0, $$sink$i = 0, $$sink$i$i$i = 0, $$sink$i3$i$i = 0, $$sink$i60 = 0, $$sink$i66 = 0, $$sink1$i$i$i = 0, $$sink1$i4$i$i = 0, $$sink102 = 0, $$sink2$i$i$i = 0, $$sink2$i5$i$i = 0, $$sink26$i = 0;
 var $$sroa$093$0104 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0;
 var $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0;
 var $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0;
 var $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0.0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0.0, $164 = 0, $165 = 0, $166 = 0, $167 = 0.0, $168 = 0.0, $169 = 0.0, $17 = 0, $170 = 0.0;
 var $171 = 0, $172 = 0.0, $173 = 0.0, $174 = 0.0, $175 = 0.0, $176 = 0, $177 = 0.0, $178 = 0.0, $179 = 0.0, $18 = 0, $180 = 0.0, $181 = 0, $182 = 0.0, $183 = 0.0, $184 = 0.0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0;
 var $19 = 0, $190 = 0.0, $191 = 0, $192 = 0, $193 = 0, $194 = 0.0, $195 = 0, $196 = 0, $197 = 0, $198 = 0.0, $199 = 0.0, $2 = 0, $20 = 0, $200 = 0.0, $201 = 0.0, $202 = 0.0, $203 = 0.0, $204 = 0.0, $205 = 0.0, $206 = 0.0;
 var $207 = 0.0, $208 = 0.0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0;
 var $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0;
 var $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0.0, $259 = 0.0, $26 = 0, $260 = 0;
 var $261 = 0, $262 = 0.0, $263 = 0, $264 = 0.0, $265 = 0, $266 = 0, $267 = 0.0, $268 = 0, $269 = 0.0, $27 = 0, $270 = 0, $271 = 0.0, $272 = 0.0, $273 = 0.0, $274 = 0.0, $275 = 0.0, $276 = 0.0, $277 = 0.0, $278 = 0, $279 = 0.0;
 var $28 = 0, $280 = 0.0, $281 = 0.0, $282 = 0, $283 = 0.0, $284 = 0.0, $285 = 0.0, $286 = 0.0, $287 = 0, $288 = 0.0, $289 = 0.0, $29 = 0, $290 = 0.0, $291 = 0, $292 = 0.0, $293 = 0.0, $294 = 0.0, $295 = 0, $296 = 0.0, $297 = 0;
 var $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0;
 var $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0.0, $325 = 0.0, $326 = 0.0, $327 = 0, $328 = 0.0, $329 = 0, $33 = 0, $330 = 0.0, $331 = 0.0, $332 = 0;
 var $333 = 0.0, $334 = 0, $335 = 0.0, $336 = 0.0, $337 = 0.0, $338 = 0.0, $339 = 0.0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0;
 var $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0;
 var $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0;
 var $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0;
 var $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0;
 var $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0.0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0;
 var $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0;
 var $46 = 0.0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0.0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0;
 var $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $5 = 0, $50 = 0.0, $51 = 0;
 var $52 = 0.0, $53 = 0, $54 = 0, $55 = 0.0, $56 = 0, $57 = 0.0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0.0, $67 = 0.0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0.0, $71 = 0, $72 = 0.0, $73 = 0, $74 = 0, $75 = 0.0, $76 = 0, $77 = 0.0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $or$cond$i = 0, $or$cond$i59 = 0, $or$cond$i63 = 0, $phitmp = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $2 = sp + 16|0;
 $3 = sp + 12|0;
 $4 = sp + 8|0;
 $5 = sp + 4|0;
 $6 = sp;
 $7 = ((($0)) + 168|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0);
 $10 = ((($0)) + 152|0);
 $11 = ((($0)) + 352|0);
 $$sink$i = $9 ? $11 : $10;
 $12 = HEAP32[$$sink$i>>2]|0;
 $13 = (__ZNK3osg8Drawable14getBoundingBoxEv($1)|0);
 $14 = ((($1)) + 100|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0|0);
 do {
  if (!($16)) {
   $17 = HEAP32[$15>>2]|0;
   $18 = ((($17)) + 76|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (FUNCTION_TABLE_ii[$19 & 8191]($15)|0);
   $21 = ($20|0)==(0|0);
   if ($21) {
    $27 = HEAP32[$14>>2]|0;
    $28 = HEAP32[$27>>2]|0;
    $29 = ((($28)) + 92|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = HEAP32[$0>>2]|0;
    $32 = ((($31)) + -12|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = (($0) + ($33)|0);
    (FUNCTION_TABLE_iiii[$30 & 8191]($27,$1,$34)|0);
    break;
   }
   $22 = HEAP32[$20>>2]|0;
   $23 = ((($22)) + 32|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = ((($0)) + 444|0);
   $26 = (FUNCTION_TABLE_iiiii[$24 & 8191]($20,$0,$1,$25)|0);
   if ($26) {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $35 = ((($1)) + 108|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = ($36|0)==(0);
 if ($37) {
  $38 = ((($1)) + 104|0);
  $39 = HEAP8[$38>>0]|0;
  $40 = ($39<<24>>24)==(0);
  if (!($40)) {
   $41 = (__ZNK3osg4Node8getBoundEv($1)|0);
   $42 = ((($41)) + 12|0);
   $43 = +HEAPF32[$42>>2];
   $44 = !($43 >= 0.0);
   if (!($44)) {
    $45 = ((($13)) + 12|0);
    $46 = +HEAPF32[$45>>2];
    $47 = +HEAPF32[$13>>2];
    $48 = !($46 >= $47);
    if (!($48)) {
     $49 = ((($13)) + 16|0);
     $50 = +HEAPF32[$49>>2];
     $51 = ((($13)) + 4|0);
     $52 = +HEAPF32[$51>>2];
     $53 = !($50 >= $52);
     if (!($53)) {
      $54 = ((($13)) + 20|0);
      $55 = +HEAPF32[$54>>2];
      $56 = ((($13)) + 8|0);
      $57 = +HEAPF32[$56>>2];
      $58 = !($55 >= $57);
      if (!($58)) {
       $59 = ((($0)) + 336|0);
       $60 = HEAP32[$59>>2]|0;
       $61 = (__ZN3osg10CullingSet8isCulledERKNS_15BoundingBoxImplINS_5Vec3fEEE($60,$13)|0);
       if ($61) {
        STACKTOP = sp;return;
       }
      }
     }
    }
   }
  }
 }
 $62 = ((($0)) + 68|0);
 $63 = HEAP32[$62>>2]|0;
 $64 = ($63|0)==(0);
 if (!($64)) {
  $65 = ((($13)) + 12|0);
  $66 = +HEAPF32[$65>>2];
  $67 = +HEAPF32[$13>>2];
  $68 = !($66 >= $67);
  if (!($68)) {
   $69 = ((($13)) + 16|0);
   $70 = +HEAPF32[$69>>2];
   $71 = ((($13)) + 4|0);
   $72 = +HEAPF32[$71>>2];
   $73 = !($70 >= $72);
   if (!($73)) {
    $74 = ((($13)) + 20|0);
    $75 = +HEAPF32[$74>>2];
    $76 = ((($13)) + 8|0);
    $77 = +HEAPF32[$76>>2];
    $78 = !($75 >= $77);
    if (!($78)) {
     $79 = ((($12)) + 32|0);
     $80 = (__ZN7osgUtil11CullVisitor23updateCalculatedNearFarERKN3osg7MatrixdERKNS1_8DrawableEb($0,$79,$1,0)|0);
     if (!($80)) {
      STACKTOP = sp;return;
     }
    }
   }
  }
 }
 $81 = ((($1)) + 120|0);
 $82 = HEAP32[$81>>2]|0;
 $83 = ($82|0)==(0|0);
 if ($83) {
  $$057 = 0;
 } else {
  $84 = ((($0)) + 376|0);
  $85 = HEAP32[$84>>2]|0;
  $86 = (__ZN7osgUtil10StateGraph14find_or_insertEPKN3osg8StateSetE($85,$82)|0);
  HEAP32[$84>>2] = $86;
  $87 = ((($82)) + 120|0);
  $88 = HEAP32[$87>>2]|0;
  $89 = ($88|0)==(0);
  if ($89) {
   $$057 = 1;
  } else {
   $90 = ((($82)) + 128|0);
   $91 = ((($90)) + 11|0);
   $92 = HEAP8[$91>>0]|0;
   $93 = ($92<<24>>24)<(0);
   if ($93) {
    $94 = ((($82)) + 132|0);
    $95 = HEAP32[$94>>2]|0;
    $97 = $95;
   } else {
    $96 = $92&255;
    $97 = $96;
   }
   $98 = ($97|0)==(0);
   if ($98) {
    $124 = $88;
   } else {
    $99 = ((($0)) + 440|0);
    $100 = HEAP32[$99>>2]|0;
    $101 = ($100|0)!=(0);
    $102 = $88 & 4;
    $103 = ($102|0)==(0);
    $or$cond$i59 = $103 & $101;
    if ($or$cond$i59) {
     $124 = $88;
    } else {
     $104 = ((($0)) + 384|0);
     $105 = ((($0)) + 392|0);
     $106 = HEAP32[$105>>2]|0;
     $107 = ((($0)) + 396|0);
     $108 = HEAP32[$107>>2]|0;
     $109 = ($106|0)==($108|0);
     if ($109) {
      $113 = ((($0)) + 388|0);
      __ZNSt3__26vectorIPN7osgUtil9RenderBinENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_($113,$104);
     } else {
      $110 = HEAP32[$104>>2]|0;
      HEAP32[$106>>2] = $110;
      $111 = HEAP32[$105>>2]|0;
      $112 = ((($111)) + 4|0);
      HEAP32[$105>>2] = $112;
     }
     $114 = ((($82)) + 140|0);
     $115 = HEAP8[$114>>0]|0;
     $116 = ($115<<24>>24)==(0);
     $117 = HEAP32[$104>>2]|0;
     if ($116) {
      $118 = ((($117)) + 40|0);
      $119 = HEAP32[$118>>2]|0;
      $$sink$i60 = $119;
     } else {
      $$sink$i60 = $117;
     }
     $120 = ((($82)) + 124|0);
     $121 = HEAP32[$120>>2]|0;
     $122 = (__ZN7osgUtil9RenderBin14find_or_insertEiRKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE($$sink$i60,$121,$90)|0);
     HEAP32[$104>>2] = $122;
     $$pre$i = HEAP32[$87>>2]|0;
     $124 = $$pre$i;
    }
   }
   $123 = $124 & 2;
   $125 = ($123|0)==(0);
   if ($125) {
    $$057 = 1;
   } else {
    $126 = ((($0)) + 440|0);
    $127 = HEAP32[$126>>2]|0;
    $128 = (($127) + 1)|0;
    HEAP32[$126>>2] = $128;
    $$057 = 1;
   }
  }
 }
 $129 = ((($0)) + 336|0);
 $130 = HEAP32[$129>>2]|0;
 $131 = ((($130)) + 64|0);
 $132 = HEAP32[$131>>2]|0;
 $133 = ((($130)) + 68|0);
 $134 = HEAP32[$133>>2]|0;
 $135 = ($132|0)==($134|0);
 if ($135) {
  $$3 = $$057;
 } else {
  $136 = ((($0)) + 376|0);
  $137 = ((($0)) + 440|0);
  $138 = ((($0)) + 384|0);
  $139 = ((($0)) + 392|0);
  $140 = ((($0)) + 396|0);
  $141 = ((($0)) + 388|0);
  $142 = ((($13)) + 12|0);
  $$1106 = $$057;$$sroa$093$0104 = $132;
  while(1) {
   $143 = ((($$sroa$093$0104)) + 4|0);
   $144 = HEAP32[$143>>2]|0;
   $145 = ($144|0)==(0);
   L48: do {
    if ($145) {
     label = 41;
    } else {
     $146 = ((($$sroa$093$0104)) + 24|0);
     HEAP32[$146>>2] = $144;
     $147 = ((($$sroa$093$0104)) + 28|0);
     $148 = HEAP32[$147>>2]|0;
     $149 = ((($$sroa$093$0104)) + 32|0);
     $150 = HEAP32[$149>>2]|0;
     $151 = ($148|0)==($150|0);
     if ($151) {
      label = 41;
     } else {
      $$01527$i = 1;$$sink26$i = $148;$153 = $144;
      while(1) {
       $152 = $$01527$i & $153;
       $154 = ($152|0)==(0);
       do {
        if ($154) {
         $492 = $153;
        } else {
         $155 = ((($$sink26$i)) + 36|0);
         $156 = HEAP32[$155>>2]|0;
         $157 = $156 & 1;
         $158 = ($157|0)!=(0);
         $$sink$i$i$i = $158 ? $142 : $13;
         $159 = +HEAPF32[$$sink$i$i$i>>2];
         $160 = $156 & 2;
         $161 = ($160|0)!=(0);
         $$sink1$i$i$i = $161 ? $142 : $13;
         $162 = ((($$sink1$i$i$i)) + 4|0);
         $163 = +HEAPF32[$162>>2];
         $164 = $156 & 4;
         $165 = ($164|0)!=(0);
         $$sink2$i$i$i = $165 ? $142 : $13;
         $166 = ((($$sink2$i$i$i)) + 8|0);
         $167 = +HEAPF32[$166>>2];
         $168 = +HEAPF64[$$sink26$i>>3];
         $169 = $159;
         $170 = $169 * $168;
         $171 = ((($$sink26$i)) + 8|0);
         $172 = +HEAPF64[$171>>3];
         $173 = $163;
         $174 = $173 * $172;
         $175 = $170 + $174;
         $176 = ((($$sink26$i)) + 16|0);
         $177 = +HEAPF64[$176>>3];
         $178 = $167;
         $179 = $178 * $177;
         $180 = $175 + $179;
         $181 = ((($$sink26$i)) + 24|0);
         $182 = +HEAPF64[$181>>3];
         $183 = $182 + $180;
         $184 = $183;
         $185 = $184 > 0.0;
         if ($185) {
          $210 = $$01527$i ^ $153;
          HEAP32[$146>>2] = $210;
          $492 = $210;
          break;
         } else {
          $186 = ((($$sink26$i)) + 32|0);
          $187 = HEAP32[$186>>2]|0;
          $188 = $187 & 1;
          $189 = ($188|0)!=(0);
          $$sink$i3$i$i = $189 ? $142 : $13;
          $190 = +HEAPF32[$$sink$i3$i$i>>2];
          $191 = $187 & 2;
          $192 = ($191|0)!=(0);
          $$sink1$i4$i$i = $192 ? $142 : $13;
          $193 = ((($$sink1$i4$i$i)) + 4|0);
          $194 = +HEAPF32[$193>>2];
          $195 = $187 & 4;
          $196 = ($195|0)!=(0);
          $$sink2$i5$i$i = $196 ? $142 : $13;
          $197 = ((($$sink2$i5$i$i)) + 8|0);
          $198 = +HEAPF32[$197>>2];
          $199 = $190;
          $200 = $168 * $199;
          $201 = $194;
          $202 = $172 * $201;
          $203 = $200 + $202;
          $204 = $198;
          $205 = $177 * $204;
          $206 = $203 + $205;
          $207 = $182 + $206;
          $208 = $207;
          $209 = $208 < 0.0;
          if ($209) {
           $$2 = $$1106;
           break L48;
          } else {
           $492 = $153;
           break;
          }
         }
        }
       } while(0);
       $211 = $$01527$i << 1;
       $212 = ((($$sink26$i)) + 40|0);
       $213 = ($212|0)==($150|0);
       if ($213) {
        label = 41;
        break;
       } else {
        $$01527$i = $211;$$sink26$i = $212;$153 = $492;
       }
      }
     }
    }
   } while(0);
   if ((label|0) == 41) {
    label = 0;
    $214 = (($$1106) + 1)|0;
    $215 = HEAP32[$$sroa$093$0104>>2]|0;
    $216 = HEAP32[$136>>2]|0;
    $217 = (__ZN7osgUtil10StateGraph14find_or_insertEPKN3osg8StateSetE($216,$215)|0);
    HEAP32[$136>>2] = $217;
    $218 = ((($215)) + 120|0);
    $219 = HEAP32[$218>>2]|0;
    $220 = ($219|0)==(0);
    if ($220) {
     $$2 = $214;
    } else {
     $221 = ((($215)) + 128|0);
     $222 = ((($221)) + 11|0);
     $223 = HEAP8[$222>>0]|0;
     $224 = ($223<<24>>24)<(0);
     if ($224) {
      $225 = ((($215)) + 132|0);
      $226 = HEAP32[$225>>2]|0;
      $228 = $226;
     } else {
      $227 = $223&255;
      $228 = $227;
     }
     $229 = ($228|0)==(0);
     if ($229) {
      $250 = $219;
     } else {
      $230 = HEAP32[$137>>2]|0;
      $231 = ($230|0)!=(0);
      $232 = $219 & 4;
      $233 = ($232|0)==(0);
      $or$cond$i63 = $233 & $231;
      if ($or$cond$i63) {
       $250 = $219;
      } else {
       $234 = HEAP32[$139>>2]|0;
       $235 = HEAP32[$140>>2]|0;
       $236 = ($234|0)==($235|0);
       if ($236) {
        __ZNSt3__26vectorIPN7osgUtil9RenderBinENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_($141,$138);
       } else {
        $237 = HEAP32[$138>>2]|0;
        HEAP32[$234>>2] = $237;
        $238 = HEAP32[$139>>2]|0;
        $239 = ((($238)) + 4|0);
        HEAP32[$139>>2] = $239;
       }
       $240 = ((($215)) + 140|0);
       $241 = HEAP8[$240>>0]|0;
       $242 = ($241<<24>>24)==(0);
       $243 = HEAP32[$138>>2]|0;
       if ($242) {
        $244 = ((($243)) + 40|0);
        $245 = HEAP32[$244>>2]|0;
        $$sink$i66 = $245;
       } else {
        $$sink$i66 = $243;
       }
       $246 = ((($215)) + 124|0);
       $247 = HEAP32[$246>>2]|0;
       $248 = (__ZN7osgUtil9RenderBin14find_or_insertEiRKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE($$sink$i66,$247,$221)|0);
       HEAP32[$138>>2] = $248;
       $$pre$i67 = HEAP32[$218>>2]|0;
       $250 = $$pre$i67;
      }
     }
     $249 = $250 & 2;
     $251 = ($249|0)==(0);
     if ($251) {
      $$2 = $214;
     } else {
      $252 = HEAP32[$137>>2]|0;
      $253 = (($252) + 1)|0;
      HEAP32[$137>>2] = $253;
      $$2 = $214;
     }
    }
   }
   $254 = ((($$sroa$093$0104)) + 52|0);
   $255 = HEAP32[$133>>2]|0;
   $256 = ($254|0)==($255|0);
   if ($256) {
    $$3 = $$2;
    break;
   } else {
    $$1106 = $$2;$$sroa$093$0104 = $254;
   }
  }
 }
 $257 = ((($13)) + 12|0);
 $258 = +HEAPF32[$257>>2];
 $259 = +HEAPF32[$13>>2];
 $260 = !($258 >= $259);
 if ($260) {
  $296 = 0.0;
 } else {
  $261 = ((($13)) + 16|0);
  $262 = +HEAPF32[$261>>2];
  $263 = ((($13)) + 4|0);
  $264 = +HEAPF32[$263>>2];
  $265 = !($262 >= $264);
  if ($265) {
   $296 = 0.0;
  } else {
   $266 = ((($13)) + 20|0);
   $267 = +HEAPF32[$266>>2];
   $268 = ((($13)) + 8|0);
   $269 = +HEAPF32[$268>>2];
   $270 = !($267 >= $269);
   if ($270) {
    $296 = 0.0;
   } else {
    $271 = $259 + $258;
    $272 = $264 + $262;
    $273 = $269 + $267;
    $274 = $271 * 0.5;
    $275 = $272 * 0.5;
    $276 = $273 * 0.5;
    $277 = $274;
    $278 = ((($12)) + 48|0);
    $279 = +HEAPF64[$278>>3];
    $280 = $277 * $279;
    $281 = $275;
    $282 = ((($12)) + 80|0);
    $283 = +HEAPF64[$282>>3];
    $284 = $281 * $283;
    $285 = $280 + $284;
    $286 = $276;
    $287 = ((($12)) + 112|0);
    $288 = +HEAPF64[$287>>3];
    $289 = $286 * $288;
    $290 = $285 + $289;
    $291 = ((($12)) + 144|0);
    $292 = +HEAPF64[$291>>3];
    $293 = $292 + $290;
    $294 = $293;
    $phitmp = -$294;
    $296 = $phitmp;
   }
  }
 }
 $295 = (HEAPF32[tempDoublePtr>>2]=$296,HEAP32[tempDoublePtr>>2]|0);
 $297 = $295 & 2147483647;
 $298 = ($297>>>0)>(2139095040);
 L84: do {
  if ($298) {
   $299 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
   do {
    if ($299) {
     $300 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
     $301 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($300,116180,40)|0);
     $302 = HEAP32[$301>>2]|0;
     $303 = ((($302)) + -12|0);
     $304 = HEAP32[$303>>2]|0;
     $305 = (($301) + ($304)|0);
     __ZNKSt3__28ios_base6getlocEv($4,$305);
     __THREW__ = 0;
     $306 = (invoke_iii(3255,($4|0),(215188|0))|0);
     $307 = __THREW__; __THREW__ = 0;
     $308 = $307&1;
     if (!($308)) {
      $309 = HEAP32[$306>>2]|0;
      $310 = ((($309)) + 28|0);
      $311 = HEAP32[$310>>2]|0;
      __THREW__ = 0;
      $312 = (invoke_iii($311|0,($306|0),10)|0);
      $313 = __THREW__; __THREW__ = 0;
      $314 = $313&1;
      if (!($314)) {
       __ZNSt3__26localeD2Ev($4);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($301,$312)|0);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($301)|0);
       $321 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($301,115908,10)|0);
       $322 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEf($321,$296)|0);
       $323 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($322,116221,10)|0);
       $324 = +HEAPF32[$13>>2];
       $325 = +HEAPF32[$257>>2];
       $326 = $324 + $325;
       $327 = ((($13)) + 4|0);
       $328 = +HEAPF32[$327>>2];
       $329 = ((($13)) + 16|0);
       $330 = +HEAPF32[$329>>2];
       $331 = $328 + $330;
       $332 = ((($13)) + 8|0);
       $333 = +HEAPF32[$332>>2];
       $334 = ((($13)) + 20|0);
       $335 = +HEAPF32[$334>>2];
       $336 = $333 + $335;
       $337 = $326 * 0.5;
       $338 = $331 * 0.5;
       $339 = $336 * 0.5;
       $340 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEf($323,$337)|0);
       $341 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($340,159071,1)|0);
       $342 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEf($341,$338)|0);
       $343 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($342,159071,1)|0);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEf($343,$339)|0);
       $344 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($323,115927,2)|0);
       $345 = HEAP32[$344>>2]|0;
       $346 = ((($345)) + -12|0);
       $347 = HEAP32[$346>>2]|0;
       $348 = (($344) + ($347)|0);
       __ZNKSt3__28ios_base6getlocEv($3,$348);
       __THREW__ = 0;
       $349 = (invoke_iii(3255,($3|0),(215188|0))|0);
       $350 = __THREW__; __THREW__ = 0;
       $351 = $350&1;
       if (!($351)) {
        $352 = HEAP32[$349>>2]|0;
        $353 = ((($352)) + 28|0);
        $354 = HEAP32[$353>>2]|0;
        __THREW__ = 0;
        $355 = (invoke_iii($354|0,($349|0),10)|0);
        $356 = __THREW__; __THREW__ = 0;
        $357 = $356&1;
        if (!($357)) {
         __ZNSt3__26localeD2Ev($3);
         (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($344,$355)|0);
         (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($344)|0);
         $364 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($344,116232,11)|0);
         $365 = ((($12)) + 32|0);
         $366 = (__ZN3osglsERNSt3__213basic_ostreamIcNS0_11char_traitsIcEEEERKNS_7MatrixdE($364,$365)|0);
         $367 = HEAP32[$366>>2]|0;
         $368 = ((($367)) + -12|0);
         $369 = HEAP32[$368>>2]|0;
         $370 = (($366) + ($369)|0);
         __ZNKSt3__28ios_base6getlocEv($2,$370);
         __THREW__ = 0;
         $371 = (invoke_iii(3255,($2|0),(215188|0))|0);
         $372 = __THREW__; __THREW__ = 0;
         $373 = $372&1;
         if (!($373)) {
          $374 = HEAP32[$371>>2]|0;
          $375 = ((($374)) + 28|0);
          $376 = HEAP32[$375>>2]|0;
          __THREW__ = 0;
          $377 = (invoke_iii($376|0,($371|0),10)|0);
          $378 = __THREW__; __THREW__ = 0;
          $379 = $378&1;
          if (!($379)) {
           __ZNSt3__26localeD2Ev($2);
           (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($366,$377)|0);
           (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($366)|0);
           break;
          }
         }
         $380 = ___cxa_find_matching_catch_2()|0;
         $381 = tempRet0;
         __THREW__ = 0;
         invoke_vi(3263,($2|0));
         $382 = __THREW__; __THREW__ = 0;
         $383 = $382&1;
         if ($383) {
          $384 = ___cxa_find_matching_catch_3(0|0)|0;
          $385 = tempRet0;
          ___clang_call_terminate($384);
          // unreachable;
         } else {
          ___resumeException($380|0);
          // unreachable;
         }
        }
       }
       $358 = ___cxa_find_matching_catch_2()|0;
       $359 = tempRet0;
       __THREW__ = 0;
       invoke_vi(3263,($3|0));
       $360 = __THREW__; __THREW__ = 0;
       $361 = $360&1;
       if ($361) {
        $362 = ___cxa_find_matching_catch_3(0|0)|0;
        $363 = tempRet0;
        ___clang_call_terminate($362);
        // unreachable;
       } else {
        ___resumeException($358|0);
        // unreachable;
       }
      }
     }
     $315 = ___cxa_find_matching_catch_2()|0;
     $316 = tempRet0;
     __THREW__ = 0;
     invoke_vi(3263,($4|0));
     $317 = __THREW__; __THREW__ = 0;
     $318 = $317&1;
     if ($318) {
      $319 = ___cxa_find_matching_catch_3(0|0)|0;
      $320 = tempRet0;
      ___clang_call_terminate($319);
      // unreachable;
     } else {
      ___resumeException($315|0);
      // unreachable;
     }
    }
   } while(0);
   $386 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(5)|0);
   do {
    if ($386) {
     $387 = (__ZN3osg6notifyENS_14NotifySeverityE(5)|0);
     $388 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($387,115953,13)|0);
     $389 = HEAP32[$388>>2]|0;
     $390 = ((($389)) + -12|0);
     $391 = HEAP32[$390>>2]|0;
     $392 = (($388) + ($391)|0);
     __ZNKSt3__28ios_base6getlocEv($5,$392);
     __THREW__ = 0;
     $393 = (invoke_iii(3255,($5|0),(215188|0))|0);
     $394 = __THREW__; __THREW__ = 0;
     $395 = $394&1;
     if (!($395)) {
      $396 = HEAP32[$393>>2]|0;
      $397 = ((($396)) + 28|0);
      $398 = HEAP32[$397>>2]|0;
      __THREW__ = 0;
      $399 = (invoke_iii($398|0,($393|0),10)|0);
      $400 = __THREW__; __THREW__ = 0;
      $401 = $400&1;
      if (!($401)) {
       __ZNSt3__26localeD2Ev($5);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($388,$399)|0);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($388)|0);
       break;
      }
     }
     $402 = ___cxa_find_matching_catch_2()|0;
     $403 = tempRet0;
     __THREW__ = 0;
     invoke_vi(3263,($5|0));
     $404 = __THREW__; __THREW__ = 0;
     $405 = $404&1;
     if ($405) {
      $406 = ___cxa_find_matching_catch_3(0|0)|0;
      $407 = tempRet0;
      ___clang_call_terminate($406);
      // unreachable;
     } else {
      ___resumeException($402|0);
      // unreachable;
     }
    }
   } while(0);
   $408 = ((($0)) + 28|0);
   $409 = HEAP32[$408>>2]|0;
   $410 = ((($0)) + 32|0);
   $411 = HEAP32[$410>>2]|0;
   $412 = ($409|0)==($411|0);
   if (!($412)) {
    $$sink102 = $409;
    while(1) {
     $413 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(5)|0);
     if ($413) {
      $414 = (__ZN3osg6notifyENS_14NotifySeverityE(5)|0);
      $415 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($414,115967,9)|0);
      $416 = HEAP32[$$sink102>>2]|0;
      $417 = ((($416)) + 12|0);
      $418 = ((($417)) + 11|0);
      $419 = HEAP8[$418>>0]|0;
      $420 = ($419<<24>>24)<(0);
      $421 = HEAP32[$417>>2]|0;
      $422 = $420 ? $421 : $417;
      $423 = ((($416)) + 16|0);
      $424 = HEAP32[$423>>2]|0;
      $425 = $419&255;
      $426 = $420 ? $424 : $425;
      $427 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($415,$422,$426)|0);
      $428 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($427,172027,1)|0);
      $429 = HEAP32[$428>>2]|0;
      $430 = ((($429)) + -12|0);
      $431 = HEAP32[$430>>2]|0;
      $432 = (($428) + ($431)|0);
      __ZNKSt3__28ios_base6getlocEv($6,$432);
      __THREW__ = 0;
      $433 = (invoke_iii(3255,($6|0),(215188|0))|0);
      $434 = __THREW__; __THREW__ = 0;
      $435 = $434&1;
      if ($435) {
       break;
      }
      $436 = HEAP32[$433>>2]|0;
      $437 = ((($436)) + 28|0);
      $438 = HEAP32[$437>>2]|0;
      __THREW__ = 0;
      $439 = (invoke_iii($438|0,($433|0),10)|0);
      $440 = __THREW__; __THREW__ = 0;
      $441 = $440&1;
      if ($441) {
       break;
      }
      __ZNSt3__26localeD2Ev($6);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($428,$439)|0);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($428)|0);
     }
     $448 = ((($$sink102)) + 4|0);
     $449 = HEAP32[$410>>2]|0;
     $450 = ($448|0)==($449|0);
     if ($450) {
      break L84;
     } else {
      $$sink102 = $448;
     }
    }
    $442 = ___cxa_find_matching_catch_2()|0;
    $443 = tempRet0;
    __THREW__ = 0;
    invoke_vi(3263,($6|0));
    $444 = __THREW__; __THREW__ = 0;
    $445 = $444&1;
    if ($445) {
     $446 = ___cxa_find_matching_catch_3(0|0)|0;
     $447 = tempRet0;
     ___clang_call_terminate($446);
     // unreachable;
    } else {
     ___resumeException($442|0);
     // unreachable;
    }
   }
  } else {
   __ZN7osgUtil11CullVisitor19addDrawableAndDepthEPN3osg8DrawableEPNS1_10RefMatrixdEf($0,$1,$12,$296);
  }
 } while(0);
 $451 = ($$3|0)==(0);
 if ($451) {
  STACKTOP = sp;return;
 }
 $452 = ((($0)) + 376|0);
 $453 = ((($0)) + 440|0);
 $454 = ((($0)) + 388|0);
 $455 = ((($0)) + 392|0);
 $456 = ((($0)) + 384|0);
 $$pre = HEAP32[$452>>2]|0;
 $$0101 = 0;$458 = $$pre;
 while(1) {
  $457 = ((($458)) + 16|0);
  $459 = HEAP32[$457>>2]|0;
  $460 = ((($459)) + 120|0);
  $461 = HEAP32[$460>>2]|0;
  $462 = $461 & 2;
  $463 = ($462|0)==(0);
  if (!($463)) {
   $464 = HEAP32[$453>>2]|0;
   $465 = (($464) + -1)|0;
   HEAP32[$453>>2] = $465;
  }
  $466 = ($461|0)==(0);
  do {
   if (!($466)) {
    $467 = ((($459)) + 128|0);
    $468 = ((($467)) + 11|0);
    $469 = HEAP8[$468>>0]|0;
    $470 = ($469<<24>>24)<(0);
    if ($470) {
     $471 = ((($459)) + 132|0);
     $472 = HEAP32[$471>>2]|0;
     $474 = $472;
    } else {
     $473 = $469&255;
     $474 = $473;
    }
    $475 = ($474|0)==(0);
    if (!($475)) {
     $476 = HEAP32[$453>>2]|0;
     $477 = ($476|0)!=(0);
     $478 = $461 & 4;
     $479 = ($478|0)==(0);
     $or$cond$i = $479 & $477;
     if (!($or$cond$i)) {
      $480 = HEAP32[$454>>2]|0;
      $481 = HEAP32[$455>>2]|0;
      $482 = ($480|0)==($481|0);
      if ($482) {
       $483 = HEAP32[$456>>2]|0;
       $484 = ((($483)) + 40|0);
       $485 = HEAP32[$484>>2]|0;
       HEAP32[$456>>2] = $485;
       break;
      } else {
       $486 = ((($481)) + -4|0);
       $487 = HEAP32[$486>>2]|0;
       HEAP32[$456>>2] = $487;
       HEAP32[$455>>2] = $486;
       break;
      }
     }
    }
   }
  } while(0);
  $488 = ((($458)) + 12|0);
  $489 = HEAP32[$488>>2]|0;
  HEAP32[$452>>2] = $489;
  $490 = (($$0101) + 1)|0;
  $exitcond = ($490|0)==($$3|0);
  $491 = $489;
  if ($exitcond) {
   break;
  } else {
   $$0101 = $490;$458 = $491;
  }
 }
 STACKTOP = sp;return;
}
function __ZN7osgUtil11CullVisitor5applyERN3osg4NodeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$pre = 0, $$pre$i = 0, $$pre$phiZ2D = 0, $$pre12$pre$phiZZ2D = 0, $$sink$i = 0, $$sroa$03$015$i$i = 0, $$sroa$03$07$i$i$i = 0, $$sroa$09$016$i$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0.0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0;
 var $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0;
 var $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0;
 var $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $or$cond$i = 0, $or$cond$i9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 108|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 do {
  if ($4) {
   $5 = ((($1)) + 104|0);
   $6 = HEAP8[$5>>0]|0;
   $7 = ($6<<24>>24)==(0);
   if ($7) {
    label = 3;
   } else {
    $10 = (__ZNK3osg4Node8getBoundEv($1)|0);
    $11 = ((($10)) + 12|0);
    $12 = +HEAPF32[$11>>2];
    $13 = !($12 >= 0.0);
    $14 = ((($0)) + 336|0);
    $15 = HEAP32[$14>>2]|0;
    if ($13) {
     $$pre12$pre$phiZZ2D = $14;$17 = $15;
     label = 5;
    } else {
     $20 = (__ZNK3osg4Node8getBoundEv($1)|0);
     $21 = (__ZN3osg10CullingSet8isCulledERKNS_18BoundingSphereImplINS_5Vec3fEEE($15,$20)|0);
     if ($21) {
      return;
     } else {
      $$pre = HEAP32[$14>>2]|0;
      $$pre$phiZ2D = $14;$22 = $$pre;
      break;
     }
    }
   }
  } else {
   label = 3;
  }
 } while(0);
 if ((label|0) == 3) {
  $8 = ((($0)) + 336|0);
  $9 = HEAP32[$8>>2]|0;
  $$pre12$pre$phiZZ2D = $8;$17 = $9;
  label = 5;
 }
 if ((label|0) == 5) {
  $16 = ((($17)) + 16|0);
  $18 = HEAP32[$16>>2]|0;
  $19 = ((($17)) + 36|0);
  HEAP32[$19>>2] = $18;
  $$pre$phiZ2D = $$pre12$pre$phiZZ2D;$22 = $17;
 }
 __ZN3osg10CullingSet15pushCurrentMaskEv($22);
 $23 = ((($1)) + 120|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)==(0|0);
 L13: do {
  if ($25) {
   $128 = ((($1)) + 100|0);
   $129 = HEAP32[$128>>2]|0;
   $130 = ($129|0)==(0|0);
   if (!($130)) {
    $131 = HEAP32[$129>>2]|0;
    $132 = ((($131)) + 92|0);
    $133 = HEAP32[$132>>2]|0;
    $134 = HEAP32[$0>>2]|0;
    $135 = ((($134)) + -12|0);
    $136 = HEAP32[$135>>2]|0;
    $137 = (($0) + ($136)|0);
    (FUNCTION_TABLE_iiii[$133 & 8191]($129,$1,$137)|0);
    break;
   }
   $138 = ((($0)) + 16|0);
   $139 = HEAP32[$138>>2]|0;
   switch ($139|0) {
   case 0:  {
    break L13;
    break;
   }
   case 1:  {
    $140 = HEAP32[$1>>2]|0;
    $141 = ((($140)) + 192|0);
    $142 = HEAP32[$141>>2]|0;
    FUNCTION_TABLE_vii[$142 & 8191]($1,$0);
    break L13;
    break;
   }
   default: {
    $143 = HEAP32[$1>>2]|0;
    $144 = ((($143)) + 196|0);
    $145 = HEAP32[$144>>2]|0;
    FUNCTION_TABLE_vii[$145 & 8191]($1,$0);
    break L13;
   }
   }
  } else {
   $26 = ((($0)) + 376|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = (__ZN7osgUtil10StateGraph14find_or_insertEPKN3osg8StateSetE($27,$24)|0);
   HEAP32[$26>>2] = $28;
   $29 = ((($24)) + 120|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = ($30|0)==(0);
   if (!($31)) {
    $32 = ((($24)) + 128|0);
    $33 = ((($32)) + 11|0);
    $34 = HEAP8[$33>>0]|0;
    $35 = ($34<<24>>24)<(0);
    if ($35) {
     $36 = ((($24)) + 132|0);
     $37 = HEAP32[$36>>2]|0;
     $39 = $37;
    } else {
     $38 = $34&255;
     $39 = $38;
    }
    $40 = ($39|0)==(0);
    if ($40) {
     $66 = $30;
    } else {
     $41 = ((($0)) + 440|0);
     $42 = HEAP32[$41>>2]|0;
     $43 = ($42|0)!=(0);
     $44 = $30 & 4;
     $45 = ($44|0)==(0);
     $or$cond$i = $45 & $43;
     if ($or$cond$i) {
      $66 = $30;
     } else {
      $46 = ((($0)) + 384|0);
      $47 = ((($0)) + 392|0);
      $48 = HEAP32[$47>>2]|0;
      $49 = ((($0)) + 396|0);
      $50 = HEAP32[$49>>2]|0;
      $51 = ($48|0)==($50|0);
      if ($51) {
       $55 = ((($0)) + 388|0);
       __ZNSt3__26vectorIPN7osgUtil9RenderBinENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_($55,$46);
      } else {
       $52 = HEAP32[$46>>2]|0;
       HEAP32[$48>>2] = $52;
       $53 = HEAP32[$47>>2]|0;
       $54 = ((($53)) + 4|0);
       HEAP32[$47>>2] = $54;
      }
      $56 = ((($24)) + 140|0);
      $57 = HEAP8[$56>>0]|0;
      $58 = ($57<<24>>24)==(0);
      $59 = HEAP32[$46>>2]|0;
      if ($58) {
       $60 = ((($59)) + 40|0);
       $61 = HEAP32[$60>>2]|0;
       $$sink$i = $61;
      } else {
       $$sink$i = $59;
      }
      $62 = ((($24)) + 124|0);
      $63 = HEAP32[$62>>2]|0;
      $64 = (__ZN7osgUtil9RenderBin14find_or_insertEiRKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE($$sink$i,$63,$32)|0);
      HEAP32[$46>>2] = $64;
      $$pre$i = HEAP32[$29>>2]|0;
      $66 = $$pre$i;
     }
    }
    $65 = $66 & 2;
    $67 = ($65|0)==(0);
    if (!($67)) {
     $68 = ((($0)) + 440|0);
     $69 = HEAP32[$68>>2]|0;
     $70 = (($69) + 1)|0;
     HEAP32[$68>>2] = $70;
    }
   }
   $71 = ((($1)) + 100|0);
   $72 = HEAP32[$71>>2]|0;
   $73 = ($72|0)==(0|0);
   L41: do {
    if ($73) {
     $81 = ((($0)) + 16|0);
     $82 = HEAP32[$81>>2]|0;
     switch ($82|0) {
     case 0:  {
      break L41;
      break;
     }
     case 1:  {
      $83 = HEAP32[$1>>2]|0;
      $84 = ((($83)) + 192|0);
      $85 = HEAP32[$84>>2]|0;
      FUNCTION_TABLE_vii[$85 & 8191]($1,$0);
      break L41;
      break;
     }
     default: {
      $86 = HEAP32[$1>>2]|0;
      $87 = ((($86)) + 196|0);
      $88 = HEAP32[$87>>2]|0;
      FUNCTION_TABLE_vii[$88 & 8191]($1,$0);
      break L41;
     }
     }
    } else {
     $74 = HEAP32[$72>>2]|0;
     $75 = ((($74)) + 92|0);
     $76 = HEAP32[$75>>2]|0;
     $77 = HEAP32[$0>>2]|0;
     $78 = ((($77)) + -12|0);
     $79 = HEAP32[$78>>2]|0;
     $80 = (($0) + ($79)|0);
     (FUNCTION_TABLE_iiii[$76 & 8191]($72,$1,$80)|0);
    }
   } while(0);
   $89 = HEAP32[$26>>2]|0;
   $90 = ((($89)) + 16|0);
   $91 = HEAP32[$90>>2]|0;
   $92 = ((($91)) + 120|0);
   $93 = HEAP32[$92>>2]|0;
   $94 = $93 & 2;
   $95 = ($94|0)==(0);
   if (!($95)) {
    $96 = ((($0)) + 440|0);
    $97 = HEAP32[$96>>2]|0;
    $98 = (($97) + -1)|0;
    HEAP32[$96>>2] = $98;
   }
   $99 = ($93|0)==(0);
   do {
    if (!($99)) {
     $100 = ((($91)) + 128|0);
     $101 = ((($100)) + 11|0);
     $102 = HEAP8[$101>>0]|0;
     $103 = ($102<<24>>24)<(0);
     if ($103) {
      $104 = ((($91)) + 132|0);
      $105 = HEAP32[$104>>2]|0;
      $107 = $105;
     } else {
      $106 = $102&255;
      $107 = $106;
     }
     $108 = ($107|0)==(0);
     if (!($108)) {
      $109 = ((($0)) + 440|0);
      $110 = HEAP32[$109>>2]|0;
      $111 = ($110|0)!=(0);
      $112 = $93 & 4;
      $113 = ($112|0)==(0);
      $or$cond$i9 = $113 & $111;
      if (!($or$cond$i9)) {
       $114 = ((($0)) + 388|0);
       $115 = HEAP32[$114>>2]|0;
       $116 = ((($0)) + 392|0);
       $117 = HEAP32[$116>>2]|0;
       $118 = ($115|0)==($117|0);
       if ($118) {
        $119 = ((($0)) + 384|0);
        $120 = HEAP32[$119>>2]|0;
        $121 = ((($120)) + 40|0);
        $122 = HEAP32[$121>>2]|0;
        HEAP32[$119>>2] = $122;
        break;
       } else {
        $123 = ((($117)) + -4|0);
        $124 = HEAP32[$123>>2]|0;
        $125 = ((($0)) + 384|0);
        HEAP32[$125>>2] = $124;
        HEAP32[$116>>2] = $123;
        break;
       }
      }
     }
    }
   } while(0);
   $126 = ((($89)) + 12|0);
   $127 = HEAP32[$126>>2]|0;
   HEAP32[$26>>2] = $127;
  }
 } while(0);
 $146 = HEAP32[$$pre$phiZ2D>>2]|0;
 $147 = ((($146)) + 32|0);
 $148 = HEAP32[$147>>2]|0;
 $149 = ($148|0)==(0);
 if (!($149)) {
  $150 = ((($146)) + 20|0);
  $151 = HEAP32[$150>>2]|0;
  $152 = ((($146)) + 24|0);
  $153 = HEAP32[$152>>2]|0;
  $154 = ($151|0)==($153|0);
  if (!($154)) {
   $155 = ((($153)) + -4|0);
   $156 = HEAP32[$155>>2]|0;
   $157 = ((($146)) + 16|0);
   HEAP32[$157>>2] = $156;
   HEAP32[$152>>2] = $155;
  }
  $158 = (($148) + -1)|0;
  HEAP32[$147>>2] = $158;
 }
 $159 = ((($146)) + 64|0);
 $160 = HEAP32[$159>>2]|0;
 $161 = ((($146)) + 68|0);
 $162 = HEAP32[$161>>2]|0;
 $163 = ($160|0)==($162|0);
 if (!($163)) {
  $$sroa$09$016$i$i = $160;
  while(1) {
   $164 = ((($$sroa$09$016$i$i)) + 20|0);
   $165 = HEAP32[$164>>2]|0;
   $166 = ($165|0)==(0);
   if (!($166)) {
    $167 = ((($$sroa$09$016$i$i)) + 8|0);
    $168 = HEAP32[$167>>2]|0;
    $169 = ((($$sroa$09$016$i$i)) + 12|0);
    $170 = HEAP32[$169>>2]|0;
    $171 = ($168|0)==($170|0);
    if (!($171)) {
     $172 = ((($170)) + -4|0);
     $173 = HEAP32[$172>>2]|0;
     $174 = ((($$sroa$09$016$i$i)) + 4|0);
     HEAP32[$174>>2] = $173;
     HEAP32[$169>>2] = $172;
    }
    $175 = (($165) + -1)|0;
    HEAP32[$164>>2] = $175;
   }
   $176 = ((($$sroa$09$016$i$i)) + 52|0);
   $177 = ($176|0)==($162|0);
   if ($177) {
    break;
   } else {
    $$sroa$09$016$i$i = $176;
   }
  }
 }
 $178 = ((($146)) + 76|0);
 $179 = HEAP32[$178>>2]|0;
 $180 = ((($146)) + 80|0);
 $181 = HEAP32[$180>>2]|0;
 $182 = ($179|0)==($181|0);
 if ($182) {
  return;
 } else {
  $$sroa$03$015$i$i = $179;
 }
 while(1) {
  $183 = ((($$sroa$03$015$i$i)) + 36|0);
  $184 = HEAP32[$183>>2]|0;
  $185 = ($184|0)==(0);
  if (!($185)) {
   $186 = ((($$sroa$03$015$i$i)) + 24|0);
   $187 = HEAP32[$186>>2]|0;
   $188 = ((($$sroa$03$015$i$i)) + 28|0);
   $189 = HEAP32[$188>>2]|0;
   $190 = ($187|0)==($189|0);
   if (!($190)) {
    $191 = ((($189)) + -4|0);
    $192 = HEAP32[$191>>2]|0;
    $193 = ((($$sroa$03$015$i$i)) + 20|0);
    HEAP32[$193>>2] = $192;
    HEAP32[$188>>2] = $191;
   }
   $194 = (($184) + -1)|0;
   HEAP32[$183>>2] = $194;
  }
  $195 = ((($$sroa$03$015$i$i)) + 68|0);
  $196 = HEAP32[$195>>2]|0;
  $197 = ((($$sroa$03$015$i$i)) + 72|0);
  $198 = HEAP32[$197>>2]|0;
  $199 = ($196|0)==($198|0);
  if (!($199)) {
   $$sroa$03$07$i$i$i = $196;
   while(1) {
    $200 = ((($$sroa$03$07$i$i$i)) + 16|0);
    $201 = HEAP32[$200>>2]|0;
    $202 = ($201|0)==(0);
    if (!($202)) {
     $203 = ((($$sroa$03$07$i$i$i)) + 4|0);
     $204 = HEAP32[$203>>2]|0;
     $205 = ((($$sroa$03$07$i$i$i)) + 8|0);
     $206 = HEAP32[$205>>2]|0;
     $207 = ($204|0)==($206|0);
     if (!($207)) {
      $208 = ((($206)) + -4|0);
      $209 = HEAP32[$208>>2]|0;
      HEAP32[$$sroa$03$07$i$i$i>>2] = $209;
      HEAP32[$205>>2] = $208;
     }
     $210 = (($201) + -1)|0;
     HEAP32[$200>>2] = $210;
    }
    $211 = ((($$sroa$03$07$i$i$i)) + 48|0);
    $212 = ($211|0)==($198|0);
    if ($212) {
     break;
    } else {
     $$sroa$03$07$i$i$i = $211;
    }
   }
  }
  $213 = ((($$sroa$03$015$i$i)) + 80|0);
  $214 = ($213|0)==($181|0);
  if ($214) {
   break;
  } else {
   $$sroa$03$015$i$i = $213;
  }
 }
 return;
}
function __ZN7osgUtil11CullVisitor5applyERN3osg5GeodeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$pre = 0, $$pre$i = 0, $$pre$phiZ2D = 0, $$pre12$pre$phiZZ2D = 0, $$sink$i = 0, $$sroa$03$015$i$i = 0, $$sroa$03$07$i$i$i = 0, $$sroa$09$016$i$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0.0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0;
 var $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0;
 var $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0;
 var $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $or$cond$i = 0, $or$cond$i9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 108|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 do {
  if ($4) {
   $5 = ((($1)) + 104|0);
   $6 = HEAP8[$5>>0]|0;
   $7 = ($6<<24>>24)==(0);
   if ($7) {
    label = 3;
   } else {
    $10 = (__ZNK3osg4Node8getBoundEv($1)|0);
    $11 = ((($10)) + 12|0);
    $12 = +HEAPF32[$11>>2];
    $13 = !($12 >= 0.0);
    $14 = ((($0)) + 336|0);
    $15 = HEAP32[$14>>2]|0;
    if ($13) {
     $$pre12$pre$phiZZ2D = $14;$17 = $15;
     label = 5;
    } else {
     $20 = (__ZNK3osg4Node8getBoundEv($1)|0);
     $21 = (__ZN3osg10CullingSet8isCulledERKNS_18BoundingSphereImplINS_5Vec3fEEE($15,$20)|0);
     if ($21) {
      return;
     } else {
      $$pre = HEAP32[$14>>2]|0;
      $$pre$phiZ2D = $14;$22 = $$pre;
      break;
     }
    }
   }
  } else {
   label = 3;
  }
 } while(0);
 if ((label|0) == 3) {
  $8 = ((($0)) + 336|0);
  $9 = HEAP32[$8>>2]|0;
  $$pre12$pre$phiZZ2D = $8;$17 = $9;
  label = 5;
 }
 if ((label|0) == 5) {
  $16 = ((($17)) + 16|0);
  $18 = HEAP32[$16>>2]|0;
  $19 = ((($17)) + 36|0);
  HEAP32[$19>>2] = $18;
  $$pre$phiZ2D = $$pre12$pre$phiZZ2D;$22 = $17;
 }
 __ZN3osg10CullingSet15pushCurrentMaskEv($22);
 $23 = ((($1)) + 120|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)==(0|0);
 L13: do {
  if ($25) {
   $128 = ((($1)) + 100|0);
   $129 = HEAP32[$128>>2]|0;
   $130 = ($129|0)==(0|0);
   if (!($130)) {
    $131 = HEAP32[$129>>2]|0;
    $132 = ((($131)) + 92|0);
    $133 = HEAP32[$132>>2]|0;
    $134 = HEAP32[$0>>2]|0;
    $135 = ((($134)) + -12|0);
    $136 = HEAP32[$135>>2]|0;
    $137 = (($0) + ($136)|0);
    (FUNCTION_TABLE_iiii[$133 & 8191]($129,$1,$137)|0);
    break;
   }
   $138 = ((($0)) + 16|0);
   $139 = HEAP32[$138>>2]|0;
   switch ($139|0) {
   case 0:  {
    break L13;
    break;
   }
   case 1:  {
    $140 = HEAP32[$1>>2]|0;
    $141 = ((($140)) + 192|0);
    $142 = HEAP32[$141>>2]|0;
    FUNCTION_TABLE_vii[$142 & 8191]($1,$0);
    break L13;
    break;
   }
   default: {
    $143 = HEAP32[$1>>2]|0;
    $144 = ((($143)) + 196|0);
    $145 = HEAP32[$144>>2]|0;
    FUNCTION_TABLE_vii[$145 & 8191]($1,$0);
    break L13;
   }
   }
  } else {
   $26 = ((($0)) + 376|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = (__ZN7osgUtil10StateGraph14find_or_insertEPKN3osg8StateSetE($27,$24)|0);
   HEAP32[$26>>2] = $28;
   $29 = ((($24)) + 120|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = ($30|0)==(0);
   if (!($31)) {
    $32 = ((($24)) + 128|0);
    $33 = ((($32)) + 11|0);
    $34 = HEAP8[$33>>0]|0;
    $35 = ($34<<24>>24)<(0);
    if ($35) {
     $36 = ((($24)) + 132|0);
     $37 = HEAP32[$36>>2]|0;
     $39 = $37;
    } else {
     $38 = $34&255;
     $39 = $38;
    }
    $40 = ($39|0)==(0);
    if ($40) {
     $66 = $30;
    } else {
     $41 = ((($0)) + 440|0);
     $42 = HEAP32[$41>>2]|0;
     $43 = ($42|0)!=(0);
     $44 = $30 & 4;
     $45 = ($44|0)==(0);
     $or$cond$i = $45 & $43;
     if ($or$cond$i) {
      $66 = $30;
     } else {
      $46 = ((($0)) + 384|0);
      $47 = ((($0)) + 392|0);
      $48 = HEAP32[$47>>2]|0;
      $49 = ((($0)) + 396|0);
      $50 = HEAP32[$49>>2]|0;
      $51 = ($48|0)==($50|0);
      if ($51) {
       $55 = ((($0)) + 388|0);
       __ZNSt3__26vectorIPN7osgUtil9RenderBinENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_($55,$46);
      } else {
       $52 = HEAP32[$46>>2]|0;
       HEAP32[$48>>2] = $52;
       $53 = HEAP32[$47>>2]|0;
       $54 = ((($53)) + 4|0);
       HEAP32[$47>>2] = $54;
      }
      $56 = ((($24)) + 140|0);
      $57 = HEAP8[$56>>0]|0;
      $58 = ($57<<24>>24)==(0);
      $59 = HEAP32[$46>>2]|0;
      if ($58) {
       $60 = ((($59)) + 40|0);
       $61 = HEAP32[$60>>2]|0;
       $$sink$i = $61;
      } else {
       $$sink$i = $59;
      }
      $62 = ((($24)) + 124|0);
      $63 = HEAP32[$62>>2]|0;
      $64 = (__ZN7osgUtil9RenderBin14find_or_insertEiRKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE($$sink$i,$63,$32)|0);
      HEAP32[$46>>2] = $64;
      $$pre$i = HEAP32[$29>>2]|0;
      $66 = $$pre$i;
     }
    }
    $65 = $66 & 2;
    $67 = ($65|0)==(0);
    if (!($67)) {
     $68 = ((($0)) + 440|0);
     $69 = HEAP32[$68>>2]|0;
     $70 = (($69) + 1)|0;
     HEAP32[$68>>2] = $70;
    }
   }
   $71 = ((($1)) + 100|0);
   $72 = HEAP32[$71>>2]|0;
   $73 = ($72|0)==(0|0);
   L41: do {
    if ($73) {
     $81 = ((($0)) + 16|0);
     $82 = HEAP32[$81>>2]|0;
     switch ($82|0) {
     case 0:  {
      break L41;
      break;
     }
     case 1:  {
      $83 = HEAP32[$1>>2]|0;
      $84 = ((($83)) + 192|0);
      $85 = HEAP32[$84>>2]|0;
      FUNCTION_TABLE_vii[$85 & 8191]($1,$0);
      break L41;
      break;
     }
     default: {
      $86 = HEAP32[$1>>2]|0;
      $87 = ((($86)) + 196|0);
      $88 = HEAP32[$87>>2]|0;
      FUNCTION_TABLE_vii[$88 & 8191]($1,$0);
      break L41;
     }
     }
    } else {
     $74 = HEAP32[$72>>2]|0;
     $75 = ((($74)) + 92|0);
     $76 = HEAP32[$75>>2]|0;
     $77 = HEAP32[$0>>2]|0;
     $78 = ((($77)) + -12|0);
     $79 = HEAP32[$78>>2]|0;
     $80 = (($0) + ($79)|0);
     (FUNCTION_TABLE_iiii[$76 & 8191]($72,$1,$80)|0);
    }
   } while(0);
   $89 = HEAP32[$26>>2]|0;
   $90 = ((($89)) + 16|0);
   $91 = HEAP32[$90>>2]|0;
   $92 = ((($91)) + 120|0);
   $93 = HEAP32[$92>>2]|0;
   $94 = $93 & 2;
   $95 = ($94|0)==(0);
   if (!($95)) {
    $96 = ((($0)) + 440|0);
    $97 = HEAP32[$96>>2]|0;
    $98 = (($97) + -1)|0;
    HEAP32[$96>>2] = $98;
   }
   $99 = ($93|0)==(0);
   do {
    if (!($99)) {
     $100 = ((($91)) + 128|0);
     $101 = ((($100)) + 11|0);
     $102 = HEAP8[$101>>0]|0;
     $103 = ($102<<24>>24)<(0);
     if ($103) {
      $104 = ((($91)) + 132|0);
      $105 = HEAP32[$104>>2]|0;
      $107 = $105;
     } else {
      $106 = $102&255;
      $107 = $106;
     }
     $108 = ($107|0)==(0);
     if (!($108)) {
      $109 = ((($0)) + 440|0);
      $110 = HEAP32[$109>>2]|0;
      $111 = ($110|0)!=(0);
      $112 = $93 & 4;
      $113 = ($112|0)==(0);
      $or$cond$i9 = $113 & $111;
      if (!($or$cond$i9)) {
       $114 = ((($0)) + 388|0);
       $115 = HEAP32[$114>>2]|0;
       $116 = ((($0)) + 392|0);
       $117 = HEAP32[$116>>2]|0;
       $118 = ($115|0)==($117|0);
       if ($118) {
        $119 = ((($0)) + 384|0);
        $120 = HEAP32[$119>>2]|0;
        $121 = ((($120)) + 40|0);
        $122 = HEAP32[$121>>2]|0;
        HEAP32[$119>>2] = $122;
        break;
       } else {
        $123 = ((($117)) + -4|0);
        $124 = HEAP32[$123>>2]|0;
        $125 = ((($0)) + 384|0);
        HEAP32[$125>>2] = $124;
        HEAP32[$116>>2] = $123;
        break;
       }
      }
     }
    }
   } while(0);
   $126 = ((($89)) + 12|0);
   $127 = HEAP32[$126>>2]|0;
   HEAP32[$26>>2] = $127;
  }
 } while(0);
 $146 = HEAP32[$$pre$phiZ2D>>2]|0;
 $147 = ((($146)) + 32|0);
 $148 = HEAP32[$147>>2]|0;
 $149 = ($148|0)==(0);
 if (!($149)) {
  $150 = ((($146)) + 20|0);
  $151 = HEAP32[$150>>2]|0;
  $152 = ((($146)) + 24|0);
  $153 = HEAP32[$152>>2]|0;
  $154 = ($151|0)==($153|0);
  if (!($154)) {
   $155 = ((($153)) + -4|0);
   $156 = HEAP32[$155>>2]|0;
   $157 = ((($146)) + 16|0);
   HEAP32[$157>>2] = $156;
   HEAP32[$152>>2] = $155;
  }
  $158 = (($148) + -1)|0;
  HEAP32[$147>>2] = $158;
 }
 $159 = ((($146)) + 64|0);
 $160 = HEAP32[$159>>2]|0;
 $161 = ((($146)) + 68|0);
 $162 = HEAP32[$161>>2]|0;
 $163 = ($160|0)==($162|0);
 if (!($163)) {
  $$sroa$09$016$i$i = $160;
  while(1) {
   $164 = ((($$sroa$09$016$i$i)) + 20|0);
   $165 = HEAP32[$164>>2]|0;
   $166 = ($165|0)==(0);
   if (!($166)) {
    $167 = ((($$sroa$09$016$i$i)) + 8|0);
    $168 = HEAP32[$167>>2]|0;
    $169 = ((($$sroa$09$016$i$i)) + 12|0);
    $170 = HEAP32[$169>>2]|0;
    $171 = ($168|0)==($170|0);
    if (!($171)) {
     $172 = ((($170)) + -4|0);
     $173 = HEAP32[$172>>2]|0;
     $174 = ((($$sroa$09$016$i$i)) + 4|0);
     HEAP32[$174>>2] = $173;
     HEAP32[$169>>2] = $172;
    }
    $175 = (($165) + -1)|0;
    HEAP32[$164>>2] = $175;
   }
   $176 = ((($$sroa$09$016$i$i)) + 52|0);
   $177 = ($176|0)==($162|0);
   if ($177) {
    break;
   } else {
    $$sroa$09$016$i$i = $176;
   }
  }
 }
 $178 = ((($146)) + 76|0);
 $179 = HEAP32[$178>>2]|0;
 $180 = ((($146)) + 80|0);
 $181 = HEAP32[$180>>2]|0;
 $182 = ($179|0)==($181|0);
 if ($182) {
  return;
 } else {
  $$sroa$03$015$i$i = $179;
 }
 while(1) {
  $183 = ((($$sroa$03$015$i$i)) + 36|0);
  $184 = HEAP32[$183>>2]|0;
  $185 = ($184|0)==(0);
  if (!($185)) {
   $186 = ((($$sroa$03$015$i$i)) + 24|0);
   $187 = HEAP32[$186>>2]|0;
   $188 = ((($$sroa$03$015$i$i)) + 28|0);
   $189 = HEAP32[$188>>2]|0;
   $190 = ($187|0)==($189|0);
   if (!($190)) {
    $191 = ((($189)) + -4|0);
    $192 = HEAP32[$191>>2]|0;
    $193 = ((($$sroa$03$015$i$i)) + 20|0);
    HEAP32[$193>>2] = $192;
    HEAP32[$188>>2] = $191;
   }
   $194 = (($184) + -1)|0;
   HEAP32[$183>>2] = $194;
  }
  $195 = ((($$sroa$03$015$i$i)) + 68|0);
  $196 = HEAP32[$195>>2]|0;
  $197 = ((($$sroa$03$015$i$i)) + 72|0);
  $198 = HEAP32[$197>>2]|0;
  $199 = ($196|0)==($198|0);
  if (!($199)) {
   $$sroa$03$07$i$i$i = $196;
   while(1) {
    $200 = ((($$sroa$03$07$i$i$i)) + 16|0);
    $201 = HEAP32[$200>>2]|0;
    $202 = ($201|0)==(0);
    if (!($202)) {
     $203 = ((($$sroa$03$07$i$i$i)) + 4|0);
     $204 = HEAP32[$203>>2]|0;
     $205 = ((($$sroa$03$07$i$i$i)) + 8|0);
     $206 = HEAP32[$205>>2]|0;
     $207 = ($204|0)==($206|0);
     if (!($207)) {
      $208 = ((($206)) + -4|0);
      $209 = HEAP32[$208>>2]|0;
      HEAP32[$$sroa$03$07$i$i$i>>2] = $209;
      HEAP32[$205>>2] = $208;
     }
     $210 = (($201) + -1)|0;
     HEAP32[$200>>2] = $210;
    }
    $211 = ((($$sroa$03$07$i$i$i)) + 48|0);
    $212 = ($211|0)==($198|0);
    if ($212) {
     break;
    } else {
     $$sroa$03$07$i$i$i = $211;
    }
   }
  }
  $213 = ((($$sroa$03$015$i$i)) + 80|0);
  $214 = ($213|0)==($181|0);
  if ($214) {
   break;
  } else {
   $$sroa$03$015$i$i = $213;
  }
 }
 return;
}
function __ZN7osgUtil11CullVisitor5applyERN3osg9BillboardE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$096 = 0, $$pre$i = 0, $$pre$i74 = 0, $$sink$i = 0, $$sink$i60 = 0, $$sink$i73 = 0, $$sink95 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0.0, $136 = 0.0, $137 = 0, $138 = 0, $139 = 0.0, $14 = 0, $140 = 0, $141 = 0.0, $142 = 0, $143 = 0, $144 = 0.0, $145 = 0, $146 = 0.0, $147 = 0;
 var $148 = 0.0, $149 = 0.0, $15 = 0, $150 = 0.0, $151 = 0.0, $152 = 0, $153 = 0.0, $154 = 0.0, $155 = 0.0, $156 = 0.0, $157 = 0.0, $158 = 0, $159 = 0.0, $16 = 0, $160 = 0.0, $161 = 0.0, $162 = 0.0, $163 = 0.0, $164 = 0.0, $165 = 0.0;
 var $166 = 0.0, $167 = 0.0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0.0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0;
 var $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0;
 var $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0.0;
 var $238 = 0, $239 = 0, $24 = 0, $240 = 0.0, $241 = 0, $242 = 0, $243 = 0.0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0;
 var $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0;
 var $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0;
 var $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0;
 var $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0;
 var $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0;
 var $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0;
 var $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0;
 var $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0;
 var $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0;
 var $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond$i = 0, $or$cond$i62 = 0, $or$cond$i65 = 0, $or$cond$i70 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $2 = sp + 16|0;
 $3 = sp + 12|0;
 $4 = sp + 8|0;
 $5 = sp + 4|0;
 $6 = sp;
 $7 = ((($0)) + 56|0);
 $8 = ((($1)) + 108|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0);
 if ($10) {
  $11 = ((($1)) + 104|0);
  $12 = HEAP8[$11>>0]|0;
  $13 = ($12<<24>>24)==(0);
  if ($13) {
   label = 3;
  } else {
   $16 = (__ZNK3osg4Node8getBoundEv($1)|0);
   $17 = ((($16)) + 12|0);
   $18 = +HEAPF32[$17>>2];
   $19 = !($18 >= 0.0);
   $20 = ((($0)) + 336|0);
   $21 = HEAP32[$20>>2]|0;
   if ($19) {
    $23 = $21;
    label = 5;
   } else {
    $26 = (__ZNK3osg4Node8getBoundEv($1)|0);
    $27 = (__ZN3osg10CullingSet8isCulledERKNS_18BoundingSphereImplINS_5Vec3fEEE($21,$26)|0);
    if ($27) {
     STACKTOP = sp;return;
    }
   }
  }
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $14 = ((($0)) + 336|0);
  $15 = HEAP32[$14>>2]|0;
  $23 = $15;
  label = 5;
 }
 if ((label|0) == 5) {
  $22 = ((($23)) + 16|0);
  $24 = HEAP32[$22>>2]|0;
  $25 = ((($23)) + 36|0);
  HEAP32[$25>>2] = $24;
 }
 $28 = ((($1)) + 120|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ($29|0)!=(0|0);
 if ($30) {
  $31 = ((($0)) + 376|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = (__ZN7osgUtil10StateGraph14find_or_insertEPKN3osg8StateSetE($32,$29)|0);
  HEAP32[$31>>2] = $33;
  $34 = ((($29)) + 120|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = ($35|0)==(0);
  if (!($36)) {
   $37 = ((($29)) + 128|0);
   $38 = ((($37)) + 11|0);
   $39 = HEAP8[$38>>0]|0;
   $40 = ($39<<24>>24)<(0);
   if ($40) {
    $41 = ((($29)) + 132|0);
    $42 = HEAP32[$41>>2]|0;
    $44 = $42;
   } else {
    $43 = $39&255;
    $44 = $43;
   }
   $45 = ($44|0)==(0);
   if ($45) {
    $71 = $35;
   } else {
    $46 = ((($0)) + 440|0);
    $47 = HEAP32[$46>>2]|0;
    $48 = ($47|0)!=(0);
    $49 = $35 & 4;
    $50 = ($49|0)==(0);
    $or$cond$i = $50 & $48;
    if ($or$cond$i) {
     $71 = $35;
    } else {
     $51 = ((($0)) + 384|0);
     $52 = ((($0)) + 392|0);
     $53 = HEAP32[$52>>2]|0;
     $54 = ((($0)) + 396|0);
     $55 = HEAP32[$54>>2]|0;
     $56 = ($53|0)==($55|0);
     if ($56) {
      $60 = ((($0)) + 388|0);
      __ZNSt3__26vectorIPN7osgUtil9RenderBinENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_($60,$51);
     } else {
      $57 = HEAP32[$51>>2]|0;
      HEAP32[$53>>2] = $57;
      $58 = HEAP32[$52>>2]|0;
      $59 = ((($58)) + 4|0);
      HEAP32[$52>>2] = $59;
     }
     $61 = ((($29)) + 140|0);
     $62 = HEAP8[$61>>0]|0;
     $63 = ($62<<24>>24)==(0);
     $64 = HEAP32[$51>>2]|0;
     if ($63) {
      $65 = ((($64)) + 40|0);
      $66 = HEAP32[$65>>2]|0;
      $$sink$i = $66;
     } else {
      $$sink$i = $64;
     }
     $67 = ((($29)) + 124|0);
     $68 = HEAP32[$67>>2]|0;
     $69 = (__ZN7osgUtil9RenderBin14find_or_insertEiRKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE($$sink$i,$68,$37)|0);
     HEAP32[$51>>2] = $69;
     $$pre$i = HEAP32[$34>>2]|0;
     $71 = $$pre$i;
    }
   }
   $70 = $71 & 2;
   $72 = ($70|0)==(0);
   if (!($72)) {
    $73 = ((($0)) + 440|0);
    $74 = HEAP32[$73>>2]|0;
    $75 = (($74) + 1)|0;
    HEAP32[$73>>2] = $75;
   }
  }
 }
 $76 = ((($0)) + 240|0);
 $77 = ((($0)) + 168|0);
 $78 = HEAP32[$77>>2]|0;
 $79 = ($78|0)==(0);
 $80 = ((($0)) + 152|0);
 $81 = ((($0)) + 352|0);
 $$sink$i60 = $79 ? $81 : $80;
 $82 = HEAP32[$$sink$i60>>2]|0;
 $83 = HEAP32[$1>>2]|0;
 $84 = ((($83)) + 224|0);
 $85 = HEAP32[$84>>2]|0;
 $86 = (FUNCTION_TABLE_ii[$85 & 8191]($1)|0);
 $87 = ($86|0)==(0);
 L31: do {
  if (!($87)) {
   $88 = ((($1)) + 320|0);
   $89 = ((($1)) + 124|0);
   $90 = ((($82)) + 32|0);
   $91 = ((($0)) + 68|0);
   $92 = ((($82)) + 48|0);
   $93 = ((($82)) + 80|0);
   $94 = ((($82)) + 112|0);
   $95 = ((($82)) + 144|0);
   $96 = ((($0)) + 376|0);
   $97 = ((($0)) + 440|0);
   $98 = ((($0)) + 384|0);
   $99 = ((($0)) + 392|0);
   $100 = ((($0)) + 396|0);
   $101 = ((($0)) + 388|0);
   $102 = ((($0)) + 28|0);
   $103 = ((($0)) + 32|0);
   $104 = ((($0)) + 388|0);
   $105 = ((($0)) + 444|0);
   $$096 = 0;
   L33: while(1) {
    $106 = HEAP32[$88>>2]|0;
    $107 = (($106) + (($$096*12)|0)|0);
    $108 = HEAP32[$89>>2]|0;
    $109 = (($108) + ($$096<<2)|0);
    $110 = HEAP32[$109>>2]|0;
    $111 = ($110|0)==(0|0);
    if ($111) {
     $117 = 0;
    } else {
     $112 = HEAP32[$110>>2]|0;
     $113 = ((($112)) + 80|0);
     $114 = HEAP32[$113>>2]|0;
     $115 = (FUNCTION_TABLE_ii[$114 & 8191]($110)|0);
     $117 = $115;
    }
    $116 = ((($117)) + 100|0);
    $118 = HEAP32[$116>>2]|0;
    $119 = ($118|0)==(0|0);
    if ($119) {
     label = 30;
    } else {
     $120 = HEAP32[$118>>2]|0;
     $121 = ((($120)) + 76|0);
     $122 = HEAP32[$121>>2]|0;
     $123 = (FUNCTION_TABLE_ii[$122 & 8191]($118)|0);
     $124 = ($123|0)==(0|0);
     if ($124) {
      label = 30;
     } else {
      $125 = HEAP32[$123>>2]|0;
      $126 = ((($125)) + 32|0);
      $127 = HEAP32[$126>>2]|0;
      $128 = (FUNCTION_TABLE_iiiii[$127 & 8191]($123,$0,$117,$105)|0);
      if (!($128)) {
       label = 30;
      }
     }
    }
    if ((label|0) == 30) {
     label = 0;
     $129 = (__ZN3osg9CullStack19createOrReuseMatrixERKNS_7MatrixdE($7,$90)|0);
     $130 = ((($129)) + 32|0);
     (__ZNK3osg9Billboard13computeMatrixERNS_7MatrixdERKNS_5Vec3fES5_($1,$130,$76,$107)|0);
     $131 = HEAP32[$91>>2]|0;
     $132 = ($131|0)==(0);
     if (!($132)) {
      $133 = (__ZNK3osg8Drawable14getBoundingBoxEv($117)|0);
      $134 = ((($133)) + 12|0);
      $135 = +HEAPF32[$134>>2];
      $136 = +HEAPF32[$133>>2];
      $137 = !($135 >= $136);
      if (!($137)) {
       $138 = ((($133)) + 16|0);
       $139 = +HEAPF32[$138>>2];
       $140 = ((($133)) + 4|0);
       $141 = +HEAPF32[$140>>2];
       $142 = !($139 >= $141);
       if (!($142)) {
        $143 = ((($133)) + 20|0);
        $144 = +HEAPF32[$143>>2];
        $145 = ((($133)) + 8|0);
        $146 = +HEAPF32[$145>>2];
        $147 = !($144 >= $146);
        if (!($147)) {
         (__ZN7osgUtil11CullVisitor23updateCalculatedNearFarERKN3osg7MatrixdERKNS1_8DrawableEb($0,$130,$117,1)|0);
        }
       }
      }
     }
     $148 = +HEAPF32[$107>>2];
     $149 = $148;
     $150 = +HEAPF64[$92>>3];
     $151 = $149 * $150;
     $152 = (((($106) + (($$096*12)|0)|0)) + 4|0);
     $153 = +HEAPF32[$152>>2];
     $154 = $153;
     $155 = +HEAPF64[$93>>3];
     $156 = $154 * $155;
     $157 = $151 + $156;
     $158 = (((($106) + (($$096*12)|0)|0)) + 8|0);
     $159 = +HEAPF32[$158>>2];
     $160 = $159;
     $161 = +HEAPF64[$94>>3];
     $162 = $160 * $161;
     $163 = $157 + $162;
     $164 = +HEAPF64[$95>>3];
     $165 = $164 + $163;
     $166 = $165;
     $167 = -$166;
     $168 = ((($117)) + 120|0);
     $169 = HEAP32[$168>>2]|0;
     $170 = ($169|0)!=(0|0);
     if ($170) {
      $171 = HEAP32[$96>>2]|0;
      $172 = (__ZN7osgUtil10StateGraph14find_or_insertEPKN3osg8StateSetE($171,$169)|0);
      HEAP32[$96>>2] = $172;
      $173 = ((($169)) + 120|0);
      $174 = HEAP32[$173>>2]|0;
      $175 = ($174|0)==(0);
      if (!($175)) {
       $176 = ((($169)) + 128|0);
       $177 = ((($176)) + 11|0);
       $178 = HEAP8[$177>>0]|0;
       $179 = ($178<<24>>24)<(0);
       if ($179) {
        $180 = ((($169)) + 132|0);
        $181 = HEAP32[$180>>2]|0;
        $183 = $181;
       } else {
        $182 = $178&255;
        $183 = $182;
       }
       $184 = ($183|0)==(0);
       if ($184) {
        $205 = $174;
       } else {
        $185 = HEAP32[$97>>2]|0;
        $186 = ($185|0)!=(0);
        $187 = $174 & 4;
        $188 = ($187|0)==(0);
        $or$cond$i70 = $188 & $186;
        if ($or$cond$i70) {
         $205 = $174;
        } else {
         $189 = HEAP32[$99>>2]|0;
         $190 = HEAP32[$100>>2]|0;
         $191 = ($189|0)==($190|0);
         if ($191) {
          __ZNSt3__26vectorIPN7osgUtil9RenderBinENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_($101,$98);
         } else {
          $192 = HEAP32[$98>>2]|0;
          HEAP32[$189>>2] = $192;
          $193 = HEAP32[$99>>2]|0;
          $194 = ((($193)) + 4|0);
          HEAP32[$99>>2] = $194;
         }
         $195 = ((($169)) + 140|0);
         $196 = HEAP8[$195>>0]|0;
         $197 = ($196<<24>>24)==(0);
         $198 = HEAP32[$98>>2]|0;
         if ($197) {
          $199 = ((($198)) + 40|0);
          $200 = HEAP32[$199>>2]|0;
          $$sink$i73 = $200;
         } else {
          $$sink$i73 = $198;
         }
         $201 = ((($169)) + 124|0);
         $202 = HEAP32[$201>>2]|0;
         $203 = (__ZN7osgUtil9RenderBin14find_or_insertEiRKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE($$sink$i73,$202,$176)|0);
         HEAP32[$98>>2] = $203;
         $$pre$i74 = HEAP32[$173>>2]|0;
         $205 = $$pre$i74;
        }
       }
       $204 = $205 & 2;
       $206 = ($204|0)==(0);
       if (!($206)) {
        $207 = HEAP32[$97>>2]|0;
        $208 = (($207) + 1)|0;
        HEAP32[$97>>2] = $208;
       }
      }
     }
     $209 = (HEAPF32[tempDoublePtr>>2]=$167,HEAP32[tempDoublePtr>>2]|0);
     $210 = $209 & 2147483647;
     $211 = ($210>>>0)>(2139095040);
     if ($211) {
      $212 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
      if ($212) {
       $213 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
       $214 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($213,115863,44)|0);
       $215 = HEAP32[$214>>2]|0;
       $216 = ((($215)) + -12|0);
       $217 = HEAP32[$216>>2]|0;
       $218 = (($214) + ($217)|0);
       __ZNKSt3__28ios_base6getlocEv($5,$218);
       __THREW__ = 0;
       $219 = (invoke_iii(3255,($5|0),(215188|0))|0);
       $220 = __THREW__; __THREW__ = 0;
       $221 = $220&1;
       if ($221) {
        label = 54;
        break;
       }
       $222 = HEAP32[$219>>2]|0;
       $223 = ((($222)) + 28|0);
       $224 = HEAP32[$223>>2]|0;
       __THREW__ = 0;
       $225 = (invoke_iii($224|0,($219|0),10)|0);
       $226 = __THREW__; __THREW__ = 0;
       $227 = $226&1;
       if ($227) {
        label = 54;
        break;
       }
       __ZNSt3__26localeD2Ev($5);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($214,$225)|0);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($214)|0);
       $234 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($214,115908,10)|0);
       $235 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEf($234,$167)|0);
       $236 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($235,115919,7)|0);
       $237 = +HEAPF32[$107>>2];
       $238 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEf($236,$237)|0);
       $239 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($238,159071,1)|0);
       $240 = +HEAPF32[$152>>2];
       $241 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEf($239,$240)|0);
       $242 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($241,159071,1)|0);
       $243 = +HEAPF32[$158>>2];
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEf($242,$243)|0);
       $244 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($236,115927,2)|0);
       $245 = HEAP32[$244>>2]|0;
       $246 = ((($245)) + -12|0);
       $247 = HEAP32[$246>>2]|0;
       $248 = (($244) + ($247)|0);
       __ZNKSt3__28ios_base6getlocEv($4,$248);
       __THREW__ = 0;
       $249 = (invoke_iii(3255,($4|0),(215188|0))|0);
       $250 = __THREW__; __THREW__ = 0;
       $251 = $250&1;
       if ($251) {
        label = 59;
        break;
       }
       $252 = HEAP32[$249>>2]|0;
       $253 = ((($252)) + 28|0);
       $254 = HEAP32[$253>>2]|0;
       __THREW__ = 0;
       $255 = (invoke_iii($254|0,($249|0),10)|0);
       $256 = __THREW__; __THREW__ = 0;
       $257 = $256&1;
       if ($257) {
        label = 59;
        break;
       }
       __ZNSt3__26localeD2Ev($4);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($244,$255)|0);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($244)|0);
       $264 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($244,115930,22)|0);
       $265 = (__ZN3osglsERNSt3__213basic_ostreamIcNS0_11char_traitsIcEEEERKNS_7MatrixdE($264,$130)|0);
       $266 = HEAP32[$265>>2]|0;
       $267 = ((($266)) + -12|0);
       $268 = HEAP32[$267>>2]|0;
       $269 = (($265) + ($268)|0);
       __ZNKSt3__28ios_base6getlocEv($3,$269);
       __THREW__ = 0;
       $270 = (invoke_iii(3255,($3|0),(215188|0))|0);
       $271 = __THREW__; __THREW__ = 0;
       $272 = $271&1;
       if ($272) {
        label = 64;
        break;
       }
       $273 = HEAP32[$270>>2]|0;
       $274 = ((($273)) + 28|0);
       $275 = HEAP32[$274>>2]|0;
       __THREW__ = 0;
       $276 = (invoke_iii($275|0,($270|0),10)|0);
       $277 = __THREW__; __THREW__ = 0;
       $278 = $277&1;
       if ($278) {
        label = 64;
        break;
       }
       __ZNSt3__26localeD2Ev($3);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($265,$276)|0);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($265)|0);
      }
      $285 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(5)|0);
      if ($285) {
       $286 = (__ZN3osg6notifyENS_14NotifySeverityE(5)|0);
       $287 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($286,115953,13)|0);
       $288 = HEAP32[$287>>2]|0;
       $289 = ((($288)) + -12|0);
       $290 = HEAP32[$289>>2]|0;
       $291 = (($287) + ($290)|0);
       __ZNKSt3__28ios_base6getlocEv($2,$291);
       __THREW__ = 0;
       $292 = (invoke_iii(3255,($2|0),(215188|0))|0);
       $293 = __THREW__; __THREW__ = 0;
       $294 = $293&1;
       if ($294) {
        label = 71;
        break;
       }
       $295 = HEAP32[$292>>2]|0;
       $296 = ((($295)) + 28|0);
       $297 = HEAP32[$296>>2]|0;
       __THREW__ = 0;
       $298 = (invoke_iii($297|0,($292|0),10)|0);
       $299 = __THREW__; __THREW__ = 0;
       $300 = $299&1;
       if ($300) {
        label = 71;
        break;
       }
       __ZNSt3__26localeD2Ev($2);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($287,$298)|0);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($287)|0);
      }
      $307 = HEAP32[$102>>2]|0;
      $308 = HEAP32[$103>>2]|0;
      $309 = ($307|0)==($308|0);
      if (!($309)) {
       $$sink95 = $307;
       while(1) {
        $310 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(5)|0);
        if ($310) {
         $311 = (__ZN3osg6notifyENS_14NotifySeverityE(5)|0);
         $312 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($311,115967,9)|0);
         $313 = HEAP32[$$sink95>>2]|0;
         $314 = ((($313)) + 12|0);
         $315 = ((($314)) + 11|0);
         $316 = HEAP8[$315>>0]|0;
         $317 = ($316<<24>>24)<(0);
         $318 = HEAP32[$314>>2]|0;
         $319 = $317 ? $318 : $314;
         $320 = ((($313)) + 16|0);
         $321 = HEAP32[$320>>2]|0;
         $322 = $316&255;
         $323 = $317 ? $321 : $322;
         $324 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($312,$319,$323)|0);
         $325 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($324,172027,1)|0);
         $326 = HEAP32[$325>>2]|0;
         $327 = ((($326)) + -12|0);
         $328 = HEAP32[$327>>2]|0;
         $329 = (($325) + ($328)|0);
         __ZNKSt3__28ios_base6getlocEv($6,$329);
         __THREW__ = 0;
         $330 = (invoke_iii(3255,($6|0),(215188|0))|0);
         $331 = __THREW__; __THREW__ = 0;
         $332 = $331&1;
         if ($332) {
          label = 79;
          break L33;
         }
         $333 = HEAP32[$330>>2]|0;
         $334 = ((($333)) + 28|0);
         $335 = HEAP32[$334>>2]|0;
         __THREW__ = 0;
         $336 = (invoke_iii($335|0,($330|0),10)|0);
         $337 = __THREW__; __THREW__ = 0;
         $338 = $337&1;
         if ($338) {
          label = 79;
          break L33;
         }
         __ZNSt3__26localeD2Ev($6);
         (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($325,$336)|0);
         (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($325)|0);
        }
        $345 = ((($$sink95)) + 4|0);
        $346 = HEAP32[$103>>2]|0;
        $347 = ($345|0)==($346|0);
        if ($347) {
         break;
        } else {
         $$sink95 = $345;
        }
       }
      }
     } else {
      __ZN7osgUtil11CullVisitor19addDrawableAndDepthEPN3osg8DrawableEPNS1_10RefMatrixdEf($0,$117,$129,$167);
     }
     if ($170) {
      $348 = HEAP32[$96>>2]|0;
      $349 = ((($348)) + 16|0);
      $350 = HEAP32[$349>>2]|0;
      $351 = ((($350)) + 120|0);
      $352 = HEAP32[$351>>2]|0;
      $353 = $352 & 2;
      $354 = ($353|0)==(0);
      if (!($354)) {
       $355 = HEAP32[$97>>2]|0;
       $356 = (($355) + -1)|0;
       HEAP32[$97>>2] = $356;
      }
      $357 = ($352|0)==(0);
      do {
       if (!($357)) {
        $358 = ((($350)) + 128|0);
        $359 = ((($358)) + 11|0);
        $360 = HEAP8[$359>>0]|0;
        $361 = ($360<<24>>24)<(0);
        if ($361) {
         $362 = ((($350)) + 132|0);
         $363 = HEAP32[$362>>2]|0;
         $365 = $363;
        } else {
         $364 = $360&255;
         $365 = $364;
        }
        $366 = ($365|0)==(0);
        if (!($366)) {
         $367 = HEAP32[$97>>2]|0;
         $368 = ($367|0)!=(0);
         $369 = $352 & 4;
         $370 = ($369|0)==(0);
         $or$cond$i65 = $370 & $368;
         if (!($or$cond$i65)) {
          $371 = HEAP32[$104>>2]|0;
          $372 = HEAP32[$99>>2]|0;
          $373 = ($371|0)==($372|0);
          if ($373) {
           $374 = HEAP32[$98>>2]|0;
           $375 = ((($374)) + 40|0);
           $376 = HEAP32[$375>>2]|0;
           HEAP32[$98>>2] = $376;
           break;
          } else {
           $377 = ((($372)) + -4|0);
           $378 = HEAP32[$377>>2]|0;
           HEAP32[$98>>2] = $378;
           HEAP32[$99>>2] = $377;
           break;
          }
         }
        }
       }
      } while(0);
      $379 = ((($348)) + 12|0);
      $380 = HEAP32[$379>>2]|0;
      HEAP32[$96>>2] = $380;
     }
    }
    $381 = (($$096) + 1)|0;
    $382 = HEAP32[$1>>2]|0;
    $383 = ((($382)) + 224|0);
    $384 = HEAP32[$383>>2]|0;
    $385 = (FUNCTION_TABLE_ii[$384 & 8191]($1)|0);
    $386 = ($381>>>0)<($385>>>0);
    if ($386) {
     $$096 = $381;
    } else {
     break L31;
    }
   }
   if ((label|0) == 54) {
    $228 = ___cxa_find_matching_catch_2()|0;
    $229 = tempRet0;
    __THREW__ = 0;
    invoke_vi(3263,($5|0));
    $230 = __THREW__; __THREW__ = 0;
    $231 = $230&1;
    if ($231) {
     $232 = ___cxa_find_matching_catch_3(0|0)|0;
     $233 = tempRet0;
     ___clang_call_terminate($232);
     // unreachable;
    } else {
     ___resumeException($228|0);
     // unreachable;
    }
   }
   else if ((label|0) == 59) {
    $258 = ___cxa_find_matching_catch_2()|0;
    $259 = tempRet0;
    __THREW__ = 0;
    invoke_vi(3263,($4|0));
    $260 = __THREW__; __THREW__ = 0;
    $261 = $260&1;
    if ($261) {
     $262 = ___cxa_find_matching_catch_3(0|0)|0;
     $263 = tempRet0;
     ___clang_call_terminate($262);
     // unreachable;
    } else {
     ___resumeException($258|0);
     // unreachable;
    }
   }
   else if ((label|0) == 64) {
    $279 = ___cxa_find_matching_catch_2()|0;
    $280 = tempRet0;
    __THREW__ = 0;
    invoke_vi(3263,($3|0));
    $281 = __THREW__; __THREW__ = 0;
    $282 = $281&1;
    if ($282) {
     $283 = ___cxa_find_matching_catch_3(0|0)|0;
     $284 = tempRet0;
     ___clang_call_terminate($283);
     // unreachable;
    } else {
     ___resumeException($279|0);
     // unreachable;
    }
   }
   else if ((label|0) == 71) {
    $301 = ___cxa_find_matching_catch_2()|0;
    $302 = tempRet0;
    __THREW__ = 0;
    invoke_vi(3263,($2|0));
    $303 = __THREW__; __THREW__ = 0;
    $304 = $303&1;
    if ($304) {
     $305 = ___cxa_find_matching_catch_3(0|0)|0;
     $306 = tempRet0;
     ___clang_call_terminate($305);
     // unreachable;
    } else {
     ___resumeException($301|0);
     // unreachable;
    }
   }
   else if ((label|0) == 79) {
    $339 = ___cxa_find_matching_catch_2()|0;
    $340 = tempRet0;
    __THREW__ = 0;
    invoke_vi(3263,($6|0));
    $341 = __THREW__; __THREW__ = 0;
    $342 = $341&1;
    if ($342) {
     $343 = ___cxa_find_matching_catch_3(0|0)|0;
     $344 = tempRet0;
     ___clang_call_terminate($343);
     // unreachable;
    } else {
     ___resumeException($339|0);
     // unreachable;
    }
   }
  }
 } while(0);
 if (!($30)) {
  STACKTOP = sp;return;
 }
 $387 = ((($0)) + 376|0);
 $388 = HEAP32[$387>>2]|0;
 $389 = ((($388)) + 16|0);
 $390 = HEAP32[$389>>2]|0;
 $391 = ((($390)) + 120|0);
 $392 = HEAP32[$391>>2]|0;
 $393 = $392 & 2;
 $394 = ($393|0)==(0);
 if (!($394)) {
  $395 = ((($0)) + 440|0);
  $396 = HEAP32[$395>>2]|0;
  $397 = (($396) + -1)|0;
  HEAP32[$395>>2] = $397;
 }
 $398 = ($392|0)==(0);
 do {
  if (!($398)) {
   $399 = ((($390)) + 128|0);
   $400 = ((($399)) + 11|0);
   $401 = HEAP8[$400>>0]|0;
   $402 = ($401<<24>>24)<(0);
   if ($402) {
    $403 = ((($390)) + 132|0);
    $404 = HEAP32[$403>>2]|0;
    $406 = $404;
   } else {
    $405 = $401&255;
    $406 = $405;
   }
   $407 = ($406|0)==(0);
   if (!($407)) {
    $408 = ((($0)) + 440|0);
    $409 = HEAP32[$408>>2]|0;
    $410 = ($409|0)!=(0);
    $411 = $392 & 4;
    $412 = ($411|0)==(0);
    $or$cond$i62 = $412 & $410;
    if (!($or$cond$i62)) {
     $413 = ((($0)) + 388|0);
     $414 = HEAP32[$413>>2]|0;
     $415 = ((($0)) + 392|0);
     $416 = HEAP32[$415>>2]|0;
     $417 = ($414|0)==($416|0);
     if ($417) {
      $418 = ((($0)) + 384|0);
      $419 = HEAP32[$418>>2]|0;
      $420 = ((($419)) + 40|0);
      $421 = HEAP32[$420>>2]|0;
      HEAP32[$418>>2] = $421;
      break;
     } else {
      $422 = ((($416)) + -4|0);
      $423 = HEAP32[$422>>2]|0;
      $424 = ((($0)) + 384|0);
      HEAP32[$424>>2] = $423;
      HEAP32[$415>>2] = $422;
      break;
     }
    }
   }
  }
 } while(0);
 $425 = ((($388)) + 12|0);
 $426 = HEAP32[$425>>2]|0;
 HEAP32[$387>>2] = $426;
 STACKTOP = sp;return;
}
function __ZN7osgUtil11CullVisitor5applyERN3osg5GroupE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$pre = 0, $$pre$i = 0, $$pre$phiZ2D = 0, $$pre12$pre$phiZZ2D = 0, $$sink$i = 0, $$sroa$03$015$i$i = 0, $$sroa$03$07$i$i$i = 0, $$sroa$09$016$i$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0.0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0;
 var $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0;
 var $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0;
 var $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $or$cond$i = 0, $or$cond$i9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 108|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 do {
  if ($4) {
   $5 = ((($1)) + 104|0);
   $6 = HEAP8[$5>>0]|0;
   $7 = ($6<<24>>24)==(0);
   if ($7) {
    label = 3;
   } else {
    $10 = (__ZNK3osg4Node8getBoundEv($1)|0);
    $11 = ((($10)) + 12|0);
    $12 = +HEAPF32[$11>>2];
    $13 = !($12 >= 0.0);
    $14 = ((($0)) + 336|0);
    $15 = HEAP32[$14>>2]|0;
    if ($13) {
     $$pre12$pre$phiZZ2D = $14;$17 = $15;
     label = 5;
    } else {
     $20 = (__ZNK3osg4Node8getBoundEv($1)|0);
     $21 = (__ZN3osg10CullingSet8isCulledERKNS_18BoundingSphereImplINS_5Vec3fEEE($15,$20)|0);
     if ($21) {
      return;
     } else {
      $$pre = HEAP32[$14>>2]|0;
      $$pre$phiZ2D = $14;$22 = $$pre;
      break;
     }
    }
   }
  } else {
   label = 3;
  }
 } while(0);
 if ((label|0) == 3) {
  $8 = ((($0)) + 336|0);
  $9 = HEAP32[$8>>2]|0;
  $$pre12$pre$phiZZ2D = $8;$17 = $9;
  label = 5;
 }
 if ((label|0) == 5) {
  $16 = ((($17)) + 16|0);
  $18 = HEAP32[$16>>2]|0;
  $19 = ((($17)) + 36|0);
  HEAP32[$19>>2] = $18;
  $$pre$phiZ2D = $$pre12$pre$phiZZ2D;$22 = $17;
 }
 __ZN3osg10CullingSet15pushCurrentMaskEv($22);
 $23 = ((($1)) + 120|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)==(0|0);
 L13: do {
  if ($25) {
   $128 = ((($1)) + 100|0);
   $129 = HEAP32[$128>>2]|0;
   $130 = ($129|0)==(0|0);
   if (!($130)) {
    $131 = HEAP32[$129>>2]|0;
    $132 = ((($131)) + 92|0);
    $133 = HEAP32[$132>>2]|0;
    $134 = HEAP32[$0>>2]|0;
    $135 = ((($134)) + -12|0);
    $136 = HEAP32[$135>>2]|0;
    $137 = (($0) + ($136)|0);
    (FUNCTION_TABLE_iiii[$133 & 8191]($129,$1,$137)|0);
    break;
   }
   $138 = ((($0)) + 16|0);
   $139 = HEAP32[$138>>2]|0;
   switch ($139|0) {
   case 0:  {
    break L13;
    break;
   }
   case 1:  {
    $140 = HEAP32[$1>>2]|0;
    $141 = ((($140)) + 192|0);
    $142 = HEAP32[$141>>2]|0;
    FUNCTION_TABLE_vii[$142 & 8191]($1,$0);
    break L13;
    break;
   }
   default: {
    $143 = HEAP32[$1>>2]|0;
    $144 = ((($143)) + 196|0);
    $145 = HEAP32[$144>>2]|0;
    FUNCTION_TABLE_vii[$145 & 8191]($1,$0);
    break L13;
   }
   }
  } else {
   $26 = ((($0)) + 376|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = (__ZN7osgUtil10StateGraph14find_or_insertEPKN3osg8StateSetE($27,$24)|0);
   HEAP32[$26>>2] = $28;
   $29 = ((($24)) + 120|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = ($30|0)==(0);
   if (!($31)) {
    $32 = ((($24)) + 128|0);
    $33 = ((($32)) + 11|0);
    $34 = HEAP8[$33>>0]|0;
    $35 = ($34<<24>>24)<(0);
    if ($35) {
     $36 = ((($24)) + 132|0);
     $37 = HEAP32[$36>>2]|0;
     $39 = $37;
    } else {
     $38 = $34&255;
     $39 = $38;
    }
    $40 = ($39|0)==(0);
    if ($40) {
     $66 = $30;
    } else {
     $41 = ((($0)) + 440|0);
     $42 = HEAP32[$41>>2]|0;
     $43 = ($42|0)!=(0);
     $44 = $30 & 4;
     $45 = ($44|0)==(0);
     $or$cond$i = $45 & $43;
     if ($or$cond$i) {
      $66 = $30;
     } else {
      $46 = ((($0)) + 384|0);
      $47 = ((($0)) + 392|0);
      $48 = HEAP32[$47>>2]|0;
      $49 = ((($0)) + 396|0);
      $50 = HEAP32[$49>>2]|0;
      $51 = ($48|0)==($50|0);
      if ($51) {
       $55 = ((($0)) + 388|0);
       __ZNSt3__26vectorIPN7osgUtil9RenderBinENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_($55,$46);
      } else {
       $52 = HEAP32[$46>>2]|0;
       HEAP32[$48>>2] = $52;
       $53 = HEAP32[$47>>2]|0;
       $54 = ((($53)) + 4|0);
       HEAP32[$47>>2] = $54;
      }
      $56 = ((($24)) + 140|0);
      $57 = HEAP8[$56>>0]|0;
      $58 = ($57<<24>>24)==(0);
      $59 = HEAP32[$46>>2]|0;
      if ($58) {
       $60 = ((($59)) + 40|0);
       $61 = HEAP32[$60>>2]|0;
       $$sink$i = $61;
      } else {
       $$sink$i = $59;
      }
      $62 = ((($24)) + 124|0);
      $63 = HEAP32[$62>>2]|0;
      $64 = (__ZN7osgUtil9RenderBin14find_or_insertEiRKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE($$sink$i,$63,$32)|0);
      HEAP32[$46>>2] = $64;
      $$pre$i = HEAP32[$29>>2]|0;
      $66 = $$pre$i;
     }
    }
    $65 = $66 & 2;
    $67 = ($65|0)==(0);
    if (!($67)) {
     $68 = ((($0)) + 440|0);
     $69 = HEAP32[$68>>2]|0;
     $70 = (($69) + 1)|0;
     HEAP32[$68>>2] = $70;
    }
   }
   $71 = ((($1)) + 100|0);
   $72 = HEAP32[$71>>2]|0;
   $73 = ($72|0)==(0|0);
   L41: do {
    if ($73) {
     $81 = ((($0)) + 16|0);
     $82 = HEAP32[$81>>2]|0;
     switch ($82|0) {
     case 0:  {
      break L41;
      break;
     }
     case 1:  {
      $83 = HEAP32[$1>>2]|0;
      $84 = ((($83)) + 192|0);
      $85 = HEAP32[$84>>2]|0;
      FUNCTION_TABLE_vii[$85 & 8191]($1,$0);
      break L41;
      break;
     }
     default: {
      $86 = HEAP32[$1>>2]|0;
      $87 = ((($86)) + 196|0);
      $88 = HEAP32[$87>>2]|0;
      FUNCTION_TABLE_vii[$88 & 8191]($1,$0);
      break L41;
     }
     }
    } else {
     $74 = HEAP32[$72>>2]|0;
     $75 = ((($74)) + 92|0);
     $76 = HEAP32[$75>>2]|0;
     $77 = HEAP32[$0>>2]|0;
     $78 = ((($77)) + -12|0);
     $79 = HEAP32[$78>>2]|0;
     $80 = (($0) + ($79)|0);
     (FUNCTION_TABLE_iiii[$76 & 8191]($72,$1,$80)|0);
    }
   } while(0);
   $89 = HEAP32[$26>>2]|0;
   $90 = ((($89)) + 16|0);
   $91 = HEAP32[$90>>2]|0;
   $92 = ((($91)) + 120|0);
   $93 = HEAP32[$92>>2]|0;
   $94 = $93 & 2;
   $95 = ($94|0)==(0);
   if (!($95)) {
    $96 = ((($0)) + 440|0);
    $97 = HEAP32[$96>>2]|0;
    $98 = (($97) + -1)|0;
    HEAP32[$96>>2] = $98;
   }
   $99 = ($93|0)==(0);
   do {
    if (!($99)) {
     $100 = ((($91)) + 128|0);
     $101 = ((($100)) + 11|0);
     $102 = HEAP8[$101>>0]|0;
     $103 = ($102<<24>>24)<(0);
     if ($103) {
      $104 = ((($91)) + 132|0);
      $105 = HEAP32[$104>>2]|0;
      $107 = $105;
     } else {
      $106 = $102&255;
      $107 = $106;
     }
     $108 = ($107|0)==(0);
     if (!($108)) {
      $109 = ((($0)) + 440|0);
      $110 = HEAP32[$109>>2]|0;
      $111 = ($110|0)!=(0);
      $112 = $93 & 4;
      $113 = ($112|0)==(0);
      $or$cond$i9 = $113 & $111;
      if (!($or$cond$i9)) {
       $114 = ((($0)) + 388|0);
       $115 = HEAP32[$114>>2]|0;
       $116 = ((($0)) + 392|0);
       $117 = HEAP32[$116>>2]|0;
       $118 = ($115|0)==($117|0);
       if ($118) {
        $119 = ((($0)) + 384|0);
        $120 = HEAP32[$119>>2]|0;
        $121 = ((($120)) + 40|0);
        $122 = HEAP32[$121>>2]|0;
        HEAP32[$119>>2] = $122;
        break;
       } else {
        $123 = ((($117)) + -4|0);
        $124 = HEAP32[$123>>2]|0;
        $125 = ((($0)) + 384|0);
        HEAP32[$125>>2] = $124;
        HEAP32[$116>>2] = $123;
        break;
       }
      }
     }
    }
   } while(0);
   $126 = ((($89)) + 12|0);
   $127 = HEAP32[$126>>2]|0;
   HEAP32[$26>>2] = $127;
  }
 } while(0);
 $146 = HEAP32[$$pre$phiZ2D>>2]|0;
 $147 = ((($146)) + 32|0);
 $148 = HEAP32[$147>>2]|0;
 $149 = ($148|0)==(0);
 if (!($149)) {
  $150 = ((($146)) + 20|0);
  $151 = HEAP32[$150>>2]|0;
  $152 = ((($146)) + 24|0);
  $153 = HEAP32[$152>>2]|0;
  $154 = ($151|0)==($153|0);
  if (!($154)) {
   $155 = ((($153)) + -4|0);
   $156 = HEAP32[$155>>2]|0;
   $157 = ((($146)) + 16|0);
   HEAP32[$157>>2] = $156;
   HEAP32[$152>>2] = $155;
  }
  $158 = (($148) + -1)|0;
  HEAP32[$147>>2] = $158;
 }
 $159 = ((($146)) + 64|0);
 $160 = HEAP32[$159>>2]|0;
 $161 = ((($146)) + 68|0);
 $162 = HEAP32[$161>>2]|0;
 $163 = ($160|0)==($162|0);
 if (!($163)) {
  $$sroa$09$016$i$i = $160;
  while(1) {
   $164 = ((($$sroa$09$016$i$i)) + 20|0);
   $165 = HEAP32[$164>>2]|0;
   $166 = ($165|0)==(0);
   if (!($166)) {
    $167 = ((($$sroa$09$016$i$i)) + 8|0);
    $168 = HEAP32[$167>>2]|0;
    $169 = ((($$sroa$09$016$i$i)) + 12|0);
    $170 = HEAP32[$169>>2]|0;
    $171 = ($168|0)==($170|0);
    if (!($171)) {
     $172 = ((($170)) + -4|0);
     $173 = HEAP32[$172>>2]|0;
     $174 = ((($$sroa$09$016$i$i)) + 4|0);
     HEAP32[$174>>2] = $173;
     HEAP32[$169>>2] = $172;
    }
    $175 = (($165) + -1)|0;
    HEAP32[$164>>2] = $175;
   }
   $176 = ((($$sroa$09$016$i$i)) + 52|0);
   $177 = ($176|0)==($162|0);
   if ($177) {
    break;
   } else {
    $$sroa$09$016$i$i = $176;
   }
  }
 }
 $178 = ((($146)) + 76|0);
 $179 = HEAP32[$178>>2]|0;
 $180 = ((($146)) + 80|0);
 $181 = HEAP32[$180>>2]|0;
 $182 = ($179|0)==($181|0);
 if ($182) {
  return;
 } else {
  $$sroa$03$015$i$i = $179;
 }
 while(1) {
  $183 = ((($$sroa$03$015$i$i)) + 36|0);
  $184 = HEAP32[$183>>2]|0;
  $185 = ($184|0)==(0);
  if (!($185)) {
   $186 = ((($$sroa$03$015$i$i)) + 24|0);
   $187 = HEAP32[$186>>2]|0;
   $188 = ((($$sroa$03$015$i$i)) + 28|0);
   $189 = HEAP32[$188>>2]|0;
   $190 = ($187|0)==($189|0);
   if (!($190)) {
    $191 = ((($189)) + -4|0);
    $192 = HEAP32[$191>>2]|0;
    $193 = ((($$sroa$03$015$i$i)) + 20|0);
    HEAP32[$193>>2] = $192;
    HEAP32[$188>>2] = $191;
   }
   $194 = (($184) + -1)|0;
   HEAP32[$183>>2] = $194;
  }
  $195 = ((($$sroa$03$015$i$i)) + 68|0);
  $196 = HEAP32[$195>>2]|0;
  $197 = ((($$sroa$03$015$i$i)) + 72|0);
  $198 = HEAP32[$197>>2]|0;
  $199 = ($196|0)==($198|0);
  if (!($199)) {
   $$sroa$03$07$i$i$i = $196;
   while(1) {
    $200 = ((($$sroa$03$07$i$i$i)) + 16|0);
    $201 = HEAP32[$200>>2]|0;
    $202 = ($201|0)==(0);
    if (!($202)) {
     $203 = ((($$sroa$03$07$i$i$i)) + 4|0);
     $204 = HEAP32[$203>>2]|0;
     $205 = ((($$sroa$03$07$i$i$i)) + 8|0);
     $206 = HEAP32[$205>>2]|0;
     $207 = ($204|0)==($206|0);
     if (!($207)) {
      $208 = ((($206)) + -4|0);
      $209 = HEAP32[$208>>2]|0;
      HEAP32[$$sroa$03$07$i$i$i>>2] = $209;
      HEAP32[$205>>2] = $208;
     }
     $210 = (($201) + -1)|0;
     HEAP32[$200>>2] = $210;
    }
    $211 = ((($$sroa$03$07$i$i$i)) + 48|0);
    $212 = ($211|0)==($198|0);
    if ($212) {
     break;
    } else {
     $$sroa$03$07$i$i$i = $211;
    }
   }
  }
  $213 = ((($$sroa$03$015$i$i)) + 80|0);
  $214 = ($213|0)==($181|0);
  if ($214) {
   break;
  } else {
   $$sroa$03$015$i$i = $213;
  }
 }
 return;
}
function __ZN7osgUtil11CullVisitor5applyERN3osg10ProjectionE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$pre$i = 0, $$sink$i = 0, $$sink$i$i = 0, $$sink$i$i27 = 0, $$sink$i$i35 = 0, $$sink$i$i38 = 0, $$sink1$i$i36 = 0, $$sink1$i$i39 = 0, $$sroa$03$015$i$i = 0, $$sroa$03$07$i$i$i = 0, $$sroa$09$016$i$i = 0, $10 = 0, $100 = 0.0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0.0, $143 = 0.0;
 var $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0;
 var $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0;
 var $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0;
 var $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0;
 var $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0;
 var $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0;
 var $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0;
 var $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0.0, $57 = 0.0, $58 = 0, $59 = 0.0, $6 = 0, $60 = 0.0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond$i = 0, $or$cond$i42 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $2 = sp + 12|0;
 $3 = sp;
 $4 = ((($0)) + 56|0);
 $5 = ((($0)) + 336|0);
 $6 = HEAP32[$5>>2]|0;
 __ZN3osg10CullingSet15pushCurrentMaskEv($6);
 $7 = ((($1)) + 120|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)!=(0|0);
 if ($9) {
  $10 = ((($0)) + 376|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (__ZN7osgUtil10StateGraph14find_or_insertEPKN3osg8StateSetE($11,$8)|0);
  HEAP32[$10>>2] = $12;
  $13 = ((($8)) + 120|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = ($14|0)==(0);
  if (!($15)) {
   $16 = ((($8)) + 128|0);
   $17 = ((($16)) + 11|0);
   $18 = HEAP8[$17>>0]|0;
   $19 = ($18<<24>>24)<(0);
   if ($19) {
    $20 = ((($8)) + 132|0);
    $21 = HEAP32[$20>>2]|0;
    $23 = $21;
   } else {
    $22 = $18&255;
    $23 = $22;
   }
   $24 = ($23|0)==(0);
   if ($24) {
    $50 = $14;
   } else {
    $25 = ((($0)) + 440|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = ($26|0)!=(0);
    $28 = $14 & 4;
    $29 = ($28|0)==(0);
    $or$cond$i = $29 & $27;
    if ($or$cond$i) {
     $50 = $14;
    } else {
     $30 = ((($0)) + 384|0);
     $31 = ((($0)) + 392|0);
     $32 = HEAP32[$31>>2]|0;
     $33 = ((($0)) + 396|0);
     $34 = HEAP32[$33>>2]|0;
     $35 = ($32|0)==($34|0);
     if ($35) {
      $39 = ((($0)) + 388|0);
      __ZNSt3__26vectorIPN7osgUtil9RenderBinENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_($39,$30);
     } else {
      $36 = HEAP32[$30>>2]|0;
      HEAP32[$32>>2] = $36;
      $37 = HEAP32[$31>>2]|0;
      $38 = ((($37)) + 4|0);
      HEAP32[$31>>2] = $38;
     }
     $40 = ((($8)) + 140|0);
     $41 = HEAP8[$40>>0]|0;
     $42 = ($41<<24>>24)==(0);
     $43 = HEAP32[$30>>2]|0;
     if ($42) {
      $44 = ((($43)) + 40|0);
      $45 = HEAP32[$44>>2]|0;
      $$sink$i = $45;
     } else {
      $$sink$i = $43;
     }
     $46 = ((($8)) + 124|0);
     $47 = HEAP32[$46>>2]|0;
     $48 = (__ZN7osgUtil9RenderBin14find_or_insertEiRKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE($$sink$i,$47,$16)|0);
     HEAP32[$30>>2] = $48;
     $$pre$i = HEAP32[$13>>2]|0;
     $50 = $$pre$i;
    }
   }
   $49 = $50 & 2;
   $51 = ($49|0)==(0);
   if (!($51)) {
    $52 = ((($0)) + 440|0);
    $53 = HEAP32[$52>>2]|0;
    $54 = (($53) + 1)|0;
    HEAP32[$52>>2] = $54;
   }
  }
 }
 $55 = ((($0)) + 408|0);
 $56 = +HEAPF64[$55>>3];
 $57 = $56;
 $58 = ((($0)) + 416|0);
 $59 = +HEAPF64[$58>>3];
 $60 = $59;
 $61 = ((($2)) + 8|0);
 $62 = ((($2)) + 4|0);
 $63 = ((($0)) + 480|0);
 $64 = HEAP32[$63>>2]|0;
 HEAP32[$2>>2] = $64;
 $65 = ((($0)) + 484|0);
 $66 = HEAP32[$65>>2]|0;
 HEAP32[$62>>2] = $66;
 HEAP32[$65>>2] = 0;
 $67 = ((($0)) + 488|0);
 $68 = HEAP32[$67>>2]|0;
 HEAP32[$61>>2] = $68;
 HEAP32[$67>>2] = 0;
 $69 = ($68|0)==(0);
 $70 = $66;
 $71 = ((($70)) + 8|0);
 $$sink$i$i = $69 ? $2 : $71;
 HEAP32[$$sink$i$i>>2] = $62;
 HEAP32[$63>>2] = $65;
 $72 = ((($3)) + 8|0);
 $73 = ((($3)) + 4|0);
 $74 = ((($0)) + 492|0);
 $75 = HEAP32[$74>>2]|0;
 HEAP32[$3>>2] = $75;
 $76 = ((($0)) + 496|0);
 $77 = HEAP32[$76>>2]|0;
 HEAP32[$73>>2] = $77;
 HEAP32[$76>>2] = 0;
 $78 = ((($0)) + 500|0);
 $79 = HEAP32[$78>>2]|0;
 HEAP32[$72>>2] = $79;
 HEAP32[$78>>2] = 0;
 $80 = ($79|0)==(0);
 $81 = $77;
 $82 = ((($81)) + 8|0);
 $$sink$i$i27 = $80 ? $3 : $82;
 HEAP32[$$sink$i$i27>>2] = $73;
 HEAP32[$74>>2] = $76;
 HEAPF64[$55>>3] = 3.4028234663852886E+38;
 HEAPF64[$58>>3] = -3.4028234663852886E+38;
 $83 = ((($1)) + 136|0);
 __THREW__ = 0;
 $84 = (invoke_iii(3622,($4|0),($83|0))|0);
 $85 = __THREW__; __THREW__ = 0;
 $86 = $85&1;
 L21: do {
  if (!($86)) {
   __THREW__ = 0;
   invoke_vii(3580,($4|0),($84|0));
   $87 = __THREW__; __THREW__ = 0;
   $88 = $87&1;
   if (!($88)) {
    $89 = ((($1)) + 108|0);
    $90 = HEAP32[$89>>2]|0;
    $91 = ($90|0)==(0);
    if ($91) {
     $92 = ((($1)) + 104|0);
     $93 = HEAP8[$92>>0]|0;
     $94 = ($93<<24>>24)==(0);
     if ($94) {
      label = 20;
     } else {
      __THREW__ = 0;
      $96 = (invoke_ii(3534,($1|0))|0);
      $97 = __THREW__; __THREW__ = 0;
      $98 = $97&1;
      if ($98) {
       break;
      }
      $99 = ((($96)) + 12|0);
      $100 = +HEAPF32[$99>>2];
      $101 = !($100 >= 0.0);
      $102 = HEAP32[$5>>2]|0;
      if ($101) {
       $110 = $102;
       label = 25;
      } else {
       __THREW__ = 0;
       $103 = (invoke_ii(3534,($1|0))|0);
       $104 = __THREW__; __THREW__ = 0;
       $105 = $104&1;
       if ($105) {
        break;
       }
       __THREW__ = 0;
       $106 = (invoke_iii(3623,($102|0),($103|0))|0);
       $107 = __THREW__; __THREW__ = 0;
       $108 = $107&1;
       if ($108) {
        break;
       }
       if (!($106)) {
        label = 27;
       }
      }
     }
    } else {
     label = 20;
    }
    if ((label|0) == 20) {
     $95 = HEAP32[$5>>2]|0;
     $110 = $95;
     label = 25;
    }
    if ((label|0) == 25) {
     $109 = ((($110)) + 16|0);
     $111 = HEAP32[$109>>2]|0;
     $112 = ((($110)) + 36|0);
     HEAP32[$112>>2] = $111;
     label = 27;
    }
    L35: do {
     if ((label|0) == 27) {
      $113 = ((($1)) + 100|0);
      $114 = HEAP32[$113>>2]|0;
      $115 = ($114|0)==(0|0);
      if (!($115)) {
       $116 = HEAP32[$114>>2]|0;
       $117 = ((($116)) + 92|0);
       $118 = HEAP32[$117>>2]|0;
       $119 = HEAP32[$0>>2]|0;
       $120 = ((($119)) + -12|0);
       $121 = HEAP32[$120>>2]|0;
       $122 = (($0) + ($121)|0);
       __THREW__ = 0;
       (invoke_iiii($118|0,($114|0),($1|0),($122|0))|0);
       $123 = __THREW__; __THREW__ = 0;
       $124 = $123&1;
       if ($124) {
        break L21;
       } else {
        break;
       }
      }
      $125 = ((($0)) + 16|0);
      $126 = HEAP32[$125>>2]|0;
      switch ($126|0) {
      case 0:  {
       break L35;
       break;
      }
      case 1:  {
       $127 = HEAP32[$1>>2]|0;
       $128 = ((($127)) + 192|0);
       $129 = HEAP32[$128>>2]|0;
       __THREW__ = 0;
       invoke_vii($129|0,($1|0),($0|0));
       $130 = __THREW__; __THREW__ = 0;
       $131 = $130&1;
       if ($131) {
        break L21;
       } else {
        break L35;
       }
       break;
      }
      default: {
       $132 = HEAP32[$1>>2]|0;
       $133 = ((($132)) + 196|0);
       $134 = HEAP32[$133>>2]|0;
       __THREW__ = 0;
       invoke_vii($134|0,($1|0),($0|0));
       $135 = __THREW__; __THREW__ = 0;
       $136 = $135&1;
       if ($136) {
        break L21;
       } else {
        break L35;
       }
      }
      }
     }
    } while(0);
    $137 = HEAP32[$0>>2]|0;
    $138 = ((($137)) + 204|0);
    $139 = HEAP32[$138>>2]|0;
    __THREW__ = 0;
    invoke_vi($139|0,($0|0));
    $140 = __THREW__; __THREW__ = 0;
    $141 = $140&1;
    if (!($141)) {
     $142 = $57;
     HEAPF64[$55>>3] = $142;
     $143 = $60;
     HEAPF64[$58>>3] = $143;
     $144 = HEAP32[$2>>2]|0;
     $145 = HEAP32[$63>>2]|0;
     HEAP32[$2>>2] = $145;
     HEAP32[$63>>2] = $144;
     $146 = HEAP32[$62>>2]|0;
     $147 = HEAP32[$65>>2]|0;
     HEAP32[$62>>2] = $147;
     HEAP32[$65>>2] = $146;
     $148 = HEAP32[$61>>2]|0;
     $149 = HEAP32[$67>>2]|0;
     HEAP32[$61>>2] = $149;
     HEAP32[$67>>2] = $148;
     $150 = ($149|0)==(0);
     $151 = $147;
     $152 = ((($151)) + 8|0);
     $$sink$i$i35 = $150 ? $2 : $152;
     HEAP32[$$sink$i$i35>>2] = $62;
     $153 = ($148|0)==(0);
     $154 = HEAP32[$65>>2]|0;
     $155 = ((($154)) + 8|0);
     $$sink1$i$i36 = $153 ? $63 : $155;
     HEAP32[$$sink1$i$i36>>2] = $65;
     $156 = HEAP32[$3>>2]|0;
     $157 = HEAP32[$74>>2]|0;
     HEAP32[$3>>2] = $157;
     HEAP32[$74>>2] = $156;
     $158 = HEAP32[$73>>2]|0;
     $159 = HEAP32[$76>>2]|0;
     HEAP32[$73>>2] = $159;
     HEAP32[$76>>2] = $158;
     $160 = HEAP32[$72>>2]|0;
     $161 = HEAP32[$78>>2]|0;
     HEAP32[$72>>2] = $161;
     HEAP32[$78>>2] = $160;
     $162 = ($161|0)==(0);
     $163 = $159;
     $164 = ((($163)) + 8|0);
     $$sink$i$i38 = $162 ? $3 : $164;
     HEAP32[$$sink$i$i38>>2] = $73;
     $165 = ($160|0)==(0);
     $166 = HEAP32[$76>>2]|0;
     $167 = ((($166)) + 8|0);
     $$sink1$i$i39 = $165 ? $74 : $167;
     HEAP32[$$sink1$i$i39>>2] = $76;
     $168 = $159;
     if ($9) {
      $169 = ((($0)) + 376|0);
      $170 = HEAP32[$169>>2]|0;
      $171 = ((($170)) + 16|0);
      $172 = HEAP32[$171>>2]|0;
      $173 = ((($172)) + 120|0);
      $174 = HEAP32[$173>>2]|0;
      $175 = $174 & 2;
      $176 = ($175|0)==(0);
      if (!($176)) {
       $177 = ((($0)) + 440|0);
       $178 = HEAP32[$177>>2]|0;
       $179 = (($178) + -1)|0;
       HEAP32[$177>>2] = $179;
      }
      $180 = ($174|0)==(0);
      do {
       if (!($180)) {
        $181 = ((($172)) + 128|0);
        $182 = ((($181)) + 11|0);
        $183 = HEAP8[$182>>0]|0;
        $184 = ($183<<24>>24)<(0);
        if ($184) {
         $185 = ((($172)) + 132|0);
         $186 = HEAP32[$185>>2]|0;
         $188 = $186;
        } else {
         $187 = $183&255;
         $188 = $187;
        }
        $189 = ($188|0)==(0);
        if (!($189)) {
         $190 = ((($0)) + 440|0);
         $191 = HEAP32[$190>>2]|0;
         $192 = ($191|0)!=(0);
         $193 = $174 & 4;
         $194 = ($193|0)==(0);
         $or$cond$i42 = $194 & $192;
         if (!($or$cond$i42)) {
          $195 = ((($0)) + 388|0);
          $196 = HEAP32[$195>>2]|0;
          $197 = ((($0)) + 392|0);
          $198 = HEAP32[$197>>2]|0;
          $199 = ($196|0)==($198|0);
          if ($199) {
           $200 = ((($0)) + 384|0);
           $201 = HEAP32[$200>>2]|0;
           $202 = ((($201)) + 40|0);
           $203 = HEAP32[$202>>2]|0;
           HEAP32[$200>>2] = $203;
           break;
          } else {
           $204 = ((($198)) + -4|0);
           $205 = HEAP32[$204>>2]|0;
           $206 = ((($0)) + 384|0);
           HEAP32[$206>>2] = $205;
           HEAP32[$197>>2] = $204;
           break;
          }
         }
        }
       }
      } while(0);
      $207 = ((($170)) + 12|0);
      $208 = HEAP32[$207>>2]|0;
      HEAP32[$169>>2] = $208;
     }
     $209 = HEAP32[$5>>2]|0;
     $210 = ((($209)) + 32|0);
     $211 = HEAP32[$210>>2]|0;
     $212 = ($211|0)==(0);
     if (!($212)) {
      $213 = ((($209)) + 20|0);
      $214 = HEAP32[$213>>2]|0;
      $215 = ((($209)) + 24|0);
      $216 = HEAP32[$215>>2]|0;
      $217 = ($214|0)==($216|0);
      if (!($217)) {
       $218 = ((($216)) + -4|0);
       $219 = HEAP32[$218>>2]|0;
       $220 = ((($209)) + 16|0);
       HEAP32[$220>>2] = $219;
       HEAP32[$215>>2] = $218;
      }
      $221 = (($211) + -1)|0;
      HEAP32[$210>>2] = $221;
     }
     $222 = ((($209)) + 64|0);
     $223 = HEAP32[$222>>2]|0;
     $224 = ((($209)) + 68|0);
     $225 = HEAP32[$224>>2]|0;
     $226 = ($223|0)==($225|0);
     if (!($226)) {
      $$sroa$09$016$i$i = $223;
      while(1) {
       $227 = ((($$sroa$09$016$i$i)) + 20|0);
       $228 = HEAP32[$227>>2]|0;
       $229 = ($228|0)==(0);
       if (!($229)) {
        $230 = ((($$sroa$09$016$i$i)) + 8|0);
        $231 = HEAP32[$230>>2]|0;
        $232 = ((($$sroa$09$016$i$i)) + 12|0);
        $233 = HEAP32[$232>>2]|0;
        $234 = ($231|0)==($233|0);
        if (!($234)) {
         $235 = ((($233)) + -4|0);
         $236 = HEAP32[$235>>2]|0;
         $237 = ((($$sroa$09$016$i$i)) + 4|0);
         HEAP32[$237>>2] = $236;
         HEAP32[$232>>2] = $235;
        }
        $238 = (($228) + -1)|0;
        HEAP32[$227>>2] = $238;
       }
       $239 = ((($$sroa$09$016$i$i)) + 52|0);
       $240 = ($239|0)==($225|0);
       if ($240) {
        break;
       } else {
        $$sroa$09$016$i$i = $239;
       }
      }
     }
     $241 = ((($209)) + 76|0);
     $242 = HEAP32[$241>>2]|0;
     $243 = ((($209)) + 80|0);
     $244 = HEAP32[$243>>2]|0;
     $245 = ($242|0)==($244|0);
     if ($245) {
      __ZNSt3__26__treeINS_12__value_typeIdN7osgUtil11CullVisitor21MatrixPlanesDrawablesEEENS_19__map_value_compareIdS5_NS_4lessIdEELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($3,$168);
      $278 = HEAP32[$62>>2]|0;
      __ZNSt3__26__treeINS_12__value_typeIdN7osgUtil11CullVisitor21MatrixPlanesDrawablesEEENS_19__map_value_compareIdS5_NS_4lessIdEELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($2,$278);
      STACKTOP = sp;return;
     } else {
      $$sroa$03$015$i$i = $242;
     }
     while(1) {
      $246 = ((($$sroa$03$015$i$i)) + 36|0);
      $247 = HEAP32[$246>>2]|0;
      $248 = ($247|0)==(0);
      if (!($248)) {
       $249 = ((($$sroa$03$015$i$i)) + 24|0);
       $250 = HEAP32[$249>>2]|0;
       $251 = ((($$sroa$03$015$i$i)) + 28|0);
       $252 = HEAP32[$251>>2]|0;
       $253 = ($250|0)==($252|0);
       if (!($253)) {
        $254 = ((($252)) + -4|0);
        $255 = HEAP32[$254>>2]|0;
        $256 = ((($$sroa$03$015$i$i)) + 20|0);
        HEAP32[$256>>2] = $255;
        HEAP32[$251>>2] = $254;
       }
       $257 = (($247) + -1)|0;
       HEAP32[$246>>2] = $257;
      }
      $258 = ((($$sroa$03$015$i$i)) + 68|0);
      $259 = HEAP32[$258>>2]|0;
      $260 = ((($$sroa$03$015$i$i)) + 72|0);
      $261 = HEAP32[$260>>2]|0;
      $262 = ($259|0)==($261|0);
      if (!($262)) {
       $$sroa$03$07$i$i$i = $259;
       while(1) {
        $263 = ((($$sroa$03$07$i$i$i)) + 16|0);
        $264 = HEAP32[$263>>2]|0;
        $265 = ($264|0)==(0);
        if (!($265)) {
         $266 = ((($$sroa$03$07$i$i$i)) + 4|0);
         $267 = HEAP32[$266>>2]|0;
         $268 = ((($$sroa$03$07$i$i$i)) + 8|0);
         $269 = HEAP32[$268>>2]|0;
         $270 = ($267|0)==($269|0);
         if (!($270)) {
          $271 = ((($269)) + -4|0);
          $272 = HEAP32[$271>>2]|0;
          HEAP32[$$sroa$03$07$i$i$i>>2] = $272;
          HEAP32[$268>>2] = $271;
         }
         $273 = (($264) + -1)|0;
         HEAP32[$263>>2] = $273;
        }
        $274 = ((($$sroa$03$07$i$i$i)) + 48|0);
        $275 = ($274|0)==($261|0);
        if ($275) {
         break;
        } else {
         $$sroa$03$07$i$i$i = $274;
        }
       }
      }
      $276 = ((($$sroa$03$015$i$i)) + 80|0);
      $277 = ($276|0)==($244|0);
      if ($277) {
       break;
      } else {
       $$sroa$03$015$i$i = $276;
      }
     }
     __ZNSt3__26__treeINS_12__value_typeIdN7osgUtil11CullVisitor21MatrixPlanesDrawablesEEENS_19__map_value_compareIdS5_NS_4lessIdEELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($3,$168);
     $278 = HEAP32[$62>>2]|0;
     __ZNSt3__26__treeINS_12__value_typeIdN7osgUtil11CullVisitor21MatrixPlanesDrawablesEEENS_19__map_value_compareIdS5_NS_4lessIdEELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($2,$278);
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $279 = ___cxa_find_matching_catch_2()|0;
 $280 = tempRet0;
 $281 = HEAP32[$73>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIdN7osgUtil11CullVisitor21MatrixPlanesDrawablesEEENS_19__map_value_compareIdS5_NS_4lessIdEELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($3,$281);
 $282 = HEAP32[$62>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIdN7osgUtil11CullVisitor21MatrixPlanesDrawablesEEENS_19__map_value_compareIdS5_NS_4lessIdEELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($2,$282);
 ___resumeException($279|0);
 // unreachable;
}
function __ZN7osgUtil11CullVisitor5applyERN3osg8ClipNodeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$pre$i = 0, $$sink$i = 0, $$sink$i18 = 0, $$sroa$020$024 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond$i = 0, $or$cond$i17 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 120|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)!=(0|0);
 if ($4) {
  $5 = ((($0)) + 376|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (__ZN7osgUtil10StateGraph14find_or_insertEPKN3osg8StateSetE($6,$3)|0);
  HEAP32[$5>>2] = $7;
  $8 = ((($3)) + 120|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($9|0)==(0);
  if (!($10)) {
   $11 = ((($3)) + 128|0);
   $12 = ((($11)) + 11|0);
   $13 = HEAP8[$12>>0]|0;
   $14 = ($13<<24>>24)<(0);
   if ($14) {
    $15 = ((($3)) + 132|0);
    $16 = HEAP32[$15>>2]|0;
    $18 = $16;
   } else {
    $17 = $13&255;
    $18 = $17;
   }
   $19 = ($18|0)==(0);
   if ($19) {
    $45 = $9;
   } else {
    $20 = ((($0)) + 440|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = ($21|0)!=(0);
    $23 = $9 & 4;
    $24 = ($23|0)==(0);
    $or$cond$i17 = $24 & $22;
    if ($or$cond$i17) {
     $45 = $9;
    } else {
     $25 = ((($0)) + 384|0);
     $26 = ((($0)) + 392|0);
     $27 = HEAP32[$26>>2]|0;
     $28 = ((($0)) + 396|0);
     $29 = HEAP32[$28>>2]|0;
     $30 = ($27|0)==($29|0);
     if ($30) {
      $34 = ((($0)) + 388|0);
      __ZNSt3__26vectorIPN7osgUtil9RenderBinENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_($34,$25);
     } else {
      $31 = HEAP32[$25>>2]|0;
      HEAP32[$27>>2] = $31;
      $32 = HEAP32[$26>>2]|0;
      $33 = ((($32)) + 4|0);
      HEAP32[$26>>2] = $33;
     }
     $35 = ((($3)) + 140|0);
     $36 = HEAP8[$35>>0]|0;
     $37 = ($36<<24>>24)==(0);
     $38 = HEAP32[$25>>2]|0;
     if ($37) {
      $39 = ((($38)) + 40|0);
      $40 = HEAP32[$39>>2]|0;
      $$sink$i = $40;
     } else {
      $$sink$i = $38;
     }
     $41 = ((($3)) + 124|0);
     $42 = HEAP32[$41>>2]|0;
     $43 = (__ZN7osgUtil9RenderBin14find_or_insertEiRKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE($$sink$i,$42,$11)|0);
     HEAP32[$25>>2] = $43;
     $$pre$i = HEAP32[$8>>2]|0;
     $45 = $$pre$i;
    }
   }
   $44 = $45 & 2;
   $46 = ($44|0)==(0);
   if (!($46)) {
    $47 = ((($0)) + 440|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = (($48) + 1)|0;
    HEAP32[$47>>2] = $49;
   }
  }
 }
 $50 = ((($0)) + 168|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = ($51|0)==(0);
 $53 = ((($0)) + 152|0);
 $54 = ((($0)) + 352|0);
 $$sink$i18 = $52 ? $54 : $53;
 $55 = HEAP32[$$sink$i18>>2]|0;
 $56 = ((($1)) + 140|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = ((($1)) + 144|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = ($57|0)==($59|0);
 if (!($60)) {
  $61 = ((($1)) + 152|0);
  $62 = ((($0)) + 384|0);
  $$sroa$020$024 = $57;
  while(1) {
   $81 = HEAP32[$61>>2]|0;
   $82 = ($81|0)==(0);
   $83 = HEAP32[$$sroa$020$024>>2]|0;
   $84 = HEAP32[$62>>2]|0;
   $85 = ((($84)) + 40|0);
   $86 = HEAP32[$85>>2]|0;
   $87 = HEAP32[$86>>2]|0;
   $88 = ((($87)) + 184|0);
   $89 = HEAP32[$88>>2]|0;
   if ($82) {
    FUNCTION_TABLE_viii[$89 & 8191]($86,$55,$83);
   } else {
    FUNCTION_TABLE_viii[$89 & 8191]($86,0,$83);
   }
   $90 = ((($$sroa$020$024)) + 4|0);
   $91 = HEAP32[$58>>2]|0;
   $92 = ($90|0)==($91|0);
   if ($92) {
    break;
   } else {
    $$sroa$020$024 = $90;
   }
  }
 }
 $63 = ((($1)) + 100|0);
 $64 = HEAP32[$63>>2]|0;
 $65 = ($64|0)==(0|0);
 L30: do {
  if ($65) {
   $73 = ((($0)) + 16|0);
   $74 = HEAP32[$73>>2]|0;
   switch ($74|0) {
   case 0:  {
    break L30;
    break;
   }
   case 1:  {
    $75 = HEAP32[$1>>2]|0;
    $76 = ((($75)) + 192|0);
    $77 = HEAP32[$76>>2]|0;
    FUNCTION_TABLE_vii[$77 & 8191]($1,$0);
    break L30;
    break;
   }
   default: {
    $78 = HEAP32[$1>>2]|0;
    $79 = ((($78)) + 196|0);
    $80 = HEAP32[$79>>2]|0;
    FUNCTION_TABLE_vii[$80 & 8191]($1,$0);
    break L30;
   }
   }
  } else {
   $66 = HEAP32[$64>>2]|0;
   $67 = ((($66)) + 92|0);
   $68 = HEAP32[$67>>2]|0;
   $69 = HEAP32[$0>>2]|0;
   $70 = ((($69)) + -12|0);
   $71 = HEAP32[$70>>2]|0;
   $72 = (($0) + ($71)|0);
   (FUNCTION_TABLE_iiii[$68 & 8191]($64,$1,$72)|0);
  }
 } while(0);
 if (!($4)) {
  return;
 }
 $93 = ((($0)) + 376|0);
 $94 = HEAP32[$93>>2]|0;
 $95 = ((($94)) + 16|0);
 $96 = HEAP32[$95>>2]|0;
 $97 = ((($96)) + 120|0);
 $98 = HEAP32[$97>>2]|0;
 $99 = $98 & 2;
 $100 = ($99|0)==(0);
 if (!($100)) {
  $101 = ((($0)) + 440|0);
  $102 = HEAP32[$101>>2]|0;
  $103 = (($102) + -1)|0;
  HEAP32[$101>>2] = $103;
 }
 $104 = ($98|0)==(0);
 do {
  if (!($104)) {
   $105 = ((($96)) + 128|0);
   $106 = ((($105)) + 11|0);
   $107 = HEAP8[$106>>0]|0;
   $108 = ($107<<24>>24)<(0);
   if ($108) {
    $109 = ((($96)) + 132|0);
    $110 = HEAP32[$109>>2]|0;
    $112 = $110;
   } else {
    $111 = $107&255;
    $112 = $111;
   }
   $113 = ($112|0)==(0);
   if (!($113)) {
    $114 = ((($0)) + 440|0);
    $115 = HEAP32[$114>>2]|0;
    $116 = ($115|0)!=(0);
    $117 = $98 & 4;
    $118 = ($117|0)==(0);
    $or$cond$i = $118 & $116;
    if (!($or$cond$i)) {
     $119 = ((($0)) + 388|0);
     $120 = HEAP32[$119>>2]|0;
     $121 = ((($0)) + 392|0);
     $122 = HEAP32[$121>>2]|0;
     $123 = ($120|0)==($122|0);
     if ($123) {
      $124 = ((($0)) + 384|0);
      $125 = HEAP32[$124>>2]|0;
      $126 = ((($125)) + 40|0);
      $127 = HEAP32[$126>>2]|0;
      HEAP32[$124>>2] = $127;
      break;
     } else {
      $128 = ((($122)) + -4|0);
      $129 = HEAP32[$128>>2]|0;
      $130 = ((($0)) + 384|0);
      HEAP32[$130>>2] = $129;
      HEAP32[$121>>2] = $128;
      break;
     }
    }
   }
  }
 } while(0);
 $131 = ((($94)) + 12|0);
 $132 = HEAP32[$131>>2]|0;
 HEAP32[$93>>2] = $132;
 return;
}
function __ZN7osgUtil11CullVisitor5applyERN3osg10TexGenNodeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$pre$i = 0, $$sink$i = 0, $$sink$i17 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond$i = 0, $or$cond$i16 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 120|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)!=(0|0);
 if ($4) {
  $5 = ((($0)) + 376|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (__ZN7osgUtil10StateGraph14find_or_insertEPKN3osg8StateSetE($6,$3)|0);
  HEAP32[$5>>2] = $7;
  $8 = ((($3)) + 120|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($9|0)==(0);
  if (!($10)) {
   $11 = ((($3)) + 128|0);
   $12 = ((($11)) + 11|0);
   $13 = HEAP8[$12>>0]|0;
   $14 = ($13<<24>>24)<(0);
   if ($14) {
    $15 = ((($3)) + 132|0);
    $16 = HEAP32[$15>>2]|0;
    $18 = $16;
   } else {
    $17 = $13&255;
    $18 = $17;
   }
   $19 = ($18|0)==(0);
   if ($19) {
    $45 = $9;
   } else {
    $20 = ((($0)) + 440|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = ($21|0)!=(0);
    $23 = $9 & 4;
    $24 = ($23|0)==(0);
    $or$cond$i16 = $24 & $22;
    if ($or$cond$i16) {
     $45 = $9;
    } else {
     $25 = ((($0)) + 384|0);
     $26 = ((($0)) + 392|0);
     $27 = HEAP32[$26>>2]|0;
     $28 = ((($0)) + 396|0);
     $29 = HEAP32[$28>>2]|0;
     $30 = ($27|0)==($29|0);
     if ($30) {
      $34 = ((($0)) + 388|0);
      __ZNSt3__26vectorIPN7osgUtil9RenderBinENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_($34,$25);
     } else {
      $31 = HEAP32[$25>>2]|0;
      HEAP32[$27>>2] = $31;
      $32 = HEAP32[$26>>2]|0;
      $33 = ((($32)) + 4|0);
      HEAP32[$26>>2] = $33;
     }
     $35 = ((($3)) + 140|0);
     $36 = HEAP8[$35>>0]|0;
     $37 = ($36<<24>>24)==(0);
     $38 = HEAP32[$25>>2]|0;
     if ($37) {
      $39 = ((($38)) + 40|0);
      $40 = HEAP32[$39>>2]|0;
      $$sink$i = $40;
     } else {
      $$sink$i = $38;
     }
     $41 = ((($3)) + 124|0);
     $42 = HEAP32[$41>>2]|0;
     $43 = (__ZN7osgUtil9RenderBin14find_or_insertEiRKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE($$sink$i,$42,$11)|0);
     HEAP32[$25>>2] = $43;
     $$pre$i = HEAP32[$8>>2]|0;
     $45 = $$pre$i;
    }
   }
   $44 = $45 & 2;
   $46 = ($44|0)==(0);
   if (!($46)) {
    $47 = ((($0)) + 440|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = (($48) + 1)|0;
    HEAP32[$47>>2] = $49;
   }
  }
 }
 $50 = ((($1)) + 144|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = ($51|0)==(0);
 $53 = ((($1)) + 136|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = ((($1)) + 140|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = ((($0)) + 384|0);
 $58 = HEAP32[$57>>2]|0;
 $59 = ((($58)) + 40|0);
 $60 = HEAP32[$59>>2]|0;
 if ($52) {
  $61 = ((($0)) + 168|0);
  $62 = HEAP32[$61>>2]|0;
  $63 = ($62|0)==(0);
  $64 = ((($0)) + 152|0);
  $65 = ((($0)) + 352|0);
  $$sink$i17 = $63 ? $65 : $64;
  $66 = HEAP32[$$sink$i17>>2]|0;
  $67 = HEAP32[$60>>2]|0;
  $68 = ((($67)) + 188|0);
  $69 = HEAP32[$68>>2]|0;
  FUNCTION_TABLE_viiii[$69 & 8191]($60,$54,$66,$56);
 } else {
  $70 = HEAP32[$60>>2]|0;
  $71 = ((($70)) + 188|0);
  $72 = HEAP32[$71>>2]|0;
  FUNCTION_TABLE_viiii[$72 & 8191]($60,$54,0,$56);
 }
 $73 = ((($1)) + 100|0);
 $74 = HEAP32[$73>>2]|0;
 $75 = ($74|0)==(0|0);
 L25: do {
  if ($75) {
   $83 = ((($0)) + 16|0);
   $84 = HEAP32[$83>>2]|0;
   switch ($84|0) {
   case 0:  {
    break L25;
    break;
   }
   case 1:  {
    $85 = HEAP32[$1>>2]|0;
    $86 = ((($85)) + 192|0);
    $87 = HEAP32[$86>>2]|0;
    FUNCTION_TABLE_vii[$87 & 8191]($1,$0);
    break L25;
    break;
   }
   default: {
    $88 = HEAP32[$1>>2]|0;
    $89 = ((($88)) + 196|0);
    $90 = HEAP32[$89>>2]|0;
    FUNCTION_TABLE_vii[$90 & 8191]($1,$0);
    break L25;
   }
   }
  } else {
   $76 = HEAP32[$74>>2]|0;
   $77 = ((($76)) + 92|0);
   $78 = HEAP32[$77>>2]|0;
   $79 = HEAP32[$0>>2]|0;
   $80 = ((($79)) + -12|0);
   $81 = HEAP32[$80>>2]|0;
   $82 = (($0) + ($81)|0);
   (FUNCTION_TABLE_iiii[$78 & 8191]($74,$1,$82)|0);
  }
 } while(0);
 if (!($4)) {
  return;
 }
 $91 = ((($0)) + 376|0);
 $92 = HEAP32[$91>>2]|0;
 $93 = ((($92)) + 16|0);
 $94 = HEAP32[$93>>2]|0;
 $95 = ((($94)) + 120|0);
 $96 = HEAP32[$95>>2]|0;
 $97 = $96 & 2;
 $98 = ($97|0)==(0);
 if (!($98)) {
  $99 = ((($0)) + 440|0);
  $100 = HEAP32[$99>>2]|0;
  $101 = (($100) + -1)|0;
  HEAP32[$99>>2] = $101;
 }
 $102 = ($96|0)==(0);
 do {
  if (!($102)) {
   $103 = ((($94)) + 128|0);
   $104 = ((($103)) + 11|0);
   $105 = HEAP8[$104>>0]|0;
   $106 = ($105<<24>>24)<(0);
   if ($106) {
    $107 = ((($94)) + 132|0);
    $108 = HEAP32[$107>>2]|0;
    $110 = $108;
   } else {
    $109 = $105&255;
    $110 = $109;
   }
   $111 = ($110|0)==(0);
   if (!($111)) {
    $112 = ((($0)) + 440|0);
    $113 = HEAP32[$112>>2]|0;
    $114 = ($113|0)!=(0);
    $115 = $96 & 4;
    $116 = ($115|0)==(0);
    $or$cond$i = $116 & $114;
    if (!($or$cond$i)) {
     $117 = ((($0)) + 388|0);
     $118 = HEAP32[$117>>2]|0;
     $119 = ((($0)) + 392|0);
     $120 = HEAP32[$119>>2]|0;
     $121 = ($118|0)==($120|0);
     if ($121) {
      $122 = HEAP32[$57>>2]|0;
      $123 = ((($122)) + 40|0);
      $124 = HEAP32[$123>>2]|0;
      HEAP32[$57>>2] = $124;
      break;
     } else {
      $125 = ((($120)) + -4|0);
      $126 = HEAP32[$125>>2]|0;
      HEAP32[$57>>2] = $126;
      HEAP32[$119>>2] = $125;
      break;
     }
    }
   }
  }
 } while(0);
 $127 = ((($92)) + 12|0);
 $128 = HEAP32[$127>>2]|0;
 HEAP32[$91>>2] = $128;
 return;
}
function __ZN7osgUtil11CullVisitor5applyERN3osg11LightSourceE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$pre$i = 0, $$sink$i = 0, $$sink$i19 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond$i = 0, $or$cond$i18 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 120|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)!=(0|0);
 if ($4) {
  $5 = ((($0)) + 376|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (__ZN7osgUtil10StateGraph14find_or_insertEPKN3osg8StateSetE($6,$3)|0);
  HEAP32[$5>>2] = $7;
  $8 = ((($3)) + 120|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($9|0)==(0);
  if (!($10)) {
   $11 = ((($3)) + 128|0);
   $12 = ((($11)) + 11|0);
   $13 = HEAP8[$12>>0]|0;
   $14 = ($13<<24>>24)<(0);
   if ($14) {
    $15 = ((($3)) + 132|0);
    $16 = HEAP32[$15>>2]|0;
    $18 = $16;
   } else {
    $17 = $13&255;
    $18 = $17;
   }
   $19 = ($18|0)==(0);
   if ($19) {
    $45 = $9;
   } else {
    $20 = ((($0)) + 440|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = ($21|0)!=(0);
    $23 = $9 & 4;
    $24 = ($23|0)==(0);
    $or$cond$i18 = $24 & $22;
    if ($or$cond$i18) {
     $45 = $9;
    } else {
     $25 = ((($0)) + 384|0);
     $26 = ((($0)) + 392|0);
     $27 = HEAP32[$26>>2]|0;
     $28 = ((($0)) + 396|0);
     $29 = HEAP32[$28>>2]|0;
     $30 = ($27|0)==($29|0);
     if ($30) {
      $34 = ((($0)) + 388|0);
      __ZNSt3__26vectorIPN7osgUtil9RenderBinENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_($34,$25);
     } else {
      $31 = HEAP32[$25>>2]|0;
      HEAP32[$27>>2] = $31;
      $32 = HEAP32[$26>>2]|0;
      $33 = ((($32)) + 4|0);
      HEAP32[$26>>2] = $33;
     }
     $35 = ((($3)) + 140|0);
     $36 = HEAP8[$35>>0]|0;
     $37 = ($36<<24>>24)==(0);
     $38 = HEAP32[$25>>2]|0;
     if ($37) {
      $39 = ((($38)) + 40|0);
      $40 = HEAP32[$39>>2]|0;
      $$sink$i = $40;
     } else {
      $$sink$i = $38;
     }
     $41 = ((($3)) + 124|0);
     $42 = HEAP32[$41>>2]|0;
     $43 = (__ZN7osgUtil9RenderBin14find_or_insertEiRKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE($$sink$i,$42,$11)|0);
     HEAP32[$25>>2] = $43;
     $$pre$i = HEAP32[$8>>2]|0;
     $45 = $$pre$i;
    }
   }
   $44 = $45 & 2;
   $46 = ($44|0)==(0);
   if (!($46)) {
    $47 = ((($0)) + 440|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = (($48) + 1)|0;
    HEAP32[$47>>2] = $49;
   }
  }
 }
 $50 = ((($1)) + 140|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = ($51|0)==(0|0);
 do {
  if (!($52)) {
   $53 = ((($1)) + 144|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = ($54|0)==(0);
   $56 = ((($0)) + 384|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = ((($57)) + 40|0);
   $59 = HEAP32[$58>>2]|0;
   if ($55) {
    $60 = ((($0)) + 168|0);
    $61 = HEAP32[$60>>2]|0;
    $62 = ($61|0)==(0);
    $63 = ((($0)) + 152|0);
    $64 = ((($0)) + 352|0);
    $$sink$i19 = $62 ? $64 : $63;
    $65 = HEAP32[$$sink$i19>>2]|0;
    $66 = HEAP32[$59>>2]|0;
    $67 = ((($66)) + 184|0);
    $68 = HEAP32[$67>>2]|0;
    FUNCTION_TABLE_viii[$68 & 8191]($59,$65,$51);
    break;
   } else {
    $69 = HEAP32[$59>>2]|0;
    $70 = ((($69)) + 184|0);
    $71 = HEAP32[$70>>2]|0;
    FUNCTION_TABLE_viii[$71 & 8191]($59,0,$51);
    break;
   }
  }
 } while(0);
 $72 = ((($1)) + 100|0);
 $73 = HEAP32[$72>>2]|0;
 $74 = ($73|0)==(0|0);
 L27: do {
  if ($74) {
   $82 = ((($0)) + 16|0);
   $83 = HEAP32[$82>>2]|0;
   switch ($83|0) {
   case 0:  {
    break L27;
    break;
   }
   case 1:  {
    $84 = HEAP32[$1>>2]|0;
    $85 = ((($84)) + 192|0);
    $86 = HEAP32[$85>>2]|0;
    FUNCTION_TABLE_vii[$86 & 8191]($1,$0);
    break L27;
    break;
   }
   default: {
    $87 = HEAP32[$1>>2]|0;
    $88 = ((($87)) + 196|0);
    $89 = HEAP32[$88>>2]|0;
    FUNCTION_TABLE_vii[$89 & 8191]($1,$0);
    break L27;
   }
   }
  } else {
   $75 = HEAP32[$73>>2]|0;
   $76 = ((($75)) + 92|0);
   $77 = HEAP32[$76>>2]|0;
   $78 = HEAP32[$0>>2]|0;
   $79 = ((($78)) + -12|0);
   $80 = HEAP32[$79>>2]|0;
   $81 = (($0) + ($80)|0);
   (FUNCTION_TABLE_iiii[$77 & 8191]($73,$1,$81)|0);
  }
 } while(0);
 if (!($4)) {
  return;
 }
 $90 = ((($0)) + 376|0);
 $91 = HEAP32[$90>>2]|0;
 $92 = ((($91)) + 16|0);
 $93 = HEAP32[$92>>2]|0;
 $94 = ((($93)) + 120|0);
 $95 = HEAP32[$94>>2]|0;
 $96 = $95 & 2;
 $97 = ($96|0)==(0);
 if (!($97)) {
  $98 = ((($0)) + 440|0);
  $99 = HEAP32[$98>>2]|0;
  $100 = (($99) + -1)|0;
  HEAP32[$98>>2] = $100;
 }
 $101 = ($95|0)==(0);
 do {
  if (!($101)) {
   $102 = ((($93)) + 128|0);
   $103 = ((($102)) + 11|0);
   $104 = HEAP8[$103>>0]|0;
   $105 = ($104<<24>>24)<(0);
   if ($105) {
    $106 = ((($93)) + 132|0);
    $107 = HEAP32[$106>>2]|0;
    $109 = $107;
   } else {
    $108 = $104&255;
    $109 = $108;
   }
   $110 = ($109|0)==(0);
   if (!($110)) {
    $111 = ((($0)) + 440|0);
    $112 = HEAP32[$111>>2]|0;
    $113 = ($112|0)!=(0);
    $114 = $95 & 4;
    $115 = ($114|0)==(0);
    $or$cond$i = $115 & $113;
    if (!($or$cond$i)) {
     $116 = ((($0)) + 388|0);
     $117 = HEAP32[$116>>2]|0;
     $118 = ((($0)) + 392|0);
     $119 = HEAP32[$118>>2]|0;
     $120 = ($117|0)==($119|0);
     if ($120) {
      $121 = ((($0)) + 384|0);
      $122 = HEAP32[$121>>2]|0;
      $123 = ((($122)) + 40|0);
      $124 = HEAP32[$123>>2]|0;
      HEAP32[$121>>2] = $124;
      break;
     } else {
      $125 = ((($119)) + -4|0);
      $126 = HEAP32[$125>>2]|0;
      $127 = ((($0)) + 384|0);
      HEAP32[$127>>2] = $126;
      HEAP32[$118>>2] = $125;
      break;
     }
    }
   }
  }
 } while(0);
 $128 = ((($91)) + 12|0);
 $129 = HEAP32[$128>>2]|0;
 HEAP32[$90>>2] = $129;
 return;
}
function __ZN7osgUtil11CullVisitor5applyERN3osg9TransformE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$pre = 0, $$pre$i = 0, $$pre$phiZ2D = 0, $$pre18$pre$phiZZ2D = 0, $$sink$i = 0, $$sink$i14 = 0, $$sroa$03$015$i$i = 0, $$sroa$03$07$i$i$i = 0, $$sroa$09$016$i$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0.0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0;
 var $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0;
 var $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0;
 var $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $or$cond$i = 0, $or$cond$i16 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 56|0);
 $3 = ((($1)) + 108|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 do {
  if ($5) {
   $6 = ((($1)) + 104|0);
   $7 = HEAP8[$6>>0]|0;
   $8 = ($7<<24>>24)==(0);
   if ($8) {
    label = 3;
   } else {
    $11 = (__ZNK3osg4Node8getBoundEv($1)|0);
    $12 = ((($11)) + 12|0);
    $13 = +HEAPF32[$12>>2];
    $14 = !($13 >= 0.0);
    $15 = ((($0)) + 336|0);
    $16 = HEAP32[$15>>2]|0;
    if ($14) {
     $$pre18$pre$phiZZ2D = $15;$18 = $16;
     label = 5;
    } else {
     $21 = (__ZNK3osg4Node8getBoundEv($1)|0);
     $22 = (__ZN3osg10CullingSet8isCulledERKNS_18BoundingSphereImplINS_5Vec3fEEE($16,$21)|0);
     if ($22) {
      return;
     } else {
      $$pre = HEAP32[$15>>2]|0;
      $$pre$phiZ2D = $15;$23 = $$pre;
      break;
     }
    }
   }
  } else {
   label = 3;
  }
 } while(0);
 if ((label|0) == 3) {
  $9 = ((($0)) + 336|0);
  $10 = HEAP32[$9>>2]|0;
  $$pre18$pre$phiZZ2D = $9;$18 = $10;
  label = 5;
 }
 if ((label|0) == 5) {
  $17 = ((($18)) + 16|0);
  $19 = HEAP32[$17>>2]|0;
  $20 = ((($18)) + 36|0);
  HEAP32[$20>>2] = $19;
  $$pre$phiZ2D = $$pre18$pre$phiZZ2D;$23 = $18;
 }
 __ZN3osg10CullingSet15pushCurrentMaskEv($23);
 $24 = ((($1)) + 120|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)!=(0|0);
 if ($26) {
  $27 = ((($0)) + 376|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (__ZN7osgUtil10StateGraph14find_or_insertEPKN3osg8StateSetE($28,$25)|0);
  HEAP32[$27>>2] = $29;
  $30 = ((($25)) + 120|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = ($31|0)==(0);
  if (!($32)) {
   $33 = ((($25)) + 128|0);
   $34 = ((($33)) + 11|0);
   $35 = HEAP8[$34>>0]|0;
   $36 = ($35<<24>>24)<(0);
   if ($36) {
    $37 = ((($25)) + 132|0);
    $38 = HEAP32[$37>>2]|0;
    $40 = $38;
   } else {
    $39 = $35&255;
    $40 = $39;
   }
   $41 = ($40|0)==(0);
   if ($41) {
    $67 = $31;
   } else {
    $42 = ((($0)) + 440|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = ($43|0)!=(0);
    $45 = $31 & 4;
    $46 = ($45|0)==(0);
    $or$cond$i = $46 & $44;
    if ($or$cond$i) {
     $67 = $31;
    } else {
     $47 = ((($0)) + 384|0);
     $48 = ((($0)) + 392|0);
     $49 = HEAP32[$48>>2]|0;
     $50 = ((($0)) + 396|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = ($49|0)==($51|0);
     if ($52) {
      $56 = ((($0)) + 388|0);
      __ZNSt3__26vectorIPN7osgUtil9RenderBinENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_($56,$47);
     } else {
      $53 = HEAP32[$47>>2]|0;
      HEAP32[$49>>2] = $53;
      $54 = HEAP32[$48>>2]|0;
      $55 = ((($54)) + 4|0);
      HEAP32[$48>>2] = $55;
     }
     $57 = ((($25)) + 140|0);
     $58 = HEAP8[$57>>0]|0;
     $59 = ($58<<24>>24)==(0);
     $60 = HEAP32[$47>>2]|0;
     if ($59) {
      $61 = ((($60)) + 40|0);
      $62 = HEAP32[$61>>2]|0;
      $$sink$i = $62;
     } else {
      $$sink$i = $60;
     }
     $63 = ((($25)) + 124|0);
     $64 = HEAP32[$63>>2]|0;
     $65 = (__ZN7osgUtil9RenderBin14find_or_insertEiRKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE($$sink$i,$64,$33)|0);
     HEAP32[$47>>2] = $65;
     $$pre$i = HEAP32[$30>>2]|0;
     $67 = $$pre$i;
    }
   }
   $66 = $67 & 2;
   $68 = ($66|0)==(0);
   if (!($68)) {
    $69 = ((($0)) + 440|0);
    $70 = HEAP32[$69>>2]|0;
    $71 = (($70) + 1)|0;
    HEAP32[$69>>2] = $71;
   }
  }
 }
 $72 = ((($0)) + 168|0);
 $73 = HEAP32[$72>>2]|0;
 $74 = ($73|0)==(0);
 $75 = ((($0)) + 152|0);
 $76 = ((($0)) + 352|0);
 $$sink$i14 = $74 ? $76 : $75;
 $77 = HEAP32[$$sink$i14>>2]|0;
 $78 = ((($77)) + 32|0);
 $79 = (__ZN3osg9CullStack19createOrReuseMatrixERKNS_7MatrixdE($2,$78)|0);
 $80 = HEAP32[$1>>2]|0;
 $81 = ((($80)) + 264|0);
 $82 = HEAP32[$81>>2]|0;
 $83 = ((($79)) + 32|0);
 (FUNCTION_TABLE_iiii[$82 & 8191]($1,$83,$0)|0);
 $84 = ((($1)) + 136|0);
 $85 = HEAP32[$84>>2]|0;
 __ZN3osg9CullStack19pushModelViewMatrixEPNS_10RefMatrixdENS_9Transform14ReferenceFrameE($2,$79,$85);
 $86 = ((($1)) + 100|0);
 $87 = HEAP32[$86>>2]|0;
 $88 = ($87|0)==(0|0);
 L33: do {
  if ($88) {
   $96 = ((($0)) + 16|0);
   $97 = HEAP32[$96>>2]|0;
   switch ($97|0) {
   case 0:  {
    break L33;
    break;
   }
   case 1:  {
    $98 = HEAP32[$1>>2]|0;
    $99 = ((($98)) + 192|0);
    $100 = HEAP32[$99>>2]|0;
    FUNCTION_TABLE_vii[$100 & 8191]($1,$0);
    break L33;
    break;
   }
   default: {
    $101 = HEAP32[$1>>2]|0;
    $102 = ((($101)) + 196|0);
    $103 = HEAP32[$102>>2]|0;
    FUNCTION_TABLE_vii[$103 & 8191]($1,$0);
    break L33;
   }
   }
  } else {
   $89 = HEAP32[$87>>2]|0;
   $90 = ((($89)) + 92|0);
   $91 = HEAP32[$90>>2]|0;
   $92 = HEAP32[$0>>2]|0;
   $93 = ((($92)) + -12|0);
   $94 = HEAP32[$93>>2]|0;
   $95 = (($0) + ($94)|0);
   (FUNCTION_TABLE_iiii[$91 & 8191]($87,$1,$95)|0);
  }
 } while(0);
 __ZN3osg9CullStack18popModelViewMatrixEv($2);
 if ($26) {
  $104 = ((($0)) + 376|0);
  $105 = HEAP32[$104>>2]|0;
  $106 = ((($105)) + 16|0);
  $107 = HEAP32[$106>>2]|0;
  $108 = ((($107)) + 120|0);
  $109 = HEAP32[$108>>2]|0;
  $110 = $109 & 2;
  $111 = ($110|0)==(0);
  if (!($111)) {
   $112 = ((($0)) + 440|0);
   $113 = HEAP32[$112>>2]|0;
   $114 = (($113) + -1)|0;
   HEAP32[$112>>2] = $114;
  }
  $115 = ($109|0)==(0);
  do {
   if (!($115)) {
    $116 = ((($107)) + 128|0);
    $117 = ((($116)) + 11|0);
    $118 = HEAP8[$117>>0]|0;
    $119 = ($118<<24>>24)<(0);
    if ($119) {
     $120 = ((($107)) + 132|0);
     $121 = HEAP32[$120>>2]|0;
     $123 = $121;
    } else {
     $122 = $118&255;
     $123 = $122;
    }
    $124 = ($123|0)==(0);
    if (!($124)) {
     $125 = ((($0)) + 440|0);
     $126 = HEAP32[$125>>2]|0;
     $127 = ($126|0)!=(0);
     $128 = $109 & 4;
     $129 = ($128|0)==(0);
     $or$cond$i16 = $129 & $127;
     if (!($or$cond$i16)) {
      $130 = ((($0)) + 388|0);
      $131 = HEAP32[$130>>2]|0;
      $132 = ((($0)) + 392|0);
      $133 = HEAP32[$132>>2]|0;
      $134 = ($131|0)==($133|0);
      if ($134) {
       $135 = ((($0)) + 384|0);
       $136 = HEAP32[$135>>2]|0;
       $137 = ((($136)) + 40|0);
       $138 = HEAP32[$137>>2]|0;
       HEAP32[$135>>2] = $138;
       break;
      } else {
       $139 = ((($133)) + -4|0);
       $140 = HEAP32[$139>>2]|0;
       $141 = ((($0)) + 384|0);
       HEAP32[$141>>2] = $140;
       HEAP32[$132>>2] = $139;
       break;
      }
     }
    }
   }
  } while(0);
  $142 = ((($105)) + 12|0);
  $143 = HEAP32[$142>>2]|0;
  HEAP32[$104>>2] = $143;
 }
 $144 = HEAP32[$$pre$phiZ2D>>2]|0;
 $145 = ((($144)) + 32|0);
 $146 = HEAP32[$145>>2]|0;
 $147 = ($146|0)==(0);
 if (!($147)) {
  $148 = ((($144)) + 20|0);
  $149 = HEAP32[$148>>2]|0;
  $150 = ((($144)) + 24|0);
  $151 = HEAP32[$150>>2]|0;
  $152 = ($149|0)==($151|0);
  if (!($152)) {
   $153 = ((($151)) + -4|0);
   $154 = HEAP32[$153>>2]|0;
   $155 = ((($144)) + 16|0);
   HEAP32[$155>>2] = $154;
   HEAP32[$150>>2] = $153;
  }
  $156 = (($146) + -1)|0;
  HEAP32[$145>>2] = $156;
 }
 $157 = ((($144)) + 64|0);
 $158 = HEAP32[$157>>2]|0;
 $159 = ((($144)) + 68|0);
 $160 = HEAP32[$159>>2]|0;
 $161 = ($158|0)==($160|0);
 if (!($161)) {
  $$sroa$09$016$i$i = $158;
  while(1) {
   $162 = ((($$sroa$09$016$i$i)) + 20|0);
   $163 = HEAP32[$162>>2]|0;
   $164 = ($163|0)==(0);
   if (!($164)) {
    $165 = ((($$sroa$09$016$i$i)) + 8|0);
    $166 = HEAP32[$165>>2]|0;
    $167 = ((($$sroa$09$016$i$i)) + 12|0);
    $168 = HEAP32[$167>>2]|0;
    $169 = ($166|0)==($168|0);
    if (!($169)) {
     $170 = ((($168)) + -4|0);
     $171 = HEAP32[$170>>2]|0;
     $172 = ((($$sroa$09$016$i$i)) + 4|0);
     HEAP32[$172>>2] = $171;
     HEAP32[$167>>2] = $170;
    }
    $173 = (($163) + -1)|0;
    HEAP32[$162>>2] = $173;
   }
   $174 = ((($$sroa$09$016$i$i)) + 52|0);
   $175 = ($174|0)==($160|0);
   if ($175) {
    break;
   } else {
    $$sroa$09$016$i$i = $174;
   }
  }
 }
 $176 = ((($144)) + 76|0);
 $177 = HEAP32[$176>>2]|0;
 $178 = ((($144)) + 80|0);
 $179 = HEAP32[$178>>2]|0;
 $180 = ($177|0)==($179|0);
 if ($180) {
  return;
 } else {
  $$sroa$03$015$i$i = $177;
 }
 while(1) {
  $181 = ((($$sroa$03$015$i$i)) + 36|0);
  $182 = HEAP32[$181>>2]|0;
  $183 = ($182|0)==(0);
  if (!($183)) {
   $184 = ((($$sroa$03$015$i$i)) + 24|0);
   $185 = HEAP32[$184>>2]|0;
   $186 = ((($$sroa$03$015$i$i)) + 28|0);
   $187 = HEAP32[$186>>2]|0;
   $188 = ($185|0)==($187|0);
   if (!($188)) {
    $189 = ((($187)) + -4|0);
    $190 = HEAP32[$189>>2]|0;
    $191 = ((($$sroa$03$015$i$i)) + 20|0);
    HEAP32[$191>>2] = $190;
    HEAP32[$186>>2] = $189;
   }
   $192 = (($182) + -1)|0;
   HEAP32[$181>>2] = $192;
  }
  $193 = ((($$sroa$03$015$i$i)) + 68|0);
  $194 = HEAP32[$193>>2]|0;
  $195 = ((($$sroa$03$015$i$i)) + 72|0);
  $196 = HEAP32[$195>>2]|0;
  $197 = ($194|0)==($196|0);
  if (!($197)) {
   $$sroa$03$07$i$i$i = $194;
   while(1) {
    $198 = ((($$sroa$03$07$i$i$i)) + 16|0);
    $199 = HEAP32[$198>>2]|0;
    $200 = ($199|0)==(0);
    if (!($200)) {
     $201 = ((($$sroa$03$07$i$i$i)) + 4|0);
     $202 = HEAP32[$201>>2]|0;
     $203 = ((($$sroa$03$07$i$i$i)) + 8|0);
     $204 = HEAP32[$203>>2]|0;
     $205 = ($202|0)==($204|0);
     if (!($205)) {
      $206 = ((($204)) + -4|0);
      $207 = HEAP32[$206>>2]|0;
      HEAP32[$$sroa$03$07$i$i$i>>2] = $207;
      HEAP32[$203>>2] = $206;
     }
     $208 = (($199) + -1)|0;
     HEAP32[$198>>2] = $208;
    }
    $209 = ((($$sroa$03$07$i$i$i)) + 48|0);
    $210 = ($209|0)==($196|0);
    if ($210) {
     break;
    } else {
     $$sroa$03$07$i$i$i = $209;
    }
   }
  }
  $211 = ((($$sroa$03$015$i$i)) + 80|0);
  $212 = ($211|0)==($179|0);
  if ($212) {
   break;
  } else {
   $$sroa$03$015$i$i = $211;
  }
 }
 return;
}
function __ZN7osgUtil11CullVisitor5applyERN3osg6CameraE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$$i$i = 0, $$0$ph$lcssa$i$i$i$i = 0, $$0$ph13$i$i$i$i = 0, $$0123 = 0, $$0124 = 0, $$05$i = 0, $$07$ph12$i$i$i$i = 0, $$0710$i$i$i$i = 0, $$11 = 0, $$11112 = 0, $$14 = 0, $$14115 = 0, $$21 = 0, $$21122 = 0, $$4 = 0, $$4105 = 0, $$9 = 0, $$9110 = 0, $$9110229 = 0, $$9231 = 0;
 var $$cast251 = 0, $$pr = 0, $$pr$i$i = 0, $$pre$i = 0, $$sink = 0, $$sink$i = 0, $$sink$i$i = 0, $$sink$i$i132 = 0, $$sink$i$i167 = 0, $$sink$i$i172 = 0, $$sink$i126 = 0, $$sink$i128 = 0, $$sink$i138 = 0, $$sink$i150 = 0, $$sink$i155 = 0, $$sink$i161 = 0, $$sink1$i$i = 0, $$sink1$i$i133 = 0, $$sink125$index = 0, $$sink125$index15 = 0;
 var $$sink240 = 0, $$sink242 = 0, $$sink244 = 0, $$sink244$in = 0, $$sink246 = 0, $$sink246$in = 0, $$sroa$0193$0 = 0, $$sroa$0193$1 = 0, $$sroa$0193$2 = 0, $$sroa$0193$4 = 0, $$sroa$0193$5 = 0, $$sroa$0193$5228 = 0, $$sroa$0218$1 = 0, $$sroa$0218$2 = 0, $$sroa$0218$3 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0;
 var $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0;
 var $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0;
 var $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0;
 var $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0.0, $167 = 0, $168 = 0.0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0;
 var $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0;
 var $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0;
 var $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0;
 var $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0;
 var $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0;
 var $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0;
 var $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0;
 var $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0;
 var $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0;
 var $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0;
 var $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0;
 var $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0.0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0;
 var $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0;
 var $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0;
 var $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0;
 var $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0.0, $457 = 0, $458 = 0, $459 = 0.0, $46 = 0, $460 = 0, $461 = 0, $462 = 0.0, $463 = 0, $464 = 0;
 var $465 = 0.0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0.0, $48 = 0, $480 = 0, $481 = 0.0, $482 = 0;
 var $483 = 0, $484 = 0.0, $485 = 0, $486 = 0, $487 = 0.0, $488 = 0, $489 = 0, $49 = 0, $490 = 0.0, $491 = 0, $492 = 0, $493 = 0.0, $494 = 0, $495 = 0, $496 = 0.0, $497 = 0, $498 = 0, $499 = 0.0, $5 = 0, $50 = 0;
 var $500 = 0, $501 = 0, $502 = 0.0, $503 = 0, $504 = 0, $505 = 0.0, $506 = 0, $507 = 0, $508 = 0.0, $509 = 0, $51 = 0, $510 = 0, $511 = 0.0, $512 = 0, $513 = 0, $514 = 0.0, $515 = 0, $516 = 0, $517 = 0.0, $518 = 0;
 var $519 = 0, $52 = 0, $520 = 0.0, $521 = 0, $522 = 0, $523 = 0.0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0;
 var $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0;
 var $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0;
 var $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0;
 var $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0;
 var $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0;
 var $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0;
 var $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0;
 var $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0;
 var $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0;
 var $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0;
 var $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $cond = 0, $or$cond$i = 0, $or$cond$i130 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 736|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(736|0);
 $2 = sp + 640|0;
 $3 = sp + 512|0;
 $4 = sp + 384|0;
 $5 = sp + 256|0;
 $6 = sp + 128|0;
 $7 = sp + 716|0;
 $8 = sp + 704|0;
 $9 = sp;
 $10 = ((($1)) + 120|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)!=(0|0);
 if ($12) {
  $13 = ((($0)) + 376|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (__ZN7osgUtil10StateGraph14find_or_insertEPKN3osg8StateSetE($14,$11)|0);
  HEAP32[$13>>2] = $15;
  $16 = ((($11)) + 120|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = ($17|0)==(0);
  if (!($18)) {
   $19 = ((($11)) + 128|0);
   $20 = ((($19)) + 11|0);
   $21 = HEAP8[$20>>0]|0;
   $22 = ($21<<24>>24)<(0);
   if ($22) {
    $23 = ((($11)) + 132|0);
    $24 = HEAP32[$23>>2]|0;
    $26 = $24;
   } else {
    $25 = $21&255;
    $26 = $25;
   }
   $27 = ($26|0)==(0);
   if ($27) {
    $53 = $17;
   } else {
    $28 = ((($0)) + 440|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = ($29|0)!=(0);
    $31 = $17 & 4;
    $32 = ($31|0)==(0);
    $or$cond$i = $32 & $30;
    if ($or$cond$i) {
     $53 = $17;
    } else {
     $33 = ((($0)) + 384|0);
     $34 = ((($0)) + 392|0);
     $35 = HEAP32[$34>>2]|0;
     $36 = ((($0)) + 396|0);
     $37 = HEAP32[$36>>2]|0;
     $38 = ($35|0)==($37|0);
     if ($38) {
      $42 = ((($0)) + 388|0);
      __ZNSt3__26vectorIPN7osgUtil9RenderBinENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_($42,$33);
     } else {
      $39 = HEAP32[$33>>2]|0;
      HEAP32[$35>>2] = $39;
      $40 = HEAP32[$34>>2]|0;
      $41 = ((($40)) + 4|0);
      HEAP32[$34>>2] = $41;
     }
     $43 = ((($11)) + 140|0);
     $44 = HEAP8[$43>>0]|0;
     $45 = ($44<<24>>24)==(0);
     $46 = HEAP32[$33>>2]|0;
     if ($45) {
      $47 = ((($46)) + 40|0);
      $48 = HEAP32[$47>>2]|0;
      $$sink$i = $48;
     } else {
      $$sink$i = $46;
     }
     $49 = ((($11)) + 124|0);
     $50 = HEAP32[$49>>2]|0;
     $51 = (__ZN7osgUtil9RenderBin14find_or_insertEiRKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE($$sink$i,$50,$19)|0);
     HEAP32[$33>>2] = $51;
     $$pre$i = HEAP32[$16>>2]|0;
     $53 = $$pre$i;
    }
   }
   $52 = $53 & 2;
   $54 = ($52|0)==(0);
   if (!($54)) {
    $55 = ((($0)) + 440|0);
    $56 = HEAP32[$55>>2]|0;
    $57 = (($56) + 1)|0;
    HEAP32[$55>>2] = $57;
   }
  }
 }
 $58 = ((($0)) + 56|0);
 __ZN3osg12CullSettingsC2ERKS0_($2,$58);
 $59 = ((($1)) + 144|0);
 __THREW__ = 0;
 invoke_vii(3624,($58|0),($59|0));
 $60 = __THREW__; __THREW__ = 0;
 $61 = $60&1;
 L21: do {
  if ($61) {
   label = 20;
  } else {
   $62 = HEAP32[$58>>2]|0;
   $63 = ((($62)) + 16|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = ((($1)) + 148|0);
   $66 = HEAP32[$65>>2]|0;
   __THREW__ = 0;
   invoke_viii($64|0,($58|0),($2|0),($66|0));
   $67 = __THREW__; __THREW__ = 0;
   $68 = $67&1;
   if ($68) {
    label = 20;
   } else {
    $69 = ((($0)) + 20|0);
    $70 = HEAP32[$69>>2]|0;
    $71 = HEAP32[$65>>2]|0;
    $72 = $71 & 1024;
    $73 = ($72|0)==(0);
    if ($73) {
     $74 = ((($1)) + 196|0);
     $75 = HEAP32[$74>>2]|0;
     HEAP32[$69>>2] = $75;
    }
    $78 = ((($0)) + 168|0);
    $79 = HEAP32[$78>>2]|0;
    $80 = ($79|0)==(0);
    $81 = ((($0)) + 152|0);
    $82 = ((($0)) + 352|0);
    $$sink$i126 = $80 ? $82 : $81;
    $83 = HEAP32[$$sink$i126>>2]|0;
    $84 = ((($1)) + 136|0);
    $85 = HEAP32[$84>>2]|0;
    $86 = ($85|0)==(0);
    do {
     if ($86) {
      $87 = ((($1)) + 292|0);
      $88 = HEAP32[$87>>2]|0;
      $89 = ($88|0)==(1);
      if ($89) {
       $90 = ((($0)) + 148|0);
       $91 = HEAP32[$90>>2]|0;
       $92 = ($91|0)==(0);
       $93 = ((($0)) + 132|0);
       $$sink$i128 = $92 ? $82 : $93;
       $94 = HEAP32[$$sink$i128>>2]|0;
       __THREW__ = 0;
       invoke_vi(3299,($3|0));
       $95 = __THREW__; __THREW__ = 0;
       $96 = $95&1;
       if (!($96)) {
        $97 = ((($1)) + 304|0);
        $98 = ((($94)) + 32|0);
        __THREW__ = 0;
        invoke_viii(3300,($3|0),($98|0),($97|0));
        $99 = __THREW__; __THREW__ = 0;
        $100 = $99&1;
        if (!($100)) {
         __THREW__ = 0;
         $101 = (invoke_iii(3622,($58|0),($3|0))|0);
         $102 = __THREW__; __THREW__ = 0;
         $103 = $102&1;
         if (!($103)) {
          $104 = HEAP32[$78>>2]|0;
          $105 = ($104|0)==(0);
          $$sink$i138 = $105 ? $82 : $81;
          $106 = HEAP32[$$sink$i138>>2]|0;
          __THREW__ = 0;
          invoke_vi(3299,($4|0));
          $107 = __THREW__; __THREW__ = 0;
          $108 = $107&1;
          if (!($108)) {
           $109 = ((($1)) + 432|0);
           $110 = ((($106)) + 32|0);
           __THREW__ = 0;
           invoke_viii(3300,($4|0),($110|0),($109|0));
           $111 = __THREW__; __THREW__ = 0;
           $112 = $111&1;
           if (!($112)) {
            __THREW__ = 0;
            $113 = (invoke_iii(3622,($58|0),($4|0))|0);
            $114 = __THREW__; __THREW__ = 0;
            $115 = $114&1;
            if (!($115)) {
             $$0123 = $101;$$0124 = $113;
             label = 44;
             break;
            }
           }
          }
          $120 = ___cxa_find_matching_catch_2()|0;
          $121 = tempRet0;
          $$21 = $120;$$21122 = $121;
          break L21;
         }
        }
       }
       $118 = ___cxa_find_matching_catch_2()|0;
       $119 = tempRet0;
       $$21 = $118;$$21122 = $119;
       break L21;
      } else {
       $122 = ((($0)) + 148|0);
       $123 = HEAP32[$122>>2]|0;
       $124 = ($123|0)==(0);
       $125 = ((($0)) + 132|0);
       $$sink$i150 = $124 ? $82 : $125;
       $126 = HEAP32[$$sink$i150>>2]|0;
       __THREW__ = 0;
       invoke_vi(3299,($5|0));
       $127 = __THREW__; __THREW__ = 0;
       $128 = $127&1;
       if (!($128)) {
        $129 = ((($126)) + 32|0);
        $130 = ((($1)) + 304|0);
        __THREW__ = 0;
        invoke_viii(3300,($5|0),($130|0),($129|0));
        $131 = __THREW__; __THREW__ = 0;
        $132 = $131&1;
        if (!($132)) {
         __THREW__ = 0;
         $133 = (invoke_iii(3622,($58|0),($5|0))|0);
         $134 = __THREW__; __THREW__ = 0;
         $135 = $134&1;
         if (!($135)) {
          $136 = HEAP32[$78>>2]|0;
          $137 = ($136|0)==(0);
          $$sink$i155 = $137 ? $82 : $81;
          $138 = HEAP32[$$sink$i155>>2]|0;
          __THREW__ = 0;
          invoke_vi(3299,($6|0));
          $139 = __THREW__; __THREW__ = 0;
          $140 = $139&1;
          if (!($140)) {
           $141 = ((($138)) + 32|0);
           $142 = ((($1)) + 432|0);
           __THREW__ = 0;
           invoke_viii(3300,($6|0),($142|0),($141|0));
           $143 = __THREW__; __THREW__ = 0;
           $144 = $143&1;
           if (!($144)) {
            __THREW__ = 0;
            $145 = (invoke_iii(3622,($58|0),($6|0))|0);
            $146 = __THREW__; __THREW__ = 0;
            $147 = $146&1;
            if (!($147)) {
             $$0123 = $133;$$0124 = $145;
             label = 44;
             break;
            }
           }
          }
          $150 = ___cxa_find_matching_catch_2()|0;
          $151 = tempRet0;
          $$21 = $150;$$21122 = $151;
          break L21;
         }
        }
       }
       $148 = ___cxa_find_matching_catch_2()|0;
       $149 = tempRet0;
       $$21 = $148;$$21122 = $149;
       break L21;
      }
     } else {
      $152 = ((($1)) + 304|0);
      __THREW__ = 0;
      $153 = (invoke_iii(3622,($58|0),($152|0))|0);
      $154 = __THREW__; __THREW__ = 0;
      $155 = $154&1;
      if (!($155)) {
       $156 = ((($1)) + 432|0);
       __THREW__ = 0;
       $157 = (invoke_iii(3622,($58|0),($156|0))|0);
       $158 = __THREW__; __THREW__ = 0;
       $159 = $158&1;
       if (!($159)) {
        $$0123 = $153;$$0124 = $157;
        label = 44;
       }
      }
     }
    } while(0);
    do {
     if ((label|0) == 44) {
      $160 = ((($1)) + 288|0);
      $161 = HEAP32[$160>>2]|0;
      $162 = ($161|0)==(0|0);
      if (!($162)) {
       __THREW__ = 0;
       invoke_vii(3579,($58|0),($161|0));
       $163 = __THREW__; __THREW__ = 0;
       $164 = $163&1;
       if ($164) {
        break;
       }
      }
      $165 = ((($0)) + 408|0);
      $166 = +HEAPF64[$165>>3];
      $167 = ((($0)) + 416|0);
      $168 = +HEAPF64[$167>>3];
      $169 = ((($7)) + 8|0);
      $170 = ((($7)) + 4|0);
      $171 = ((($0)) + 480|0);
      $172 = HEAP32[$171>>2]|0;
      HEAP32[$7>>2] = $172;
      $173 = ((($0)) + 484|0);
      $174 = HEAP32[$173>>2]|0;
      HEAP32[$170>>2] = $174;
      HEAP32[$173>>2] = 0;
      $175 = ((($0)) + 488|0);
      $176 = HEAP32[$175>>2]|0;
      HEAP32[$169>>2] = $176;
      HEAP32[$175>>2] = 0;
      $177 = ($176|0)==(0);
      $178 = $174;
      $179 = ((($178)) + 8|0);
      $$sink$i$i167 = $177 ? $7 : $179;
      HEAP32[$$sink$i$i167>>2] = $170;
      HEAP32[$171>>2] = $173;
      $180 = ((($8)) + 8|0);
      $181 = ((($8)) + 4|0);
      $182 = ((($0)) + 492|0);
      $183 = HEAP32[$182>>2]|0;
      HEAP32[$8>>2] = $183;
      $184 = ((($0)) + 496|0);
      $185 = HEAP32[$184>>2]|0;
      HEAP32[$181>>2] = $185;
      HEAP32[$184>>2] = 0;
      $186 = ((($0)) + 500|0);
      $187 = HEAP32[$186>>2]|0;
      HEAP32[$180>>2] = $187;
      HEAP32[$186>>2] = 0;
      $188 = ($187|0)==(0);
      $189 = $185;
      $190 = ((($189)) + 8|0);
      $$sink$i$i172 = $188 ? $8 : $190;
      HEAP32[$$sink$i$i172>>2] = $181;
      HEAP32[$182>>2] = $184;
      HEAPF64[$165>>3] = 3.4028234663852886E+38;
      HEAPF64[$167>>3] = -3.4028234663852886E+38;
      __THREW__ = 0;
      invoke_vii(3580,($58|0),($$0123|0));
      $191 = __THREW__; __THREW__ = 0;
      $192 = $191&1;
      L59: do {
       if ($192) {
        label = 54;
       } else {
        $193 = HEAP32[$84>>2]|0;
        __THREW__ = 0;
        invoke_viii(3581,($58|0),($$0124|0),($193|0));
        $194 = __THREW__; __THREW__ = 0;
        $195 = $194&1;
        if ($195) {
         label = 54;
        } else {
         $196 = ((($1)) + 560|0);
         $197 = HEAP32[$196>>2]|0;
         $198 = ($197|0)==(1);
         L62: do {
          if ($198) {
           $199 = ((($1)) + 100|0);
           $200 = HEAP32[$199>>2]|0;
           $201 = ($200|0)==(0|0);
           if (!($201)) {
            $202 = HEAP32[$200>>2]|0;
            $203 = ((($202)) + 92|0);
            $204 = HEAP32[$203>>2]|0;
            $205 = HEAP32[$0>>2]|0;
            $206 = ((($205)) + -12|0);
            $207 = HEAP32[$206>>2]|0;
            $208 = (($0) + ($207)|0);
            __THREW__ = 0;
            (invoke_iiii($204|0,($200|0),($1|0),($208|0))|0);
            $209 = __THREW__; __THREW__ = 0;
            $210 = $209&1;
            if ($210) {
             label = 54;
             break L59;
            } else {
             break;
            }
           }
           $211 = ((($0)) + 16|0);
           $212 = HEAP32[$211>>2]|0;
           switch ($212|0) {
           case 0:  {
            break L62;
            break;
           }
           case 1:  {
            $213 = HEAP32[$1>>2]|0;
            $214 = ((($213)) + 192|0);
            $215 = HEAP32[$214>>2]|0;
            __THREW__ = 0;
            invoke_vii($215|0,($1|0),($0|0));
            $216 = __THREW__; __THREW__ = 0;
            $217 = $216&1;
            if ($217) {
             label = 54;
             break L59;
            } else {
             break L62;
            }
            break;
           }
           default: {
            $218 = HEAP32[$1>>2]|0;
            $219 = ((($218)) + 196|0);
            $220 = HEAP32[$219>>2]|0;
            __THREW__ = 0;
            invoke_vii($220|0,($1|0),($0|0));
            $221 = __THREW__; __THREW__ = 0;
            $222 = $221&1;
            if ($222) {
             label = 54;
             break L59;
            } else {
             break L62;
            }
           }
           }
          } else {
           $225 = ((($0)) + 384|0);
           $226 = HEAP32[$225>>2]|0;
           $227 = ((($226)) + 40|0);
           $228 = HEAP32[$227>>2]|0;
           $229 = ((($1)) + 632|0);
           $230 = HEAP32[$229>>2]|0;
           $231 = ($230|0)==(0|0);
           if ($231) {
            label = 58;
           } else {
            $232 = (___dynamic_cast($230,26112,22608,0)|0);
            $233 = ($232|0)==(0|0);
            if ($233) {
             label = 58;
            } else {
             $234 = ((($232)) + 8|0);
             $235 = HEAP32[$234>>2]|0;HEAP32[$234>>2] = (($235+1)|0);
             $$sroa$0218$2 = $232;
             label = 66;
            }
           }
           if ((label|0) == 58) {
            __THREW__ = 0;
            $236 = (invoke_ii(3276,60)|0);
            $237 = __THREW__; __THREW__ = 0;
            $238 = $237&1;
            if ($238) {
             $$sroa$0218$1 = 0;
             label = 64;
            } else {
             __THREW__ = 0;
             invoke_vi(3625,($236|0));
             $239 = __THREW__; __THREW__ = 0;
             $240 = $239&1;
             if ($240) {
              $254 = ___cxa_find_matching_catch_2()|0;
              $255 = tempRet0;
              __ZdlPv($236);
              $$14 = $254;$$14115 = $255;
              break L59;
             }
             $241 = ((($236)) + 8|0);
             $242 = HEAP32[$241>>2]|0;HEAP32[$241>>2] = (($242+1)|0);
             $243 = HEAP32[$229>>2]|0;
             $244 = ($243|0)==($236|0);
             if ($244) {
              $$sroa$0218$2 = $236;
              label = 66;
             } else {
              HEAP32[$229>>2] = $236;
              $245 = HEAP32[$241>>2]|0;HEAP32[$241>>2] = (($245+1)|0);
              $246 = ($243|0)==(0|0);
              if ($246) {
               $$sroa$0218$2 = $236;
               label = 66;
              } else {
               $247 = ((($243)) + 8|0);
               $248 = HEAP32[$247>>2]|0;HEAP32[$247>>2] = (($248-1)|0);
               $249 = ($248|0)==(1);
               if ($249) {
                __THREW__ = 0;
                invoke_viii(3262,($243|0),1,1);
                $250 = __THREW__; __THREW__ = 0;
                $251 = $250&1;
                if ($251) {
                 $$sroa$0218$1 = $236;
                 label = 64;
                } else {
                 $$sroa$0218$2 = $236;
                 label = 66;
                }
               } else {
                $$sroa$0218$2 = $236;
                label = 66;
               }
              }
             }
            }
           }
           L83: do {
            if ((label|0) == 66) {
             $256 = HEAP32[$0>>2]|0;
             $257 = ((($256)) + -12|0);
             $258 = HEAP32[$257>>2]|0;
             $259 = (($0) + ($258)|0);
             $260 = ((($$sroa$0218$2)) + 36|0);
             $261 = HEAP32[$260>>2]|0;
             $262 = ((($261)) + 8|0);
             $263 = HEAP32[$262>>2]|0;
             __THREW__ = 0;
             (invoke_ii($263|0,($260|0))|0);
             $264 = __THREW__; __THREW__ = 0;
             $265 = $264&1;
             if ($265) {
              $$sroa$0218$1 = $$sroa$0218$2;
              label = 64;
             } else {
              $266 = ((($$sroa$0218$2)) + 52|0);
              $267 = HEAP32[$266>>2]|0;
              $268 = ($267|0)==(0|0);
              if ($268) {
               $$05$i = 0;$379 = 0;
              } else {
               $$0$ph13$i$i$i$i = $266;$$07$ph12$i$i$i$i = $267;
               L87: while(1) {
                $$0710$i$i$i$i = $$07$ph12$i$i$i$i;
                while(1) {
                 $269 = ((($$0710$i$i$i$i)) + 16|0);
                 $270 = HEAP32[$269>>2]|0;
                 $271 = ($270>>>0)<($259>>>0);
                 if (!($271)) {
                  break;
                 }
                 $274 = ((($$0710$i$i$i$i)) + 4|0);
                 $275 = HEAP32[$274>>2]|0;
                 $276 = ($275|0)==(0|0);
                 if ($276) {
                  $$0$ph$lcssa$i$i$i$i = $$0$ph13$i$i$i$i;
                  break L87;
                 } else {
                  $$0710$i$i$i$i = $275;
                 }
                }
                $272 = HEAP32[$$0710$i$i$i$i>>2]|0;
                $273 = ($272|0)==(0|0);
                if ($273) {
                 $$0$ph$lcssa$i$i$i$i = $$0710$i$i$i$i;
                 break;
                } else {
                 $$0$ph13$i$i$i$i = $$0710$i$i$i$i;$$07$ph12$i$i$i$i = $272;
                }
               }
               $277 = ($$0$ph$lcssa$i$i$i$i|0)==($266|0);
               if ($277) {
                $$05$i = 0;$379 = 0;
               } else {
                $278 = ((($$0$ph$lcssa$i$i$i$i)) + 16|0);
                $279 = HEAP32[$278>>2]|0;
                $280 = ($279>>>0)>($259>>>0);
                if ($280) {
                 $$05$i = 0;$379 = 0;
                } else {
                 $281 = ((($$0$ph$lcssa$i$i$i$i)) + 20|0);
                 $282 = HEAP32[$281>>2]|0;
                 $$05$i = $282;$379 = $282;
                }
               }
              }
              $283 = HEAP32[$260>>2]|0;
              $284 = ((($283)) + 12|0);
              $285 = HEAP32[$284>>2]|0;
              __THREW__ = 0;
              (invoke_ii($285|0,($260|0))|0);
              $286 = __THREW__; __THREW__ = 0;
              $287 = $286&1;
              if ($287) {
               $$sroa$0218$1 = $$sroa$0218$2;
               label = 64;
              } else {
               $288 = ($$05$i|0)==(0|0);
               L98: do {
                if ($288) {
                 $289 = ((($1)) + 208|0);
                 $290 = HEAP32[$289>>2]|0;
                 $291 = ((($290)) + 8|0);
                 $292 = HEAP32[$291>>2]|0;
                 __THREW__ = 0;
                 (invoke_ii($292|0,($289|0))|0);
                 $293 = __THREW__; __THREW__ = 0;
                 $294 = $293&1;
                 if ($294) {
                  label = 99;
                  break;
                 }
                 $295 = ((($0)) + 380|0);
                 $296 = HEAP32[$295>>2]|0;
                 $297 = ($296|0)==(0|0);
                 do {
                  if ($297) {
                   __THREW__ = 0;
                   $301 = (invoke_ii(3276,424)|0);
                   $302 = __THREW__; __THREW__ = 0;
                   $303 = $302&1;
                   if ($303) {
                    $$sroa$0193$1 = 0;
                    label = 100;
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3573,($301|0));
                   $304 = __THREW__; __THREW__ = 0;
                   $305 = $304&1;
                   if (!($305)) {
                    $308 = $301;
                    label = 83;
                    break;
                   }
                   $351 = ___cxa_find_matching_catch_2()|0;
                   $352 = tempRet0;
                   __ZdlPv($301);
                   $$4 = $351;$$4105 = $352;$$sroa$0193$2 = 0;
                  } else {
                   __THREW__ = 0;
                   $298 = (invoke_ii(3626,($296|0))|0);
                   $299 = __THREW__; __THREW__ = 0;
                   $300 = $299&1;
                   if ($300) {
                    $$sroa$0193$1 = 0;
                    label = 100;
                    break;
                   }
                   $306 = ($298|0)==(0|0);
                   if ($306) {
                    $$sroa$0193$0 = 0;
                    label = 84;
                   } else {
                    $308 = $298;
                    label = 83;
                   }
                  }
                 } while(0);
                 if ((label|0) == 83) {
                  $307 = ((($308)) + 8|0);
                  $309 = HEAP32[$307>>2]|0;HEAP32[$307>>2] = (($309+1)|0);
                  $$sroa$0193$0 = $308;
                  label = 84;
                 }
                 L109: do {
                  if ((label|0) == 84) {
                   $310 = HEAP32[$0>>2]|0;
                   $311 = ((($310)) + -12|0);
                   $312 = HEAP32[$311>>2]|0;
                   $313 = (($0) + ($312)|0);
                   __THREW__ = 0;
                   invoke_viii(3627,($$sroa$0218$2|0),($313|0),($$sroa$0193$0|0));
                   $314 = __THREW__; __THREW__ = 0;
                   $315 = $314&1;
                   if ($315) {
                    $$sroa$0193$1 = $$sroa$0193$0;
                    label = 100;
                    break;
                   }
                   $316 = ((($$sroa$0193$0)) + 232|0);
                   $317 = HEAP32[$316>>2]|0;
                   $318 = ($317|0)==($1|0);
                   if (!($318)) {
                    __THREW__ = 0;
                    $319 = (invoke_ii(3325,($1|0))|0);
                    $320 = __THREW__; __THREW__ = 0;
                    $321 = $320&1;
                    if ($321) {
                     $$sroa$0193$1 = $$sroa$0193$0;
                     label = 100;
                     break;
                    }
                    $322 = ((($$sroa$0193$0)) + 228|0);
                    $323 = HEAP32[$322>>2]|0;
                    $324 = ($323|0)==($319|0);
                    if ($324) {
                     $334 = $319;
                    } else {
                     HEAP32[$322>>2] = $319;
                     $325 = ($319|0)==(0|0);
                     if (!($325)) {
                      $326 = ((($319)) + 8|0);
                      $327 = HEAP32[$326>>2]|0;HEAP32[$326>>2] = (($327+1)|0);
                     }
                     $328 = ($323|0)==(0|0);
                     do {
                      if (!($328)) {
                       $329 = ((($323)) + 8|0);
                       $330 = HEAP32[$329>>2]|0;HEAP32[$329>>2] = (($330-1)|0);
                       $331 = ($330|0)==(1);
                       if (!($331)) {
                        break;
                       }
                       __THREW__ = 0;
                       invoke_viii(3262,($323|0),1,1);
                       $332 = __THREW__; __THREW__ = 0;
                       $333 = $332&1;
                       if ($333) {
                        $$sroa$0193$1 = $$sroa$0193$0;
                        label = 100;
                        break L109;
                       }
                      }
                     } while(0);
                     $$pr$i$i = HEAP32[$322>>2]|0;
                     $334 = $$pr$i$i;
                    }
                    $335 = ($334|0)==(0|0);
                    if ($335) {
                     $339 = 0;
                    } else {
                     $336 = ((($334)) + 24|0);
                     $337 = HEAP32[$336>>2]|0;
                     $338 = ($337|0)!=(0|0);
                     $$$i$i = $338 ? $1 : 0;
                     $339 = $$$i$i;
                    }
                    HEAP32[$316>>2] = $339;
                    $340 = ((($$sroa$0193$0)) + 220|0);
                    HEAP8[$340>>0] = 1;
                   }
                   $341 = HEAP32[$65>>2]|0;
                   $342 = $341 & 131072;
                   $343 = ($342|0)==(0);
                   if ($343) {
                    $353 = ((($1)) + 568|0);
                    $$sink = 1;$$sink244$in = $353;
                   } else {
                    $344 = ((($228)) + 148|0);
                    $345 = ((($228)) + 152|0);
                    $346 = HEAP8[$345>>0]|0;
                    $$sink = $346;$$sink244$in = $344;
                   }
                   $$sink244 = HEAP32[$$sink244$in>>2]|0;
                   $354 = ((($$sroa$0193$0)) + 148|0);
                   HEAP32[$354>>2] = $$sink244;
                   $355 = ((($$sroa$0193$0)) + 152|0);
                   HEAP8[$355>>0] = $$sink;
                   $356 = $341 & 262144;
                   $357 = ($356|0)==(0);
                   if ($357) {
                    $361 = ((($1)) + 572|0);
                    $$sink240 = 1;$$sink246$in = $361;
                   } else {
                    $358 = ((($228)) + 156|0);
                    $359 = ((($228)) + 160|0);
                    $360 = HEAP8[$359>>0]|0;
                    $$sink240 = $360;$$sink246$in = $358;
                   }
                   $$sink246 = HEAP32[$$sink246$in>>2]|0;
                   $362 = ((($$sroa$0193$0)) + 156|0);
                   HEAP32[$362>>2] = $$sink246;
                   $363 = ((($$sroa$0193$0)) + 160|0);
                   HEAP8[$363>>0] = $$sink240;
                   $364 = HEAP32[$289>>2]|0;
                   $365 = ((($364)) + 12|0);
                   $366 = HEAP32[$365>>2]|0;
                   __THREW__ = 0;
                   (invoke_ii($366|0,($289|0))|0);
                   $367 = __THREW__; __THREW__ = 0;
                   $368 = $367&1;
                   if (!($368)) {
                    $$sroa$0193$4 = $$sroa$0193$0;
                    label = 110;
                    break L98;
                   }
                   $369 = ___cxa_find_matching_catch_2()|0;
                   $370 = tempRet0;
                   $$9110229 = $370;$$9231 = $369;$$sroa$0193$5228 = $$sroa$0193$0;
                   break L98;
                  }
                 } while(0);
                 if ((label|0) == 100) {
                  $349 = ___cxa_find_matching_catch_2()|0;
                  $350 = tempRet0;
                  $$4 = $349;$$4105 = $350;$$sroa$0193$2 = $$sroa$0193$1;
                 }
                 $371 = HEAP32[$289>>2]|0;
                 $372 = ((($371)) + 12|0);
                 $373 = HEAP32[$372>>2]|0;
                 __THREW__ = 0;
                 (invoke_ii($373|0,($289|0))|0);
                 $374 = __THREW__; __THREW__ = 0;
                 $375 = $374&1;
                 if (!($375)) {
                  $$9 = $$4;$$9110 = $$4105;$$sroa$0193$5 = $$sroa$0193$2;
                  label = 176;
                  break;
                 }
                 $722 = ___cxa_find_matching_catch_3(0|0)|0;
                 $723 = tempRet0;
                 ___clang_call_terminate($722);
                 // unreachable;
                } else {
                 $376 = ((($$05$i)) + 8|0);
                 $377 = HEAP32[$376>>2]|0;HEAP32[$376>>2] = (($377+1)|0);
                 $378 = HEAP32[$379>>2]|0;
                 $380 = ((($378)) + 140|0);
                 $381 = HEAP32[$380>>2]|0;
                 __THREW__ = 0;
                 invoke_vi($381|0,($$05$i|0));
                 $382 = __THREW__; __THREW__ = 0;
                 $383 = $382&1;
                 if ($383) {
                  label = 99;
                 } else {
                  $$sroa$0193$4 = $$05$i;
                  label = 110;
                 }
                }
               } while(0);
               L143: do {
                if ((label|0) == 99) {
                 $347 = ___cxa_find_matching_catch_2()|0;
                 $348 = tempRet0;
                 $$9 = $347;$$9110 = $348;$$sroa$0193$5 = $$05$i;
                 label = 176;
                }
                else if ((label|0) == 110) {
                 $384 = ((($1)) + 272|0);
                 $385 = +HEAPF64[$384>>3];
                 $386 = ((($$sroa$0193$4)) + 208|0);
                 HEAPF64[$386>>3] = $385;
                 $387 = ((($1)) + 256|0);
                 $388 = ((($$sroa$0193$4)) + 188|0);
                 ;HEAP32[$388>>2]=HEAP32[$387>>2]|0;HEAP32[$388+4>>2]=HEAP32[$387+4>>2]|0;HEAP32[$388+8>>2]=HEAP32[$387+8>>2]|0;HEAP32[$388+12>>2]=HEAP32[$387+12>>2]|0;
                 $389 = ((($1)) + 280|0);
                 $390 = HEAP32[$389>>2]|0;
                 $391 = ((($$sroa$0193$4)) + 216|0);
                 HEAP32[$391>>2] = $390;
                 $392 = HEAP32[$65>>2]|0;
                 $393 = $392 & 16384;
                 $394 = ($393|0)==(0);
                 $395 = ((($1)) + 236|0);
                 $396 = ((($228)) + 164|0);
                 $$sink242 = $394 ? $395 : $396;
                 $397 = HEAP32[$$sink242>>2]|0;
                 $398 = ((($$sroa$0193$4)) + 164|0);
                 HEAP32[$398>>2] = $397;
                 $399 = $392 & 8192;
                 $400 = ($399|0)==(0);
                 $401 = ((($228)) + 172|0);
                 $402 = ((($1)) + 240|0);
                 $403 = $400 ? $402 : $401;
                 $404 = ((($$sroa$0193$4)) + 172|0);
                 ;HEAP32[$404>>2]=HEAP32[$403>>2]|0;HEAP32[$404+4>>2]=HEAP32[$403+4>>2]|0;HEAP32[$404+8>>2]=HEAP32[$403+8>>2]|0;HEAP32[$404+12>>2]=HEAP32[$403+12>>2]|0;
                 $405 = ((($1)) + 284|0);
                 $406 = HEAP32[$405>>2]|0;
                 $407 = ($406|0)==(0|0);
                 if ($407) {
                  $408 = ((($228)) + 168|0);
                  $409 = HEAP32[$408>>2]|0;
                  $413 = $409;
                 } else {
                  $413 = $406;
                 }
                 $410 = ((($$sroa$0193$4)) + 168|0);
                 $411 = HEAP32[$410>>2]|0;
                 $412 = ($411|0)==($413|0);
                 do {
                  if (!($412)) {
                   HEAP32[$410>>2] = $413;
                   $414 = ($413|0)==(0|0);
                   if (!($414)) {
                    $415 = ((($413)) + 8|0);
                    $416 = HEAP32[$415>>2]|0;HEAP32[$415>>2] = (($416+1)|0);
                   }
                   $417 = ($411|0)==(0|0);
                   if ($417) {
                    break;
                   }
                   $418 = ((($411)) + 8|0);
                   $419 = HEAP32[$418>>2]|0;HEAP32[$418>>2] = (($419-1)|0);
                   $420 = ($419|0)==(1);
                   if (!($420)) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(3262,($411|0),1,1);
                   $421 = __THREW__; __THREW__ = 0;
                   $422 = $421&1;
                   if (!($422)) {
                    break;
                   }
                   $588 = ___cxa_find_matching_catch_2()|0;
                   $589 = tempRet0;
                   $$9 = $588;$$9110 = $589;$$sroa$0193$5 = $$sroa$0193$4;
                   label = 176;
                   break L143;
                  }
                 } while(0);
                 $423 = HEAP32[$160>>2]|0;
                 $424 = ($423|0)==(0|0);
                 if ($424) {
                  $425 = ((($228)) + 140|0);
                  $426 = HEAP32[$425>>2]|0;
                  $430 = $426;
                 } else {
                  $430 = $423;
                 }
                 $427 = ((($$sroa$0193$4)) + 140|0);
                 $428 = HEAP32[$427>>2]|0;
                 $429 = ($428|0)==($430|0);
                 do {
                  if ($429) {
                   label = 126;
                  } else {
                   HEAP32[$427>>2] = $430;
                   $431 = ($430|0)==(0|0);
                   if (!($431)) {
                    $432 = ((($430)) + 8|0);
                    $433 = HEAP32[$432>>2]|0;HEAP32[$432>>2] = (($433+1)|0);
                   }
                   $434 = ($428|0)==(0|0);
                   if ($434) {
                    label = 126;
                    break;
                   }
                   $435 = ((($428)) + 8|0);
                   $436 = HEAP32[$435>>2]|0;HEAP32[$435>>2] = (($436-1)|0);
                   $437 = ($436|0)==(1);
                   if (!($437)) {
                    label = 126;
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(3262,($428|0),1,1);
                   $438 = __THREW__; __THREW__ = 0;
                   $439 = $438&1;
                   if (!($439)) {
                    label = 126;
                   }
                  }
                 } while(0);
                 L168: do {
                  if ((label|0) == 126) {
                   $440 = ((($$sroa$0193$4)) + 144|0);
                   $441 = HEAP32[$440>>2]|0;
                   $442 = ($441|0)==($$0124|0);
                   do {
                    if (!($442)) {
                     HEAP32[$440>>2] = $$0124;
                     $443 = ($$0124|0)==(0|0);
                     if (!($443)) {
                      $444 = ((($$0124)) + 8|0);
                      $445 = HEAP32[$444>>2]|0;HEAP32[$444>>2] = (($445+1)|0);
                     }
                     $446 = ($441|0)==(0|0);
                     if ($446) {
                      break;
                     }
                     $447 = ((($441)) + 8|0);
                     $448 = HEAP32[$447>>2]|0;HEAP32[$447>>2] = (($448-1)|0);
                     $449 = ($448|0)==(1);
                     if (!($449)) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_viii(3262,($441|0),1,1);
                     $450 = __THREW__; __THREW__ = 0;
                     $451 = $450&1;
                     if ($451) {
                      break L168;
                     }
                    }
                   } while(0);
                   __THREW__ = 0;
                   invoke_vi(3299,($9|0));
                   $452 = __THREW__; __THREW__ = 0;
                   $453 = $452&1;
                   if ($453) {
                    break;
                   }
                   $454 = ((($83)) + 32|0);
                   $455 = ((($83)) + 56|0);
                   $456 = +HEAPF64[$455>>3];
                   $457 = $456 == 0.0;
                   do {
                    if ($457) {
                     $458 = ((($83)) + 88|0);
                     $459 = +HEAPF64[$458>>3];
                     $460 = $459 == 0.0;
                     if (!($460)) {
                      label = 138;
                      break;
                     }
                     $461 = ((($83)) + 120|0);
                     $462 = +HEAPF64[$461>>3];
                     $463 = $462 == 0.0;
                     if (!($463)) {
                      label = 138;
                      break;
                     }
                     $464 = ((($83)) + 152|0);
                     $465 = +HEAPF64[$464>>3];
                     $466 = $465 == 1.0;
                     if (!($466)) {
                      label = 138;
                      break;
                     }
                     __THREW__ = 0;
                     (invoke_iii(3303,($9|0),($454|0))|0);
                     $467 = __THREW__; __THREW__ = 0;
                     $468 = $467&1;
                     if ($468) {
                      label = 165;
                     } else {
                      label = 139;
                     }
                    } else {
                     label = 138;
                    }
                   } while(0);
                   if ((label|0) == 138) {
                    __THREW__ = 0;
                    (invoke_iii(3304,($9|0),($454|0))|0);
                    $469 = __THREW__; __THREW__ = 0;
                    $470 = $469&1;
                    if ($470) {
                     label = 165;
                    } else {
                     label = 139;
                    }
                   }
                   L186: do {
                    if ((label|0) == 139) {
                     $471 = HEAP32[$78>>2]|0;
                     $472 = ($471|0)==(0);
                     $$sink$i161 = $472 ? $82 : $81;
                     $473 = HEAP32[$$sink$i161>>2]|0;
                     $474 = ((($473)) + 32|0);
                     __THREW__ = 0;
                     invoke_vii(3302,($9|0),($474|0));
                     $475 = __THREW__; __THREW__ = 0;
                     $476 = $475&1;
                     if ($476) {
                      label = 165;
                      break;
                     }
                     $477 = ((($$sroa$0193$4)) + 288|0);
                     $478 = ($477|0)==($9|0);
                     if (!($478)) {
                      $479 = +HEAPF64[$9>>3];
                      HEAPF64[$477>>3] = $479;
                      $480 = ((($9)) + 8|0);
                      $481 = +HEAPF64[$480>>3];
                      $482 = ((($$sroa$0193$4)) + 296|0);
                      HEAPF64[$482>>3] = $481;
                      $483 = ((($9)) + 16|0);
                      $484 = +HEAPF64[$483>>3];
                      $485 = ((($$sroa$0193$4)) + 304|0);
                      HEAPF64[$485>>3] = $484;
                      $486 = ((($9)) + 24|0);
                      $487 = +HEAPF64[$486>>3];
                      $488 = ((($$sroa$0193$4)) + 312|0);
                      HEAPF64[$488>>3] = $487;
                      $489 = ((($9)) + 32|0);
                      $490 = +HEAPF64[$489>>3];
                      $491 = ((($$sroa$0193$4)) + 320|0);
                      HEAPF64[$491>>3] = $490;
                      $492 = ((($9)) + 40|0);
                      $493 = +HEAPF64[$492>>3];
                      $494 = ((($$sroa$0193$4)) + 328|0);
                      HEAPF64[$494>>3] = $493;
                      $495 = ((($9)) + 48|0);
                      $496 = +HEAPF64[$495>>3];
                      $497 = ((($$sroa$0193$4)) + 336|0);
                      HEAPF64[$497>>3] = $496;
                      $498 = ((($9)) + 56|0);
                      $499 = +HEAPF64[$498>>3];
                      $500 = ((($$sroa$0193$4)) + 344|0);
                      HEAPF64[$500>>3] = $499;
                      $501 = ((($9)) + 64|0);
                      $502 = +HEAPF64[$501>>3];
                      $503 = ((($$sroa$0193$4)) + 352|0);
                      HEAPF64[$503>>3] = $502;
                      $504 = ((($9)) + 72|0);
                      $505 = +HEAPF64[$504>>3];
                      $506 = ((($$sroa$0193$4)) + 360|0);
                      HEAPF64[$506>>3] = $505;
                      $507 = ((($9)) + 80|0);
                      $508 = +HEAPF64[$507>>3];
                      $509 = ((($$sroa$0193$4)) + 368|0);
                      HEAPF64[$509>>3] = $508;
                      $510 = ((($9)) + 88|0);
                      $511 = +HEAPF64[$510>>3];
                      $512 = ((($$sroa$0193$4)) + 376|0);
                      HEAPF64[$512>>3] = $511;
                      $513 = ((($9)) + 96|0);
                      $514 = +HEAPF64[$513>>3];
                      $515 = ((($$sroa$0193$4)) + 384|0);
                      HEAPF64[$515>>3] = $514;
                      $516 = ((($9)) + 104|0);
                      $517 = +HEAPF64[$516>>3];
                      $518 = ((($$sroa$0193$4)) + 392|0);
                      HEAPF64[$518>>3] = $517;
                      $519 = ((($9)) + 112|0);
                      $520 = +HEAPF64[$519>>3];
                      $521 = ((($$sroa$0193$4)) + 400|0);
                      HEAPF64[$521>>3] = $520;
                      $522 = ((($9)) + 120|0);
                      $523 = +HEAPF64[$522>>3];
                      $524 = ((($$sroa$0193$4)) + 408|0);
                      HEAPF64[$524>>3] = $523;
                     }
                     $525 = ((($228)) + 420|0);
                     $526 = HEAP32[$525>>2]|0;
                     $527 = ($526|0)==(0|0);
                     do {
                      if ($527) {
                       __THREW__ = 0;
                       $528 = (invoke_ii(3276,56)|0);
                       $529 = __THREW__; __THREW__ = 0;
                       $530 = $529&1;
                       if ($530) {
                        label = 165;
                        break L186;
                       }
                       __THREW__ = 0;
                       invoke_vi(3628,($528|0));
                       $531 = __THREW__; __THREW__ = 0;
                       $532 = $531&1;
                       if ($532) {
                        $543 = ___cxa_find_matching_catch_2()|0;
                        $544 = tempRet0;
                        __ZdlPv($528);
                        $$sink125$index = $543;$$sink125$index15 = $544;
                        break L186;
                       }
                       $533 = HEAP32[$525>>2]|0;
                       $534 = ($533|0)==($528|0);
                       if ($534) {
                        $548 = $528;
                        break;
                       }
                       HEAP32[$525>>2] = $528;
                       $535 = ((($528)) + 8|0);
                       $536 = HEAP32[$535>>2]|0;HEAP32[$535>>2] = (($536+1)|0);
                       $537 = ($533|0)==(0|0);
                       do {
                        if (!($537)) {
                         $538 = ((($533)) + 8|0);
                         $539 = HEAP32[$538>>2]|0;HEAP32[$538>>2] = (($539-1)|0);
                         $540 = ($539|0)==(1);
                         if (!($540)) {
                          break;
                         }
                         __THREW__ = 0;
                         invoke_viii(3262,($533|0),1,1);
                         $541 = __THREW__; __THREW__ = 0;
                         $542 = $541&1;
                         if ($542) {
                          label = 165;
                          break L186;
                         }
                        }
                       } while(0);
                       $$pr = HEAP32[$525>>2]|0;
                       $548 = $$pr;
                      } else {
                       $548 = $526;
                      }
                     } while(0);
                     $545 = ((($$sroa$0193$4)) + 416|0);
                     $546 = HEAP32[$545>>2]|0;
                     $547 = ($546|0)==($548|0);
                     do {
                      if (!($547)) {
                       HEAP32[$545>>2] = $548;
                       $549 = ($548|0)==(0|0);
                       if (!($549)) {
                        $550 = ((($548)) + 8|0);
                        $551 = HEAP32[$550>>2]|0;HEAP32[$550>>2] = (($551+1)|0);
                       }
                       $552 = ($546|0)==(0|0);
                       if ($552) {
                        break;
                       }
                       $553 = ((($546)) + 8|0);
                       $554 = HEAP32[$553>>2]|0;HEAP32[$553>>2] = (($554-1)|0);
                       $555 = ($554|0)==(1);
                       if (!($555)) {
                        break;
                       }
                       __THREW__ = 0;
                       invoke_viii(3262,($546|0),1,1);
                       $556 = __THREW__; __THREW__ = 0;
                       $557 = $556&1;
                       if ($557) {
                        label = 165;
                        break L186;
                       }
                      }
                     } while(0);
                     $558 = HEAP32[$225>>2]|0;
                     HEAP32[$225>>2] = $$sroa$0193$4;
                     $559 = ((($1)) + 100|0);
                     $560 = HEAP32[$559>>2]|0;
                     $561 = ($560|0)==(0|0);
                     L212: do {
                      if ($561) {
                       $571 = ((($0)) + 16|0);
                       $572 = HEAP32[$571>>2]|0;
                       switch ($572|0) {
                       case 0:  {
                        label = 162;
                        break L212;
                        break;
                       }
                       case 1:  {
                        $573 = HEAP32[$1>>2]|0;
                        $574 = ((($573)) + 192|0);
                        $575 = HEAP32[$574>>2]|0;
                        __THREW__ = 0;
                        invoke_vii($575|0,($1|0),($0|0));
                        $576 = __THREW__; __THREW__ = 0;
                        $577 = $576&1;
                        if ($577) {
                         break L212;
                        } else {
                         label = 162;
                         break L212;
                        }
                        break;
                       }
                       default: {
                        $578 = HEAP32[$1>>2]|0;
                        $579 = ((($578)) + 196|0);
                        $580 = HEAP32[$579>>2]|0;
                        __THREW__ = 0;
                        invoke_vii($580|0,($1|0),($0|0));
                        $581 = __THREW__; __THREW__ = 0;
                        $582 = $581&1;
                        if ($582) {
                         break L212;
                        } else {
                         label = 162;
                         break L212;
                        }
                       }
                       }
                      } else {
                       $562 = HEAP32[$560>>2]|0;
                       $563 = ((($562)) + 92|0);
                       $564 = HEAP32[$563>>2]|0;
                       $565 = HEAP32[$0>>2]|0;
                       $566 = ((($565)) + -12|0);
                       $567 = HEAP32[$566>>2]|0;
                       $568 = (($0) + ($567)|0);
                       __THREW__ = 0;
                       (invoke_iiii($564|0,($560|0),($1|0),($568|0))|0);
                       $569 = __THREW__; __THREW__ = 0;
                       $570 = $569&1;
                       if (!($570)) {
                        label = 162;
                       }
                      }
                     } while(0);
                     do {
                      if ((label|0) == 162) {
                       HEAP32[$225>>2] = $558;
                       $583 = HEAP32[$196>>2]|0;
                       $cond = ($583|0)==(0);
                       $$cast251 = $558;
                       $584 = ((($$cast251)) + 40|0);
                       $585 = HEAP32[$584>>2]|0;
                       $586 = ((($1)) + 564|0);
                       $587 = HEAP32[$586>>2]|0;
                       if ($cond) {
                        __THREW__ = 0;
                        invoke_viii(3629,($585|0),($$sroa$0193$4|0),($587|0));
                        $596 = __THREW__; __THREW__ = 0;
                        $597 = $596&1;
                        if ($597) {
                         break;
                        }
                       } else {
                        __THREW__ = 0;
                        invoke_viii(3630,($585|0),($$sroa$0193$4|0),($587|0));
                        $598 = __THREW__; __THREW__ = 0;
                        $599 = $598&1;
                        if ($599) {
                         break;
                        }
                       }
                       $600 = ((($$sroa$0193$4)) + 8|0);
                       $601 = HEAP32[$600>>2]|0;HEAP32[$600>>2] = (($601-1)|0);
                       $602 = ($601|0)==(1);
                       do {
                        if ($602) {
                         __THREW__ = 0;
                         invoke_viii(3262,($$sroa$0193$4|0),1,1);
                         $603 = __THREW__; __THREW__ = 0;
                         $604 = $603&1;
                         if (!($604)) {
                          break;
                         }
                         $611 = ___cxa_find_matching_catch_2()|0;
                         $612 = tempRet0;
                         $$11 = $611;$$11112 = $612;$$sroa$0218$3 = $$sroa$0218$2;
                         break L83;
                        }
                       } while(0);
                       $605 = ($$sroa$0218$2|0)==(0|0);
                       if ($605) {
                        break L62;
                       }
                       $606 = ((($$sroa$0218$2)) + 8|0);
                       $607 = HEAP32[$606>>2]|0;HEAP32[$606>>2] = (($607-1)|0);
                       $608 = ($607|0)==(1);
                       if (!($608)) {
                        break L62;
                       }
                       __THREW__ = 0;
                       invoke_viii(3262,($$sroa$0218$2|0),1,1);
                       $609 = __THREW__; __THREW__ = 0;
                       $610 = $609&1;
                       if (!($610)) {
                        break L62;
                       }
                       $619 = ___cxa_find_matching_catch_2()|0;
                       $620 = tempRet0;
                       $$14 = $619;$$14115 = $620;
                       break L59;
                      }
                     } while(0);
                     $594 = ___cxa_find_matching_catch_2()|0;
                     $595 = tempRet0;
                     $$sink125$index = $594;$$sink125$index15 = $595;
                    }
                   } while(0);
                   if ((label|0) == 165) {
                    $592 = ___cxa_find_matching_catch_2()|0;
                    $593 = tempRet0;
                    $$sink125$index = $592;$$sink125$index15 = $593;
                   }
                   $$9 = $$sink125$index;$$9110 = $$sink125$index15;$$sroa$0193$5 = $$sroa$0193$4;
                   label = 176;
                   break L143;
                  }
                 } while(0);
                 $590 = ___cxa_find_matching_catch_2()|0;
                 $591 = tempRet0;
                 $$9 = $590;$$9110 = $591;$$sroa$0193$5 = $$sroa$0193$4;
                 label = 176;
                }
               } while(0);
               if ((label|0) == 176) {
                $613 = ($$sroa$0193$5|0)==(0|0);
                if ($613) {
                 $$11 = $$9;$$11112 = $$9110;$$sroa$0218$3 = $$sroa$0218$2;
                 break;
                } else {
                 $$9110229 = $$9110;$$9231 = $$9;$$sroa$0193$5228 = $$sroa$0193$5;
                }
               }
               $614 = ((($$sroa$0193$5228)) + 8|0);
               $615 = HEAP32[$614>>2]|0;HEAP32[$614>>2] = (($615-1)|0);
               $616 = ($615|0)==(1);
               if ($616) {
                __THREW__ = 0;
                invoke_viii(3262,($$sroa$0193$5228|0),1,1);
                $617 = __THREW__; __THREW__ = 0;
                $618 = $617&1;
                if (!($618)) {
                 $$11 = $$9231;$$11112 = $$9110229;$$sroa$0218$3 = $$sroa$0218$2;
                 break;
                }
                $722 = ___cxa_find_matching_catch_3(0|0)|0;
                $723 = tempRet0;
                ___clang_call_terminate($722);
                // unreachable;
               } else {
                $$11 = $$9231;$$11112 = $$9110229;$$sroa$0218$3 = $$sroa$0218$2;
               }
              }
             }
            }
           } while(0);
           if ((label|0) == 64) {
            $252 = ___cxa_find_matching_catch_2()|0;
            $253 = tempRet0;
            $$11 = $252;$$11112 = $253;$$sroa$0218$3 = $$sroa$0218$1;
           }
           $621 = ($$sroa$0218$3|0)==(0|0);
           if ($621) {
            $$14 = $$11;$$14115 = $$11112;
            break L59;
           }
           $622 = ((($$sroa$0218$3)) + 8|0);
           $623 = HEAP32[$622>>2]|0;HEAP32[$622>>2] = (($623-1)|0);
           $624 = ($623|0)==(1);
           if (!($624)) {
            $$14 = $$11;$$14115 = $$11112;
            break L59;
           }
           __THREW__ = 0;
           invoke_viii(3262,($$sroa$0218$3|0),1,1);
           $625 = __THREW__; __THREW__ = 0;
           $626 = $625&1;
           if (!($626)) {
            $$14 = $$11;$$14115 = $$11112;
            break L59;
           }
           $722 = ___cxa_find_matching_catch_3(0|0)|0;
           $723 = tempRet0;
           ___clang_call_terminate($722);
           // unreachable;
          }
         } while(0);
         __THREW__ = 0;
         invoke_vi(3582,($58|0));
         $627 = __THREW__; __THREW__ = 0;
         $628 = $627&1;
         if ($628) {
          label = 54;
         } else {
          $629 = HEAP32[$0>>2]|0;
          $630 = ((($629)) + 204|0);
          $631 = HEAP32[$630>>2]|0;
          __THREW__ = 0;
          invoke_vi($631|0,($0|0));
          $632 = __THREW__; __THREW__ = 0;
          $633 = $632&1;
          if ($633) {
           label = 54;
          } else {
           HEAPF64[$165>>3] = $166;
           HEAPF64[$167>>3] = $168;
           $634 = HEAP32[$7>>2]|0;
           $635 = HEAP32[$171>>2]|0;
           HEAP32[$7>>2] = $635;
           HEAP32[$171>>2] = $634;
           $636 = HEAP32[$170>>2]|0;
           $637 = HEAP32[$173>>2]|0;
           HEAP32[$170>>2] = $637;
           HEAP32[$173>>2] = $636;
           $638 = HEAP32[$169>>2]|0;
           $639 = HEAP32[$175>>2]|0;
           HEAP32[$169>>2] = $639;
           HEAP32[$175>>2] = $638;
           $640 = ($639|0)==(0);
           $641 = $637;
           $642 = ((($641)) + 8|0);
           $$sink$i$i132 = $640 ? $7 : $642;
           HEAP32[$$sink$i$i132>>2] = $170;
           $643 = ($638|0)==(0);
           $644 = HEAP32[$173>>2]|0;
           $645 = ((($644)) + 8|0);
           $$sink1$i$i133 = $643 ? $171 : $645;
           HEAP32[$$sink1$i$i133>>2] = $173;
           $646 = HEAP32[$8>>2]|0;
           $647 = HEAP32[$182>>2]|0;
           HEAP32[$8>>2] = $647;
           HEAP32[$182>>2] = $646;
           $648 = HEAP32[$181>>2]|0;
           $649 = HEAP32[$184>>2]|0;
           HEAP32[$181>>2] = $649;
           HEAP32[$184>>2] = $648;
           $650 = HEAP32[$180>>2]|0;
           $651 = HEAP32[$186>>2]|0;
           HEAP32[$180>>2] = $651;
           HEAP32[$186>>2] = $650;
           $652 = ($651|0)==(0);
           $653 = $649;
           $654 = ((($653)) + 8|0);
           $$sink$i$i = $652 ? $8 : $654;
           HEAP32[$$sink$i$i>>2] = $181;
           $655 = ($650|0)==(0);
           $656 = HEAP32[$184>>2]|0;
           $657 = ((($656)) + 8|0);
           $$sink1$i$i = $655 ? $182 : $657;
           HEAP32[$$sink1$i$i>>2] = $184;
           $658 = HEAP32[$160>>2]|0;
           $659 = ($658|0)==(0|0);
           if (!($659)) {
            __THREW__ = 0;
            invoke_vi(3584,($58|0));
            $660 = __THREW__; __THREW__ = 0;
            $661 = $660&1;
            if ($661) {
             label = 54;
             break;
            }
           }
           if ($73) {
            HEAP32[$69>>2] = $70;
           }
           __THREW__ = 0;
           invoke_vii(3624,($58|0),($2|0));
           $662 = __THREW__; __THREW__ = 0;
           $663 = $662&1;
           if ($663) {
            label = 54;
           } else {
            if ($12) {
             $664 = ((($0)) + 376|0);
             $665 = HEAP32[$664>>2]|0;
             $666 = ((($665)) + 16|0);
             $667 = HEAP32[$666>>2]|0;
             $668 = ((($667)) + 120|0);
             $669 = HEAP32[$668>>2]|0;
             $670 = $669 & 2;
             $671 = ($670|0)==(0);
             if (!($671)) {
              $672 = ((($0)) + 440|0);
              $673 = HEAP32[$672>>2]|0;
              $674 = (($673) + -1)|0;
              HEAP32[$672>>2] = $674;
             }
             $675 = ($669|0)==(0);
             do {
              if (!($675)) {
               $676 = ((($667)) + 128|0);
               $677 = ((($676)) + 11|0);
               $678 = HEAP8[$677>>0]|0;
               $679 = ($678<<24>>24)<(0);
               if ($679) {
                $680 = ((($667)) + 132|0);
                $681 = HEAP32[$680>>2]|0;
                $683 = $681;
               } else {
                $682 = $678&255;
                $683 = $682;
               }
               $684 = ($683|0)==(0);
               if ($684) {
                break;
               }
               $685 = ((($0)) + 440|0);
               $686 = HEAP32[$685>>2]|0;
               $687 = ($686|0)!=(0);
               $688 = $669 & 4;
               $689 = ($688|0)==(0);
               $or$cond$i130 = $689 & $687;
               if ($or$cond$i130) {
                break;
               }
               $690 = ((($0)) + 388|0);
               $691 = HEAP32[$690>>2]|0;
               $692 = ((($0)) + 392|0);
               $693 = HEAP32[$692>>2]|0;
               $694 = ($691|0)==($693|0);
               if ($694) {
                $695 = ((($0)) + 384|0);
                $696 = HEAP32[$695>>2]|0;
                $697 = ((($696)) + 40|0);
                $698 = HEAP32[$697>>2]|0;
                HEAP32[$695>>2] = $698;
                break;
               } else {
                $699 = ((($693)) + -4|0);
                $700 = HEAP32[$699>>2]|0;
                $701 = ((($0)) + 384|0);
                HEAP32[$701>>2] = $700;
                HEAP32[$692>>2] = $699;
                break;
               }
              }
             } while(0);
             $702 = ((($665)) + 12|0);
             $703 = HEAP32[$702>>2]|0;
             HEAP32[$664>>2] = $703;
            }
            $704 = HEAP32[$181>>2]|0;
            __ZNSt3__26__treeINS_12__value_typeIdN7osgUtil11CullVisitor21MatrixPlanesDrawablesEEENS_19__map_value_compareIdS5_NS_4lessIdEELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($8,$704);
            $705 = HEAP32[$170>>2]|0;
            __ZNSt3__26__treeINS_12__value_typeIdN7osgUtil11CullVisitor21MatrixPlanesDrawablesEEENS_19__map_value_compareIdS5_NS_4lessIdEELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($7,$705);
            HEAP32[$2>>2] = (58232);
            $706 = ((($2)) + 28|0);
            $707 = HEAP32[$706>>2]|0;
            $708 = ($707|0)==(0|0);
            if ($708) {
             STACKTOP = sp;return;
            }
            $709 = ((($707)) + 8|0);
            $710 = HEAP32[$709>>2]|0;HEAP32[$709>>2] = (($710-1)|0);
            $711 = ($710|0)==(1);
            if (!($711)) {
             STACKTOP = sp;return;
            }
            __ZNK3osg10Referenced24signalObserversAndDeleteEbb($707,1,1);
            STACKTOP = sp;return;
           }
          }
         }
        }
       }
      } while(0);
      if ((label|0) == 54) {
       $223 = ___cxa_find_matching_catch_2()|0;
       $224 = tempRet0;
       $$14 = $223;$$14115 = $224;
      }
      $712 = HEAP32[$181>>2]|0;
      __ZNSt3__26__treeINS_12__value_typeIdN7osgUtil11CullVisitor21MatrixPlanesDrawablesEEENS_19__map_value_compareIdS5_NS_4lessIdEELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($8,$712);
      $713 = HEAP32[$170>>2]|0;
      __ZNSt3__26__treeINS_12__value_typeIdN7osgUtil11CullVisitor21MatrixPlanesDrawablesEEENS_19__map_value_compareIdS5_NS_4lessIdEELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($7,$713);
      $$21 = $$14;$$21122 = $$14115;
      break L21;
     }
    } while(0);
    $116 = ___cxa_find_matching_catch_2()|0;
    $117 = tempRet0;
    $$21 = $116;$$21122 = $117;
   }
  }
 } while(0);
 if ((label|0) == 20) {
  $76 = ___cxa_find_matching_catch_2()|0;
  $77 = tempRet0;
  $$21 = $76;$$21122 = $77;
 }
 HEAP32[$2>>2] = (58232);
 $714 = ((($2)) + 28|0);
 $715 = HEAP32[$714>>2]|0;
 $716 = ($715|0)==(0|0);
 if ($716) {
  ___resumeException($$21|0);
  // unreachable;
 }
 $717 = ((($715)) + 8|0);
 $718 = HEAP32[$717>>2]|0;HEAP32[$717>>2] = (($718-1)|0);
 $719 = ($718|0)==(1);
 if (!($719)) {
  ___resumeException($$21|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(3262,($715|0),1,1);
 $720 = __THREW__; __THREW__ = 0;
 $721 = $720&1;
 if ($721) {
  $722 = ___cxa_find_matching_catch_3(0|0)|0;
  $723 = tempRet0;
  ___clang_call_terminate($722);
  // unreachable;
 } else {
  ___resumeException($$21|0);
  // unreachable;
 }
}
function __ZN7osgUtil11CullVisitor5applyERN3osg6SwitchE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $3 = ((($2)) + 120|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 8191]($0,$1);
 return;
}
function __ZN7osgUtil11CullVisitor5applyERN3osg3LODE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$pre = 0, $$pre$i = 0, $$pre$phiZ2D = 0, $$pre12$pre$phiZZ2D = 0, $$sink$i = 0, $$sroa$03$015$i$i = 0, $$sroa$03$07$i$i$i = 0, $$sroa$09$016$i$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0.0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0;
 var $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0;
 var $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0;
 var $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $or$cond$i = 0, $or$cond$i9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 108|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 do {
  if ($4) {
   $5 = ((($1)) + 104|0);
   $6 = HEAP8[$5>>0]|0;
   $7 = ($6<<24>>24)==(0);
   if ($7) {
    label = 3;
   } else {
    $10 = (__ZNK3osg4Node8getBoundEv($1)|0);
    $11 = ((($10)) + 12|0);
    $12 = +HEAPF32[$11>>2];
    $13 = !($12 >= 0.0);
    $14 = ((($0)) + 336|0);
    $15 = HEAP32[$14>>2]|0;
    if ($13) {
     $$pre12$pre$phiZZ2D = $14;$17 = $15;
     label = 5;
    } else {
     $20 = (__ZNK3osg4Node8getBoundEv($1)|0);
     $21 = (__ZN3osg10CullingSet8isCulledERKNS_18BoundingSphereImplINS_5Vec3fEEE($15,$20)|0);
     if ($21) {
      return;
     } else {
      $$pre = HEAP32[$14>>2]|0;
      $$pre$phiZ2D = $14;$22 = $$pre;
      break;
     }
    }
   }
  } else {
   label = 3;
  }
 } while(0);
 if ((label|0) == 3) {
  $8 = ((($0)) + 336|0);
  $9 = HEAP32[$8>>2]|0;
  $$pre12$pre$phiZZ2D = $8;$17 = $9;
  label = 5;
 }
 if ((label|0) == 5) {
  $16 = ((($17)) + 16|0);
  $18 = HEAP32[$16>>2]|0;
  $19 = ((($17)) + 36|0);
  HEAP32[$19>>2] = $18;
  $$pre$phiZ2D = $$pre12$pre$phiZZ2D;$22 = $17;
 }
 __ZN3osg10CullingSet15pushCurrentMaskEv($22);
 $23 = ((($1)) + 120|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)==(0|0);
 L13: do {
  if ($25) {
   $128 = ((($1)) + 100|0);
   $129 = HEAP32[$128>>2]|0;
   $130 = ($129|0)==(0|0);
   if (!($130)) {
    $131 = HEAP32[$129>>2]|0;
    $132 = ((($131)) + 92|0);
    $133 = HEAP32[$132>>2]|0;
    $134 = HEAP32[$0>>2]|0;
    $135 = ((($134)) + -12|0);
    $136 = HEAP32[$135>>2]|0;
    $137 = (($0) + ($136)|0);
    (FUNCTION_TABLE_iiii[$133 & 8191]($129,$1,$137)|0);
    break;
   }
   $138 = ((($0)) + 16|0);
   $139 = HEAP32[$138>>2]|0;
   switch ($139|0) {
   case 0:  {
    break L13;
    break;
   }
   case 1:  {
    $140 = HEAP32[$1>>2]|0;
    $141 = ((($140)) + 192|0);
    $142 = HEAP32[$141>>2]|0;
    FUNCTION_TABLE_vii[$142 & 8191]($1,$0);
    break L13;
    break;
   }
   default: {
    $143 = HEAP32[$1>>2]|0;
    $144 = ((($143)) + 196|0);
    $145 = HEAP32[$144>>2]|0;
    FUNCTION_TABLE_vii[$145 & 8191]($1,$0);
    break L13;
   }
   }
  } else {
   $26 = ((($0)) + 376|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = (__ZN7osgUtil10StateGraph14find_or_insertEPKN3osg8StateSetE($27,$24)|0);
   HEAP32[$26>>2] = $28;
   $29 = ((($24)) + 120|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = ($30|0)==(0);
   if (!($31)) {
    $32 = ((($24)) + 128|0);
    $33 = ((($32)) + 11|0);
    $34 = HEAP8[$33>>0]|0;
    $35 = ($34<<24>>24)<(0);
    if ($35) {
     $36 = ((($24)) + 132|0);
     $37 = HEAP32[$36>>2]|0;
     $39 = $37;
    } else {
     $38 = $34&255;
     $39 = $38;
    }
    $40 = ($39|0)==(0);
    if ($40) {
     $66 = $30;
    } else {
     $41 = ((($0)) + 440|0);
     $42 = HEAP32[$41>>2]|0;
     $43 = ($42|0)!=(0);
     $44 = $30 & 4;
     $45 = ($44|0)==(0);
     $or$cond$i = $45 & $43;
     if ($or$cond$i) {
      $66 = $30;
     } else {
      $46 = ((($0)) + 384|0);
      $47 = ((($0)) + 392|0);
      $48 = HEAP32[$47>>2]|0;
      $49 = ((($0)) + 396|0);
      $50 = HEAP32[$49>>2]|0;
      $51 = ($48|0)==($50|0);
      if ($51) {
       $55 = ((($0)) + 388|0);
       __ZNSt3__26vectorIPN7osgUtil9RenderBinENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_($55,$46);
      } else {
       $52 = HEAP32[$46>>2]|0;
       HEAP32[$48>>2] = $52;
       $53 = HEAP32[$47>>2]|0;
       $54 = ((($53)) + 4|0);
       HEAP32[$47>>2] = $54;
      }
      $56 = ((($24)) + 140|0);
      $57 = HEAP8[$56>>0]|0;
      $58 = ($57<<24>>24)==(0);
      $59 = HEAP32[$46>>2]|0;
      if ($58) {
       $60 = ((($59)) + 40|0);
       $61 = HEAP32[$60>>2]|0;
       $$sink$i = $61;
      } else {
       $$sink$i = $59;
      }
      $62 = ((($24)) + 124|0);
      $63 = HEAP32[$62>>2]|0;
      $64 = (__ZN7osgUtil9RenderBin14find_or_insertEiRKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE($$sink$i,$63,$32)|0);
      HEAP32[$46>>2] = $64;
      $$pre$i = HEAP32[$29>>2]|0;
      $66 = $$pre$i;
     }
    }
    $65 = $66 & 2;
    $67 = ($65|0)==(0);
    if (!($67)) {
     $68 = ((($0)) + 440|0);
     $69 = HEAP32[$68>>2]|0;
     $70 = (($69) + 1)|0;
     HEAP32[$68>>2] = $70;
    }
   }
   $71 = ((($1)) + 100|0);
   $72 = HEAP32[$71>>2]|0;
   $73 = ($72|0)==(0|0);
   L41: do {
    if ($73) {
     $81 = ((($0)) + 16|0);
     $82 = HEAP32[$81>>2]|0;
     switch ($82|0) {
     case 0:  {
      break L41;
      break;
     }
     case 1:  {
      $83 = HEAP32[$1>>2]|0;
      $84 = ((($83)) + 192|0);
      $85 = HEAP32[$84>>2]|0;
      FUNCTION_TABLE_vii[$85 & 8191]($1,$0);
      break L41;
      break;
     }
     default: {
      $86 = HEAP32[$1>>2]|0;
      $87 = ((($86)) + 196|0);
      $88 = HEAP32[$87>>2]|0;
      FUNCTION_TABLE_vii[$88 & 8191]($1,$0);
      break L41;
     }
     }
    } else {
     $74 = HEAP32[$72>>2]|0;
     $75 = ((($74)) + 92|0);
     $76 = HEAP32[$75>>2]|0;
     $77 = HEAP32[$0>>2]|0;
     $78 = ((($77)) + -12|0);
     $79 = HEAP32[$78>>2]|0;
     $80 = (($0) + ($79)|0);
     (FUNCTION_TABLE_iiii[$76 & 8191]($72,$1,$80)|0);
    }
   } while(0);
   $89 = HEAP32[$26>>2]|0;
   $90 = ((($89)) + 16|0);
   $91 = HEAP32[$90>>2]|0;
   $92 = ((($91)) + 120|0);
   $93 = HEAP32[$92>>2]|0;
   $94 = $93 & 2;
   $95 = ($94|0)==(0);
   if (!($95)) {
    $96 = ((($0)) + 440|0);
    $97 = HEAP32[$96>>2]|0;
    $98 = (($97) + -1)|0;
    HEAP32[$96>>2] = $98;
   }
   $99 = ($93|0)==(0);
   do {
    if (!($99)) {
     $100 = ((($91)) + 128|0);
     $101 = ((($100)) + 11|0);
     $102 = HEAP8[$101>>0]|0;
     $103 = ($102<<24>>24)<(0);
     if ($103) {
      $104 = ((($91)) + 132|0);
      $105 = HEAP32[$104>>2]|0;
      $107 = $105;
     } else {
      $106 = $102&255;
      $107 = $106;
     }
     $108 = ($107|0)==(0);
     if (!($108)) {
      $109 = ((($0)) + 440|0);
      $110 = HEAP32[$109>>2]|0;
      $111 = ($110|0)!=(0);
      $112 = $93 & 4;
      $113 = ($112|0)==(0);
      $or$cond$i9 = $113 & $111;
      if (!($or$cond$i9)) {
       $114 = ((($0)) + 388|0);
       $115 = HEAP32[$114>>2]|0;
       $116 = ((($0)) + 392|0);
       $117 = HEAP32[$116>>2]|0;
       $118 = ($115|0)==($117|0);
       if ($118) {
        $119 = ((($0)) + 384|0);
        $120 = HEAP32[$119>>2]|0;
        $121 = ((($120)) + 40|0);
        $122 = HEAP32[$121>>2]|0;
        HEAP32[$119>>2] = $122;
        break;
       } else {
        $123 = ((($117)) + -4|0);
        $124 = HEAP32[$123>>2]|0;
        $125 = ((($0)) + 384|0);
        HEAP32[$125>>2] = $124;
        HEAP32[$116>>2] = $123;
        break;
       }
      }
     }
    }
   } while(0);
   $126 = ((($89)) + 12|0);
   $127 = HEAP32[$126>>2]|0;
   HEAP32[$26>>2] = $127;
  }
 } while(0);
 $146 = HEAP32[$$pre$phiZ2D>>2]|0;
 $147 = ((($146)) + 32|0);
 $148 = HEAP32[$147>>2]|0;
 $149 = ($148|0)==(0);
 if (!($149)) {
  $150 = ((($146)) + 20|0);
  $151 = HEAP32[$150>>2]|0;
  $152 = ((($146)) + 24|0);
  $153 = HEAP32[$152>>2]|0;
  $154 = ($151|0)==($153|0);
  if (!($154)) {
   $155 = ((($153)) + -4|0);
   $156 = HEAP32[$155>>2]|0;
   $157 = ((($146)) + 16|0);
   HEAP32[$157>>2] = $156;
   HEAP32[$152>>2] = $155;
  }
  $158 = (($148) + -1)|0;
  HEAP32[$147>>2] = $158;
 }
 $159 = ((($146)) + 64|0);
 $160 = HEAP32[$159>>2]|0;
 $161 = ((($146)) + 68|0);
 $162 = HEAP32[$161>>2]|0;
 $163 = ($160|0)==($162|0);
 if (!($163)) {
  $$sroa$09$016$i$i = $160;
  while(1) {
   $164 = ((($$sroa$09$016$i$i)) + 20|0);
   $165 = HEAP32[$164>>2]|0;
   $166 = ($165|0)==(0);
   if (!($166)) {
    $167 = ((($$sroa$09$016$i$i)) + 8|0);
    $168 = HEAP32[$167>>2]|0;
    $169 = ((($$sroa$09$016$i$i)) + 12|0);
    $170 = HEAP32[$169>>2]|0;
    $171 = ($168|0)==($170|0);
    if (!($171)) {
     $172 = ((($170)) + -4|0);
     $173 = HEAP32[$172>>2]|0;
     $174 = ((($$sroa$09$016$i$i)) + 4|0);
     HEAP32[$174>>2] = $173;
     HEAP32[$169>>2] = $172;
    }
    $175 = (($165) + -1)|0;
    HEAP32[$164>>2] = $175;
   }
   $176 = ((($$sroa$09$016$i$i)) + 52|0);
   $177 = ($176|0)==($162|0);
   if ($177) {
    break;
   } else {
    $$sroa$09$016$i$i = $176;
   }
  }
 }
 $178 = ((($146)) + 76|0);
 $179 = HEAP32[$178>>2]|0;
 $180 = ((($146)) + 80|0);
 $181 = HEAP32[$180>>2]|0;
 $182 = ($179|0)==($181|0);
 if ($182) {
  return;
 } else {
  $$sroa$03$015$i$i = $179;
 }
 while(1) {
  $183 = ((($$sroa$03$015$i$i)) + 36|0);
  $184 = HEAP32[$183>>2]|0;
  $185 = ($184|0)==(0);
  if (!($185)) {
   $186 = ((($$sroa$03$015$i$i)) + 24|0);
   $187 = HEAP32[$186>>2]|0;
   $188 = ((($$sroa$03$015$i$i)) + 28|0);
   $189 = HEAP32[$188>>2]|0;
   $190 = ($187|0)==($189|0);
   if (!($190)) {
    $191 = ((($189)) + -4|0);
    $192 = HEAP32[$191>>2]|0;
    $193 = ((($$sroa$03$015$i$i)) + 20|0);
    HEAP32[$193>>2] = $192;
    HEAP32[$188>>2] = $191;
   }
   $194 = (($184) + -1)|0;
   HEAP32[$183>>2] = $194;
  }
  $195 = ((($$sroa$03$015$i$i)) + 68|0);
  $196 = HEAP32[$195>>2]|0;
  $197 = ((($$sroa$03$015$i$i)) + 72|0);
  $198 = HEAP32[$197>>2]|0;
  $199 = ($196|0)==($198|0);
  if (!($199)) {
   $$sroa$03$07$i$i$i = $196;
   while(1) {
    $200 = ((($$sroa$03$07$i$i$i)) + 16|0);
    $201 = HEAP32[$200>>2]|0;
    $202 = ($201|0)==(0);
    if (!($202)) {
     $203 = ((($$sroa$03$07$i$i$i)) + 4|0);
     $204 = HEAP32[$203>>2]|0;
     $205 = ((($$sroa$03$07$i$i$i)) + 8|0);
     $206 = HEAP32[$205>>2]|0;
     $207 = ($204|0)==($206|0);
     if (!($207)) {
      $208 = ((($206)) + -4|0);
      $209 = HEAP32[$208>>2]|0;
      HEAP32[$$sroa$03$07$i$i$i>>2] = $209;
      HEAP32[$205>>2] = $208;
     }
     $210 = (($201) + -1)|0;
     HEAP32[$200>>2] = $210;
    }
    $211 = ((($$sroa$03$07$i$i$i)) + 48|0);
    $212 = ($211|0)==($198|0);
    if ($212) {
     break;
    } else {
     $$sroa$03$07$i$i$i = $211;
    }
   }
  }
  $213 = ((($$sroa$03$015$i$i)) + 80|0);
  $214 = ($213|0)==($181|0);
  if ($214) {
   break;
  } else {
   $$sroa$03$015$i$i = $213;
  }
 }
 return;
}
function __ZN7osgUtil11CullVisitor5applyERN3osg9ClearNodeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$pre$i = 0, $$sink = 0, $$sink$i = 0, $$sink14 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond$i = 0;
 var $or$cond$i12 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 136|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 $5 = ((($0)) + 384|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($6)) + 40|0);
 $8 = HEAP32[$7>>2]|0;
 if ($4) {
  $$sink = 0;$$sink14 = $8;
 } else {
  $9 = ((($1)) + 140|0);
  $10 = ((($8)) + 172|0);
  ;HEAP32[$10>>2]=HEAP32[$9>>2]|0;HEAP32[$10+4>>2]=HEAP32[$9+4>>2]|0;HEAP32[$10+8>>2]=HEAP32[$9+8>>2]|0;HEAP32[$10+12>>2]=HEAP32[$9+12>>2]|0;
  $11 = HEAP32[$5>>2]|0;
  $12 = ((($11)) + 40|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ((($1)) + 156|0);
  $15 = HEAP32[$14>>2]|0;
  $$sink = $15;$$sink14 = $13;
 }
 $16 = ((($$sink14)) + 164|0);
 HEAP32[$16>>2] = $$sink;
 $17 = ((($1)) + 120|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ($18|0)==(0|0);
 if ($19) {
  $119 = ((($1)) + 100|0);
  $120 = HEAP32[$119>>2]|0;
  $121 = ($120|0)==(0|0);
  if (!($121)) {
   $122 = HEAP32[$120>>2]|0;
   $123 = ((($122)) + 92|0);
   $124 = HEAP32[$123>>2]|0;
   $125 = HEAP32[$0>>2]|0;
   $126 = ((($125)) + -12|0);
   $127 = HEAP32[$126>>2]|0;
   $128 = (($0) + ($127)|0);
   (FUNCTION_TABLE_iiii[$124 & 8191]($120,$1,$128)|0);
   return;
  }
  $129 = ((($0)) + 16|0);
  $130 = HEAP32[$129>>2]|0;
  switch ($130|0) {
  case 1:  {
   $131 = HEAP32[$1>>2]|0;
   $132 = ((($131)) + 192|0);
   $133 = HEAP32[$132>>2]|0;
   FUNCTION_TABLE_vii[$133 & 8191]($1,$0);
   return;
   break;
  }
  case 0:  {
   return;
   break;
  }
  default: {
   $134 = HEAP32[$1>>2]|0;
   $135 = ((($134)) + 196|0);
   $136 = HEAP32[$135>>2]|0;
   FUNCTION_TABLE_vii[$136 & 8191]($1,$0);
   return;
  }
  }
 }
 $20 = ((($0)) + 376|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (__ZN7osgUtil10StateGraph14find_or_insertEPKN3osg8StateSetE($21,$18)|0);
 HEAP32[$20>>2] = $22;
 $23 = ((($18)) + 120|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)==(0);
 if (!($25)) {
  $26 = ((($18)) + 128|0);
  $27 = ((($26)) + 11|0);
  $28 = HEAP8[$27>>0]|0;
  $29 = ($28<<24>>24)<(0);
  if ($29) {
   $30 = ((($18)) + 132|0);
   $31 = HEAP32[$30>>2]|0;
   $33 = $31;
  } else {
   $32 = $28&255;
   $33 = $32;
  }
  $34 = ($33|0)==(0);
  if ($34) {
   $59 = $24;
  } else {
   $35 = ((($0)) + 440|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = ($36|0)!=(0);
   $38 = $24 & 4;
   $39 = ($38|0)==(0);
   $or$cond$i12 = $39 & $37;
   if ($or$cond$i12) {
    $59 = $24;
   } else {
    $40 = ((($0)) + 392|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = ((($0)) + 396|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = ($41|0)==($43|0);
    if ($44) {
     $48 = ((($0)) + 388|0);
     __ZNSt3__26vectorIPN7osgUtil9RenderBinENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_($48,$5);
    } else {
     $45 = HEAP32[$5>>2]|0;
     HEAP32[$41>>2] = $45;
     $46 = HEAP32[$40>>2]|0;
     $47 = ((($46)) + 4|0);
     HEAP32[$40>>2] = $47;
    }
    $49 = ((($18)) + 140|0);
    $50 = HEAP8[$49>>0]|0;
    $51 = ($50<<24>>24)==(0);
    $52 = HEAP32[$5>>2]|0;
    if ($51) {
     $53 = ((($52)) + 40|0);
     $54 = HEAP32[$53>>2]|0;
     $$sink$i = $54;
    } else {
     $$sink$i = $52;
    }
    $55 = ((($18)) + 124|0);
    $56 = HEAP32[$55>>2]|0;
    $57 = (__ZN7osgUtil9RenderBin14find_or_insertEiRKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE($$sink$i,$56,$26)|0);
    HEAP32[$5>>2] = $57;
    $$pre$i = HEAP32[$23>>2]|0;
    $59 = $$pre$i;
   }
  }
  $58 = $59 & 2;
  $60 = ($58|0)==(0);
  if (!($60)) {
   $61 = ((($0)) + 440|0);
   $62 = HEAP32[$61>>2]|0;
   $63 = (($62) + 1)|0;
   HEAP32[$61>>2] = $63;
  }
 }
 $64 = ((($1)) + 100|0);
 $65 = HEAP32[$64>>2]|0;
 $66 = ($65|0)==(0|0);
 L36: do {
  if ($66) {
   $74 = ((($0)) + 16|0);
   $75 = HEAP32[$74>>2]|0;
   switch ($75|0) {
   case 0:  {
    break L36;
    break;
   }
   case 1:  {
    $76 = HEAP32[$1>>2]|0;
    $77 = ((($76)) + 192|0);
    $78 = HEAP32[$77>>2]|0;
    FUNCTION_TABLE_vii[$78 & 8191]($1,$0);
    break L36;
    break;
   }
   default: {
    $79 = HEAP32[$1>>2]|0;
    $80 = ((($79)) + 196|0);
    $81 = HEAP32[$80>>2]|0;
    FUNCTION_TABLE_vii[$81 & 8191]($1,$0);
    break L36;
   }
   }
  } else {
   $67 = HEAP32[$65>>2]|0;
   $68 = ((($67)) + 92|0);
   $69 = HEAP32[$68>>2]|0;
   $70 = HEAP32[$0>>2]|0;
   $71 = ((($70)) + -12|0);
   $72 = HEAP32[$71>>2]|0;
   $73 = (($0) + ($72)|0);
   (FUNCTION_TABLE_iiii[$69 & 8191]($65,$1,$73)|0);
  }
 } while(0);
 $82 = HEAP32[$20>>2]|0;
 $83 = ((($82)) + 16|0);
 $84 = HEAP32[$83>>2]|0;
 $85 = ((($84)) + 120|0);
 $86 = HEAP32[$85>>2]|0;
 $87 = $86 & 2;
 $88 = ($87|0)==(0);
 if (!($88)) {
  $89 = ((($0)) + 440|0);
  $90 = HEAP32[$89>>2]|0;
  $91 = (($90) + -1)|0;
  HEAP32[$89>>2] = $91;
 }
 $92 = ($86|0)==(0);
 do {
  if (!($92)) {
   $93 = ((($84)) + 128|0);
   $94 = ((($93)) + 11|0);
   $95 = HEAP8[$94>>0]|0;
   $96 = ($95<<24>>24)<(0);
   if ($96) {
    $97 = ((($84)) + 132|0);
    $98 = HEAP32[$97>>2]|0;
    $100 = $98;
   } else {
    $99 = $95&255;
    $100 = $99;
   }
   $101 = ($100|0)==(0);
   if (!($101)) {
    $102 = ((($0)) + 440|0);
    $103 = HEAP32[$102>>2]|0;
    $104 = ($103|0)!=(0);
    $105 = $86 & 4;
    $106 = ($105|0)==(0);
    $or$cond$i = $106 & $104;
    if (!($or$cond$i)) {
     $107 = ((($0)) + 388|0);
     $108 = HEAP32[$107>>2]|0;
     $109 = ((($0)) + 392|0);
     $110 = HEAP32[$109>>2]|0;
     $111 = ($108|0)==($110|0);
     if ($111) {
      $112 = HEAP32[$5>>2]|0;
      $113 = ((($112)) + 40|0);
      $114 = HEAP32[$113>>2]|0;
      HEAP32[$5>>2] = $114;
      break;
     } else {
      $115 = ((($110)) + -4|0);
      $116 = HEAP32[$115>>2]|0;
      HEAP32[$5>>2] = $116;
      HEAP32[$109>>2] = $115;
      break;
     }
    }
   }
  }
 } while(0);
 $117 = ((($82)) + 12|0);
 $118 = HEAP32[$117>>2]|0;
 HEAP32[$20>>2] = $118;
 return;
}
function __ZN7osgUtil11CullVisitor5applyERN3osg12OccluderNodeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$pre$i = 0, $$sink$i = 0, $$sroa$03$015$i$i = 0, $$sroa$03$07$i$i$i = 0, $$sroa$09$016$i$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0.0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0;
 var $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0;
 var $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $or$cond$i = 0, $or$cond$i9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 28|0);
 $3 = ((($0)) + 336|0);
 $4 = HEAP32[$3>>2]|0;
 __ZN3osg10CullingSet34disableAndPushOccludersCurrentMaskERNSt3__26vectorIPNS_4NodeENS1_9allocatorIS4_EEEE($4,$2);
 $5 = ((($1)) + 108|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  $8 = ((($1)) + 104|0);
  $9 = HEAP8[$8>>0]|0;
  $10 = ($9<<24>>24)==(0);
  if ($10) {
   label = 3;
  } else {
   $12 = (__ZNK3osg4Node8getBoundEv($1)|0);
   $13 = ((($12)) + 12|0);
   $14 = +HEAPF32[$13>>2];
   $15 = !($14 >= 0.0);
   $16 = HEAP32[$3>>2]|0;
   if ($15) {
    $18 = $16;
    label = 5;
   } else {
    $21 = (__ZNK3osg4Node8getBoundEv($1)|0);
    $22 = (__ZN3osg10CullingSet8isCulledERKNS_18BoundingSphereImplINS_5Vec3fEEE($16,$21)|0);
    $23 = HEAP32[$3>>2]|0;
    if ($22) {
     __ZN3osg10CullingSet23popOccludersCurrentMaskERNSt3__26vectorIPNS_4NodeENS1_9allocatorIS4_EEEE($23,$2);
     return;
    } else {
     $24 = $23;
    }
   }
  }
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $11 = HEAP32[$3>>2]|0;
  $18 = $11;
  label = 5;
 }
 if ((label|0) == 5) {
  $17 = ((($18)) + 16|0);
  $19 = HEAP32[$17>>2]|0;
  $20 = ((($18)) + 36|0);
  HEAP32[$20>>2] = $19;
  $24 = $18;
 }
 __ZN3osg10CullingSet15pushCurrentMaskEv($24);
 $25 = ((($1)) + 120|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($26|0)==(0|0);
 L12: do {
  if ($27) {
   $130 = ((($1)) + 100|0);
   $131 = HEAP32[$130>>2]|0;
   $132 = ($131|0)==(0|0);
   if (!($132)) {
    $133 = HEAP32[$131>>2]|0;
    $134 = ((($133)) + 92|0);
    $135 = HEAP32[$134>>2]|0;
    $136 = HEAP32[$0>>2]|0;
    $137 = ((($136)) + -12|0);
    $138 = HEAP32[$137>>2]|0;
    $139 = (($0) + ($138)|0);
    (FUNCTION_TABLE_iiii[$135 & 8191]($131,$1,$139)|0);
    break;
   }
   $140 = ((($0)) + 16|0);
   $141 = HEAP32[$140>>2]|0;
   switch ($141|0) {
   case 0:  {
    break L12;
    break;
   }
   case 1:  {
    $142 = HEAP32[$1>>2]|0;
    $143 = ((($142)) + 192|0);
    $144 = HEAP32[$143>>2]|0;
    FUNCTION_TABLE_vii[$144 & 8191]($1,$0);
    break L12;
    break;
   }
   default: {
    $145 = HEAP32[$1>>2]|0;
    $146 = ((($145)) + 196|0);
    $147 = HEAP32[$146>>2]|0;
    FUNCTION_TABLE_vii[$147 & 8191]($1,$0);
    break L12;
   }
   }
  } else {
   $28 = ((($0)) + 376|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = (__ZN7osgUtil10StateGraph14find_or_insertEPKN3osg8StateSetE($29,$26)|0);
   HEAP32[$28>>2] = $30;
   $31 = ((($26)) + 120|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ($32|0)==(0);
   if (!($33)) {
    $34 = ((($26)) + 128|0);
    $35 = ((($34)) + 11|0);
    $36 = HEAP8[$35>>0]|0;
    $37 = ($36<<24>>24)<(0);
    if ($37) {
     $38 = ((($26)) + 132|0);
     $39 = HEAP32[$38>>2]|0;
     $41 = $39;
    } else {
     $40 = $36&255;
     $41 = $40;
    }
    $42 = ($41|0)==(0);
    if ($42) {
     $68 = $32;
    } else {
     $43 = ((($0)) + 440|0);
     $44 = HEAP32[$43>>2]|0;
     $45 = ($44|0)!=(0);
     $46 = $32 & 4;
     $47 = ($46|0)==(0);
     $or$cond$i = $47 & $45;
     if ($or$cond$i) {
      $68 = $32;
     } else {
      $48 = ((($0)) + 384|0);
      $49 = ((($0)) + 392|0);
      $50 = HEAP32[$49>>2]|0;
      $51 = ((($0)) + 396|0);
      $52 = HEAP32[$51>>2]|0;
      $53 = ($50|0)==($52|0);
      if ($53) {
       $57 = ((($0)) + 388|0);
       __ZNSt3__26vectorIPN7osgUtil9RenderBinENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_($57,$48);
      } else {
       $54 = HEAP32[$48>>2]|0;
       HEAP32[$50>>2] = $54;
       $55 = HEAP32[$49>>2]|0;
       $56 = ((($55)) + 4|0);
       HEAP32[$49>>2] = $56;
      }
      $58 = ((($26)) + 140|0);
      $59 = HEAP8[$58>>0]|0;
      $60 = ($59<<24>>24)==(0);
      $61 = HEAP32[$48>>2]|0;
      if ($60) {
       $62 = ((($61)) + 40|0);
       $63 = HEAP32[$62>>2]|0;
       $$sink$i = $63;
      } else {
       $$sink$i = $61;
      }
      $64 = ((($26)) + 124|0);
      $65 = HEAP32[$64>>2]|0;
      $66 = (__ZN7osgUtil9RenderBin14find_or_insertEiRKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE($$sink$i,$65,$34)|0);
      HEAP32[$48>>2] = $66;
      $$pre$i = HEAP32[$31>>2]|0;
      $68 = $$pre$i;
     }
    }
    $67 = $68 & 2;
    $69 = ($67|0)==(0);
    if (!($69)) {
     $70 = ((($0)) + 440|0);
     $71 = HEAP32[$70>>2]|0;
     $72 = (($71) + 1)|0;
     HEAP32[$70>>2] = $72;
    }
   }
   $73 = ((($1)) + 100|0);
   $74 = HEAP32[$73>>2]|0;
   $75 = ($74|0)==(0|0);
   L40: do {
    if ($75) {
     $83 = ((($0)) + 16|0);
     $84 = HEAP32[$83>>2]|0;
     switch ($84|0) {
     case 0:  {
      break L40;
      break;
     }
     case 1:  {
      $85 = HEAP32[$1>>2]|0;
      $86 = ((($85)) + 192|0);
      $87 = HEAP32[$86>>2]|0;
      FUNCTION_TABLE_vii[$87 & 8191]($1,$0);
      break L40;
      break;
     }
     default: {
      $88 = HEAP32[$1>>2]|0;
      $89 = ((($88)) + 196|0);
      $90 = HEAP32[$89>>2]|0;
      FUNCTION_TABLE_vii[$90 & 8191]($1,$0);
      break L40;
     }
     }
    } else {
     $76 = HEAP32[$74>>2]|0;
     $77 = ((($76)) + 92|0);
     $78 = HEAP32[$77>>2]|0;
     $79 = HEAP32[$0>>2]|0;
     $80 = ((($79)) + -12|0);
     $81 = HEAP32[$80>>2]|0;
     $82 = (($0) + ($81)|0);
     (FUNCTION_TABLE_iiii[$78 & 8191]($74,$1,$82)|0);
    }
   } while(0);
   $91 = HEAP32[$28>>2]|0;
   $92 = ((($91)) + 16|0);
   $93 = HEAP32[$92>>2]|0;
   $94 = ((($93)) + 120|0);
   $95 = HEAP32[$94>>2]|0;
   $96 = $95 & 2;
   $97 = ($96|0)==(0);
   if (!($97)) {
    $98 = ((($0)) + 440|0);
    $99 = HEAP32[$98>>2]|0;
    $100 = (($99) + -1)|0;
    HEAP32[$98>>2] = $100;
   }
   $101 = ($95|0)==(0);
   do {
    if (!($101)) {
     $102 = ((($93)) + 128|0);
     $103 = ((($102)) + 11|0);
     $104 = HEAP8[$103>>0]|0;
     $105 = ($104<<24>>24)<(0);
     if ($105) {
      $106 = ((($93)) + 132|0);
      $107 = HEAP32[$106>>2]|0;
      $109 = $107;
     } else {
      $108 = $104&255;
      $109 = $108;
     }
     $110 = ($109|0)==(0);
     if (!($110)) {
      $111 = ((($0)) + 440|0);
      $112 = HEAP32[$111>>2]|0;
      $113 = ($112|0)!=(0);
      $114 = $95 & 4;
      $115 = ($114|0)==(0);
      $or$cond$i9 = $115 & $113;
      if (!($or$cond$i9)) {
       $116 = ((($0)) + 388|0);
       $117 = HEAP32[$116>>2]|0;
       $118 = ((($0)) + 392|0);
       $119 = HEAP32[$118>>2]|0;
       $120 = ($117|0)==($119|0);
       if ($120) {
        $121 = ((($0)) + 384|0);
        $122 = HEAP32[$121>>2]|0;
        $123 = ((($122)) + 40|0);
        $124 = HEAP32[$123>>2]|0;
        HEAP32[$121>>2] = $124;
        break;
       } else {
        $125 = ((($119)) + -4|0);
        $126 = HEAP32[$125>>2]|0;
        $127 = ((($0)) + 384|0);
        HEAP32[$127>>2] = $126;
        HEAP32[$118>>2] = $125;
        break;
       }
      }
     }
    }
   } while(0);
   $128 = ((($91)) + 12|0);
   $129 = HEAP32[$128>>2]|0;
   HEAP32[$28>>2] = $129;
  }
 } while(0);
 $148 = HEAP32[$3>>2]|0;
 $149 = ((($148)) + 32|0);
 $150 = HEAP32[$149>>2]|0;
 $151 = ($150|0)==(0);
 if (!($151)) {
  $152 = ((($148)) + 20|0);
  $153 = HEAP32[$152>>2]|0;
  $154 = ((($148)) + 24|0);
  $155 = HEAP32[$154>>2]|0;
  $156 = ($153|0)==($155|0);
  if (!($156)) {
   $157 = ((($155)) + -4|0);
   $158 = HEAP32[$157>>2]|0;
   $159 = ((($148)) + 16|0);
   HEAP32[$159>>2] = $158;
   HEAP32[$154>>2] = $157;
  }
  $160 = (($150) + -1)|0;
  HEAP32[$149>>2] = $160;
 }
 $161 = ((($148)) + 64|0);
 $162 = HEAP32[$161>>2]|0;
 $163 = ((($148)) + 68|0);
 $164 = HEAP32[$163>>2]|0;
 $165 = ($162|0)==($164|0);
 if (!($165)) {
  $$sroa$09$016$i$i = $162;
  while(1) {
   $166 = ((($$sroa$09$016$i$i)) + 20|0);
   $167 = HEAP32[$166>>2]|0;
   $168 = ($167|0)==(0);
   if (!($168)) {
    $169 = ((($$sroa$09$016$i$i)) + 8|0);
    $170 = HEAP32[$169>>2]|0;
    $171 = ((($$sroa$09$016$i$i)) + 12|0);
    $172 = HEAP32[$171>>2]|0;
    $173 = ($170|0)==($172|0);
    if (!($173)) {
     $174 = ((($172)) + -4|0);
     $175 = HEAP32[$174>>2]|0;
     $176 = ((($$sroa$09$016$i$i)) + 4|0);
     HEAP32[$176>>2] = $175;
     HEAP32[$171>>2] = $174;
    }
    $177 = (($167) + -1)|0;
    HEAP32[$166>>2] = $177;
   }
   $178 = ((($$sroa$09$016$i$i)) + 52|0);
   $179 = ($178|0)==($164|0);
   if ($179) {
    break;
   } else {
    $$sroa$09$016$i$i = $178;
   }
  }
 }
 $180 = ((($148)) + 76|0);
 $181 = HEAP32[$180>>2]|0;
 $182 = ((($148)) + 80|0);
 $183 = HEAP32[$182>>2]|0;
 $184 = ($181|0)==($183|0);
 if (!($184)) {
  $$sroa$03$015$i$i = $181;
  while(1) {
   $185 = ((($$sroa$03$015$i$i)) + 36|0);
   $186 = HEAP32[$185>>2]|0;
   $187 = ($186|0)==(0);
   if (!($187)) {
    $188 = ((($$sroa$03$015$i$i)) + 24|0);
    $189 = HEAP32[$188>>2]|0;
    $190 = ((($$sroa$03$015$i$i)) + 28|0);
    $191 = HEAP32[$190>>2]|0;
    $192 = ($189|0)==($191|0);
    if (!($192)) {
     $193 = ((($191)) + -4|0);
     $194 = HEAP32[$193>>2]|0;
     $195 = ((($$sroa$03$015$i$i)) + 20|0);
     HEAP32[$195>>2] = $194;
     HEAP32[$190>>2] = $193;
    }
    $196 = (($186) + -1)|0;
    HEAP32[$185>>2] = $196;
   }
   $197 = ((($$sroa$03$015$i$i)) + 68|0);
   $198 = HEAP32[$197>>2]|0;
   $199 = ((($$sroa$03$015$i$i)) + 72|0);
   $200 = HEAP32[$199>>2]|0;
   $201 = ($198|0)==($200|0);
   if (!($201)) {
    $$sroa$03$07$i$i$i = $198;
    while(1) {
     $202 = ((($$sroa$03$07$i$i$i)) + 16|0);
     $203 = HEAP32[$202>>2]|0;
     $204 = ($203|0)==(0);
     if (!($204)) {
      $205 = ((($$sroa$03$07$i$i$i)) + 4|0);
      $206 = HEAP32[$205>>2]|0;
      $207 = ((($$sroa$03$07$i$i$i)) + 8|0);
      $208 = HEAP32[$207>>2]|0;
      $209 = ($206|0)==($208|0);
      if (!($209)) {
       $210 = ((($208)) + -4|0);
       $211 = HEAP32[$210>>2]|0;
       HEAP32[$$sroa$03$07$i$i$i>>2] = $211;
       HEAP32[$207>>2] = $210;
      }
      $212 = (($203) + -1)|0;
      HEAP32[$202>>2] = $212;
     }
     $213 = ((($$sroa$03$07$i$i$i)) + 48|0);
     $214 = ($213|0)==($200|0);
     if ($214) {
      break;
     } else {
      $$sroa$03$07$i$i$i = $213;
     }
    }
   }
   $215 = ((($$sroa$03$015$i$i)) + 80|0);
   $216 = ($215|0)==($183|0);
   if ($216) {
    break;
   } else {
    $$sroa$03$015$i$i = $215;
   }
  }
 }
 __ZN3osg10CullingSet23popOccludersCurrentMaskERNSt3__26vectorIPNS_4NodeENS1_9allocatorIS4_EEEE($148,$2);
 return;
}
function __ZN7osgUtil11CullVisitor5applyERN3osg18OcclusionQueryNodeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$pre = 0, $$pre$i = 0, $$pre$phiZ2D = 0, $$pre18$pre$phiZZ2D = 0, $$sink$i = 0, $$sroa$03$015$i$i = 0, $$sroa$03$07$i$i$i = 0, $$sroa$09$016$i$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0.0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0;
 var $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0;
 var $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0;
 var $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond$i = 0;
 var $or$cond$i16 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 108|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 do {
  if ($4) {
   $5 = ((($1)) + 104|0);
   $6 = HEAP8[$5>>0]|0;
   $7 = ($6<<24>>24)==(0);
   if ($7) {
    label = 3;
   } else {
    $10 = (__ZNK3osg4Node8getBoundEv($1)|0);
    $11 = ((($10)) + 12|0);
    $12 = +HEAPF32[$11>>2];
    $13 = !($12 >= 0.0);
    $14 = ((($0)) + 336|0);
    $15 = HEAP32[$14>>2]|0;
    if ($13) {
     $$pre18$pre$phiZZ2D = $14;$17 = $15;
     label = 5;
    } else {
     $20 = (__ZNK3osg4Node8getBoundEv($1)|0);
     $21 = (__ZN3osg10CullingSet8isCulledERKNS_18BoundingSphereImplINS_5Vec3fEEE($15,$20)|0);
     if ($21) {
      return;
     } else {
      $$pre = HEAP32[$14>>2]|0;
      $$pre$phiZ2D = $14;$22 = $$pre;
      break;
     }
    }
   }
  } else {
   label = 3;
  }
 } while(0);
 if ((label|0) == 3) {
  $8 = ((($0)) + 336|0);
  $9 = HEAP32[$8>>2]|0;
  $$pre18$pre$phiZZ2D = $8;$17 = $9;
  label = 5;
 }
 if ((label|0) == 5) {
  $16 = ((($17)) + 16|0);
  $18 = HEAP32[$16>>2]|0;
  $19 = ((($17)) + 36|0);
  HEAP32[$19>>2] = $18;
  $$pre$phiZ2D = $$pre18$pre$phiZZ2D;$22 = $17;
 }
 __ZN3osg10CullingSet15pushCurrentMaskEv($22);
 $23 = ((($1)) + 120|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)!=(0|0);
 if ($25) {
  $26 = ((($0)) + 376|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = (__ZN7osgUtil10StateGraph14find_or_insertEPKN3osg8StateSetE($27,$24)|0);
  HEAP32[$26>>2] = $28;
  $29 = ((($24)) + 120|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = ($30|0)==(0);
  if (!($31)) {
   $32 = ((($24)) + 128|0);
   $33 = ((($32)) + 11|0);
   $34 = HEAP8[$33>>0]|0;
   $35 = ($34<<24>>24)<(0);
   if ($35) {
    $36 = ((($24)) + 132|0);
    $37 = HEAP32[$36>>2]|0;
    $39 = $37;
   } else {
    $38 = $34&255;
    $39 = $38;
   }
   $40 = ($39|0)==(0);
   if ($40) {
    $66 = $30;
   } else {
    $41 = ((($0)) + 440|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = ($42|0)!=(0);
    $44 = $30 & 4;
    $45 = ($44|0)==(0);
    $or$cond$i = $45 & $43;
    if ($or$cond$i) {
     $66 = $30;
    } else {
     $46 = ((($0)) + 384|0);
     $47 = ((($0)) + 392|0);
     $48 = HEAP32[$47>>2]|0;
     $49 = ((($0)) + 396|0);
     $50 = HEAP32[$49>>2]|0;
     $51 = ($48|0)==($50|0);
     if ($51) {
      $55 = ((($0)) + 388|0);
      __ZNSt3__26vectorIPN7osgUtil9RenderBinENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_($55,$46);
     } else {
      $52 = HEAP32[$46>>2]|0;
      HEAP32[$48>>2] = $52;
      $53 = HEAP32[$47>>2]|0;
      $54 = ((($53)) + 4|0);
      HEAP32[$47>>2] = $54;
     }
     $56 = ((($24)) + 140|0);
     $57 = HEAP8[$56>>0]|0;
     $58 = ($57<<24>>24)==(0);
     $59 = HEAP32[$46>>2]|0;
     if ($58) {
      $60 = ((($59)) + 40|0);
      $61 = HEAP32[$60>>2]|0;
      $$sink$i = $61;
     } else {
      $$sink$i = $59;
     }
     $62 = ((($24)) + 124|0);
     $63 = HEAP32[$62>>2]|0;
     $64 = (__ZN7osgUtil9RenderBin14find_or_insertEiRKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE($$sink$i,$63,$32)|0);
     HEAP32[$46>>2] = $64;
     $$pre$i = HEAP32[$29>>2]|0;
     $66 = $$pre$i;
    }
   }
   $65 = $66 & 2;
   $67 = ($65|0)==(0);
   if (!($67)) {
    $68 = ((($0)) + 440|0);
    $69 = HEAP32[$68>>2]|0;
    $70 = (($69) + 1)|0;
    HEAP32[$68>>2] = $70;
   }
  }
 }
 $71 = ((($0)) + 384|0);
 $72 = HEAP32[$71>>2]|0;
 $73 = ((($72)) + 40|0);
 $74 = HEAP32[$73>>2]|0;
 $75 = ((($74)) + 228|0);
 $76 = HEAP32[$75>>2]|0;
 $77 = ($76|0)==(0|0);
 if ($77) {
  $86 = 0;
 } else {
  $78 = ((($76)) + 24|0);
  $79 = HEAP32[$78>>2]|0;
  $80 = ($79|0)==(0|0);
  if ($80) {
   $86 = 0;
  } else {
   $81 = ((($74)) + 232|0);
   $82 = HEAP32[$81>>2]|0;
   $86 = $82;
  }
 }
 $83 = HEAP32[$1>>2]|0;
 $84 = ((($83)) + 240|0);
 $85 = HEAP32[$84>>2]|0;
 $87 = (FUNCTION_TABLE_iiii[$85 & 8191]($1,$86,$0)|0);
 L37: do {
  if ($87) {
   $88 = ((($1)) + 100|0);
   $89 = HEAP32[$88>>2]|0;
   $90 = ($89|0)==(0|0);
   if (!($90)) {
    $91 = HEAP32[$89>>2]|0;
    $92 = ((($91)) + 92|0);
    $93 = HEAP32[$92>>2]|0;
    $94 = HEAP32[$0>>2]|0;
    $95 = ((($94)) + -12|0);
    $96 = HEAP32[$95>>2]|0;
    $97 = (($0) + ($96)|0);
    (FUNCTION_TABLE_iiii[$93 & 8191]($89,$1,$97)|0);
    break;
   }
   $98 = ((($0)) + 16|0);
   $99 = HEAP32[$98>>2]|0;
   switch ($99|0) {
   case 0:  {
    break L37;
    break;
   }
   case 1:  {
    $100 = HEAP32[$1>>2]|0;
    $101 = ((($100)) + 192|0);
    $102 = HEAP32[$101>>2]|0;
    FUNCTION_TABLE_vii[$102 & 8191]($1,$0);
    break L37;
    break;
   }
   default: {
    $103 = HEAP32[$1>>2]|0;
    $104 = ((($103)) + 196|0);
    $105 = HEAP32[$104>>2]|0;
    FUNCTION_TABLE_vii[$105 & 8191]($1,$0);
    break L37;
   }
   }
  }
 } while(0);
 __ZN3osg18OcclusionQueryNode13traverseQueryEPKNS_6CameraERNS_11NodeVisitorE($1,$86,$0);
 __ZN3osg18OcclusionQueryNode13traverseDebugERNS_11NodeVisitorE($1,$0);
 if ($25) {
  $106 = ((($0)) + 376|0);
  $107 = HEAP32[$106>>2]|0;
  $108 = ((($107)) + 16|0);
  $109 = HEAP32[$108>>2]|0;
  $110 = ((($109)) + 120|0);
  $111 = HEAP32[$110>>2]|0;
  $112 = $111 & 2;
  $113 = ($112|0)==(0);
  if (!($113)) {
   $114 = ((($0)) + 440|0);
   $115 = HEAP32[$114>>2]|0;
   $116 = (($115) + -1)|0;
   HEAP32[$114>>2] = $116;
  }
  $117 = ($111|0)==(0);
  do {
   if (!($117)) {
    $118 = ((($109)) + 128|0);
    $119 = ((($118)) + 11|0);
    $120 = HEAP8[$119>>0]|0;
    $121 = ($120<<24>>24)<(0);
    if ($121) {
     $122 = ((($109)) + 132|0);
     $123 = HEAP32[$122>>2]|0;
     $125 = $123;
    } else {
     $124 = $120&255;
     $125 = $124;
    }
    $126 = ($125|0)==(0);
    if (!($126)) {
     $127 = ((($0)) + 440|0);
     $128 = HEAP32[$127>>2]|0;
     $129 = ($128|0)!=(0);
     $130 = $111 & 4;
     $131 = ($130|0)==(0);
     $or$cond$i16 = $131 & $129;
     if (!($or$cond$i16)) {
      $132 = ((($0)) + 388|0);
      $133 = HEAP32[$132>>2]|0;
      $134 = ((($0)) + 392|0);
      $135 = HEAP32[$134>>2]|0;
      $136 = ($133|0)==($135|0);
      if ($136) {
       $137 = HEAP32[$71>>2]|0;
       $138 = ((($137)) + 40|0);
       $139 = HEAP32[$138>>2]|0;
       HEAP32[$71>>2] = $139;
       break;
      } else {
       $140 = ((($135)) + -4|0);
       $141 = HEAP32[$140>>2]|0;
       HEAP32[$71>>2] = $141;
       HEAP32[$134>>2] = $140;
       break;
      }
     }
    }
   }
  } while(0);
  $142 = ((($107)) + 12|0);
  $143 = HEAP32[$142>>2]|0;
  HEAP32[$106>>2] = $143;
 }
 $144 = HEAP32[$$pre$phiZ2D>>2]|0;
 $145 = ((($144)) + 32|0);
 $146 = HEAP32[$145>>2]|0;
 $147 = ($146|0)==(0);
 if (!($147)) {
  $148 = ((($144)) + 20|0);
  $149 = HEAP32[$148>>2]|0;
  $150 = ((($144)) + 24|0);
  $151 = HEAP32[$150>>2]|0;
  $152 = ($149|0)==($151|0);
  if (!($152)) {
   $153 = ((($151)) + -4|0);
   $154 = HEAP32[$153>>2]|0;
   $155 = ((($144)) + 16|0);
   HEAP32[$155>>2] = $154;
   HEAP32[$150>>2] = $153;
  }
  $156 = (($146) + -1)|0;
  HEAP32[$145>>2] = $156;
 }
 $157 = ((($144)) + 64|0);
 $158 = HEAP32[$157>>2]|0;
 $159 = ((($144)) + 68|0);
 $160 = HEAP32[$159>>2]|0;
 $161 = ($158|0)==($160|0);
 if (!($161)) {
  $$sroa$09$016$i$i = $158;
  while(1) {
   $162 = ((($$sroa$09$016$i$i)) + 20|0);
   $163 = HEAP32[$162>>2]|0;
   $164 = ($163|0)==(0);
   if (!($164)) {
    $165 = ((($$sroa$09$016$i$i)) + 8|0);
    $166 = HEAP32[$165>>2]|0;
    $167 = ((($$sroa$09$016$i$i)) + 12|0);
    $168 = HEAP32[$167>>2]|0;
    $169 = ($166|0)==($168|0);
    if (!($169)) {
     $170 = ((($168)) + -4|0);
     $171 = HEAP32[$170>>2]|0;
     $172 = ((($$sroa$09$016$i$i)) + 4|0);
     HEAP32[$172>>2] = $171;
     HEAP32[$167>>2] = $170;
    }
    $173 = (($163) + -1)|0;
    HEAP32[$162>>2] = $173;
   }
   $174 = ((($$sroa$09$016$i$i)) + 52|0);
   $175 = ($174|0)==($160|0);
   if ($175) {
    break;
   } else {
    $$sroa$09$016$i$i = $174;
   }
  }
 }
 $176 = ((($144)) + 76|0);
 $177 = HEAP32[$176>>2]|0;
 $178 = ((($144)) + 80|0);
 $179 = HEAP32[$178>>2]|0;
 $180 = ($177|0)==($179|0);
 if ($180) {
  return;
 } else {
  $$sroa$03$015$i$i = $177;
 }
 while(1) {
  $181 = ((($$sroa$03$015$i$i)) + 36|0);
  $182 = HEAP32[$181>>2]|0;
  $183 = ($182|0)==(0);
  if (!($183)) {
   $184 = ((($$sroa$03$015$i$i)) + 24|0);
   $185 = HEAP32[$184>>2]|0;
   $186 = ((($$sroa$03$015$i$i)) + 28|0);
   $187 = HEAP32[$186>>2]|0;
   $188 = ($185|0)==($187|0);
   if (!($188)) {
    $189 = ((($187)) + -4|0);
    $190 = HEAP32[$189>>2]|0;
    $191 = ((($$sroa$03$015$i$i)) + 20|0);
    HEAP32[$191>>2] = $190;
    HEAP32[$186>>2] = $189;
   }
   $192 = (($182) + -1)|0;
   HEAP32[$181>>2] = $192;
  }
  $193 = ((($$sroa$03$015$i$i)) + 68|0);
  $194 = HEAP32[$193>>2]|0;
  $195 = ((($$sroa$03$015$i$i)) + 72|0);
  $196 = HEAP32[$195>>2]|0;
  $197 = ($194|0)==($196|0);
  if (!($197)) {
   $$sroa$03$07$i$i$i = $194;
   while(1) {
    $198 = ((($$sroa$03$07$i$i$i)) + 16|0);
    $199 = HEAP32[$198>>2]|0;
    $200 = ($199|0)==(0);
    if (!($200)) {
     $201 = ((($$sroa$03$07$i$i$i)) + 4|0);
     $202 = HEAP32[$201>>2]|0;
     $203 = ((($$sroa$03$07$i$i$i)) + 8|0);
     $204 = HEAP32[$203>>2]|0;
     $205 = ($202|0)==($204|0);
     if (!($205)) {
      $206 = ((($204)) + -4|0);
      $207 = HEAP32[$206>>2]|0;
      HEAP32[$$sroa$03$07$i$i$i>>2] = $207;
      HEAP32[$203>>2] = $206;
     }
     $208 = (($199) + -1)|0;
     HEAP32[$198>>2] = $208;
    }
    $209 = ((($$sroa$03$07$i$i$i)) + 48|0);
    $210 = ($209|0)==($196|0);
    if ($210) {
     break;
    } else {
     $$sroa$03$07$i$i$i = $209;
    }
   }
  }
  $211 = ((($$sroa$03$015$i$i)) + 80|0);
  $212 = ($211|0)==($179|0);
  if ($212) {
   break;
  } else {
   $$sroa$03$015$i$i = $211;
  }
 }
 return;
}
function __ZNK7osgUtil11CullVisitor5cloneEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(544)|0);
 __THREW__ = 0;
 invoke_vii(3631,($1|0),($0|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch_2()|0;
  $5 = tempRet0;
  __ZdlPv($1);
  ___resumeException($4|0);
  // unreachable;
 } else {
  return ($1|0);
 }
 return (0)|0;
}
function __ZN7osgUtil11CullVisitor19popProjectionMatrixEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0.0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0.0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp + 8|0;
 $2 = sp;
 __ZN7osgUtil11CullVisitor16computeNearPlaneEv($0);
 $3 = ((($0)) + 56|0);
 $4 = ((($0)) + 68|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  __ZN3osg9CullStack19popProjectionMatrixEv($3);
  STACKTOP = sp;return;
 }
 $7 = ((($0)) + 416|0);
 $8 = +HEAPF64[$7>>3];
 $9 = ((($0)) + 408|0);
 $10 = +HEAPF64[$9>>3];
 $11 = !($8 >= $10);
 if ($11) {
  __ZN3osg9CullStack19popProjectionMatrixEv($3);
  STACKTOP = sp;return;
 }
 $12 = ((($0)) + 132|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($13)) + 32|0);
 HEAPF64[$1>>3] = $10;
 HEAPF64[$2>>3] = $8;
 $15 = ((($0)) + 84|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==(0|0);
 if ($17) {
  $21 = HEAP32[$0>>2]|0;
  $22 = ((($21)) + 212|0);
  $23 = HEAP32[$22>>2]|0;
  (FUNCTION_TABLE_iiiii[$23 & 8191]($0,$14,$1,$2)|0);
 } else {
  $18 = HEAP32[$16>>2]|0;
  $19 = ((($18)) + 16|0);
  $20 = HEAP32[$19>>2]|0;
  (FUNCTION_TABLE_iiiii[$20 & 8191]($16,$14,$1,$2)|0);
 }
 __ZN3osg9CullStack19popProjectionMatrixEv($3);
 STACKTOP = sp;return;
}
function __ZNK7osgUtil11CullVisitor35clampProjectionMatrixImplementationERN3osg7MatrixfERdS4_($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $4 = 0, $5 = 0.0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ((($0)) + 88|0);
 $5 = +HEAPF64[$4>>3];
 $6 = (__Z22_clampProjectionMatrixIN3osg7MatrixfEdEbRT_RdS4_T0_($1,$2,$3,$5)|0);
 return ($6|0);
}
function __ZNK7osgUtil11CullVisitor35clampProjectionMatrixImplementationERN3osg7MatrixdERdS4_($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $4 = 0, $5 = 0.0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ((($0)) + 88|0);
 $5 = +HEAPF64[$4>>3];
 $6 = (__Z22_clampProjectionMatrixIN3osg7MatrixdEdEbRT_RdS4_T0_($1,$2,$3,$5)|0);
 return ($6|0);
}
function __ZThn56_N7osgUtil11CullVisitorD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -56|0);
 __THREW__ = 0;
 invoke_vii(3621,($1|0),(51908|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  $11 = ((($1)) + 508|0);
  __ZN3osg6ObjectD2Ev($11);
  return;
 }
 $4 = ___cxa_find_matching_catch_2()|0;
 $5 = tempRet0;
 $6 = ((($1)) + 508|0);
 __THREW__ = 0;
 invoke_vi(388,($6|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch_3(0|0)|0;
  $10 = tempRet0;
  ___clang_call_terminate($9);
  // unreachable;
 } else {
  ___resumeException($4|0);
  // unreachable;
 }
}
function __ZThn56_N7osgUtil11CullVisitorD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$i$index2Z2D = 0, $eh$lpad$body$i$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -56|0);
 __THREW__ = 0;
 invoke_vii(3621,($1|0),(51908|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $7 = ___cxa_find_matching_catch_2()|0;
  $8 = tempRet0;
  $9 = ((($1)) + 508|0);
  __THREW__ = 0;
  invoke_vi(388,($9|0));
  $10 = __THREW__; __THREW__ = 0;
  $11 = $10&1;
  if ($11) {
   $12 = ___cxa_find_matching_catch_3(0|0)|0;
   $13 = tempRet0;
   ___clang_call_terminate($12);
   // unreachable;
  } else {
   $eh$lpad$body$i$index2Z2D = $8;$eh$lpad$body$i$indexZ2D = $7;
   __ZdlPv($1);
   ___resumeException($eh$lpad$body$i$indexZ2D|0);
   // unreachable;
  }
 }
 $4 = ((($1)) + 508|0);
 __THREW__ = 0;
 invoke_vi(388,($4|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if (!($6)) {
  __ZdlPv($1);
  return;
 }
 $14 = ___cxa_find_matching_catch_2()|0;
 $15 = tempRet0;
 $eh$lpad$body$i$index2Z2D = $15;$eh$lpad$body$i$indexZ2D = $14;
 __ZdlPv($1);
 ___resumeException($eh$lpad$body$i$indexZ2D|0);
 // unreachable;
}
function __ZN3osg12CullSettings19inheritCullSettingsERKS0_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $3 = ((($2)) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 FUNCTION_TABLE_viii[$4 & 8191]($0,$1,$6);
 return;
}
function __ZTv0_n16_N7osgUtil11CullVisitorD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __THREW__ = 0;
 invoke_vii(3621,($4|0),(51908|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if (!($6)) {
  $14 = ((($4)) + 508|0);
  __ZN3osg6ObjectD2Ev($14);
  return;
 }
 $7 = ___cxa_find_matching_catch_2()|0;
 $8 = tempRet0;
 $9 = ((($4)) + 508|0);
 __THREW__ = 0;
 invoke_vi(388,($9|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if ($11) {
  $12 = ___cxa_find_matching_catch_3(0|0)|0;
  $13 = tempRet0;
  ___clang_call_terminate($12);
  // unreachable;
 } else {
  ___resumeException($7|0);
  // unreachable;
 }
}
function __ZTv0_n16_N7osgUtil11CullVisitorD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$i$index2Z2D = 0, $eh$lpad$body$i$indexZ2D = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __THREW__ = 0;
 invoke_vii(3621,($4|0),(51908|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $10 = ___cxa_find_matching_catch_2()|0;
  $11 = tempRet0;
  $12 = ((($4)) + 508|0);
  __THREW__ = 0;
  invoke_vi(388,($12|0));
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if ($14) {
   $15 = ___cxa_find_matching_catch_3(0|0)|0;
   $16 = tempRet0;
   ___clang_call_terminate($15);
   // unreachable;
  } else {
   $eh$lpad$body$i$index2Z2D = $11;$eh$lpad$body$i$indexZ2D = $10;
   __ZdlPv($4);
   ___resumeException($eh$lpad$body$i$indexZ2D|0);
   // unreachable;
  }
 }
 $7 = ((($4)) + 508|0);
 __THREW__ = 0;
 invoke_vi(388,($7|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if (!($9)) {
  __ZdlPv($4);
  return;
 }
 $17 = ___cxa_find_matching_catch_2()|0;
 $18 = tempRet0;
 $eh$lpad$body$i$index2Z2D = $18;$eh$lpad$body$i$indexZ2D = $17;
 __ZdlPv($4);
 ___resumeException($eh$lpad$body$i$indexZ2D|0);
 // unreachable;
}
function __ZTv0_n32_NK7osgUtil11CullVisitor11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (116801|0);
}
function __ZTv0_n36_NK7osgUtil11CullVisitor9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (115214|0);
}
function __ZN7osgUtil11CullVisitorD2Ev($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$03 = 0, $$3 = 0, $$36 = 0, $$6 = 0, $$69 = 0, $$7 = 0, $$710 = 0, $$8 = 0, $$811 = 0, $$cast = 0, $$pre$i = 0, $$pre$i19 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0;
 var $160 = 0, $161 = 0, $162 = 0, $163 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i23 = 0, $scevgep5$i$i$i = 0, $scevgep5$i$i$i24 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $2;
 $3 = ((($1)) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $$cast = $2;
 $5 = ((($$cast)) + -12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($0) + ($6)|0);
 HEAP32[$7>>2] = $4;
 $8 = ((($0)) + 56|0);
 HEAP32[$8>>2] = (51604);
 $9 = HEAP32[$0>>2]|0;
 $10 = ((($9)) + 76|0);
 $11 = HEAP32[$10>>2]|0;
 __THREW__ = 0;
 invoke_vi($11|0,($0|0));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 do {
  if ($13) {
   $81 = ___cxa_find_matching_catch_2()|0;
   $82 = tempRet0;
   $83 = ((($0)) + 504|0);
   $84 = HEAP32[$83>>2]|0;
   $85 = ($84|0)==(0|0);
   if (!($85)) {
    $86 = ((($84)) + 8|0);
    $87 = HEAP32[$86>>2]|0;HEAP32[$86>>2] = (($87-1)|0);
    $88 = ($87|0)==(1);
    if ($88) {
     __THREW__ = 0;
     invoke_viii(3262,($84|0),1,1);
     $89 = __THREW__; __THREW__ = 0;
     $90 = $89&1;
     if ($90) {
      $162 = ___cxa_find_matching_catch_3(0|0)|0;
      $163 = tempRet0;
      ___clang_call_terminate($162);
      // unreachable;
     }
    }
   }
   HEAP32[$83>>2] = 0;
   $$0 = $82;$$03 = $81;
   label = 33;
  } else {
   $14 = ((($0)) + 504|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = ($15|0)==(0|0);
   if (!($16)) {
    $17 = ((($15)) + 8|0);
    $18 = HEAP32[$17>>2]|0;HEAP32[$17>>2] = (($18-1)|0);
    $19 = ($18|0)==(1);
    if ($19) {
     __THREW__ = 0;
     invoke_viii(3262,($15|0),1,1);
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      $91 = ___cxa_find_matching_catch_2()|0;
      $92 = tempRet0;
      $$0 = $92;$$03 = $91;
      label = 33;
      break;
     }
    }
   }
   HEAP32[$14>>2] = 0;
   $22 = ((($0)) + 492|0);
   $23 = ((($0)) + 496|0);
   $24 = HEAP32[$23>>2]|0;
   __ZNSt3__26__treeINS_12__value_typeIdN7osgUtil11CullVisitor21MatrixPlanesDrawablesEEENS_19__map_value_compareIdS5_NS_4lessIdEELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($22,$24);
   $25 = ((($0)) + 480|0);
   $26 = ((($0)) + 484|0);
   $27 = HEAP32[$26>>2]|0;
   __ZNSt3__26__treeINS_12__value_typeIdN7osgUtil11CullVisitor21MatrixPlanesDrawablesEEENS_19__map_value_compareIdS5_NS_4lessIdEELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($25,$27);
   $28 = ((($0)) + 444|0);
   __THREW__ = 0;
   invoke_vi(3504,($28|0));
   $29 = __THREW__; __THREW__ = 0;
   $30 = $29&1;
   if ($30) {
    $93 = ___cxa_find_matching_catch_2()|0;
    $94 = tempRet0;
    $$3 = $94;$$36 = $93;
    label = 34;
    break;
   }
   $31 = ((($0)) + 424|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ($32|0)==(0|0);
   if (!($33)) {
    $34 = ((($0)) + 428|0);
    $35 = HEAP32[$34>>2]|0;
    $36 = ($35|0)==($32|0);
    do {
     if ($36) {
      $50 = $32;
     } else {
      $38 = $35;
      while(1) {
       $37 = ((($38)) + -4|0);
       HEAP32[$34>>2] = $37;
       $39 = HEAP32[$37>>2]|0;
       $40 = ($39|0)==(0|0);
       if (!($40)) {
        $41 = ((($39)) + 8|0);
        $42 = HEAP32[$41>>2]|0;HEAP32[$41>>2] = (($42-1)|0);
        $43 = ($42|0)==(1);
        if ($43) {
         __THREW__ = 0;
         invoke_viii(3262,($39|0),1,1);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          label = 12;
          break;
         }
        }
       }
       HEAP32[$37>>2] = 0;
       $46 = HEAP32[$34>>2]|0;
       $47 = ($46|0)==($32|0);
       if ($47) {
        label = 13;
        break;
       } else {
        $38 = $46;
       }
      }
      if ((label|0) == 12) {
       $48 = ___cxa_find_matching_catch_2()|0;
       $49 = tempRet0;
       ___cxa_call_unexpected(($48|0));
       // unreachable;
      }
      else if ((label|0) == 13) {
       $$pre$i = HEAP32[$31>>2]|0;
       $50 = $$pre$i;
       break;
      }
     }
    } while(0);
    __ZdlPv($50);
   }
   $51 = ((($0)) + 388|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = ($52|0)==(0|0);
   if (!($53)) {
    $54 = ((($0)) + 392|0);
    $55 = HEAP32[$54>>2]|0;
    $56 = ($55|0)==($52|0);
    if (!($56)) {
     $scevgep$i$i$i = ((($55)) + -4|0);
     $57 = $scevgep$i$i$i;
     $58 = $52;
     $59 = (($57) - ($58))|0;
     $60 = $59 >>> 2;
     $61 = $60 ^ -1;
     $scevgep5$i$i$i = (($55) + ($61<<2)|0);
     HEAP32[$54>>2] = $scevgep5$i$i$i;
    }
    __ZdlPv($52);
   }
   $62 = ((($0)) + 380|0);
   $63 = HEAP32[$62>>2]|0;
   $64 = ($63|0)==(0|0);
   if (!($64)) {
    $65 = ((($63)) + 8|0);
    $66 = HEAP32[$65>>2]|0;HEAP32[$65>>2] = (($66-1)|0);
    $67 = ($66|0)==(1);
    if ($67) {
     __THREW__ = 0;
     invoke_viii(3262,($63|0),1,1);
     $68 = __THREW__; __THREW__ = 0;
     $69 = $68&1;
     if ($69) {
      $135 = ___cxa_find_matching_catch_2()|0;
      $136 = tempRet0;
      $$6 = $136;$$69 = $135;
      label = 53;
      break;
     }
    }
   }
   HEAP32[$62>>2] = 0;
   $70 = ((($0)) + 372|0);
   $71 = HEAP32[$70>>2]|0;
   $72 = ($71|0)==(0|0);
   if (!($72)) {
    $73 = ((($71)) + 8|0);
    $74 = HEAP32[$73>>2]|0;HEAP32[$73>>2] = (($74-1)|0);
    $75 = ($74|0)==(1);
    if ($75) {
     __THREW__ = 0;
     invoke_viii(3262,($71|0),1,1);
     $76 = __THREW__; __THREW__ = 0;
     $77 = $76&1;
     if ($77) {
      $145 = ___cxa_find_matching_catch_2()|0;
      $146 = tempRet0;
      $$7 = $146;$$710 = $145;
      label = 58;
      break;
     }
    }
   }
   HEAP32[$70>>2] = 0;
   __THREW__ = 0;
   invoke_vi(1621,($8|0));
   $78 = __THREW__; __THREW__ = 0;
   $79 = $78&1;
   if ($79) {
    $155 = ___cxa_find_matching_catch_2()|0;
    $156 = tempRet0;
    $$8 = $156;$$811 = $155;
    break;
   } else {
    $80 = ((($1)) + 4|0);
    __ZN3osg11NodeVisitorD2Ev($0,$80);
    return;
   }
  }
 } while(0);
 if ((label|0) == 33) {
  $95 = ((($0)) + 492|0);
  $96 = ((($0)) + 496|0);
  $97 = HEAP32[$96>>2]|0;
  __ZNSt3__26__treeINS_12__value_typeIdN7osgUtil11CullVisitor21MatrixPlanesDrawablesEEENS_19__map_value_compareIdS5_NS_4lessIdEELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($95,$97);
  $98 = ((($0)) + 480|0);
  $99 = ((($0)) + 484|0);
  $100 = HEAP32[$99>>2]|0;
  __ZNSt3__26__treeINS_12__value_typeIdN7osgUtil11CullVisitor21MatrixPlanesDrawablesEEENS_19__map_value_compareIdS5_NS_4lessIdEELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($98,$100);
  $101 = ((($0)) + 444|0);
  __THREW__ = 0;
  invoke_vi(3504,($101|0));
  $102 = __THREW__; __THREW__ = 0;
  $103 = $102&1;
  if ($103) {
   $162 = ___cxa_find_matching_catch_3(0|0)|0;
   $163 = tempRet0;
   ___clang_call_terminate($162);
   // unreachable;
  } else {
   $$3 = $$0;$$36 = $$03;
   label = 34;
  }
 }
 if ((label|0) == 34) {
  $104 = ((($0)) + 424|0);
  $105 = HEAP32[$104>>2]|0;
  $106 = ($105|0)==(0|0);
  if (!($106)) {
   $107 = ((($0)) + 428|0);
   $108 = HEAP32[$107>>2]|0;
   $109 = ($108|0)==($105|0);
   do {
    if ($109) {
     $123 = $105;
    } else {
     $111 = $108;
     while(1) {
      $110 = ((($111)) + -4|0);
      HEAP32[$107>>2] = $110;
      $112 = HEAP32[$110>>2]|0;
      $113 = ($112|0)==(0|0);
      if (!($113)) {
       $114 = ((($112)) + 8|0);
       $115 = HEAP32[$114>>2]|0;HEAP32[$114>>2] = (($115-1)|0);
       $116 = ($115|0)==(1);
       if ($116) {
        __THREW__ = 0;
        invoke_viii(3262,($112|0),1,1);
        $117 = __THREW__; __THREW__ = 0;
        $118 = $117&1;
        if ($118) {
         label = 40;
         break;
        }
       }
      }
      HEAP32[$110>>2] = 0;
      $119 = HEAP32[$107>>2]|0;
      $120 = ($119|0)==($105|0);
      if ($120) {
       label = 41;
       break;
      } else {
       $111 = $119;
      }
     }
     if ((label|0) == 40) {
      $121 = ___cxa_find_matching_catch_2()|0;
      $122 = tempRet0;
      ___cxa_call_unexpected(($121|0));
      // unreachable;
     }
     else if ((label|0) == 41) {
      $$pre$i19 = HEAP32[$104>>2]|0;
      $123 = $$pre$i19;
      break;
     }
    }
   } while(0);
   __ZdlPv($123);
  }
  $124 = ((($0)) + 388|0);
  $125 = HEAP32[$124>>2]|0;
  $126 = ($125|0)==(0|0);
  if (!($126)) {
   $127 = ((($0)) + 392|0);
   $128 = HEAP32[$127>>2]|0;
   $129 = ($128|0)==($125|0);
   if (!($129)) {
    $scevgep$i$i$i23 = ((($128)) + -4|0);
    $130 = $scevgep$i$i$i23;
    $131 = $125;
    $132 = (($130) - ($131))|0;
    $133 = $132 >>> 2;
    $134 = $133 ^ -1;
    $scevgep5$i$i$i24 = (($128) + ($134<<2)|0);
    HEAP32[$127>>2] = $scevgep5$i$i$i24;
   }
   __ZdlPv($125);
  }
  $137 = ((($0)) + 380|0);
  $138 = HEAP32[$137>>2]|0;
  $139 = ($138|0)==(0|0);
  if (!($139)) {
   $140 = ((($138)) + 8|0);
   $141 = HEAP32[$140>>2]|0;HEAP32[$140>>2] = (($141-1)|0);
   $142 = ($141|0)==(1);
   if ($142) {
    __THREW__ = 0;
    invoke_viii(3262,($138|0),1,1);
    $143 = __THREW__; __THREW__ = 0;
    $144 = $143&1;
    if ($144) {
     $162 = ___cxa_find_matching_catch_3(0|0)|0;
     $163 = tempRet0;
     ___clang_call_terminate($162);
     // unreachable;
    }
   }
  }
  HEAP32[$137>>2] = 0;
  $$6 = $$3;$$69 = $$36;
  label = 53;
 }
 if ((label|0) == 53) {
  $147 = ((($0)) + 372|0);
  $148 = HEAP32[$147>>2]|0;
  $149 = ($148|0)==(0|0);
  if (!($149)) {
   $150 = ((($148)) + 8|0);
   $151 = HEAP32[$150>>2]|0;HEAP32[$150>>2] = (($151-1)|0);
   $152 = ($151|0)==(1);
   if ($152) {
    __THREW__ = 0;
    invoke_viii(3262,($148|0),1,1);
    $153 = __THREW__; __THREW__ = 0;
    $154 = $153&1;
    if ($154) {
     $162 = ___cxa_find_matching_catch_3(0|0)|0;
     $163 = tempRet0;
     ___clang_call_terminate($162);
     // unreachable;
    }
   }
  }
  HEAP32[$147>>2] = 0;
  $$7 = $$6;$$710 = $$69;
  label = 58;
 }
 if ((label|0) == 58) {
  __THREW__ = 0;
  invoke_vi(1621,($8|0));
  $157 = __THREW__; __THREW__ = 0;
  $158 = $157&1;
  if ($158) {
   $162 = ___cxa_find_matching_catch_3(0|0)|0;
   $163 = tempRet0;
   ___clang_call_terminate($162);
   // unreachable;
  } else {
   $$8 = $$7;$$811 = $$710;
  }
 }
 $159 = ((($1)) + 4|0);
 __THREW__ = 0;
 invoke_vii(3284,($0|0),($159|0));
 $160 = __THREW__; __THREW__ = 0;
 $161 = $160&1;
 if ($161) {
  $162 = ___cxa_find_matching_catch_3(0|0)|0;
  $163 = tempRet0;
  ___clang_call_terminate($162);
  // unreachable;
 } else {
  ___resumeException($$811|0);
  // unreachable;
 }
}
function __ZNSt3__26__treeINS_12__value_typeIdN7osgUtil11CullVisitor21MatrixPlanesDrawablesEEENS_19__map_value_compareIdS5_NS_4lessIdEELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 }
 $3 = HEAP32[$1>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIdN7osgUtil11CullVisitor21MatrixPlanesDrawablesEEENS_19__map_value_compareIdS5_NS_4lessIdEELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($0,$3);
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIdN7osgUtil11CullVisitor21MatrixPlanesDrawablesEEENS_19__map_value_compareIdS5_NS_4lessIdEELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($0,$5);
 $6 = ((($1)) + 156|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = ((($1)) + 160|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10|0)==($7|0);
  if (!($11)) {
   $scevgep$i$i$i$i$i$i$i = ((($10)) + -40|0);
   $12 = $scevgep$i$i$i$i$i$i$i;
   $13 = $7;
   $14 = (($12) - ($13))|0;
   $15 = (($14>>>0) / 40)&-1;
   $16 = $15 ^ -1;
   $scevgep5$i$i$i$i$i$i$i = (($10) + (($16*40)|0)|0);
   HEAP32[$9>>2] = $scevgep5$i$i$i$i$i$i$i;
  }
  __ZdlPv($7);
 }
 __ZdlPv($1);
 return;
}
function __Z22_clampProjectionMatrixIN3osg7MatrixdEdEbRT_RdS4_T0_($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = +$3;
 var $$0 = 0, $$0114 = 0.0, $$0115 = 0.0, $10 = 0, $100 = 0.0, $101 = 0.0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0.0, $16 = 0, $17 = 0, $18 = 0.0, $19 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0.0, $4 = 0;
 var $40 = 0, $41 = 0.0, $42 = 0.0, $43 = 0.0, $44 = 0.0, $45 = 0, $46 = 0.0, $47 = 0.0, $48 = 0, $49 = 0, $5 = 0, $50 = 0.0, $51 = 0.0, $52 = 0, $53 = 0, $54 = 0.0, $55 = 0.0, $56 = 0, $57 = 0.0, $58 = 0.0;
 var $59 = 0.0, $6 = 0.0, $60 = 0.0, $61 = 0, $62 = 0.0, $63 = 0.0, $64 = 0.0, $65 = 0.0, $66 = 0, $67 = 0.0, $68 = 0.0, $69 = 0.0, $7 = 0.0, $70 = 0, $71 = 0.0, $72 = 0.0, $73 = 0.0, $74 = 0.0, $75 = 0, $76 = 0.0;
 var $77 = 0, $78 = 0.0, $79 = 0.0, $8 = 0.0, $80 = 0, $81 = 0.0, $82 = 0.0, $83 = 0, $84 = 0.0, $85 = 0.0, $86 = 0, $87 = 0.0, $88 = 0.0, $89 = 0.0, $9 = 0, $90 = 0.0, $91 = 0.0, $92 = 0.0, $93 = 0.0, $94 = 0.0;
 var $95 = 0.0, $96 = 0.0, $97 = 0.0, $98 = 0.0, $99 = 0.0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(144|0);
 $4 = sp + 128|0;
 $5 = sp;
 $6 = +HEAPF64[$2>>3];
 $7 = +HEAPF64[$1>>3];
 $8 = $7 + -9.9999999999999995E-7;
 $9 = $6 < $8;
 if ($9) {
  $10 = $6 != -3.4028234663852886E+38;
  $11 = $7 != 3.4028234663852886E+38;
  $or$cond = $10 | $11;
  if (!($or$cond)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $12 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
  if (!($12)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $13 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
  $14 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($13,115226,65)|0);
  $15 = +HEAPF64[$1>>3];
  $16 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEd($14,$15)|0);
  $17 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($16,115292,9)|0);
  $18 = +HEAPF64[$2>>3];
  $19 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEd($17,$18)|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = ((($20)) + -12|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = (($19) + ($22)|0);
  __ZNKSt3__28ios_base6getlocEv($4,$23);
  __THREW__ = 0;
  $24 = (invoke_iii(3255,($4|0),(215188|0))|0);
  $25 = __THREW__; __THREW__ = 0;
  $26 = $25&1;
  if (!($26)) {
   $27 = HEAP32[$24>>2]|0;
   $28 = ((($27)) + 28|0);
   $29 = HEAP32[$28>>2]|0;
   __THREW__ = 0;
   $30 = (invoke_iii($29|0,($24|0),10)|0);
   $31 = __THREW__; __THREW__ = 0;
   $32 = $31&1;
   if (!($32)) {
    __ZNSt3__26localeD2Ev($4);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($19,$30)|0);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($19)|0);
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
  }
  $33 = ___cxa_find_matching_catch_2()|0;
  $34 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3263,($4|0));
  $35 = __THREW__; __THREW__ = 0;
  $36 = $35&1;
  if ($36) {
   $37 = ___cxa_find_matching_catch_3(0|0)|0;
   $38 = tempRet0;
   ___clang_call_terminate($37);
   // unreachable;
  } else {
   ___resumeException($33|0);
   // unreachable;
  }
 } else {
  $39 = $7 + 9.9999999999999995E-7;
  $40 = $6 < $39;
  $41 = $6 + $7;
  $42 = $41 * 0.5;
  if ($40) {
   $43 = $42 + 9.9999999999999995E-7;
   $44 = $42 + -9.9999999999999995E-7;
   HEAPF64[$1>>3] = $44;
   HEAPF64[$2>>3] = $43;
   $59 = $43;
  } else {
   $59 = $6;
  }
  $45 = ((($0)) + 24|0);
  $46 = +HEAPF64[$45>>3];
  $47 = (+Math_abs((+$46)));
  $48 = $47 < 9.9999999999999995E-7;
  if ($48) {
   $49 = ((($0)) + 56|0);
   $50 = +HEAPF64[$49>>3];
   $51 = (+Math_abs((+$50)));
   $52 = $51 < 9.9999999999999995E-7;
   if ($52) {
    $53 = ((($0)) + 88|0);
    $54 = +HEAPF64[$53>>3];
    $55 = (+Math_abs((+$54)));
    $56 = $55 < 9.9999999999999995E-7;
    if ($56) {
     $57 = +HEAPF64[$1>>3];
     $58 = $59 - $57;
     $60 = $58 * 0.02;
     $61 = $60 < 1.0;
     $$0114 = $61 ? 1.0 : $60;
     $62 = $57 - $$0114;
     $63 = $59 + $$0114;
     HEAPF64[$1>>3] = $62;
     HEAPF64[$2>>3] = $63;
     $64 = $63 - $62;
     $65 = -2.0 / $64;
     $66 = ((($0)) + 80|0);
     HEAPF64[$66>>3] = $65;
     $67 = $63 + $62;
     $68 = -$67;
     $69 = $68 / $64;
     $70 = ((($0)) + 112|0);
     HEAPF64[$70>>3] = $69;
     $$0 = 1;
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
  $71 = +HEAPF64[$1>>3];
  $72 = $71 * 0.97999999999999998;
  $73 = $59 * 1.02;
  $74 = $59 * $3;
  $75 = $72 < $74;
  $$0115 = $75 ? $74 : $72;
  HEAPF64[$1>>3] = $$0115;
  HEAPF64[$2>>3] = $73;
  $76 = -$$0115;
  $77 = ((($0)) + 80|0);
  $78 = +HEAPF64[$77>>3];
  $79 = $78 * $76;
  $80 = ((($0)) + 112|0);
  $81 = +HEAPF64[$80>>3];
  $82 = $79 + $81;
  $83 = ((($0)) + 88|0);
  $84 = +HEAPF64[$83>>3];
  $85 = $84 * $76;
  $86 = ((($0)) + 120|0);
  $87 = +HEAPF64[$86>>3];
  $88 = $85 + $87;
  $89 = $82 / $88;
  $90 = -$73;
  $91 = $78 * $90;
  $92 = $91 + $81;
  $93 = $84 * $90;
  $94 = $93 + $87;
  $95 = $92 / $94;
  $96 = $89 - $95;
  $97 = 2.0 / $96;
  $98 = (+Math_abs((+$97)));
  $99 = $89 + $95;
  $100 = $99 * -0.5;
  $101 = $98 * $100;
  __ZN3osg7MatrixdC2Edddddddddddddddd($5,1.0,0.0,0.0,0.0,0.0,1.0,0.0,0.0,0.0,0.0,$98,0.0,0.0,0.0,$101,1.0);
  __THREW__ = 0;
  invoke_vii(3302,($0|0),($5|0));
  $102 = __THREW__; __THREW__ = 0;
  $103 = $102&1;
  if ($103) {
   $104 = ___cxa_find_matching_catch_2()|0;
   $105 = tempRet0;
   ___resumeException($104|0);
   // unreachable;
  }
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 return (0)|0;
}
function __Z22_clampProjectionMatrixIN3osg7MatrixfEdEbRT_RdS4_T0_($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = +$3;
 var $$0115 = 0, $$0116 = 0.0, $$0117 = 0.0, $10 = 0, $100 = 0.0, $101 = 0.0, $102 = 0.0, $103 = 0.0, $104 = 0.0, $105 = 0.0, $106 = 0.0, $107 = 0.0, $108 = 0.0, $109 = 0.0, $11 = 0, $110 = 0.0, $111 = 0.0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0.0, $17 = 0, $18 = 0, $19 = 0.0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0.0, $41 = 0, $42 = 0.0, $43 = 0.0, $44 = 0.0, $45 = 0.0, $46 = 0, $47 = 0.0;
 var $48 = 0.0, $49 = 0.0, $5 = 0, $50 = 0, $51 = 0, $52 = 0.0, $53 = 0.0, $54 = 0.0, $55 = 0, $56 = 0, $57 = 0.0, $58 = 0.0, $59 = 0.0, $6 = 0, $60 = 0, $61 = 0.0, $62 = 0.0, $63 = 0.0, $64 = 0.0, $65 = 0;
 var $66 = 0.0, $67 = 0.0, $68 = 0.0, $69 = 0.0, $7 = 0.0, $70 = 0.0, $71 = 0, $72 = 0.0, $73 = 0.0, $74 = 0.0, $75 = 0.0, $76 = 0, $77 = 0.0, $78 = 0.0, $79 = 0.0, $8 = 0.0, $80 = 0.0, $81 = 0, $82 = 0.0, $83 = 0;
 var $84 = 0.0, $85 = 0.0, $86 = 0.0, $87 = 0, $88 = 0.0, $89 = 0.0, $9 = 0.0, $90 = 0.0, $91 = 0, $92 = 0.0, $93 = 0.0, $94 = 0.0, $95 = 0, $96 = 0.0, $97 = 0.0, $98 = 0.0, $99 = 0.0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 208|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(208|0);
 $4 = sp + 192|0;
 $5 = sp + 128|0;
 $6 = sp;
 $7 = +HEAPF64[$2>>3];
 $8 = +HEAPF64[$1>>3];
 $9 = $8 + -9.9999999999999995E-7;
 $10 = $7 < $9;
 if ($10) {
  $11 = $7 != -3.4028234663852886E+38;
  $12 = $8 != 3.4028234663852886E+38;
  $or$cond = $11 | $12;
  if (!($or$cond)) {
   $$0115 = 0;
   STACKTOP = sp;return ($$0115|0);
  }
  $13 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
  if (!($13)) {
   $$0115 = 0;
   STACKTOP = sp;return ($$0115|0);
  }
  $14 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
  $15 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($14,115226,65)|0);
  $16 = +HEAPF64[$1>>3];
  $17 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEd($15,$16)|0);
  $18 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($17,115292,9)|0);
  $19 = +HEAPF64[$2>>3];
  $20 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEd($18,$19)|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = ((($21)) + -12|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (($20) + ($23)|0);
  __ZNKSt3__28ios_base6getlocEv($4,$24);
  __THREW__ = 0;
  $25 = (invoke_iii(3255,($4|0),(215188|0))|0);
  $26 = __THREW__; __THREW__ = 0;
  $27 = $26&1;
  if (!($27)) {
   $28 = HEAP32[$25>>2]|0;
   $29 = ((($28)) + 28|0);
   $30 = HEAP32[$29>>2]|0;
   __THREW__ = 0;
   $31 = (invoke_iii($30|0,($25|0),10)|0);
   $32 = __THREW__; __THREW__ = 0;
   $33 = $32&1;
   if (!($33)) {
    __ZNSt3__26localeD2Ev($4);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($20,$31)|0);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($20)|0);
    $$0115 = 0;
    STACKTOP = sp;return ($$0115|0);
   }
  }
  $34 = ___cxa_find_matching_catch_2()|0;
  $35 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3263,($4|0));
  $36 = __THREW__; __THREW__ = 0;
  $37 = $36&1;
  if ($37) {
   $38 = ___cxa_find_matching_catch_3(0|0)|0;
   $39 = tempRet0;
   ___clang_call_terminate($38);
   // unreachable;
  } else {
   ___resumeException($34|0);
   // unreachable;
  }
 }
 $40 = $8 + 9.9999999999999995E-7;
 $41 = $7 < $40;
 $42 = $7 + $8;
 $43 = $42 * 0.5;
 if ($41) {
  $44 = $43 + 9.9999999999999995E-7;
  $45 = $43 + -9.9999999999999995E-7;
  HEAPF64[$1>>3] = $45;
  HEAPF64[$2>>3] = $44;
  $63 = $44;
 } else {
  $63 = $7;
 }
 $46 = ((($0)) + 12|0);
 $47 = +HEAPF32[$46>>2];
 $48 = (+Math_abs((+$47)));
 $49 = $48;
 $50 = $49 < 9.9999999999999995E-7;
 if ($50) {
  $51 = ((($0)) + 28|0);
  $52 = +HEAPF32[$51>>2];
  $53 = (+Math_abs((+$52)));
  $54 = $53;
  $55 = $54 < 9.9999999999999995E-7;
  if ($55) {
   $56 = ((($0)) + 44|0);
   $57 = +HEAPF32[$56>>2];
   $58 = (+Math_abs((+$57)));
   $59 = $58;
   $60 = $59 < 9.9999999999999995E-7;
   if ($60) {
    $61 = +HEAPF64[$1>>3];
    $62 = $63 - $61;
    $64 = $62 * 0.02;
    $65 = $64 < 1.0;
    $$0116 = $65 ? 1.0 : $64;
    $66 = $61 - $$0116;
    $67 = $63 + $$0116;
    HEAPF64[$1>>3] = $66;
    HEAPF64[$2>>3] = $67;
    $68 = $67 - $66;
    $69 = -2.0 / $68;
    $70 = $69;
    $71 = ((($0)) + 40|0);
    HEAPF32[$71>>2] = $70;
    $72 = $67 + $66;
    $73 = -$72;
    $74 = $73 / $68;
    $75 = $74;
    $76 = ((($0)) + 56|0);
    HEAPF32[$76>>2] = $75;
    $$0115 = 1;
    STACKTOP = sp;return ($$0115|0);
   }
  }
 }
 $77 = +HEAPF64[$1>>3];
 $78 = $77 * 0.97999999999999998;
 $79 = $63 * 1.02;
 $80 = $63 * $3;
 $81 = $78 < $80;
 $$0117 = $81 ? $80 : $78;
 HEAPF64[$1>>3] = $$0117;
 HEAPF64[$2>>3] = $79;
 $82 = -$$0117;
 $83 = ((($0)) + 40|0);
 $84 = +HEAPF32[$83>>2];
 $85 = $84;
 $86 = $85 * $82;
 $87 = ((($0)) + 56|0);
 $88 = +HEAPF32[$87>>2];
 $89 = $88;
 $90 = $86 + $89;
 $91 = ((($0)) + 44|0);
 $92 = +HEAPF32[$91>>2];
 $93 = $92;
 $94 = $93 * $82;
 $95 = ((($0)) + 60|0);
 $96 = +HEAPF32[$95>>2];
 $97 = $96;
 $98 = $94 + $97;
 $99 = $90 / $98;
 $100 = -$79;
 $101 = $85 * $100;
 $102 = $101 + $89;
 $103 = $93 * $100;
 $104 = $103 + $97;
 $105 = $102 / $104;
 $106 = $99 - $105;
 $107 = 2.0 / $106;
 $108 = (+Math_abs((+$107)));
 $109 = $99 + $105;
 $110 = $109 * -0.5;
 $111 = $108 * $110;
 __ZN3osg7MatrixdC2Edddddddddddddddd($6,1.0,0.0,0.0,0.0,0.0,1.0,0.0,0.0,0.0,0.0,$108,0.0,0.0,0.0,$111,1.0);
 __THREW__ = 0;
 invoke_vii(3632,($5|0),($6|0));
 $112 = __THREW__; __THREW__ = 0;
 $113 = $112&1;
 if ($113) {
  $116 = ___cxa_find_matching_catch_2()|0;
  $117 = tempRet0;
  ___resumeException($116|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_vii(3633,($0|0),($5|0));
 $114 = __THREW__; __THREW__ = 0;
 $115 = $114&1;
 if ($115) {
  $116 = ___cxa_find_matching_catch_2()|0;
  $117 = tempRet0;
  ___resumeException($116|0);
  // unreachable;
 }
 $$0115 = 1;
 STACKTOP = sp;return ($$0115|0);
}
function __ZN7osgUtil11CullVisitor16computeNearPlaneEv($0) {
 $0 = $0|0;
 var $$0$i$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i$i = 0, $$0$i$i$i$i$i$i16 = 0, $$0$i$i$i$i$i$i22 = 0, $$0$i$i$i$i$i$i28 = 0, $$0$i$i$i$i$i15 = 0, $$0$i$i$i$i$i18 = 0, $$0$i$i$i$i$i24 = 0, $$0$i$i$i$i$i30 = 0, $$0$i$i$i$i34 = 0, $$08$i$i$i$i = 0, $$08$i$i$i$i$i = 0, $$08$i$i$i$i$i20 = 0, $$08$i$i$i$i$i26 = 0, $$08$i$i$i$i$i32 = 0, $$pre = 0.0, $$sink62 = 0, $$sroa$049$0$be = 0, $$sroa$049$063 = 0;
 var $1 = 0, $10 = 0.0, $11 = 0, $12 = 0.0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0.0, $19 = 0.0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0.0, $56 = 0.0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0.0, $85 = 0.0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 480|0);
 $2 = ((($0)) + 488|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if (!($4)) {
  $5 = HEAP32[$1>>2]|0;
  $6 = ((($0)) + 484|0);
  $7 = ($5|0)==($6|0);
  L3: do {
   if (!($7)) {
    $8 = ((($0)) + 408|0);
    $$pre = +HEAPF64[$8>>3];
    $$sroa$049$063 = $5;$12 = $$pre;
    while(1) {
     $9 = ((($$sroa$049$063)) + 16|0);
     $10 = +HEAPF64[$9>>3];
     $11 = $10 < $12;
     if (!($11)) {
      break L3;
     }
     $14 = ((($$sroa$049$063)) + 24|0);
     $15 = ((($$sroa$049$063)) + 156|0);
     $16 = ((($$sroa$049$063)) + 152|0);
     $17 = HEAP32[$16>>2]|0;
     $18 = (+__ZN7osgUtil11CullVisitor28computeNearestPointInFrustumERKN3osg7MatrixdERKNSt3__26vectorINS1_5PlaneENS5_9allocatorIS7_EEEERKNS1_8DrawableE(0,$14,$15,$17));
     $19 = +HEAPF64[$8>>3];
     $20 = $18 < $19;
     if ($20) {
      HEAPF64[$8>>3] = $18;
      $98 = $18;
     } else {
      $98 = $19;
     }
     $21 = ((($$sroa$049$063)) + 4|0);
     $22 = HEAP32[$21>>2]|0;
     $23 = ($22|0)==(0|0);
     if ($23) {
      $24 = ((($$sroa$049$063)) + 8|0);
      $25 = HEAP32[$24>>2]|0;
      $26 = HEAP32[$25>>2]|0;
      $27 = ($26|0)==($$sroa$049$063|0);
      if ($27) {
       $$sroa$049$0$be = $25;
      } else {
       $32 = $24;
       while(1) {
        $31 = HEAP32[$32>>2]|0;
        $33 = ((($31)) + 8|0);
        $34 = HEAP32[$33>>2]|0;
        $35 = HEAP32[$34>>2]|0;
        $36 = ($35|0)==($31|0);
        if ($36) {
         $$sroa$049$0$be = $34;
         break;
        } else {
         $32 = $33;
        }
       }
      }
     } else {
      $$0$i$i$i$i34 = $22;
      while(1) {
       $29 = HEAP32[$$0$i$i$i$i34>>2]|0;
       $30 = ($29|0)==(0|0);
       if ($30) {
        break;
       } else {
        $$0$i$i$i$i34 = $29;
       }
      }
      $$sroa$049$0$be = $$0$i$i$i$i34;
     }
     $28 = ($$sroa$049$0$be|0)==($6|0);
     if ($28) {
      break;
     } else {
      $$sroa$049$063 = $$sroa$049$0$be;$12 = $98;
     }
    }
   }
  } while(0);
  $13 = HEAP32[$6>>2]|0;
  __ZNSt3__26__treeINS_12__value_typeIdN7osgUtil11CullVisitor21MatrixPlanesDrawablesEEENS_19__map_value_compareIdS5_NS_4lessIdEELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($1,$13);
  HEAP32[$2>>2] = 0;
  HEAP32[$1>>2] = $6;
  HEAP32[$6>>2] = 0;
 }
 $37 = ((($0)) + 492|0);
 $38 = ((($0)) + 500|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = ($39|0)==(0);
 if ($40) {
  return;
 }
 $41 = ((($0)) + 496|0);
 $42 = HEAP32[$37>>2]|0;
 $43 = ($41|0)==($42|0);
 L24: do {
  if (!($43)) {
   $44 = ((($0)) + 416|0);
   $$sink62 = $41;
   while(1) {
    $45 = HEAP32[$$sink62>>2]|0;
    $46 = ($45|0)==(0|0);
    if ($46) {
     $$0$i$i$i$i$i30 = $$sink62;
     while(1) {
      $50 = ((($$0$i$i$i$i$i30)) + 8|0);
      $51 = HEAP32[$50>>2]|0;
      $52 = HEAP32[$51>>2]|0;
      $53 = ($52|0)==($$0$i$i$i$i$i30|0);
      if ($53) {
       $$0$i$i$i$i$i30 = $51;
      } else {
       $$08$i$i$i$i$i32 = $51;
       break;
      }
     }
    } else {
     $$0$i$i$i$i$i$i28 = $45;
     while(1) {
      $47 = ((($$0$i$i$i$i$i$i28)) + 4|0);
      $48 = HEAP32[$47>>2]|0;
      $49 = ($48|0)==(0|0);
      if ($49) {
       $$08$i$i$i$i$i32 = $$0$i$i$i$i$i$i28;
       break;
      } else {
       $$0$i$i$i$i$i$i28 = $48;
      }
     }
    }
    $54 = ((($$08$i$i$i$i$i32)) + 16|0);
    $55 = +HEAPF64[$54>>3];
    $56 = +HEAPF64[$44>>3];
    $57 = $55 > $56;
    if (!($57)) {
     break L24;
    }
    if ($46) {
     $$0$i$i$i$i$i24 = $$sink62;
     while(1) {
      $62 = ((($$0$i$i$i$i$i24)) + 8|0);
      $63 = HEAP32[$62>>2]|0;
      $64 = HEAP32[$63>>2]|0;
      $65 = ($64|0)==($$0$i$i$i$i$i24|0);
      if ($65) {
       $$0$i$i$i$i$i24 = $63;
      } else {
       $$08$i$i$i$i$i26 = $63;
       break;
      }
     }
    } else {
     $$0$i$i$i$i$i$i22 = $45;
     while(1) {
      $59 = ((($$0$i$i$i$i$i$i22)) + 4|0);
      $60 = HEAP32[$59>>2]|0;
      $61 = ($60|0)==(0|0);
      if ($61) {
       $$08$i$i$i$i$i26 = $$0$i$i$i$i$i$i22;
       break;
      } else {
       $$0$i$i$i$i$i$i22 = $60;
      }
     }
    }
    $66 = ((($$08$i$i$i$i$i26)) + 24|0);
    if ($46) {
     $$0$i$i$i$i$i18 = $$sink62;
     while(1) {
      $70 = ((($$0$i$i$i$i$i18)) + 8|0);
      $71 = HEAP32[$70>>2]|0;
      $72 = HEAP32[$71>>2]|0;
      $73 = ($72|0)==($$0$i$i$i$i$i18|0);
      if ($73) {
       $$0$i$i$i$i$i18 = $71;
      } else {
       $$08$i$i$i$i$i20 = $71;
       break;
      }
     }
    } else {
     $$0$i$i$i$i$i$i16 = $45;
     while(1) {
      $67 = ((($$0$i$i$i$i$i$i16)) + 4|0);
      $68 = HEAP32[$67>>2]|0;
      $69 = ($68|0)==(0|0);
      if ($69) {
       $$08$i$i$i$i$i20 = $$0$i$i$i$i$i$i16;
       break;
      } else {
       $$0$i$i$i$i$i$i16 = $68;
      }
     }
    }
    $74 = ((($$08$i$i$i$i$i20)) + 156|0);
    if ($46) {
     $$0$i$i$i$i$i15 = $$sink62;
     while(1) {
      $78 = ((($$0$i$i$i$i$i15)) + 8|0);
      $79 = HEAP32[$78>>2]|0;
      $80 = HEAP32[$79>>2]|0;
      $81 = ($80|0)==($$0$i$i$i$i$i15|0);
      if ($81) {
       $$0$i$i$i$i$i15 = $79;
      } else {
       $$08$i$i$i$i$i = $79;
       break;
      }
     }
    } else {
     $$0$i$i$i$i$i$i = $45;
     while(1) {
      $75 = ((($$0$i$i$i$i$i$i)) + 4|0);
      $76 = HEAP32[$75>>2]|0;
      $77 = ($76|0)==(0|0);
      if ($77) {
       $$08$i$i$i$i$i = $$0$i$i$i$i$i$i;
       break;
      } else {
       $$0$i$i$i$i$i$i = $76;
      }
     }
    }
    $82 = ((($$08$i$i$i$i$i)) + 152|0);
    $83 = HEAP32[$82>>2]|0;
    $84 = (+__ZN7osgUtil11CullVisitor29computeFurthestPointInFrustumERKN3osg7MatrixdERKNSt3__26vectorINS1_5PlaneENS5_9allocatorIS7_EEEERKNS1_8DrawableE(0,$66,$74,$83));
    $85 = +HEAPF64[$44>>3];
    $86 = $84 > $85;
    if ($86) {
     HEAPF64[$44>>3] = $84;
    }
    $87 = HEAP32[$$sink62>>2]|0;
    $88 = ($87|0)==(0|0);
    if ($88) {
     $$0$i$i$i$i = $$sink62;
     while(1) {
      $92 = ((($$0$i$i$i$i)) + 8|0);
      $93 = HEAP32[$92>>2]|0;
      $94 = HEAP32[$93>>2]|0;
      $95 = ($94|0)==($$0$i$i$i$i|0);
      if ($95) {
       $$0$i$i$i$i = $93;
      } else {
       $$08$i$i$i$i = $93;
       break;
      }
     }
    } else {
     $$0$i$i$i$i$i = $87;
     while(1) {
      $89 = ((($$0$i$i$i$i$i)) + 4|0);
      $90 = HEAP32[$89>>2]|0;
      $91 = ($90|0)==(0|0);
      if ($91) {
       $$08$i$i$i$i = $$0$i$i$i$i$i;
       break;
      } else {
       $$0$i$i$i$i$i = $90;
      }
     }
    }
    $96 = HEAP32[$37>>2]|0;
    $97 = ($$08$i$i$i$i|0)==($96|0);
    if ($97) {
     break;
    } else {
     $$sink62 = $$08$i$i$i$i;
    }
   }
  }
 } while(0);
 $58 = HEAP32[$41>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIdN7osgUtil11CullVisitor21MatrixPlanesDrawablesEEENS_19__map_value_compareIdS5_NS_4lessIdEELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($37,$58);
 HEAP32[$38>>2] = 0;
 HEAP32[$37>>2] = $41;
 HEAP32[$41>>2] = 0;
 return;
}
function __ZN7osgUtil11CullVisitor28computeNearestPointInFrustumERKN3osg7MatrixdERKNSt3__26vectorINS1_5PlaneENS5_9allocatorIS7_EEEERKNS1_8DrawableE($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0.0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $14 = 0.0, $15 = 0, $16 = 0, $17 = 0.0;
 var $18 = 0, $19 = 0, $20 = 0.0, $21 = 0, $22 = 0, $23 = 0.0, $24 = 0, $25 = 0, $26 = 0.0, $27 = 0, $28 = 0, $29 = 0.0, $30 = 0, $31 = 0, $32 = 0.0, $33 = 0, $34 = 0, $35 = 0.0, $36 = 0, $37 = 0;
 var $38 = 0.0, $39 = 0, $4 = 0, $40 = 0, $41 = 0.0, $42 = 0, $43 = 0, $44 = 0.0, $45 = 0, $46 = 0, $47 = 0.0, $48 = 0, $49 = 0, $5 = 0, $50 = 0.0, $51 = 0, $52 = 0, $53 = 0.0, $54 = 0, $55 = 0;
 var $56 = 0.0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0.0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i5 = 0, $scevgep$i$i$i4$i$i = 0, $scevgep$i$i$i4$i$i10 = 0, $scevgep$i$i$i9$i$i = 0, $scevgep$i$i$i9$i$i15 = 0, $scevgep5$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i6 = 0, $scevgep5$i$i$i10$i$i = 0, $scevgep5$i$i$i10$i$i16 = 0, $scevgep5$i$i$i5$i$i = 0, $scevgep5$i$i$i5$i$i11 = 0;
 var dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 208|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(208|0);
 $4 = sp;
 HEAP32[$4>>2] = (51932);
 $5 = ((($4)) + 8|0);
 $6 = ((($5)) + 8|0);
 HEAPF64[$6>>3] = 0.0;
 $7 = ((($5)) + 16|0);
 __ZN3osg7Matrixd12makeIdentityEv($7);
 $8 = ((($5)) + 144|0);
 dest=$8; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAP32[$4>>2] = (52044);
 $9 = ((($4)) + 192|0);
 HEAP32[$9>>2] = 0;
 $10 = ((($4)) + 196|0);
 HEAP32[$10>>2] = 0;
 HEAPF64[$6>>3] = 3.4028234663852886E+38;
 $11 = ($7|0)==($1|0);
 if (!($11)) {
  $12 = +HEAPF64[$1>>3];
  HEAPF64[$7>>3] = $12;
  $13 = ((($1)) + 8|0);
  $14 = +HEAPF64[$13>>3];
  $15 = ((($5)) + 24|0);
  HEAPF64[$15>>3] = $14;
  $16 = ((($1)) + 16|0);
  $17 = +HEAPF64[$16>>3];
  $18 = ((($5)) + 32|0);
  HEAPF64[$18>>3] = $17;
  $19 = ((($1)) + 24|0);
  $20 = +HEAPF64[$19>>3];
  $21 = ((($5)) + 40|0);
  HEAPF64[$21>>3] = $20;
  $22 = ((($1)) + 32|0);
  $23 = +HEAPF64[$22>>3];
  $24 = ((($5)) + 48|0);
  HEAPF64[$24>>3] = $23;
  $25 = ((($1)) + 40|0);
  $26 = +HEAPF64[$25>>3];
  $27 = ((($5)) + 56|0);
  HEAPF64[$27>>3] = $26;
  $28 = ((($1)) + 48|0);
  $29 = +HEAPF64[$28>>3];
  $30 = ((($5)) + 64|0);
  HEAPF64[$30>>3] = $29;
  $31 = ((($1)) + 56|0);
  $32 = +HEAPF64[$31>>3];
  $33 = ((($5)) + 72|0);
  HEAPF64[$33>>3] = $32;
  $34 = ((($1)) + 64|0);
  $35 = +HEAPF64[$34>>3];
  $36 = ((($5)) + 80|0);
  HEAPF64[$36>>3] = $35;
  $37 = ((($1)) + 72|0);
  $38 = +HEAPF64[$37>>3];
  $39 = ((($5)) + 88|0);
  HEAPF64[$39>>3] = $38;
  $40 = ((($1)) + 80|0);
  $41 = +HEAPF64[$40>>3];
  $42 = ((($5)) + 96|0);
  HEAPF64[$42>>3] = $41;
  $43 = ((($1)) + 88|0);
  $44 = +HEAPF64[$43>>3];
  $45 = ((($5)) + 104|0);
  HEAPF64[$45>>3] = $44;
  $46 = ((($1)) + 96|0);
  $47 = +HEAPF64[$46>>3];
  $48 = ((($5)) + 112|0);
  HEAPF64[$48>>3] = $47;
  $49 = ((($1)) + 104|0);
  $50 = +HEAPF64[$49>>3];
  $51 = ((($5)) + 120|0);
  HEAPF64[$51>>3] = $50;
  $52 = ((($1)) + 112|0);
  $53 = +HEAPF64[$52>>3];
  $54 = ((($5)) + 128|0);
  HEAPF64[$54>>3] = $53;
  $55 = ((($1)) + 120|0);
  $56 = +HEAPF64[$55>>3];
  $57 = ((($5)) + 136|0);
  HEAPF64[$57>>3] = $56;
 }
 HEAP32[$8>>2] = $2;
 $58 = HEAP32[$3>>2]|0;
 $59 = ((($58)) + 264|0);
 $60 = HEAP32[$59>>2]|0;
 __THREW__ = 0;
 invoke_vii($60|0,($3|0),($4|0));
 $61 = __THREW__; __THREW__ = 0;
 $62 = $61&1;
 if ($62) {
  $97 = ___cxa_find_matching_catch_2()|0;
  $98 = tempRet0;
  $99 = ((($5)) + 172|0);
  $100 = HEAP32[$99>>2]|0;
  $101 = ($100|0)==(0|0);
  if (!($101)) {
   $102 = ((($5)) + 176|0);
   $103 = HEAP32[$102>>2]|0;
   $104 = ($103|0)==($100|0);
   if (!($104)) {
    $scevgep$i$i$i$i$i5 = ((($103)) + -16|0);
    $105 = $scevgep$i$i$i$i$i5;
    $106 = $100;
    $107 = (($105) - ($106))|0;
    $108 = $107 >>> 4;
    $109 = $108 ^ -1;
    $scevgep5$i$i$i$i$i6 = (($103) + ($109<<4)|0);
    HEAP32[$102>>2] = $scevgep5$i$i$i$i$i6;
   }
   __ZdlPv($100);
  }
  $110 = ((($5)) + 160|0);
  $111 = HEAP32[$110>>2]|0;
  $112 = ($111|0)==(0|0);
  if (!($112)) {
   $113 = ((($5)) + 164|0);
   $114 = HEAP32[$113>>2]|0;
   $115 = ($114|0)==($111|0);
   if (!($115)) {
    $scevgep$i$i$i4$i$i10 = ((($114)) + -16|0);
    $116 = $scevgep$i$i$i4$i$i10;
    $117 = $111;
    $118 = (($116) - ($117))|0;
    $119 = $118 >>> 4;
    $120 = $119 ^ -1;
    $scevgep5$i$i$i5$i$i11 = (($114) + ($120<<4)|0);
    HEAP32[$113>>2] = $scevgep5$i$i$i5$i$i11;
   }
   __ZdlPv($111);
  }
  $121 = ((($5)) + 148|0);
  $122 = HEAP32[$121>>2]|0;
  $123 = ($122|0)==(0|0);
  if ($123) {
   ___resumeException($97|0);
   // unreachable;
  }
  $124 = ((($5)) + 152|0);
  $125 = HEAP32[$124>>2]|0;
  $126 = ($125|0)==($122|0);
  if (!($126)) {
   $scevgep$i$i$i9$i$i15 = ((($125)) + -16|0);
   $127 = $scevgep$i$i$i9$i$i15;
   $128 = $122;
   $129 = (($127) - ($128))|0;
   $130 = $129 >>> 4;
   $131 = $130 ^ -1;
   $scevgep5$i$i$i10$i$i16 = (($125) + ($131<<4)|0);
   HEAP32[$124>>2] = $scevgep5$i$i$i10$i$i16;
  }
  __ZdlPv($122);
  ___resumeException($97|0);
  // unreachable;
 } else {
  $63 = +HEAPF64[$6>>3];
  $64 = ((($5)) + 172|0);
  $65 = HEAP32[$64>>2]|0;
  $66 = ($65|0)==(0|0);
  if (!($66)) {
   $67 = ((($5)) + 176|0);
   $68 = HEAP32[$67>>2]|0;
   $69 = ($68|0)==($65|0);
   if (!($69)) {
    $scevgep$i$i$i$i$i = ((($68)) + -16|0);
    $70 = $scevgep$i$i$i$i$i;
    $71 = $65;
    $72 = (($70) - ($71))|0;
    $73 = $72 >>> 4;
    $74 = $73 ^ -1;
    $scevgep5$i$i$i$i$i = (($68) + ($74<<4)|0);
    HEAP32[$67>>2] = $scevgep5$i$i$i$i$i;
   }
   __ZdlPv($65);
  }
  $75 = ((($5)) + 160|0);
  $76 = HEAP32[$75>>2]|0;
  $77 = ($76|0)==(0|0);
  if (!($77)) {
   $78 = ((($5)) + 164|0);
   $79 = HEAP32[$78>>2]|0;
   $80 = ($79|0)==($76|0);
   if (!($80)) {
    $scevgep$i$i$i4$i$i = ((($79)) + -16|0);
    $81 = $scevgep$i$i$i4$i$i;
    $82 = $76;
    $83 = (($81) - ($82))|0;
    $84 = $83 >>> 4;
    $85 = $84 ^ -1;
    $scevgep5$i$i$i5$i$i = (($79) + ($85<<4)|0);
    HEAP32[$78>>2] = $scevgep5$i$i$i5$i$i;
   }
   __ZdlPv($76);
  }
  $86 = ((($5)) + 148|0);
  $87 = HEAP32[$86>>2]|0;
  $88 = ($87|0)==(0|0);
  if ($88) {
   STACKTOP = sp;return (+$63);
  }
  $89 = ((($5)) + 152|0);
  $90 = HEAP32[$89>>2]|0;
  $91 = ($90|0)==($87|0);
  if (!($91)) {
   $scevgep$i$i$i9$i$i = ((($90)) + -16|0);
   $92 = $scevgep$i$i$i9$i$i;
   $93 = $87;
   $94 = (($92) - ($93))|0;
   $95 = $94 >>> 4;
   $96 = $95 ^ -1;
   $scevgep5$i$i$i10$i$i = (($90) + ($96<<4)|0);
   HEAP32[$89>>2] = $scevgep5$i$i$i10$i$i;
  }
  __ZdlPv($87);
  STACKTOP = sp;return (+$63);
 }
 return +(0.0);
}
function __ZN7osgUtil11CullVisitor29computeFurthestPointInFrustumERKN3osg7MatrixdERKNSt3__26vectorINS1_5PlaneENS5_9allocatorIS7_EEEERKNS1_8DrawableE($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0.0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $14 = 0.0, $15 = 0, $16 = 0, $17 = 0.0;
 var $18 = 0, $19 = 0, $20 = 0.0, $21 = 0, $22 = 0, $23 = 0.0, $24 = 0, $25 = 0, $26 = 0.0, $27 = 0, $28 = 0, $29 = 0.0, $30 = 0, $31 = 0, $32 = 0.0, $33 = 0, $34 = 0, $35 = 0.0, $36 = 0, $37 = 0;
 var $38 = 0.0, $39 = 0, $4 = 0, $40 = 0, $41 = 0.0, $42 = 0, $43 = 0, $44 = 0.0, $45 = 0, $46 = 0, $47 = 0.0, $48 = 0, $49 = 0, $5 = 0, $50 = 0.0, $51 = 0, $52 = 0, $53 = 0.0, $54 = 0, $55 = 0;
 var $56 = 0.0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0.0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i5 = 0, $scevgep$i$i$i4$i$i = 0, $scevgep$i$i$i4$i$i10 = 0, $scevgep$i$i$i9$i$i = 0, $scevgep$i$i$i9$i$i15 = 0, $scevgep5$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i6 = 0, $scevgep5$i$i$i10$i$i = 0, $scevgep5$i$i$i10$i$i16 = 0, $scevgep5$i$i$i5$i$i = 0, $scevgep5$i$i$i5$i$i11 = 0;
 var dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 208|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(208|0);
 $4 = sp;
 HEAP32[$4>>2] = (51932);
 $5 = ((($4)) + 8|0);
 $6 = ((($5)) + 8|0);
 HEAPF64[$6>>3] = 0.0;
 $7 = ((($5)) + 16|0);
 __ZN3osg7Matrixd12makeIdentityEv($7);
 $8 = ((($5)) + 144|0);
 dest=$8; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAP32[$4>>2] = (51988);
 $9 = ((($4)) + 192|0);
 HEAP32[$9>>2] = 0;
 $10 = ((($4)) + 196|0);
 HEAP32[$10>>2] = 0;
 HEAPF64[$6>>3] = -3.4028234663852886E+38;
 $11 = ($7|0)==($1|0);
 if (!($11)) {
  $12 = +HEAPF64[$1>>3];
  HEAPF64[$7>>3] = $12;
  $13 = ((($1)) + 8|0);
  $14 = +HEAPF64[$13>>3];
  $15 = ((($5)) + 24|0);
  HEAPF64[$15>>3] = $14;
  $16 = ((($1)) + 16|0);
  $17 = +HEAPF64[$16>>3];
  $18 = ((($5)) + 32|0);
  HEAPF64[$18>>3] = $17;
  $19 = ((($1)) + 24|0);
  $20 = +HEAPF64[$19>>3];
  $21 = ((($5)) + 40|0);
  HEAPF64[$21>>3] = $20;
  $22 = ((($1)) + 32|0);
  $23 = +HEAPF64[$22>>3];
  $24 = ((($5)) + 48|0);
  HEAPF64[$24>>3] = $23;
  $25 = ((($1)) + 40|0);
  $26 = +HEAPF64[$25>>3];
  $27 = ((($5)) + 56|0);
  HEAPF64[$27>>3] = $26;
  $28 = ((($1)) + 48|0);
  $29 = +HEAPF64[$28>>3];
  $30 = ((($5)) + 64|0);
  HEAPF64[$30>>3] = $29;
  $31 = ((($1)) + 56|0);
  $32 = +HEAPF64[$31>>3];
  $33 = ((($5)) + 72|0);
  HEAPF64[$33>>3] = $32;
  $34 = ((($1)) + 64|0);
  $35 = +HEAPF64[$34>>3];
  $36 = ((($5)) + 80|0);
  HEAPF64[$36>>3] = $35;
  $37 = ((($1)) + 72|0);
  $38 = +HEAPF64[$37>>3];
  $39 = ((($5)) + 88|0);
  HEAPF64[$39>>3] = $38;
  $40 = ((($1)) + 80|0);
  $41 = +HEAPF64[$40>>3];
  $42 = ((($5)) + 96|0);
  HEAPF64[$42>>3] = $41;
  $43 = ((($1)) + 88|0);
  $44 = +HEAPF64[$43>>3];
  $45 = ((($5)) + 104|0);
  HEAPF64[$45>>3] = $44;
  $46 = ((($1)) + 96|0);
  $47 = +HEAPF64[$46>>3];
  $48 = ((($5)) + 112|0);
  HEAPF64[$48>>3] = $47;
  $49 = ((($1)) + 104|0);
  $50 = +HEAPF64[$49>>3];
  $51 = ((($5)) + 120|0);
  HEAPF64[$51>>3] = $50;
  $52 = ((($1)) + 112|0);
  $53 = +HEAPF64[$52>>3];
  $54 = ((($5)) + 128|0);
  HEAPF64[$54>>3] = $53;
  $55 = ((($1)) + 120|0);
  $56 = +HEAPF64[$55>>3];
  $57 = ((($5)) + 136|0);
  HEAPF64[$57>>3] = $56;
 }
 HEAP32[$8>>2] = $2;
 $58 = HEAP32[$3>>2]|0;
 $59 = ((($58)) + 264|0);
 $60 = HEAP32[$59>>2]|0;
 __THREW__ = 0;
 invoke_vii($60|0,($3|0),($4|0));
 $61 = __THREW__; __THREW__ = 0;
 $62 = $61&1;
 if ($62) {
  $97 = ___cxa_find_matching_catch_2()|0;
  $98 = tempRet0;
  $99 = ((($5)) + 172|0);
  $100 = HEAP32[$99>>2]|0;
  $101 = ($100|0)==(0|0);
  if (!($101)) {
   $102 = ((($5)) + 176|0);
   $103 = HEAP32[$102>>2]|0;
   $104 = ($103|0)==($100|0);
   if (!($104)) {
    $scevgep$i$i$i$i$i5 = ((($103)) + -16|0);
    $105 = $scevgep$i$i$i$i$i5;
    $106 = $100;
    $107 = (($105) - ($106))|0;
    $108 = $107 >>> 4;
    $109 = $108 ^ -1;
    $scevgep5$i$i$i$i$i6 = (($103) + ($109<<4)|0);
    HEAP32[$102>>2] = $scevgep5$i$i$i$i$i6;
   }
   __ZdlPv($100);
  }
  $110 = ((($5)) + 160|0);
  $111 = HEAP32[$110>>2]|0;
  $112 = ($111|0)==(0|0);
  if (!($112)) {
   $113 = ((($5)) + 164|0);
   $114 = HEAP32[$113>>2]|0;
   $115 = ($114|0)==($111|0);
   if (!($115)) {
    $scevgep$i$i$i4$i$i10 = ((($114)) + -16|0);
    $116 = $scevgep$i$i$i4$i$i10;
    $117 = $111;
    $118 = (($116) - ($117))|0;
    $119 = $118 >>> 4;
    $120 = $119 ^ -1;
    $scevgep5$i$i$i5$i$i11 = (($114) + ($120<<4)|0);
    HEAP32[$113>>2] = $scevgep5$i$i$i5$i$i11;
   }
   __ZdlPv($111);
  }
  $121 = ((($5)) + 148|0);
  $122 = HEAP32[$121>>2]|0;
  $123 = ($122|0)==(0|0);
  if ($123) {
   ___resumeException($97|0);
   // unreachable;
  }
  $124 = ((($5)) + 152|0);
  $125 = HEAP32[$124>>2]|0;
  $126 = ($125|0)==($122|0);
  if (!($126)) {
   $scevgep$i$i$i9$i$i15 = ((($125)) + -16|0);
   $127 = $scevgep$i$i$i9$i$i15;
   $128 = $122;
   $129 = (($127) - ($128))|0;
   $130 = $129 >>> 4;
   $131 = $130 ^ -1;
   $scevgep5$i$i$i10$i$i16 = (($125) + ($131<<4)|0);
   HEAP32[$124>>2] = $scevgep5$i$i$i10$i$i16;
  }
  __ZdlPv($122);
  ___resumeException($97|0);
  // unreachable;
 } else {
  $63 = +HEAPF64[$6>>3];
  $64 = ((($5)) + 172|0);
  $65 = HEAP32[$64>>2]|0;
  $66 = ($65|0)==(0|0);
  if (!($66)) {
   $67 = ((($5)) + 176|0);
   $68 = HEAP32[$67>>2]|0;
   $69 = ($68|0)==($65|0);
   if (!($69)) {
    $scevgep$i$i$i$i$i = ((($68)) + -16|0);
    $70 = $scevgep$i$i$i$i$i;
    $71 = $65;
    $72 = (($70) - ($71))|0;
    $73 = $72 >>> 4;
    $74 = $73 ^ -1;
    $scevgep5$i$i$i$i$i = (($68) + ($74<<4)|0);
    HEAP32[$67>>2] = $scevgep5$i$i$i$i$i;
   }
   __ZdlPv($65);
  }
  $75 = ((($5)) + 160|0);
  $76 = HEAP32[$75>>2]|0;
  $77 = ($76|0)==(0|0);
  if (!($77)) {
   $78 = ((($5)) + 164|0);
   $79 = HEAP32[$78>>2]|0;
   $80 = ($79|0)==($76|0);
   if (!($80)) {
    $scevgep$i$i$i4$i$i = ((($79)) + -16|0);
    $81 = $scevgep$i$i$i4$i$i;
    $82 = $76;
    $83 = (($81) - ($82))|0;
    $84 = $83 >>> 4;
    $85 = $84 ^ -1;
    $scevgep5$i$i$i5$i$i = (($79) + ($85<<4)|0);
    HEAP32[$78>>2] = $scevgep5$i$i$i5$i$i;
   }
   __ZdlPv($76);
  }
  $86 = ((($5)) + 148|0);
  $87 = HEAP32[$86>>2]|0;
  $88 = ($87|0)==(0|0);
  if ($88) {
   STACKTOP = sp;return (+$63);
  }
  $89 = ((($5)) + 152|0);
  $90 = HEAP32[$89>>2]|0;
  $91 = ($90|0)==($87|0);
  if (!($91)) {
   $scevgep$i$i$i9$i$i = ((($90)) + -16|0);
   $92 = $scevgep$i$i$i9$i$i;
   $93 = $87;
   $94 = (($92) - ($93))|0;
   $95 = $94 >>> 4;
   $96 = $95 ^ -1;
   $scevgep5$i$i$i10$i$i = (($90) + ($96<<4)|0);
   HEAP32[$89>>2] = $scevgep5$i$i$i10$i$i;
  }
  __ZdlPv($87);
  STACKTOP = sp;return (+$63);
 }
 return +(0.0);
}
function __ZN3osg24TemplatePrimitiveFunctorI21ComputeNearFarFunctorI17GreaterComparatorEED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i$i4$i = 0, $scevgep$i$i$i9$i = 0, $scevgep5$i$i$i$i = 0, $scevgep5$i$i$i10$i = 0, $scevgep5$i$i$i5$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 8|0);
 $2 = ((($1)) + 172|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = ((($1)) + 176|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==($3|0);
  if (!($7)) {
   $scevgep$i$i$i$i = ((($6)) + -16|0);
   $8 = $scevgep$i$i$i$i;
   $9 = $3;
   $10 = (($8) - ($9))|0;
   $11 = $10 >>> 4;
   $12 = $11 ^ -1;
   $scevgep5$i$i$i$i = (($6) + ($12<<4)|0);
   HEAP32[$5>>2] = $scevgep5$i$i$i$i;
  }
  __ZdlPv($3);
 }
 $13 = ((($1)) + 160|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(0|0);
 if (!($15)) {
  $16 = ((($1)) + 164|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = ($17|0)==($14|0);
  if (!($18)) {
   $scevgep$i$i$i4$i = ((($17)) + -16|0);
   $19 = $scevgep$i$i$i4$i;
   $20 = $14;
   $21 = (($19) - ($20))|0;
   $22 = $21 >>> 4;
   $23 = $22 ^ -1;
   $scevgep5$i$i$i5$i = (($17) + ($23<<4)|0);
   HEAP32[$16>>2] = $scevgep5$i$i$i5$i;
  }
  __ZdlPv($14);
 }
 $24 = ((($1)) + 148|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)==(0|0);
 if ($26) {
  return;
 }
 $27 = ((($1)) + 152|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = ($28|0)==($25|0);
 if (!($29)) {
  $scevgep$i$i$i9$i = ((($28)) + -16|0);
  $30 = $scevgep$i$i$i9$i;
  $31 = $25;
  $32 = (($30) - ($31))|0;
  $33 = $32 >>> 4;
  $34 = $33 ^ -1;
  $scevgep5$i$i$i10$i = (($28) + ($34<<4)|0);
  HEAP32[$27>>2] = $scevgep5$i$i$i10$i;
 }
 __ZdlPv($25);
 return;
}
function __ZN3osg24TemplatePrimitiveFunctorI21ComputeNearFarFunctorI17GreaterComparatorEED0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i4$i$i = 0, $scevgep$i$i$i9$i$i = 0, $scevgep5$i$i$i$i$i = 0, $scevgep5$i$i$i10$i$i = 0, $scevgep5$i$i$i5$i$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 8|0);
 $2 = ((($1)) + 172|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = ((($1)) + 176|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==($3|0);
  if (!($7)) {
   $scevgep$i$i$i$i$i = ((($6)) + -16|0);
   $8 = $scevgep$i$i$i$i$i;
   $9 = $3;
   $10 = (($8) - ($9))|0;
   $11 = $10 >>> 4;
   $12 = $11 ^ -1;
   $scevgep5$i$i$i$i$i = (($6) + ($12<<4)|0);
   HEAP32[$5>>2] = $scevgep5$i$i$i$i$i;
  }
  __ZdlPv($3);
 }
 $13 = ((($1)) + 160|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(0|0);
 if (!($15)) {
  $16 = ((($1)) + 164|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = ($17|0)==($14|0);
  if (!($18)) {
   $scevgep$i$i$i4$i$i = ((($17)) + -16|0);
   $19 = $scevgep$i$i$i4$i$i;
   $20 = $14;
   $21 = (($19) - ($20))|0;
   $22 = $21 >>> 4;
   $23 = $22 ^ -1;
   $scevgep5$i$i$i5$i$i = (($17) + ($23<<4)|0);
   HEAP32[$16>>2] = $scevgep5$i$i$i5$i$i;
  }
  __ZdlPv($14);
 }
 $24 = ((($1)) + 148|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)==(0|0);
 if ($26) {
  __ZdlPv($0);
  return;
 }
 $27 = ((($1)) + 152|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = ($28|0)==($25|0);
 if (!($29)) {
  $scevgep$i$i$i9$i$i = ((($28)) + -16|0);
  $30 = $scevgep$i$i$i9$i$i;
  $31 = $25;
  $32 = (($30) - ($31))|0;
  $33 = $32 >>> 4;
  $34 = $33 ^ -1;
  $scevgep5$i$i$i10$i$i = (($28) + ($34<<4)|0);
  HEAP32[$27>>2] = $scevgep5$i$i$i10$i$i;
 }
 __ZdlPv($25);
 __ZdlPv($0);
 return;
}
function __ZN3osg24TemplatePrimitiveFunctorI21ComputeNearFarFunctorI17GreaterComparatorEE14setVertexArrayEjPKNS_5Vec2fE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
 $5 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($4,115521,53)|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($6)) + -12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($5) + ($8)|0);
 __ZNKSt3__28ios_base6getlocEv($3,$9);
 __THREW__ = 0;
 $10 = (invoke_iii(3255,($3|0),(215188|0))|0);
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if (!($12)) {
  $13 = HEAP32[$10>>2]|0;
  $14 = ((($13)) + 28|0);
  $15 = HEAP32[$14>>2]|0;
  __THREW__ = 0;
  $16 = (invoke_iii($15|0,($10|0),10)|0);
  $17 = __THREW__; __THREW__ = 0;
  $18 = $17&1;
  if (!($18)) {
   __ZNSt3__26localeD2Ev($3);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($5,$16)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($5)|0);
   STACKTOP = sp;return;
  }
 }
 $19 = ___cxa_find_matching_catch_2()|0;
 $20 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($3|0));
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if ($22) {
  $23 = ___cxa_find_matching_catch_3(0|0)|0;
  $24 = tempRet0;
  ___clang_call_terminate($23);
  // unreachable;
 } else {
  ___resumeException($19|0);
  // unreachable;
 }
}
function __ZN3osg24TemplatePrimitiveFunctorI21ComputeNearFarFunctorI17GreaterComparatorEE14setVertexArrayEjPKNS_5Vec3fE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 192|0);
 HEAP32[$3>>2] = $1;
 $4 = ((($0)) + 196|0);
 HEAP32[$4>>2] = $2;
 return;
}
function __ZN3osg24TemplatePrimitiveFunctorI21ComputeNearFarFunctorI17GreaterComparatorEE14setVertexArrayEjPKNS_5Vec4fE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
 $5 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($4,115467,53)|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($6)) + -12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($5) + ($8)|0);
 __ZNKSt3__28ios_base6getlocEv($3,$9);
 __THREW__ = 0;
 $10 = (invoke_iii(3255,($3|0),(215188|0))|0);
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if (!($12)) {
  $13 = HEAP32[$10>>2]|0;
  $14 = ((($13)) + 28|0);
  $15 = HEAP32[$14>>2]|0;
  __THREW__ = 0;
  $16 = (invoke_iii($15|0,($10|0),10)|0);
  $17 = __THREW__; __THREW__ = 0;
  $18 = $17&1;
  if (!($18)) {
   __ZNSt3__26localeD2Ev($3);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($5,$16)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($5)|0);
   STACKTOP = sp;return;
  }
 }
 $19 = ___cxa_find_matching_catch_2()|0;
 $20 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($3|0));
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if ($22) {
  $23 = ___cxa_find_matching_catch_3(0|0)|0;
  $24 = tempRet0;
  ___clang_call_terminate($23);
  // unreachable;
 } else {
  ___resumeException($19|0);
  // unreachable;
 }
}
function __ZN3osg24TemplatePrimitiveFunctorI21ComputeNearFarFunctorI17GreaterComparatorEE14setVertexArrayEjPKNS_5Vec2dE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
 $5 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($4,115412,54)|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($6)) + -12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($5) + ($8)|0);
 __ZNKSt3__28ios_base6getlocEv($3,$9);
 __THREW__ = 0;
 $10 = (invoke_iii(3255,($3|0),(215188|0))|0);
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if (!($12)) {
  $13 = HEAP32[$10>>2]|0;
  $14 = ((($13)) + 28|0);
  $15 = HEAP32[$14>>2]|0;
  __THREW__ = 0;
  $16 = (invoke_iii($15|0,($10|0),10)|0);
  $17 = __THREW__; __THREW__ = 0;
  $18 = $17&1;
  if (!($18)) {
   __ZNSt3__26localeD2Ev($3);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($5,$16)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($5)|0);
   STACKTOP = sp;return;
  }
 }
 $19 = ___cxa_find_matching_catch_2()|0;
 $20 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($3|0));
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if ($22) {
  $23 = ___cxa_find_matching_catch_3(0|0)|0;
  $24 = tempRet0;
  ___clang_call_terminate($23);
  // unreachable;
 } else {
  ___resumeException($19|0);
  // unreachable;
 }
}
function __ZN3osg24TemplatePrimitiveFunctorI21ComputeNearFarFunctorI17GreaterComparatorEE14setVertexArrayEjPKNS_5Vec3dE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
 $5 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($4,115357,54)|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($6)) + -12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($5) + ($8)|0);
 __ZNKSt3__28ios_base6getlocEv($3,$9);
 __THREW__ = 0;
 $10 = (invoke_iii(3255,($3|0),(215188|0))|0);
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if (!($12)) {
  $13 = HEAP32[$10>>2]|0;
  $14 = ((($13)) + 28|0);
  $15 = HEAP32[$14>>2]|0;
  __THREW__ = 0;
  $16 = (invoke_iii($15|0,($10|0),10)|0);
  $17 = __THREW__; __THREW__ = 0;
  $18 = $17&1;
  if (!($18)) {
   __ZNSt3__26localeD2Ev($3);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($5,$16)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($5)|0);
   STACKTOP = sp;return;
  }
 }
 $19 = ___cxa_find_matching_catch_2()|0;
 $20 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($3|0));
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if ($22) {
  $23 = ___cxa_find_matching_catch_3(0|0)|0;
  $24 = tempRet0;
  ___clang_call_terminate($23);
  // unreachable;
 } else {
  ___resumeException($19|0);
  // unreachable;
 }
}
function __ZN3osg24TemplatePrimitiveFunctorI21ComputeNearFarFunctorI17GreaterComparatorEE14setVertexArrayEjPKNS_5Vec4dE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
 $5 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($4,115302,54)|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($6)) + -12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($5) + ($8)|0);
 __ZNKSt3__28ios_base6getlocEv($3,$9);
 __THREW__ = 0;
 $10 = (invoke_iii(3255,($3|0),(215188|0))|0);
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if (!($12)) {
  $13 = HEAP32[$10>>2]|0;
  $14 = ((($13)) + 28|0);
  $15 = HEAP32[$14>>2]|0;
  __THREW__ = 0;
  $16 = (invoke_iii($15|0,($10|0),10)|0);
  $17 = __THREW__; __THREW__ = 0;
  $18 = $17&1;
  if (!($18)) {
   __ZNSt3__26localeD2Ev($3);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($5,$16)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($5)|0);
   STACKTOP = sp;return;
  }
 }
 $19 = ___cxa_find_matching_catch_2()|0;
 $20 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($3|0));
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if ($22) {
  $23 = ___cxa_find_matching_catch_3(0|0)|0;
  $24 = tempRet0;
  ___clang_call_terminate($23);
  // unreachable;
 } else {
  ___resumeException($19|0);
  // unreachable;
 }
}
function __ZN3osg24TemplatePrimitiveFunctorI21ComputeNearFarFunctorI17GreaterComparatorEE10drawArraysEjii($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0131152 = 0, $$0132171 = 0, $$0133154 = 0, $$0134169 = 0, $$0135153 = 0, $$0136167 = 0, $$0137157 = 0, $$0138165 = 0, $$0139156 = 0, $$0140163 = 0, $$0141162 = 0, $$0142160 = 0, $$0143159 = 0, $$0173 = 0, $$pre = 0, $$pre$phiZ2D = 0, $$pre184 = 0.0, $$pre185 = 0.0, $$pre186 = 0.0, $$pre187 = 0.0;
 var $$pre188 = 0.0, $$sroa$015$019$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0.0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0.0, $62 = 0.0, $63 = 0.0, $64 = 0, $65 = 0.0;
 var $66 = 0.0, $67 = 0.0, $68 = 0.0, $69 = 0, $7 = 0, $70 = 0.0, $71 = 0.0, $72 = 0.0, $73 = 0.0, $74 = 0.0, $75 = 0.0, $76 = 0, $77 = 0.0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0.0, $87 = 0.0, $88 = 0, $89 = 0.0, $9 = 0, $90 = 0.0, $91 = 0.0, $92 = 0, $93 = 0.0, $94 = 0.0, $95 = 0.0, $96 = 0, $97 = 0.0, $98 = 0.0, $99 = 0.0, $exitcond = 0, $exitcond183 = 0, $not$$i = 0;
 var $or$cond = 0, $or$cond$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ((($0)) + 196|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 $7 = ($3|0)==(0);
 $or$cond = $7 | $6;
 if ($or$cond) {
  return;
 }
 do {
  switch ($1|0) {
  case 4:  {
   $8 = (($3) + ($2))|0;
   $9 = (($5) + (($8*12)|0)|0);
   $10 = ($3|0)>(0);
   if (!($10)) {
    return;
   }
   $11 = (($5) + (($2*12)|0)|0);
   $12 = ((($0)) + 8|0);
   $$0131152 = $11;
   while(1) {
    $13 = ((($$0131152)) + 12|0);
    $14 = ((($$0131152)) + 24|0);
    __ZN21ComputeNearFarFunctorI17GreaterComparatorEclERKN3osg5Vec3fES5_S5_b($12,$$0131152,$13,$14,0);
    $15 = ((($$0131152)) + 36|0);
    $16 = ($15>>>0)<($9>>>0);
    if ($16) {
     $$0131152 = $15;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 5:  {
   $17 = ($3|0)>(2);
   if (!($17)) {
    return;
   }
   $18 = (($5) + (($2*12)|0)|0);
   $19 = ((($0)) + 8|0);
   $$0133154 = $18;$$0135153 = 2;
   while(1) {
    $20 = $$0135153 & 1;
    $21 = ($20|0)==(0);
    if ($21) {
     $24 = ((($$0133154)) + 12|0);
     $25 = ((($$0133154)) + 24|0);
     __ZN21ComputeNearFarFunctorI17GreaterComparatorEclERKN3osg5Vec3fES5_S5_b($19,$$0133154,$24,$25,0);
     $$pre$phiZ2D = $24;
    } else {
     $22 = ((($$0133154)) + 24|0);
     $23 = ((($$0133154)) + 12|0);
     __ZN21ComputeNearFarFunctorI17GreaterComparatorEclERKN3osg5Vec3fES5_S5_b($19,$$0133154,$22,$23,0);
     $$pre$phiZ2D = $23;
    }
    $26 = (($$0135153) + 1)|0;
    $exitcond = ($26|0)==($3|0);
    if ($exitcond) {
     break;
    } else {
     $$0133154 = $$pre$phiZ2D;$$0135153 = $26;
    }
   }
   return;
   break;
  }
  case 7:  {
   $27 = ($3|0)>(3);
   if (!($27)) {
    return;
   }
   $28 = (($5) + (($2*12)|0)|0);
   $29 = ((($0)) + 8|0);
   $$0137157 = $28;$$0139156 = 3;
   while(1) {
    $30 = ((($$0137157)) + 12|0);
    $31 = ((($$0137157)) + 24|0);
    $32 = ((($$0137157)) + 36|0);
    __ZN21ComputeNearFarFunctorI17GreaterComparatorEclERKN3osg5Vec3fES5_S5_b($29,$$0137157,$30,$31,0);
    __ZN21ComputeNearFarFunctorI17GreaterComparatorEclERKN3osg5Vec3fES5_S5_b($29,$$0137157,$31,$32,0);
    $33 = (($$0139156) + 4)|0;
    $34 = ((($$0137157)) + 48|0);
    $35 = ($33|0)<($3|0);
    if ($35) {
     $$0137157 = $34;$$0139156 = $33;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 8:  {
   $36 = ($3|0)>(3);
   if (!($36)) {
    return;
   }
   $37 = (($5) + (($2*12)|0)|0);
   $38 = ((($0)) + 8|0);
   $$0142160 = $37;$$0143159 = 3;
   while(1) {
    $39 = ((($$0142160)) + 12|0);
    $40 = ((($$0142160)) + 36|0);
    $41 = ((($$0142160)) + 24|0);
    __ZN21ComputeNearFarFunctorI17GreaterComparatorEclERKN3osg5Vec3fES5_S5_b($38,$$0142160,$39,$40,0);
    __ZN21ComputeNearFarFunctorI17GreaterComparatorEclERKN3osg5Vec3fES5_S5_b($38,$$0142160,$40,$41,0);
    $42 = (($$0143159) + 2)|0;
    $43 = ($42|0)<($3|0);
    if ($43) {
     $$0142160 = $41;$$0143159 = $42;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 6: case 9:  {
   $44 = (($5) + (($2*12)|0)|0);
   $45 = ($3|0)>(2);
   if (!($45)) {
    return;
   }
   $46 = ((($44)) + 12|0);
   $47 = ((($0)) + 8|0);
   $$0140163 = 2;$$0141162 = $46;
   while(1) {
    $48 = ((($$0141162)) + 12|0);
    __ZN21ComputeNearFarFunctorI17GreaterComparatorEclERKN3osg5Vec3fES5_S5_b($47,$44,$$0141162,$48,0);
    $49 = (($$0140163) + 1)|0;
    $exitcond183 = ($49|0)==($3|0);
    if ($exitcond183) {
     break;
    } else {
     $$0140163 = $49;$$0141162 = $48;
    }
   }
   return;
   break;
  }
  case 0:  {
   $50 = (($3) + ($2))|0;
   $51 = (($5) + (($50*12)|0)|0);
   $52 = ($3|0)>(0);
   if (!($52)) {
    return;
   }
   $53 = (($5) + (($2*12)|0)|0);
   $54 = ((($0)) + 8|0);
   $55 = ((($54)) + 32|0);
   $56 = ((($54)) + 64|0);
   $57 = ((($54)) + 96|0);
   $58 = ((($54)) + 128|0);
   $59 = ((($54)) + 8|0);
   $60 = ((($54)) + 144|0);
   $$pre184 = +HEAPF64[$55>>3];
   $$pre185 = +HEAPF64[$56>>3];
   $$pre186 = +HEAPF64[$57>>3];
   $$pre187 = +HEAPF64[$58>>3];
   $$pre188 = +HEAPF64[$59>>3];
   $$0138165 = $53;$77 = $$pre188;
   while(1) {
    $61 = +HEAPF32[$$0138165>>2];
    $62 = $61;
    $63 = $62 * $$pre184;
    $64 = ((($$0138165)) + 4|0);
    $65 = +HEAPF32[$64>>2];
    $66 = $65;
    $67 = $66 * $$pre185;
    $68 = $63 + $67;
    $69 = ((($$0138165)) + 8|0);
    $70 = +HEAPF32[$69>>2];
    $71 = $70;
    $72 = $71 * $$pre186;
    $73 = $68 + $72;
    $74 = $$pre187 + $73;
    $75 = -$74;
    $76 = $77 >= $75;
    $78 = $74 > -0.0;
    $or$cond$i = $76 | $78;
    L50: do {
     if ($or$cond$i) {
      $138 = $77;
     } else {
      $79 = HEAP32[$60>>2]|0;
      $80 = HEAP32[$79>>2]|0;
      $81 = ((($79)) + 4|0);
      $82 = HEAP32[$81>>2]|0;
      $83 = ($80|0)==($82|0);
      if (!($83)) {
       $$sroa$015$019$i = $80;
       while(1) {
        $86 = +HEAPF64[$$sroa$015$019$i>>3];
        $87 = $62 * $86;
        $88 = ((($$sroa$015$019$i)) + 8|0);
        $89 = +HEAPF64[$88>>3];
        $90 = $66 * $89;
        $91 = $87 + $90;
        $92 = ((($$sroa$015$019$i)) + 16|0);
        $93 = +HEAPF64[$92>>3];
        $94 = $71 * $93;
        $95 = $91 + $94;
        $96 = ((($$sroa$015$019$i)) + 24|0);
        $97 = +HEAPF64[$96>>3];
        $98 = $97 + $95;
        $99 = $98;
        $not$$i = !($99 < 0.0);
        $84 = ((($$sroa$015$019$i)) + 40|0);
        if (!($not$$i)) {
         $138 = $77;
         break L50;
        }
        $85 = ($84|0)==($82|0);
        if ($85) {
         break;
        } else {
         $$sroa$015$019$i = $84;
        }
       }
      }
      HEAPF64[$59>>3] = $75;
      $138 = $75;
     }
    } while(0);
    $100 = ((($$0138165)) + 12|0);
    $101 = ($100>>>0)<($51>>>0);
    if ($101) {
     $$0138165 = $100;$77 = $138;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 1:  {
   $102 = (($2) + -1)|0;
   $103 = (($102) + ($3))|0;
   $104 = (($5) + (($103*12)|0)|0);
   $105 = ($103|0)>($2|0);
   if (!($105)) {
    return;
   }
   $106 = (($5) + (($2*12)|0)|0);
   $107 = ((($0)) + 8|0);
   $$0136167 = $106;
   while(1) {
    $108 = ((($$0136167)) + 12|0);
    __ZN21ComputeNearFarFunctorI17GreaterComparatorEclERKN3osg5Vec3fES5_b($107,$$0136167,$108,0);
    $109 = ((($$0136167)) + 24|0);
    $110 = ($109>>>0)<($104>>>0);
    if ($110) {
     $$0136167 = $109;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 3:  {
   $111 = (($2) + -1)|0;
   $112 = (($111) + ($3))|0;
   $113 = (($5) + (($112*12)|0)|0);
   $114 = ($112|0)>($2|0);
   if (!($114)) {
    return;
   }
   $115 = (($5) + (($2*12)|0)|0);
   $116 = ((($0)) + 8|0);
   $$0134169 = $115;
   while(1) {
    $117 = ((($$0134169)) + 12|0);
    __ZN21ComputeNearFarFunctorI17GreaterComparatorEclERKN3osg5Vec3fES5_b($116,$$0134169,$117,0);
    $118 = ($117>>>0)<($113>>>0);
    if ($118) {
     $$0134169 = $117;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 11:  {
   $119 = (($2) + -2)|0;
   $120 = (($119) + ($3))|0;
   $121 = (($5) + (($120*12)|0)|0);
   $122 = (($2) + 1)|0;
   $123 = ($122|0)<($120|0);
   if (!($123)) {
    return;
   }
   $124 = (($5) + (($122*12)|0)|0);
   $125 = ((($0)) + 8|0);
   $$0132171 = $124;
   while(1) {
    $126 = ((($$0132171)) + 12|0);
    __ZN21ComputeNearFarFunctorI17GreaterComparatorEclERKN3osg5Vec3fES5_b($125,$$0132171,$126,0);
    $127 = ($126>>>0)<($121>>>0);
    if ($127) {
     $$0132171 = $126;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 2:  {
   $128 = (($2) + -1)|0;
   $129 = (($128) + ($3))|0;
   $130 = (($5) + (($129*12)|0)|0);
   $131 = ($129|0)>($2|0);
   $132 = ((($0)) + 8|0);
   if ($131) {
    $133 = (($5) + (($2*12)|0)|0);
    $$0173 = $133;
    while(1) {
     $136 = ((($$0173)) + 12|0);
     __ZN21ComputeNearFarFunctorI17GreaterComparatorEclERKN3osg5Vec3fES5_b($132,$$0173,$136,0);
     $137 = ($136>>>0)<($130>>>0);
     if ($137) {
      $$0173 = $136;
     } else {
      break;
     }
    }
    $$pre = HEAP32[$4>>2]|0;
    $135 = $$pre;
   } else {
    $135 = $5;
   }
   $134 = (($135) + (($2*12)|0)|0);
   __ZN21ComputeNearFarFunctorI17GreaterComparatorEclERKN3osg5Vec3fES5_b($132,$130,$134,0);
   return;
   break;
  }
  default: {
   return;
  }
  }
 } while(0);
}
function __ZN3osg24TemplatePrimitiveFunctorI21ComputeNearFarFunctorI17GreaterComparatorEE12drawElementsEjiPKh($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg24TemplatePrimitiveFunctorI21ComputeNearFarFunctorI17GreaterComparatorEE20drawElementsTemplateIhEEvjiPKT_($0,$1,$2,$3);
 return;
}
function __ZN3osg24TemplatePrimitiveFunctorI21ComputeNearFarFunctorI17GreaterComparatorEE12drawElementsEjiPKt($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg24TemplatePrimitiveFunctorI21ComputeNearFarFunctorI17GreaterComparatorEE20drawElementsTemplateItEEvjiPKT_($0,$1,$2,$3);
 return;
}
function __ZN3osg24TemplatePrimitiveFunctorI21ComputeNearFarFunctorI17GreaterComparatorEE12drawElementsEjiPKj($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg24TemplatePrimitiveFunctorI21ComputeNearFarFunctorI17GreaterComparatorEE20drawElementsTemplateIjEEvjiPKT_($0,$1,$2,$3);
 return;
}
function __ZN3osg24TemplatePrimitiveFunctorI21ComputeNearFarFunctorI17GreaterComparatorEE20drawElementsTemplateIjEEvjiPKT_($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0133157 = 0, $$0134176 = 0, $$0135159 = 0, $$0136174 = 0, $$0137158 = 0, $$0138172 = 0, $$0139162 = 0, $$0140170 = 0, $$0141161 = 0, $$0143165 = 0, $$0145164 = 0, $$0178 = 0, $$lcssa156 = 0, $$pre = 0.0, $$pre190 = 0.0, $$pre191 = 0.0, $$pre192 = 0.0, $$pre193 = 0.0, $$pre195 = 0, $$sroa$015$019$i = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0.0, $107 = 0.0, $108 = 0.0, $109 = 0, $11 = 0, $110 = 0.0, $111 = 0.0, $112 = 0.0, $113 = 0.0, $114 = 0, $115 = 0.0, $116 = 0.0, $117 = 0.0;
 var $118 = 0.0, $119 = 0.0, $12 = 0, $120 = 0.0, $121 = 0, $122 = 0.0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0.0, $132 = 0.0, $133 = 0, $134 = 0.0, $135 = 0.0;
 var $136 = 0.0, $137 = 0, $138 = 0.0, $139 = 0.0, $14 = 0, $140 = 0.0, $141 = 0, $142 = 0.0, $143 = 0.0, $144 = 0.0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0;
 var $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0;
 var $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0;
 var $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0.0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $exitcond = 0, $exitcond189 = 0, $exitcond189212 = 0, $not$$i = 0, $or$cond = 0, $or$cond$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ($3|0)==(0|0);
 $5 = ($2|0)==(0);
 $or$cond = $5 | $4;
 if ($or$cond) {
  return;
 }
 do {
  switch ($1|0) {
  case 4:  {
   $15 = (($3) + ($2<<2)|0);
   $16 = ($2|0)>(0);
   if (!($16)) {
    return;
   }
   $17 = ((($0)) + 8|0);
   $18 = ((($0)) + 196|0);
   $$0133157 = $3;
   while(1) {
    $19 = HEAP32[$18>>2]|0;
    $20 = HEAP32[$$0133157>>2]|0;
    $21 = (($19) + (($20*12)|0)|0);
    $22 = ((($$0133157)) + 4|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = (($19) + (($23*12)|0)|0);
    $25 = ((($$0133157)) + 8|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = (($19) + (($26*12)|0)|0);
    __ZN21ComputeNearFarFunctorI17GreaterComparatorEclERKN3osg5Vec3fES5_S5_b($17,$21,$24,$27,0);
    $28 = ((($$0133157)) + 12|0);
    $29 = ($28>>>0)<($15>>>0);
    if ($29) {
     $$0133157 = $28;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 5:  {
   $12 = ($2|0)>(2);
   if (!($12)) {
    return;
   }
   $13 = ((($0)) + 8|0);
   $14 = ((($0)) + 196|0);
   $$0135159 = $3;$$0137158 = 2;
   while(1) {
    $30 = $$0137158 & 1;
    $31 = ($30|0)==(0);
    $32 = HEAP32[$14>>2]|0;
    $33 = HEAP32[$$0135159>>2]|0;
    $34 = (($32) + (($33*12)|0)|0);
    $35 = ((($$0135159)) + 4|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = ((($$0135159)) + 8|0);
    $38 = HEAP32[$37>>2]|0;
    if ($31) {
     $41 = (($32) + (($36*12)|0)|0);
     $42 = (($32) + (($38*12)|0)|0);
     __ZN21ComputeNearFarFunctorI17GreaterComparatorEclERKN3osg5Vec3fES5_S5_b($13,$34,$41,$42,0);
    } else {
     $39 = (($32) + (($38*12)|0)|0);
     $40 = (($32) + (($36*12)|0)|0);
     __ZN21ComputeNearFarFunctorI17GreaterComparatorEclERKN3osg5Vec3fES5_S5_b($13,$34,$39,$40,0);
    }
    $43 = (($$0137158) + 1)|0;
    $exitcond = ($43|0)==($2|0);
    if ($exitcond) {
     break;
    } else {
     $$0135159 = $35;$$0137158 = $43;
    }
   }
   return;
   break;
  }
  case 7:  {
   $9 = ($2|0)>(3);
   if (!($9)) {
    return;
   }
   $10 = ((($0)) + 8|0);
   $11 = ((($0)) + 196|0);
   $$0139162 = $3;$$0141161 = 3;
   while(1) {
    $44 = HEAP32[$11>>2]|0;
    $45 = HEAP32[$$0139162>>2]|0;
    $46 = (($44) + (($45*12)|0)|0);
    $47 = ((($$0139162)) + 4|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = (($44) + (($48*12)|0)|0);
    $50 = ((($$0139162)) + 8|0);
    $51 = HEAP32[$50>>2]|0;
    $52 = (($44) + (($51*12)|0)|0);
    $53 = ((($$0139162)) + 12|0);
    $54 = HEAP32[$53>>2]|0;
    $55 = (($44) + (($54*12)|0)|0);
    __ZN21ComputeNearFarFunctorI17GreaterComparatorEclERKN3osg5Vec3fES5_S5_b($10,$46,$49,$52,0);
    __ZN21ComputeNearFarFunctorI17GreaterComparatorEclERKN3osg5Vec3fES5_S5_b($10,$46,$52,$55,0);
    $56 = (($$0141161) + 4)|0;
    $57 = ((($$0139162)) + 16|0);
    $58 = ($56|0)<($2|0);
    if ($58) {
     $$0139162 = $57;$$0141161 = $56;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 8:  {
   $6 = ($2|0)>(3);
   if (!($6)) {
    return;
   }
   $7 = ((($0)) + 8|0);
   $8 = ((($0)) + 196|0);
   $$0143165 = $3;$$0145164 = 3;
   while(1) {
    $59 = HEAP32[$8>>2]|0;
    $60 = HEAP32[$$0143165>>2]|0;
    $61 = (($59) + (($60*12)|0)|0);
    $62 = ((($$0143165)) + 4|0);
    $63 = HEAP32[$62>>2]|0;
    $64 = (($59) + (($63*12)|0)|0);
    $65 = ((($$0143165)) + 12|0);
    $66 = HEAP32[$65>>2]|0;
    $67 = (($59) + (($66*12)|0)|0);
    $68 = ((($$0143165)) + 8|0);
    $69 = HEAP32[$68>>2]|0;
    $70 = (($59) + (($69*12)|0)|0);
    __ZN21ComputeNearFarFunctorI17GreaterComparatorEclERKN3osg5Vec3fES5_S5_b($7,$61,$64,$67,0);
    __ZN21ComputeNearFarFunctorI17GreaterComparatorEclERKN3osg5Vec3fES5_S5_b($7,$61,$67,$70,0);
    $71 = (($$0145164) + 2)|0;
    $72 = ($71|0)<($2|0);
    if ($72) {
     $$0143165 = $68;$$0145164 = $71;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 6: case 9:  {
   $73 = ((($0)) + 196|0);
   $74 = HEAP32[$73>>2]|0;
   $75 = HEAP32[$3>>2]|0;
   $76 = (($74) + (($75*12)|0)|0);
   $77 = ($2|0)>(2);
   if (!($77)) {
    return;
   }
   $78 = ((($3)) + 4|0);
   $79 = ((($0)) + 8|0);
   $80 = HEAP32[$78>>2]|0;
   $81 = (($74) + (($80*12)|0)|0);
   $82 = ((($3)) + 8|0);
   $83 = HEAP32[$82>>2]|0;
   $84 = (($74) + (($83*12)|0)|0);
   __ZN21ComputeNearFarFunctorI17GreaterComparatorEclERKN3osg5Vec3fES5_S5_b($79,$76,$81,$84,0);
   $exitcond189212 = ($2|0)==(3);
   if ($exitcond189212) {
    return;
   } else {
    $86 = $82;$92 = 3;
   }
   while(1) {
    $$pre195 = HEAP32[$73>>2]|0;
    $85 = HEAP32[$86>>2]|0;
    $87 = (($$pre195) + (($85*12)|0)|0);
    $88 = ((($86)) + 4|0);
    $89 = HEAP32[$88>>2]|0;
    $90 = (($$pre195) + (($89*12)|0)|0);
    __ZN21ComputeNearFarFunctorI17GreaterComparatorEclERKN3osg5Vec3fES5_S5_b($79,$76,$87,$90,0);
    $91 = (($92) + 1)|0;
    $exitcond189 = ($91|0)==($2|0);
    if ($exitcond189) {
     break;
    } else {
     $86 = $88;$92 = $91;
    }
   }
   return;
   break;
  }
  case 0:  {
   $93 = (($3) + ($2<<2)|0);
   $94 = ($2|0)>(0);
   if (!($94)) {
    return;
   }
   $95 = ((($0)) + 8|0);
   $96 = ((($0)) + 196|0);
   $97 = HEAP32[$96>>2]|0;
   $98 = ((($95)) + 32|0);
   $99 = ((($95)) + 64|0);
   $100 = ((($95)) + 96|0);
   $101 = ((($95)) + 128|0);
   $102 = ((($95)) + 8|0);
   $103 = ((($95)) + 144|0);
   $$pre = +HEAPF64[$98>>3];
   $$pre190 = +HEAPF64[$99>>3];
   $$pre191 = +HEAPF64[$100>>3];
   $$pre192 = +HEAPF64[$101>>3];
   $$pre193 = +HEAPF64[$102>>3];
   $$0140170 = $3;$122 = $$pre193;
   while(1) {
    $104 = HEAP32[$$0140170>>2]|0;
    $105 = (($97) + (($104*12)|0)|0);
    $106 = +HEAPF32[$105>>2];
    $107 = $106;
    $108 = $107 * $$pre;
    $109 = (((($97) + (($104*12)|0)|0)) + 4|0);
    $110 = +HEAPF32[$109>>2];
    $111 = $110;
    $112 = $111 * $$pre190;
    $113 = $108 + $112;
    $114 = (((($97) + (($104*12)|0)|0)) + 8|0);
    $115 = +HEAPF32[$114>>2];
    $116 = $115;
    $117 = $116 * $$pre191;
    $118 = $113 + $117;
    $119 = $$pre192 + $118;
    $120 = -$119;
    $121 = $122 >= $120;
    $123 = $119 > -0.0;
    $or$cond$i = $121 | $123;
    L52: do {
     if ($or$cond$i) {
      $203 = $122;
     } else {
      $124 = HEAP32[$103>>2]|0;
      $125 = HEAP32[$124>>2]|0;
      $126 = ((($124)) + 4|0);
      $127 = HEAP32[$126>>2]|0;
      $128 = ($125|0)==($127|0);
      if (!($128)) {
       $$sroa$015$019$i = $125;
       while(1) {
        $131 = +HEAPF64[$$sroa$015$019$i>>3];
        $132 = $107 * $131;
        $133 = ((($$sroa$015$019$i)) + 8|0);
        $134 = +HEAPF64[$133>>3];
        $135 = $111 * $134;
        $136 = $132 + $135;
        $137 = ((($$sroa$015$019$i)) + 16|0);
        $138 = +HEAPF64[$137>>3];
        $139 = $116 * $138;
        $140 = $136 + $139;
        $141 = ((($$sroa$015$019$i)) + 24|0);
        $142 = +HEAPF64[$141>>3];
        $143 = $142 + $140;
        $144 = $143;
        $not$$i = !($144 < 0.0);
        $129 = ((($$sroa$015$019$i)) + 40|0);
        if (!($not$$i)) {
         $203 = $122;
         break L52;
        }
        $130 = ($129|0)==($127|0);
        if ($130) {
         break;
        } else {
         $$sroa$015$019$i = $129;
        }
       }
      }
      HEAPF64[$102>>3] = $120;
      $203 = $120;
     }
    } while(0);
    $145 = ((($$0140170)) + 4|0);
    $146 = ($145>>>0)<($93>>>0);
    if ($146) {
     $$0140170 = $145;$122 = $203;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 1:  {
   $147 = (($2) + -1)|0;
   $148 = (($3) + ($147<<2)|0);
   $149 = ($2|0)>(1);
   if (!($149)) {
    return;
   }
   $150 = ((($0)) + 8|0);
   $151 = ((($0)) + 196|0);
   $$0138172 = $3;
   while(1) {
    $152 = HEAP32[$151>>2]|0;
    $153 = HEAP32[$$0138172>>2]|0;
    $154 = (($152) + (($153*12)|0)|0);
    $155 = ((($$0138172)) + 4|0);
    $156 = HEAP32[$155>>2]|0;
    $157 = (($152) + (($156*12)|0)|0);
    __ZN21ComputeNearFarFunctorI17GreaterComparatorEclERKN3osg5Vec3fES5_b($150,$154,$157,0);
    $158 = ((($$0138172)) + 8|0);
    $159 = ($158>>>0)<($148>>>0);
    if ($159) {
     $$0138172 = $158;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 3:  {
   $160 = (($2) + -1)|0;
   $161 = (($3) + ($160<<2)|0);
   $162 = ($2|0)>(1);
   if (!($162)) {
    return;
   }
   $163 = ((($0)) + 8|0);
   $164 = ((($0)) + 196|0);
   $$0136174 = $3;
   while(1) {
    $165 = HEAP32[$164>>2]|0;
    $166 = HEAP32[$$0136174>>2]|0;
    $167 = (($165) + (($166*12)|0)|0);
    $168 = ((($$0136174)) + 4|0);
    $169 = HEAP32[$168>>2]|0;
    $170 = (($165) + (($169*12)|0)|0);
    __ZN21ComputeNearFarFunctorI17GreaterComparatorEclERKN3osg5Vec3fES5_b($163,$167,$170,0);
    $171 = ($168>>>0)<($161>>>0);
    if ($171) {
     $$0136174 = $168;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 11:  {
   $172 = (($2) + -2)|0;
   $173 = (($3) + ($172<<2)|0);
   $174 = ($172|0)>(1);
   if (!($174)) {
    return;
   }
   $175 = ((($3)) + 4|0);
   $176 = ((($0)) + 8|0);
   $177 = ((($0)) + 196|0);
   $$0134176 = $175;
   while(1) {
    $178 = HEAP32[$177>>2]|0;
    $179 = HEAP32[$$0134176>>2]|0;
    $180 = (($178) + (($179*12)|0)|0);
    $181 = ((($$0134176)) + 4|0);
    $182 = HEAP32[$181>>2]|0;
    $183 = (($178) + (($182*12)|0)|0);
    __ZN21ComputeNearFarFunctorI17GreaterComparatorEclERKN3osg5Vec3fES5_b($176,$180,$183,0);
    $184 = ($181>>>0)<($173>>>0);
    if ($184) {
     $$0134176 = $181;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 2:  {
   $185 = (($2) + -1)|0;
   $186 = (($3) + ($185<<2)|0);
   $187 = ($2|0)>(1);
   $188 = ((($0)) + 196|0);
   $189 = HEAP32[$188>>2]|0;
   $190 = ((($0)) + 8|0);
   if ($187) {
    $$0178 = $3;$197 = $189;
    while(1) {
     $195 = HEAP32[$$0178>>2]|0;
     $196 = (($197) + (($195*12)|0)|0);
     $198 = ((($$0178)) + 4|0);
     $199 = HEAP32[$198>>2]|0;
     $200 = (($197) + (($199*12)|0)|0);
     __ZN21ComputeNearFarFunctorI17GreaterComparatorEclERKN3osg5Vec3fES5_b($190,$196,$200,0);
     $201 = ($198>>>0)<($186>>>0);
     $202 = HEAP32[$188>>2]|0;
     if ($201) {
      $$0178 = $198;$197 = $202;
     } else {
      $$lcssa156 = $202;
      break;
     }
    }
   } else {
    $$lcssa156 = $189;
   }
   $191 = HEAP32[$186>>2]|0;
   $192 = (($$lcssa156) + (($191*12)|0)|0);
   $193 = HEAP32[$3>>2]|0;
   $194 = (($$lcssa156) + (($193*12)|0)|0);
   __ZN21ComputeNearFarFunctorI17GreaterComparatorEclERKN3osg5Vec3fES5_b($190,$192,$194,0);
   return;
   break;
  }
  default: {
   return;
  }
  }
 } while(0);
}
function __ZN21ComputeNearFarFunctorI17GreaterComparatorEclERKN3osg5Vec3fES5_S5_b($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$$098 = 0, $$0101167 = 0, $$096177 = 0, $$098176 = 0, $$2172 = 0, $$in = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre182 = 0, $$pre183 = 0, $$pre184 = 0, $$pre185 = 0, $$pre186 = 0.0, $$pre187 = 0, $$pre188 = 0, $$pre189 = 0, $$pre189$pre = 0, $$pre190 = 0, $$pre191 = 0, $$pre192 = 0.0;
 var $$sroa$0114$0164 = 0, $$sroa$0124$0$$sroa_idx = 0, $$sroa$0135$0165 = 0, $$sroa$0151$0175 = 0, $$sroa$0151$1170 = 0, $$sroa$4126$0$$sroa_idx128 = 0, $$sroa$5$0$$sroa_idx130 = 0, $10 = 0.0, $100 = 0.0, $101 = 0.0, $102 = 0.0, $103 = 0.0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0.0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0.0, $129 = 0;
 var $13 = 0.0, $130 = 0.0, $131 = 0, $132 = 0.0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0.0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0.0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0.0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0.0, $19 = 0.0, $190 = 0, $191 = 0.0, $192 = 0, $193 = 0.0, $194 = 0, $195 = 0.0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0.0, $200 = 0, $201 = 0;
 var $202 = 0.0, $203 = 0.0, $204 = 0.0, $205 = 0, $206 = 0.0, $207 = 0.0, $208 = 0.0, $209 = 0.0, $21 = 0, $210 = 0, $211 = 0.0, $212 = 0.0, $213 = 0.0, $214 = 0.0, $215 = 0.0, $216 = 0.0, $217 = 0, $218 = 0, $219 = 0, $22 = 0.0;
 var $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0.0, $230 = 0, $231 = 0, $232 = 0.0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0;
 var $239 = 0, $24 = 0, $240 = 0, $241 = 0.0, $242 = 0, $243 = 0, $244 = 0.0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0.0, $25 = 0.0, $250 = 0.0, $251 = 0.0, $252 = 0.0, $253 = 0.0, $254 = 0, $255 = 0, $256 = 0.0;
 var $257 = 0.0, $258 = 0, $259 = 0.0, $26 = 0.0, $260 = 0.0, $261 = 0, $262 = 0.0, $263 = 0.0, $264 = 0, $265 = 0.0, $266 = 0.0, $267 = 0, $268 = 0.0, $269 = 0.0, $27 = 0.0, $270 = 0, $271 = 0.0, $272 = 0.0, $273 = 0.0, $274 = 0.0;
 var $275 = 0.0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0.0, $290 = 0.0, $291 = 0.0, $292 = 0.0;
 var $293 = 0.0, $294 = 0, $295 = 0.0, $296 = 0.0, $297 = 0.0, $298 = 0, $299 = 0.0, $30 = 0.0, $300 = 0.0, $301 = 0.0, $302 = 0.0, $303 = 0, $304 = 0.0, $305 = 0.0, $306 = 0.0, $307 = 0.0, $308 = 0.0, $309 = 0.0, $31 = 0.0, $310 = 0;
 var $311 = 0.0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0.0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0;
 var $33 = 0.0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0.0, $34 = 0.0, $35 = 0, $36 = 0.0, $37 = 0.0, $38 = 0.0, $39 = 0.0, $40 = 0, $41 = 0.0, $42 = 0.0, $43 = 0.0, $44 = 0.0, $45 = 0.0;
 var $46 = 0.0, $47 = 0.0, $48 = 0.0, $49 = 0.0, $5 = 0, $50 = 0, $51 = 0.0, $52 = 0.0, $53 = 0.0, $54 = 0.0, $55 = 0, $56 = 0.0, $57 = 0.0, $58 = 0.0, $59 = 0.0, $6 = 0, $60 = 0.0, $61 = 0.0, $62 = 0, $63 = 0.0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0.0, $77 = 0.0, $78 = 0, $79 = 0.0, $8 = 0, $80 = 0.0, $81 = 0.0;
 var $82 = 0, $83 = 0.0, $84 = 0.0, $85 = 0.0, $86 = 0, $87 = 0.0, $88 = 0.0, $89 = 0.0, $9 = 0.0, $90 = 0.0, $91 = 0.0, $92 = 0.0, $93 = 0.0, $94 = 0.0, $95 = 0.0, $96 = 0.0, $97 = 0.0, $98 = 0.0, $99 = 0.0, $exitcond = 0;
 var $or$cond = 0, $or$cond160 = 0, $or$cond161 = 0, $or$cond3 = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i109 = 0, $scevgep5$i$i$i = 0, $scevgep5$i$i$i110 = 0, $tmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(64|0);
 $5 = sp + 48|0;
 $6 = sp + 32|0;
 $7 = sp + 16|0;
 $8 = sp;
 $9 = +HEAPF32[$1>>2];
 $10 = $9;
 $11 = ((($0)) + 32|0);
 $12 = +HEAPF64[$11>>3];
 $13 = $10 * $12;
 $14 = ((($1)) + 4|0);
 $15 = +HEAPF32[$14>>2];
 $16 = $15;
 $17 = ((($0)) + 64|0);
 $18 = +HEAPF64[$17>>3];
 $19 = $16 * $18;
 $20 = $13 + $19;
 $21 = ((($1)) + 8|0);
 $22 = +HEAPF32[$21>>2];
 $23 = $22;
 $24 = ((($0)) + 96|0);
 $25 = +HEAPF64[$24>>3];
 $26 = $23 * $25;
 $27 = $20 + $26;
 $28 = ((($0)) + 128|0);
 $29 = +HEAPF64[$28>>3];
 $30 = $29 + $27;
 $31 = -$30;
 $32 = +HEAPF32[$2>>2];
 $33 = $32;
 $34 = $12 * $33;
 $35 = ((($2)) + 4|0);
 $36 = +HEAPF32[$35>>2];
 $37 = $36;
 $38 = $18 * $37;
 $39 = $34 + $38;
 $40 = ((($2)) + 8|0);
 $41 = +HEAPF32[$40>>2];
 $42 = $41;
 $43 = $25 * $42;
 $44 = $39 + $43;
 $45 = $29 + $44;
 $46 = -$45;
 $47 = +HEAPF32[$3>>2];
 $48 = $47;
 $49 = $12 * $48;
 $50 = ((($3)) + 4|0);
 $51 = +HEAPF32[$50>>2];
 $52 = $51;
 $53 = $18 * $52;
 $54 = $49 + $53;
 $55 = ((($3)) + 8|0);
 $56 = +HEAPF32[$55>>2];
 $57 = $56;
 $58 = $25 * $57;
 $59 = $54 + $58;
 $60 = $29 + $59;
 $61 = -$60;
 $62 = ((($0)) + 8|0);
 $63 = +HEAPF64[$62>>3];
 $64 = $63 >= $31;
 $65 = $63 >= $46;
 $or$cond160 = $64 & $65;
 $66 = $63 >= $61;
 $or$cond161 = $or$cond160 & $66;
 if ($or$cond161) {
  STACKTOP = sp;return;
 }
 $67 = $30 > -0.0;
 $68 = $45 > -0.0;
 $or$cond = $67 & $68;
 $69 = $60 > -0.0;
 $or$cond3 = $or$cond & $69;
 if ($or$cond3) {
  STACKTOP = sp;return;
 }
 $70 = ((($0)) + 144|0);
 $71 = HEAP32[$70>>2]|0;
 $72 = HEAP32[$71>>2]|0;
 $73 = ((($71)) + 4|0);
 $74 = HEAP32[$73>>2]|0;
 $75 = ($72|0)==($74|0);
 if (!($75)) {
  $$096177 = 1;$$098176 = 0;$$sroa$0151$0175 = $72;
  while(1) {
   $76 = +HEAPF64[$$sroa$0151$0175>>3];
   $77 = $76 * $10;
   $78 = ((($$sroa$0151$0175)) + 8|0);
   $79 = +HEAPF64[$78>>3];
   $80 = $79 * $16;
   $81 = $77 + $80;
   $82 = ((($$sroa$0151$0175)) + 16|0);
   $83 = +HEAPF64[$82>>3];
   $84 = $83 * $23;
   $85 = $81 + $84;
   $86 = ((($$sroa$0151$0175)) + 24|0);
   $87 = +HEAPF64[$86>>3];
   $88 = $87 + $85;
   $89 = $88;
   $90 = $76 * $33;
   $91 = $79 * $37;
   $92 = $90 + $91;
   $93 = $83 * $42;
   $94 = $92 + $93;
   $95 = $87 + $94;
   $96 = $95;
   $97 = $76 * $48;
   $98 = $79 * $52;
   $99 = $97 + $98;
   $100 = $83 * $57;
   $101 = $99 + $100;
   $102 = $87 + $101;
   $103 = $102;
   $104 = $89 < 0.0;
   $105 = $104&1;
   $106 = $96 < 0.0;
   $107 = $106&1;
   $108 = (($107) + ($105))|0;
   $109 = $103 < 0.0;
   $110 = $109&1;
   $111 = (($108) + ($110))|0;
   $112 = ($111|0)==(3);
   if ($112) {
    label = 51;
    break;
   }
   $113 = $89 >= 0.0;
   $114 = $113&1;
   $115 = $96 >= 0.0;
   $116 = $115&1;
   $117 = (($116) + ($114))|0;
   $118 = $103 >= 0.0;
   $119 = $118&1;
   $120 = (($117) + ($119))|0;
   $121 = ($120>>>0)<(3);
   $122 = $121 ? $$096177 : 0;
   $$$098 = $122 | $$098176;
   $123 = $$096177 << 1;
   $124 = ((($$sroa$0151$0175)) + 40|0);
   $125 = ($124|0)==($74|0);
   if ($125) {
    break;
   } else {
    $$096177 = $123;$$098176 = $$$098;$$sroa$0151$0175 = $124;
   }
  }
  if ((label|0) == 51) {
   STACKTOP = sp;return;
  }
  $126 = ($$$098|0)==(0);
  if (!($126)) {
   $133 = ((($0)) + 148|0);
   $134 = HEAP32[$133>>2]|0;
   $135 = ((($0)) + 152|0);
   $136 = HEAP32[$135>>2]|0;
   $137 = ($136|0)==($134|0);
   if ($137) {
    $146 = $134;
   } else {
    $scevgep$i$i$i109 = ((($136)) + -16|0);
    $138 = $scevgep$i$i$i109;
    $139 = $134;
    $140 = (($138) - ($139))|0;
    $141 = $140 >>> 4;
    $142 = $141 ^ -1;
    $scevgep5$i$i$i110 = (($136) + ($142<<4)|0);
    HEAP32[$135>>2] = $scevgep5$i$i$i110;
    $146 = $scevgep5$i$i$i110;
   }
   HEAP32[$5>>2] = 0;
   $143 = ((($5)) + 4|0);
   ;HEAP32[$143>>2]=HEAP32[$1>>2]|0;HEAP32[$143+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$143+8>>2]=HEAP32[$1+8>>2]|0;
   $144 = ((($0)) + 156|0);
   $145 = HEAP32[$144>>2]|0;
   $147 = ($146|0)==($145|0);
   if ($147) {
    __ZNSt3__26vectorINS_4pairIfN3osg5Vec3fEEENS_9allocatorIS4_EEE21__push_back_slow_pathIKS4_EEvRT_($133,$5);
    $$pre = HEAP32[$135>>2]|0;
    $152 = $$pre;
   } else {
    ;HEAP32[$146>>2]=HEAP32[$5>>2]|0;HEAP32[$146+4>>2]=HEAP32[$5+4>>2]|0;HEAP32[$146+8>>2]=HEAP32[$5+8>>2]|0;HEAP32[$146+12>>2]=HEAP32[$5+12>>2]|0;
    $148 = HEAP32[$135>>2]|0;
    $149 = ((($148)) + 16|0);
    HEAP32[$135>>2] = $149;
    $152 = $149;
   }
   HEAP32[$6>>2] = 0;
   $150 = ((($6)) + 4|0);
   ;HEAP32[$150>>2]=HEAP32[$2>>2]|0;HEAP32[$150+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$150+8>>2]=HEAP32[$2+8>>2]|0;
   $151 = HEAP32[$144>>2]|0;
   $153 = ($152|0)==($151|0);
   if ($153) {
    __ZNSt3__26vectorINS_4pairIfN3osg5Vec3fEEENS_9allocatorIS4_EEE21__push_back_slow_pathIKS4_EEvRT_($133,$6);
    $$pre182 = HEAP32[$135>>2]|0;
    $158 = $$pre182;
   } else {
    ;HEAP32[$152>>2]=HEAP32[$6>>2]|0;HEAP32[$152+4>>2]=HEAP32[$6+4>>2]|0;HEAP32[$152+8>>2]=HEAP32[$6+8>>2]|0;HEAP32[$152+12>>2]=HEAP32[$6+12>>2]|0;
    $154 = HEAP32[$135>>2]|0;
    $155 = ((($154)) + 16|0);
    HEAP32[$135>>2] = $155;
    $158 = $155;
   }
   HEAP32[$7>>2] = 0;
   $156 = ((($7)) + 4|0);
   ;HEAP32[$156>>2]=HEAP32[$3>>2]|0;HEAP32[$156+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$156+8>>2]=HEAP32[$3+8>>2]|0;
   $157 = HEAP32[$144>>2]|0;
   $159 = ($158|0)==($157|0);
   if ($159) {
    __ZNSt3__26vectorINS_4pairIfN3osg5Vec3fEEENS_9allocatorIS4_EEE21__push_back_slow_pathIKS4_EEvRT_($133,$7);
   } else {
    ;HEAP32[$158>>2]=HEAP32[$7>>2]|0;HEAP32[$158+4>>2]=HEAP32[$7+4>>2]|0;HEAP32[$158+8>>2]=HEAP32[$7+8>>2]|0;HEAP32[$158+12>>2]=HEAP32[$7+12>>2]|0;
    $160 = HEAP32[$135>>2]|0;
    $161 = ((($160)) + 16|0);
    HEAP32[$135>>2] = $161;
   }
   $162 = HEAP32[$70>>2]|0;
   $163 = HEAP32[$162>>2]|0;
   $164 = ((($162)) + 4|0);
   $165 = HEAP32[$164>>2]|0;
   $166 = ($163|0)==($165|0);
   L30: do {
    if ($166) {
     $$pre190 = HEAP32[$133>>2]|0;
     $$pre191 = HEAP32[$135>>2]|0;
     $287 = $$pre190;$289 = $$pre191;$314 = $$pre191;
    } else {
     $167 = ((($0)) + 160|0);
     $168 = ((($0)) + 164|0);
     $169 = ((($0)) + 168|0);
     $$sroa$0124$0$$sroa_idx = ((($8)) + 4|0);
     $$sroa$4126$0$$sroa_idx128 = ((($8)) + 8|0);
     $$sroa$5$0$$sroa_idx130 = ((($8)) + 12|0);
     $$pre183 = HEAP32[$133>>2]|0;
     $$pre184 = HEAP32[$135>>2]|0;
     $170 = $$pre184;
     $171 = $$pre183;
     $$2172 = 1;$$sroa$0151$1170 = $163;$172 = $$pre183;$174 = $$pre184;$186 = $$pre183;$188 = $$pre184;$197 = $171;$198 = $170;$219 = $$pre184;$315 = $$pre184;$316 = $$pre184;$317 = $$pre183;$318 = $162;$319 = $$pre183;$320 = $$pre183;$321 = $$pre183;
     while(1) {
      $173 = ($172|0)==($174|0);
      if ($173) {
       $287 = $317;$289 = $316;$314 = $315;
       break L30;
      }
      $175 = $$2172 & $$$098;
      $176 = ($175|0)==(0);
      if ($176) {
       $284 = $318;$322 = $315;$323 = $316;$324 = $317;$325 = $319;$326 = $320;$327 = $321;$328 = $197;$329 = $198;$330 = $219;$331 = $188;$332 = $186;$333 = $174;$334 = $172;
      } else {
       $177 = HEAP32[$167>>2]|0;
       $178 = HEAP32[$168>>2]|0;
       $179 = ($178|0)==($177|0);
       $180 = $177;
       if ($179) {
        $$in = $178;
       } else {
        $scevgep$i$i$i = ((($178)) + -16|0);
        $181 = $scevgep$i$i$i;
        $182 = (($181) - ($180))|0;
        $183 = $182 >>> 4;
        $184 = $183 ^ -1;
        $scevgep5$i$i$i = (($178) + ($184<<4)|0);
        HEAP32[$168>>2] = $scevgep5$i$i$i;
        $$in = $scevgep5$i$i$i;
       }
       $185 = $$in;
       $187 = ($186|0)==($188|0);
       if (!($187)) {
        $189 = +HEAPF64[$$sroa$0151$1170>>3];
        $190 = ((($$sroa$0151$1170)) + 8|0);
        $191 = +HEAPF64[$190>>3];
        $192 = ((($$sroa$0151$1170)) + 16|0);
        $193 = +HEAPF64[$192>>3];
        $194 = ((($$sroa$0151$1170)) + 24|0);
        $195 = +HEAPF64[$194>>3];
        $$sroa$0135$0165 = $186;
        while(1) {
         $201 = ((($$sroa$0135$0165)) + 4|0);
         $202 = +HEAPF32[$201>>2];
         $203 = $202;
         $204 = $189 * $203;
         $205 = ((($$sroa$0135$0165)) + 8|0);
         $206 = +HEAPF32[$205>>2];
         $207 = $206;
         $208 = $191 * $207;
         $209 = $204 + $208;
         $210 = ((($$sroa$0135$0165)) + 12|0);
         $211 = +HEAPF32[$210>>2];
         $212 = $211;
         $213 = $193 * $212;
         $214 = $209 + $213;
         $215 = $195 + $214;
         $216 = $215;
         HEAPF32[$$sroa$0135$0165>>2] = $216;
         $217 = ((($$sroa$0135$0165)) + 16|0);
         $218 = ($217|0)==($219|0);
         if ($218) {
          break;
         } else {
          $$sroa$0135$0165 = $217;
         }
        }
       }
       $196 = (($198) - ($197))|0;
       $199 = $196 >> 4;
       $200 = ($199|0)==(0);
       if ($200) {
        $$pre189 = $318;$221 = $180;$223 = $185;
       } else {
        $$0101167 = 0;$231 = $321;$246 = $320;$335 = $319;
        while(1) {
         $228 = (($$0101167) + 1)|0;
         $229 = ($228|0)==($199|0);
         $tmp = $229 ? 0 : $228;
         $230 = (($231) + ($$0101167<<4)|0);
         $232 = +HEAPF32[$230>>2];
         $233 = !($232 >= 0.0);
         do {
          if ($233) {
           $243 = (($231) + ($tmp<<4)|0);
           $244 = +HEAPF32[$243>>2];
           $245 = $244 > 0.0;
           if (!($245)) {
            break;
           }
           $$phi$trans$insert = (($246) + ($tmp<<4)|0);
           $$pre186 = +HEAPF32[$$phi$trans$insert>>2];
           $248 = $246;$251 = $$pre186;$255 = $335;
           label = 41;
          } else {
           $234 = HEAP32[$168>>2]|0;
           $235 = HEAP32[$169>>2]|0;
           $236 = ($234|0)==($235|0);
           if ($236) {
            __ZNSt3__26vectorINS_4pairIfN3osg5Vec3fEEENS_9allocatorIS4_EEE21__push_back_slow_pathIKS4_EEvRT_($167,$230);
           } else {
            ;HEAP32[$234>>2]=HEAP32[$230>>2]|0;HEAP32[$234+4>>2]=HEAP32[$230+4>>2]|0;HEAP32[$234+8>>2]=HEAP32[$230+8>>2]|0;HEAP32[$234+12>>2]=HEAP32[$230+12>>2]|0;
            $237 = HEAP32[$168>>2]|0;
            $238 = ((($237)) + 16|0);
            HEAP32[$168>>2] = $238;
           }
           $239 = HEAP32[$133>>2]|0;
           $240 = (($239) + ($tmp<<4)|0);
           $241 = +HEAPF32[$240>>2];
           $242 = $241 < 0.0;
           if ($242) {
            $248 = $239;$251 = $241;$255 = $239;
            label = 41;
           }
          }
         } while(0);
         if ((label|0) == 41) {
          label = 0;
          $247 = (($248) + ($$0101167<<4)|0);
          $249 = +HEAPF32[$247>>2];
          $250 = $249 - $251;
          $252 = $249 / $250;
          $253 = 1.0 - $252;
          $254 = (((($255) + ($$0101167<<4)|0)) + 4|0);
          $256 = +HEAPF32[$254>>2];
          $257 = $256 * $253;
          $258 = (((($255) + ($$0101167<<4)|0)) + 8|0);
          $259 = +HEAPF32[$258>>2];
          $260 = $253 * $259;
          $261 = (((($255) + ($$0101167<<4)|0)) + 12|0);
          $262 = +HEAPF32[$261>>2];
          $263 = $253 * $262;
          $264 = (((($255) + ($tmp<<4)|0)) + 4|0);
          $265 = +HEAPF32[$264>>2];
          $266 = $252 * $265;
          $267 = (((($255) + ($tmp<<4)|0)) + 8|0);
          $268 = +HEAPF32[$267>>2];
          $269 = $252 * $268;
          $270 = (((($255) + ($tmp<<4)|0)) + 12|0);
          $271 = +HEAPF32[$270>>2];
          $272 = $252 * $271;
          $273 = $257 + $266;
          $274 = $260 + $269;
          $275 = $263 + $272;
          HEAP32[$8>>2] = 0;
          HEAPF32[$$sroa$0124$0$$sroa_idx>>2] = $273;
          HEAPF32[$$sroa$4126$0$$sroa_idx128>>2] = $274;
          HEAPF32[$$sroa$5$0$$sroa_idx130>>2] = $275;
          $276 = HEAP32[$168>>2]|0;
          $277 = HEAP32[$169>>2]|0;
          $278 = ($276|0)==($277|0);
          if ($278) {
           __ZNSt3__26vectorINS_4pairIfN3osg5Vec3fEEENS_9allocatorIS4_EEE21__push_back_slow_pathIKS4_EEvRT_($167,$8);
          } else {
           ;HEAP32[$276>>2]=HEAP32[$8>>2]|0;HEAP32[$276+4>>2]=HEAP32[$8+4>>2]|0;HEAP32[$276+8>>2]=HEAP32[$8+8>>2]|0;HEAP32[$276+12>>2]=HEAP32[$8+12>>2]|0;
           $279 = HEAP32[$168>>2]|0;
           $280 = ((($279)) + 16|0);
           HEAP32[$168>>2] = $280;
          }
         }
         $exitcond = ($228|0)==($199|0);
         if ($exitcond) {
          break;
         }
         $$pre185 = HEAP32[$133>>2]|0;
         $$0101167 = $228;$231 = $$pre185;$246 = $$pre185;$335 = $$pre185;
        }
        $$pre187 = HEAP32[$167>>2]|0;
        $$pre188 = HEAP32[$168>>2]|0;
        $$pre189$pre = HEAP32[$70>>2]|0;
        $$pre189 = $$pre189$pre;$221 = $$pre187;$223 = $$pre188;
       }
       $220 = HEAP32[$133>>2]|0;
       HEAP32[$133>>2] = $221;
       HEAP32[$167>>2] = $220;
       $222 = HEAP32[$135>>2]|0;
       HEAP32[$135>>2] = $223;
       HEAP32[$168>>2] = $222;
       $224 = HEAP32[$144>>2]|0;
       $225 = HEAP32[$169>>2]|0;
       HEAP32[$144>>2] = $225;
       HEAP32[$169>>2] = $224;
       $226 = $221;
       $227 = $223;
       $284 = $$pre189;$322 = $227;$323 = $227;$324 = $226;$325 = $226;$326 = $226;$327 = $226;$328 = $221;$329 = $223;$330 = $227;$331 = $227;$332 = $226;$333 = $227;$334 = $226;
      }
      $281 = $$2172 << 1;
      $282 = ((($$sroa$0151$1170)) + 40|0);
      $283 = ((($284)) + 4|0);
      $285 = HEAP32[$283>>2]|0;
      $286 = ($282|0)==($285|0);
      if ($286) {
       $287 = $324;$289 = $323;$314 = $322;
       break;
      } else {
       $$2172 = $281;$$sroa$0151$1170 = $282;$172 = $334;$174 = $333;$186 = $332;$188 = $331;$197 = $328;$198 = $329;$219 = $330;$315 = $322;$316 = $323;$317 = $324;$318 = $284;$319 = $325;$320 = $326;$321 = $327;
      }
     }
    }
   } while(0);
   $288 = ($287|0)==($289|0);
   if ($288) {
    STACKTOP = sp;return;
   }
   $290 = +HEAPF64[$11>>3];
   $291 = +HEAPF64[$17>>3];
   $292 = +HEAPF64[$24>>3];
   $293 = +HEAPF64[$28>>3];
   $$pre192 = +HEAPF64[$62>>3];
   $$sroa$0114$0164 = $287;$311 = $$pre192;
   while(1) {
    $294 = ((($$sroa$0114$0164)) + 4|0);
    $295 = +HEAPF32[$294>>2];
    $296 = $295;
    $297 = $296 * $290;
    $298 = ((($$sroa$0114$0164)) + 8|0);
    $299 = +HEAPF32[$298>>2];
    $300 = $299;
    $301 = $300 * $291;
    $302 = $297 + $301;
    $303 = ((($$sroa$0114$0164)) + 12|0);
    $304 = +HEAPF32[$303>>2];
    $305 = $304;
    $306 = $305 * $292;
    $307 = $302 + $306;
    $308 = $293 + $307;
    $309 = -$308;
    $310 = $311 < $309;
    if ($310) {
     HEAPF64[$62>>3] = $309;
     $336 = $309;
    } else {
     $336 = $311;
    }
    $312 = ((($$sroa$0114$0164)) + 16|0);
    $313 = ($312|0)==($314|0);
    if ($313) {
     break;
    } else {
     $$sroa$0114$0164 = $312;$311 = $336;
    }
   }
   STACKTOP = sp;return;
  }
 }
 $127 = $63 > $31;
 $128 = $127 ? $63 : $31;
 $129 = $128 > $46;
 $130 = $129 ? $128 : $46;
 $131 = $130 > $61;
 $132 = $131 ? $130 : $61;
 HEAPF64[$62>>3] = $132;
 STACKTOP = sp;return;
}
function __ZN21ComputeNearFarFunctorI17GreaterComparatorEclERKN3osg5Vec3fES5_b($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$$064 = 0, $$063188 = 0, $$064187 = 0, $$2180 = 0, $$sroa$0161$0186 = 0, $$sroa$0161$1179 = 0, $$sroa$11$0$lcssa = 0.0, $$sroa$11$0174 = 0.0, $$sroa$11$1 = 0.0, $$sroa$12$0$lcssa = 0.0, $$sroa$12$0177 = 0.0, $$sroa$12$1 = 0.0, $$sroa$16$0$lcssa = 0.0, $$sroa$16$0175 = 0.0, $$sroa$16$1 = 0.0, $$sroa$17$0$lcssa = 0.0, $$sroa$17$0178 = 0.0, $$sroa$17$1 = 0.0, $$sroa$5125$0$lcssa = 0.0, $$sroa$5125$0173 = 0.0;
 var $$sroa$5125$1 = 0.0, $$sroa$6144$0$lcssa = 0.0, $$sroa$6144$0176 = 0.0, $$sroa$6144$1 = 0.0, $10 = 0.0, $100 = 0.0, $101 = 0, $102 = 0.0, $103 = 0.0, $104 = 0.0, $105 = 0.0, $106 = 0, $107 = 0.0, $108 = 0.0, $109 = 0.0, $11 = 0.0, $110 = 0.0, $111 = 0, $112 = 0.0, $113 = 0.0;
 var $114 = 0.0, $115 = 0.0, $116 = 0.0, $117 = 0.0, $118 = 0.0, $119 = 0.0, $12 = 0, $120 = 0.0, $121 = 0.0, $122 = 0.0, $123 = 0.0, $124 = 0.0, $125 = 0, $126 = 0, $127 = 0.0, $128 = 0.0, $129 = 0.0, $13 = 0.0, $130 = 0.0, $131 = 0.0;
 var $132 = 0.0, $133 = 0.0, $134 = 0.0, $135 = 0.0, $136 = 0.0, $137 = 0.0, $138 = 0.0, $139 = 0, $14 = 0.0, $140 = 0.0, $141 = 0.0, $142 = 0.0, $143 = 0.0, $144 = 0.0, $145 = 0.0, $146 = 0.0, $147 = 0.0, $148 = 0.0, $149 = 0.0, $15 = 0.0;
 var $150 = 0.0, $151 = 0.0, $152 = 0, $153 = 0, $154 = 0, $155 = 0.0, $156 = 0.0, $157 = 0.0, $158 = 0.0, $159 = 0.0, $16 = 0, $160 = 0.0, $161 = 0.0, $162 = 0.0, $163 = 0.0, $164 = 0.0, $165 = 0.0, $166 = 0.0, $167 = 0.0, $168 = 0.0;
 var $169 = 0.0, $17 = 0.0, $170 = 0.0, $171 = 0.0, $172 = 0.0, $173 = 0.0, $174 = 0.0, $175 = 0, $176 = 0.0, $18 = 0.0, $19 = 0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0, $24 = 0.0, $25 = 0.0, $26 = 0.0, $27 = 0.0, $28 = 0.0;
 var $29 = 0.0, $30 = 0, $31 = 0.0, $32 = 0.0, $33 = 0.0, $34 = 0.0, $35 = 0, $36 = 0.0, $37 = 0.0, $38 = 0.0, $39 = 0.0, $4 = 0.0, $40 = 0.0, $41 = 0.0, $42 = 0, $43 = 0.0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0.0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0.0, $55 = 0.0, $56 = 0, $57 = 0.0, $58 = 0.0, $59 = 0.0, $6 = 0, $60 = 0, $61 = 0.0, $62 = 0.0, $63 = 0.0, $64 = 0, $65 = 0.0;
 var $66 = 0.0, $67 = 0.0, $68 = 0.0, $69 = 0.0, $7 = 0.0, $70 = 0.0, $71 = 0.0, $72 = 0.0, $73 = 0.0, $74 = 0.0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0.0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0.0, $94 = 0, $95 = 0.0, $96 = 0, $97 = 0, $98 = 0.0, $99 = 0.0, $or$cond = 0, $or$cond170 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $4 = +HEAPF32[$1>>2];
 $5 = $4;
 $6 = ((($0)) + 32|0);
 $7 = +HEAPF64[$6>>3];
 $8 = $5 * $7;
 $9 = ((($1)) + 4|0);
 $10 = +HEAPF32[$9>>2];
 $11 = $10;
 $12 = ((($0)) + 64|0);
 $13 = +HEAPF64[$12>>3];
 $14 = $11 * $13;
 $15 = $8 + $14;
 $16 = ((($1)) + 8|0);
 $17 = +HEAPF32[$16>>2];
 $18 = $17;
 $19 = ((($0)) + 96|0);
 $20 = +HEAPF64[$19>>3];
 $21 = $18 * $20;
 $22 = $15 + $21;
 $23 = ((($0)) + 128|0);
 $24 = +HEAPF64[$23>>3];
 $25 = $24 + $22;
 $26 = -$25;
 $27 = +HEAPF32[$2>>2];
 $28 = $27;
 $29 = $7 * $28;
 $30 = ((($2)) + 4|0);
 $31 = +HEAPF32[$30>>2];
 $32 = $31;
 $33 = $13 * $32;
 $34 = $29 + $33;
 $35 = ((($2)) + 8|0);
 $36 = +HEAPF32[$35>>2];
 $37 = $36;
 $38 = $20 * $37;
 $39 = $34 + $38;
 $40 = $24 + $39;
 $41 = -$40;
 $42 = ((($0)) + 8|0);
 $43 = +HEAPF64[$42>>3];
 $44 = $43 >= $26;
 $45 = $43 >= $41;
 $or$cond170 = $44 & $45;
 if ($or$cond170) {
  return;
 }
 $46 = $25 > -0.0;
 $47 = $40 > -0.0;
 $or$cond = $46 & $47;
 if ($or$cond) {
  return;
 }
 $48 = ((($0)) + 144|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = HEAP32[$49>>2]|0;
 $51 = ((($49)) + 4|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = ($50|0)==($52|0);
 if (!($53)) {
  $$063188 = 1;$$064187 = 0;$$sroa$0161$0186 = $50;
  while(1) {
   $54 = +HEAPF64[$$sroa$0161$0186>>3];
   $55 = $54 * $5;
   $56 = ((($$sroa$0161$0186)) + 8|0);
   $57 = +HEAPF64[$56>>3];
   $58 = $57 * $11;
   $59 = $55 + $58;
   $60 = ((($$sroa$0161$0186)) + 16|0);
   $61 = +HEAPF64[$60>>3];
   $62 = $61 * $18;
   $63 = $59 + $62;
   $64 = ((($$sroa$0161$0186)) + 24|0);
   $65 = +HEAPF64[$64>>3];
   $66 = $65 + $63;
   $67 = $66;
   $68 = $54 * $28;
   $69 = $57 * $32;
   $70 = $68 + $69;
   $71 = $61 * $37;
   $72 = $70 + $71;
   $73 = $65 + $72;
   $74 = $73;
   $75 = $67 < 0.0;
   $76 = $75&1;
   $77 = $74 < 0.0;
   $78 = $77&1;
   $79 = (($78) + ($76))|0;
   $80 = ($79|0)==(2);
   if ($80) {
    label = 17;
    break;
   }
   $81 = $$063188 << 1;
   $82 = $67 >= 0.0;
   $83 = $82&1;
   $84 = $74 >= 0.0;
   $85 = $84&1;
   $86 = (($85) + ($83))|0;
   $87 = ($86>>>0)<(2);
   $88 = $87 ? $$063188 : 0;
   $$$064 = $88 | $$064187;
   $89 = ((($$sroa$0161$0186)) + 40|0);
   $90 = ($89|0)==($52|0);
   if ($90) {
    break;
   } else {
    $$063188 = $81;$$064187 = $$$064;$$sroa$0161$0186 = $89;
   }
  }
  if ((label|0) == 17) {
   return;
  }
  $91 = ($$$064|0)==(0);
  if (!($91)) {
   if ($53) {
    $$sroa$11$0$lcssa = $31;$$sroa$12$0$lcssa = $10;$$sroa$16$0$lcssa = $36;$$sroa$17$0$lcssa = $17;$$sroa$5125$0$lcssa = $27;$$sroa$6144$0$lcssa = $4;
   } else {
    $$2180 = 1;$$sroa$0161$1179 = $50;$$sroa$11$0174 = $31;$$sroa$12$0177 = $10;$$sroa$16$0175 = $36;$$sroa$17$0178 = $17;$$sroa$5125$0173 = $27;$$sroa$6144$0176 = $4;
    while(1) {
     $96 = $$2180 & $$$064;
     $97 = ($96|0)==(0);
     do {
      if ($97) {
       $$sroa$11$1 = $$sroa$11$0174;$$sroa$12$1 = $$sroa$12$0177;$$sroa$16$1 = $$sroa$16$0175;$$sroa$17$1 = $$sroa$17$0178;$$sroa$5125$1 = $$sroa$5125$0173;$$sroa$6144$1 = $$sroa$6144$0176;
      } else {
       $98 = +HEAPF64[$$sroa$0161$1179>>3];
       $99 = $$sroa$6144$0176;
       $100 = $99 * $98;
       $101 = ((($$sroa$0161$1179)) + 8|0);
       $102 = +HEAPF64[$101>>3];
       $103 = $$sroa$12$0177;
       $104 = $103 * $102;
       $105 = $100 + $104;
       $106 = ((($$sroa$0161$1179)) + 16|0);
       $107 = +HEAPF64[$106>>3];
       $108 = $$sroa$17$0178;
       $109 = $108 * $107;
       $110 = $105 + $109;
       $111 = ((($$sroa$0161$1179)) + 24|0);
       $112 = +HEAPF64[$111>>3];
       $113 = $112 + $110;
       $114 = $113;
       $115 = $$sroa$5125$0173;
       $116 = $115 * $98;
       $117 = $$sroa$11$0174;
       $118 = $117 * $102;
       $119 = $116 + $118;
       $120 = $$sroa$16$0175;
       $121 = $120 * $107;
       $122 = $119 + $121;
       $123 = $112 + $122;
       $124 = $123;
       $125 = !($114 >= 0.0);
       if ($125) {
        $139 = !($124 >= 0.0);
        if ($139) {
         $$sroa$11$1 = $$sroa$11$0174;$$sroa$12$1 = $$sroa$12$0177;$$sroa$16$1 = $$sroa$16$0175;$$sroa$17$1 = $$sroa$17$0178;$$sroa$5125$1 = $$sroa$5125$0173;$$sroa$6144$1 = $$sroa$6144$0176;
         break;
        }
        $140 = $114 - $124;
        $141 = $114 / $140;
        $142 = 1.0 - $141;
        $143 = $$sroa$6144$0176 * $142;
        $144 = $$sroa$12$0177 * $142;
        $145 = $$sroa$17$0178 * $142;
        $146 = $$sroa$5125$0173 * $141;
        $147 = $$sroa$11$0174 * $141;
        $148 = $$sroa$16$0175 * $141;
        $149 = $146 + $143;
        $150 = $147 + $144;
        $151 = $148 + $145;
        $$sroa$11$1 = $$sroa$11$0174;$$sroa$12$1 = $150;$$sroa$16$1 = $$sroa$16$0175;$$sroa$17$1 = $151;$$sroa$5125$1 = $$sroa$5125$0173;$$sroa$6144$1 = $149;
        break;
       } else {
        $126 = $124 < 0.0;
        if (!($126)) {
         $$sroa$11$1 = $$sroa$11$0174;$$sroa$12$1 = $$sroa$12$0177;$$sroa$16$1 = $$sroa$16$0175;$$sroa$17$1 = $$sroa$17$0178;$$sroa$5125$1 = $$sroa$5125$0173;$$sroa$6144$1 = $$sroa$6144$0176;
         break;
        }
        $127 = $114 - $124;
        $128 = $114 / $127;
        $129 = 1.0 - $128;
        $130 = $$sroa$6144$0176 * $129;
        $131 = $$sroa$12$0177 * $129;
        $132 = $$sroa$17$0178 * $129;
        $133 = $$sroa$5125$0173 * $128;
        $134 = $$sroa$11$0174 * $128;
        $135 = $$sroa$16$0175 * $128;
        $136 = $133 + $130;
        $137 = $134 + $131;
        $138 = $135 + $132;
        $$sroa$11$1 = $137;$$sroa$12$1 = $$sroa$12$0177;$$sroa$16$1 = $138;$$sroa$17$1 = $$sroa$17$0178;$$sroa$5125$1 = $136;$$sroa$6144$1 = $$sroa$6144$0176;
        break;
       }
      }
     } while(0);
     $152 = $$2180 << 1;
     $153 = ((($$sroa$0161$1179)) + 40|0);
     $154 = ($153|0)==($52|0);
     if ($154) {
      $$sroa$11$0$lcssa = $$sroa$11$1;$$sroa$12$0$lcssa = $$sroa$12$1;$$sroa$16$0$lcssa = $$sroa$16$1;$$sroa$17$0$lcssa = $$sroa$17$1;$$sroa$5125$0$lcssa = $$sroa$5125$1;$$sroa$6144$0$lcssa = $$sroa$6144$1;
      break;
     } else {
      $$2180 = $152;$$sroa$0161$1179 = $153;$$sroa$11$0174 = $$sroa$11$1;$$sroa$12$0177 = $$sroa$12$1;$$sroa$16$0175 = $$sroa$16$1;$$sroa$17$0178 = $$sroa$17$1;$$sroa$5125$0173 = $$sroa$5125$1;$$sroa$6144$0176 = $$sroa$6144$1;
     }
    }
   }
   $155 = $$sroa$6144$0$lcssa;
   $156 = $155 * $7;
   $157 = $$sroa$12$0$lcssa;
   $158 = $157 * $13;
   $159 = $156 + $158;
   $160 = $$sroa$17$0$lcssa;
   $161 = $160 * $20;
   $162 = $159 + $161;
   $163 = $24 + $162;
   $164 = -$163;
   $165 = $$sroa$5125$0$lcssa;
   $166 = $165 * $7;
   $167 = $$sroa$11$0$lcssa;
   $168 = $167 * $13;
   $169 = $166 + $168;
   $170 = $$sroa$16$0$lcssa;
   $171 = $170 * $20;
   $172 = $169 + $171;
   $173 = $24 + $172;
   $174 = -$173;
   $175 = $164 > $174;
   $176 = $175 ? $164 : $174;
   HEAPF64[$42>>3] = $176;
   return;
  }
 }
 $92 = $43 < $26;
 $93 = $92 ? $43 : $26;
 $94 = $93 < $41;
 $95 = $94 ? $93 : $41;
 HEAPF64[$42>>3] = $95;
 return;
}
function __ZNSt3__26vectorINS_4pairIfN3osg5Vec3fEEENS_9allocatorIS4_EEE21__push_back_slow_pathIKS4_EEvRT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 4;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(268435455);
 if ($8) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $9 = ((($0)) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) - ($4))|0;
 $12 = $11 >> 4;
 $13 = ($12>>>0)<(134217727);
 $14 = $11 >> 3;
 $15 = ($14>>>0)<($7>>>0);
 $$sroa$speculated$i = $15 ? $7 : $14;
 $$sroa$speculated$$i = $13 ? $$sroa$speculated$i : 268435455;
 $16 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($16) {
   $26 = 0;
  } else {
   $17 = ($$sroa$speculated$$i>>>0)>(268435455);
   if (!($17)) {
    $23 = $$sroa$speculated$$i << 4;
    $24 = (__Znwj($23)|0);
    $26 = $24;
    break;
   }
   $18 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($18|0),(204840|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if ($20) {
    $21 = ___cxa_find_matching_catch_2()|0;
    $22 = tempRet0;
    ___cxa_free_exception(($18|0));
    ___resumeException($21|0);
    // unreachable;
   } else {
    HEAP32[$18>>2] = (99824);
    ___cxa_throw(($18|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $25 = (($26) + ($6<<4)|0);
 $27 = (($26) + ($$sroa$speculated$$i<<4)|0);
 $28 = $27;
 ;HEAP32[$25>>2]=HEAP32[$1>>2]|0;HEAP32[$25+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$25+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$25+12>>2]=HEAP32[$1+12>>2]|0;
 $29 = ((($25)) + 16|0);
 $30 = $29;
 $31 = (0 - ($6))|0;
 $32 = (($25) + ($31<<4)|0);
 $33 = $32;
 $34 = ($5|0)>(0);
 if ($34) {
  $35 = $4;
  _memcpy(($32|0),($35|0),($5|0))|0;
 }
 HEAP32[$0>>2] = $33;
 HEAP32[$2>>2] = $30;
 HEAP32[$9>>2] = $28;
 $36 = ($4|0)==(0);
 if ($36) {
  return;
 }
 $37 = $4;
 __ZdlPv($37);
 return;
}
function __ZN3osg24TemplatePrimitiveFunctorI21ComputeNearFarFunctorI17GreaterComparatorEE20drawElementsTemplateItEEvjiPKT_($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0133157 = 0, $$0134176 = 0, $$0135159 = 0, $$0136174 = 0, $$0137158 = 0, $$0138172 = 0, $$0139162 = 0, $$0140170 = 0, $$0141161 = 0, $$0143165 = 0, $$0145164 = 0, $$0178 = 0, $$lcssa156 = 0, $$pre = 0.0, $$pre190 = 0.0, $$pre191 = 0.0, $$pre192 = 0.0, $$pre193 = 0.0, $$pre195 = 0, $$sroa$015$019$i = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0.0, $127 = 0.0, $128 = 0.0, $129 = 0, $13 = 0, $130 = 0.0, $131 = 0.0, $132 = 0.0, $133 = 0.0, $134 = 0, $135 = 0.0;
 var $136 = 0.0, $137 = 0.0, $138 = 0.0, $139 = 0.0, $14 = 0, $140 = 0.0, $141 = 0, $142 = 0.0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0.0, $152 = 0.0, $153 = 0;
 var $154 = 0.0, $155 = 0.0, $156 = 0.0, $157 = 0, $158 = 0.0, $159 = 0.0, $16 = 0, $160 = 0.0, $161 = 0, $162 = 0.0, $163 = 0.0, $164 = 0.0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0;
 var $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0;
 var $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0;
 var $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0;
 var $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0.0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $exitcond189 = 0, $exitcond189212 = 0, $not$$i = 0, $or$cond = 0, $or$cond$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ($3|0)==(0|0);
 $5 = ($2|0)==(0);
 $or$cond = $5 | $4;
 if ($or$cond) {
  return;
 }
 do {
  switch ($1|0) {
  case 4:  {
   $15 = (($3) + ($2<<1)|0);
   $16 = ($2|0)>(0);
   if (!($16)) {
    return;
   }
   $17 = ((($0)) + 8|0);
   $18 = ((($0)) + 196|0);
   $$0133157 = $3;
   while(1) {
    $19 = HEAP32[$18>>2]|0;
    $20 = HEAP16[$$0133157>>1]|0;
    $21 = $20&65535;
    $22 = (($19) + (($21*12)|0)|0);
    $23 = ((($$0133157)) + 2|0);
    $24 = HEAP16[$23>>1]|0;
    $25 = $24&65535;
    $26 = (($19) + (($25*12)|0)|0);
    $27 = ((($$0133157)) + 4|0);
    $28 = HEAP16[$27>>1]|0;
    $29 = $28&65535;
    $30 = (($19) + (($29*12)|0)|0);
    __ZN21ComputeNearFarFunctorI17GreaterComparatorEclERKN3osg5Vec3fES5_S5_b($17,$22,$26,$30,0);
    $31 = ((($$0133157)) + 6|0);
    $32 = ($31>>>0)<($15>>>0);
    if ($32) {
     $$0133157 = $31;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 5:  {
   $12 = ($2|0)>(2);
   if (!($12)) {
    return;
   }
   $13 = ((($0)) + 8|0);
   $14 = ((($0)) + 196|0);
   $$0135159 = $3;$$0137158 = 2;
   while(1) {
    $33 = $$0137158 & 1;
    $34 = ($33|0)==(0);
    $35 = HEAP32[$14>>2]|0;
    $36 = HEAP16[$$0135159>>1]|0;
    $37 = $36&65535;
    $38 = (($35) + (($37*12)|0)|0);
    $39 = ((($$0135159)) + 2|0);
    $40 = HEAP16[$39>>1]|0;
    $41 = ((($$0135159)) + 4|0);
    $42 = HEAP16[$41>>1]|0;
    $43 = $40&65535;
    $44 = $42&65535;
    if ($34) {
     $47 = (($35) + (($43*12)|0)|0);
     $48 = (($35) + (($44*12)|0)|0);
     __ZN21ComputeNearFarFunctorI17GreaterComparatorEclERKN3osg5Vec3fES5_S5_b($13,$38,$47,$48,0);
    } else {
     $45 = (($35) + (($44*12)|0)|0);
     $46 = (($35) + (($43*12)|0)|0);
     __ZN21ComputeNearFarFunctorI17GreaterComparatorEclERKN3osg5Vec3fES5_S5_b($13,$38,$45,$46,0);
    }
    $49 = (($$0137158) + 1)|0;
    $exitcond = ($49|0)==($2|0);
    if ($exitcond) {
     break;
    } else {
     $$0135159 = $39;$$0137158 = $49;
    }
   }
   return;
   break;
  }
  case 7:  {
   $9 = ($2|0)>(3);
   if (!($9)) {
    return;
   }
   $10 = ((($0)) + 8|0);
   $11 = ((($0)) + 196|0);
   $$0139162 = $3;$$0141161 = 3;
   while(1) {
    $50 = HEAP32[$11>>2]|0;
    $51 = HEAP16[$$0139162>>1]|0;
    $52 = $51&65535;
    $53 = (($50) + (($52*12)|0)|0);
    $54 = ((($$0139162)) + 2|0);
    $55 = HEAP16[$54>>1]|0;
    $56 = $55&65535;
    $57 = (($50) + (($56*12)|0)|0);
    $58 = ((($$0139162)) + 4|0);
    $59 = HEAP16[$58>>1]|0;
    $60 = $59&65535;
    $61 = (($50) + (($60*12)|0)|0);
    $62 = ((($$0139162)) + 6|0);
    $63 = HEAP16[$62>>1]|0;
    $64 = $63&65535;
    $65 = (($50) + (($64*12)|0)|0);
    __ZN21ComputeNearFarFunctorI17GreaterComparatorEclERKN3osg5Vec3fES5_S5_b($10,$53,$57,$61,0);
    __ZN21ComputeNearFarFunctorI17GreaterComparatorEclERKN3osg5Vec3fES5_S5_b($10,$53,$61,$65,0);
    $66 = (($$0141161) + 4)|0;
    $67 = ((($$0139162)) + 8|0);
    $68 = ($66|0)<($2|0);
    if ($68) {
     $$0139162 = $67;$$0141161 = $66;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 8:  {
   $6 = ($2|0)>(3);
   if (!($6)) {
    return;
   }
   $7 = ((($0)) + 8|0);
   $8 = ((($0)) + 196|0);
   $$0143165 = $3;$$0145164 = 3;
   while(1) {
    $69 = HEAP32[$8>>2]|0;
    $70 = HEAP16[$$0143165>>1]|0;
    $71 = $70&65535;
    $72 = (($69) + (($71*12)|0)|0);
    $73 = ((($$0143165)) + 2|0);
    $74 = HEAP16[$73>>1]|0;
    $75 = $74&65535;
    $76 = (($69) + (($75*12)|0)|0);
    $77 = ((($$0143165)) + 6|0);
    $78 = HEAP16[$77>>1]|0;
    $79 = $78&65535;
    $80 = (($69) + (($79*12)|0)|0);
    $81 = ((($$0143165)) + 4|0);
    $82 = HEAP16[$81>>1]|0;
    $83 = $82&65535;
    $84 = (($69) + (($83*12)|0)|0);
    __ZN21ComputeNearFarFunctorI17GreaterComparatorEclERKN3osg5Vec3fES5_S5_b($7,$72,$76,$80,0);
    __ZN21ComputeNearFarFunctorI17GreaterComparatorEclERKN3osg5Vec3fES5_S5_b($7,$72,$80,$84,0);
    $85 = (($$0145164) + 2)|0;
    $86 = ($85|0)<($2|0);
    if ($86) {
     $$0143165 = $81;$$0145164 = $85;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 6: case 9:  {
   $87 = ((($0)) + 196|0);
   $88 = HEAP32[$87>>2]|0;
   $89 = HEAP16[$3>>1]|0;
   $90 = $89&65535;
   $91 = (($88) + (($90*12)|0)|0);
   $92 = ($2|0)>(2);
   if (!($92)) {
    return;
   }
   $93 = ((($3)) + 2|0);
   $94 = ((($0)) + 8|0);
   $95 = HEAP16[$93>>1]|0;
   $96 = $95&65535;
   $97 = (($88) + (($96*12)|0)|0);
   $98 = ((($3)) + 4|0);
   $99 = HEAP16[$98>>1]|0;
   $100 = $99&65535;
   $101 = (($88) + (($100*12)|0)|0);
   __ZN21ComputeNearFarFunctorI17GreaterComparatorEclERKN3osg5Vec3fES5_S5_b($94,$91,$97,$101,0);
   $exitcond189212 = ($2|0)==(3);
   if ($exitcond189212) {
    return;
   } else {
    $103 = $98;$111 = 3;
   }
   while(1) {
    $$pre195 = HEAP32[$87>>2]|0;
    $102 = HEAP16[$103>>1]|0;
    $104 = $102&65535;
    $105 = (($$pre195) + (($104*12)|0)|0);
    $106 = ((($103)) + 2|0);
    $107 = HEAP16[$106>>1]|0;
    $108 = $107&65535;
    $109 = (($$pre195) + (($108*12)|0)|0);
    __ZN21ComputeNearFarFunctorI17GreaterComparatorEclERKN3osg5Vec3fES5_S5_b($94,$91,$105,$109,0);
    $110 = (($111) + 1)|0;
    $exitcond189 = ($110|0)==($2|0);
    if ($exitcond189) {
     break;
    } else {
     $103 = $106;$111 = $110;
    }
   }
   return;
   break;
  }
  case 0:  {
   $112 = (($3) + ($2<<1)|0);
   $113 = ($2|0)>(0);
   if (!($113)) {
    return;
   }
   $114 = ((($0)) + 8|0);
   $115 = ((($0)) + 196|0);
   $116 = HEAP32[$115>>2]|0;
   $117 = ((($114)) + 32|0);
   $118 = ((($114)) + 64|0);
   $119 = ((($114)) + 96|0);
   $120 = ((($114)) + 128|0);
   $121 = ((($114)) + 8|0);
   $122 = ((($114)) + 144|0);
   $$pre = +HEAPF64[$117>>3];
   $$pre190 = +HEAPF64[$118>>3];
   $$pre191 = +HEAPF64[$119>>3];
   $$pre192 = +HEAPF64[$120>>3];
   $$pre193 = +HEAPF64[$121>>3];
   $$0140170 = $3;$142 = $$pre193;
   while(1) {
    $123 = HEAP16[$$0140170>>1]|0;
    $124 = $123&65535;
    $125 = (($116) + (($124*12)|0)|0);
    $126 = +HEAPF32[$125>>2];
    $127 = $126;
    $128 = $127 * $$pre;
    $129 = (((($116) + (($124*12)|0)|0)) + 4|0);
    $130 = +HEAPF32[$129>>2];
    $131 = $130;
    $132 = $131 * $$pre190;
    $133 = $128 + $132;
    $134 = (((($116) + (($124*12)|0)|0)) + 8|0);
    $135 = +HEAPF32[$134>>2];
    $136 = $135;
    $137 = $136 * $$pre191;
    $138 = $133 + $137;
    $139 = $$pre192 + $138;
    $140 = -$139;
    $141 = $142 >= $140;
    $143 = $139 > -0.0;
    $or$cond$i = $141 | $143;
    L52: do {
     if ($or$cond$i) {
      $233 = $142;
     } else {
      $144 = HEAP32[$122>>2]|0;
      $145 = HEAP32[$144>>2]|0;
      $146 = ((($144)) + 4|0);
      $147 = HEAP32[$146>>2]|0;
      $148 = ($145|0)==($147|0);
      if (!($148)) {
       $$sroa$015$019$i = $145;
       while(1) {
        $151 = +HEAPF64[$$sroa$015$019$i>>3];
        $152 = $127 * $151;
        $153 = ((($$sroa$015$019$i)) + 8|0);
        $154 = +HEAPF64[$153>>3];
        $155 = $131 * $154;
        $156 = $152 + $155;
        $157 = ((($$sroa$015$019$i)) + 16|0);
        $158 = +HEAPF64[$157>>3];
        $159 = $136 * $158;
        $160 = $156 + $159;
        $161 = ((($$sroa$015$019$i)) + 24|0);
        $162 = +HEAPF64[$161>>3];
        $163 = $162 + $160;
        $164 = $163;
        $not$$i = !($164 < 0.0);
        $149 = ((($$sroa$015$019$i)) + 40|0);
        if (!($not$$i)) {
         $233 = $142;
         break L52;
        }
        $150 = ($149|0)==($147|0);
        if ($150) {
         break;
        } else {
         $$sroa$015$019$i = $149;
        }
       }
      }
      HEAPF64[$121>>3] = $140;
      $233 = $140;
     }
    } while(0);
    $165 = ((($$0140170)) + 2|0);
    $166 = ($165>>>0)<($112>>>0);
    if ($166) {
     $$0140170 = $165;$142 = $233;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 1:  {
   $167 = (($2) + -1)|0;
   $168 = (($3) + ($167<<1)|0);
   $169 = ($2|0)>(1);
   if (!($169)) {
    return;
   }
   $170 = ((($0)) + 8|0);
   $171 = ((($0)) + 196|0);
   $$0138172 = $3;
   while(1) {
    $172 = HEAP32[$171>>2]|0;
    $173 = HEAP16[$$0138172>>1]|0;
    $174 = $173&65535;
    $175 = (($172) + (($174*12)|0)|0);
    $176 = ((($$0138172)) + 2|0);
    $177 = HEAP16[$176>>1]|0;
    $178 = $177&65535;
    $179 = (($172) + (($178*12)|0)|0);
    __ZN21ComputeNearFarFunctorI17GreaterComparatorEclERKN3osg5Vec3fES5_b($170,$175,$179,0);
    $180 = ((($$0138172)) + 4|0);
    $181 = ($180>>>0)<($168>>>0);
    if ($181) {
     $$0138172 = $180;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 3:  {
   $182 = (($2) + -1)|0;
   $183 = (($3) + ($182<<1)|0);
   $184 = ($2|0)>(1);
   if (!($184)) {
    return;
   }
   $185 = ((($0)) + 8|0);
   $186 = ((($0)) + 196|0);
   $$0136174 = $3;
   while(1) {
    $187 = HEAP32[$186>>2]|0;
    $188 = HEAP16[$$0136174>>1]|0;
    $189 = $188&65535;
    $190 = (($187) + (($189*12)|0)|0);
    $191 = ((($$0136174)) + 2|0);
    $192 = HEAP16[$191>>1]|0;
    $193 = $192&65535;
    $194 = (($187) + (($193*12)|0)|0);
    __ZN21ComputeNearFarFunctorI17GreaterComparatorEclERKN3osg5Vec3fES5_b($185,$190,$194,0);
    $195 = ($191>>>0)<($183>>>0);
    if ($195) {
     $$0136174 = $191;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 11:  {
   $196 = (($2) + -2)|0;
   $197 = (($3) + ($196<<1)|0);
   $198 = ($196|0)>(1);
   if (!($198)) {
    return;
   }
   $199 = ((($3)) + 2|0);
   $200 = ((($0)) + 8|0);
   $201 = ((($0)) + 196|0);
   $$0134176 = $199;
   while(1) {
    $202 = HEAP32[$201>>2]|0;
    $203 = HEAP16[$$0134176>>1]|0;
    $204 = $203&65535;
    $205 = (($202) + (($204*12)|0)|0);
    $206 = ((($$0134176)) + 2|0);
    $207 = HEAP16[$206>>1]|0;
    $208 = $207&65535;
    $209 = (($202) + (($208*12)|0)|0);
    __ZN21ComputeNearFarFunctorI17GreaterComparatorEclERKN3osg5Vec3fES5_b($200,$205,$209,0);
    $210 = ($206>>>0)<($197>>>0);
    if ($210) {
     $$0134176 = $206;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 2:  {
   $211 = (($2) + -1)|0;
   $212 = (($3) + ($211<<1)|0);
   $213 = ($2|0)>(1);
   $214 = ((($0)) + 196|0);
   $215 = HEAP32[$214>>2]|0;
   $216 = ((($0)) + 8|0);
   if ($213) {
    $$0178 = $3;$226 = $215;
    while(1) {
     $223 = HEAP16[$$0178>>1]|0;
     $224 = $223&65535;
     $225 = (($226) + (($224*12)|0)|0);
     $227 = ((($$0178)) + 2|0);
     $228 = HEAP16[$227>>1]|0;
     $229 = $228&65535;
     $230 = (($226) + (($229*12)|0)|0);
     __ZN21ComputeNearFarFunctorI17GreaterComparatorEclERKN3osg5Vec3fES5_b($216,$225,$230,0);
     $231 = ($227>>>0)<($212>>>0);
     $232 = HEAP32[$214>>2]|0;
     if ($231) {
      $$0178 = $227;$226 = $232;
     } else {
      $$lcssa156 = $232;
      break;
     }
    }
   } else {
    $$lcssa156 = $215;
   }
   $217 = HEAP16[$212>>1]|0;
   $218 = $217&65535;
   $219 = (($$lcssa156) + (($218*12)|0)|0);
   $220 = HEAP16[$3>>1]|0;
   $221 = $220&65535;
   $222 = (($$lcssa156) + (($221*12)|0)|0);
   __ZN21ComputeNearFarFunctorI17GreaterComparatorEclERKN3osg5Vec3fES5_b($216,$219,$222,0);
   return;
   break;
  }
  default: {
   return;
  }
  }
 } while(0);
}
function __ZN3osg24TemplatePrimitiveFunctorI21ComputeNearFarFunctorI17GreaterComparatorEE20drawElementsTemplateIhEEvjiPKT_($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0133157 = 0, $$0134176 = 0, $$0135159 = 0, $$0136174 = 0, $$0137158 = 0, $$0138172 = 0, $$0139162 = 0, $$0140170 = 0, $$0141161 = 0, $$0143165 = 0, $$0145164 = 0, $$0178 = 0, $$lcssa156 = 0, $$pre = 0, $$pre190 = 0.0, $$pre191 = 0.0, $$pre192 = 0.0, $$pre193 = 0.0, $$pre194 = 0.0, $$pre196 = 0;
 var $$sroa$015$019$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0;
 var $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0.0, $126 = 0.0, $127 = 0.0, $128 = 0, $129 = 0.0, $13 = 0, $130 = 0.0, $131 = 0.0, $132 = 0.0, $133 = 0, $134 = 0.0;
 var $135 = 0.0, $136 = 0.0, $137 = 0.0, $138 = 0.0, $139 = 0.0, $14 = 0, $140 = 0, $141 = 0.0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0.0, $151 = 0.0, $152 = 0;
 var $153 = 0.0, $154 = 0.0, $155 = 0.0, $156 = 0, $157 = 0.0, $158 = 0.0, $159 = 0.0, $16 = 0, $160 = 0, $161 = 0.0, $162 = 0.0, $163 = 0.0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0;
 var $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0;
 var $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0;
 var $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0;
 var $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0.0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $exitcond189 = 0, $exitcond189213 = 0, $not$$i = 0, $or$cond = 0, $or$cond$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ($3|0)==(0|0);
 $5 = ($2|0)==(0);
 $or$cond = $5 | $4;
 if ($or$cond) {
  return;
 }
 do {
  switch ($1|0) {
  case 4:  {
   $15 = (($3) + ($2)|0);
   $16 = ($2|0)>(0);
   if (!($16)) {
    return;
   }
   $17 = ((($0)) + 8|0);
   $18 = ((($0)) + 196|0);
   $$0133157 = $3;
   while(1) {
    $19 = HEAP32[$18>>2]|0;
    $20 = HEAP8[$$0133157>>0]|0;
    $21 = $20&255;
    $22 = (($19) + (($21*12)|0)|0);
    $23 = ((($$0133157)) + 1|0);
    $24 = HEAP8[$23>>0]|0;
    $25 = $24&255;
    $26 = (($19) + (($25*12)|0)|0);
    $27 = ((($$0133157)) + 2|0);
    $28 = HEAP8[$27>>0]|0;
    $29 = $28&255;
    $30 = (($19) + (($29*12)|0)|0);
    __ZN21ComputeNearFarFunctorI17GreaterComparatorEclERKN3osg5Vec3fES5_S5_b($17,$22,$26,$30,0);
    $31 = ((($$0133157)) + 3|0);
    $32 = ($31>>>0)<($15>>>0);
    if ($32) {
     $$0133157 = $31;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 5:  {
   $12 = ($2|0)>(2);
   if (!($12)) {
    return;
   }
   $13 = ((($0)) + 8|0);
   $14 = ((($0)) + 196|0);
   $$0135159 = $3;$$0137158 = 2;
   while(1) {
    $33 = $$0137158 & 1;
    $34 = ($33|0)==(0);
    $35 = HEAP32[$14>>2]|0;
    $36 = HEAP8[$$0135159>>0]|0;
    $37 = $36&255;
    $38 = (($35) + (($37*12)|0)|0);
    $39 = ((($$0135159)) + 1|0);
    $40 = HEAP8[$39>>0]|0;
    $41 = ((($$0135159)) + 2|0);
    $42 = HEAP8[$41>>0]|0;
    $43 = $40&255;
    $44 = $42&255;
    if ($34) {
     $47 = (($35) + (($43*12)|0)|0);
     $48 = (($35) + (($44*12)|0)|0);
     __ZN21ComputeNearFarFunctorI17GreaterComparatorEclERKN3osg5Vec3fES5_S5_b($13,$38,$47,$48,0);
    } else {
     $45 = (($35) + (($44*12)|0)|0);
     $46 = (($35) + (($43*12)|0)|0);
     __ZN21ComputeNearFarFunctorI17GreaterComparatorEclERKN3osg5Vec3fES5_S5_b($13,$38,$45,$46,0);
    }
    $49 = (($$0137158) + 1)|0;
    $exitcond = ($49|0)==($2|0);
    if ($exitcond) {
     break;
    } else {
     $$0135159 = $39;$$0137158 = $49;
    }
   }
   return;
   break;
  }
  case 7:  {
   $9 = ($2|0)>(3);
   if (!($9)) {
    return;
   }
   $10 = ((($0)) + 8|0);
   $11 = ((($0)) + 196|0);
   $$0139162 = $3;$$0141161 = 3;
   while(1) {
    $50 = HEAP32[$11>>2]|0;
    $51 = HEAP8[$$0139162>>0]|0;
    $52 = $51&255;
    $53 = (($50) + (($52*12)|0)|0);
    $54 = ((($$0139162)) + 1|0);
    $55 = HEAP8[$54>>0]|0;
    $56 = $55&255;
    $57 = (($50) + (($56*12)|0)|0);
    $58 = ((($$0139162)) + 2|0);
    $59 = HEAP8[$58>>0]|0;
    $60 = $59&255;
    $61 = (($50) + (($60*12)|0)|0);
    $62 = ((($$0139162)) + 3|0);
    $63 = HEAP8[$62>>0]|0;
    $64 = $63&255;
    $65 = (($50) + (($64*12)|0)|0);
    __ZN21ComputeNearFarFunctorI17GreaterComparatorEclERKN3osg5Vec3fES5_S5_b($10,$53,$57,$61,0);
    __ZN21ComputeNearFarFunctorI17GreaterComparatorEclERKN3osg5Vec3fES5_S5_b($10,$53,$61,$65,0);
    $66 = (($$0141161) + 4)|0;
    $67 = ((($$0139162)) + 4|0);
    $68 = ($66|0)<($2|0);
    if ($68) {
     $$0139162 = $67;$$0141161 = $66;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 8:  {
   $6 = ($2|0)>(3);
   if (!($6)) {
    return;
   }
   $7 = ((($0)) + 8|0);
   $8 = ((($0)) + 196|0);
   $$0143165 = $3;$$0145164 = 3;
   while(1) {
    $69 = HEAP32[$8>>2]|0;
    $70 = HEAP8[$$0143165>>0]|0;
    $71 = $70&255;
    $72 = (($69) + (($71*12)|0)|0);
    $73 = ((($$0143165)) + 1|0);
    $74 = HEAP8[$73>>0]|0;
    $75 = $74&255;
    $76 = (($69) + (($75*12)|0)|0);
    $77 = ((($$0143165)) + 3|0);
    $78 = HEAP8[$77>>0]|0;
    $79 = $78&255;
    $80 = (($69) + (($79*12)|0)|0);
    $81 = ((($$0143165)) + 2|0);
    $82 = HEAP8[$81>>0]|0;
    $83 = $82&255;
    $84 = (($69) + (($83*12)|0)|0);
    __ZN21ComputeNearFarFunctorI17GreaterComparatorEclERKN3osg5Vec3fES5_S5_b($7,$72,$76,$80,0);
    __ZN21ComputeNearFarFunctorI17GreaterComparatorEclERKN3osg5Vec3fES5_S5_b($7,$72,$80,$84,0);
    $85 = (($$0145164) + 2)|0;
    $86 = ($85|0)<($2|0);
    if ($86) {
     $$0143165 = $81;$$0145164 = $85;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 6: case 9:  {
   $87 = ((($0)) + 196|0);
   $88 = HEAP32[$87>>2]|0;
   $89 = HEAP8[$3>>0]|0;
   $90 = $89&255;
   $91 = (($88) + (($90*12)|0)|0);
   $92 = ($2|0)>(2);
   if (!($92)) {
    return;
   }
   $93 = ((($3)) + 1|0);
   $94 = ((($0)) + 8|0);
   $95 = HEAP8[$93>>0]|0;
   $96 = $95&255;
   $97 = (($88) + (($96*12)|0)|0);
   $98 = ((($3)) + 2|0);
   $99 = HEAP8[$98>>0]|0;
   $100 = $99&255;
   $101 = (($88) + (($100*12)|0)|0);
   __ZN21ComputeNearFarFunctorI17GreaterComparatorEclERKN3osg5Vec3fES5_S5_b($94,$91,$97,$101,0);
   $exitcond189213 = ($2|0)==(3);
   if ($exitcond189213) {
    return;
   } else {
    $103 = $98;$111 = 3;
   }
   while(1) {
    $$pre196 = HEAP32[$87>>2]|0;
    $102 = HEAP8[$103>>0]|0;
    $104 = $102&255;
    $105 = (($$pre196) + (($104*12)|0)|0);
    $106 = ((($103)) + 1|0);
    $107 = HEAP8[$106>>0]|0;
    $108 = $107&255;
    $109 = (($$pre196) + (($108*12)|0)|0);
    __ZN21ComputeNearFarFunctorI17GreaterComparatorEclERKN3osg5Vec3fES5_S5_b($94,$91,$105,$109,0);
    $110 = (($111) + 1)|0;
    $exitcond189 = ($110|0)==($2|0);
    if ($exitcond189) {
     break;
    } else {
     $103 = $106;$111 = $110;
    }
   }
   return;
   break;
  }
  case 0:  {
   $112 = (($3) + ($2)|0);
   $113 = ($2|0)>(0);
   if (!($113)) {
    return;
   }
   $114 = ((($0)) + 8|0);
   $115 = ((($0)) + 196|0);
   $116 = ((($114)) + 32|0);
   $117 = ((($114)) + 64|0);
   $118 = ((($114)) + 96|0);
   $119 = ((($114)) + 128|0);
   $120 = ((($114)) + 8|0);
   $121 = ((($114)) + 144|0);
   $$pre = HEAP32[$115>>2]|0;
   $$pre190 = +HEAPF64[$116>>3];
   $$pre191 = +HEAPF64[$117>>3];
   $$pre192 = +HEAPF64[$118>>3];
   $$pre193 = +HEAPF64[$119>>3];
   $$pre194 = +HEAPF64[$120>>3];
   $$0140170 = $3;$141 = $$pre194;
   while(1) {
    $122 = HEAP8[$$0140170>>0]|0;
    $123 = $122&255;
    $124 = (($$pre) + (($123*12)|0)|0);
    $125 = +HEAPF32[$124>>2];
    $126 = $125;
    $127 = $126 * $$pre190;
    $128 = (((($$pre) + (($123*12)|0)|0)) + 4|0);
    $129 = +HEAPF32[$128>>2];
    $130 = $129;
    $131 = $130 * $$pre191;
    $132 = $127 + $131;
    $133 = (((($$pre) + (($123*12)|0)|0)) + 8|0);
    $134 = +HEAPF32[$133>>2];
    $135 = $134;
    $136 = $135 * $$pre192;
    $137 = $132 + $136;
    $138 = $$pre193 + $137;
    $139 = -$138;
    $140 = $141 >= $139;
    $142 = $138 > -0.0;
    $or$cond$i = $140 | $142;
    L52: do {
     if ($or$cond$i) {
      $232 = $141;
     } else {
      $143 = HEAP32[$121>>2]|0;
      $144 = HEAP32[$143>>2]|0;
      $145 = ((($143)) + 4|0);
      $146 = HEAP32[$145>>2]|0;
      $147 = ($144|0)==($146|0);
      if (!($147)) {
       $$sroa$015$019$i = $144;
       while(1) {
        $150 = +HEAPF64[$$sroa$015$019$i>>3];
        $151 = $126 * $150;
        $152 = ((($$sroa$015$019$i)) + 8|0);
        $153 = +HEAPF64[$152>>3];
        $154 = $130 * $153;
        $155 = $151 + $154;
        $156 = ((($$sroa$015$019$i)) + 16|0);
        $157 = +HEAPF64[$156>>3];
        $158 = $135 * $157;
        $159 = $155 + $158;
        $160 = ((($$sroa$015$019$i)) + 24|0);
        $161 = +HEAPF64[$160>>3];
        $162 = $161 + $159;
        $163 = $162;
        $not$$i = !($163 < 0.0);
        $148 = ((($$sroa$015$019$i)) + 40|0);
        if (!($not$$i)) {
         $232 = $141;
         break L52;
        }
        $149 = ($148|0)==($146|0);
        if ($149) {
         break;
        } else {
         $$sroa$015$019$i = $148;
        }
       }
      }
      HEAPF64[$120>>3] = $139;
      $232 = $139;
     }
    } while(0);
    $164 = ((($$0140170)) + 1|0);
    $165 = ($164>>>0)<($112>>>0);
    if ($165) {
     $$0140170 = $164;$141 = $232;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 1:  {
   $166 = (($2) + -1)|0;
   $167 = (($3) + ($166)|0);
   $168 = ($2|0)>(1);
   if (!($168)) {
    return;
   }
   $169 = ((($0)) + 8|0);
   $170 = ((($0)) + 196|0);
   $$0138172 = $3;
   while(1) {
    $171 = HEAP32[$170>>2]|0;
    $172 = HEAP8[$$0138172>>0]|0;
    $173 = $172&255;
    $174 = (($171) + (($173*12)|0)|0);
    $175 = ((($$0138172)) + 1|0);
    $176 = HEAP8[$175>>0]|0;
    $177 = $176&255;
    $178 = (($171) + (($177*12)|0)|0);
    __ZN21ComputeNearFarFunctorI17GreaterComparatorEclERKN3osg5Vec3fES5_b($169,$174,$178,0);
    $179 = ((($$0138172)) + 2|0);
    $180 = ($179>>>0)<($167>>>0);
    if ($180) {
     $$0138172 = $179;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 3:  {
   $181 = (($2) + -1)|0;
   $182 = (($3) + ($181)|0);
   $183 = ($2|0)>(1);
   if (!($183)) {
    return;
   }
   $184 = ((($0)) + 8|0);
   $185 = ((($0)) + 196|0);
   $$0136174 = $3;
   while(1) {
    $186 = HEAP32[$185>>2]|0;
    $187 = HEAP8[$$0136174>>0]|0;
    $188 = $187&255;
    $189 = (($186) + (($188*12)|0)|0);
    $190 = ((($$0136174)) + 1|0);
    $191 = HEAP8[$190>>0]|0;
    $192 = $191&255;
    $193 = (($186) + (($192*12)|0)|0);
    __ZN21ComputeNearFarFunctorI17GreaterComparatorEclERKN3osg5Vec3fES5_b($184,$189,$193,0);
    $194 = ($190>>>0)<($182>>>0);
    if ($194) {
     $$0136174 = $190;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 11:  {
   $195 = (($2) + -2)|0;
   $196 = (($3) + ($195)|0);
   $197 = ($195|0)>(1);
   if (!($197)) {
    return;
   }
   $198 = ((($3)) + 1|0);
   $199 = ((($0)) + 8|0);
   $200 = ((($0)) + 196|0);
   $$0134176 = $198;
   while(1) {
    $201 = HEAP32[$200>>2]|0;
    $202 = HEAP8[$$0134176>>0]|0;
    $203 = $202&255;
    $204 = (($201) + (($203*12)|0)|0);
    $205 = ((($$0134176)) + 1|0);
    $206 = HEAP8[$205>>0]|0;
    $207 = $206&255;
    $208 = (($201) + (($207*12)|0)|0);
    __ZN21ComputeNearFarFunctorI17GreaterComparatorEclERKN3osg5Vec3fES5_b($199,$204,$208,0);
    $209 = ($205>>>0)<($196>>>0);
    if ($209) {
     $$0134176 = $205;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 2:  {
   $210 = (($2) + -1)|0;
   $211 = (($3) + ($210)|0);
   $212 = ($2|0)>(1);
   $213 = ((($0)) + 196|0);
   $214 = HEAP32[$213>>2]|0;
   $215 = ((($0)) + 8|0);
   if ($212) {
    $$0178 = $3;$225 = $214;
    while(1) {
     $222 = HEAP8[$$0178>>0]|0;
     $223 = $222&255;
     $224 = (($225) + (($223*12)|0)|0);
     $226 = ((($$0178)) + 1|0);
     $227 = HEAP8[$226>>0]|0;
     $228 = $227&255;
     $229 = (($225) + (($228*12)|0)|0);
     __ZN21ComputeNearFarFunctorI17GreaterComparatorEclERKN3osg5Vec3fES5_b($215,$224,$229,0);
     $230 = ($226>>>0)<($211>>>0);
     $231 = HEAP32[$213>>2]|0;
     if ($230) {
      $$0178 = $226;$225 = $231;
     } else {
      $$lcssa156 = $231;
      break;
     }
    }
   } else {
    $$lcssa156 = $214;
   }
   $216 = HEAP8[$211>>0]|0;
   $217 = $216&255;
   $218 = (($$lcssa156) + (($217*12)|0)|0);
   $219 = HEAP8[$3>>0]|0;
   $220 = $219&255;
   $221 = (($$lcssa156) + (($220*12)|0)|0);
   __ZN21ComputeNearFarFunctorI17GreaterComparatorEclERKN3osg5Vec3fES5_b($215,$218,$221,0);
   return;
   break;
  }
  default: {
   return;
  }
  }
 } while(0);
}
function __ZN3osg16PrimitiveFunctorD2Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN3osg16PrimitiveFunctorD0Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($0);
 return;
}
function __ZN3osg24TemplatePrimitiveFunctorI21ComputeNearFarFunctorI14LessComparatorEED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i$i4$i = 0, $scevgep$i$i$i9$i = 0, $scevgep5$i$i$i$i = 0, $scevgep5$i$i$i10$i = 0, $scevgep5$i$i$i5$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 8|0);
 $2 = ((($1)) + 172|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = ((($1)) + 176|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==($3|0);
  if (!($7)) {
   $scevgep$i$i$i$i = ((($6)) + -16|0);
   $8 = $scevgep$i$i$i$i;
   $9 = $3;
   $10 = (($8) - ($9))|0;
   $11 = $10 >>> 4;
   $12 = $11 ^ -1;
   $scevgep5$i$i$i$i = (($6) + ($12<<4)|0);
   HEAP32[$5>>2] = $scevgep5$i$i$i$i;
  }
  __ZdlPv($3);
 }
 $13 = ((($1)) + 160|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(0|0);
 if (!($15)) {
  $16 = ((($1)) + 164|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = ($17|0)==($14|0);
  if (!($18)) {
   $scevgep$i$i$i4$i = ((($17)) + -16|0);
   $19 = $scevgep$i$i$i4$i;
   $20 = $14;
   $21 = (($19) - ($20))|0;
   $22 = $21 >>> 4;
   $23 = $22 ^ -1;
   $scevgep5$i$i$i5$i = (($17) + ($23<<4)|0);
   HEAP32[$16>>2] = $scevgep5$i$i$i5$i;
  }
  __ZdlPv($14);
 }
 $24 = ((($1)) + 148|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)==(0|0);
 if ($26) {
  return;
 }
 $27 = ((($1)) + 152|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = ($28|0)==($25|0);
 if (!($29)) {
  $scevgep$i$i$i9$i = ((($28)) + -16|0);
  $30 = $scevgep$i$i$i9$i;
  $31 = $25;
  $32 = (($30) - ($31))|0;
  $33 = $32 >>> 4;
  $34 = $33 ^ -1;
  $scevgep5$i$i$i10$i = (($28) + ($34<<4)|0);
  HEAP32[$27>>2] = $scevgep5$i$i$i10$i;
 }
 __ZdlPv($25);
 return;
}
function __ZN3osg24TemplatePrimitiveFunctorI21ComputeNearFarFunctorI14LessComparatorEED0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i4$i$i = 0, $scevgep$i$i$i9$i$i = 0, $scevgep5$i$i$i$i$i = 0, $scevgep5$i$i$i10$i$i = 0, $scevgep5$i$i$i5$i$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 8|0);
 $2 = ((($1)) + 172|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = ((($1)) + 176|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==($3|0);
  if (!($7)) {
   $scevgep$i$i$i$i$i = ((($6)) + -16|0);
   $8 = $scevgep$i$i$i$i$i;
   $9 = $3;
   $10 = (($8) - ($9))|0;
   $11 = $10 >>> 4;
   $12 = $11 ^ -1;
   $scevgep5$i$i$i$i$i = (($6) + ($12<<4)|0);
   HEAP32[$5>>2] = $scevgep5$i$i$i$i$i;
  }
  __ZdlPv($3);
 }
 $13 = ((($1)) + 160|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(0|0);
 if (!($15)) {
  $16 = ((($1)) + 164|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = ($17|0)==($14|0);
  if (!($18)) {
   $scevgep$i$i$i4$i$i = ((($17)) + -16|0);
   $19 = $scevgep$i$i$i4$i$i;
   $20 = $14;
   $21 = (($19) - ($20))|0;
   $22 = $21 >>> 4;
   $23 = $22 ^ -1;
   $scevgep5$i$i$i5$i$i = (($17) + ($23<<4)|0);
   HEAP32[$16>>2] = $scevgep5$i$i$i5$i$i;
  }
  __ZdlPv($14);
 }
 $24 = ((($1)) + 148|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)==(0|0);
 if ($26) {
  __ZdlPv($0);
  return;
 }
 $27 = ((($1)) + 152|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = ($28|0)==($25|0);
 if (!($29)) {
  $scevgep$i$i$i9$i$i = ((($28)) + -16|0);
  $30 = $scevgep$i$i$i9$i$i;
  $31 = $25;
  $32 = (($30) - ($31))|0;
  $33 = $32 >>> 4;
  $34 = $33 ^ -1;
  $scevgep5$i$i$i10$i$i = (($28) + ($34<<4)|0);
  HEAP32[$27>>2] = $scevgep5$i$i$i10$i$i;
 }
 __ZdlPv($25);
 __ZdlPv($0);
 return;
}
function __ZN3osg24TemplatePrimitiveFunctorI21ComputeNearFarFunctorI14LessComparatorEE14setVertexArrayEjPKNS_5Vec2fE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
 $5 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($4,115521,53)|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($6)) + -12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($5) + ($8)|0);
 __ZNKSt3__28ios_base6getlocEv($3,$9);
 __THREW__ = 0;
 $10 = (invoke_iii(3255,($3|0),(215188|0))|0);
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if (!($12)) {
  $13 = HEAP32[$10>>2]|0;
  $14 = ((($13)) + 28|0);
  $15 = HEAP32[$14>>2]|0;
  __THREW__ = 0;
  $16 = (invoke_iii($15|0,($10|0),10)|0);
  $17 = __THREW__; __THREW__ = 0;
  $18 = $17&1;
  if (!($18)) {
   __ZNSt3__26localeD2Ev($3);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($5,$16)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($5)|0);
   STACKTOP = sp;return;
  }
 }
 $19 = ___cxa_find_matching_catch_2()|0;
 $20 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($3|0));
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if ($22) {
  $23 = ___cxa_find_matching_catch_3(0|0)|0;
  $24 = tempRet0;
  ___clang_call_terminate($23);
  // unreachable;
 } else {
  ___resumeException($19|0);
  // unreachable;
 }
}
function __ZN3osg24TemplatePrimitiveFunctorI21ComputeNearFarFunctorI14LessComparatorEE14setVertexArrayEjPKNS_5Vec3fE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 192|0);
 HEAP32[$3>>2] = $1;
 $4 = ((($0)) + 196|0);
 HEAP32[$4>>2] = $2;
 return;
}
function __ZN3osg24TemplatePrimitiveFunctorI21ComputeNearFarFunctorI14LessComparatorEE14setVertexArrayEjPKNS_5Vec4fE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
 $5 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($4,115467,53)|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($6)) + -12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($5) + ($8)|0);
 __ZNKSt3__28ios_base6getlocEv($3,$9);
 __THREW__ = 0;
 $10 = (invoke_iii(3255,($3|0),(215188|0))|0);
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if (!($12)) {
  $13 = HEAP32[$10>>2]|0;
  $14 = ((($13)) + 28|0);
  $15 = HEAP32[$14>>2]|0;
  __THREW__ = 0;
  $16 = (invoke_iii($15|0,($10|0),10)|0);
  $17 = __THREW__; __THREW__ = 0;
  $18 = $17&1;
  if (!($18)) {
   __ZNSt3__26localeD2Ev($3);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($5,$16)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($5)|0);
   STACKTOP = sp;return;
  }
 }
 $19 = ___cxa_find_matching_catch_2()|0;
 $20 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($3|0));
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if ($22) {
  $23 = ___cxa_find_matching_catch_3(0|0)|0;
  $24 = tempRet0;
  ___clang_call_terminate($23);
  // unreachable;
 } else {
  ___resumeException($19|0);
  // unreachable;
 }
}
function __ZN3osg24TemplatePrimitiveFunctorI21ComputeNearFarFunctorI14LessComparatorEE14setVertexArrayEjPKNS_5Vec2dE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
 $5 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($4,115412,54)|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($6)) + -12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($5) + ($8)|0);
 __ZNKSt3__28ios_base6getlocEv($3,$9);
 __THREW__ = 0;
 $10 = (invoke_iii(3255,($3|0),(215188|0))|0);
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if (!($12)) {
  $13 = HEAP32[$10>>2]|0;
  $14 = ((($13)) + 28|0);
  $15 = HEAP32[$14>>2]|0;
  __THREW__ = 0;
  $16 = (invoke_iii($15|0,($10|0),10)|0);
  $17 = __THREW__; __THREW__ = 0;
  $18 = $17&1;
  if (!($18)) {
   __ZNSt3__26localeD2Ev($3);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($5,$16)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($5)|0);
   STACKTOP = sp;return;
  }
 }
 $19 = ___cxa_find_matching_catch_2()|0;
 $20 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($3|0));
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if ($22) {
  $23 = ___cxa_find_matching_catch_3(0|0)|0;
  $24 = tempRet0;
  ___clang_call_terminate($23);
  // unreachable;
 } else {
  ___resumeException($19|0);
  // unreachable;
 }
}
function __ZN3osg24TemplatePrimitiveFunctorI21ComputeNearFarFunctorI14LessComparatorEE14setVertexArrayEjPKNS_5Vec3dE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
 $5 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($4,115357,54)|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($6)) + -12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($5) + ($8)|0);
 __ZNKSt3__28ios_base6getlocEv($3,$9);
 __THREW__ = 0;
 $10 = (invoke_iii(3255,($3|0),(215188|0))|0);
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if (!($12)) {
  $13 = HEAP32[$10>>2]|0;
  $14 = ((($13)) + 28|0);
  $15 = HEAP32[$14>>2]|0;
  __THREW__ = 0;
  $16 = (invoke_iii($15|0,($10|0),10)|0);
  $17 = __THREW__; __THREW__ = 0;
  $18 = $17&1;
  if (!($18)) {
   __ZNSt3__26localeD2Ev($3);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($5,$16)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($5)|0);
   STACKTOP = sp;return;
  }
 }
 $19 = ___cxa_find_matching_catch_2()|0;
 $20 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($3|0));
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if ($22) {
  $23 = ___cxa_find_matching_catch_3(0|0)|0;
  $24 = tempRet0;
  ___clang_call_terminate($23);
  // unreachable;
 } else {
  ___resumeException($19|0);
  // unreachable;
 }
}
function __ZN3osg24TemplatePrimitiveFunctorI21ComputeNearFarFunctorI14LessComparatorEE14setVertexArrayEjPKNS_5Vec4dE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
 $5 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($4,115302,54)|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($6)) + -12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($5) + ($8)|0);
 __ZNKSt3__28ios_base6getlocEv($3,$9);
 __THREW__ = 0;
 $10 = (invoke_iii(3255,($3|0),(215188|0))|0);
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if (!($12)) {
  $13 = HEAP32[$10>>2]|0;
  $14 = ((($13)) + 28|0);
  $15 = HEAP32[$14>>2]|0;
  __THREW__ = 0;
  $16 = (invoke_iii($15|0,($10|0),10)|0);
  $17 = __THREW__; __THREW__ = 0;
  $18 = $17&1;
  if (!($18)) {
   __ZNSt3__26localeD2Ev($3);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($5,$16)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($5)|0);
   STACKTOP = sp;return;
  }
 }
 $19 = ___cxa_find_matching_catch_2()|0;
 $20 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($3|0));
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if ($22) {
  $23 = ___cxa_find_matching_catch_3(0|0)|0;
  $24 = tempRet0;
  ___clang_call_terminate($23);
  // unreachable;
 } else {
  ___resumeException($19|0);
  // unreachable;
 }
}
function __ZN3osg24TemplatePrimitiveFunctorI21ComputeNearFarFunctorI14LessComparatorEE10drawArraysEjii($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0131152 = 0, $$0132171 = 0, $$0133154 = 0, $$0134169 = 0, $$0135153 = 0, $$0136167 = 0, $$0137157 = 0, $$0138165 = 0, $$0139156 = 0, $$0140163 = 0, $$0141162 = 0, $$0142160 = 0, $$0143159 = 0, $$0173 = 0, $$pre = 0, $$pre$phiZ2D = 0, $$pre184 = 0.0, $$pre185 = 0.0, $$pre186 = 0.0, $$pre187 = 0.0;
 var $$pre188 = 0.0, $$sroa$015$019$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0.0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0.0, $62 = 0.0, $63 = 0.0, $64 = 0, $65 = 0.0;
 var $66 = 0.0, $67 = 0.0, $68 = 0.0, $69 = 0, $7 = 0, $70 = 0.0, $71 = 0.0, $72 = 0.0, $73 = 0.0, $74 = 0.0, $75 = 0.0, $76 = 0, $77 = 0.0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0.0, $87 = 0.0, $88 = 0, $89 = 0.0, $9 = 0, $90 = 0.0, $91 = 0.0, $92 = 0, $93 = 0.0, $94 = 0.0, $95 = 0.0, $96 = 0, $97 = 0.0, $98 = 0.0, $99 = 0.0, $exitcond = 0, $exitcond183 = 0, $not$$i = 0;
 var $or$cond = 0, $or$cond$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ((($0)) + 196|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 $7 = ($3|0)==(0);
 $or$cond = $7 | $6;
 if ($or$cond) {
  return;
 }
 do {
  switch ($1|0) {
  case 4:  {
   $8 = (($3) + ($2))|0;
   $9 = (($5) + (($8*12)|0)|0);
   $10 = ($3|0)>(0);
   if (!($10)) {
    return;
   }
   $11 = (($5) + (($2*12)|0)|0);
   $12 = ((($0)) + 8|0);
   $$0131152 = $11;
   while(1) {
    $13 = ((($$0131152)) + 12|0);
    $14 = ((($$0131152)) + 24|0);
    __ZN21ComputeNearFarFunctorI14LessComparatorEclERKN3osg5Vec3fES5_S5_b($12,$$0131152,$13,$14,0);
    $15 = ((($$0131152)) + 36|0);
    $16 = ($15>>>0)<($9>>>0);
    if ($16) {
     $$0131152 = $15;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 5:  {
   $17 = ($3|0)>(2);
   if (!($17)) {
    return;
   }
   $18 = (($5) + (($2*12)|0)|0);
   $19 = ((($0)) + 8|0);
   $$0133154 = $18;$$0135153 = 2;
   while(1) {
    $20 = $$0135153 & 1;
    $21 = ($20|0)==(0);
    if ($21) {
     $24 = ((($$0133154)) + 12|0);
     $25 = ((($$0133154)) + 24|0);
     __ZN21ComputeNearFarFunctorI14LessComparatorEclERKN3osg5Vec3fES5_S5_b($19,$$0133154,$24,$25,0);
     $$pre$phiZ2D = $24;
    } else {
     $22 = ((($$0133154)) + 24|0);
     $23 = ((($$0133154)) + 12|0);
     __ZN21ComputeNearFarFunctorI14LessComparatorEclERKN3osg5Vec3fES5_S5_b($19,$$0133154,$22,$23,0);
     $$pre$phiZ2D = $23;
    }
    $26 = (($$0135153) + 1)|0;
    $exitcond = ($26|0)==($3|0);
    if ($exitcond) {
     break;
    } else {
     $$0133154 = $$pre$phiZ2D;$$0135153 = $26;
    }
   }
   return;
   break;
  }
  case 7:  {
   $27 = ($3|0)>(3);
   if (!($27)) {
    return;
   }
   $28 = (($5) + (($2*12)|0)|0);
   $29 = ((($0)) + 8|0);
   $$0137157 = $28;$$0139156 = 3;
   while(1) {
    $30 = ((($$0137157)) + 12|0);
    $31 = ((($$0137157)) + 24|0);
    $32 = ((($$0137157)) + 36|0);
    __ZN21ComputeNearFarFunctorI14LessComparatorEclERKN3osg5Vec3fES5_S5_b($29,$$0137157,$30,$31,0);
    __ZN21ComputeNearFarFunctorI14LessComparatorEclERKN3osg5Vec3fES5_S5_b($29,$$0137157,$31,$32,0);
    $33 = (($$0139156) + 4)|0;
    $34 = ((($$0137157)) + 48|0);
    $35 = ($33|0)<($3|0);
    if ($35) {
     $$0137157 = $34;$$0139156 = $33;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 8:  {
   $36 = ($3|0)>(3);
   if (!($36)) {
    return;
   }
   $37 = (($5) + (($2*12)|0)|0);
   $38 = ((($0)) + 8|0);
   $$0142160 = $37;$$0143159 = 3;
   while(1) {
    $39 = ((($$0142160)) + 12|0);
    $40 = ((($$0142160)) + 36|0);
    $41 = ((($$0142160)) + 24|0);
    __ZN21ComputeNearFarFunctorI14LessComparatorEclERKN3osg5Vec3fES5_S5_b($38,$$0142160,$39,$40,0);
    __ZN21ComputeNearFarFunctorI14LessComparatorEclERKN3osg5Vec3fES5_S5_b($38,$$0142160,$40,$41,0);
    $42 = (($$0143159) + 2)|0;
    $43 = ($42|0)<($3|0);
    if ($43) {
     $$0142160 = $41;$$0143159 = $42;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 6: case 9:  {
   $44 = (($5) + (($2*12)|0)|0);
   $45 = ($3|0)>(2);
   if (!($45)) {
    return;
   }
   $46 = ((($44)) + 12|0);
   $47 = ((($0)) + 8|0);
   $$0140163 = 2;$$0141162 = $46;
   while(1) {
    $48 = ((($$0141162)) + 12|0);
    __ZN21ComputeNearFarFunctorI14LessComparatorEclERKN3osg5Vec3fES5_S5_b($47,$44,$$0141162,$48,0);
    $49 = (($$0140163) + 1)|0;
    $exitcond183 = ($49|0)==($3|0);
    if ($exitcond183) {
     break;
    } else {
     $$0140163 = $49;$$0141162 = $48;
    }
   }
   return;
   break;
  }
  case 0:  {
   $50 = (($3) + ($2))|0;
   $51 = (($5) + (($50*12)|0)|0);
   $52 = ($3|0)>(0);
   if (!($52)) {
    return;
   }
   $53 = (($5) + (($2*12)|0)|0);
   $54 = ((($0)) + 8|0);
   $55 = ((($54)) + 32|0);
   $56 = ((($54)) + 64|0);
   $57 = ((($54)) + 96|0);
   $58 = ((($54)) + 128|0);
   $59 = ((($54)) + 8|0);
   $60 = ((($54)) + 144|0);
   $$pre184 = +HEAPF64[$55>>3];
   $$pre185 = +HEAPF64[$56>>3];
   $$pre186 = +HEAPF64[$57>>3];
   $$pre187 = +HEAPF64[$58>>3];
   $$pre188 = +HEAPF64[$59>>3];
   $$0138165 = $53;$77 = $$pre188;
   while(1) {
    $61 = +HEAPF32[$$0138165>>2];
    $62 = $61;
    $63 = $62 * $$pre184;
    $64 = ((($$0138165)) + 4|0);
    $65 = +HEAPF32[$64>>2];
    $66 = $65;
    $67 = $66 * $$pre185;
    $68 = $63 + $67;
    $69 = ((($$0138165)) + 8|0);
    $70 = +HEAPF32[$69>>2];
    $71 = $70;
    $72 = $71 * $$pre186;
    $73 = $68 + $72;
    $74 = $$pre187 + $73;
    $75 = -$74;
    $76 = $77 <= $75;
    $78 = $74 > -0.0;
    $or$cond$i = $76 | $78;
    L50: do {
     if ($or$cond$i) {
      $138 = $77;
     } else {
      $79 = HEAP32[$60>>2]|0;
      $80 = HEAP32[$79>>2]|0;
      $81 = ((($79)) + 4|0);
      $82 = HEAP32[$81>>2]|0;
      $83 = ($80|0)==($82|0);
      if (!($83)) {
       $$sroa$015$019$i = $80;
       while(1) {
        $86 = +HEAPF64[$$sroa$015$019$i>>3];
        $87 = $62 * $86;
        $88 = ((($$sroa$015$019$i)) + 8|0);
        $89 = +HEAPF64[$88>>3];
        $90 = $66 * $89;
        $91 = $87 + $90;
        $92 = ((($$sroa$015$019$i)) + 16|0);
        $93 = +HEAPF64[$92>>3];
        $94 = $71 * $93;
        $95 = $91 + $94;
        $96 = ((($$sroa$015$019$i)) + 24|0);
        $97 = +HEAPF64[$96>>3];
        $98 = $97 + $95;
        $99 = $98;
        $not$$i = !($99 < 0.0);
        $84 = ((($$sroa$015$019$i)) + 40|0);
        if (!($not$$i)) {
         $138 = $77;
         break L50;
        }
        $85 = ($84|0)==($82|0);
        if ($85) {
         break;
        } else {
         $$sroa$015$019$i = $84;
        }
       }
      }
      HEAPF64[$59>>3] = $75;
      $138 = $75;
     }
    } while(0);
    $100 = ((($$0138165)) + 12|0);
    $101 = ($100>>>0)<($51>>>0);
    if ($101) {
     $$0138165 = $100;$77 = $138;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 1:  {
   $102 = (($2) + -1)|0;
   $103 = (($102) + ($3))|0;
   $104 = (($5) + (($103*12)|0)|0);
   $105 = ($103|0)>($2|0);
   if (!($105)) {
    return;
   }
   $106 = (($5) + (($2*12)|0)|0);
   $107 = ((($0)) + 8|0);
   $$0136167 = $106;
   while(1) {
    $108 = ((($$0136167)) + 12|0);
    __ZN21ComputeNearFarFunctorI14LessComparatorEclERKN3osg5Vec3fES5_b($107,$$0136167,$108,0);
    $109 = ((($$0136167)) + 24|0);
    $110 = ($109>>>0)<($104>>>0);
    if ($110) {
     $$0136167 = $109;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 3:  {
   $111 = (($2) + -1)|0;
   $112 = (($111) + ($3))|0;
   $113 = (($5) + (($112*12)|0)|0);
   $114 = ($112|0)>($2|0);
   if (!($114)) {
    return;
   }
   $115 = (($5) + (($2*12)|0)|0);
   $116 = ((($0)) + 8|0);
   $$0134169 = $115;
   while(1) {
    $117 = ((($$0134169)) + 12|0);
    __ZN21ComputeNearFarFunctorI14LessComparatorEclERKN3osg5Vec3fES5_b($116,$$0134169,$117,0);
    $118 = ($117>>>0)<($113>>>0);
    if ($118) {
     $$0134169 = $117;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 11:  {
   $119 = (($2) + -2)|0;
   $120 = (($119) + ($3))|0;
   $121 = (($5) + (($120*12)|0)|0);
   $122 = (($2) + 1)|0;
   $123 = ($122|0)<($120|0);
   if (!($123)) {
    return;
   }
   $124 = (($5) + (($122*12)|0)|0);
   $125 = ((($0)) + 8|0);
   $$0132171 = $124;
   while(1) {
    $126 = ((($$0132171)) + 12|0);
    __ZN21ComputeNearFarFunctorI14LessComparatorEclERKN3osg5Vec3fES5_b($125,$$0132171,$126,0);
    $127 = ($126>>>0)<($121>>>0);
    if ($127) {
     $$0132171 = $126;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 2:  {
   $128 = (($2) + -1)|0;
   $129 = (($128) + ($3))|0;
   $130 = (($5) + (($129*12)|0)|0);
   $131 = ($129|0)>($2|0);
   $132 = ((($0)) + 8|0);
   if ($131) {
    $133 = (($5) + (($2*12)|0)|0);
    $$0173 = $133;
    while(1) {
     $136 = ((($$0173)) + 12|0);
     __ZN21ComputeNearFarFunctorI14LessComparatorEclERKN3osg5Vec3fES5_b($132,$$0173,$136,0);
     $137 = ($136>>>0)<($130>>>0);
     if ($137) {
      $$0173 = $136;
     } else {
      break;
     }
    }
    $$pre = HEAP32[$4>>2]|0;
    $135 = $$pre;
   } else {
    $135 = $5;
   }
   $134 = (($135) + (($2*12)|0)|0);
   __ZN21ComputeNearFarFunctorI14LessComparatorEclERKN3osg5Vec3fES5_b($132,$130,$134,0);
   return;
   break;
  }
  default: {
   return;
  }
  }
 } while(0);
}
function __ZN3osg24TemplatePrimitiveFunctorI21ComputeNearFarFunctorI14LessComparatorEE12drawElementsEjiPKh($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg24TemplatePrimitiveFunctorI21ComputeNearFarFunctorI14LessComparatorEE20drawElementsTemplateIhEEvjiPKT_($0,$1,$2,$3);
 return;
}
function __ZN3osg24TemplatePrimitiveFunctorI21ComputeNearFarFunctorI14LessComparatorEE12drawElementsEjiPKt($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg24TemplatePrimitiveFunctorI21ComputeNearFarFunctorI14LessComparatorEE20drawElementsTemplateItEEvjiPKT_($0,$1,$2,$3);
 return;
}
function __ZN3osg24TemplatePrimitiveFunctorI21ComputeNearFarFunctorI14LessComparatorEE12drawElementsEjiPKj($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg24TemplatePrimitiveFunctorI21ComputeNearFarFunctorI14LessComparatorEE20drawElementsTemplateIjEEvjiPKT_($0,$1,$2,$3);
 return;
}
function __ZN3osg24TemplatePrimitiveFunctorI21ComputeNearFarFunctorI14LessComparatorEE20drawElementsTemplateIjEEvjiPKT_($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0133157 = 0, $$0134176 = 0, $$0135159 = 0, $$0136174 = 0, $$0137158 = 0, $$0138172 = 0, $$0139162 = 0, $$0140170 = 0, $$0141161 = 0, $$0143165 = 0, $$0145164 = 0, $$0178 = 0, $$lcssa156 = 0, $$pre = 0.0, $$pre190 = 0.0, $$pre191 = 0.0, $$pre192 = 0.0, $$pre193 = 0.0, $$pre195 = 0, $$sroa$015$019$i = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0.0, $107 = 0.0, $108 = 0.0, $109 = 0, $11 = 0, $110 = 0.0, $111 = 0.0, $112 = 0.0, $113 = 0.0, $114 = 0, $115 = 0.0, $116 = 0.0, $117 = 0.0;
 var $118 = 0.0, $119 = 0.0, $12 = 0, $120 = 0.0, $121 = 0, $122 = 0.0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0.0, $132 = 0.0, $133 = 0, $134 = 0.0, $135 = 0.0;
 var $136 = 0.0, $137 = 0, $138 = 0.0, $139 = 0.0, $14 = 0, $140 = 0.0, $141 = 0, $142 = 0.0, $143 = 0.0, $144 = 0.0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0;
 var $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0;
 var $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0;
 var $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0.0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $exitcond = 0, $exitcond189 = 0, $exitcond189212 = 0, $not$$i = 0, $or$cond = 0, $or$cond$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ($3|0)==(0|0);
 $5 = ($2|0)==(0);
 $or$cond = $5 | $4;
 if ($or$cond) {
  return;
 }
 do {
  switch ($1|0) {
  case 4:  {
   $15 = (($3) + ($2<<2)|0);
   $16 = ($2|0)>(0);
   if (!($16)) {
    return;
   }
   $17 = ((($0)) + 8|0);
   $18 = ((($0)) + 196|0);
   $$0133157 = $3;
   while(1) {
    $19 = HEAP32[$18>>2]|0;
    $20 = HEAP32[$$0133157>>2]|0;
    $21 = (($19) + (($20*12)|0)|0);
    $22 = ((($$0133157)) + 4|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = (($19) + (($23*12)|0)|0);
    $25 = ((($$0133157)) + 8|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = (($19) + (($26*12)|0)|0);
    __ZN21ComputeNearFarFunctorI14LessComparatorEclERKN3osg5Vec3fES5_S5_b($17,$21,$24,$27,0);
    $28 = ((($$0133157)) + 12|0);
    $29 = ($28>>>0)<($15>>>0);
    if ($29) {
     $$0133157 = $28;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 5:  {
   $12 = ($2|0)>(2);
   if (!($12)) {
    return;
   }
   $13 = ((($0)) + 8|0);
   $14 = ((($0)) + 196|0);
   $$0135159 = $3;$$0137158 = 2;
   while(1) {
    $30 = $$0137158 & 1;
    $31 = ($30|0)==(0);
    $32 = HEAP32[$14>>2]|0;
    $33 = HEAP32[$$0135159>>2]|0;
    $34 = (($32) + (($33*12)|0)|0);
    $35 = ((($$0135159)) + 4|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = ((($$0135159)) + 8|0);
    $38 = HEAP32[$37>>2]|0;
    if ($31) {
     $41 = (($32) + (($36*12)|0)|0);
     $42 = (($32) + (($38*12)|0)|0);
     __ZN21ComputeNearFarFunctorI14LessComparatorEclERKN3osg5Vec3fES5_S5_b($13,$34,$41,$42,0);
    } else {
     $39 = (($32) + (($38*12)|0)|0);
     $40 = (($32) + (($36*12)|0)|0);
     __ZN21ComputeNearFarFunctorI14LessComparatorEclERKN3osg5Vec3fES5_S5_b($13,$34,$39,$40,0);
    }
    $43 = (($$0137158) + 1)|0;
    $exitcond = ($43|0)==($2|0);
    if ($exitcond) {
     break;
    } else {
     $$0135159 = $35;$$0137158 = $43;
    }
   }
   return;
   break;
  }
  case 7:  {
   $9 = ($2|0)>(3);
   if (!($9)) {
    return;
   }
   $10 = ((($0)) + 8|0);
   $11 = ((($0)) + 196|0);
   $$0139162 = $3;$$0141161 = 3;
   while(1) {
    $44 = HEAP32[$11>>2]|0;
    $45 = HEAP32[$$0139162>>2]|0;
    $46 = (($44) + (($45*12)|0)|0);
    $47 = ((($$0139162)) + 4|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = (($44) + (($48*12)|0)|0);
    $50 = ((($$0139162)) + 8|0);
    $51 = HEAP32[$50>>2]|0;
    $52 = (($44) + (($51*12)|0)|0);
    $53 = ((($$0139162)) + 12|0);
    $54 = HEAP32[$53>>2]|0;
    $55 = (($44) + (($54*12)|0)|0);
    __ZN21ComputeNearFarFunctorI14LessComparatorEclERKN3osg5Vec3fES5_S5_b($10,$46,$49,$52,0);
    __ZN21ComputeNearFarFunctorI14LessComparatorEclERKN3osg5Vec3fES5_S5_b($10,$46,$52,$55,0);
    $56 = (($$0141161) + 4)|0;
    $57 = ((($$0139162)) + 16|0);
    $58 = ($56|0)<($2|0);
    if ($58) {
     $$0139162 = $57;$$0141161 = $56;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 8:  {
   $6 = ($2|0)>(3);
   if (!($6)) {
    return;
   }
   $7 = ((($0)) + 8|0);
   $8 = ((($0)) + 196|0);
   $$0143165 = $3;$$0145164 = 3;
   while(1) {
    $59 = HEAP32[$8>>2]|0;
    $60 = HEAP32[$$0143165>>2]|0;
    $61 = (($59) + (($60*12)|0)|0);
    $62 = ((($$0143165)) + 4|0);
    $63 = HEAP32[$62>>2]|0;
    $64 = (($59) + (($63*12)|0)|0);
    $65 = ((($$0143165)) + 12|0);
    $66 = HEAP32[$65>>2]|0;
    $67 = (($59) + (($66*12)|0)|0);
    $68 = ((($$0143165)) + 8|0);
    $69 = HEAP32[$68>>2]|0;
    $70 = (($59) + (($69*12)|0)|0);
    __ZN21ComputeNearFarFunctorI14LessComparatorEclERKN3osg5Vec3fES5_S5_b($7,$61,$64,$67,0);
    __ZN21ComputeNearFarFunctorI14LessComparatorEclERKN3osg5Vec3fES5_S5_b($7,$61,$67,$70,0);
    $71 = (($$0145164) + 2)|0;
    $72 = ($71|0)<($2|0);
    if ($72) {
     $$0143165 = $68;$$0145164 = $71;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 6: case 9:  {
   $73 = ((($0)) + 196|0);
   $74 = HEAP32[$73>>2]|0;
   $75 = HEAP32[$3>>2]|0;
   $76 = (($74) + (($75*12)|0)|0);
   $77 = ($2|0)>(2);
   if (!($77)) {
    return;
   }
   $78 = ((($3)) + 4|0);
   $79 = ((($0)) + 8|0);
   $80 = HEAP32[$78>>2]|0;
   $81 = (($74) + (($80*12)|0)|0);
   $82 = ((($3)) + 8|0);
   $83 = HEAP32[$82>>2]|0;
   $84 = (($74) + (($83*12)|0)|0);
   __ZN21ComputeNearFarFunctorI14LessComparatorEclERKN3osg5Vec3fES5_S5_b($79,$76,$81,$84,0);
   $exitcond189212 = ($2|0)==(3);
   if ($exitcond189212) {
    return;
   } else {
    $86 = $82;$92 = 3;
   }
   while(1) {
    $$pre195 = HEAP32[$73>>2]|0;
    $85 = HEAP32[$86>>2]|0;
    $87 = (($$pre195) + (($85*12)|0)|0);
    $88 = ((($86)) + 4|0);
    $89 = HEAP32[$88>>2]|0;
    $90 = (($$pre195) + (($89*12)|0)|0);
    __ZN21ComputeNearFarFunctorI14LessComparatorEclERKN3osg5Vec3fES5_S5_b($79,$76,$87,$90,0);
    $91 = (($92) + 1)|0;
    $exitcond189 = ($91|0)==($2|0);
    if ($exitcond189) {
     break;
    } else {
     $86 = $88;$92 = $91;
    }
   }
   return;
   break;
  }
  case 0:  {
   $93 = (($3) + ($2<<2)|0);
   $94 = ($2|0)>(0);
   if (!($94)) {
    return;
   }
   $95 = ((($0)) + 8|0);
   $96 = ((($0)) + 196|0);
   $97 = HEAP32[$96>>2]|0;
   $98 = ((($95)) + 32|0);
   $99 = ((($95)) + 64|0);
   $100 = ((($95)) + 96|0);
   $101 = ((($95)) + 128|0);
   $102 = ((($95)) + 8|0);
   $103 = ((($95)) + 144|0);
   $$pre = +HEAPF64[$98>>3];
   $$pre190 = +HEAPF64[$99>>3];
   $$pre191 = +HEAPF64[$100>>3];
   $$pre192 = +HEAPF64[$101>>3];
   $$pre193 = +HEAPF64[$102>>3];
   $$0140170 = $3;$122 = $$pre193;
   while(1) {
    $104 = HEAP32[$$0140170>>2]|0;
    $105 = (($97) + (($104*12)|0)|0);
    $106 = +HEAPF32[$105>>2];
    $107 = $106;
    $108 = $107 * $$pre;
    $109 = (((($97) + (($104*12)|0)|0)) + 4|0);
    $110 = +HEAPF32[$109>>2];
    $111 = $110;
    $112 = $111 * $$pre190;
    $113 = $108 + $112;
    $114 = (((($97) + (($104*12)|0)|0)) + 8|0);
    $115 = +HEAPF32[$114>>2];
    $116 = $115;
    $117 = $116 * $$pre191;
    $118 = $113 + $117;
    $119 = $$pre192 + $118;
    $120 = -$119;
    $121 = $122 <= $120;
    $123 = $119 > -0.0;
    $or$cond$i = $121 | $123;
    L52: do {
     if ($or$cond$i) {
      $203 = $122;
     } else {
      $124 = HEAP32[$103>>2]|0;
      $125 = HEAP32[$124>>2]|0;
      $126 = ((($124)) + 4|0);
      $127 = HEAP32[$126>>2]|0;
      $128 = ($125|0)==($127|0);
      if (!($128)) {
       $$sroa$015$019$i = $125;
       while(1) {
        $131 = +HEAPF64[$$sroa$015$019$i>>3];
        $132 = $107 * $131;
        $133 = ((($$sroa$015$019$i)) + 8|0);
        $134 = +HEAPF64[$133>>3];
        $135 = $111 * $134;
        $136 = $132 + $135;
        $137 = ((($$sroa$015$019$i)) + 16|0);
        $138 = +HEAPF64[$137>>3];
        $139 = $116 * $138;
        $140 = $136 + $139;
        $141 = ((($$sroa$015$019$i)) + 24|0);
        $142 = +HEAPF64[$141>>3];
        $143 = $142 + $140;
        $144 = $143;
        $not$$i = !($144 < 0.0);
        $129 = ((($$sroa$015$019$i)) + 40|0);
        if (!($not$$i)) {
         $203 = $122;
         break L52;
        }
        $130 = ($129|0)==($127|0);
        if ($130) {
         break;
        } else {
         $$sroa$015$019$i = $129;
        }
       }
      }
      HEAPF64[$102>>3] = $120;
      $203 = $120;
     }
    } while(0);
    $145 = ((($$0140170)) + 4|0);
    $146 = ($145>>>0)<($93>>>0);
    if ($146) {
     $$0140170 = $145;$122 = $203;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 1:  {
   $147 = (($2) + -1)|0;
   $148 = (($3) + ($147<<2)|0);
   $149 = ($2|0)>(1);
   if (!($149)) {
    return;
   }
   $150 = ((($0)) + 8|0);
   $151 = ((($0)) + 196|0);
   $$0138172 = $3;
   while(1) {
    $152 = HEAP32[$151>>2]|0;
    $153 = HEAP32[$$0138172>>2]|0;
    $154 = (($152) + (($153*12)|0)|0);
    $155 = ((($$0138172)) + 4|0);
    $156 = HEAP32[$155>>2]|0;
    $157 = (($152) + (($156*12)|0)|0);
    __ZN21ComputeNearFarFunctorI14LessComparatorEclERKN3osg5Vec3fES5_b($150,$154,$157,0);
    $158 = ((($$0138172)) + 8|0);
    $159 = ($158>>>0)<($148>>>0);
    if ($159) {
     $$0138172 = $158;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 3:  {
   $160 = (($2) + -1)|0;
   $161 = (($3) + ($160<<2)|0);
   $162 = ($2|0)>(1);
   if (!($162)) {
    return;
   }
   $163 = ((($0)) + 8|0);
   $164 = ((($0)) + 196|0);
   $$0136174 = $3;
   while(1) {
    $165 = HEAP32[$164>>2]|0;
    $166 = HEAP32[$$0136174>>2]|0;
    $167 = (($165) + (($166*12)|0)|0);
    $168 = ((($$0136174)) + 4|0);
    $169 = HEAP32[$168>>2]|0;
    $170 = (($165) + (($169*12)|0)|0);
    __ZN21ComputeNearFarFunctorI14LessComparatorEclERKN3osg5Vec3fES5_b($163,$167,$170,0);
    $171 = ($168>>>0)<($161>>>0);
    if ($171) {
     $$0136174 = $168;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 11:  {
   $172 = (($2) + -2)|0;
   $173 = (($3) + ($172<<2)|0);
   $174 = ($172|0)>(1);
   if (!($174)) {
    return;
   }
   $175 = ((($3)) + 4|0);
   $176 = ((($0)) + 8|0);
   $177 = ((($0)) + 196|0);
   $$0134176 = $175;
   while(1) {
    $178 = HEAP32[$177>>2]|0;
    $179 = HEAP32[$$0134176>>2]|0;
    $180 = (($178) + (($179*12)|0)|0);
    $181 = ((($$0134176)) + 4|0);
    $182 = HEAP32[$181>>2]|0;
    $183 = (($178) + (($182*12)|0)|0);
    __ZN21ComputeNearFarFunctorI14LessComparatorEclERKN3osg5Vec3fES5_b($176,$180,$183,0);
    $184 = ($181>>>0)<($173>>>0);
    if ($184) {
     $$0134176 = $181;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 2:  {
   $185 = (($2) + -1)|0;
   $186 = (($3) + ($185<<2)|0);
   $187 = ($2|0)>(1);
   $188 = ((($0)) + 196|0);
   $189 = HEAP32[$188>>2]|0;
   $190 = ((($0)) + 8|0);
   if ($187) {
    $$0178 = $3;$197 = $189;
    while(1) {
     $195 = HEAP32[$$0178>>2]|0;
     $196 = (($197) + (($195*12)|0)|0);
     $198 = ((($$0178)) + 4|0);
     $199 = HEAP32[$198>>2]|0;
     $200 = (($197) + (($199*12)|0)|0);
     __ZN21ComputeNearFarFunctorI14LessComparatorEclERKN3osg5Vec3fES5_b($190,$196,$200,0);
     $201 = ($198>>>0)<($186>>>0);
     $202 = HEAP32[$188>>2]|0;
     if ($201) {
      $$0178 = $198;$197 = $202;
     } else {
      $$lcssa156 = $202;
      break;
     }
    }
   } else {
    $$lcssa156 = $189;
   }
   $191 = HEAP32[$186>>2]|0;
   $192 = (($$lcssa156) + (($191*12)|0)|0);
   $193 = HEAP32[$3>>2]|0;
   $194 = (($$lcssa156) + (($193*12)|0)|0);
   __ZN21ComputeNearFarFunctorI14LessComparatorEclERKN3osg5Vec3fES5_b($190,$192,$194,0);
   return;
   break;
  }
  default: {
   return;
  }
  }
 } while(0);
}
function __ZN21ComputeNearFarFunctorI14LessComparatorEclERKN3osg5Vec3fES5_S5_b($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$$098 = 0, $$0101167 = 0, $$096177 = 0, $$098176 = 0, $$2172 = 0, $$in = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre182 = 0, $$pre183 = 0, $$pre184 = 0, $$pre185 = 0, $$pre186 = 0.0, $$pre187 = 0, $$pre188 = 0, $$pre189 = 0, $$pre189$pre = 0, $$pre190 = 0, $$pre191 = 0, $$pre192 = 0.0;
 var $$sroa$0114$0164 = 0, $$sroa$0124$0$$sroa_idx = 0, $$sroa$0135$0165 = 0, $$sroa$0151$0175 = 0, $$sroa$0151$1170 = 0, $$sroa$4126$0$$sroa_idx128 = 0, $$sroa$5$0$$sroa_idx130 = 0, $10 = 0.0, $100 = 0.0, $101 = 0.0, $102 = 0.0, $103 = 0.0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0.0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0.0, $129 = 0;
 var $13 = 0.0, $130 = 0.0, $131 = 0, $132 = 0.0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0.0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0.0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0.0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0.0, $19 = 0.0, $190 = 0, $191 = 0.0, $192 = 0, $193 = 0.0, $194 = 0, $195 = 0.0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0.0, $200 = 0, $201 = 0;
 var $202 = 0.0, $203 = 0.0, $204 = 0.0, $205 = 0, $206 = 0.0, $207 = 0.0, $208 = 0.0, $209 = 0.0, $21 = 0, $210 = 0, $211 = 0.0, $212 = 0.0, $213 = 0.0, $214 = 0.0, $215 = 0.0, $216 = 0.0, $217 = 0, $218 = 0, $219 = 0, $22 = 0.0;
 var $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0.0, $230 = 0, $231 = 0, $232 = 0.0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0;
 var $239 = 0, $24 = 0, $240 = 0, $241 = 0.0, $242 = 0, $243 = 0, $244 = 0.0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0.0, $25 = 0.0, $250 = 0.0, $251 = 0.0, $252 = 0.0, $253 = 0.0, $254 = 0, $255 = 0, $256 = 0.0;
 var $257 = 0.0, $258 = 0, $259 = 0.0, $26 = 0.0, $260 = 0.0, $261 = 0, $262 = 0.0, $263 = 0.0, $264 = 0, $265 = 0.0, $266 = 0.0, $267 = 0, $268 = 0.0, $269 = 0.0, $27 = 0.0, $270 = 0, $271 = 0.0, $272 = 0.0, $273 = 0.0, $274 = 0.0;
 var $275 = 0.0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0.0, $290 = 0.0, $291 = 0.0, $292 = 0.0;
 var $293 = 0.0, $294 = 0, $295 = 0.0, $296 = 0.0, $297 = 0.0, $298 = 0, $299 = 0.0, $30 = 0.0, $300 = 0.0, $301 = 0.0, $302 = 0.0, $303 = 0, $304 = 0.0, $305 = 0.0, $306 = 0.0, $307 = 0.0, $308 = 0.0, $309 = 0.0, $31 = 0.0, $310 = 0;
 var $311 = 0.0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0.0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0;
 var $33 = 0.0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0.0, $34 = 0.0, $35 = 0, $36 = 0.0, $37 = 0.0, $38 = 0.0, $39 = 0.0, $40 = 0, $41 = 0.0, $42 = 0.0, $43 = 0.0, $44 = 0.0, $45 = 0.0;
 var $46 = 0.0, $47 = 0.0, $48 = 0.0, $49 = 0.0, $5 = 0, $50 = 0, $51 = 0.0, $52 = 0.0, $53 = 0.0, $54 = 0.0, $55 = 0, $56 = 0.0, $57 = 0.0, $58 = 0.0, $59 = 0.0, $6 = 0, $60 = 0.0, $61 = 0.0, $62 = 0, $63 = 0.0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0.0, $77 = 0.0, $78 = 0, $79 = 0.0, $8 = 0, $80 = 0.0, $81 = 0.0;
 var $82 = 0, $83 = 0.0, $84 = 0.0, $85 = 0.0, $86 = 0, $87 = 0.0, $88 = 0.0, $89 = 0.0, $9 = 0.0, $90 = 0.0, $91 = 0.0, $92 = 0.0, $93 = 0.0, $94 = 0.0, $95 = 0.0, $96 = 0.0, $97 = 0.0, $98 = 0.0, $99 = 0.0, $exitcond = 0;
 var $or$cond = 0, $or$cond160 = 0, $or$cond161 = 0, $or$cond3 = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i109 = 0, $scevgep5$i$i$i = 0, $scevgep5$i$i$i110 = 0, $tmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(64|0);
 $5 = sp + 48|0;
 $6 = sp + 32|0;
 $7 = sp + 16|0;
 $8 = sp;
 $9 = +HEAPF32[$1>>2];
 $10 = $9;
 $11 = ((($0)) + 32|0);
 $12 = +HEAPF64[$11>>3];
 $13 = $10 * $12;
 $14 = ((($1)) + 4|0);
 $15 = +HEAPF32[$14>>2];
 $16 = $15;
 $17 = ((($0)) + 64|0);
 $18 = +HEAPF64[$17>>3];
 $19 = $16 * $18;
 $20 = $13 + $19;
 $21 = ((($1)) + 8|0);
 $22 = +HEAPF32[$21>>2];
 $23 = $22;
 $24 = ((($0)) + 96|0);
 $25 = +HEAPF64[$24>>3];
 $26 = $23 * $25;
 $27 = $20 + $26;
 $28 = ((($0)) + 128|0);
 $29 = +HEAPF64[$28>>3];
 $30 = $29 + $27;
 $31 = -$30;
 $32 = +HEAPF32[$2>>2];
 $33 = $32;
 $34 = $12 * $33;
 $35 = ((($2)) + 4|0);
 $36 = +HEAPF32[$35>>2];
 $37 = $36;
 $38 = $18 * $37;
 $39 = $34 + $38;
 $40 = ((($2)) + 8|0);
 $41 = +HEAPF32[$40>>2];
 $42 = $41;
 $43 = $25 * $42;
 $44 = $39 + $43;
 $45 = $29 + $44;
 $46 = -$45;
 $47 = +HEAPF32[$3>>2];
 $48 = $47;
 $49 = $12 * $48;
 $50 = ((($3)) + 4|0);
 $51 = +HEAPF32[$50>>2];
 $52 = $51;
 $53 = $18 * $52;
 $54 = $49 + $53;
 $55 = ((($3)) + 8|0);
 $56 = +HEAPF32[$55>>2];
 $57 = $56;
 $58 = $25 * $57;
 $59 = $54 + $58;
 $60 = $29 + $59;
 $61 = -$60;
 $62 = ((($0)) + 8|0);
 $63 = +HEAPF64[$62>>3];
 $64 = $63 <= $31;
 $65 = $63 <= $46;
 $or$cond160 = $64 & $65;
 $66 = $63 <= $61;
 $or$cond161 = $or$cond160 & $66;
 if ($or$cond161) {
  STACKTOP = sp;return;
 }
 $67 = $30 > -0.0;
 $68 = $45 > -0.0;
 $or$cond = $67 & $68;
 $69 = $60 > -0.0;
 $or$cond3 = $or$cond & $69;
 if ($or$cond3) {
  STACKTOP = sp;return;
 }
 $70 = ((($0)) + 144|0);
 $71 = HEAP32[$70>>2]|0;
 $72 = HEAP32[$71>>2]|0;
 $73 = ((($71)) + 4|0);
 $74 = HEAP32[$73>>2]|0;
 $75 = ($72|0)==($74|0);
 if (!($75)) {
  $$096177 = 1;$$098176 = 0;$$sroa$0151$0175 = $72;
  while(1) {
   $76 = +HEAPF64[$$sroa$0151$0175>>3];
   $77 = $76 * $10;
   $78 = ((($$sroa$0151$0175)) + 8|0);
   $79 = +HEAPF64[$78>>3];
   $80 = $79 * $16;
   $81 = $77 + $80;
   $82 = ((($$sroa$0151$0175)) + 16|0);
   $83 = +HEAPF64[$82>>3];
   $84 = $83 * $23;
   $85 = $81 + $84;
   $86 = ((($$sroa$0151$0175)) + 24|0);
   $87 = +HEAPF64[$86>>3];
   $88 = $87 + $85;
   $89 = $88;
   $90 = $76 * $33;
   $91 = $79 * $37;
   $92 = $90 + $91;
   $93 = $83 * $42;
   $94 = $92 + $93;
   $95 = $87 + $94;
   $96 = $95;
   $97 = $76 * $48;
   $98 = $79 * $52;
   $99 = $97 + $98;
   $100 = $83 * $57;
   $101 = $99 + $100;
   $102 = $87 + $101;
   $103 = $102;
   $104 = $89 < 0.0;
   $105 = $104&1;
   $106 = $96 < 0.0;
   $107 = $106&1;
   $108 = (($107) + ($105))|0;
   $109 = $103 < 0.0;
   $110 = $109&1;
   $111 = (($108) + ($110))|0;
   $112 = ($111|0)==(3);
   if ($112) {
    label = 51;
    break;
   }
   $113 = $89 >= 0.0;
   $114 = $113&1;
   $115 = $96 >= 0.0;
   $116 = $115&1;
   $117 = (($116) + ($114))|0;
   $118 = $103 >= 0.0;
   $119 = $118&1;
   $120 = (($117) + ($119))|0;
   $121 = ($120>>>0)<(3);
   $122 = $121 ? $$096177 : 0;
   $$$098 = $122 | $$098176;
   $123 = $$096177 << 1;
   $124 = ((($$sroa$0151$0175)) + 40|0);
   $125 = ($124|0)==($74|0);
   if ($125) {
    break;
   } else {
    $$096177 = $123;$$098176 = $$$098;$$sroa$0151$0175 = $124;
   }
  }
  if ((label|0) == 51) {
   STACKTOP = sp;return;
  }
  $126 = ($$$098|0)==(0);
  if (!($126)) {
   $133 = ((($0)) + 148|0);
   $134 = HEAP32[$133>>2]|0;
   $135 = ((($0)) + 152|0);
   $136 = HEAP32[$135>>2]|0;
   $137 = ($136|0)==($134|0);
   if ($137) {
    $146 = $134;
   } else {
    $scevgep$i$i$i109 = ((($136)) + -16|0);
    $138 = $scevgep$i$i$i109;
    $139 = $134;
    $140 = (($138) - ($139))|0;
    $141 = $140 >>> 4;
    $142 = $141 ^ -1;
    $scevgep5$i$i$i110 = (($136) + ($142<<4)|0);
    HEAP32[$135>>2] = $scevgep5$i$i$i110;
    $146 = $scevgep5$i$i$i110;
   }
   HEAP32[$5>>2] = 0;
   $143 = ((($5)) + 4|0);
   ;HEAP32[$143>>2]=HEAP32[$1>>2]|0;HEAP32[$143+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$143+8>>2]=HEAP32[$1+8>>2]|0;
   $144 = ((($0)) + 156|0);
   $145 = HEAP32[$144>>2]|0;
   $147 = ($146|0)==($145|0);
   if ($147) {
    __ZNSt3__26vectorINS_4pairIfN3osg5Vec3fEEENS_9allocatorIS4_EEE21__push_back_slow_pathIKS4_EEvRT_($133,$5);
    $$pre = HEAP32[$135>>2]|0;
    $152 = $$pre;
   } else {
    ;HEAP32[$146>>2]=HEAP32[$5>>2]|0;HEAP32[$146+4>>2]=HEAP32[$5+4>>2]|0;HEAP32[$146+8>>2]=HEAP32[$5+8>>2]|0;HEAP32[$146+12>>2]=HEAP32[$5+12>>2]|0;
    $148 = HEAP32[$135>>2]|0;
    $149 = ((($148)) + 16|0);
    HEAP32[$135>>2] = $149;
    $152 = $149;
   }
   HEAP32[$6>>2] = 0;
   $150 = ((($6)) + 4|0);
   ;HEAP32[$150>>2]=HEAP32[$2>>2]|0;HEAP32[$150+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$150+8>>2]=HEAP32[$2+8>>2]|0;
   $151 = HEAP32[$144>>2]|0;
   $153 = ($152|0)==($151|0);
   if ($153) {
    __ZNSt3__26vectorINS_4pairIfN3osg5Vec3fEEENS_9allocatorIS4_EEE21__push_back_slow_pathIKS4_EEvRT_($133,$6);
    $$pre182 = HEAP32[$135>>2]|0;
    $158 = $$pre182;
   } else {
    ;HEAP32[$152>>2]=HEAP32[$6>>2]|0;HEAP32[$152+4>>2]=HEAP32[$6+4>>2]|0;HEAP32[$152+8>>2]=HEAP32[$6+8>>2]|0;HEAP32[$152+12>>2]=HEAP32[$6+12>>2]|0;
    $154 = HEAP32[$135>>2]|0;
    $155 = ((($154)) + 16|0);
    HEAP32[$135>>2] = $155;
    $158 = $155;
   }
   HEAP32[$7>>2] = 0;
   $156 = ((($7)) + 4|0);
   ;HEAP32[$156>>2]=HEAP32[$3>>2]|0;HEAP32[$156+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$156+8>>2]=HEAP32[$3+8>>2]|0;
   $157 = HEAP32[$144>>2]|0;
   $159 = ($158|0)==($157|0);
   if ($159) {
    __ZNSt3__26vectorINS_4pairIfN3osg5Vec3fEEENS_9allocatorIS4_EEE21__push_back_slow_pathIKS4_EEvRT_($133,$7);
   } else {
    ;HEAP32[$158>>2]=HEAP32[$7>>2]|0;HEAP32[$158+4>>2]=HEAP32[$7+4>>2]|0;HEAP32[$158+8>>2]=HEAP32[$7+8>>2]|0;HEAP32[$158+12>>2]=HEAP32[$7+12>>2]|0;
    $160 = HEAP32[$135>>2]|0;
    $161 = ((($160)) + 16|0);
    HEAP32[$135>>2] = $161;
   }
   $162 = HEAP32[$70>>2]|0;
   $163 = HEAP32[$162>>2]|0;
   $164 = ((($162)) + 4|0);
   $165 = HEAP32[$164>>2]|0;
   $166 = ($163|0)==($165|0);
   L30: do {
    if ($166) {
     $$pre190 = HEAP32[$133>>2]|0;
     $$pre191 = HEAP32[$135>>2]|0;
     $287 = $$pre190;$289 = $$pre191;$314 = $$pre191;
    } else {
     $167 = ((($0)) + 160|0);
     $168 = ((($0)) + 164|0);
     $169 = ((($0)) + 168|0);
     $$sroa$0124$0$$sroa_idx = ((($8)) + 4|0);
     $$sroa$4126$0$$sroa_idx128 = ((($8)) + 8|0);
     $$sroa$5$0$$sroa_idx130 = ((($8)) + 12|0);
     $$pre183 = HEAP32[$133>>2]|0;
     $$pre184 = HEAP32[$135>>2]|0;
     $170 = $$pre184;
     $171 = $$pre183;
     $$2172 = 1;$$sroa$0151$1170 = $163;$172 = $$pre183;$174 = $$pre184;$186 = $$pre183;$188 = $$pre184;$197 = $171;$198 = $170;$219 = $$pre184;$315 = $$pre184;$316 = $$pre184;$317 = $$pre183;$318 = $162;$319 = $$pre183;$320 = $$pre183;$321 = $$pre183;
     while(1) {
      $173 = ($172|0)==($174|0);
      if ($173) {
       $287 = $317;$289 = $316;$314 = $315;
       break L30;
      }
      $175 = $$2172 & $$$098;
      $176 = ($175|0)==(0);
      if ($176) {
       $284 = $318;$322 = $315;$323 = $316;$324 = $317;$325 = $319;$326 = $320;$327 = $321;$328 = $197;$329 = $198;$330 = $219;$331 = $188;$332 = $186;$333 = $174;$334 = $172;
      } else {
       $177 = HEAP32[$167>>2]|0;
       $178 = HEAP32[$168>>2]|0;
       $179 = ($178|0)==($177|0);
       $180 = $177;
       if ($179) {
        $$in = $178;
       } else {
        $scevgep$i$i$i = ((($178)) + -16|0);
        $181 = $scevgep$i$i$i;
        $182 = (($181) - ($180))|0;
        $183 = $182 >>> 4;
        $184 = $183 ^ -1;
        $scevgep5$i$i$i = (($178) + ($184<<4)|0);
        HEAP32[$168>>2] = $scevgep5$i$i$i;
        $$in = $scevgep5$i$i$i;
       }
       $185 = $$in;
       $187 = ($186|0)==($188|0);
       if (!($187)) {
        $189 = +HEAPF64[$$sroa$0151$1170>>3];
        $190 = ((($$sroa$0151$1170)) + 8|0);
        $191 = +HEAPF64[$190>>3];
        $192 = ((($$sroa$0151$1170)) + 16|0);
        $193 = +HEAPF64[$192>>3];
        $194 = ((($$sroa$0151$1170)) + 24|0);
        $195 = +HEAPF64[$194>>3];
        $$sroa$0135$0165 = $186;
        while(1) {
         $201 = ((($$sroa$0135$0165)) + 4|0);
         $202 = +HEAPF32[$201>>2];
         $203 = $202;
         $204 = $189 * $203;
         $205 = ((($$sroa$0135$0165)) + 8|0);
         $206 = +HEAPF32[$205>>2];
         $207 = $206;
         $208 = $191 * $207;
         $209 = $204 + $208;
         $210 = ((($$sroa$0135$0165)) + 12|0);
         $211 = +HEAPF32[$210>>2];
         $212 = $211;
         $213 = $193 * $212;
         $214 = $209 + $213;
         $215 = $195 + $214;
         $216 = $215;
         HEAPF32[$$sroa$0135$0165>>2] = $216;
         $217 = ((($$sroa$0135$0165)) + 16|0);
         $218 = ($217|0)==($219|0);
         if ($218) {
          break;
         } else {
          $$sroa$0135$0165 = $217;
         }
        }
       }
       $196 = (($198) - ($197))|0;
       $199 = $196 >> 4;
       $200 = ($199|0)==(0);
       if ($200) {
        $$pre189 = $318;$221 = $180;$223 = $185;
       } else {
        $$0101167 = 0;$231 = $321;$246 = $320;$335 = $319;
        while(1) {
         $228 = (($$0101167) + 1)|0;
         $229 = ($228|0)==($199|0);
         $tmp = $229 ? 0 : $228;
         $230 = (($231) + ($$0101167<<4)|0);
         $232 = +HEAPF32[$230>>2];
         $233 = !($232 >= 0.0);
         do {
          if ($233) {
           $243 = (($231) + ($tmp<<4)|0);
           $244 = +HEAPF32[$243>>2];
           $245 = $244 > 0.0;
           if (!($245)) {
            break;
           }
           $$phi$trans$insert = (($246) + ($tmp<<4)|0);
           $$pre186 = +HEAPF32[$$phi$trans$insert>>2];
           $248 = $246;$251 = $$pre186;$255 = $335;
           label = 41;
          } else {
           $234 = HEAP32[$168>>2]|0;
           $235 = HEAP32[$169>>2]|0;
           $236 = ($234|0)==($235|0);
           if ($236) {
            __ZNSt3__26vectorINS_4pairIfN3osg5Vec3fEEENS_9allocatorIS4_EEE21__push_back_slow_pathIKS4_EEvRT_($167,$230);
           } else {
            ;HEAP32[$234>>2]=HEAP32[$230>>2]|0;HEAP32[$234+4>>2]=HEAP32[$230+4>>2]|0;HEAP32[$234+8>>2]=HEAP32[$230+8>>2]|0;HEAP32[$234+12>>2]=HEAP32[$230+12>>2]|0;
            $237 = HEAP32[$168>>2]|0;
            $238 = ((($237)) + 16|0);
            HEAP32[$168>>2] = $238;
           }
           $239 = HEAP32[$133>>2]|0;
           $240 = (($239) + ($tmp<<4)|0);
           $241 = +HEAPF32[$240>>2];
           $242 = $241 < 0.0;
           if ($242) {
            $248 = $239;$251 = $241;$255 = $239;
            label = 41;
           }
          }
         } while(0);
         if ((label|0) == 41) {
          label = 0;
          $247 = (($248) + ($$0101167<<4)|0);
          $249 = +HEAPF32[$247>>2];
          $250 = $249 - $251;
          $252 = $249 / $250;
          $253 = 1.0 - $252;
          $254 = (((($255) + ($$0101167<<4)|0)) + 4|0);
          $256 = +HEAPF32[$254>>2];
          $257 = $256 * $253;
          $258 = (((($255) + ($$0101167<<4)|0)) + 8|0);
          $259 = +HEAPF32[$258>>2];
          $260 = $253 * $259;
          $261 = (((($255) + ($$0101167<<4)|0)) + 12|0);
          $262 = +HEAPF32[$261>>2];
          $263 = $253 * $262;
          $264 = (((($255) + ($tmp<<4)|0)) + 4|0);
          $265 = +HEAPF32[$264>>2];
          $266 = $252 * $265;
          $267 = (((($255) + ($tmp<<4)|0)) + 8|0);
          $268 = +HEAPF32[$267>>2];
          $269 = $252 * $268;
          $270 = (((($255) + ($tmp<<4)|0)) + 12|0);
          $271 = +HEAPF32[$270>>2];
          $272 = $252 * $271;
          $273 = $257 + $266;
          $274 = $260 + $269;
          $275 = $263 + $272;
          HEAP32[$8>>2] = 0;
          HEAPF32[$$sroa$0124$0$$sroa_idx>>2] = $273;
          HEAPF32[$$sroa$4126$0$$sroa_idx128>>2] = $274;
          HEAPF32[$$sroa$5$0$$sroa_idx130>>2] = $275;
          $276 = HEAP32[$168>>2]|0;
          $277 = HEAP32[$169>>2]|0;
          $278 = ($276|0)==($277|0);
          if ($278) {
           __ZNSt3__26vectorINS_4pairIfN3osg5Vec3fEEENS_9allocatorIS4_EEE21__push_back_slow_pathIKS4_EEvRT_($167,$8);
          } else {
           ;HEAP32[$276>>2]=HEAP32[$8>>2]|0;HEAP32[$276+4>>2]=HEAP32[$8+4>>2]|0;HEAP32[$276+8>>2]=HEAP32[$8+8>>2]|0;HEAP32[$276+12>>2]=HEAP32[$8+12>>2]|0;
           $279 = HEAP32[$168>>2]|0;
           $280 = ((($279)) + 16|0);
           HEAP32[$168>>2] = $280;
          }
         }
         $exitcond = ($228|0)==($199|0);
         if ($exitcond) {
          break;
         }
         $$pre185 = HEAP32[$133>>2]|0;
         $$0101167 = $228;$231 = $$pre185;$246 = $$pre185;$335 = $$pre185;
        }
        $$pre187 = HEAP32[$167>>2]|0;
        $$pre188 = HEAP32[$168>>2]|0;
        $$pre189$pre = HEAP32[$70>>2]|0;
        $$pre189 = $$pre189$pre;$221 = $$pre187;$223 = $$pre188;
       }
       $220 = HEAP32[$133>>2]|0;
       HEAP32[$133>>2] = $221;
       HEAP32[$167>>2] = $220;
       $222 = HEAP32[$135>>2]|0;
       HEAP32[$135>>2] = $223;
       HEAP32[$168>>2] = $222;
       $224 = HEAP32[$144>>2]|0;
       $225 = HEAP32[$169>>2]|0;
       HEAP32[$144>>2] = $225;
       HEAP32[$169>>2] = $224;
       $226 = $221;
       $227 = $223;
       $284 = $$pre189;$322 = $227;$323 = $227;$324 = $226;$325 = $226;$326 = $226;$327 = $226;$328 = $221;$329 = $223;$330 = $227;$331 = $227;$332 = $226;$333 = $227;$334 = $226;
      }
      $281 = $$2172 << 1;
      $282 = ((($$sroa$0151$1170)) + 40|0);
      $283 = ((($284)) + 4|0);
      $285 = HEAP32[$283>>2]|0;
      $286 = ($282|0)==($285|0);
      if ($286) {
       $287 = $324;$289 = $323;$314 = $322;
       break;
      } else {
       $$2172 = $281;$$sroa$0151$1170 = $282;$172 = $334;$174 = $333;$186 = $332;$188 = $331;$197 = $328;$198 = $329;$219 = $330;$315 = $322;$316 = $323;$317 = $324;$318 = $284;$319 = $325;$320 = $326;$321 = $327;
      }
     }
    }
   } while(0);
   $288 = ($287|0)==($289|0);
   if ($288) {
    STACKTOP = sp;return;
   }
   $290 = +HEAPF64[$11>>3];
   $291 = +HEAPF64[$17>>3];
   $292 = +HEAPF64[$24>>3];
   $293 = +HEAPF64[$28>>3];
   $$pre192 = +HEAPF64[$62>>3];
   $$sroa$0114$0164 = $287;$311 = $$pre192;
   while(1) {
    $294 = ((($$sroa$0114$0164)) + 4|0);
    $295 = +HEAPF32[$294>>2];
    $296 = $295;
    $297 = $296 * $290;
    $298 = ((($$sroa$0114$0164)) + 8|0);
    $299 = +HEAPF32[$298>>2];
    $300 = $299;
    $301 = $300 * $291;
    $302 = $297 + $301;
    $303 = ((($$sroa$0114$0164)) + 12|0);
    $304 = +HEAPF32[$303>>2];
    $305 = $304;
    $306 = $305 * $292;
    $307 = $302 + $306;
    $308 = $293 + $307;
    $309 = -$308;
    $310 = $311 > $309;
    if ($310) {
     HEAPF64[$62>>3] = $309;
     $336 = $309;
    } else {
     $336 = $311;
    }
    $312 = ((($$sroa$0114$0164)) + 16|0);
    $313 = ($312|0)==($314|0);
    if ($313) {
     break;
    } else {
     $$sroa$0114$0164 = $312;$311 = $336;
    }
   }
   STACKTOP = sp;return;
  }
 }
 $127 = $63 < $31;
 $128 = $127 ? $63 : $31;
 $129 = $128 < $46;
 $130 = $129 ? $128 : $46;
 $131 = $130 < $61;
 $132 = $131 ? $130 : $61;
 HEAPF64[$62>>3] = $132;
 STACKTOP = sp;return;
}
function __ZN21ComputeNearFarFunctorI14LessComparatorEclERKN3osg5Vec3fES5_b($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$$064 = 0, $$063188 = 0, $$064187 = 0, $$2180 = 0, $$sroa$0161$0186 = 0, $$sroa$0161$1179 = 0, $$sroa$11$0$lcssa = 0.0, $$sroa$11$0174 = 0.0, $$sroa$11$1 = 0.0, $$sroa$12$0$lcssa = 0.0, $$sroa$12$0177 = 0.0, $$sroa$12$1 = 0.0, $$sroa$16$0$lcssa = 0.0, $$sroa$16$0175 = 0.0, $$sroa$16$1 = 0.0, $$sroa$17$0$lcssa = 0.0, $$sroa$17$0178 = 0.0, $$sroa$17$1 = 0.0, $$sroa$5125$0$lcssa = 0.0, $$sroa$5125$0173 = 0.0;
 var $$sroa$5125$1 = 0.0, $$sroa$6144$0$lcssa = 0.0, $$sroa$6144$0176 = 0.0, $$sroa$6144$1 = 0.0, $10 = 0.0, $100 = 0.0, $101 = 0, $102 = 0.0, $103 = 0.0, $104 = 0.0, $105 = 0.0, $106 = 0, $107 = 0.0, $108 = 0.0, $109 = 0.0, $11 = 0.0, $110 = 0.0, $111 = 0, $112 = 0.0, $113 = 0.0;
 var $114 = 0.0, $115 = 0.0, $116 = 0.0, $117 = 0.0, $118 = 0.0, $119 = 0.0, $12 = 0, $120 = 0.0, $121 = 0.0, $122 = 0.0, $123 = 0.0, $124 = 0.0, $125 = 0, $126 = 0, $127 = 0.0, $128 = 0.0, $129 = 0.0, $13 = 0.0, $130 = 0.0, $131 = 0.0;
 var $132 = 0.0, $133 = 0.0, $134 = 0.0, $135 = 0.0, $136 = 0.0, $137 = 0.0, $138 = 0.0, $139 = 0, $14 = 0.0, $140 = 0.0, $141 = 0.0, $142 = 0.0, $143 = 0.0, $144 = 0.0, $145 = 0.0, $146 = 0.0, $147 = 0.0, $148 = 0.0, $149 = 0.0, $15 = 0.0;
 var $150 = 0.0, $151 = 0.0, $152 = 0, $153 = 0, $154 = 0, $155 = 0.0, $156 = 0.0, $157 = 0.0, $158 = 0.0, $159 = 0.0, $16 = 0, $160 = 0.0, $161 = 0.0, $162 = 0.0, $163 = 0.0, $164 = 0.0, $165 = 0.0, $166 = 0.0, $167 = 0.0, $168 = 0.0;
 var $169 = 0.0, $17 = 0.0, $170 = 0.0, $171 = 0.0, $172 = 0.0, $173 = 0.0, $174 = 0.0, $175 = 0, $176 = 0.0, $18 = 0.0, $19 = 0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0, $24 = 0.0, $25 = 0.0, $26 = 0.0, $27 = 0.0, $28 = 0.0;
 var $29 = 0.0, $30 = 0, $31 = 0.0, $32 = 0.0, $33 = 0.0, $34 = 0.0, $35 = 0, $36 = 0.0, $37 = 0.0, $38 = 0.0, $39 = 0.0, $4 = 0.0, $40 = 0.0, $41 = 0.0, $42 = 0, $43 = 0.0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0.0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0.0, $55 = 0.0, $56 = 0, $57 = 0.0, $58 = 0.0, $59 = 0.0, $6 = 0, $60 = 0, $61 = 0.0, $62 = 0.0, $63 = 0.0, $64 = 0, $65 = 0.0;
 var $66 = 0.0, $67 = 0.0, $68 = 0.0, $69 = 0.0, $7 = 0.0, $70 = 0.0, $71 = 0.0, $72 = 0.0, $73 = 0.0, $74 = 0.0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0.0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0.0, $94 = 0, $95 = 0.0, $96 = 0, $97 = 0, $98 = 0.0, $99 = 0.0, $or$cond = 0, $or$cond170 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $4 = +HEAPF32[$1>>2];
 $5 = $4;
 $6 = ((($0)) + 32|0);
 $7 = +HEAPF64[$6>>3];
 $8 = $5 * $7;
 $9 = ((($1)) + 4|0);
 $10 = +HEAPF32[$9>>2];
 $11 = $10;
 $12 = ((($0)) + 64|0);
 $13 = +HEAPF64[$12>>3];
 $14 = $11 * $13;
 $15 = $8 + $14;
 $16 = ((($1)) + 8|0);
 $17 = +HEAPF32[$16>>2];
 $18 = $17;
 $19 = ((($0)) + 96|0);
 $20 = +HEAPF64[$19>>3];
 $21 = $18 * $20;
 $22 = $15 + $21;
 $23 = ((($0)) + 128|0);
 $24 = +HEAPF64[$23>>3];
 $25 = $24 + $22;
 $26 = -$25;
 $27 = +HEAPF32[$2>>2];
 $28 = $27;
 $29 = $7 * $28;
 $30 = ((($2)) + 4|0);
 $31 = +HEAPF32[$30>>2];
 $32 = $31;
 $33 = $13 * $32;
 $34 = $29 + $33;
 $35 = ((($2)) + 8|0);
 $36 = +HEAPF32[$35>>2];
 $37 = $36;
 $38 = $20 * $37;
 $39 = $34 + $38;
 $40 = $24 + $39;
 $41 = -$40;
 $42 = ((($0)) + 8|0);
 $43 = +HEAPF64[$42>>3];
 $44 = $43 <= $26;
 $45 = $43 <= $41;
 $or$cond170 = $44 & $45;
 if ($or$cond170) {
  return;
 }
 $46 = $25 > -0.0;
 $47 = $40 > -0.0;
 $or$cond = $46 & $47;
 if ($or$cond) {
  return;
 }
 $48 = ((($0)) + 144|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = HEAP32[$49>>2]|0;
 $51 = ((($49)) + 4|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = ($50|0)==($52|0);
 if (!($53)) {
  $$063188 = 1;$$064187 = 0;$$sroa$0161$0186 = $50;
  while(1) {
   $54 = +HEAPF64[$$sroa$0161$0186>>3];
   $55 = $54 * $5;
   $56 = ((($$sroa$0161$0186)) + 8|0);
   $57 = +HEAPF64[$56>>3];
   $58 = $57 * $11;
   $59 = $55 + $58;
   $60 = ((($$sroa$0161$0186)) + 16|0);
   $61 = +HEAPF64[$60>>3];
   $62 = $61 * $18;
   $63 = $59 + $62;
   $64 = ((($$sroa$0161$0186)) + 24|0);
   $65 = +HEAPF64[$64>>3];
   $66 = $65 + $63;
   $67 = $66;
   $68 = $54 * $28;
   $69 = $57 * $32;
   $70 = $68 + $69;
   $71 = $61 * $37;
   $72 = $70 + $71;
   $73 = $65 + $72;
   $74 = $73;
   $75 = $67 < 0.0;
   $76 = $75&1;
   $77 = $74 < 0.0;
   $78 = $77&1;
   $79 = (($78) + ($76))|0;
   $80 = ($79|0)==(2);
   if ($80) {
    label = 17;
    break;
   }
   $81 = $$063188 << 1;
   $82 = $67 >= 0.0;
   $83 = $82&1;
   $84 = $74 >= 0.0;
   $85 = $84&1;
   $86 = (($85) + ($83))|0;
   $87 = ($86>>>0)<(2);
   $88 = $87 ? $$063188 : 0;
   $$$064 = $88 | $$064187;
   $89 = ((($$sroa$0161$0186)) + 40|0);
   $90 = ($89|0)==($52|0);
   if ($90) {
    break;
   } else {
    $$063188 = $81;$$064187 = $$$064;$$sroa$0161$0186 = $89;
   }
  }
  if ((label|0) == 17) {
   return;
  }
  $91 = ($$$064|0)==(0);
  if (!($91)) {
   if ($53) {
    $$sroa$11$0$lcssa = $31;$$sroa$12$0$lcssa = $10;$$sroa$16$0$lcssa = $36;$$sroa$17$0$lcssa = $17;$$sroa$5125$0$lcssa = $27;$$sroa$6144$0$lcssa = $4;
   } else {
    $$2180 = 1;$$sroa$0161$1179 = $50;$$sroa$11$0174 = $31;$$sroa$12$0177 = $10;$$sroa$16$0175 = $36;$$sroa$17$0178 = $17;$$sroa$5125$0173 = $27;$$sroa$6144$0176 = $4;
    while(1) {
     $96 = $$2180 & $$$064;
     $97 = ($96|0)==(0);
     do {
      if ($97) {
       $$sroa$11$1 = $$sroa$11$0174;$$sroa$12$1 = $$sroa$12$0177;$$sroa$16$1 = $$sroa$16$0175;$$sroa$17$1 = $$sroa$17$0178;$$sroa$5125$1 = $$sroa$5125$0173;$$sroa$6144$1 = $$sroa$6144$0176;
      } else {
       $98 = +HEAPF64[$$sroa$0161$1179>>3];
       $99 = $$sroa$6144$0176;
       $100 = $99 * $98;
       $101 = ((($$sroa$0161$1179)) + 8|0);
       $102 = +HEAPF64[$101>>3];
       $103 = $$sroa$12$0177;
       $104 = $103 * $102;
       $105 = $100 + $104;
       $106 = ((($$sroa$0161$1179)) + 16|0);
       $107 = +HEAPF64[$106>>3];
       $108 = $$sroa$17$0178;
       $109 = $108 * $107;
       $110 = $105 + $109;
       $111 = ((($$sroa$0161$1179)) + 24|0);
       $112 = +HEAPF64[$111>>3];
       $113 = $112 + $110;
       $114 = $113;
       $115 = $$sroa$5125$0173;
       $116 = $115 * $98;
       $117 = $$sroa$11$0174;
       $118 = $117 * $102;
       $119 = $116 + $118;
       $120 = $$sroa$16$0175;
       $121 = $120 * $107;
       $122 = $119 + $121;
       $123 = $112 + $122;
       $124 = $123;
       $125 = !($114 >= 0.0);
       if ($125) {
        $139 = !($124 >= 0.0);
        if ($139) {
         $$sroa$11$1 = $$sroa$11$0174;$$sroa$12$1 = $$sroa$12$0177;$$sroa$16$1 = $$sroa$16$0175;$$sroa$17$1 = $$sroa$17$0178;$$sroa$5125$1 = $$sroa$5125$0173;$$sroa$6144$1 = $$sroa$6144$0176;
         break;
        }
        $140 = $114 - $124;
        $141 = $114 / $140;
        $142 = 1.0 - $141;
        $143 = $$sroa$6144$0176 * $142;
        $144 = $$sroa$12$0177 * $142;
        $145 = $$sroa$17$0178 * $142;
        $146 = $$sroa$5125$0173 * $141;
        $147 = $$sroa$11$0174 * $141;
        $148 = $$sroa$16$0175 * $141;
        $149 = $146 + $143;
        $150 = $147 + $144;
        $151 = $148 + $145;
        $$sroa$11$1 = $$sroa$11$0174;$$sroa$12$1 = $150;$$sroa$16$1 = $$sroa$16$0175;$$sroa$17$1 = $151;$$sroa$5125$1 = $$sroa$5125$0173;$$sroa$6144$1 = $149;
        break;
       } else {
        $126 = $124 < 0.0;
        if (!($126)) {
         $$sroa$11$1 = $$sroa$11$0174;$$sroa$12$1 = $$sroa$12$0177;$$sroa$16$1 = $$sroa$16$0175;$$sroa$17$1 = $$sroa$17$0178;$$sroa$5125$1 = $$sroa$5125$0173;$$sroa$6144$1 = $$sroa$6144$0176;
         break;
        }
        $127 = $114 - $124;
        $128 = $114 / $127;
        $129 = 1.0 - $128;
        $130 = $$sroa$6144$0176 * $129;
        $131 = $$sroa$12$0177 * $129;
        $132 = $$sroa$17$0178 * $129;
        $133 = $$sroa$5125$0173 * $128;
        $134 = $$sroa$11$0174 * $128;
        $135 = $$sroa$16$0175 * $128;
        $136 = $133 + $130;
        $137 = $134 + $131;
        $138 = $135 + $132;
        $$sroa$11$1 = $137;$$sroa$12$1 = $$sroa$12$0177;$$sroa$16$1 = $138;$$sroa$17$1 = $$sroa$17$0178;$$sroa$5125$1 = $136;$$sroa$6144$1 = $$sroa$6144$0176;
        break;
       }
      }
     } while(0);
     $152 = $$2180 << 1;
     $153 = ((($$sroa$0161$1179)) + 40|0);
     $154 = ($153|0)==($52|0);
     if ($154) {
      $$sroa$11$0$lcssa = $$sroa$11$1;$$sroa$12$0$lcssa = $$sroa$12$1;$$sroa$16$0$lcssa = $$sroa$16$1;$$sroa$17$0$lcssa = $$sroa$17$1;$$sroa$5125$0$lcssa = $$sroa$5125$1;$$sroa$6144$0$lcssa = $$sroa$6144$1;
      break;
     } else {
      $$2180 = $152;$$sroa$0161$1179 = $153;$$sroa$11$0174 = $$sroa$11$1;$$sroa$12$0177 = $$sroa$12$1;$$sroa$16$0175 = $$sroa$16$1;$$sroa$17$0178 = $$sroa$17$1;$$sroa$5125$0173 = $$sroa$5125$1;$$sroa$6144$0176 = $$sroa$6144$1;
     }
    }
   }
   $155 = $$sroa$6144$0$lcssa;
   $156 = $155 * $7;
   $157 = $$sroa$12$0$lcssa;
   $158 = $157 * $13;
   $159 = $156 + $158;
   $160 = $$sroa$17$0$lcssa;
   $161 = $160 * $20;
   $162 = $159 + $161;
   $163 = $24 + $162;
   $164 = -$163;
   $165 = $$sroa$5125$0$lcssa;
   $166 = $165 * $7;
   $167 = $$sroa$11$0$lcssa;
   $168 = $167 * $13;
   $169 = $166 + $168;
   $170 = $$sroa$16$0$lcssa;
   $171 = $170 * $20;
   $172 = $169 + $171;
   $173 = $24 + $172;
   $174 = -$173;
   $175 = $164 < $174;
   $176 = $175 ? $164 : $174;
   HEAPF64[$42>>3] = $176;
   return;
  }
 }
 $92 = $43 < $26;
 $93 = $92 ? $43 : $26;
 $94 = $93 < $41;
 $95 = $94 ? $93 : $41;
 HEAPF64[$42>>3] = $95;
 return;
}
function __ZN3osg24TemplatePrimitiveFunctorI21ComputeNearFarFunctorI14LessComparatorEE20drawElementsTemplateItEEvjiPKT_($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0133157 = 0, $$0134176 = 0, $$0135159 = 0, $$0136174 = 0, $$0137158 = 0, $$0138172 = 0, $$0139162 = 0, $$0140170 = 0, $$0141161 = 0, $$0143165 = 0, $$0145164 = 0, $$0178 = 0, $$lcssa156 = 0, $$pre = 0.0, $$pre190 = 0.0, $$pre191 = 0.0, $$pre192 = 0.0, $$pre193 = 0.0, $$pre195 = 0, $$sroa$015$019$i = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0.0, $127 = 0.0, $128 = 0.0, $129 = 0, $13 = 0, $130 = 0.0, $131 = 0.0, $132 = 0.0, $133 = 0.0, $134 = 0, $135 = 0.0;
 var $136 = 0.0, $137 = 0.0, $138 = 0.0, $139 = 0.0, $14 = 0, $140 = 0.0, $141 = 0, $142 = 0.0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0.0, $152 = 0.0, $153 = 0;
 var $154 = 0.0, $155 = 0.0, $156 = 0.0, $157 = 0, $158 = 0.0, $159 = 0.0, $16 = 0, $160 = 0.0, $161 = 0, $162 = 0.0, $163 = 0.0, $164 = 0.0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0;
 var $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0;
 var $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0;
 var $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0;
 var $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0.0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $exitcond189 = 0, $exitcond189212 = 0, $not$$i = 0, $or$cond = 0, $or$cond$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ($3|0)==(0|0);
 $5 = ($2|0)==(0);
 $or$cond = $5 | $4;
 if ($or$cond) {
  return;
 }
 do {
  switch ($1|0) {
  case 4:  {
   $15 = (($3) + ($2<<1)|0);
   $16 = ($2|0)>(0);
   if (!($16)) {
    return;
   }
   $17 = ((($0)) + 8|0);
   $18 = ((($0)) + 196|0);
   $$0133157 = $3;
   while(1) {
    $19 = HEAP32[$18>>2]|0;
    $20 = HEAP16[$$0133157>>1]|0;
    $21 = $20&65535;
    $22 = (($19) + (($21*12)|0)|0);
    $23 = ((($$0133157)) + 2|0);
    $24 = HEAP16[$23>>1]|0;
    $25 = $24&65535;
    $26 = (($19) + (($25*12)|0)|0);
    $27 = ((($$0133157)) + 4|0);
    $28 = HEAP16[$27>>1]|0;
    $29 = $28&65535;
    $30 = (($19) + (($29*12)|0)|0);
    __ZN21ComputeNearFarFunctorI14LessComparatorEclERKN3osg5Vec3fES5_S5_b($17,$22,$26,$30,0);
    $31 = ((($$0133157)) + 6|0);
    $32 = ($31>>>0)<($15>>>0);
    if ($32) {
     $$0133157 = $31;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 5:  {
   $12 = ($2|0)>(2);
   if (!($12)) {
    return;
   }
   $13 = ((($0)) + 8|0);
   $14 = ((($0)) + 196|0);
   $$0135159 = $3;$$0137158 = 2;
   while(1) {
    $33 = $$0137158 & 1;
    $34 = ($33|0)==(0);
    $35 = HEAP32[$14>>2]|0;
    $36 = HEAP16[$$0135159>>1]|0;
    $37 = $36&65535;
    $38 = (($35) + (($37*12)|0)|0);
    $39 = ((($$0135159)) + 2|0);
    $40 = HEAP16[$39>>1]|0;
    $41 = ((($$0135159)) + 4|0);
    $42 = HEAP16[$41>>1]|0;
    $43 = $40&65535;
    $44 = $42&65535;
    if ($34) {
     $47 = (($35) + (($43*12)|0)|0);
     $48 = (($35) + (($44*12)|0)|0);
     __ZN21ComputeNearFarFunctorI14LessComparatorEclERKN3osg5Vec3fES5_S5_b($13,$38,$47,$48,0);
    } else {
     $45 = (($35) + (($44*12)|0)|0);
     $46 = (($35) + (($43*12)|0)|0);
     __ZN21ComputeNearFarFunctorI14LessComparatorEclERKN3osg5Vec3fES5_S5_b($13,$38,$45,$46,0);
    }
    $49 = (($$0137158) + 1)|0;
    $exitcond = ($49|0)==($2|0);
    if ($exitcond) {
     break;
    } else {
     $$0135159 = $39;$$0137158 = $49;
    }
   }
   return;
   break;
  }
  case 7:  {
   $9 = ($2|0)>(3);
   if (!($9)) {
    return;
   }
   $10 = ((($0)) + 8|0);
   $11 = ((($0)) + 196|0);
   $$0139162 = $3;$$0141161 = 3;
   while(1) {
    $50 = HEAP32[$11>>2]|0;
    $51 = HEAP16[$$0139162>>1]|0;
    $52 = $51&65535;
    $53 = (($50) + (($52*12)|0)|0);
    $54 = ((($$0139162)) + 2|0);
    $55 = HEAP16[$54>>1]|0;
    $56 = $55&65535;
    $57 = (($50) + (($56*12)|0)|0);
    $58 = ((($$0139162)) + 4|0);
    $59 = HEAP16[$58>>1]|0;
    $60 = $59&65535;
    $61 = (($50) + (($60*12)|0)|0);
    $62 = ((($$0139162)) + 6|0);
    $63 = HEAP16[$62>>1]|0;
    $64 = $63&65535;
    $65 = (($50) + (($64*12)|0)|0);
    __ZN21ComputeNearFarFunctorI14LessComparatorEclERKN3osg5Vec3fES5_S5_b($10,$53,$57,$61,0);
    __ZN21ComputeNearFarFunctorI14LessComparatorEclERKN3osg5Vec3fES5_S5_b($10,$53,$61,$65,0);
    $66 = (($$0141161) + 4)|0;
    $67 = ((($$0139162)) + 8|0);
    $68 = ($66|0)<($2|0);
    if ($68) {
     $$0139162 = $67;$$0141161 = $66;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 8:  {
   $6 = ($2|0)>(3);
   if (!($6)) {
    return;
   }
   $7 = ((($0)) + 8|0);
   $8 = ((($0)) + 196|0);
   $$0143165 = $3;$$0145164 = 3;
   while(1) {
    $69 = HEAP32[$8>>2]|0;
    $70 = HEAP16[$$0143165>>1]|0;
    $71 = $70&65535;
    $72 = (($69) + (($71*12)|0)|0);
    $73 = ((($$0143165)) + 2|0);
    $74 = HEAP16[$73>>1]|0;
    $75 = $74&65535;
    $76 = (($69) + (($75*12)|0)|0);
    $77 = ((($$0143165)) + 6|0);
    $78 = HEAP16[$77>>1]|0;
    $79 = $78&65535;
    $80 = (($69) + (($79*12)|0)|0);
    $81 = ((($$0143165)) + 4|0);
    $82 = HEAP16[$81>>1]|0;
    $83 = $82&65535;
    $84 = (($69) + (($83*12)|0)|0);
    __ZN21ComputeNearFarFunctorI14LessComparatorEclERKN3osg5Vec3fES5_S5_b($7,$72,$76,$80,0);
    __ZN21ComputeNearFarFunctorI14LessComparatorEclERKN3osg5Vec3fES5_S5_b($7,$72,$80,$84,0);
    $85 = (($$0145164) + 2)|0;
    $86 = ($85|0)<($2|0);
    if ($86) {
     $$0143165 = $81;$$0145164 = $85;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 6: case 9:  {
   $87 = ((($0)) + 196|0);
   $88 = HEAP32[$87>>2]|0;
   $89 = HEAP16[$3>>1]|0;
   $90 = $89&65535;
   $91 = (($88) + (($90*12)|0)|0);
   $92 = ($2|0)>(2);
   if (!($92)) {
    return;
   }
   $93 = ((($3)) + 2|0);
   $94 = ((($0)) + 8|0);
   $95 = HEAP16[$93>>1]|0;
   $96 = $95&65535;
   $97 = (($88) + (($96*12)|0)|0);
   $98 = ((($3)) + 4|0);
   $99 = HEAP16[$98>>1]|0;
   $100 = $99&65535;
   $101 = (($88) + (($100*12)|0)|0);
   __ZN21ComputeNearFarFunctorI14LessComparatorEclERKN3osg5Vec3fES5_S5_b($94,$91,$97,$101,0);
   $exitcond189212 = ($2|0)==(3);
   if ($exitcond189212) {
    return;
   } else {
    $103 = $98;$111 = 3;
   }
   while(1) {
    $$pre195 = HEAP32[$87>>2]|0;
    $102 = HEAP16[$103>>1]|0;
    $104 = $102&65535;
    $105 = (($$pre195) + (($104*12)|0)|0);
    $106 = ((($103)) + 2|0);
    $107 = HEAP16[$106>>1]|0;
    $108 = $107&65535;
    $109 = (($$pre195) + (($108*12)|0)|0);
    __ZN21ComputeNearFarFunctorI14LessComparatorEclERKN3osg5Vec3fES5_S5_b($94,$91,$105,$109,0);
    $110 = (($111) + 1)|0;
    $exitcond189 = ($110|0)==($2|0);
    if ($exitcond189) {
     break;
    } else {
     $103 = $106;$111 = $110;
    }
   }
   return;
   break;
  }
  case 0:  {
   $112 = (($3) + ($2<<1)|0);
   $113 = ($2|0)>(0);
   if (!($113)) {
    return;
   }
   $114 = ((($0)) + 8|0);
   $115 = ((($0)) + 196|0);
   $116 = HEAP32[$115>>2]|0;
   $117 = ((($114)) + 32|0);
   $118 = ((($114)) + 64|0);
   $119 = ((($114)) + 96|0);
   $120 = ((($114)) + 128|0);
   $121 = ((($114)) + 8|0);
   $122 = ((($114)) + 144|0);
   $$pre = +HEAPF64[$117>>3];
   $$pre190 = +HEAPF64[$118>>3];
   $$pre191 = +HEAPF64[$119>>3];
   $$pre192 = +HEAPF64[$120>>3];
   $$pre193 = +HEAPF64[$121>>3];
   $$0140170 = $3;$142 = $$pre193;
   while(1) {
    $123 = HEAP16[$$0140170>>1]|0;
    $124 = $123&65535;
    $125 = (($116) + (($124*12)|0)|0);
    $126 = +HEAPF32[$125>>2];
    $127 = $126;
    $128 = $127 * $$pre;
    $129 = (((($116) + (($124*12)|0)|0)) + 4|0);
    $130 = +HEAPF32[$129>>2];
    $131 = $130;
    $132 = $131 * $$pre190;
    $133 = $128 + $132;
    $134 = (((($116) + (($124*12)|0)|0)) + 8|0);
    $135 = +HEAPF32[$134>>2];
    $136 = $135;
    $137 = $136 * $$pre191;
    $138 = $133 + $137;
    $139 = $$pre192 + $138;
    $140 = -$139;
    $141 = $142 <= $140;
    $143 = $139 > -0.0;
    $or$cond$i = $141 | $143;
    L52: do {
     if ($or$cond$i) {
      $233 = $142;
     } else {
      $144 = HEAP32[$122>>2]|0;
      $145 = HEAP32[$144>>2]|0;
      $146 = ((($144)) + 4|0);
      $147 = HEAP32[$146>>2]|0;
      $148 = ($145|0)==($147|0);
      if (!($148)) {
       $$sroa$015$019$i = $145;
       while(1) {
        $151 = +HEAPF64[$$sroa$015$019$i>>3];
        $152 = $127 * $151;
        $153 = ((($$sroa$015$019$i)) + 8|0);
        $154 = +HEAPF64[$153>>3];
        $155 = $131 * $154;
        $156 = $152 + $155;
        $157 = ((($$sroa$015$019$i)) + 16|0);
        $158 = +HEAPF64[$157>>3];
        $159 = $136 * $158;
        $160 = $156 + $159;
        $161 = ((($$sroa$015$019$i)) + 24|0);
        $162 = +HEAPF64[$161>>3];
        $163 = $162 + $160;
        $164 = $163;
        $not$$i = !($164 < 0.0);
        $149 = ((($$sroa$015$019$i)) + 40|0);
        if (!($not$$i)) {
         $233 = $142;
         break L52;
        }
        $150 = ($149|0)==($147|0);
        if ($150) {
         break;
        } else {
         $$sroa$015$019$i = $149;
        }
       }
      }
      HEAPF64[$121>>3] = $140;
      $233 = $140;
     }
    } while(0);
    $165 = ((($$0140170)) + 2|0);
    $166 = ($165>>>0)<($112>>>0);
    if ($166) {
     $$0140170 = $165;$142 = $233;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 1:  {
   $167 = (($2) + -1)|0;
   $168 = (($3) + ($167<<1)|0);
   $169 = ($2|0)>(1);
   if (!($169)) {
    return;
   }
   $170 = ((($0)) + 8|0);
   $171 = ((($0)) + 196|0);
   $$0138172 = $3;
   while(1) {
    $172 = HEAP32[$171>>2]|0;
    $173 = HEAP16[$$0138172>>1]|0;
    $174 = $173&65535;
    $175 = (($172) + (($174*12)|0)|0);
    $176 = ((($$0138172)) + 2|0);
    $177 = HEAP16[$176>>1]|0;
    $178 = $177&65535;
    $179 = (($172) + (($178*12)|0)|0);
    __ZN21ComputeNearFarFunctorI14LessComparatorEclERKN3osg5Vec3fES5_b($170,$175,$179,0);
    $180 = ((($$0138172)) + 4|0);
    $181 = ($180>>>0)<($168>>>0);
    if ($181) {
     $$0138172 = $180;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 3:  {
   $182 = (($2) + -1)|0;
   $183 = (($3) + ($182<<1)|0);
   $184 = ($2|0)>(1);
   if (!($184)) {
    return;
   }
   $185 = ((($0)) + 8|0);
   $186 = ((($0)) + 196|0);
   $$0136174 = $3;
   while(1) {
    $187 = HEAP32[$186>>2]|0;
    $188 = HEAP16[$$0136174>>1]|0;
    $189 = $188&65535;
    $190 = (($187) + (($189*12)|0)|0);
    $191 = ((($$0136174)) + 2|0);
    $192 = HEAP16[$191>>1]|0;
    $193 = $192&65535;
    $194 = (($187) + (($193*12)|0)|0);
    __ZN21ComputeNearFarFunctorI14LessComparatorEclERKN3osg5Vec3fES5_b($185,$190,$194,0);
    $195 = ($191>>>0)<($183>>>0);
    if ($195) {
     $$0136174 = $191;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 11:  {
   $196 = (($2) + -2)|0;
   $197 = (($3) + ($196<<1)|0);
   $198 = ($196|0)>(1);
   if (!($198)) {
    return;
   }
   $199 = ((($3)) + 2|0);
   $200 = ((($0)) + 8|0);
   $201 = ((($0)) + 196|0);
   $$0134176 = $199;
   while(1) {
    $202 = HEAP32[$201>>2]|0;
    $203 = HEAP16[$$0134176>>1]|0;
    $204 = $203&65535;
    $205 = (($202) + (($204*12)|0)|0);
    $206 = ((($$0134176)) + 2|0);
    $207 = HEAP16[$206>>1]|0;
    $208 = $207&65535;
    $209 = (($202) + (($208*12)|0)|0);
    __ZN21ComputeNearFarFunctorI14LessComparatorEclERKN3osg5Vec3fES5_b($200,$205,$209,0);
    $210 = ($206>>>0)<($197>>>0);
    if ($210) {
     $$0134176 = $206;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 2:  {
   $211 = (($2) + -1)|0;
   $212 = (($3) + ($211<<1)|0);
   $213 = ($2|0)>(1);
   $214 = ((($0)) + 196|0);
   $215 = HEAP32[$214>>2]|0;
   $216 = ((($0)) + 8|0);
   if ($213) {
    $$0178 = $3;$226 = $215;
    while(1) {
     $223 = HEAP16[$$0178>>1]|0;
     $224 = $223&65535;
     $225 = (($226) + (($224*12)|0)|0);
     $227 = ((($$0178)) + 2|0);
     $228 = HEAP16[$227>>1]|0;
     $229 = $228&65535;
     $230 = (($226) + (($229*12)|0)|0);
     __ZN21ComputeNearFarFunctorI14LessComparatorEclERKN3osg5Vec3fES5_b($216,$225,$230,0);
     $231 = ($227>>>0)<($212>>>0);
     $232 = HEAP32[$214>>2]|0;
     if ($231) {
      $$0178 = $227;$226 = $232;
     } else {
      $$lcssa156 = $232;
      break;
     }
    }
   } else {
    $$lcssa156 = $215;
   }
   $217 = HEAP16[$212>>1]|0;
   $218 = $217&65535;
   $219 = (($$lcssa156) + (($218*12)|0)|0);
   $220 = HEAP16[$3>>1]|0;
   $221 = $220&65535;
   $222 = (($$lcssa156) + (($221*12)|0)|0);
   __ZN21ComputeNearFarFunctorI14LessComparatorEclERKN3osg5Vec3fES5_b($216,$219,$222,0);
   return;
   break;
  }
  default: {
   return;
  }
  }
 } while(0);
}
function __ZN3osg24TemplatePrimitiveFunctorI21ComputeNearFarFunctorI14LessComparatorEE20drawElementsTemplateIhEEvjiPKT_($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0133157 = 0, $$0134176 = 0, $$0135159 = 0, $$0136174 = 0, $$0137158 = 0, $$0138172 = 0, $$0139162 = 0, $$0140170 = 0, $$0141161 = 0, $$0143165 = 0, $$0145164 = 0, $$0178 = 0, $$lcssa156 = 0, $$pre = 0, $$pre190 = 0.0, $$pre191 = 0.0, $$pre192 = 0.0, $$pre193 = 0.0, $$pre194 = 0.0, $$pre196 = 0;
 var $$sroa$015$019$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0;
 var $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0.0, $126 = 0.0, $127 = 0.0, $128 = 0, $129 = 0.0, $13 = 0, $130 = 0.0, $131 = 0.0, $132 = 0.0, $133 = 0, $134 = 0.0;
 var $135 = 0.0, $136 = 0.0, $137 = 0.0, $138 = 0.0, $139 = 0.0, $14 = 0, $140 = 0, $141 = 0.0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0.0, $151 = 0.0, $152 = 0;
 var $153 = 0.0, $154 = 0.0, $155 = 0.0, $156 = 0, $157 = 0.0, $158 = 0.0, $159 = 0.0, $16 = 0, $160 = 0, $161 = 0.0, $162 = 0.0, $163 = 0.0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0;
 var $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0;
 var $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0;
 var $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0;
 var $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0.0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $exitcond189 = 0, $exitcond189213 = 0, $not$$i = 0, $or$cond = 0, $or$cond$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ($3|0)==(0|0);
 $5 = ($2|0)==(0);
 $or$cond = $5 | $4;
 if ($or$cond) {
  return;
 }
 do {
  switch ($1|0) {
  case 4:  {
   $15 = (($3) + ($2)|0);
   $16 = ($2|0)>(0);
   if (!($16)) {
    return;
   }
   $17 = ((($0)) + 8|0);
   $18 = ((($0)) + 196|0);
   $$0133157 = $3;
   while(1) {
    $19 = HEAP32[$18>>2]|0;
    $20 = HEAP8[$$0133157>>0]|0;
    $21 = $20&255;
    $22 = (($19) + (($21*12)|0)|0);
    $23 = ((($$0133157)) + 1|0);
    $24 = HEAP8[$23>>0]|0;
    $25 = $24&255;
    $26 = (($19) + (($25*12)|0)|0);
    $27 = ((($$0133157)) + 2|0);
    $28 = HEAP8[$27>>0]|0;
    $29 = $28&255;
    $30 = (($19) + (($29*12)|0)|0);
    __ZN21ComputeNearFarFunctorI14LessComparatorEclERKN3osg5Vec3fES5_S5_b($17,$22,$26,$30,0);
    $31 = ((($$0133157)) + 3|0);
    $32 = ($31>>>0)<($15>>>0);
    if ($32) {
     $$0133157 = $31;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 5:  {
   $12 = ($2|0)>(2);
   if (!($12)) {
    return;
   }
   $13 = ((($0)) + 8|0);
   $14 = ((($0)) + 196|0);
   $$0135159 = $3;$$0137158 = 2;
   while(1) {
    $33 = $$0137158 & 1;
    $34 = ($33|0)==(0);
    $35 = HEAP32[$14>>2]|0;
    $36 = HEAP8[$$0135159>>0]|0;
    $37 = $36&255;
    $38 = (($35) + (($37*12)|0)|0);
    $39 = ((($$0135159)) + 1|0);
    $40 = HEAP8[$39>>0]|0;
    $41 = ((($$0135159)) + 2|0);
    $42 = HEAP8[$41>>0]|0;
    $43 = $40&255;
    $44 = $42&255;
    if ($34) {
     $47 = (($35) + (($43*12)|0)|0);
     $48 = (($35) + (($44*12)|0)|0);
     __ZN21ComputeNearFarFunctorI14LessComparatorEclERKN3osg5Vec3fES5_S5_b($13,$38,$47,$48,0);
    } else {
     $45 = (($35) + (($44*12)|0)|0);
     $46 = (($35) + (($43*12)|0)|0);
     __ZN21ComputeNearFarFunctorI14LessComparatorEclERKN3osg5Vec3fES5_S5_b($13,$38,$45,$46,0);
    }
    $49 = (($$0137158) + 1)|0;
    $exitcond = ($49|0)==($2|0);
    if ($exitcond) {
     break;
    } else {
     $$0135159 = $39;$$0137158 = $49;
    }
   }
   return;
   break;
  }
  case 7:  {
   $9 = ($2|0)>(3);
   if (!($9)) {
    return;
   }
   $10 = ((($0)) + 8|0);
   $11 = ((($0)) + 196|0);
   $$0139162 = $3;$$0141161 = 3;
   while(1) {
    $50 = HEAP32[$11>>2]|0;
    $51 = HEAP8[$$0139162>>0]|0;
    $52 = $51&255;
    $53 = (($50) + (($52*12)|0)|0);
    $54 = ((($$0139162)) + 1|0);
    $55 = HEAP8[$54>>0]|0;
    $56 = $55&255;
    $57 = (($50) + (($56*12)|0)|0);
    $58 = ((($$0139162)) + 2|0);
    $59 = HEAP8[$58>>0]|0;
    $60 = $59&255;
    $61 = (($50) + (($60*12)|0)|0);
    $62 = ((($$0139162)) + 3|0);
    $63 = HEAP8[$62>>0]|0;
    $64 = $63&255;
    $65 = (($50) + (($64*12)|0)|0);
    __ZN21ComputeNearFarFunctorI14LessComparatorEclERKN3osg5Vec3fES5_S5_b($10,$53,$57,$61,0);
    __ZN21ComputeNearFarFunctorI14LessComparatorEclERKN3osg5Vec3fES5_S5_b($10,$53,$61,$65,0);
    $66 = (($$0141161) + 4)|0;
    $67 = ((($$0139162)) + 4|0);
    $68 = ($66|0)<($2|0);
    if ($68) {
     $$0139162 = $67;$$0141161 = $66;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 8:  {
   $6 = ($2|0)>(3);
   if (!($6)) {
    return;
   }
   $7 = ((($0)) + 8|0);
   $8 = ((($0)) + 196|0);
   $$0143165 = $3;$$0145164 = 3;
   while(1) {
    $69 = HEAP32[$8>>2]|0;
    $70 = HEAP8[$$0143165>>0]|0;
    $71 = $70&255;
    $72 = (($69) + (($71*12)|0)|0);
    $73 = ((($$0143165)) + 1|0);
    $74 = HEAP8[$73>>0]|0;
    $75 = $74&255;
    $76 = (($69) + (($75*12)|0)|0);
    $77 = ((($$0143165)) + 3|0);
    $78 = HEAP8[$77>>0]|0;
    $79 = $78&255;
    $80 = (($69) + (($79*12)|0)|0);
    $81 = ((($$0143165)) + 2|0);
    $82 = HEAP8[$81>>0]|0;
    $83 = $82&255;
    $84 = (($69) + (($83*12)|0)|0);
    __ZN21ComputeNearFarFunctorI14LessComparatorEclERKN3osg5Vec3fES5_S5_b($7,$72,$76,$80,0);
    __ZN21ComputeNearFarFunctorI14LessComparatorEclERKN3osg5Vec3fES5_S5_b($7,$72,$80,$84,0);
    $85 = (($$0145164) + 2)|0;
    $86 = ($85|0)<($2|0);
    if ($86) {
     $$0143165 = $81;$$0145164 = $85;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 6: case 9:  {
   $87 = ((($0)) + 196|0);
   $88 = HEAP32[$87>>2]|0;
   $89 = HEAP8[$3>>0]|0;
   $90 = $89&255;
   $91 = (($88) + (($90*12)|0)|0);
   $92 = ($2|0)>(2);
   if (!($92)) {
    return;
   }
   $93 = ((($3)) + 1|0);
   $94 = ((($0)) + 8|0);
   $95 = HEAP8[$93>>0]|0;
   $96 = $95&255;
   $97 = (($88) + (($96*12)|0)|0);
   $98 = ((($3)) + 2|0);
   $99 = HEAP8[$98>>0]|0;
   $100 = $99&255;
   $101 = (($88) + (($100*12)|0)|0);
   __ZN21ComputeNearFarFunctorI14LessComparatorEclERKN3osg5Vec3fES5_S5_b($94,$91,$97,$101,0);
   $exitcond189213 = ($2|0)==(3);
   if ($exitcond189213) {
    return;
   } else {
    $103 = $98;$111 = 3;
   }
   while(1) {
    $$pre196 = HEAP32[$87>>2]|0;
    $102 = HEAP8[$103>>0]|0;
    $104 = $102&255;
    $105 = (($$pre196) + (($104*12)|0)|0);
    $106 = ((($103)) + 1|0);
    $107 = HEAP8[$106>>0]|0;
    $108 = $107&255;
    $109 = (($$pre196) + (($108*12)|0)|0);
    __ZN21ComputeNearFarFunctorI14LessComparatorEclERKN3osg5Vec3fES5_S5_b($94,$91,$105,$109,0);
    $110 = (($111) + 1)|0;
    $exitcond189 = ($110|0)==($2|0);
    if ($exitcond189) {
     break;
    } else {
     $103 = $106;$111 = $110;
    }
   }
   return;
   break;
  }
  case 0:  {
   $112 = (($3) + ($2)|0);
   $113 = ($2|0)>(0);
   if (!($113)) {
    return;
   }
   $114 = ((($0)) + 8|0);
   $115 = ((($0)) + 196|0);
   $116 = ((($114)) + 32|0);
   $117 = ((($114)) + 64|0);
   $118 = ((($114)) + 96|0);
   $119 = ((($114)) + 128|0);
   $120 = ((($114)) + 8|0);
   $121 = ((($114)) + 144|0);
   $$pre = HEAP32[$115>>2]|0;
   $$pre190 = +HEAPF64[$116>>3];
   $$pre191 = +HEAPF64[$117>>3];
   $$pre192 = +HEAPF64[$118>>3];
   $$pre193 = +HEAPF64[$119>>3];
   $$pre194 = +HEAPF64[$120>>3];
   $$0140170 = $3;$141 = $$pre194;
   while(1) {
    $122 = HEAP8[$$0140170>>0]|0;
    $123 = $122&255;
    $124 = (($$pre) + (($123*12)|0)|0);
    $125 = +HEAPF32[$124>>2];
    $126 = $125;
    $127 = $126 * $$pre190;
    $128 = (((($$pre) + (($123*12)|0)|0)) + 4|0);
    $129 = +HEAPF32[$128>>2];
    $130 = $129;
    $131 = $130 * $$pre191;
    $132 = $127 + $131;
    $133 = (((($$pre) + (($123*12)|0)|0)) + 8|0);
    $134 = +HEAPF32[$133>>2];
    $135 = $134;
    $136 = $135 * $$pre192;
    $137 = $132 + $136;
    $138 = $$pre193 + $137;
    $139 = -$138;
    $140 = $141 <= $139;
    $142 = $138 > -0.0;
    $or$cond$i = $140 | $142;
    L52: do {
     if ($or$cond$i) {
      $232 = $141;
     } else {
      $143 = HEAP32[$121>>2]|0;
      $144 = HEAP32[$143>>2]|0;
      $145 = ((($143)) + 4|0);
      $146 = HEAP32[$145>>2]|0;
      $147 = ($144|0)==($146|0);
      if (!($147)) {
       $$sroa$015$019$i = $144;
       while(1) {
        $150 = +HEAPF64[$$sroa$015$019$i>>3];
        $151 = $126 * $150;
        $152 = ((($$sroa$015$019$i)) + 8|0);
        $153 = +HEAPF64[$152>>3];
        $154 = $130 * $153;
        $155 = $151 + $154;
        $156 = ((($$sroa$015$019$i)) + 16|0);
        $157 = +HEAPF64[$156>>3];
        $158 = $135 * $157;
        $159 = $155 + $158;
        $160 = ((($$sroa$015$019$i)) + 24|0);
        $161 = +HEAPF64[$160>>3];
        $162 = $161 + $159;
        $163 = $162;
        $not$$i = !($163 < 0.0);
        $148 = ((($$sroa$015$019$i)) + 40|0);
        if (!($not$$i)) {
         $232 = $141;
         break L52;
        }
        $149 = ($148|0)==($146|0);
        if ($149) {
         break;
        } else {
         $$sroa$015$019$i = $148;
        }
       }
      }
      HEAPF64[$120>>3] = $139;
      $232 = $139;
     }
    } while(0);
    $164 = ((($$0140170)) + 1|0);
    $165 = ($164>>>0)<($112>>>0);
    if ($165) {
     $$0140170 = $164;$141 = $232;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 1:  {
   $166 = (($2) + -1)|0;
   $167 = (($3) + ($166)|0);
   $168 = ($2|0)>(1);
   if (!($168)) {
    return;
   }
   $169 = ((($0)) + 8|0);
   $170 = ((($0)) + 196|0);
   $$0138172 = $3;
   while(1) {
    $171 = HEAP32[$170>>2]|0;
    $172 = HEAP8[$$0138172>>0]|0;
    $173 = $172&255;
    $174 = (($171) + (($173*12)|0)|0);
    $175 = ((($$0138172)) + 1|0);
    $176 = HEAP8[$175>>0]|0;
    $177 = $176&255;
    $178 = (($171) + (($177*12)|0)|0);
    __ZN21ComputeNearFarFunctorI14LessComparatorEclERKN3osg5Vec3fES5_b($169,$174,$178,0);
    $179 = ((($$0138172)) + 2|0);
    $180 = ($179>>>0)<($167>>>0);
    if ($180) {
     $$0138172 = $179;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 3:  {
   $181 = (($2) + -1)|0;
   $182 = (($3) + ($181)|0);
   $183 = ($2|0)>(1);
   if (!($183)) {
    return;
   }
   $184 = ((($0)) + 8|0);
   $185 = ((($0)) + 196|0);
   $$0136174 = $3;
   while(1) {
    $186 = HEAP32[$185>>2]|0;
    $187 = HEAP8[$$0136174>>0]|0;
    $188 = $187&255;
    $189 = (($186) + (($188*12)|0)|0);
    $190 = ((($$0136174)) + 1|0);
    $191 = HEAP8[$190>>0]|0;
    $192 = $191&255;
    $193 = (($186) + (($192*12)|0)|0);
    __ZN21ComputeNearFarFunctorI14LessComparatorEclERKN3osg5Vec3fES5_b($184,$189,$193,0);
    $194 = ($190>>>0)<($182>>>0);
    if ($194) {
     $$0136174 = $190;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 11:  {
   $195 = (($2) + -2)|0;
   $196 = (($3) + ($195)|0);
   $197 = ($195|0)>(1);
   if (!($197)) {
    return;
   }
   $198 = ((($3)) + 1|0);
   $199 = ((($0)) + 8|0);
   $200 = ((($0)) + 196|0);
   $$0134176 = $198;
   while(1) {
    $201 = HEAP32[$200>>2]|0;
    $202 = HEAP8[$$0134176>>0]|0;
    $203 = $202&255;
    $204 = (($201) + (($203*12)|0)|0);
    $205 = ((($$0134176)) + 1|0);
    $206 = HEAP8[$205>>0]|0;
    $207 = $206&255;
    $208 = (($201) + (($207*12)|0)|0);
    __ZN21ComputeNearFarFunctorI14LessComparatorEclERKN3osg5Vec3fES5_b($199,$204,$208,0);
    $209 = ($205>>>0)<($196>>>0);
    if ($209) {
     $$0134176 = $205;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 2:  {
   $210 = (($2) + -1)|0;
   $211 = (($3) + ($210)|0);
   $212 = ($2|0)>(1);
   $213 = ((($0)) + 196|0);
   $214 = HEAP32[$213>>2]|0;
   $215 = ((($0)) + 8|0);
   if ($212) {
    $$0178 = $3;$225 = $214;
    while(1) {
     $222 = HEAP8[$$0178>>0]|0;
     $223 = $222&255;
     $224 = (($225) + (($223*12)|0)|0);
     $226 = ((($$0178)) + 1|0);
     $227 = HEAP8[$226>>0]|0;
     $228 = $227&255;
     $229 = (($225) + (($228*12)|0)|0);
     __ZN21ComputeNearFarFunctorI14LessComparatorEclERKN3osg5Vec3fES5_b($215,$224,$229,0);
     $230 = ($226>>>0)<($211>>>0);
     $231 = HEAP32[$213>>2]|0;
     if ($230) {
      $$0178 = $226;$225 = $231;
     } else {
      $$lcssa156 = $231;
      break;
     }
    }
   } else {
    $$lcssa156 = $214;
   }
   $216 = HEAP8[$211>>0]|0;
   $217 = $216&255;
   $218 = (($$lcssa156) + (($217*12)|0)|0);
   $219 = HEAP8[$3>>0]|0;
   $220 = $219&255;
   $221 = (($$lcssa156) + (($220*12)|0)|0);
   __ZN21ComputeNearFarFunctorI14LessComparatorEclERKN3osg5Vec3fES5_b($215,$218,$221,0);
   return;
   break;
  }
  default: {
   return;
  }
  }
 } while(0);
}
function __ZN7osgUtil11CullVisitorC1ERKS0_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$6 = 0, $$612 = 0, $$7 = 0, $$713 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp + 8|0;
 $3 = sp;
 $4 = ((($0)) + 508|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = ((($5)) + -12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($1) + ($7)|0);
 HEAP32[$2>>2] = (58136);
 $9 = ((($2)) + 4|0);
 HEAP32[$9>>2] = 0;
 __THREW__ = 0;
 invoke_viii(3468,($4|0),($8|0),($2|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if ($11) {
  $37 = ___cxa_find_matching_catch_2()|0;
  $38 = tempRet0;
  $$7 = $38;$$713 = $37;
  ___resumeException($$713|0);
  // unreachable;
 }
 HEAP32[$3>>2] = (58136);
 $12 = ((($3)) + 4|0);
 HEAP32[$12>>2] = 0;
 __THREW__ = 0;
 invoke_viiii(3634,($0|0),((51912)|0),($1|0),($3|0));
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 do {
  if ($14) {
   $39 = ___cxa_find_matching_catch_2()|0;
   $40 = tempRet0;
   $$6 = $40;$$612 = $39;
  } else {
   $15 = ((($0)) + 56|0);
   $16 = ((($1)) + 56|0);
   __THREW__ = 0;
   invoke_vii(3635,($15|0),($16|0));
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if ($18) {
    $41 = ___cxa_find_matching_catch_2()|0;
    $42 = tempRet0;
    __THREW__ = 0;
    invoke_vii(3284,($0|0),((51912)|0));
    $43 = __THREW__; __THREW__ = 0;
    $44 = $43&1;
    if (!($44)) {
     $$6 = $42;$$612 = $41;
     break;
    }
    $47 = ___cxa_find_matching_catch_3(0|0)|0;
    $48 = tempRet0;
    ___clang_call_terminate($47);
    // unreachable;
   }
   HEAP32[$0>>2] = (51380);
   HEAP32[$4>>2] = (51768);
   HEAP32[$15>>2] = (51604);
   $19 = ((($0)) + 372|0);
   $20 = ((($0)) + 408|0);
   ;HEAP32[$19>>2]=0|0;HEAP32[$19+4>>2]=0|0;HEAP32[$19+8>>2]=0|0;HEAP32[$19+12>>2]=0|0;HEAP32[$19+16>>2]=0|0;HEAP32[$19+20>>2]=0|0;HEAP32[$19+24>>2]=0|0;HEAP32[$19+28>>2]=0|0;
   HEAPF64[$20>>3] = 3.4028234663852886E+38;
   $21 = ((($0)) + 416|0);
   HEAPF64[$21>>3] = -3.4028234663852886E+38;
   $22 = ((($0)) + 424|0);
   $23 = ((($0)) + 484|0);
   HEAP32[$23>>2] = 0;
   $24 = ((($0)) + 488|0);
   HEAP32[$24>>2] = 0;
   $25 = ((($0)) + 484|0);
   $26 = ((($0)) + 480|0);
   dest=$22; stop=dest+56|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
   HEAP32[$26>>2] = $25;
   $27 = ((($0)) + 496|0);
   HEAP32[$27>>2] = 0;
   $28 = ((($0)) + 500|0);
   HEAP32[$28>>2] = 0;
   $29 = ((($0)) + 496|0);
   $30 = ((($0)) + 492|0);
   HEAP32[$30>>2] = $29;
   $31 = ((($0)) + 504|0);
   $32 = ((($1)) + 504|0);
   $33 = HEAP32[$32>>2]|0;
   HEAP32[$31>>2] = $33;
   $34 = ($33|0)==(0|0);
   if ($34) {
    STACKTOP = sp;return;
   }
   $35 = ((($33)) + 8|0);
   $36 = HEAP32[$35>>2]|0;HEAP32[$35>>2] = (($36+1)|0);
   STACKTOP = sp;return;
  }
 } while(0);
 __THREW__ = 0;
 invoke_vi(388,($4|0));
 $45 = __THREW__; __THREW__ = 0;
 $46 = $45&1;
 if ($46) {
  $47 = ___cxa_find_matching_catch_3(0|0)|0;
  $48 = tempRet0;
  ___clang_call_terminate($47);
  // unreachable;
 } else {
  $$7 = $$6;$$713 = $$612;
  ___resumeException($$713|0);
  // unreachable;
 }
}
function __ZN3osg10CullingSet8isCulledERKNS_18BoundingSphereImplINS_5Vec3fEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$$i$i = 0, $$0$i$i = 0, $$01525$i = 0, $$1 = 0, $$sink24$i = 0, $$sroa$08$014 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0.0, $16 = 0.0, $17 = 0, $18 = 0.0, $19 = 0.0, $2 = 0, $20 = 0, $21 = 0.0, $22 = 0.0;
 var $23 = 0, $24 = 0.0, $25 = 0.0, $26 = 0, $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0.0, $31 = 0, $32 = 0.0, $33 = 0.0, $34 = 0.0, $35 = 0, $36 = 0.0, $37 = 0.0, $38 = 0.0, $39 = 0, $4 = 0, $40 = 0.0;
 var $41 = 0.0, $42 = 0.0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0.0, $54 = 0, $55 = 0.0, $56 = 0.0, $57 = 0, $58 = 0.0, $59 = 0;
 var $6 = 0, $60 = 0.0, $61 = 0.0, $62 = 0.0, $63 = 0, $64 = 0.0, $65 = 0, $66 = 0.0, $67 = 0.0, $68 = 0.0, $69 = 0, $7 = 0, $70 = 0.0, $71 = 0.0, $72 = 0, $73 = 0.0, $74 = 0.0, $75 = 0, $76 = 0.0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 & 7;
 $5 = ($4|0)==(0);
 L1: do {
  if (!($5)) {
   $6 = ((($0)) + 16|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($7|0)==(0);
   if (!($8)) {
    $9 = ((($0)) + 36|0);
    HEAP32[$9>>2] = $7;
    $10 = ((($0)) + 40|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ((($0)) + 44|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = ($11|0)==($13|0);
    if (!($14)) {
     $15 = +HEAPF32[$1>>2];
     $16 = $15;
     $17 = ((($1)) + 4|0);
     $18 = +HEAPF32[$17>>2];
     $19 = $18;
     $20 = ((($1)) + 8|0);
     $21 = +HEAPF32[$20>>2];
     $22 = $21;
     $23 = ((($1)) + 12|0);
     $24 = +HEAPF32[$23>>2];
     $25 = -$24;
     $$01525$i = 1;$$sink24$i = $11;$27 = $7;
     while(1) {
      $26 = $$01525$i & $27;
      $28 = ($26|0)==(0);
      if ($28) {
       $89 = $27;
      } else {
       $29 = +HEAPF64[$$sink24$i>>3];
       $30 = $16 * $29;
       $31 = ((($$sink24$i)) + 8|0);
       $32 = +HEAPF64[$31>>3];
       $33 = $19 * $32;
       $34 = $30 + $33;
       $35 = ((($$sink24$i)) + 16|0);
       $36 = +HEAPF64[$35>>3];
       $37 = $22 * $36;
       $38 = $34 + $37;
       $39 = ((($$sink24$i)) + 24|0);
       $40 = +HEAPF64[$39>>3];
       $41 = $40 + $38;
       $42 = $41;
       $43 = $42 > $24;
       $44 = $42 < $25;
       $$$i$i = $44 << 31 >> 31;
       $$0$i$i = $43 ? 1 : $$$i$i;
       $45 = ($$0$i$i|0)<(0);
       if ($45) {
        $$1 = 1;
        break;
       }
       $46 = ($$0$i$i|0)==(0);
       $47 = $$01525$i ^ $27;
       if ($46) {
        $89 = $27;
       } else {
        HEAP32[$9>>2] = $47;
        $89 = $47;
       }
      }
      $48 = $$01525$i << 1;
      $49 = ((($$sink24$i)) + 40|0);
      $50 = ($49|0)==($13|0);
      if ($50) {
       break L1;
      } else {
       $$01525$i = $48;$$sink24$i = $49;$27 = $89;
      }
     }
     return ($$1|0);
    }
   }
  }
 } while(0);
 $51 = $3 & 8;
 $52 = ($51|0)==(0);
 if (!($52)) {
  $53 = +HEAPF32[$1>>2];
  $54 = ((($0)) + 88|0);
  $55 = +HEAPF32[$54>>2];
  $56 = $53 * $55;
  $57 = ((($1)) + 4|0);
  $58 = +HEAPF32[$57>>2];
  $59 = ((($0)) + 92|0);
  $60 = +HEAPF32[$59>>2];
  $61 = $58 * $60;
  $62 = $56 + $61;
  $63 = ((($1)) + 8|0);
  $64 = +HEAPF32[$63>>2];
  $65 = ((($0)) + 96|0);
  $66 = +HEAPF32[$65>>2];
  $67 = $64 * $66;
  $68 = $62 + $67;
  $69 = ((($0)) + 100|0);
  $70 = +HEAPF32[$69>>2];
  $71 = $70 + $68;
  $72 = ((($0)) + 104|0);
  $73 = +HEAPF32[$72>>2];
  $74 = $73 * $71;
  $75 = ((($1)) + 12|0);
  $76 = +HEAPF32[$75>>2];
  $77 = $74 > $76;
  if ($77) {
   $$1 = 1;
   return ($$1|0);
  }
 }
 $78 = $3 & 16;
 $79 = ($78|0)==(0);
 if ($79) {
  $$1 = 0;
  return ($$1|0);
 }
 $80 = ((($0)) + 76|0);
 $81 = HEAP32[$80>>2]|0;
 $82 = ((($0)) + 80|0);
 $83 = HEAP32[$82>>2]|0;
 $84 = ($81|0)==($83|0);
 if ($84) {
  $$1 = 0;
  return ($$1|0);
 } else {
  $$sroa$08$014 = $81;
 }
 while(1) {
  $88 = (__ZN3osg20ShadowVolumeOccluder8containsERKNS_18BoundingSphereImplINS_5Vec3fEEE($$sroa$08$014,$1)|0);
  $86 = ((($$sroa$08$014)) + 80|0);
  if ($88) {
   $$1 = 1;
   label = 16;
   break;
  }
  $85 = HEAP32[$82>>2]|0;
  $87 = ($86|0)==($85|0);
  if ($87) {
   $$1 = 0;
   label = 16;
   break;
  } else {
   $$sroa$08$014 = $86;
  }
 }
 if ((label|0) == 16) {
  return ($$1|0);
 }
 return (0)|0;
}
function __ZN3osg10CullingSet15pushCurrentMaskEv($0) {
 $0 = $0|0;
 var $$pre = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i$i$i = 0, $$pre$i$i1 = 0, $$sroa$010$017 = 0, $$sroa$04$016 = 0, $$sroa$04$08$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 36|0);
 $2 = ((($0)) + 32|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 $$pre$i$i = ((($0)) + 16|0);
 do {
  if (!($4)) {
   $5 = ((($0)) + 24|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ((($0)) + 28|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ($6|0)==($8|0);
   if ($9) {
    $12 = ((($0)) + 20|0);
    __ZNSt3__26vectorIjNS_9allocatorIjEEE21__push_back_slow_pathIKjEEvRT_($12,$$pre$i$i);
    break;
   } else {
    $10 = HEAP32[$$pre$i$i>>2]|0;
    HEAP32[$6>>2] = $10;
    $11 = ((($6)) + 4|0);
    HEAP32[$5>>2] = $11;
    break;
   }
  }
 } while(0);
 $13 = HEAP32[$1>>2]|0;
 HEAP32[$$pre$i$i>>2] = $13;
 $14 = HEAP32[$2>>2]|0;
 $15 = (($14) + 1)|0;
 HEAP32[$2>>2] = $15;
 $16 = ((($0)) + 64|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ((($0)) + 68|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($17|0)==($19|0);
 if (!($20)) {
  $$sroa$010$017 = $17;$85 = $19;
  while(1) {
   $21 = ((($$sroa$010$017)) + 24|0);
   $22 = ((($$sroa$010$017)) + 20|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = ($23|0)==(0);
   $$pre$i$i1 = ((($$sroa$010$017)) + 4|0);
   do {
    if ($24) {
     $38 = $85;
    } else {
     $25 = ((($$sroa$010$017)) + 12|0);
     $26 = HEAP32[$25>>2]|0;
     $27 = ((($$sroa$010$017)) + 16|0);
     $28 = HEAP32[$27>>2]|0;
     $29 = ($26|0)==($28|0);
     if ($29) {
      $32 = ((($$sroa$010$017)) + 8|0);
      __ZNSt3__26vectorIjNS_9allocatorIjEEE21__push_back_slow_pathIKjEEvRT_($32,$$pre$i$i1);
      $$pre = HEAP32[$18>>2]|0;
      $38 = $$pre;
      break;
     } else {
      $30 = HEAP32[$$pre$i$i1>>2]|0;
      HEAP32[$26>>2] = $30;
      $31 = ((($26)) + 4|0);
      HEAP32[$25>>2] = $31;
      $38 = $85;
      break;
     }
    }
   } while(0);
   $33 = HEAP32[$21>>2]|0;
   HEAP32[$$pre$i$i1>>2] = $33;
   $34 = HEAP32[$22>>2]|0;
   $35 = (($34) + 1)|0;
   HEAP32[$22>>2] = $35;
   $36 = ((($$sroa$010$017)) + 52|0);
   $37 = ($36|0)==($38|0);
   if ($37) {
    break;
   } else {
    $$sroa$010$017 = $36;$85 = $38;
   }
  }
 }
 $39 = ((($0)) + 76|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ((($0)) + 80|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ($40|0)==($42|0);
 if ($43) {
  return;
 } else {
  $$sroa$04$016 = $40;
 }
 while(1) {
  $44 = ((($$sroa$04$016)) + 40|0);
  $45 = ((($$sroa$04$016)) + 36|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = ($46|0)==(0);
  $$pre$i$i$i = ((($$sroa$04$016)) + 20|0);
  do {
   if (!($47)) {
    $48 = ((($$sroa$04$016)) + 28|0);
    $49 = HEAP32[$48>>2]|0;
    $50 = ((($$sroa$04$016)) + 32|0);
    $51 = HEAP32[$50>>2]|0;
    $52 = ($49|0)==($51|0);
    if ($52) {
     $55 = ((($$sroa$04$016)) + 24|0);
     __ZNSt3__26vectorIjNS_9allocatorIjEEE21__push_back_slow_pathIKjEEvRT_($55,$$pre$i$i$i);
     break;
    } else {
     $53 = HEAP32[$$pre$i$i$i>>2]|0;
     HEAP32[$49>>2] = $53;
     $54 = ((($49)) + 4|0);
     HEAP32[$48>>2] = $54;
     break;
    }
   }
  } while(0);
  $56 = HEAP32[$44>>2]|0;
  HEAP32[$$pre$i$i$i>>2] = $56;
  $57 = HEAP32[$45>>2]|0;
  $58 = (($57) + 1)|0;
  HEAP32[$45>>2] = $58;
  $59 = ((($$sroa$04$016)) + 68|0);
  $60 = HEAP32[$59>>2]|0;
  $61 = ((($$sroa$04$016)) + 72|0);
  $62 = HEAP32[$61>>2]|0;
  $63 = ($60|0)==($62|0);
  if (!($63)) {
   $$sroa$04$08$i = $60;$86 = $62;
   while(1) {
    $64 = ((($$sroa$04$08$i)) + 20|0);
    $65 = ((($$sroa$04$08$i)) + 16|0);
    $66 = HEAP32[$65>>2]|0;
    $67 = ($66|0)==(0);
    do {
     if ($67) {
      $81 = $86;
     } else {
      $68 = ((($$sroa$04$08$i)) + 8|0);
      $69 = HEAP32[$68>>2]|0;
      $70 = ((($$sroa$04$08$i)) + 12|0);
      $71 = HEAP32[$70>>2]|0;
      $72 = ($69|0)==($71|0);
      if ($72) {
       $75 = ((($$sroa$04$08$i)) + 4|0);
       __ZNSt3__26vectorIjNS_9allocatorIjEEE21__push_back_slow_pathIKjEEvRT_($75,$$sroa$04$08$i);
       $$pre$i = HEAP32[$61>>2]|0;
       $81 = $$pre$i;
       break;
      } else {
       $73 = HEAP32[$$sroa$04$08$i>>2]|0;
       HEAP32[$69>>2] = $73;
       $74 = ((($69)) + 4|0);
       HEAP32[$68>>2] = $74;
       $81 = $86;
       break;
      }
     }
    } while(0);
    $76 = HEAP32[$64>>2]|0;
    HEAP32[$$sroa$04$08$i>>2] = $76;
    $77 = HEAP32[$65>>2]|0;
    $78 = (($77) + 1)|0;
    HEAP32[$65>>2] = $78;
    $79 = ((($$sroa$04$08$i)) + 48|0);
    $80 = ($79|0)==($81|0);
    if ($80) {
     break;
    } else {
     $$sroa$04$08$i = $79;$86 = $81;
    }
   }
  }
  $82 = ((($$sroa$04$016)) + 80|0);
  $83 = HEAP32[$41>>2]|0;
  $84 = ($82|0)==($83|0);
  if ($84) {
   break;
  } else {
   $$sroa$04$016 = $82;
  }
 }
 return;
}
function __ZN3osg9CullStack19createOrReuseMatrixERKNS_7MatrixdE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$013 = 0, $$014 = 0, $$pre = 0, $$pre$i = 0, $$pre33 = 0, $10 = 0, $100 = 0, $101 = 0.0, $102 = 0, $103 = 0, $104 = 0.0, $105 = 0, $106 = 0, $107 = 0.0, $108 = 0, $109 = 0, $11 = 0, $110 = 0.0, $111 = 0;
 var $112 = 0, $113 = 0.0, $114 = 0, $115 = 0, $116 = 0.0, $117 = 0, $118 = 0, $119 = 0.0, $12 = 0, $120 = 0, $121 = 0, $122 = 0.0, $123 = 0, $124 = 0, $125 = 0.0, $126 = 0, $127 = 0, $128 = 0.0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0.0, $132 = 0, $133 = 0, $134 = 0.0, $135 = 0, $136 = 0, $137 = 0.0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0.0, $4 = 0, $40 = 0, $41 = 0, $42 = 0.0, $43 = 0, $44 = 0, $45 = 0.0, $46 = 0, $47 = 0;
 var $48 = 0.0, $49 = 0, $5 = 0, $50 = 0, $51 = 0.0, $52 = 0, $53 = 0, $54 = 0.0, $55 = 0, $56 = 0, $57 = 0.0, $58 = 0, $59 = 0, $6 = 0, $60 = 0.0, $61 = 0, $62 = 0, $63 = 0.0, $64 = 0, $65 = 0;
 var $66 = 0.0, $67 = 0, $68 = 0, $69 = 0.0, $7 = 0, $70 = 0, $71 = 0, $72 = 0.0, $73 = 0, $74 = 0, $75 = 0.0, $76 = 0, $77 = 0, $78 = 0.0, $79 = 0, $8 = 0, $80 = 0, $81 = 0.0, $82 = 0, $83 = 0;
 var $84 = 0.0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0.0, $93 = 0, $94 = 0, $95 = 0.0, $96 = 0, $97 = 0, $98 = 0.0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = ((($0)) + 312|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 300|0);
 $6 = ((($0)) + 304|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$5>>2]|0;
 $9 = (($7) - ($8))|0;
 $10 = $9 >> 2;
 $11 = ($4>>>0)<($10>>>0);
 $12 = $8;
 L1: do {
  if ($11) {
   $14 = $12;$15 = $4;
   while(1) {
    $13 = (($14) + ($15<<2)|0);
    $16 = HEAP32[$13>>2]|0;
    /* fence */;
    $17 = ((($16)) + 8|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = ($18|0)>(1);
    $20 = HEAP32[$3>>2]|0;
    if (!($19)) {
     break;
    }
    $21 = (($20) + 1)|0;
    HEAP32[$3>>2] = $21;
    $22 = HEAP32[$6>>2]|0;
    $23 = HEAP32[$5>>2]|0;
    $24 = (($22) - ($23))|0;
    $25 = $24 >> 2;
    $26 = ($21>>>0)<($25>>>0);
    $27 = $23;
    if ($26) {
     $14 = $27;$15 = $21;
    } else {
     $30 = $23;$31 = $22;$33 = $21;$37 = $27;
     break L1;
    }
   }
   $$pre = HEAP32[$6>>2]|0;
   $$pre33 = HEAP32[$5>>2]|0;
   $28 = $$pre33;
   $30 = $$pre33;$31 = $$pre;$33 = $20;$37 = $28;
  } else {
   $30 = $8;$31 = $7;$33 = $4;$37 = $12;
  }
 } while(0);
 $29 = (($31) - ($30))|0;
 $32 = $29 >> 2;
 $34 = ($33>>>0)<($32>>>0);
 if ($34) {
  $35 = (($33) + 1)|0;
  HEAP32[$3>>2] = $35;
  $36 = (($37) + ($33<<2)|0);
  $38 = HEAP32[$36>>2]|0;
  $39 = +HEAPF64[$1>>3];
  $40 = ((($38)) + 32|0);
  HEAPF64[$40>>3] = $39;
  $41 = ((($1)) + 8|0);
  $42 = +HEAPF64[$41>>3];
  $43 = ((($38)) + 40|0);
  HEAPF64[$43>>3] = $42;
  $44 = ((($1)) + 16|0);
  $45 = +HEAPF64[$44>>3];
  $46 = ((($38)) + 48|0);
  HEAPF64[$46>>3] = $45;
  $47 = ((($1)) + 24|0);
  $48 = +HEAPF64[$47>>3];
  $49 = ((($38)) + 56|0);
  HEAPF64[$49>>3] = $48;
  $50 = ((($1)) + 32|0);
  $51 = +HEAPF64[$50>>3];
  $52 = ((($38)) + 64|0);
  HEAPF64[$52>>3] = $51;
  $53 = ((($1)) + 40|0);
  $54 = +HEAPF64[$53>>3];
  $55 = ((($38)) + 72|0);
  HEAPF64[$55>>3] = $54;
  $56 = ((($1)) + 48|0);
  $57 = +HEAPF64[$56>>3];
  $58 = ((($38)) + 80|0);
  HEAPF64[$58>>3] = $57;
  $59 = ((($1)) + 56|0);
  $60 = +HEAPF64[$59>>3];
  $61 = ((($38)) + 88|0);
  HEAPF64[$61>>3] = $60;
  $62 = ((($1)) + 64|0);
  $63 = +HEAPF64[$62>>3];
  $64 = ((($38)) + 96|0);
  HEAPF64[$64>>3] = $63;
  $65 = ((($1)) + 72|0);
  $66 = +HEAPF64[$65>>3];
  $67 = ((($38)) + 104|0);
  HEAPF64[$67>>3] = $66;
  $68 = ((($1)) + 80|0);
  $69 = +HEAPF64[$68>>3];
  $70 = ((($38)) + 112|0);
  HEAPF64[$70>>3] = $69;
  $71 = ((($1)) + 88|0);
  $72 = +HEAPF64[$71>>3];
  $73 = ((($38)) + 120|0);
  HEAPF64[$73>>3] = $72;
  $74 = ((($1)) + 96|0);
  $75 = +HEAPF64[$74>>3];
  $76 = ((($38)) + 128|0);
  HEAPF64[$76>>3] = $75;
  $77 = ((($1)) + 104|0);
  $78 = +HEAPF64[$77>>3];
  $79 = ((($38)) + 136|0);
  HEAPF64[$79>>3] = $78;
  $80 = ((($1)) + 112|0);
  $81 = +HEAPF64[$80>>3];
  $82 = ((($38)) + 144|0);
  HEAPF64[$82>>3] = $81;
  $83 = ((($1)) + 120|0);
  $84 = +HEAPF64[$83>>3];
  $85 = ((($38)) + 152|0);
  HEAPF64[$85>>3] = $84;
  $$014 = $38;
  STACKTOP = sp;return ($$014|0);
 }
 $86 = (__Znwj(160)|0);
 __THREW__ = 0;
 invoke_vii(3435,($86|0),0);
 $87 = __THREW__; __THREW__ = 0;
 $88 = $87&1;
 if ($88) {
  $160 = ___cxa_find_matching_catch_2()|0;
  $161 = tempRet0;
  __ZdlPv($86);
  $$0 = $161;$$013 = $160;
  ___resumeException($$013|0);
  // unreachable;
 }
 $89 = ((($86)) + 12|0);
 ;HEAP32[$89>>2]=0|0;HEAP32[$89+4>>2]=0|0;HEAP32[$89+8>>2]=0|0;
 $90 = ((($86)) + 24|0);
 HEAP32[$90>>2] = 2;
 $91 = ((($86)) + 28|0);
 HEAP32[$91>>2] = 0;
 $92 = +HEAPF64[$1>>3];
 $93 = ((($86)) + 32|0);
 HEAPF64[$93>>3] = $92;
 $94 = ((($1)) + 8|0);
 $95 = +HEAPF64[$94>>3];
 $96 = ((($86)) + 40|0);
 HEAPF64[$96>>3] = $95;
 $97 = ((($1)) + 16|0);
 $98 = +HEAPF64[$97>>3];
 $99 = ((($86)) + 48|0);
 HEAPF64[$99>>3] = $98;
 $100 = ((($1)) + 24|0);
 $101 = +HEAPF64[$100>>3];
 $102 = ((($86)) + 56|0);
 HEAPF64[$102>>3] = $101;
 $103 = ((($1)) + 32|0);
 $104 = +HEAPF64[$103>>3];
 $105 = ((($86)) + 64|0);
 HEAPF64[$105>>3] = $104;
 $106 = ((($1)) + 40|0);
 $107 = +HEAPF64[$106>>3];
 $108 = ((($86)) + 72|0);
 HEAPF64[$108>>3] = $107;
 $109 = ((($1)) + 48|0);
 $110 = +HEAPF64[$109>>3];
 $111 = ((($86)) + 80|0);
 HEAPF64[$111>>3] = $110;
 $112 = ((($1)) + 56|0);
 $113 = +HEAPF64[$112>>3];
 $114 = ((($86)) + 88|0);
 HEAPF64[$114>>3] = $113;
 $115 = ((($1)) + 64|0);
 $116 = +HEAPF64[$115>>3];
 $117 = ((($86)) + 96|0);
 HEAPF64[$117>>3] = $116;
 $118 = ((($1)) + 72|0);
 $119 = +HEAPF64[$118>>3];
 $120 = ((($86)) + 104|0);
 HEAPF64[$120>>3] = $119;
 $121 = ((($1)) + 80|0);
 $122 = +HEAPF64[$121>>3];
 $123 = ((($86)) + 112|0);
 HEAPF64[$123>>3] = $122;
 $124 = ((($1)) + 88|0);
 $125 = +HEAPF64[$124>>3];
 $126 = ((($86)) + 120|0);
 HEAPF64[$126>>3] = $125;
 $127 = ((($1)) + 96|0);
 $128 = +HEAPF64[$127>>3];
 $129 = ((($86)) + 128|0);
 HEAPF64[$129>>3] = $128;
 $130 = ((($1)) + 104|0);
 $131 = +HEAPF64[$130>>3];
 $132 = ((($86)) + 136|0);
 HEAPF64[$132>>3] = $131;
 $133 = ((($1)) + 112|0);
 $134 = +HEAPF64[$133>>3];
 $135 = ((($86)) + 144|0);
 HEAPF64[$135>>3] = $134;
 $136 = ((($1)) + 120|0);
 $137 = +HEAPF64[$136>>3];
 $138 = ((($86)) + 152|0);
 HEAPF64[$138>>3] = $137;
 HEAP32[$86>>2] = (47588);
 HEAP32[$2>>2] = $86;
 $139 = ((($86)) + 8|0);
 $140 = HEAP32[$139>>2]|0;HEAP32[$139>>2] = (($140+1)|0);
 $141 = HEAP32[$6>>2]|0;
 $142 = ((($0)) + 308|0);
 $143 = HEAP32[$142>>2]|0;
 $144 = ($141|0)==($143|0);
 if ($144) {
  __THREW__ = 0;
  invoke_vii(3636,($5|0),($2|0));
  $151 = __THREW__; __THREW__ = 0;
  $152 = $151&1;
  if ($152) {
   $162 = ___cxa_find_matching_catch_2()|0;
   $163 = tempRet0;
   $164 = HEAP32[$2>>2]|0;
   $165 = ($164|0)==(0|0);
   if (!($165)) {
    $166 = ((($164)) + 8|0);
    $167 = HEAP32[$166>>2]|0;HEAP32[$166>>2] = (($167-1)|0);
    $168 = ($167|0)==(1);
    if ($168) {
     __THREW__ = 0;
     invoke_viii(3262,($164|0),1,1);
     $169 = __THREW__; __THREW__ = 0;
     $170 = $169&1;
     if ($170) {
      $171 = ___cxa_find_matching_catch_3(0|0)|0;
      $172 = tempRet0;
      ___clang_call_terminate($171);
      // unreachable;
     }
    }
   }
   $$0 = $163;$$013 = $162;
   ___resumeException($$013|0);
   // unreachable;
  }
 } else {
  $145 = HEAP32[$2>>2]|0;
  HEAP32[$141>>2] = $145;
  $146 = ($145|0)==(0|0);
  if ($146) {
   $150 = $141;
  } else {
   $147 = ((($145)) + 8|0);
   $148 = HEAP32[$147>>2]|0;HEAP32[$147>>2] = (($148+1)|0);
   $$pre$i = HEAP32[$6>>2]|0;
   $150 = $$pre$i;
  }
  $149 = ((($150)) + 4|0);
  HEAP32[$6>>2] = $149;
 }
 $153 = HEAP32[$2>>2]|0;
 $154 = ($153|0)==(0|0);
 if (!($154)) {
  $155 = ((($153)) + 8|0);
  $156 = HEAP32[$155>>2]|0;HEAP32[$155>>2] = (($156-1)|0);
  $157 = ($156|0)==(1);
  if ($157) {
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($153,1,1);
  }
 }
 $158 = HEAP32[$3>>2]|0;
 $159 = (($158) + 1)|0;
 HEAP32[$3>>2] = $159;
 $$014 = $86;
 STACKTOP = sp;return ($$014|0);
}
function __ZN7osgUtil16RenderStageCacheC2Ev($0) {
 $0 = $0|0;
 var $$1 = 0, $$13 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg10ReferencedC2Ev($0);
 HEAP32[$0>>2] = (63412);
 $1 = ((($0)) + 12|0);
 ;HEAP32[$1>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;
 $2 = ((($0)) + 24|0);
 HEAP32[$2>>2] = 2;
 $3 = ((($0)) + 28|0);
 HEAP32[$3>>2] = 0;
 $4 = ((($0)) + 32|0);
 __THREW__ = 0;
 invoke_vi(3637,($4|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $14 = ___cxa_find_matching_catch_2()|0;
  $15 = tempRet0;
  $$1 = $15;$$13 = $14;
 } else {
  HEAP32[$0>>2] = (52100);
  HEAP32[$4>>2] = (52252);
  $7 = ((($0)) + 36|0);
  __THREW__ = 0;
  invoke_vii(3507,($7|0),0);
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   $10 = ((($0)) + 52|0);
   HEAP32[$10>>2] = 0;
   $11 = ((($0)) + 56|0);
   HEAP32[$11>>2] = 0;
   $12 = ((($0)) + 52|0);
   $13 = ((($0)) + 48|0);
   HEAP32[$13>>2] = $12;
   return;
  }
  $16 = ___cxa_find_matching_catch_2()|0;
  $17 = tempRet0;
  __THREW__ = 0;
  $18 = __THREW__; __THREW__ = 0;
  $19 = $18&1;
  if ($19) {
   $22 = ___cxa_find_matching_catch_3(0|0)|0;
   $23 = tempRet0;
   ___clang_call_terminate($22);
   // unreachable;
  } else {
   $$1 = $17;$$13 = $16;
  }
 }
 __THREW__ = 0;
 invoke_vi(388,($0|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if ($21) {
  $22 = ___cxa_find_matching_catch_3(0|0)|0;
  $23 = tempRet0;
  ___clang_call_terminate($22);
  // unreachable;
 } else {
  ___resumeException($$13|0);
  // unreachable;
 }
}
function __ZN3osg9cloneTypeIN7osgUtil11RenderStageEEEPT_PKS3_($0) {
 $0 = $0|0;
 var $$1 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp + 4|0;
 $2 = sp;
 $3 = ($0|0)==(0|0);
 if ($3) {
  $61 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
  if (!($61)) {
   $$1 = 0;
   STACKTOP = sp;return ($$1|0);
  }
  $62 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
  $63 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($62,128845,78)|0);
  $64 = HEAP32[$63>>2]|0;
  $65 = ((($64)) + -12|0);
  $66 = HEAP32[$65>>2]|0;
  $67 = (($63) + ($66)|0);
  __ZNKSt3__28ios_base6getlocEv($2,$67);
  __THREW__ = 0;
  $68 = (invoke_iii(3255,($2|0),(215188|0))|0);
  $69 = __THREW__; __THREW__ = 0;
  $70 = $69&1;
  if (!($70)) {
   $71 = HEAP32[$68>>2]|0;
   $72 = ((($71)) + 28|0);
   $73 = HEAP32[$72>>2]|0;
   __THREW__ = 0;
   $74 = (invoke_iii($73|0,($68|0),10)|0);
   $75 = __THREW__; __THREW__ = 0;
   $76 = $75&1;
   if (!($76)) {
    __ZNSt3__26localeD2Ev($2);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($63,$74)|0);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($63)|0);
    $$1 = 0;
    STACKTOP = sp;return ($$1|0);
   }
  }
  $77 = ___cxa_find_matching_catch_2()|0;
  $78 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3263,($2|0));
  $79 = __THREW__; __THREW__ = 0;
  $80 = $79&1;
  if ($80) {
   $81 = ___cxa_find_matching_catch_3(0|0)|0;
   $82 = tempRet0;
   ___clang_call_terminate($81);
   // unreachable;
  } else {
   ___resumeException($77|0);
   // unreachable;
  }
 }
 $4 = HEAP32[$0>>2]|0;
 $5 = ((($4)) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_ii[$6 & 8191]($0)|0);
 $8 = ($7|0)==(0|0);
 if ($8) {
  label = 9;
 } else {
  $9 = ((($7)) + 8|0);
  $10 = HEAP32[$9>>2]|0;HEAP32[$9>>2] = (($10+1)|0);
  $11 = (___dynamic_cast($7,26112,22912,0)|0);
  $12 = ($11|0)==(0|0);
  if ($12) {
   label = 9;
  } else {
   __THREW__ = 0;
   (invoke_ii(3335,($7|0))|0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if ($14) {
    label = 5;
   } else {
    $$1 = $11;
    STACKTOP = sp;return ($$1|0);
   }
  }
 }
 L19: do {
  if ((label|0) == 9) {
   __THREW__ = 0;
   $22 = (invoke_ii(3265,2)|0);
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if ($24) {
    label = 5;
   } else {
    do {
     if ($22) {
      __THREW__ = 0;
      $25 = (invoke_ii(3266,2)|0);
      $26 = __THREW__; __THREW__ = 0;
      $27 = $26&1;
      if ($27) {
       label = 5;
       break L19;
      }
      __THREW__ = 0;
      $28 = (invoke_iiii(3267,($25|0),(128766|0),78)|0);
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if ($30) {
       label = 5;
       break L19;
      }
      $31 = HEAP32[$28>>2]|0;
      $32 = ((($31)) + -12|0);
      $33 = HEAP32[$32>>2]|0;
      $34 = (($28) + ($33)|0);
      __THREW__ = 0;
      invoke_vii(3257,($1|0),($34|0));
      $35 = __THREW__; __THREW__ = 0;
      $36 = $35&1;
      if ($36) {
       label = 5;
       break L19;
      }
      __THREW__ = 0;
      $37 = (invoke_iii(3255,($1|0),(215188|0))|0);
      $38 = __THREW__; __THREW__ = 0;
      $39 = $38&1;
      if (!($39)) {
       $40 = HEAP32[$37>>2]|0;
       $41 = ((($40)) + 28|0);
       $42 = HEAP32[$41>>2]|0;
       __THREW__ = 0;
       $43 = (invoke_iii($42|0,($37|0),10)|0);
       $44 = __THREW__; __THREW__ = 0;
       $45 = $44&1;
       if (!($45)) {
        __THREW__ = 0;
        invoke_vi(3263,($1|0));
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 5;
         break L19;
        }
        __THREW__ = 0;
        (invoke_iii(3268,($28|0),($43|0))|0);
        $54 = __THREW__; __THREW__ = 0;
        $55 = $54&1;
        if ($55) {
         label = 5;
         break L19;
        }
        __THREW__ = 0;
        (invoke_ii(3269,($28|0))|0);
        $56 = __THREW__; __THREW__ = 0;
        $57 = $56&1;
        if ($57) {
         label = 5;
         break L19;
        } else {
         break;
        }
       }
      }
      $46 = ___cxa_find_matching_catch_2()|0;
      $47 = tempRet0;
      __THREW__ = 0;
      invoke_vi(3263,($1|0));
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       $50 = ___cxa_find_matching_catch_3(0|0)|0;
       $51 = tempRet0;
       ___clang_call_terminate($50);
       // unreachable;
      } else {
       $eh$lpad$body$index2Z2D = $47;$eh$lpad$body$indexZ2D = $46;
       break L19;
      }
     }
    } while(0);
    if ($8) {
     $$1 = 0;
     STACKTOP = sp;return ($$1|0);
    }
    $58 = ((($7)) + 8|0);
    $59 = HEAP32[$58>>2]|0;HEAP32[$58>>2] = (($59-1)|0);
    $60 = ($59|0)==(1);
    if (!($60)) {
     $$1 = 0;
     STACKTOP = sp;return ($$1|0);
    }
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($7,1,1);
    $$1 = 0;
    STACKTOP = sp;return ($$1|0);
   }
  }
 } while(0);
 if ((label|0) == 5) {
  $15 = ___cxa_find_matching_catch_2()|0;
  $16 = tempRet0;
  $eh$lpad$body$index2Z2D = $16;$eh$lpad$body$indexZ2D = $15;
 }
 if ($8) {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 $17 = ((($7)) + 8|0);
 $18 = HEAP32[$17>>2]|0;HEAP32[$17>>2] = (($18-1)|0);
 $19 = ($18|0)==(1);
 if (!($19)) {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(3262,($7|0),1,1);
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if ($21) {
  $83 = ___cxa_find_matching_catch_3(0|0)|0;
  $84 = tempRet0;
  ___clang_call_terminate($83);
  // unreachable;
 } else {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 return (0)|0;
}
function __ZN7osgUtil16RenderStageCache14setRenderStageEPN3osg10ReferencedEPNS_11RenderStageE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$i$i = 0, $$0$ph$i$i = 0, $$0$ph$lcssa$i$i$i = 0, $$0$ph13$i$i$i = 0, $$014$i = 0, $$024$i$i = 0, $$025$i53$i = 0, $$03752$i = 0, $$07$ph12$i$i$i = 0, $$0710$i$i$i = 0, $$in$i$i = 0, $$pre$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = $1;
 $4 = ((($0)) + 36|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($5)) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 (FUNCTION_TABLE_ii[$7 & 8191]($4)|0);
 $8 = ((($0)) + 48|0);
 $9 = ((($0)) + 52|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 do {
  if ($11) {
   $$025$i53$i = $9;$$03752$i = $9;
   label = 18;
  } else {
   $$0$ph13$i$i$i = $9;$$07$ph12$i$i$i = $10;
   L3: while(1) {
    $$0710$i$i$i = $$07$ph12$i$i$i;
    while(1) {
     $12 = ((($$0710$i$i$i)) + 16|0);
     $13 = HEAP32[$12>>2]|0;
     $14 = ($13>>>0)<($1>>>0);
     if (!($14)) {
      break;
     }
     $17 = ((($$0710$i$i$i)) + 4|0);
     $18 = HEAP32[$17>>2]|0;
     $19 = ($18|0)==(0|0);
     if ($19) {
      $$0$ph$lcssa$i$i$i = $$0$ph13$i$i$i;
      break L3;
     } else {
      $$0710$i$i$i = $18;
     }
    }
    $15 = HEAP32[$$0710$i$i$i>>2]|0;
    $16 = ($15|0)==(0|0);
    if ($16) {
     $$0$ph$lcssa$i$i$i = $$0710$i$i$i;
     break;
    } else {
     $$0$ph13$i$i$i = $$0710$i$i$i;$$07$ph12$i$i$i = $15;
    }
   }
   $20 = ($$0$ph$lcssa$i$i$i|0)==($9|0);
   if (!($20)) {
    $21 = ((($$0$ph$lcssa$i$i$i)) + 16|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = ($22>>>0)>($1>>>0);
    if (!($23)) {
     $68 = ((($$0$ph$lcssa$i$i$i)) + 20|0);
     $69 = HEAP32[$68>>2]|0;
     $70 = ($69|0)==($2|0);
     if ($70) {
      $80 = HEAP32[$4>>2]|0;
      $81 = ((($80)) + 12|0);
      $82 = HEAP32[$81>>2]|0;
      (FUNCTION_TABLE_ii[$82 & 8191]($4)|0);
      return;
     }
     HEAP32[$68>>2] = $2;
     $71 = ($2|0)==(0|0);
     if (!($71)) {
      $72 = ((($2)) + 8|0);
      $73 = HEAP32[$72>>2]|0;HEAP32[$72>>2] = (($73+1)|0);
     }
     $74 = ($69|0)==(0|0);
     if ($74) {
      $80 = HEAP32[$4>>2]|0;
      $81 = ((($80)) + 12|0);
      $82 = HEAP32[$81>>2]|0;
      (FUNCTION_TABLE_ii[$82 & 8191]($4)|0);
      return;
     }
     $75 = ((($69)) + 8|0);
     $76 = HEAP32[$75>>2]|0;HEAP32[$75>>2] = (($76-1)|0);
     $77 = ($76|0)==(1);
     if (!($77)) {
      $80 = HEAP32[$4>>2]|0;
      $81 = ((($80)) + 12|0);
      $82 = HEAP32[$81>>2]|0;
      (FUNCTION_TABLE_ii[$82 & 8191]($4)|0);
      return;
     }
     __THREW__ = 0;
     invoke_viii(3262,($69|0),1,1);
     $78 = __THREW__; __THREW__ = 0;
     $79 = $78&1;
     if ($79) {
      break;
     }
     $80 = HEAP32[$4>>2]|0;
     $81 = ((($80)) + 12|0);
     $82 = HEAP32[$81>>2]|0;
     (FUNCTION_TABLE_ii[$82 & 8191]($4)|0);
     return;
    }
   }
   $24 = ((($0)) + 52|0);
   $$0$i$i = $24;$$024$i$i = $10;$34 = $10;
   while(1) {
    $25 = ((($$024$i$i)) + 16|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = ($26>>>0)>($1>>>0);
    if ($27) {
     $28 = HEAP32[$$024$i$i>>2]|0;
     $29 = ($28|0)==(0|0);
     if ($29) {
      label = 12;
      break;
     } else {
      $$0$ph$i$i = $$024$i$i;$$in$i$i = $28;
     }
    } else {
     $30 = ($26>>>0)<($1>>>0);
     if (!($30)) {
      label = 17;
      break;
     }
     $31 = ((($$024$i$i)) + 4|0);
     $32 = HEAP32[$31>>2]|0;
     $33 = ($32|0)==(0|0);
     if ($33) {
      label = 15;
      break;
     } else {
      $$0$ph$i$i = $31;$$in$i$i = $32;
     }
    }
    $$0$i$i = $$0$ph$i$i;$$024$i$i = $$in$i$i;$34 = $$in$i$i;
   }
   if ((label|0) == 12) {
    $$025$i53$i = $$024$i$i;$$03752$i = $$024$i$i;
    label = 18;
    break;
   }
   else if ((label|0) == 15) {
    $$025$i53$i = $31;$$03752$i = $$024$i$i;
    label = 18;
    break;
   }
   else if ((label|0) == 17) {
    $35 = ($34|0)==(0|0);
    if ($35) {
     $$025$i53$i = $$0$i$i;$$03752$i = $$024$i$i;
     label = 18;
     break;
    } else {
     $$014$i = $34;
     label = 22;
     break;
    }
   }
  }
 } while(0);
 if ((label|0) == 18) {
  __THREW__ = 0;
  $36 = (invoke_ii(3276,24)|0);
  $37 = __THREW__; __THREW__ = 0;
  $38 = $37&1;
  if (!($38)) {
   $39 = ((($36)) + 16|0);
   HEAP32[$39>>2] = $3;
   $40 = ((($36)) + 20|0);
   HEAP32[$40>>2] = 0;
   HEAP32[$36>>2] = 0;
   $41 = ((($36)) + 4|0);
   HEAP32[$41>>2] = 0;
   $42 = ((($36)) + 8|0);
   HEAP32[$42>>2] = $$03752$i;
   HEAP32[$$025$i53$i>>2] = $36;
   $43 = HEAP32[$8>>2]|0;
   $44 = HEAP32[$43>>2]|0;
   $45 = ($44|0)==(0|0);
   if ($45) {
    $49 = $36;
   } else {
    $46 = $44;
    HEAP32[$8>>2] = $46;
    $$pre$i$i = HEAP32[$$025$i53$i>>2]|0;
    $49 = $$pre$i$i;
   }
   $47 = ((($0)) + 52|0);
   $48 = HEAP32[$47>>2]|0;
   __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($48,$49);
   $50 = ((($0)) + 56|0);
   $51 = HEAP32[$50>>2]|0;
   $52 = (($51) + 1)|0;
   HEAP32[$50>>2] = $52;
   $$014$i = $36;
   label = 22;
  }
 }
 do {
  if ((label|0) == 22) {
   $53 = ((($$014$i)) + 20|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = ($54|0)==($2|0);
   if (!($55)) {
    HEAP32[$53>>2] = $2;
    $56 = ($2|0)==(0|0);
    if (!($56)) {
     $57 = ((($2)) + 8|0);
     $58 = HEAP32[$57>>2]|0;HEAP32[$57>>2] = (($58+1)|0);
    }
    $59 = ($54|0)==(0|0);
    if (!($59)) {
     $60 = ((($54)) + 8|0);
     $61 = HEAP32[$60>>2]|0;HEAP32[$60>>2] = (($61-1)|0);
     $62 = ($61|0)==(1);
     if ($62) {
      __THREW__ = 0;
      invoke_viii(3262,($54|0),1,1);
      $63 = __THREW__; __THREW__ = 0;
      $64 = $63&1;
      if ($64) {
       break;
      }
     }
    }
   }
   $65 = ((($0)) + 32|0);
   __THREW__ = 0;
   invoke_vii(3638,($1|0),($65|0));
   $66 = __THREW__; __THREW__ = 0;
   $67 = $66&1;
   if (!($67)) {
    $80 = HEAP32[$4>>2]|0;
    $81 = ((($80)) + 12|0);
    $82 = HEAP32[$81>>2]|0;
    (FUNCTION_TABLE_ii[$82 & 8191]($4)|0);
    return;
   }
  }
 } while(0);
 $83 = ___cxa_find_matching_catch_2()|0;
 $84 = tempRet0;
 $85 = HEAP32[$4>>2]|0;
 $86 = ((($85)) + 12|0);
 $87 = HEAP32[$86>>2]|0;
 __THREW__ = 0;
 (invoke_ii($87|0,($4|0))|0);
 $88 = __THREW__; __THREW__ = 0;
 $89 = $88&1;
 if ($89) {
  $90 = ___cxa_find_matching_catch_3(0|0)|0;
  $91 = tempRet0;
  ___clang_call_terminate($90);
  // unreachable;
 } else {
  ___resumeException($83|0);
  // unreachable;
 }
}
function __ZN7osgUtil16RenderStageCacheD2Ev($0) {
 $0 = $0|0;
 var $$0$i$i$i$i = 0, $$2 = 0, $$24 = 0, $$3 = 0, $$35 = 0, $$sroa$08$0$be = 0, $$sroa$08$015 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (52100);
 $1 = ((($0)) + 32|0);
 HEAP32[$1>>2] = (52252);
 $2 = ((($0)) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 52|0);
 $5 = ($3|0)==($4|0);
 L1: do {
  if ($5) {
   label = 9;
  } else {
   $$sroa$08$015 = $3;
   while(1) {
    $6 = ((($$sroa$08$015)) + 16|0);
    $7 = HEAP32[$6>>2]|0;
    __THREW__ = 0;
    invoke_vii(3639,($7|0),($1|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = ((($$sroa$08$015)) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)==(0|0);
    if ($12) {
     $13 = ((($$sroa$08$015)) + 8|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = HEAP32[$14>>2]|0;
     $16 = ($15|0)==($$sroa$08$015|0);
     if ($16) {
      $$sroa$08$0$be = $14;
     } else {
      $21 = $13;
      while(1) {
       $20 = HEAP32[$21>>2]|0;
       $22 = ((($20)) + 8|0);
       $23 = HEAP32[$22>>2]|0;
       $24 = HEAP32[$23>>2]|0;
       $25 = ($24|0)==($20|0);
       if ($25) {
        $$sroa$08$0$be = $23;
        break;
       } else {
        $21 = $22;
       }
      }
     }
    } else {
     $$0$i$i$i$i = $11;
     while(1) {
      $18 = HEAP32[$$0$i$i$i$i>>2]|0;
      $19 = ($18|0)==(0|0);
      if ($19) {
       break;
      } else {
       $$0$i$i$i$i = $18;
      }
     }
     $$sroa$08$0$be = $$0$i$i$i$i;
    }
    $17 = ($$sroa$08$0$be|0)==($4|0);
    if ($17) {
     label = 9;
     break L1;
    } else {
     $$sroa$08$015 = $$sroa$08$0$be;
    }
   }
   $34 = ___cxa_find_matching_catch_2()|0;
   $35 = tempRet0;
   $36 = HEAP32[$4>>2]|0;
   __ZNSt3__26__treeINS_12__value_typeIPN3osg10ReferencedENS2_7ref_ptrIN7osgUtil11RenderStageEEEEENS_19__map_value_compareIS4_S9_NS_4lessIS4_EELb1EEENS_9allocatorIS9_EEE7destroyEPNS_11__tree_nodeIS9_PvEE($2,$36);
   $37 = ((($0)) + 36|0);
   __THREW__ = 0;
   invoke_vi(707,($37|0));
   $38 = __THREW__; __THREW__ = 0;
   $39 = $38&1;
   if ($39) {
    $46 = ___cxa_find_matching_catch_3(0|0)|0;
    $47 = tempRet0;
    ___clang_call_terminate($46);
    // unreachable;
   } else {
    $$2 = $35;$$24 = $34;
    label = 15;
   }
  }
 } while(0);
 do {
  if ((label|0) == 9) {
   $26 = HEAP32[$4>>2]|0;
   __ZNSt3__26__treeINS_12__value_typeIPN3osg10ReferencedENS2_7ref_ptrIN7osgUtil11RenderStageEEEEENS_19__map_value_compareIS4_S9_NS_4lessIS4_EELb1EEENS_9allocatorIS9_EEE7destroyEPNS_11__tree_nodeIS9_PvEE($2,$26);
   $27 = ((($0)) + 36|0);
   __THREW__ = 0;
   invoke_vi(707,($27|0));
   $28 = __THREW__; __THREW__ = 0;
   $29 = $28&1;
   if ($29) {
    $32 = ___cxa_find_matching_catch_2()|0;
    $33 = tempRet0;
    $$2 = $33;$$24 = $32;
    label = 15;
    break;
   }
   __THREW__ = 0;
   $30 = __THREW__; __THREW__ = 0;
   $31 = $30&1;
   if ($31) {
    $40 = ___cxa_find_matching_catch_2()|0;
    $41 = tempRet0;
    $$3 = $41;$$35 = $40;
    break;
   } else {
    __ZN3osg6ObjectD2Ev($0);
    return;
   }
  }
 } while(0);
 if ((label|0) == 15) {
  __THREW__ = 0;
  $42 = __THREW__; __THREW__ = 0;
  $43 = $42&1;
  if ($43) {
   $46 = ___cxa_find_matching_catch_3(0|0)|0;
   $47 = tempRet0;
   ___clang_call_terminate($46);
   // unreachable;
  } else {
   $$3 = $$2;$$35 = $$24;
  }
 }
 __THREW__ = 0;
 invoke_vi(388,($0|0));
 $44 = __THREW__; __THREW__ = 0;
 $45 = $44&1;
 if ($45) {
  $46 = ___cxa_find_matching_catch_3(0|0)|0;
  $47 = tempRet0;
  ___clang_call_terminate($46);
  // unreachable;
 } else {
  ___resumeException($$35|0);
  // unreachable;
 }
}
function __ZN7osgUtil16RenderStageCacheD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1252,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK7osgUtil16RenderStageCache9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(60)|0);
 __THREW__ = 0;
 invoke_vi(3625,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch_2()|0;
  $5 = tempRet0;
  __ZdlPv($1);
  ___resumeException($4|0);
  // unreachable;
 } else {
  return ($1|0);
 }
 return (0)|0;
}
function __ZNK7osgUtil16RenderStageCache5cloneERKN3osg6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(60)|0);
 __THREW__ = 0;
 invoke_viii(3640,($2|0),($0|0),($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch_2()|0;
  $6 = tempRet0;
  __ZdlPv($2);
  ___resumeException($5|0);
  // unreachable;
 } else {
  return ($2|0);
 }
 return (0)|0;
}
function __ZNK7osgUtil16RenderStageCache12isSameKindAsEPKN3osg6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,22608,0)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK7osgUtil16RenderStageCache11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (116801|0);
}
function __ZNK7osgUtil16RenderStageCache9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (115817|0);
}
function __ZN7osgUtil16RenderStageCache21resizeGLObjectBuffersEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i$i$i = 0, $$0$i$i$i$sink$be = 0, $$0$i$i$i$sink12 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 52|0);
 $5 = ($3|0)==($4|0);
 if ($5) {
  return;
 } else {
  $$0$i$i$i$sink12 = $3;
 }
 while(1) {
  $6 = ((($$0$i$i$i$sink12)) + 20|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = HEAP32[$7>>2]|0;
  $9 = ((($8)) + 132|0);
  $10 = HEAP32[$9>>2]|0;
  FUNCTION_TABLE_vii[$10 & 8191]($7,$1);
  $11 = ((($$0$i$i$i$sink12)) + 4|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($12|0)==(0|0);
  if ($13) {
   $14 = ((($$0$i$i$i$sink12)) + 8|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = HEAP32[$15>>2]|0;
   $17 = ($16|0)==($$0$i$i$i$sink12|0);
   if ($17) {
    $$0$i$i$i$sink$be = $15;
   } else {
    $22 = $14;
    while(1) {
     $21 = HEAP32[$22>>2]|0;
     $23 = ((($21)) + 8|0);
     $24 = HEAP32[$23>>2]|0;
     $25 = HEAP32[$24>>2]|0;
     $26 = ($25|0)==($21|0);
     if ($26) {
      $$0$i$i$i$sink$be = $24;
      break;
     } else {
      $22 = $23;
     }
    }
   }
  } else {
   $$0$i$i$i$i = $12;
   while(1) {
    $19 = HEAP32[$$0$i$i$i$i>>2]|0;
    $20 = ($19|0)==(0|0);
    if ($20) {
     break;
    } else {
     $$0$i$i$i$i = $19;
    }
   }
   $$0$i$i$i$sink$be = $$0$i$i$i$i;
  }
  $18 = ($$0$i$i$i$sink$be|0)==($4|0);
  if ($18) {
   break;
  } else {
   $$0$i$i$i$sink12 = $$0$i$i$i$sink$be;
  }
 }
 return;
}
function __ZNK7osgUtil16RenderStageCache16releaseGLObjectsEPN3osg5StateE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i$i$i = 0, $$sroa$03$0$be = 0, $$sroa$03$07 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 52|0);
 $5 = ($3|0)==($4|0);
 if ($5) {
  return;
 } else {
  $$sroa$03$07 = $3;
 }
 while(1) {
  $6 = ((($$sroa$03$07)) + 20|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = HEAP32[$7>>2]|0;
  $9 = ((($8)) + 136|0);
  $10 = HEAP32[$9>>2]|0;
  FUNCTION_TABLE_vii[$10 & 8191]($7,$1);
  $11 = ((($$sroa$03$07)) + 4|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($12|0)==(0|0);
  if ($13) {
   $14 = ((($$sroa$03$07)) + 8|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = HEAP32[$15>>2]|0;
   $17 = ($16|0)==($$sroa$03$07|0);
   if ($17) {
    $$sroa$03$0$be = $15;
   } else {
    $22 = $14;
    while(1) {
     $21 = HEAP32[$22>>2]|0;
     $23 = ((($21)) + 8|0);
     $24 = HEAP32[$23>>2]|0;
     $25 = HEAP32[$24>>2]|0;
     $26 = ($25|0)==($21|0);
     if ($26) {
      $$sroa$03$0$be = $24;
      break;
     } else {
      $22 = $23;
     }
    }
   }
  } else {
   $$0$i$i$i$i = $12;
   while(1) {
    $19 = HEAP32[$$0$i$i$i$i>>2]|0;
    $20 = ($19|0)==(0|0);
    if ($20) {
     break;
    } else {
     $$0$i$i$i$i = $19;
    }
   }
   $$sroa$03$0$be = $$0$i$i$i$i;
  }
  $18 = ($$sroa$03$0$be|0)==($4|0);
  if ($18) {
   break;
  } else {
   $$sroa$03$07 = $$sroa$03$0$be;
  }
 }
 return;
}
function __ZN7osgUtil16RenderStageCache13objectDeletedEPv($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$ph$lcssa$i$i$i = 0, $$0$ph13$i$i$i = 0, $$07$ph12$i$i$i = 0, $$0710$i$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 36|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 (FUNCTION_TABLE_ii[$5 & 8191]($2)|0);
 $6 = ((($0)) + 48|0);
 $7 = ((($0)) + 52|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if ($9) {
  $51 = HEAP32[$2>>2]|0;
  $52 = ((($51)) + 12|0);
  $53 = HEAP32[$52>>2]|0;
  (FUNCTION_TABLE_ii[$53 & 8191]($2)|0);
  return;
 } else {
  $$0$ph13$i$i$i = $7;$$07$ph12$i$i$i = $8;
 }
 L3: while(1) {
  $$0710$i$i$i = $$07$ph12$i$i$i;
  while(1) {
   $10 = ((($$0710$i$i$i)) + 16|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = ($11>>>0)<($1>>>0);
   if (!($12)) {
    break;
   }
   $15 = ((($$0710$i$i$i)) + 4|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ($16|0)==(0|0);
   if ($17) {
    $$0$ph$lcssa$i$i$i = $$0$ph13$i$i$i;
    break L3;
   } else {
    $$0710$i$i$i = $16;
   }
  }
  $13 = HEAP32[$$0710$i$i$i>>2]|0;
  $14 = ($13|0)==(0|0);
  if ($14) {
   $$0$ph$lcssa$i$i$i = $$0710$i$i$i;
   break;
  } else {
   $$0$ph13$i$i$i = $$0710$i$i$i;$$07$ph12$i$i$i = $13;
  }
 }
 $18 = ($$0$ph$lcssa$i$i$i|0)==($7|0);
 if ($18) {
  $51 = HEAP32[$2>>2]|0;
  $52 = ((($51)) + 12|0);
  $53 = HEAP32[$52>>2]|0;
  (FUNCTION_TABLE_ii[$53 & 8191]($2)|0);
  return;
 }
 $19 = ((($$0$ph$lcssa$i$i$i)) + 16|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($1>>>0)<($20>>>0);
 if ($21) {
  $51 = HEAP32[$2>>2]|0;
  $52 = ((($51)) + 12|0);
  $53 = HEAP32[$52>>2]|0;
  (FUNCTION_TABLE_ii[$53 & 8191]($2)|0);
  return;
 }
 $22 = ((($$0$ph$lcssa$i$i$i)) + 4|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)==(0|0);
 if ($24) {
  $25 = ((($$0$ph$lcssa$i$i$i)) + 8|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = HEAP32[$26>>2]|0;
  $28 = ($27|0)==($$0$ph$lcssa$i$i$i|0);
  if ($28) {
   $$0$i$i$i$i = $26;
  } else {
   $32 = $25;
   while(1) {
    $31 = HEAP32[$32>>2]|0;
    $33 = ((($31)) + 8|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = HEAP32[$34>>2]|0;
    $36 = ($35|0)==($31|0);
    if ($36) {
     $$0$i$i$i$i = $34;
     break;
    } else {
     $32 = $33;
    }
   }
  }
 } else {
  $$0$i$i$i$i$i = $23;
  while(1) {
   $29 = HEAP32[$$0$i$i$i$i$i>>2]|0;
   $30 = ($29|0)==(0|0);
   if ($30) {
    break;
   } else {
    $$0$i$i$i$i$i = $29;
   }
  }
  $$0$i$i$i$i = $$0$i$i$i$i$i;
 }
 $37 = HEAP32[$6>>2]|0;
 $38 = ($37|0)==($$0$ph$lcssa$i$i$i|0);
 if ($38) {
  $39 = $$0$i$i$i$i;
  HEAP32[$6>>2] = $39;
 }
 $40 = ((($0)) + 56|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = (($41) + -1)|0;
 HEAP32[$40>>2] = $42;
 __ZNSt3__213__tree_removeIPNS_16__tree_node_baseIPvEEEEvT_S5_($8,$$0$ph$lcssa$i$i$i);
 $43 = ((($$0$ph$lcssa$i$i$i)) + 20|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = ($44|0)==(0|0);
 if (!($45)) {
  $46 = ((($44)) + 8|0);
  $47 = HEAP32[$46>>2]|0;HEAP32[$46>>2] = (($47-1)|0);
  $48 = ($47|0)==(1);
  if ($48) {
   __THREW__ = 0;
   invoke_viii(3262,($44|0),1,1);
   $49 = __THREW__; __THREW__ = 0;
   $50 = $49&1;
   if ($50) {
    $54 = ___cxa_find_matching_catch_2()|0;
    $55 = tempRet0;
    $56 = HEAP32[$2>>2]|0;
    $57 = ((($56)) + 12|0);
    $58 = HEAP32[$57>>2]|0;
    __THREW__ = 0;
    (invoke_ii($58|0,($2|0))|0);
    $59 = __THREW__; __THREW__ = 0;
    $60 = $59&1;
    if ($60) {
     $61 = ___cxa_find_matching_catch_3(0|0)|0;
     $62 = tempRet0;
     ___clang_call_terminate($61);
     // unreachable;
    } else {
     ___resumeException($54|0);
     // unreachable;
    }
   }
  }
 }
 __ZdlPv($$0$ph$lcssa$i$i$i);
 $51 = HEAP32[$2>>2]|0;
 $52 = ((($51)) + 12|0);
 $53 = HEAP32[$52>>2]|0;
 (FUNCTION_TABLE_ii[$53 & 8191]($2)|0);
 return;
}
function __ZThn32_N7osgUtil16RenderStageCacheD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -32|0);
 __ZN7osgUtil16RenderStageCacheD2Ev($1);
 return;
}
function __ZThn32_N7osgUtil16RenderStageCacheD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -32|0);
 __THREW__ = 0;
 invoke_vi(1252,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch_2()|0;
  $5 = tempRet0;
  __ZdlPv($1);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZdlPv($1);
  return;
 }
}
function __ZThn32_N7osgUtil16RenderStageCache13objectDeletedEPv($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + -32|0);
 __ZN7osgUtil16RenderStageCache13objectDeletedEPv($2,$1);
 return;
}
function __ZN7osgUtil16RenderStageCacheC2ERKS0_RKN3osg6CopyOpE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$1 = 0, $$13 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg10ReferencedC2Ev($0);
 HEAP32[$0>>2] = (63412);
 $3 = ((($0)) + 12|0);
 ;HEAP32[$3>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;
 $4 = ((($0)) + 24|0);
 HEAP32[$4>>2] = 2;
 $5 = ((($0)) + 28|0);
 HEAP32[$5>>2] = 0;
 $6 = ((($0)) + 32|0);
 __THREW__ = 0;
 invoke_vi(3637,($6|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $16 = ___cxa_find_matching_catch_2()|0;
  $17 = tempRet0;
  $$1 = $17;$$13 = $16;
 } else {
  HEAP32[$0>>2] = (52100);
  HEAP32[$6>>2] = (52252);
  $9 = ((($0)) + 36|0);
  __THREW__ = 0;
  invoke_vii(3507,($9|0),0);
  $10 = __THREW__; __THREW__ = 0;
  $11 = $10&1;
  if (!($11)) {
   $12 = ((($0)) + 52|0);
   HEAP32[$12>>2] = 0;
   $13 = ((($0)) + 56|0);
   HEAP32[$13>>2] = 0;
   $14 = ((($0)) + 52|0);
   $15 = ((($0)) + 48|0);
   HEAP32[$15>>2] = $14;
   return;
  }
  $18 = ___cxa_find_matching_catch_2()|0;
  $19 = tempRet0;
  __THREW__ = 0;
  $20 = __THREW__; __THREW__ = 0;
  $21 = $20&1;
  if ($21) {
   $24 = ___cxa_find_matching_catch_3(0|0)|0;
   $25 = tempRet0;
   ___clang_call_terminate($24);
   // unreachable;
  } else {
   $$1 = $19;$$13 = $18;
  }
 }
 __THREW__ = 0;
 invoke_vi(388,($0|0));
 $22 = __THREW__; __THREW__ = 0;
 $23 = $22&1;
 if ($23) {
  $24 = ___cxa_find_matching_catch_3(0|0)|0;
  $25 = tempRet0;
  ___clang_call_terminate($24);
  // unreachable;
 } else {
  ___resumeException($$13|0);
  // unreachable;
 }
}
function __ZNSt3__26__treeINS_12__value_typeIPN3osg10ReferencedENS2_7ref_ptrIN7osgUtil11RenderStageEEEEENS_19__map_value_compareIS4_S9_NS_4lessIS4_EELb1EEENS_9allocatorIS9_EEE7destroyEPNS_11__tree_nodeIS9_PvEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 }
 $3 = HEAP32[$1>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIPN3osg10ReferencedENS2_7ref_ptrIN7osgUtil11RenderStageEEEEENS_19__map_value_compareIS4_S9_NS_4lessIS4_EELb1EEENS_9allocatorIS9_EEE7destroyEPNS_11__tree_nodeIS9_PvEE($0,$3);
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIPN3osg10ReferencedENS2_7ref_ptrIN7osgUtil11RenderStageEEEEENS_19__map_value_compareIS4_S9_NS_4lessIS4_EELb1EEENS_9allocatorIS9_EEE7destroyEPNS_11__tree_nodeIS9_PvEE($0,$5);
 $6 = ((($1)) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = ((($7)) + 8|0);
  $10 = HEAP32[$9>>2]|0;HEAP32[$9>>2] = (($10-1)|0);
  $11 = ($10|0)==(1);
  if ($11) {
   __THREW__ = 0;
   invoke_viii(3262,($7|0),1,1);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if ($13) {
    $14 = ___cxa_find_matching_catch_2()|0;
    $15 = tempRet0;
    ___cxa_call_unexpected(($14|0));
    // unreachable;
   }
  }
 }
 __ZdlPv($1);
 return;
}
function __ZNSt3__26vectorIN3osg7ref_ptrINS1_10RefMatrixdEEENS_9allocatorIS4_EEE21__push_back_slow_pathIKS4_EEvRT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$06$i$i = 0, $$pre = 0, $$pre$i = 0, $$pre38 = 0, $$pre39 = 0, $$sroa$7$0 = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(1073741823);
 $9 = $4;
 $10 = $3;
 if ($8) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $11 = ((($0)) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) - ($4))|0;
 $14 = $13 >> 2;
 $15 = ($14>>>0)<(536870911);
 $16 = $13 >> 1;
 $17 = ($16>>>0)<($7>>>0);
 $$sroa$speculated$i = $17 ? $7 : $16;
 $$sroa$speculated$$i = $15 ? $$sroa$speculated$i : 1073741823;
 $18 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($18) {
   $28 = 0;
  } else {
   $19 = ($$sroa$speculated$$i>>>0)>(1073741823);
   if (!($19)) {
    $25 = $$sroa$speculated$$i << 2;
    $26 = (__Znwj($25)|0);
    $28 = $26;
    break;
   }
   $20 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($20|0),(204840|0));
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if ($22) {
    $23 = ___cxa_find_matching_catch_2()|0;
    $24 = tempRet0;
    ___cxa_free_exception(($20|0));
    ___resumeException($23|0);
    // unreachable;
   } else {
    HEAP32[$20>>2] = (99824);
    ___cxa_throw(($20|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $27 = (($28) + ($6<<2)|0);
 $29 = $27;
 $30 = (($28) + ($$sroa$speculated$$i<<2)|0);
 $31 = $30;
 $32 = HEAP32[$1>>2]|0;
 HEAP32[$27>>2] = $32;
 $33 = ($32|0)==(0|0);
 if ($33) {
  $38 = $10;$40 = $9;
 } else {
  $34 = ((($32)) + 8|0);
  $35 = HEAP32[$34>>2]|0;HEAP32[$34>>2] = (($35+1)|0);
  $$pre = HEAP32[$0>>2]|0;
  $$pre38 = HEAP32[$2>>2]|0;
  $38 = $$pre38;$40 = $$pre;
 }
 $36 = ((($27)) + 4|0);
 $37 = $36;
 $39 = ($38|0)==($40|0);
 if ($39) {
  $41 = $38;
  $53 = $29;$54 = $41;$56 = $38;
 } else {
  $$06$i$i = $38;$$sroa$7$0 = $29;$44 = $27;
  while(1) {
   $42 = ((($$06$i$i)) + -4|0);
   $43 = ((($44)) + -4|0);
   $45 = HEAP32[$42>>2]|0;
   HEAP32[$43>>2] = $45;
   $46 = ($45|0)==(0|0);
   if (!($46)) {
    $47 = ((($45)) + 8|0);
    $48 = HEAP32[$47>>2]|0;HEAP32[$47>>2] = (($48+1)|0);
   }
   $49 = $$sroa$7$0;
   $50 = ((($49)) + -4|0);
   $51 = $50;
   $52 = ($42|0)==($40|0);
   if ($52) {
    break;
   } else {
    $$06$i$i = $42;$$sroa$7$0 = $51;$44 = $50;
   }
  }
  $$pre$i = HEAP32[$0>>2]|0;
  $$pre39 = HEAP32[$2>>2]|0;
  $53 = $51;$54 = $$pre$i;$56 = $$pre39;
 }
 HEAP32[$0>>2] = $53;
 HEAP32[$2>>2] = $37;
 HEAP32[$11>>2] = $31;
 $55 = $54;
 $57 = ($56|0)==($55|0);
 L25: do {
  if (!($57)) {
   $59 = $56;
   while(1) {
    $58 = ((($59)) + -4|0);
    $60 = HEAP32[$58>>2]|0;
    $61 = ($60|0)==(0|0);
    if (!($61)) {
     $62 = ((($60)) + 8|0);
     $63 = HEAP32[$62>>2]|0;HEAP32[$62>>2] = (($63-1)|0);
     $64 = ($63|0)==(1);
     if ($64) {
      __THREW__ = 0;
      invoke_viii(3262,($60|0),1,1);
      $65 = __THREW__; __THREW__ = 0;
      $66 = $65&1;
      if ($66) {
       break;
      }
     }
    }
    HEAP32[$58>>2] = 0;
    $67 = ($58|0)==($55|0);
    if ($67) {
     break L25;
    } else {
     $59 = $58;
    }
   }
   $68 = ___cxa_find_matching_catch_2()|0;
   $69 = tempRet0;
   ___cxa_call_unexpected(($68|0));
   // unreachable;
  }
 } while(0);
 $70 = ($54|0)==(0);
 if ($70) {
  return;
 }
 $71 = $54;
 __ZdlPv($71);
 return;
}
function __ZN7osgUtil11CullVisitor23updateCalculatedNearFarERKN3osg7MatrixdERKNS1_8DrawableEb($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $$0$be$in$i$i$i = 0, $$0$be$in$i$i$i69 = 0, $$0$i$i$i = 0, $$0$i$i$i67 = 0, $$015$i$i$i = 0, $$015$i$i$i73 = 0, $$0160 = 0.0, $$0162 = 0.0, $$042$i$i = 0, $$042$i$i72 = 0, $$1 = 0, $$1161 = 0.0, $$1163 = 0.0, $$139 = 0, $$2 = 0, $$240 = 0, $$3 = 0, $$341 = 0, $$pr$pre = 0;
 var $$pre$i$i$i = 0, $$pre$i$i$i75 = 0, $$sink$i = 0, $$sink$i58 = 0, $$sink$i78 = 0, $$sink$i83 = 0, $$sink1$i = 0, $$sink1$i59 = 0, $$sink1$i79 = 0, $$sink1$i84 = 0, $$sink2$i = 0, $$sink2$i60 = 0, $$sink2$i80 = 0, $$sink2$i85 = 0, $10 = 0, $100 = 0.0, $101 = 0, $102 = 0.0, $103 = 0.0, $104 = 0.0;
 var $105 = 0, $106 = 0.0, $107 = 0.0, $108 = 0.0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0.0, $114 = 0, $115 = 0, $116 = 0, $117 = 0.0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0.0, $122 = 0.0;
 var $123 = 0.0, $124 = 0.0, $125 = 0.0, $126 = 0.0, $127 = 0.0, $128 = 0.0, $129 = 0.0, $13 = 0, $130 = 0.0, $131 = 0.0, $132 = 0, $133 = 0.0, $134 = 0.0, $135 = 0, $136 = 0.0, $137 = 0.0, $138 = 0.0, $139 = 0.0, $14 = 0.0, $140 = 0;
 var $141 = 0.0, $142 = 0.0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0.0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0;
 var $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0.0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0;
 var $178 = 0, $179 = 0, $18 = 0.0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0;
 var $196 = 0.0, $197 = 0, $198 = 0, $199 = 0.0, $20 = 0.0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0.0, $210 = 0, $211 = 0, $212 = 0, $213 = 0;
 var $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0;
 var $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0;
 var $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0;
 var $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0;
 var $287 = 0, $288 = 0.0, $289 = 0, $29 = 0, $290 = 0.0, $291 = 0, $292 = 0, $293 = 0.0, $294 = 0, $295 = 0, $296 = 0.0, $297 = 0, $298 = 0, $299 = 0.0, $30 = 0, $300 = 0, $301 = 0, $302 = 0.0, $303 = 0, $304 = 0;
 var $305 = 0.0, $306 = 0, $307 = 0, $308 = 0.0, $309 = 0, $31 = 0, $310 = 0, $311 = 0.0, $312 = 0, $313 = 0, $314 = 0.0, $315 = 0, $316 = 0, $317 = 0.0, $318 = 0, $319 = 0, $32 = 0, $320 = 0.0, $321 = 0, $322 = 0;
 var $323 = 0.0, $324 = 0, $325 = 0, $326 = 0.0, $327 = 0, $328 = 0, $329 = 0.0, $33 = 0, $330 = 0, $331 = 0, $332 = 0.0, $333 = 0, $334 = 0, $335 = 0.0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0.0, $340 = 0;
 var $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0.0, $348 = 0, $349 = 0.0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0;
 var $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0;
 var $378 = 0, $379 = 0, $38 = 0.0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0;
 var $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0.0, $401 = 0, $402 = 0.0, $403 = 0, $404 = 0, $405 = 0.0, $406 = 0, $407 = 0, $408 = 0.0, $409 = 0, $41 = 0, $410 = 0, $411 = 0.0, $412 = 0;
 var $413 = 0, $414 = 0.0, $415 = 0, $416 = 0, $417 = 0.0, $418 = 0, $419 = 0, $42 = 0.0, $420 = 0.0, $421 = 0, $422 = 0, $423 = 0.0, $424 = 0, $425 = 0, $426 = 0.0, $427 = 0, $428 = 0, $429 = 0.0, $43 = 0.0, $430 = 0;
 var $431 = 0, $432 = 0.0, $433 = 0, $434 = 0, $435 = 0.0, $436 = 0, $437 = 0, $438 = 0.0, $439 = 0, $44 = 0.0, $440 = 0, $441 = 0.0, $442 = 0, $443 = 0, $444 = 0.0, $445 = 0, $446 = 0, $447 = 0.0, $448 = 0, $449 = 0;
 var $45 = 0.0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0.0, $46 = 0.0, $460 = 0, $461 = 0.0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0;
 var $468 = 0, $469 = 0, $47 = 0.0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0.0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0;
 var $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0.0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0.0, $500 = 0, $501 = 0, $502 = 0;
 var $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0.0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0.0, $520 = 0;
 var $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0.0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0.0, $535 = 0, $536 = 0, $537 = 0.0, $538 = 0, $54 = 0.0;
 var $55 = 0.0, $56 = 0, $57 = 0.0, $58 = 0, $59 = 0.0, $6 = 0, $60 = 0.0, $61 = 0.0, $62 = 0.0, $63 = 0.0, $64 = 0.0, $65 = 0.0, $66 = 0.0, $67 = 0.0, $68 = 0.0, $69 = 0.0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0.0, $83 = 0, $84 = 0, $85 = 0, $86 = 0.0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0.0;
 var $91 = 0.0, $92 = 0, $93 = 0.0, $94 = 0.0, $95 = 0.0, $96 = 0, $97 = 0.0, $98 = 0.0, $99 = 0.0, $phitmp = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i105 = 0, $scevgep$i$i$i$i$i47 = 0, $scevgep$i$i$i$i$i53 = 0, $scevgep$i$i$i$i$i61 = 0, $scevgep$i$i$i$i$i90 = 0, $scevgep$i$i$i$i42 = 0, $scevgep$i$i$i$i86 = 0, $scevgep$i$i$i$i95 = 0;
 var $scevgep$i$i$i3$i = 0, $scevgep$i$i$i3$i100 = 0, $scevgep5$i$i$i$i = 0, $scevgep5$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i106 = 0, $scevgep5$i$i$i$i$i48 = 0, $scevgep5$i$i$i$i$i54 = 0, $scevgep5$i$i$i$i$i62 = 0, $scevgep5$i$i$i$i$i91 = 0, $scevgep5$i$i$i$i43 = 0, $scevgep5$i$i$i$i87 = 0, $scevgep5$i$i$i$i96 = 0, $scevgep5$i$i$i4$i = 0, $scevgep5$i$i$i4$i101 = 0, $switch = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 528|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(528|0);
 $4 = sp + 524|0;
 $5 = sp + 520|0;
 $6 = sp + 508|0;
 $7 = sp + 496|0;
 $8 = sp + 304|0;
 $9 = sp + 448|0;
 $10 = sp + 152|0;
 $11 = sp;
 $12 = (__ZNK3osg8Drawable14getBoundingBoxEv($2)|0);
 if ($3) {
  $13 = ((($1)) + 16|0);
  $14 = +HEAPF64[$13>>3];
  $15 = $14;
  $16 = ((($1)) + 48|0);
  $17 = +HEAPF64[$16>>3];
  $18 = $17;
  $19 = ((($1)) + 80|0);
  $20 = +HEAPF64[$19>>3];
  $21 = $20;
  $22 = $15 <= -0.0;
  $23 = $22&1;
  $24 = $18 <= -0.0;
  $25 = $24 ? 2 : 0;
  $26 = $25 | $23;
  $27 = $21 <= -0.0;
  $28 = $27 ? 4 : 0;
  $29 = $26 | $28;
  $30 = $29 ^ 7;
  $31 = $30 & 1;
  $32 = ($31|0)!=(0);
  $33 = ((($12)) + 12|0);
  $$sink$i = $32 ? $33 : $12;
  $34 = +HEAPF32[$$sink$i>>2];
  $35 = $30 & 2;
  $36 = ($35|0)!=(0);
  $$sink1$i = $36 ? $33 : $12;
  $37 = ((($$sink1$i)) + 4|0);
  $38 = +HEAPF32[$37>>2];
  $39 = $30 & 4;
  $40 = ($39|0)!=(0);
  $$sink2$i = $40 ? $33 : $12;
  $41 = ((($$sink2$i)) + 8|0);
  $42 = +HEAPF32[$41>>2];
  $43 = $34;
  $44 = $14 * $43;
  $45 = $38;
  $46 = $17 * $45;
  $47 = $44 + $46;
  $48 = $42;
  $49 = $20 * $48;
  $50 = $47 + $49;
  $51 = ((($1)) + 112|0);
  $52 = +HEAPF64[$51>>3];
  $53 = $52 + $50;
  $54 = -$53;
  $$sink$i58 = $22 ? $33 : $12;
  $55 = +HEAPF32[$$sink$i58>>2];
  $$sink1$i59 = $24 ? $33 : $12;
  $56 = ((($$sink1$i59)) + 4|0);
  $57 = +HEAPF32[$56>>2];
  $$sink2$i60 = $27 ? $33 : $12;
  $58 = ((($$sink2$i60)) + 8|0);
  $59 = +HEAPF32[$58>>2];
  $60 = $55;
  $61 = $14 * $60;
  $62 = $57;
  $63 = $17 * $62;
  $64 = $61 + $63;
  $65 = $59;
  $66 = $20 * $65;
  $67 = $64 + $66;
  $68 = $52 + $67;
  $69 = -$68;
  $70 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
  if ($70) {
   $71 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
   $72 = HEAP32[$71>>2]|0;
   $73 = ((($72)) + -12|0);
   $74 = HEAP32[$73>>2]|0;
   $75 = (($71) + ($74)|0);
   $76 = ((($75)) + 8|0);
   HEAP32[$76>>2] = 15;
   $$0160 = $54;$$0162 = $69;
  } else {
   $$0160 = $54;$$0162 = $69;
  }
 } else {
  $77 = ((($0)) + 344|0);
  $78 = HEAP32[$77>>2]|0;
  $79 = $78 & 1;
  $80 = ($79|0)!=(0);
  $81 = ((($12)) + 12|0);
  $$sink$i78 = $80 ? $81 : $12;
  $82 = +HEAPF32[$$sink$i78>>2];
  $83 = $78 & 2;
  $84 = ($83|0)!=(0);
  $$sink1$i79 = $84 ? $81 : $12;
  $85 = ((($$sink1$i79)) + 4|0);
  $86 = +HEAPF32[$85>>2];
  $87 = $78 & 4;
  $88 = ($87|0)!=(0);
  $$sink2$i80 = $88 ? $81 : $12;
  $89 = ((($$sink2$i80)) + 8|0);
  $90 = +HEAPF32[$89>>2];
  $91 = $82;
  $92 = ((($1)) + 16|0);
  $93 = +HEAPF64[$92>>3];
  $94 = $91 * $93;
  $95 = $86;
  $96 = ((($1)) + 48|0);
  $97 = +HEAPF64[$96>>3];
  $98 = $95 * $97;
  $99 = $94 + $98;
  $100 = $90;
  $101 = ((($1)) + 80|0);
  $102 = +HEAPF64[$101>>3];
  $103 = $100 * $102;
  $104 = $99 + $103;
  $105 = ((($1)) + 112|0);
  $106 = +HEAPF64[$105>>3];
  $107 = $106 + $104;
  $108 = -$107;
  $109 = ((($0)) + 348|0);
  $110 = HEAP32[$109>>2]|0;
  $111 = $110 & 1;
  $112 = ($111|0)!=(0);
  $$sink$i83 = $112 ? $81 : $12;
  $113 = +HEAPF32[$$sink$i83>>2];
  $114 = $110 & 2;
  $115 = ($114|0)!=(0);
  $$sink1$i84 = $115 ? $81 : $12;
  $116 = ((($$sink1$i84)) + 4|0);
  $117 = +HEAPF32[$116>>2];
  $118 = $110 & 4;
  $119 = ($118|0)!=(0);
  $$sink2$i85 = $119 ? $81 : $12;
  $120 = ((($$sink2$i85)) + 8|0);
  $121 = +HEAPF32[$120>>2];
  $122 = $113;
  $123 = $93 * $122;
  $124 = $117;
  $125 = $97 * $124;
  $126 = $123 + $125;
  $127 = $121;
  $128 = $102 * $127;
  $129 = $126 + $128;
  $130 = $106 + $129;
  $131 = -$130;
  $$0160 = $108;$$0162 = $131;
 }
 $132 = $$0160 > $$0162;
 do {
  if ($132) {
   $133 = $$0162;
   $134 = $$0160;
   $135 = $133 == $134;
   if ($135) {
    $$1161 = $$0162;$$1163 = $$0160;
   } else {
    $136 = $133 - $134;
    $137 = (+Math_abs((+$136)));
    $138 = (+Math_abs((+$133)));
    $139 = (+Math_abs((+$134)));
    $140 = $138 > $139;
    $141 = $140 ? $138 : $139;
    $142 = $141 * 0.0010000000474974513;
    $143 = !($137 <= $142);
    if ($143) {
     $144 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
     do {
      if ($144) {
       $145 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
       $146 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($145,116046,79)|0);
       $147 = HEAP32[$146>>2]|0;
       $148 = ((($147)) + -12|0);
       $149 = HEAP32[$148>>2]|0;
       $150 = (($146) + ($149)|0);
       __ZNKSt3__28ios_base6getlocEv($5,$150);
       __THREW__ = 0;
       $151 = (invoke_iii(3255,($5|0),(215188|0))|0);
       $152 = __THREW__; __THREW__ = 0;
       $153 = $152&1;
       if (!($153)) {
        $154 = HEAP32[$151>>2]|0;
        $155 = ((($154)) + 28|0);
        $156 = HEAP32[$155>>2]|0;
        __THREW__ = 0;
        $157 = (invoke_iii($156|0,($151|0),10)|0);
        $158 = __THREW__; __THREW__ = 0;
        $159 = $158&1;
        if (!($159)) {
         __ZNSt3__26localeD2Ev($5);
         (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($146,$157)|0);
         (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($146)|0);
         break;
        }
       }
       $160 = ___cxa_find_matching_catch_2()|0;
       $161 = tempRet0;
       __THREW__ = 0;
       invoke_vi(3263,($5|0));
       $162 = __THREW__; __THREW__ = 0;
       $163 = $162&1;
       if ($163) {
        $164 = ___cxa_find_matching_catch_3(0|0)|0;
        $165 = tempRet0;
        ___clang_call_terminate($164);
        // unreachable;
       } else {
        ___resumeException($160|0);
        // unreachable;
       }
      }
     } while(0);
     $166 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
     if ($166) {
      $167 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
      $168 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($167,116126,46)|0);
      $169 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEd($168,$$0162)|0);
      $170 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($169,116173,6)|0);
      $171 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEd($170,$$0160)|0);
      $172 = HEAP32[$171>>2]|0;
      $173 = ((($172)) + -12|0);
      $174 = HEAP32[$173>>2]|0;
      $175 = (($171) + ($174)|0);
      __ZNKSt3__28ios_base6getlocEv($4,$175);
      __THREW__ = 0;
      $176 = (invoke_iii(3255,($4|0),(215188|0))|0);
      $177 = __THREW__; __THREW__ = 0;
      $178 = $177&1;
      if (!($178)) {
       $179 = HEAP32[$176>>2]|0;
       $180 = ((($179)) + 28|0);
       $181 = HEAP32[$180>>2]|0;
       __THREW__ = 0;
       $182 = (invoke_iii($181|0,($176|0),10)|0);
       $183 = __THREW__; __THREW__ = 0;
       $184 = $183&1;
       if (!($184)) {
        __ZNSt3__26localeD2Ev($4);
        (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($171,$182)|0);
        (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($171)|0);
        $$1161 = $$0162;$$1163 = $$0160;
        break;
       }
      }
      $185 = ___cxa_find_matching_catch_2()|0;
      $186 = tempRet0;
      __THREW__ = 0;
      invoke_vi(3263,($4|0));
      $187 = __THREW__; __THREW__ = 0;
      $188 = $187&1;
      if ($188) {
       $189 = ___cxa_find_matching_catch_3(0|0)|0;
       $190 = tempRet0;
       ___clang_call_terminate($189);
       // unreachable;
      } else {
       ___resumeException($185|0);
       // unreachable;
      }
     } else {
      $$1161 = $$0162;$$1163 = $$0160;
     }
    } else {
     $$1161 = $$0162;$$1163 = $$0160;
    }
   }
  } else {
   $$1161 = $$0160;$$1163 = $$0162;
  }
 } while(0);
 $191 = $$1163 < 0.0;
 if ($191) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $192 = ((($0)) + 68|0);
 $193 = HEAP32[$192>>2]|0;
 $194 = $193 & -2;
 $switch = ($194|0)==(2);
 $195 = ((($0)) + 408|0);
 $196 = +HEAPF64[$195>>3];
 $197 = $$1161 < $196;
 if (!($switch)) {
  if ($197) {
   HEAPF64[$195>>3] = $$1161;
  }
  $536 = ((($0)) + 416|0);
  $537 = +HEAPF64[$536>>3];
  $538 = $$1163 > $537;
  if (!($538)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  HEAPF64[$536>>3] = $$1163;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 if (!($197)) {
  $198 = ((($0)) + 416|0);
  $199 = +HEAPF64[$198>>3];
  $200 = $$1163 > $199;
  if (!($200)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $201 = ((($0)) + 336|0);
 $202 = HEAP32[$201>>2]|0;
 $203 = ((($202)) + 16|0);
 $204 = ((($202)) + 36|0);
 $205 = HEAP32[$204>>2]|0;
 $206 = ($205|0)==(0);
 if ($206) {
  if ($197) {
   HEAPF64[$195>>3] = $$1161;
  }
  $533 = ((($0)) + 416|0);
  $534 = +HEAPF64[$533>>3];
  $535 = $$1163 > $534;
  if (!($535)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  HEAPF64[$533>>3] = $$1163;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 __ZN3osg7Matrixd12makeIdentityEv($8);
 $207 = ((($8)) + 128|0);
 ;HEAP32[$207>>2]=0|0;HEAP32[$207+4>>2]=0|0;HEAP32[$207+8>>2]=0|0;HEAP32[$207+12>>2]=0|0;
 do {
  if ($3) {
   $208 = ((($9)) + 16|0);
   dest=$9; stop=dest+48|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
   HEAP32[$208>>2] = 1;
   $209 = ((($0)) + 312|0);
   $210 = HEAP32[$209>>2]|0;
   $211 = ((($210)) + -92|0);
   __THREW__ = 0;
   invoke_viii(3641,($9|0),($211|0),($1|0));
   $212 = __THREW__; __THREW__ = 0;
   $213 = $212&1;
   if (!($213)) {
    __THREW__ = 0;
    invoke_viiii(3642,($8|0),($1|0),($2|0),($9|0));
    $214 = __THREW__; __THREW__ = 0;
    $215 = $214&1;
    if (!($215)) {
     $216 = ((($9)) + 36|0);
     $217 = HEAP32[$216>>2]|0;
     $218 = ($217|0)==(0|0);
     if (!($218)) {
      $219 = ((($9)) + 40|0);
      $220 = HEAP32[$219>>2]|0;
      $221 = ($220|0)==($217|0);
      if (!($221)) {
       $scevgep$i$i$i$i95 = ((($220)) + -12|0);
       $222 = $scevgep$i$i$i$i95;
       $223 = $217;
       $224 = (($222) - ($223))|0;
       $225 = (($224>>>0) / 12)&-1;
       $226 = $225 ^ -1;
       $scevgep5$i$i$i$i96 = (($220) + (($226*12)|0)|0);
       HEAP32[$219>>2] = $scevgep5$i$i$i$i96;
      }
      __ZdlPv($217);
     }
     $227 = ((($9)) + 24|0);
     $228 = HEAP32[$227>>2]|0;
     $229 = ($228|0)==(0|0);
     if (!($229)) {
      $230 = ((($9)) + 28|0);
      $231 = HEAP32[$230>>2]|0;
      $232 = ($231|0)==($228|0);
      if (!($232)) {
       $scevgep$i$i$i3$i100 = ((($231)) + -40|0);
       $233 = $scevgep$i$i$i3$i100;
       $234 = $228;
       $235 = (($233) - ($234))|0;
       $236 = (($235>>>0) / 40)&-1;
       $237 = $236 ^ -1;
       $scevgep5$i$i$i4$i101 = (($231) + (($237*40)|0)|0);
       HEAP32[$230>>2] = $scevgep5$i$i$i4$i101;
      }
      __ZdlPv($228);
     }
     $238 = ((($9)) + 4|0);
     $239 = HEAP32[$238>>2]|0;
     $240 = ($239|0)==(0|0);
     if (!($240)) {
      $241 = ((($9)) + 8|0);
      $242 = HEAP32[$241>>2]|0;
      $243 = ($242|0)==($239|0);
      if (!($243)) {
       $scevgep$i$i$i$i$i105 = ((($242)) + -4|0);
       $244 = $scevgep$i$i$i$i$i105;
       $245 = $239;
       $246 = (($244) - ($245))|0;
       $247 = $246 >>> 2;
       $248 = $247 ^ -1;
       $scevgep5$i$i$i$i$i106 = (($242) + ($248<<2)|0);
       HEAP32[$241>>2] = $scevgep5$i$i$i$i$i106;
      }
      __ZdlPv($239);
     }
     label = 58;
     break;
    }
   }
   $251 = ___cxa_find_matching_catch_2()|0;
   $252 = tempRet0;
   $253 = ((($9)) + 36|0);
   $254 = HEAP32[$253>>2]|0;
   $255 = ($254|0)==(0|0);
   if (!($255)) {
    $256 = ((($9)) + 40|0);
    $257 = HEAP32[$256>>2]|0;
    $258 = ($257|0)==($254|0);
    if (!($258)) {
     $scevgep$i$i$i$i86 = ((($257)) + -12|0);
     $259 = $scevgep$i$i$i$i86;
     $260 = $254;
     $261 = (($259) - ($260))|0;
     $262 = (($261>>>0) / 12)&-1;
     $263 = $262 ^ -1;
     $scevgep5$i$i$i$i87 = (($257) + (($263*12)|0)|0);
     HEAP32[$256>>2] = $scevgep5$i$i$i$i87;
    }
    __ZdlPv($254);
   }
   $264 = ((($9)) + 24|0);
   $265 = HEAP32[$264>>2]|0;
   $266 = ($265|0)==(0|0);
   if (!($266)) {
    $267 = ((($9)) + 28|0);
    $268 = HEAP32[$267>>2]|0;
    $269 = ($268|0)==($265|0);
    if (!($269)) {
     $scevgep$i$i$i3$i = ((($268)) + -40|0);
     $270 = $scevgep$i$i$i3$i;
     $271 = $265;
     $272 = (($270) - ($271))|0;
     $273 = (($272>>>0) / 40)&-1;
     $274 = $273 ^ -1;
     $scevgep5$i$i$i4$i = (($268) + (($274*40)|0)|0);
     HEAP32[$267>>2] = $scevgep5$i$i$i4$i;
    }
    __ZdlPv($265);
   }
   $275 = ((($9)) + 4|0);
   $276 = HEAP32[$275>>2]|0;
   $277 = ($276|0)==(0|0);
   if (!($277)) {
    $278 = ((($9)) + 8|0);
    $279 = HEAP32[$278>>2]|0;
    $280 = ($279|0)==($276|0);
    if (!($280)) {
     $scevgep$i$i$i$i$i90 = ((($279)) + -4|0);
     $281 = $scevgep$i$i$i$i$i90;
     $282 = $276;
     $283 = (($281) - ($282))|0;
     $284 = $283 >>> 2;
     $285 = $284 ^ -1;
     $scevgep5$i$i$i$i$i91 = (($279) + ($285<<2)|0);
     HEAP32[$278>>2] = $scevgep5$i$i$i$i$i91;
    }
    __ZdlPv($276);
   }
   $$3 = $252;$$341 = $251;
  } else {
   __THREW__ = 0;
   invoke_viiii(3642,($8|0),($1|0),($2|0),($203|0));
   $286 = __THREW__; __THREW__ = 0;
   $287 = $286&1;
   if ($287) {
    $249 = ___cxa_find_matching_catch_2()|0;
    $250 = tempRet0;
    $$3 = $250;$$341 = $249;
   } else {
    label = 58;
   }
  }
 } while(0);
 L100: do {
  if ((label|0) == 58) {
   $288 = +HEAPF64[$195>>3];
   $289 = $$1161 < $288;
   L102: do {
    if ($289) {
     HEAPF64[$10>>3] = $$1161;
     $290 = +HEAPF64[$8>>3];
     $291 = ((($10)) + 8|0);
     HEAPF64[$291>>3] = $290;
     $292 = ((($8)) + 8|0);
     $293 = +HEAPF64[$292>>3];
     $294 = ((($10)) + 16|0);
     HEAPF64[$294>>3] = $293;
     $295 = ((($8)) + 16|0);
     $296 = +HEAPF64[$295>>3];
     $297 = ((($10)) + 24|0);
     HEAPF64[$297>>3] = $296;
     $298 = ((($8)) + 24|0);
     $299 = +HEAPF64[$298>>3];
     $300 = ((($10)) + 32|0);
     HEAPF64[$300>>3] = $299;
     $301 = ((($8)) + 32|0);
     $302 = +HEAPF64[$301>>3];
     $303 = ((($10)) + 40|0);
     HEAPF64[$303>>3] = $302;
     $304 = ((($8)) + 40|0);
     $305 = +HEAPF64[$304>>3];
     $306 = ((($10)) + 48|0);
     HEAPF64[$306>>3] = $305;
     $307 = ((($8)) + 48|0);
     $308 = +HEAPF64[$307>>3];
     $309 = ((($10)) + 56|0);
     HEAPF64[$309>>3] = $308;
     $310 = ((($8)) + 56|0);
     $311 = +HEAPF64[$310>>3];
     $312 = ((($10)) + 64|0);
     HEAPF64[$312>>3] = $311;
     $313 = ((($8)) + 64|0);
     $314 = +HEAPF64[$313>>3];
     $315 = ((($10)) + 72|0);
     HEAPF64[$315>>3] = $314;
     $316 = ((($8)) + 72|0);
     $317 = +HEAPF64[$316>>3];
     $318 = ((($10)) + 80|0);
     HEAPF64[$318>>3] = $317;
     $319 = ((($8)) + 80|0);
     $320 = +HEAPF64[$319>>3];
     $321 = ((($10)) + 88|0);
     HEAPF64[$321>>3] = $320;
     $322 = ((($8)) + 88|0);
     $323 = +HEAPF64[$322>>3];
     $324 = ((($10)) + 96|0);
     HEAPF64[$324>>3] = $323;
     $325 = ((($8)) + 96|0);
     $326 = +HEAPF64[$325>>3];
     $327 = ((($10)) + 104|0);
     HEAPF64[$327>>3] = $326;
     $328 = ((($8)) + 104|0);
     $329 = +HEAPF64[$328>>3];
     $330 = ((($10)) + 112|0);
     HEAPF64[$330>>3] = $329;
     $331 = ((($8)) + 112|0);
     $332 = +HEAPF64[$331>>3];
     $333 = ((($10)) + 120|0);
     HEAPF64[$333>>3] = $332;
     $334 = ((($8)) + 120|0);
     $335 = +HEAPF64[$334>>3];
     $336 = ((($10)) + 128|0);
     HEAPF64[$336>>3] = $335;
     $337 = ((($10)) + 136|0);
     $338 = HEAP32[$207>>2]|0;
     HEAP32[$337>>2] = $338;
     $339 = ((($10)) + 140|0);
     $340 = ((($8)) + 132|0);
     __THREW__ = 0;
     invoke_vii(3598,($339|0),($340|0));
     $341 = __THREW__; __THREW__ = 0;
     $342 = $341&1;
     do {
      if ($342) {
       $382 = ___cxa_find_matching_catch_2()|0;
       $383 = tempRet0;
       $$1 = $383;$$139 = $382;
      } else {
       $343 = ((($0)) + 480|0);
       $344 = ((($0)) + 484|0);
       $345 = HEAP32[$344>>2]|0;
       $346 = ($345|0)==(0|0);
       do {
        if ($346) {
         $$015$i$i$i73 = $344;$$042$i$i72 = $344;
        } else {
         $347 = +HEAPF64[$10>>3];
         $$0$i$i$i67 = $345;
         while(1) {
          $348 = ((($$0$i$i$i67)) + 16|0);
          $349 = +HEAPF64[$348>>3];
          $350 = $347 < $349;
          if ($350) {
           $351 = HEAP32[$$0$i$i$i67>>2]|0;
           $352 = ($351|0)==(0|0);
           if ($352) {
            label = 64;
            break;
           } else {
            $$0$be$in$i$i$i69 = $351;
           }
          } else {
           $353 = ((($$0$i$i$i67)) + 4|0);
           $354 = HEAP32[$353>>2]|0;
           $355 = ($354|0)==(0|0);
           if ($355) {
            label = 67;
            break;
           } else {
            $$0$be$in$i$i$i69 = $354;
           }
          }
          $$0$i$i$i67 = $$0$be$in$i$i$i69;
         }
         if ((label|0) == 64) {
          $$015$i$i$i73 = $$0$i$i$i67;$$042$i$i72 = $$0$i$i$i67;
          break;
         }
         else if ((label|0) == 67) {
          $$015$i$i$i73 = $353;$$042$i$i72 = $$0$i$i$i67;
          break;
         }
        }
       } while(0);
       __THREW__ = 0;
       invoke_viii(3643,($6|0),($343|0),($10|0));
       $356 = __THREW__; __THREW__ = 0;
       $357 = $356&1;
       if ($357) {
        $384 = ___cxa_find_matching_catch_2()|0;
        $385 = tempRet0;
        $386 = ((($10)) + 140|0);
        $387 = HEAP32[$386>>2]|0;
        $388 = ($387|0)==(0|0);
        if ($388) {
         $$1 = $385;$$139 = $384;
         break;
        }
        $389 = ((($10)) + 144|0);
        $390 = HEAP32[$389>>2]|0;
        $391 = ($390|0)==($387|0);
        if (!($391)) {
         $scevgep$i$i$i$i$i53 = ((($390)) + -40|0);
         $392 = $scevgep$i$i$i$i$i53;
         $393 = $387;
         $394 = (($392) - ($393))|0;
         $395 = (($394>>>0) / 40)&-1;
         $396 = $395 ^ -1;
         $scevgep5$i$i$i$i$i54 = (($390) + (($396*40)|0)|0);
         HEAP32[$389>>2] = $scevgep5$i$i$i$i$i54;
        }
        __ZdlPv($387);
        $$1 = $385;$$139 = $384;
        break;
       }
       $358 = HEAP32[$6>>2]|0;
       HEAP32[$6>>2] = 0;
       HEAP32[$358>>2] = 0;
       $359 = ((($358)) + 4|0);
       HEAP32[$359>>2] = 0;
       $360 = ((($358)) + 8|0);
       HEAP32[$360>>2] = $$042$i$i72;
       HEAP32[$$015$i$i$i73>>2] = $358;
       $361 = HEAP32[$343>>2]|0;
       $362 = HEAP32[$361>>2]|0;
       $363 = ($362|0)==(0|0);
       if ($363) {
        $367 = $358;
       } else {
        $364 = $362;
        HEAP32[$343>>2] = $364;
        $$pre$i$i$i75 = HEAP32[$$015$i$i$i73>>2]|0;
        $367 = $$pre$i$i$i75;
       }
       $365 = ((($0)) + 484|0);
       $366 = HEAP32[$365>>2]|0;
       __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($366,$367);
       $368 = ((($0)) + 488|0);
       $369 = HEAP32[$368>>2]|0;
       $370 = (($369) + 1)|0;
       HEAP32[$368>>2] = $370;
       $371 = ((($10)) + 140|0);
       $372 = HEAP32[$371>>2]|0;
       $373 = ($372|0)==(0|0);
       if (!($373)) {
        $374 = ((($10)) + 144|0);
        $375 = HEAP32[$374>>2]|0;
        $376 = ($375|0)==($372|0);
        if (!($376)) {
         $scevgep$i$i$i$i$i61 = ((($375)) + -40|0);
         $377 = $scevgep$i$i$i$i$i61;
         $378 = $372;
         $379 = (($377) - ($378))|0;
         $380 = (($379>>>0) / 40)&-1;
         $381 = $380 ^ -1;
         $scevgep5$i$i$i$i$i62 = (($375) + (($381*40)|0)|0);
         HEAP32[$374>>2] = $scevgep5$i$i$i$i$i62;
        }
        __ZdlPv($372);
       }
       break L102;
      }
     } while(0);
     $$3 = $$1;$$341 = $$139;
     break L100;
    }
   } while(0);
   $397 = HEAP32[$192>>2]|0;
   $398 = ($397|0)==(2);
   $399 = ((($0)) + 416|0);
   L138: do {
    if ($398) {
     $400 = +HEAPF64[$399>>3];
     $401 = $$1163 > $400;
     if ($401) {
      HEAPF64[$11>>3] = $$1163;
      $402 = +HEAPF64[$8>>3];
      $403 = ((($11)) + 8|0);
      HEAPF64[$403>>3] = $402;
      $404 = ((($8)) + 8|0);
      $405 = +HEAPF64[$404>>3];
      $406 = ((($11)) + 16|0);
      HEAPF64[$406>>3] = $405;
      $407 = ((($8)) + 16|0);
      $408 = +HEAPF64[$407>>3];
      $409 = ((($11)) + 24|0);
      HEAPF64[$409>>3] = $408;
      $410 = ((($8)) + 24|0);
      $411 = +HEAPF64[$410>>3];
      $412 = ((($11)) + 32|0);
      HEAPF64[$412>>3] = $411;
      $413 = ((($8)) + 32|0);
      $414 = +HEAPF64[$413>>3];
      $415 = ((($11)) + 40|0);
      HEAPF64[$415>>3] = $414;
      $416 = ((($8)) + 40|0);
      $417 = +HEAPF64[$416>>3];
      $418 = ((($11)) + 48|0);
      HEAPF64[$418>>3] = $417;
      $419 = ((($8)) + 48|0);
      $420 = +HEAPF64[$419>>3];
      $421 = ((($11)) + 56|0);
      HEAPF64[$421>>3] = $420;
      $422 = ((($8)) + 56|0);
      $423 = +HEAPF64[$422>>3];
      $424 = ((($11)) + 64|0);
      HEAPF64[$424>>3] = $423;
      $425 = ((($8)) + 64|0);
      $426 = +HEAPF64[$425>>3];
      $427 = ((($11)) + 72|0);
      HEAPF64[$427>>3] = $426;
      $428 = ((($8)) + 72|0);
      $429 = +HEAPF64[$428>>3];
      $430 = ((($11)) + 80|0);
      HEAPF64[$430>>3] = $429;
      $431 = ((($8)) + 80|0);
      $432 = +HEAPF64[$431>>3];
      $433 = ((($11)) + 88|0);
      HEAPF64[$433>>3] = $432;
      $434 = ((($8)) + 88|0);
      $435 = +HEAPF64[$434>>3];
      $436 = ((($11)) + 96|0);
      HEAPF64[$436>>3] = $435;
      $437 = ((($8)) + 96|0);
      $438 = +HEAPF64[$437>>3];
      $439 = ((($11)) + 104|0);
      HEAPF64[$439>>3] = $438;
      $440 = ((($8)) + 104|0);
      $441 = +HEAPF64[$440>>3];
      $442 = ((($11)) + 112|0);
      HEAPF64[$442>>3] = $441;
      $443 = ((($8)) + 112|0);
      $444 = +HEAPF64[$443>>3];
      $445 = ((($11)) + 120|0);
      HEAPF64[$445>>3] = $444;
      $446 = ((($8)) + 120|0);
      $447 = +HEAPF64[$446>>3];
      $448 = ((($11)) + 128|0);
      HEAPF64[$448>>3] = $447;
      $449 = ((($11)) + 136|0);
      $450 = HEAP32[$207>>2]|0;
      HEAP32[$449>>2] = $450;
      $451 = ((($11)) + 140|0);
      $452 = ((($8)) + 132|0);
      __THREW__ = 0;
      invoke_vii(3598,($451|0),($452|0));
      $453 = __THREW__; __THREW__ = 0;
      $454 = $453&1;
      do {
       if ($454) {
        $494 = ___cxa_find_matching_catch_2()|0;
        $495 = tempRet0;
        $$2 = $495;$$240 = $494;
       } else {
        $455 = ((($0)) + 492|0);
        $456 = ((($0)) + 496|0);
        $457 = HEAP32[$456>>2]|0;
        $458 = ($457|0)==(0|0);
        do {
         if ($458) {
          $$015$i$i$i = $456;$$042$i$i = $456;
         } else {
          $459 = +HEAPF64[$11>>3];
          $$0$i$i$i = $457;
          while(1) {
           $460 = ((($$0$i$i$i)) + 16|0);
           $461 = +HEAPF64[$460>>3];
           $462 = $459 < $461;
           if ($462) {
            $463 = HEAP32[$$0$i$i$i>>2]|0;
            $464 = ($463|0)==(0|0);
            if ($464) {
             label = 90;
             break;
            } else {
             $$0$be$in$i$i$i = $463;
            }
           } else {
            $465 = ((($$0$i$i$i)) + 4|0);
            $466 = HEAP32[$465>>2]|0;
            $467 = ($466|0)==(0|0);
            if ($467) {
             label = 93;
             break;
            } else {
             $$0$be$in$i$i$i = $466;
            }
           }
           $$0$i$i$i = $$0$be$in$i$i$i;
          }
          if ((label|0) == 90) {
           $$015$i$i$i = $$0$i$i$i;$$042$i$i = $$0$i$i$i;
           break;
          }
          else if ((label|0) == 93) {
           $$015$i$i$i = $465;$$042$i$i = $$0$i$i$i;
           break;
          }
         }
        } while(0);
        __THREW__ = 0;
        invoke_viii(3643,($7|0),($455|0),($11|0));
        $468 = __THREW__; __THREW__ = 0;
        $469 = $468&1;
        if ($469) {
         $496 = ___cxa_find_matching_catch_2()|0;
         $497 = tempRet0;
         $498 = ((($11)) + 140|0);
         $499 = HEAP32[$498>>2]|0;
         $500 = ($499|0)==(0|0);
         if ($500) {
          $$2 = $497;$$240 = $496;
          break;
         }
         $501 = ((($11)) + 144|0);
         $502 = HEAP32[$501>>2]|0;
         $503 = ($502|0)==($499|0);
         if (!($503)) {
          $scevgep$i$i$i$i$i = ((($502)) + -40|0);
          $504 = $scevgep$i$i$i$i$i;
          $505 = $499;
          $506 = (($504) - ($505))|0;
          $507 = (($506>>>0) / 40)&-1;
          $508 = $507 ^ -1;
          $scevgep5$i$i$i$i$i = (($502) + (($508*40)|0)|0);
          HEAP32[$501>>2] = $scevgep5$i$i$i$i$i;
         }
         __ZdlPv($499);
         $$2 = $497;$$240 = $496;
         break;
        }
        $470 = HEAP32[$7>>2]|0;
        HEAP32[$7>>2] = 0;
        HEAP32[$470>>2] = 0;
        $471 = ((($470)) + 4|0);
        HEAP32[$471>>2] = 0;
        $472 = ((($470)) + 8|0);
        HEAP32[$472>>2] = $$042$i$i;
        HEAP32[$$015$i$i$i>>2] = $470;
        $473 = HEAP32[$455>>2]|0;
        $474 = HEAP32[$473>>2]|0;
        $475 = ($474|0)==(0|0);
        if ($475) {
         $479 = $470;
        } else {
         $476 = $474;
         HEAP32[$455>>2] = $476;
         $$pre$i$i$i = HEAP32[$$015$i$i$i>>2]|0;
         $479 = $$pre$i$i$i;
        }
        $477 = ((($0)) + 496|0);
        $478 = HEAP32[$477>>2]|0;
        __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($478,$479);
        $480 = ((($0)) + 500|0);
        $481 = HEAP32[$480>>2]|0;
        $482 = (($481) + 1)|0;
        HEAP32[$480>>2] = $482;
        $483 = ((($11)) + 140|0);
        $484 = HEAP32[$483>>2]|0;
        $485 = ($484|0)==(0|0);
        if (!($485)) {
         $486 = ((($11)) + 144|0);
         $487 = HEAP32[$486>>2]|0;
         $488 = ($487|0)==($484|0);
         if (!($488)) {
          $scevgep$i$i$i$i$i47 = ((($487)) + -40|0);
          $489 = $scevgep$i$i$i$i$i47;
          $490 = $484;
          $491 = (($489) - ($490))|0;
          $492 = (($491>>>0) / 40)&-1;
          $493 = $492 ^ -1;
          $scevgep5$i$i$i$i$i48 = (($487) + (($493*40)|0)|0);
          HEAP32[$486>>2] = $scevgep5$i$i$i$i$i48;
         }
         __ZdlPv($484);
        }
        $$pr$pre = HEAP32[$192>>2]|0;
        $phitmp = ($$pr$pre|0)==(2);
        if ($phitmp) {
         break L138;
        } else {
         label = 109;
         break L138;
        }
       }
      } while(0);
      $$3 = $$2;$$341 = $$240;
      break L100;
     }
    } else {
     label = 109;
    }
   } while(0);
   if ((label|0) == 109) {
    $509 = +HEAPF64[$399>>3];
    $510 = $$1163 > $509;
    if ($510) {
     HEAPF64[$399>>3] = $$1163;
    }
   }
   $511 = ((($8)) + 132|0);
   $512 = HEAP32[$511>>2]|0;
   $513 = ($512|0)==(0|0);
   if (!($513)) {
    $514 = ((($8)) + 136|0);
    $515 = HEAP32[$514>>2]|0;
    $516 = ($515|0)==($512|0);
    if (!($516)) {
     $scevgep$i$i$i$i42 = ((($515)) + -40|0);
     $517 = $scevgep$i$i$i$i42;
     $518 = $512;
     $519 = (($517) - ($518))|0;
     $520 = (($519>>>0) / 40)&-1;
     $521 = $520 ^ -1;
     $scevgep5$i$i$i$i43 = (($515) + (($521*40)|0)|0);
     HEAP32[$514>>2] = $scevgep5$i$i$i$i43;
    }
    __ZdlPv($512);
   }
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 $522 = ((($8)) + 132|0);
 $523 = HEAP32[$522>>2]|0;
 $524 = ($523|0)==(0|0);
 if ($524) {
  ___resumeException($$341|0);
  // unreachable;
 }
 $525 = ((($8)) + 136|0);
 $526 = HEAP32[$525>>2]|0;
 $527 = ($526|0)==($523|0);
 if (!($527)) {
  $scevgep$i$i$i$i = ((($526)) + -40|0);
  $528 = $scevgep$i$i$i$i;
  $529 = $523;
  $530 = (($528) - ($529))|0;
  $531 = (($530>>>0) / 40)&-1;
  $532 = $531 ^ -1;
  $scevgep5$i$i$i$i = (($526) + (($532*40)|0)|0);
  HEAP32[$525>>2] = $scevgep5$i$i$i$i;
 }
 __ZdlPv($523);
 ___resumeException($$341|0);
 // unreachable;
 return (0)|0;
}
function __ZN7osgUtil11CullVisitor19addDrawableAndDepthEPN3osg8DrawableEPNS1_10RefMatrixdEf($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = +$3;
 var $$pre = 0, $$pre$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $4 = sp + 4|0;
 $5 = sp;
 $6 = ((($0)) + 376|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($7)) + 36|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($7)) + 40|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($9|0)==($11|0);
 if ($12) {
  $13 = ((($0)) + 384|0);
  $14 = HEAP32[$13>>2]|0;
  HEAP32[$4>>2] = $7;
  $15 = ((($14)) + 60|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ((($14)) + 64|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = ($16|0)==($18|0);
  if ($19) {
   $23 = ((($14)) + 56|0);
   __ZNSt3__26vectorIPN7osgUtil10StateGraphENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_($23,$4);
  } else {
   $20 = $7;
   HEAP32[$16>>2] = $20;
   $21 = HEAP32[$15>>2]|0;
   $22 = ((($21)) + 4|0);
   HEAP32[$15>>2] = $22;
  }
  $$pre = HEAP32[$6>>2]|0;
  $29 = $$pre;
 } else {
  $29 = $7;
 }
 $24 = ((($0)) + 132|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (__ZN7osgUtil11CullVisitor23createOrReuseRenderLeafEPN3osg8DrawableEPNS1_10RefMatrixdES5_f($0,$1,$25,$2,$3)|0);
 $27 = ($26|0)==(0|0);
 if ($27) {
  STACKTOP = sp;return;
 }
 $28 = ((($29)) + 48|0);
 HEAPF32[$28>>2] = 3.4028234663852886E+38;
 $30 = ((($29)) + 52|0);
 HEAPF32[$30>>2] = 3.4028234663852886E+38;
 HEAP32[$5>>2] = $26;
 $31 = ((($26)) + 8|0);
 $32 = HEAP32[$31>>2]|0;HEAP32[$31>>2] = (($32+1)|0);
 $33 = ((($29)) + 40|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ((($29)) + 44|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = ($34|0)==($36|0);
 if ($37) {
  $44 = ((($29)) + 36|0);
  __THREW__ = 0;
  invoke_vii(3644,($44|0),($5|0));
  $45 = __THREW__; __THREW__ = 0;
  $46 = $45&1;
  if ($46) {
   $57 = ___cxa_find_matching_catch_2()|0;
   $58 = tempRet0;
   $59 = HEAP32[$5>>2]|0;
   $60 = ($59|0)==(0|0);
   if ($60) {
    ___resumeException($57|0);
    // unreachable;
   }
   $61 = ((($59)) + 8|0);
   $62 = HEAP32[$61>>2]|0;HEAP32[$61>>2] = (($62-1)|0);
   $63 = ($62|0)==(1);
   if (!($63)) {
    ___resumeException($57|0);
    // unreachable;
   }
   __THREW__ = 0;
   invoke_viii(3262,($59|0),1,1);
   $64 = __THREW__; __THREW__ = 0;
   $65 = $64&1;
   if ($65) {
    $66 = ___cxa_find_matching_catch_3(0|0)|0;
    $67 = tempRet0;
    ___clang_call_terminate($66);
    // unreachable;
   } else {
    ___resumeException($57|0);
    // unreachable;
   }
  }
 } else {
  $38 = HEAP32[$5>>2]|0;
  HEAP32[$34>>2] = $38;
  $39 = ($38|0)==(0|0);
  if ($39) {
   $43 = $34;
  } else {
   $40 = ((($38)) + 8|0);
   $41 = HEAP32[$40>>2]|0;HEAP32[$40>>2] = (($41+1)|0);
   $$pre$i$i = HEAP32[$33>>2]|0;
   $43 = $$pre$i$i;
  }
  $42 = ((($43)) + 4|0);
  HEAP32[$33>>2] = $42;
 }
 $47 = HEAP32[$5>>2]|0;
 $48 = ($47|0)==(0|0);
 if (!($48)) {
  $49 = ((($47)) + 8|0);
  $50 = HEAP32[$49>>2]|0;HEAP32[$49>>2] = (($50-1)|0);
  $51 = ($50|0)==(1);
  if ($51) {
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($47,1,1);
  }
 }
 $52 = ((($26)) + 12|0);
 HEAP32[$52>>2] = $29;
 $53 = ((($29)) + 60|0);
 $54 = HEAP8[$53>>0]|0;
 $55 = ($54<<24>>24)==(0);
 if ($55) {
  STACKTOP = sp;return;
 }
 $56 = ((($26)) + 32|0);
 HEAP8[$56>>0] = 1;
 STACKTOP = sp;return;
}
function __ZNSt3__26vectorIPN7osgUtil10StateGraphENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(1073741823);
 if ($8) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $9 = ((($0)) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) - ($4))|0;
 $12 = $11 >> 2;
 $13 = ($12>>>0)<(536870911);
 $14 = $11 >> 1;
 $15 = ($14>>>0)<($7>>>0);
 $$sroa$speculated$i = $15 ? $7 : $14;
 $$sroa$speculated$$i = $13 ? $$sroa$speculated$i : 1073741823;
 $16 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($16) {
   $26 = 0;
  } else {
   $17 = ($$sroa$speculated$$i>>>0)>(1073741823);
   if (!($17)) {
    $23 = $$sroa$speculated$$i << 2;
    $24 = (__Znwj($23)|0);
    $26 = $24;
    break;
   }
   $18 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($18|0),(204840|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if ($20) {
    $21 = ___cxa_find_matching_catch_2()|0;
    $22 = tempRet0;
    ___cxa_free_exception(($18|0));
    ___resumeException($21|0);
    // unreachable;
   } else {
    HEAP32[$18>>2] = (99824);
    ___cxa_throw(($18|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $25 = (($26) + ($6<<2)|0);
 $27 = (($26) + ($$sroa$speculated$$i<<2)|0);
 $28 = $27;
 $29 = HEAP32[$1>>2]|0;
 HEAP32[$25>>2] = $29;
 $30 = ((($25)) + 4|0);
 $31 = $30;
 $32 = (0 - ($6))|0;
 $33 = (($25) + ($32<<2)|0);
 $34 = $33;
 $35 = ($5|0)>(0);
 if ($35) {
  $36 = $4;
  _memcpy(($33|0),($36|0),($5|0))|0;
 }
 HEAP32[$0>>2] = $34;
 HEAP32[$2>>2] = $31;
 HEAP32[$9>>2] = $28;
 $37 = ($4|0)==(0);
 if ($37) {
  return;
 }
 $38 = $4;
 __ZdlPv($38);
 return;
}
function __ZN7osgUtil11CullVisitor23createOrReuseRenderLeafEPN3osg8DrawableEPNS1_10RefMatrixdES5_f($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = +$4;
 var $$0 = 0, $$019 = 0, $$020 = 0, $$pre = 0, $$pre$i = 0, $$pre$pre = 0, $$pre44 = 0, $$pre44$pre = 0, $$pre45 = 0, $$pre45$pre = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0;
 var $163 = 0, $164 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $5 = sp + 4|0;
 $6 = sp;
 $7 = ((($0)) + 436|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($0)) + 424|0);
 $10 = ((($0)) + 428|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = HEAP32[$9>>2]|0;
 $13 = (($11) - ($12))|0;
 $14 = $13 >> 2;
 $15 = ($8>>>0)<($14>>>0);
 $16 = $12;
 if ($15) {
  $18 = $16;$19 = $8;
  while(1) {
   $17 = (($18) + ($19<<2)|0);
   $20 = HEAP32[$17>>2]|0;
   /* fence */;
   $21 = ((($20)) + 8|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = ($22|0)>(1);
   if (!($23)) {
    label = 4;
    break;
   }
   $24 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
   $25 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($24,115977,68)|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = ((($26)) + -12|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = (($25) + ($28)|0);
   __ZNKSt3__28ios_base6getlocEv($5,$29);
   __THREW__ = 0;
   $30 = (invoke_iii(3255,($5|0),(215188|0))|0);
   $31 = __THREW__; __THREW__ = 0;
   $32 = $31&1;
   if ($32) {
    label = 7;
    break;
   }
   $33 = HEAP32[$30>>2]|0;
   $34 = ((($33)) + 28|0);
   $35 = HEAP32[$34>>2]|0;
   __THREW__ = 0;
   $36 = (invoke_iii($35|0,($30|0),10)|0);
   $37 = __THREW__; __THREW__ = 0;
   $38 = $37&1;
   if ($38) {
    label = 7;
    break;
   }
   __ZNSt3__26localeD2Ev($5);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($25,$36)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($25)|0);
   $45 = HEAP32[$7>>2]|0;
   $46 = (($45) + 1)|0;
   HEAP32[$7>>2] = $46;
   $47 = HEAP32[$10>>2]|0;
   $48 = HEAP32[$9>>2]|0;
   $49 = (($47) - ($48))|0;
   $50 = $49 >> 2;
   $51 = ($46>>>0)<($50>>>0);
   $52 = $48;
   if ($51) {
    $18 = $52;$19 = $46;
   } else {
    $$pre = $46;$$pre44 = $47;$$pre45 = $48;
    break;
   }
  }
  if ((label|0) == 4) {
   $$pre$pre = HEAP32[$7>>2]|0;
   $$pre44$pre = HEAP32[$10>>2]|0;
   $$pre45$pre = HEAP32[$9>>2]|0;
   $$pre = $$pre$pre;$$pre44 = $$pre44$pre;$$pre45 = $$pre45$pre;
  }
  else if ((label|0) == 7) {
   $39 = ___cxa_find_matching_catch_2()|0;
   $40 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($5|0));
   $41 = __THREW__; __THREW__ = 0;
   $42 = $41&1;
   if ($42) {
    $43 = ___cxa_find_matching_catch_3(0|0)|0;
    $44 = tempRet0;
    ___clang_call_terminate($43);
    // unreachable;
   } else {
    ___resumeException($39|0);
    // unreachable;
   }
  }
  $53 = $$pre45;
  $55 = $$pre45;$56 = $$pre44;$58 = $$pre;$62 = $53;
 } else {
  $55 = $12;$56 = $11;$58 = $8;$62 = $16;
 }
 $54 = (($56) - ($55))|0;
 $57 = $54 >> 2;
 $59 = ($58>>>0)<($57>>>0);
 if ($59) {
  $60 = (($58) + 1)|0;
  HEAP32[$7>>2] = $60;
  $61 = (($62) + ($58<<2)|0);
  $63 = HEAP32[$61>>2]|0;
  $64 = ((($0)) + 400|0);
  $65 = HEAP32[$64>>2]|0;
  $66 = (($65) + 1)|0;
  HEAP32[$64>>2] = $66;
  $67 = ((($63)) + 12|0);
  HEAP32[$67>>2] = 0;
  $68 = ((($63)) + 16|0);
  $69 = HEAP32[$68>>2]|0;
  $70 = ($69|0)==($1|0);
  if (!($70)) {
   HEAP32[$68>>2] = $1;
   $71 = ($1|0)==(0|0);
   if (!($71)) {
    $72 = ((($1)) + 8|0);
    $73 = HEAP32[$72>>2]|0;HEAP32[$72>>2] = (($73+1)|0);
   }
   $74 = ($69|0)==(0|0);
   if (!($74)) {
    $75 = ((($69)) + 8|0);
    $76 = HEAP32[$75>>2]|0;HEAP32[$75>>2] = (($76-1)|0);
    $77 = ($76|0)==(1);
    if ($77) {
     __ZNK3osg10Referenced24signalObserversAndDeleteEbb($69,1,1);
    }
   }
  }
  $78 = ((($63)) + 20|0);
  $79 = HEAP32[$78>>2]|0;
  $80 = ($79|0)==($2|0);
  if (!($80)) {
   HEAP32[$78>>2] = $2;
   $81 = ($2|0)==(0|0);
   if (!($81)) {
    $82 = ((($2)) + 8|0);
    $83 = HEAP32[$82>>2]|0;HEAP32[$82>>2] = (($83+1)|0);
   }
   $84 = ($79|0)==(0|0);
   if (!($84)) {
    $85 = ((($79)) + 8|0);
    $86 = HEAP32[$85>>2]|0;HEAP32[$85>>2] = (($86-1)|0);
    $87 = ($86|0)==(1);
    if ($87) {
     __ZNK3osg10Referenced24signalObserversAndDeleteEbb($79,1,1);
    }
   }
  }
  $88 = ((($63)) + 24|0);
  $89 = HEAP32[$88>>2]|0;
  $90 = ($89|0)==($3|0);
  if (!($90)) {
   HEAP32[$88>>2] = $3;
   $91 = ($3|0)==(0|0);
   if (!($91)) {
    $92 = ((($3)) + 8|0);
    $93 = HEAP32[$92>>2]|0;HEAP32[$92>>2] = (($93+1)|0);
   }
   $94 = ($89|0)==(0|0);
   if (!($94)) {
    $95 = ((($89)) + 8|0);
    $96 = HEAP32[$95>>2]|0;HEAP32[$95>>2] = (($96-1)|0);
    $97 = ($96|0)==(1);
    if ($97) {
     __ZNK3osg10Referenced24signalObserversAndDeleteEbb($89,1,1);
    }
   }
  }
  $98 = ((($63)) + 28|0);
  HEAPF32[$98>>2] = $4;
  $99 = ((($1)) + 24|0);
  $100 = HEAP32[$99>>2]|0;
  $101 = ($100|0)==(0);
  $102 = ((($63)) + 32|0);
  $103 = $101&1;
  HEAP8[$102>>0] = $103;
  $104 = ((($63)) + 36|0);
  HEAP32[$104>>2] = $65;
  $$020 = $63;
  STACKTOP = sp;return ($$020|0);
 }
 $105 = (__Znwj(40)|0);
 $106 = ((($0)) + 400|0);
 $107 = HEAP32[$106>>2]|0;
 $108 = (($107) + 1)|0;
 HEAP32[$106>>2] = $108;
 __THREW__ = 0;
 invoke_vii(3435,($105|0),0);
 $109 = __THREW__; __THREW__ = 0;
 $110 = $109&1;
 if ($110) {
  $152 = ___cxa_find_matching_catch_2()|0;
  $153 = tempRet0;
  __ZdlPv($105);
  $$0 = $153;$$019 = $152;
  ___resumeException($$019|0);
  // unreachable;
 }
 HEAP32[$105>>2] = (54188);
 $111 = ((($105)) + 12|0);
 HEAP32[$111>>2] = 0;
 $112 = ((($105)) + 16|0);
 HEAP32[$112>>2] = $1;
 $113 = ($1|0)==(0|0);
 if (!($113)) {
  $114 = ((($1)) + 8|0);
  $115 = HEAP32[$114>>2]|0;HEAP32[$114>>2] = (($115+1)|0);
 }
 $116 = ((($105)) + 20|0);
 HEAP32[$116>>2] = $2;
 $117 = ($2|0)==(0|0);
 if (!($117)) {
  $118 = ((($2)) + 8|0);
  $119 = HEAP32[$118>>2]|0;HEAP32[$118>>2] = (($119+1)|0);
 }
 $120 = ((($105)) + 24|0);
 HEAP32[$120>>2] = $3;
 $121 = ($3|0)==(0|0);
 if (!($121)) {
  $122 = ((($3)) + 8|0);
  $123 = HEAP32[$122>>2]|0;HEAP32[$122>>2] = (($123+1)|0);
 }
 $124 = ((($105)) + 28|0);
 HEAPF32[$124>>2] = $4;
 $125 = ((($105)) + 36|0);
 HEAP32[$125>>2] = $107;
 $126 = ((($1)) + 24|0);
 $127 = HEAP32[$126>>2]|0;
 $128 = ($127|0)==(0);
 $129 = ((($105)) + 32|0);
 $130 = $128&1;
 HEAP8[$129>>0] = $130;
 HEAP32[$6>>2] = $105;
 $131 = ((($105)) + 8|0);
 $132 = HEAP32[$131>>2]|0;HEAP32[$131>>2] = (($132+1)|0);
 $133 = HEAP32[$10>>2]|0;
 $134 = ((($0)) + 432|0);
 $135 = HEAP32[$134>>2]|0;
 $136 = ($133|0)==($135|0);
 if ($136) {
  __THREW__ = 0;
  invoke_vii(3644,($9|0),($6|0));
  $143 = __THREW__; __THREW__ = 0;
  $144 = $143&1;
  if ($144) {
   $154 = ___cxa_find_matching_catch_2()|0;
   $155 = tempRet0;
   $156 = HEAP32[$6>>2]|0;
   $157 = ($156|0)==(0|0);
   if (!($157)) {
    $158 = ((($156)) + 8|0);
    $159 = HEAP32[$158>>2]|0;HEAP32[$158>>2] = (($159-1)|0);
    $160 = ($159|0)==(1);
    if ($160) {
     __THREW__ = 0;
     invoke_viii(3262,($156|0),1,1);
     $161 = __THREW__; __THREW__ = 0;
     $162 = $161&1;
     if ($162) {
      $163 = ___cxa_find_matching_catch_3(0|0)|0;
      $164 = tempRet0;
      ___clang_call_terminate($163);
      // unreachable;
     }
    }
   }
   $$0 = $155;$$019 = $154;
   ___resumeException($$019|0);
   // unreachable;
  }
 } else {
  $137 = HEAP32[$6>>2]|0;
  HEAP32[$133>>2] = $137;
  $138 = ($137|0)==(0|0);
  if ($138) {
   $142 = $133;
  } else {
   $139 = ((($137)) + 8|0);
   $140 = HEAP32[$139>>2]|0;HEAP32[$139>>2] = (($140+1)|0);
   $$pre$i = HEAP32[$10>>2]|0;
   $142 = $$pre$i;
  }
  $141 = ((($142)) + 4|0);
  HEAP32[$10>>2] = $141;
 }
 $145 = HEAP32[$6>>2]|0;
 $146 = ($145|0)==(0|0);
 if (!($146)) {
  $147 = ((($145)) + 8|0);
  $148 = HEAP32[$147>>2]|0;HEAP32[$147>>2] = (($148-1)|0);
  $149 = ($148|0)==(1);
  if ($149) {
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($145,1,1);
  }
 }
 $150 = HEAP32[$7>>2]|0;
 $151 = (($150) + 1)|0;
 HEAP32[$7>>2] = $151;
 $$020 = $105;
 STACKTOP = sp;return ($$020|0);
}
function __ZNSt3__26vectorIN3osg7ref_ptrIN7osgUtil10RenderLeafEEENS_9allocatorIS5_EEE21__push_back_slow_pathIKS5_EEvRT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$06$i$i = 0, $$pre = 0, $$pre$i = 0, $$pre38 = 0, $$pre39 = 0, $$sroa$7$0 = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(1073741823);
 $9 = $4;
 $10 = $3;
 if ($8) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $11 = ((($0)) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) - ($4))|0;
 $14 = $13 >> 2;
 $15 = ($14>>>0)<(536870911);
 $16 = $13 >> 1;
 $17 = ($16>>>0)<($7>>>0);
 $$sroa$speculated$i = $17 ? $7 : $16;
 $$sroa$speculated$$i = $15 ? $$sroa$speculated$i : 1073741823;
 $18 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($18) {
   $28 = 0;
  } else {
   $19 = ($$sroa$speculated$$i>>>0)>(1073741823);
   if (!($19)) {
    $25 = $$sroa$speculated$$i << 2;
    $26 = (__Znwj($25)|0);
    $28 = $26;
    break;
   }
   $20 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($20|0),(204840|0));
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if ($22) {
    $23 = ___cxa_find_matching_catch_2()|0;
    $24 = tempRet0;
    ___cxa_free_exception(($20|0));
    ___resumeException($23|0);
    // unreachable;
   } else {
    HEAP32[$20>>2] = (99824);
    ___cxa_throw(($20|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $27 = (($28) + ($6<<2)|0);
 $29 = $27;
 $30 = (($28) + ($$sroa$speculated$$i<<2)|0);
 $31 = $30;
 $32 = HEAP32[$1>>2]|0;
 HEAP32[$27>>2] = $32;
 $33 = ($32|0)==(0|0);
 if ($33) {
  $38 = $10;$40 = $9;
 } else {
  $34 = ((($32)) + 8|0);
  $35 = HEAP32[$34>>2]|0;HEAP32[$34>>2] = (($35+1)|0);
  $$pre = HEAP32[$0>>2]|0;
  $$pre38 = HEAP32[$2>>2]|0;
  $38 = $$pre38;$40 = $$pre;
 }
 $36 = ((($27)) + 4|0);
 $37 = $36;
 $39 = ($38|0)==($40|0);
 if ($39) {
  $41 = $38;
  $53 = $29;$54 = $41;$56 = $38;
 } else {
  $$06$i$i = $38;$$sroa$7$0 = $29;$44 = $27;
  while(1) {
   $42 = ((($$06$i$i)) + -4|0);
   $43 = ((($44)) + -4|0);
   $45 = HEAP32[$42>>2]|0;
   HEAP32[$43>>2] = $45;
   $46 = ($45|0)==(0|0);
   if (!($46)) {
    $47 = ((($45)) + 8|0);
    $48 = HEAP32[$47>>2]|0;HEAP32[$47>>2] = (($48+1)|0);
   }
   $49 = $$sroa$7$0;
   $50 = ((($49)) + -4|0);
   $51 = $50;
   $52 = ($42|0)==($40|0);
   if ($52) {
    break;
   } else {
    $$06$i$i = $42;$$sroa$7$0 = $51;$44 = $50;
   }
  }
  $$pre$i = HEAP32[$0>>2]|0;
  $$pre39 = HEAP32[$2>>2]|0;
  $53 = $51;$54 = $$pre$i;$56 = $$pre39;
 }
 HEAP32[$0>>2] = $53;
 HEAP32[$2>>2] = $37;
 HEAP32[$11>>2] = $31;
 $55 = $54;
 $57 = ($56|0)==($55|0);
 L25: do {
  if (!($57)) {
   $59 = $56;
   while(1) {
    $58 = ((($59)) + -4|0);
    $60 = HEAP32[$58>>2]|0;
    $61 = ($60|0)==(0|0);
    if (!($61)) {
     $62 = ((($60)) + 8|0);
     $63 = HEAP32[$62>>2]|0;HEAP32[$62>>2] = (($63-1)|0);
     $64 = ($63|0)==(1);
     if ($64) {
      __THREW__ = 0;
      invoke_viii(3262,($60|0),1,1);
      $65 = __THREW__; __THREW__ = 0;
      $66 = $65&1;
      if ($66) {
       break;
      }
     }
    }
    HEAP32[$58>>2] = 0;
    $67 = ($58|0)==($55|0);
    if ($67) {
     break L25;
    } else {
     $59 = $58;
    }
   }
   $68 = ___cxa_find_matching_catch_2()|0;
   $69 = tempRet0;
   ___cxa_call_unexpected(($68|0));
   // unreachable;
  }
 } while(0);
 $70 = ($54|0)==(0);
 if ($70) {
  return;
 }
 $71 = $54;
 __ZdlPv($71);
 return;
}
function __ZN3osg8Polytope31setAndTransformProvidingInverseERKS0_RKNS_7MatrixdE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$02849 = 0, $$030$ = 0, $$030$lcssa = 0, $$03048 = 0, $$046 = 0, $$1 = 0, $$12945 = 0, $$phi$trans$insert = 0, $$phi$trans$insert55 = 0, $$phi$trans$insert57 = 0, $$phi$trans$insert59 = 0, $$pre = 0, $$pre$phi62Z2D = 0, $$pre$phi63Z2D = 0, $$pre$phi64Z2D = 0, $$pre$phi66Z2D = 0, $$pre$phi68Z2D = 0, $$pre$phiZ2D = 0, $$pre54 = 0.0, $$pre56 = 0.0;
 var $$pre58 = 0.0, $$pre60 = 0.0, $$pre61 = 0, $$pre65 = 0, $$pre67 = 0, $$sroa$038$047 = 0, $$sroa$038$144 = 0, $10 = 0, $100 = 0.0, $101 = 0.0, $102 = 0.0, $103 = 0.0, $104 = 0.0, $105 = 0.0, $106 = 0.0, $107 = 0.0, $108 = 0.0, $109 = 0.0, $11 = 0, $110 = 0.0;
 var $111 = 0.0, $112 = 0.0, $113 = 0.0, $114 = 0.0, $115 = 0.0, $116 = 0.0, $117 = 0.0, $118 = 0.0, $119 = 0.0, $12 = 0, $120 = 0.0, $121 = 0.0, $122 = 0.0, $123 = 0.0, $124 = 0.0, $125 = 0.0, $126 = 0.0, $127 = 0.0, $128 = 0.0, $129 = 0.0;
 var $13 = 0, $130 = 0.0, $131 = 0.0, $132 = 0.0, $133 = 0.0, $134 = 0.0, $135 = 0.0, $136 = 0.0, $137 = 0.0, $138 = 0.0, $139 = 0.0, $14 = 0, $140 = 0.0, $141 = 0.0, $142 = 0.0, $143 = 0.0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0.0, $154 = 0.0, $155 = 0.0, $156 = 0.0, $157 = 0.0, $158 = 0.0, $159 = 0.0, $16 = 0, $160 = 0.0, $161 = 0.0, $162 = 0.0, $163 = 0.0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0.0, $75 = 0, $76 = 0.0, $77 = 0, $78 = 0, $79 = 0.0, $8 = 0, $80 = 0, $81 = 0, $82 = 0.0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0.0, $97 = 0.0, $98 = 0.0, $99 = 0.0, $not$ = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i32 = 0, $scevgep5$i$i$i = 0;
 var $scevgep5$i$i$i33 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($0|0)==($1|0);
 if (!($3)) {
  $4 = ((($0)) + 36|0);
  $5 = ((($1)) + 36|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ((($1)) + 40|0);
  $8 = HEAP32[$7>>2]|0;
  __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE6assignIPS2_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS2_NS_15iterator_traitsIS9_E9referenceEEE5valueEvE4typeES9_S9_($4,$6,$8);
 }
 $9 = HEAP32[$1>>2]|0;
 $10 = ($9|0)==(0);
 if ($10) {
  HEAP32[$0>>2] = 0;
  $11 = ((($0)) + 20|0);
  HEAP32[$11>>2] = 0;
  $12 = ((($0)) + 24|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ((($0)) + 28|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = ($15|0)==($13|0);
  if ($16) {
   return;
  }
  $scevgep$i$i$i32 = ((($15)) + -40|0);
  $17 = $scevgep$i$i$i32;
  $18 = $13;
  $19 = (($17) - ($18))|0;
  $20 = (($19>>>0) / 40)&-1;
  $21 = $20 ^ -1;
  $scevgep5$i$i$i33 = (($15) + (($21*40)|0)|0);
  HEAP32[$14>>2] = $scevgep5$i$i$i33;
  return;
 }
 $22 = ((($1)) + 24|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ((($1)) + 28|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($23|0)==($25|0);
 if ($26) {
  $$030$lcssa = 0;
 } else {
  $$02849 = 1;$$03048 = 0;$$sroa$038$047 = $23;
  while(1) {
   $27 = $$02849 & $9;
   $not$ = ($27|0)!=(0);
   $28 = $not$&1;
   $$030$ = (($28) + ($$03048))|0;
   $29 = $$02849 << 1;
   $30 = ((($$sroa$038$047)) + 40|0);
   $31 = ($30|0)==($25|0);
   if ($31) {
    $$030$lcssa = $$030$;
    break;
   } else {
    $$02849 = $29;$$03048 = $$030$;$$sroa$038$047 = $30;
   }
  }
 }
 $32 = ((($0)) + 24|0);
 $33 = ((($0)) + 28|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = HEAP32[$32>>2]|0;
 $36 = (($34) - ($35))|0;
 $37 = (($36|0) / 40)&-1;
 $38 = ($$030$lcssa>>>0)>($37>>>0);
 $39 = $35;
 $40 = $34;
 if ($38) {
  $41 = (($$030$lcssa) - ($37))|0;
  __ZNSt3__26vectorIN3osg5PlaneENS_9allocatorIS2_EEE8__appendEj($32,$41);
  $$pre = HEAP32[$22>>2]|0;
  $52 = $$pre;
 } else {
  $42 = ($$030$lcssa>>>0)<($37>>>0);
  if ($42) {
   $43 = (($39) + (($$030$lcssa*40)|0)|0);
   $44 = ($40|0)==($43|0);
   if ($44) {
    $52 = $23;
   } else {
    $scevgep$i$i$i = ((($40)) + -40|0);
    $45 = $scevgep$i$i$i;
    $46 = $43;
    $47 = (($45) - ($46))|0;
    $48 = (($47>>>0) / 40)&-1;
    $49 = $48 ^ -1;
    $scevgep5$i$i$i = (($40) + (($49*40)|0)|0);
    HEAP32[$33>>2] = $scevgep5$i$i$i;
    $52 = $23;
   }
  } else {
   $52 = $23;
  }
 }
 $50 = ((($0)) + 20|0);
 HEAP32[$50>>2] = 0;
 $51 = HEAP32[$24>>2]|0;
 $53 = ($52|0)==($51|0);
 if ($53) {
  $170 = 0;
 } else {
  $54 = ((($2)) + 8|0);
  $55 = ((($2)) + 16|0);
  $56 = ((($2)) + 24|0);
  $57 = ((($2)) + 32|0);
  $58 = ((($2)) + 40|0);
  $59 = ((($2)) + 48|0);
  $60 = ((($2)) + 56|0);
  $61 = ((($2)) + 64|0);
  $62 = ((($2)) + 72|0);
  $63 = ((($2)) + 80|0);
  $64 = ((($2)) + 88|0);
  $65 = ((($2)) + 96|0);
  $66 = ((($2)) + 104|0);
  $67 = ((($2)) + 112|0);
  $68 = ((($2)) + 120|0);
  $$046 = 0;$$12945 = 1;$$sroa$038$144 = $52;$165 = 0;
  while(1) {
   $69 = $$12945 & $9;
   $70 = ($69|0)==(0);
   if ($70) {
    $$1 = $$046;$171 = $165;
   } else {
    $71 = HEAP32[$32>>2]|0;
    $72 = (($71) + (($$046*40)|0)|0);
    $73 = ($$sroa$038$144|0)==($72|0);
    if ($73) {
     $$phi$trans$insert = (($71) + (($$046*40)|0)|0);
     $$pre54 = +HEAPF64[$$phi$trans$insert>>3];
     $$phi$trans$insert55 = (((($71) + (($$046*40)|0)|0)) + 8|0);
     $$pre56 = +HEAPF64[$$phi$trans$insert55>>3];
     $$phi$trans$insert57 = (((($71) + (($$046*40)|0)|0)) + 16|0);
     $$pre58 = +HEAPF64[$$phi$trans$insert57>>3];
     $$phi$trans$insert59 = (((($71) + (($$046*40)|0)|0)) + 24|0);
     $$pre60 = +HEAPF64[$$phi$trans$insert59>>3];
     $$pre65 = (((($71) + (($$046*40)|0)|0)) + 32|0);
     $$pre67 = (((($71) + (($$046*40)|0)|0)) + 36|0);
     $$pre$phi62Z2D = $$phi$trans$insert55;$$pre$phi63Z2D = $$phi$trans$insert57;$$pre$phi64Z2D = $$phi$trans$insert59;$$pre$phi66Z2D = $$pre65;$$pre$phi68Z2D = $$pre67;$$pre$phiZ2D = $$phi$trans$insert;$101 = $$pre56;$105 = $$pre58;$109 = $$pre60;$98 = $$pre54;
    } else {
     $74 = +HEAPF64[$$sroa$038$144>>3];
     HEAPF64[$72>>3] = $74;
     $75 = ((($$sroa$038$144)) + 8|0);
     $76 = +HEAPF64[$75>>3];
     $77 = (((($71) + (($$046*40)|0)|0)) + 8|0);
     HEAPF64[$77>>3] = $76;
     $78 = ((($$sroa$038$144)) + 16|0);
     $79 = +HEAPF64[$78>>3];
     $80 = (((($71) + (($$046*40)|0)|0)) + 16|0);
     HEAPF64[$80>>3] = $79;
     $81 = ((($$sroa$038$144)) + 24|0);
     $82 = +HEAPF64[$81>>3];
     $83 = (((($71) + (($$046*40)|0)|0)) + 24|0);
     HEAPF64[$83>>3] = $82;
     $84 = $74 >= 0.0;
     $85 = $84&1;
     $86 = $76 >= 0.0;
     $87 = $86 ? 2 : 0;
     $88 = $87 | $85;
     $89 = $79 >= 0.0;
     $90 = $89 ? 4 : 0;
     $91 = $88 | $90;
     $92 = (((($71) + (($$046*40)|0)|0)) + 32|0);
     HEAP32[$92>>2] = $91;
     $93 = $91 ^ 7;
     $94 = (((($71) + (($$046*40)|0)|0)) + 36|0);
     HEAP32[$94>>2] = $93;
     $$pre61 = (($71) + (($$046*40)|0)|0);
     $$pre$phi62Z2D = $77;$$pre$phi63Z2D = $80;$$pre$phi64Z2D = $83;$$pre$phi66Z2D = $92;$$pre$phi68Z2D = $94;$$pre$phiZ2D = $$pre61;$101 = $76;$105 = $79;$109 = $82;$98 = $74;
    }
    $95 = (($$046) + 1)|0;
    $96 = +HEAPF64[$2>>3];
    $97 = $98 * $96;
    $99 = +HEAPF64[$54>>3];
    $100 = $101 * $99;
    $102 = $97 + $100;
    $103 = +HEAPF64[$55>>3];
    $104 = $105 * $103;
    $106 = $102 + $104;
    $107 = +HEAPF64[$56>>3];
    $108 = $109 * $107;
    $110 = $106 + $108;
    $111 = +HEAPF64[$57>>3];
    $112 = $98 * $111;
    $113 = +HEAPF64[$58>>3];
    $114 = $101 * $113;
    $115 = $112 + $114;
    $116 = +HEAPF64[$59>>3];
    $117 = $105 * $116;
    $118 = $115 + $117;
    $119 = +HEAPF64[$60>>3];
    $120 = $109 * $119;
    $121 = $118 + $120;
    $122 = +HEAPF64[$61>>3];
    $123 = $98 * $122;
    $124 = +HEAPF64[$62>>3];
    $125 = $101 * $124;
    $126 = $123 + $125;
    $127 = +HEAPF64[$63>>3];
    $128 = $105 * $127;
    $129 = $126 + $128;
    $130 = +HEAPF64[$64>>3];
    $131 = $109 * $130;
    $132 = $129 + $131;
    $133 = +HEAPF64[$65>>3];
    $134 = $98 * $133;
    $135 = +HEAPF64[$66>>3];
    $136 = $101 * $135;
    $137 = $134 + $136;
    $138 = +HEAPF64[$67>>3];
    $139 = $105 * $138;
    $140 = $137 + $139;
    $141 = +HEAPF64[$68>>3];
    $142 = $109 * $141;
    $143 = $140 + $142;
    $144 = $110 >= 0.0;
    $145 = $144&1;
    $146 = $121 >= 0.0;
    $147 = $146 ? 2 : 0;
    $148 = $147 | $145;
    $149 = $132 >= 0.0;
    $150 = $149 ? 4 : 0;
    $151 = $148 | $150;
    HEAP32[$$pre$phi66Z2D>>2] = $151;
    $152 = $151 ^ 7;
    HEAP32[$$pre$phi68Z2D>>2] = $152;
    $153 = $110 * $110;
    $154 = $121 * $121;
    $155 = $153 + $154;
    $156 = $132 * $132;
    $157 = $155 + $156;
    $158 = (+Math_sqrt((+$157)));
    $159 = 1.0 / $158;
    $160 = $110 * $159;
    HEAPF64[$$pre$phiZ2D>>3] = $160;
    $161 = $121 * $159;
    HEAPF64[$$pre$phi62Z2D>>3] = $161;
    $162 = $132 * $159;
    HEAPF64[$$pre$phi63Z2D>>3] = $162;
    $163 = $143 * $159;
    HEAPF64[$$pre$phi64Z2D>>3] = $163;
    $164 = $165 << 1;
    $166 = $164 | 1;
    HEAP32[$50>>2] = $166;
    $$1 = $95;$171 = $166;
   }
   $167 = $$12945 << 1;
   $168 = ((($$sroa$038$144)) + 40|0);
   $169 = ($168|0)==($51|0);
   if ($169) {
    $170 = $171;
    break;
   } else {
    $$046 = $$1;$$12945 = $167;$$sroa$038$144 = $168;$165 = $171;
   }
  }
 }
 HEAP32[$0>>2] = $170;
 return;
}
function __ZN7osgUtil11CullVisitor21MatrixPlanesDrawables3setERKN3osg7MatrixdEPKNS2_8DrawableERKNS2_8PolytopeE($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$017 = 0, $$sroa$012$016 = 0, $10 = 0.0, $100 = 0, $11 = 0, $12 = 0, $13 = 0.0, $14 = 0, $15 = 0, $16 = 0.0, $17 = 0, $18 = 0, $19 = 0.0, $20 = 0, $21 = 0, $22 = 0.0, $23 = 0, $24 = 0, $25 = 0.0, $26 = 0;
 var $27 = 0, $28 = 0.0, $29 = 0, $30 = 0, $31 = 0.0, $32 = 0, $33 = 0, $34 = 0.0, $35 = 0, $36 = 0, $37 = 0.0, $38 = 0, $39 = 0, $4 = 0, $40 = 0.0, $41 = 0, $42 = 0, $43 = 0.0, $44 = 0, $45 = 0;
 var $46 = 0.0, $47 = 0, $48 = 0, $49 = 0.0, $5 = 0.0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0.0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0.0, $76 = 0, $77 = 0.0, $78 = 0, $79 = 0, $8 = 0, $80 = 0.0, $81 = 0;
 var $82 = 0, $83 = 0.0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $scevgep$i$i$i = 0;
 var $scevgep5$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ($0|0)==($1|0);
 if (!($4)) {
  $5 = +HEAPF64[$1>>3];
  HEAPF64[$0>>3] = $5;
  $6 = ((($1)) + 8|0);
  $7 = +HEAPF64[$6>>3];
  $8 = ((($0)) + 8|0);
  HEAPF64[$8>>3] = $7;
  $9 = ((($1)) + 16|0);
  $10 = +HEAPF64[$9>>3];
  $11 = ((($0)) + 16|0);
  HEAPF64[$11>>3] = $10;
  $12 = ((($1)) + 24|0);
  $13 = +HEAPF64[$12>>3];
  $14 = ((($0)) + 24|0);
  HEAPF64[$14>>3] = $13;
  $15 = ((($1)) + 32|0);
  $16 = +HEAPF64[$15>>3];
  $17 = ((($0)) + 32|0);
  HEAPF64[$17>>3] = $16;
  $18 = ((($1)) + 40|0);
  $19 = +HEAPF64[$18>>3];
  $20 = ((($0)) + 40|0);
  HEAPF64[$20>>3] = $19;
  $21 = ((($1)) + 48|0);
  $22 = +HEAPF64[$21>>3];
  $23 = ((($0)) + 48|0);
  HEAPF64[$23>>3] = $22;
  $24 = ((($1)) + 56|0);
  $25 = +HEAPF64[$24>>3];
  $26 = ((($0)) + 56|0);
  HEAPF64[$26>>3] = $25;
  $27 = ((($1)) + 64|0);
  $28 = +HEAPF64[$27>>3];
  $29 = ((($0)) + 64|0);
  HEAPF64[$29>>3] = $28;
  $30 = ((($1)) + 72|0);
  $31 = +HEAPF64[$30>>3];
  $32 = ((($0)) + 72|0);
  HEAPF64[$32>>3] = $31;
  $33 = ((($1)) + 80|0);
  $34 = +HEAPF64[$33>>3];
  $35 = ((($0)) + 80|0);
  HEAPF64[$35>>3] = $34;
  $36 = ((($1)) + 88|0);
  $37 = +HEAPF64[$36>>3];
  $38 = ((($0)) + 88|0);
  HEAPF64[$38>>3] = $37;
  $39 = ((($1)) + 96|0);
  $40 = +HEAPF64[$39>>3];
  $41 = ((($0)) + 96|0);
  HEAPF64[$41>>3] = $40;
  $42 = ((($1)) + 104|0);
  $43 = +HEAPF64[$42>>3];
  $44 = ((($0)) + 104|0);
  HEAPF64[$44>>3] = $43;
  $45 = ((($1)) + 112|0);
  $46 = +HEAPF64[$45>>3];
  $47 = ((($0)) + 112|0);
  HEAPF64[$47>>3] = $46;
  $48 = ((($1)) + 120|0);
  $49 = +HEAPF64[$48>>3];
  $50 = ((($0)) + 120|0);
  HEAPF64[$50>>3] = $49;
 }
 $51 = ((($0)) + 128|0);
 HEAP32[$51>>2] = $2;
 $52 = ((($0)) + 132|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = ((($0)) + 136|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = ($53|0)==($55|0);
 if (!($56)) {
  $scevgep$i$i$i = ((($55)) + -40|0);
  $57 = $scevgep$i$i$i;
  $58 = $53;
  $59 = (($57) - ($58))|0;
  $60 = (($59>>>0) / 40)&-1;
  $61 = $60 ^ -1;
  $scevgep5$i$i$i = (($55) + (($61*40)|0)|0);
  HEAP32[$54>>2] = $scevgep5$i$i$i;
 }
 $62 = ((($3)) + 20|0);
 $63 = HEAP32[$62>>2]|0;
 $64 = ((($3)) + 24|0);
 $65 = HEAP32[$64>>2]|0;
 $66 = ((($3)) + 28|0);
 $67 = HEAP32[$66>>2]|0;
 $68 = ($65|0)==($67|0);
 if ($68) {
  return;
 }
 $69 = ((($0)) + 140|0);
 $$017 = 1;$$sroa$012$016 = $65;
 while(1) {
  $70 = $$017 & $63;
  $71 = ($70|0)==(0);
  do {
   if (!($71)) {
    $72 = HEAP32[$54>>2]|0;
    $73 = HEAP32[$69>>2]|0;
    $74 = ($72|0)==($73|0);
    if ($74) {
     __ZNSt3__26vectorIN3osg5PlaneENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($52,$$sroa$012$016);
     break;
    } else {
     $75 = +HEAPF64[$$sroa$012$016>>3];
     HEAPF64[$72>>3] = $75;
     $76 = ((($$sroa$012$016)) + 8|0);
     $77 = +HEAPF64[$76>>3];
     $78 = ((($72)) + 8|0);
     HEAPF64[$78>>3] = $77;
     $79 = ((($$sroa$012$016)) + 16|0);
     $80 = +HEAPF64[$79>>3];
     $81 = ((($72)) + 16|0);
     HEAPF64[$81>>3] = $80;
     $82 = ((($$sroa$012$016)) + 24|0);
     $83 = +HEAPF64[$82>>3];
     $84 = ((($72)) + 24|0);
     HEAPF64[$84>>3] = $83;
     $85 = $75 >= 0.0;
     $86 = $85&1;
     $87 = $77 >= 0.0;
     $88 = $87 ? 2 : 0;
     $89 = $88 | $86;
     $90 = $80 >= 0.0;
     $91 = $90 ? 4 : 0;
     $92 = $89 | $91;
     $93 = ((($72)) + 32|0);
     HEAP32[$93>>2] = $92;
     $94 = $92 ^ 7;
     $95 = ((($72)) + 36|0);
     HEAP32[$95>>2] = $94;
     $96 = ((($72)) + 40|0);
     HEAP32[$54>>2] = $96;
     break;
    }
   }
  } while(0);
  $97 = $$017 << 1;
  $98 = ((($$sroa$012$016)) + 40|0);
  $99 = HEAP32[$66>>2]|0;
  $100 = ($98|0)==($99|0);
  if ($100) {
   break;
  } else {
   $$017 = $97;$$sroa$012$016 = $98;
  }
 }
 return;
}
function __ZNSt3__26__treeINS_12__value_typeIdN7osgUtil11CullVisitor21MatrixPlanesDrawablesEEENS_19__map_value_compareIdS5_NS_4lessIdEELb1EEENS_9allocatorIS5_EEE16__construct_nodeERKNS_4pairIKdS4_EE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0.0, $11 = 0, $12 = 0, $13 = 0.0, $14 = 0, $15 = 0, $16 = 0.0, $17 = 0, $18 = 0, $19 = 0.0, $20 = 0, $21 = 0, $22 = 0.0, $23 = 0, $24 = 0, $25 = 0.0, $26 = 0, $27 = 0, $28 = 0.0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0.0, $32 = 0, $33 = 0, $34 = 0.0, $35 = 0, $36 = 0, $37 = 0.0, $38 = 0, $39 = 0, $4 = 0, $40 = 0.0, $41 = 0, $42 = 0, $43 = 0.0, $44 = 0, $45 = 0, $46 = 0.0, $47 = 0;
 var $48 = 0, $49 = 0.0, $5 = 0.0, $50 = 0, $51 = 0, $52 = 0.0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0.0, $70 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (__Znwj(168)|0);
 $4 = ((($3)) + 16|0);
 $5 = +HEAPF64[$2>>3];
 HEAPF64[$4>>3] = $5;
 $6 = ((($2)) + 8|0);
 $7 = +HEAPF64[$6>>3];
 $8 = ((($3)) + 24|0);
 HEAPF64[$8>>3] = $7;
 $9 = ((($2)) + 16|0);
 $10 = +HEAPF64[$9>>3];
 $11 = ((($3)) + 32|0);
 HEAPF64[$11>>3] = $10;
 $12 = ((($2)) + 24|0);
 $13 = +HEAPF64[$12>>3];
 $14 = ((($3)) + 40|0);
 HEAPF64[$14>>3] = $13;
 $15 = ((($2)) + 32|0);
 $16 = +HEAPF64[$15>>3];
 $17 = ((($3)) + 48|0);
 HEAPF64[$17>>3] = $16;
 $18 = ((($2)) + 40|0);
 $19 = +HEAPF64[$18>>3];
 $20 = ((($3)) + 56|0);
 HEAPF64[$20>>3] = $19;
 $21 = ((($2)) + 48|0);
 $22 = +HEAPF64[$21>>3];
 $23 = ((($3)) + 64|0);
 HEAPF64[$23>>3] = $22;
 $24 = ((($2)) + 56|0);
 $25 = +HEAPF64[$24>>3];
 $26 = ((($3)) + 72|0);
 HEAPF64[$26>>3] = $25;
 $27 = ((($2)) + 64|0);
 $28 = +HEAPF64[$27>>3];
 $29 = ((($3)) + 80|0);
 HEAPF64[$29>>3] = $28;
 $30 = ((($2)) + 72|0);
 $31 = +HEAPF64[$30>>3];
 $32 = ((($3)) + 88|0);
 HEAPF64[$32>>3] = $31;
 $33 = ((($2)) + 80|0);
 $34 = +HEAPF64[$33>>3];
 $35 = ((($3)) + 96|0);
 HEAPF64[$35>>3] = $34;
 $36 = ((($2)) + 88|0);
 $37 = +HEAPF64[$36>>3];
 $38 = ((($3)) + 104|0);
 HEAPF64[$38>>3] = $37;
 $39 = ((($2)) + 96|0);
 $40 = +HEAPF64[$39>>3];
 $41 = ((($3)) + 112|0);
 HEAPF64[$41>>3] = $40;
 $42 = ((($2)) + 104|0);
 $43 = +HEAPF64[$42>>3];
 $44 = ((($3)) + 120|0);
 HEAPF64[$44>>3] = $43;
 $45 = ((($2)) + 112|0);
 $46 = +HEAPF64[$45>>3];
 $47 = ((($3)) + 128|0);
 HEAPF64[$47>>3] = $46;
 $48 = ((($2)) + 120|0);
 $49 = +HEAPF64[$48>>3];
 $50 = ((($3)) + 136|0);
 HEAPF64[$50>>3] = $49;
 $51 = ((($2)) + 128|0);
 $52 = +HEAPF64[$51>>3];
 $53 = ((($3)) + 144|0);
 HEAPF64[$53>>3] = $52;
 $54 = ((($3)) + 152|0);
 $55 = ((($2)) + 136|0);
 $56 = HEAP32[$55>>2]|0;
 HEAP32[$54>>2] = $56;
 $57 = ((($3)) + 156|0);
 $58 = ((($2)) + 140|0);
 __THREW__ = 0;
 invoke_vii(3598,($57|0),($58|0));
 $59 = __THREW__; __THREW__ = 0;
 $60 = $59&1;
 if ($60) {
  $69 = ___cxa_find_matching_catch_2()|0;
  $70 = tempRet0;
  __ZdlPv($3);
  ___resumeException($69|0);
  // unreachable;
 } else {
  $61 = $3;
  $62 = ((($1)) + 4|0);
  $63 = $62;
  HEAP32[$0>>2] = $61;
  $64 = ((($0)) + 4|0);
  $65 = $64;
  $66 = $65;
  HEAP32[$66>>2] = $63;
  $67 = (($65) + 4)|0;
  $68 = $67;
  HEAP32[$68>>2] = 1;
  return;
 }
}
function __ZNSt3__26vectorIN3osg5PlaneENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$06$i$i = 0, $$in = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0.0, $32 = 0, $33 = 0.0, $34 = 0, $35 = 0, $36 = 0.0, $37 = 0, $38 = 0, $39 = 0.0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0.0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0.0;
 var $61 = 0, $62 = 0, $63 = 0.0, $64 = 0, $65 = 0, $66 = 0.0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = (($5|0) / 40)&-1;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(107374182);
 $9 = $4;
 $10 = $3;
 if ($8) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $11 = ((($0)) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) - ($4))|0;
 $14 = (($13|0) / 40)&-1;
 $15 = ($14>>>0)<(53687091);
 $16 = $14 << 1;
 $17 = ($16>>>0)<($7>>>0);
 $$sroa$speculated$i = $17 ? $7 : $16;
 $$sroa$speculated$$i = $15 ? $$sroa$speculated$i : 107374182;
 $18 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($18) {
   $28 = 0;
  } else {
   $19 = ($$sroa$speculated$$i>>>0)>(107374182);
   if (!($19)) {
    $25 = ($$sroa$speculated$$i*40)|0;
    $26 = (__Znwj($25)|0);
    $28 = $26;
    break;
   }
   $20 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($20|0),(204840|0));
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if ($22) {
    $23 = ___cxa_find_matching_catch_2()|0;
    $24 = tempRet0;
    ___cxa_free_exception(($20|0));
    ___resumeException($23|0);
    // unreachable;
   } else {
    HEAP32[$20>>2] = (99824);
    ___cxa_throw(($20|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $27 = (($28) + (($6*40)|0)|0);
 $29 = (($28) + (($$sroa$speculated$$i*40)|0)|0);
 $30 = $29;
 $31 = +HEAPF64[$1>>3];
 HEAPF64[$27>>3] = $31;
 $32 = ((($1)) + 8|0);
 $33 = +HEAPF64[$32>>3];
 $34 = (((($28) + (($6*40)|0)|0)) + 8|0);
 HEAPF64[$34>>3] = $33;
 $35 = ((($1)) + 16|0);
 $36 = +HEAPF64[$35>>3];
 $37 = (((($28) + (($6*40)|0)|0)) + 16|0);
 HEAPF64[$37>>3] = $36;
 $38 = ((($1)) + 24|0);
 $39 = +HEAPF64[$38>>3];
 $40 = (((($28) + (($6*40)|0)|0)) + 24|0);
 HEAPF64[$40>>3] = $39;
 $41 = $31 >= 0.0;
 $42 = $41&1;
 $43 = $33 >= 0.0;
 $44 = $43 ? 2 : 0;
 $45 = $44 | $42;
 $46 = $36 >= 0.0;
 $47 = $46 ? 4 : 0;
 $48 = $45 | $47;
 $49 = (((($28) + (($6*40)|0)|0)) + 32|0);
 HEAP32[$49>>2] = $48;
 $50 = $48 ^ 7;
 $51 = (((($28) + (($6*40)|0)|0)) + 36|0);
 HEAP32[$51>>2] = $50;
 $52 = ((($27)) + 40|0);
 $53 = $52;
 $54 = ($10|0)==($9|0);
 if ($54) {
  $$in = $27;
 } else {
  $$06$i$i = $10;$58 = $27;
  while(1) {
   $55 = ((($$06$i$i)) + -40|0);
   $56 = +HEAPF64[$55>>3];
   $57 = ((($58)) + -40|0);
   HEAPF64[$57>>3] = $56;
   $59 = ((($$06$i$i)) + -32|0);
   $60 = +HEAPF64[$59>>3];
   $61 = ((($58)) + -32|0);
   HEAPF64[$61>>3] = $60;
   $62 = ((($$06$i$i)) + -24|0);
   $63 = +HEAPF64[$62>>3];
   $64 = ((($58)) + -24|0);
   HEAPF64[$64>>3] = $63;
   $65 = ((($$06$i$i)) + -16|0);
   $66 = +HEAPF64[$65>>3];
   $67 = ((($58)) + -16|0);
   HEAPF64[$67>>3] = $66;
   $68 = $56 >= 0.0;
   $69 = $68&1;
   $70 = $60 >= 0.0;
   $71 = $70 ? 2 : 0;
   $72 = $71 | $69;
   $73 = $63 >= 0.0;
   $74 = $73 ? 4 : 0;
   $75 = $72 | $74;
   $76 = ((($58)) + -8|0);
   HEAP32[$76>>2] = $75;
   $77 = $75 ^ 7;
   $78 = ((($58)) + -4|0);
   HEAP32[$78>>2] = $77;
   $79 = ((($58)) + -40|0);
   $80 = ($55|0)==($9|0);
   if ($80) {
    $$in = $79;
    break;
   } else {
    $$06$i$i = $55;$58 = $79;
   }
  }
 }
 $81 = $$in;
 HEAP32[$0>>2] = $81;
 HEAP32[$2>>2] = $53;
 HEAP32[$11>>2] = $30;
 $82 = ($4|0)==(0);
 if ($82) {
  return;
 }
 $83 = $4;
 __ZdlPv($83);
 return;
}
function __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE6assignIPS2_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS2_NS_15iterator_traitsIS9_E9referenceEEE5valueEvE4typeES9_S9_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$ = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $scevgep$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep5$i$i = 0, $scevgep5$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = $2;
 $4 = $1;
 $5 = (($3) - ($4))|0;
 $6 = (($5|0) / 12)&-1;
 $7 = ((($0)) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$0>>2]|0;
 $10 = (($8) - ($9))|0;
 $11 = (($10|0) / 12)&-1;
 $12 = ($6>>>0)>($11>>>0);
 $13 = $9;
 if (!($12)) {
  $14 = ((($0)) + 4|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (($15) - ($9))|0;
  $17 = (($16|0) / 12)&-1;
  $18 = ($6>>>0)>($17>>>0);
  $19 = (($1) + (($17*12)|0)|0);
  $$ = $18 ? $19 : $2;
  $20 = $$;
  $21 = (($20) - ($4))|0;
  $22 = (($21|0) / 12)&-1;
  $23 = ($21|0)==(0);
  if (!($23)) {
   $24 = $9;
   _memmove(($24|0),($1|0),($21|0))|0;
  }
  $25 = (($13) + (($22*12)|0)|0);
  if ($18) {
   $26 = (($3) - ($20))|0;
   $27 = ($26|0)>(0);
   if (!($27)) {
    return;
   }
   $28 = (($26>>>0) / 12)&-1;
   $29 = HEAP32[$14>>2]|0;
   _memcpy(($29|0),($$|0),($26|0))|0;
   $30 = HEAP32[$14>>2]|0;
   $31 = (($30) + (($28*12)|0)|0);
   HEAP32[$14>>2] = $31;
   return;
  } else {
   $32 = HEAP32[$14>>2]|0;
   $33 = ($32|0)==($25|0);
   if ($33) {
    return;
   }
   $scevgep$i$i = ((($32)) + -12|0);
   $34 = $scevgep$i$i;
   $35 = $25;
   $36 = (($34) - ($35))|0;
   $37 = (($36>>>0) / 12)&-1;
   $38 = $37 ^ -1;
   $scevgep5$i$i = (($32) + (($38*12)|0)|0);
   HEAP32[$14>>2] = $scevgep5$i$i;
   return;
  }
 }
 $39 = ($9|0)==(0);
 $40 = $9;
 if ($39) {
  $50 = $8;
 } else {
  $41 = ((($0)) + 4|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = ($42|0)==($13|0);
  if (!($43)) {
   $scevgep$i$i$i$i = ((($42)) + -12|0);
   $44 = $scevgep$i$i$i$i;
   $45 = (($44) - ($9))|0;
   $46 = (($45>>>0) / 12)&-1;
   $47 = $46 ^ -1;
   $scevgep5$i$i$i$i = (($42) + (($47*12)|0)|0);
   HEAP32[$41>>2] = $scevgep5$i$i$i$i;
  }
  __ZdlPv($40);
  HEAP32[$7>>2] = 0;
  HEAP32[$41>>2] = 0;
  HEAP32[$0>>2] = 0;
  $50 = 0;
 }
 $48 = ($6>>>0)>(357913941);
 if ($48) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $49 = (($50|0) / 12)&-1;
 $51 = ($49>>>0)<(178956970);
 $52 = $49 << 1;
 $53 = ($52>>>0)<($6>>>0);
 $$sroa$speculated$i = $53 ? $6 : $52;
 $$sroa$speculated$$i = $51 ? $$sroa$speculated$i : 357913941;
 $54 = ($$sroa$speculated$$i>>>0)>(357913941);
 if ($54) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $55 = ($$sroa$speculated$$i*12)|0;
 $56 = (__Znwj($55)|0);
 $57 = ((($0)) + 4|0);
 HEAP32[$57>>2] = $56;
 HEAP32[$0>>2] = $56;
 $58 = (($56) + (($$sroa$speculated$$i*12)|0)|0);
 HEAP32[$7>>2] = $58;
 $59 = ($5|0)>(0);
 if (!($59)) {
  return;
 }
 $60 = (($5>>>0) / 12)&-1;
 _memcpy(($56|0),($1|0),($5|0))|0;
 $61 = (($56) + (($60*12)|0)|0);
 HEAP32[$57>>2] = $61;
 return;
}
function __ZNSt3__26vectorIN3osg5PlaneENS_9allocatorIS2_EEE8__appendEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i = 0, $$0$i16 = 0, $$06$i$i = 0, $$in = 0, $$pre$i14 = 0, $$sroa$15$0 = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0.0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0.0, $54 = 0, $55 = 0, $56 = 0.0, $57 = 0;
 var $58 = 0, $59 = 0.0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) - ($5))|0;
 $7 = (($6|0) / 40)&-1;
 $8 = ($7>>>0)<($1>>>0);
 if (!($8)) {
  $9 = $5;
  $$0$i = $1;$10 = $9;
  while(1) {
   dest=$10; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
   $11 = HEAP32[$4>>2]|0;
   $12 = ((($11)) + 40|0);
   HEAP32[$4>>2] = $12;
   $13 = (($$0$i) + -1)|0;
   $14 = ($13|0)==(0);
   if ($14) {
    break;
   } else {
    $$0$i = $13;$10 = $12;
   }
  }
  return;
 }
 $15 = HEAP32[$0>>2]|0;
 $16 = (($5) - ($15))|0;
 $17 = (($16|0) / 40)&-1;
 $18 = (($17) + ($1))|0;
 $19 = ($18>>>0)>(107374182);
 if ($19) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $20 = (($3) - ($15))|0;
 $21 = (($20|0) / 40)&-1;
 $22 = ($21>>>0)<(53687091);
 $23 = $21 << 1;
 $24 = ($23>>>0)<($18>>>0);
 $$sroa$speculated$i = $24 ? $18 : $23;
 $$sroa$speculated$$i = $22 ? $$sroa$speculated$i : 107374182;
 $25 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($25) {
   $35 = 0;
  } else {
   $26 = ($$sroa$speculated$$i>>>0)>(107374182);
   if (!($26)) {
    $32 = ($$sroa$speculated$$i*40)|0;
    $33 = (__Znwj($32)|0);
    $35 = $33;
    break;
   }
   $27 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($27|0),(204840|0));
   $28 = __THREW__; __THREW__ = 0;
   $29 = $28&1;
   if ($29) {
    $30 = ___cxa_find_matching_catch_2()|0;
    $31 = tempRet0;
    ___cxa_free_exception(($27|0));
    ___resumeException($30|0);
    // unreachable;
   } else {
    HEAP32[$27>>2] = (99824);
    ___cxa_throw(($27|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $34 = (($35) + (($17*40)|0)|0);
 $36 = $34;
 $37 = (($35) + (($$sroa$speculated$$i*40)|0)|0);
 $$0$i16 = $1;$$in = $34;$$sroa$15$0 = $36;
 while(1) {
  dest=$$in; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
  $38 = $$sroa$15$0;
  $39 = ((($38)) + 40|0);
  $40 = $39;
  $41 = (($$0$i16) + -1)|0;
  $42 = ($41|0)==(0);
  if ($42) {
   break;
  } else {
   $$0$i16 = $41;$$in = $39;$$sroa$15$0 = $40;
  }
 }
 $43 = $37;
 $44 = HEAP32[$0>>2]|0;
 $45 = HEAP32[$4>>2]|0;
 $46 = ($45|0)==($44|0);
 if ($46) {
  $47 = $44;
  $75 = $36;$76 = $47;
 } else {
  $$06$i$i = $45;$51 = $34;
  while(1) {
   $48 = ((($$06$i$i)) + -40|0);
   $49 = +HEAPF64[$48>>3];
   $50 = ((($51)) + -40|0);
   HEAPF64[$50>>3] = $49;
   $52 = ((($$06$i$i)) + -32|0);
   $53 = +HEAPF64[$52>>3];
   $54 = ((($51)) + -32|0);
   HEAPF64[$54>>3] = $53;
   $55 = ((($$06$i$i)) + -24|0);
   $56 = +HEAPF64[$55>>3];
   $57 = ((($51)) + -24|0);
   HEAPF64[$57>>3] = $56;
   $58 = ((($$06$i$i)) + -16|0);
   $59 = +HEAPF64[$58>>3];
   $60 = ((($51)) + -16|0);
   HEAPF64[$60>>3] = $59;
   $61 = $49 >= 0.0;
   $62 = $61&1;
   $63 = $53 >= 0.0;
   $64 = $63 ? 2 : 0;
   $65 = $64 | $62;
   $66 = $56 >= 0.0;
   $67 = $66 ? 4 : 0;
   $68 = $65 | $67;
   $69 = ((($51)) + -8|0);
   HEAP32[$69>>2] = $68;
   $70 = $68 ^ 7;
   $71 = ((($51)) + -4|0);
   HEAP32[$71>>2] = $70;
   $72 = ((($51)) + -40|0);
   $73 = ($48|0)==($44|0);
   if ($73) {
    break;
   } else {
    $$06$i$i = $48;$51 = $72;
   }
  }
  $$pre$i14 = HEAP32[$0>>2]|0;
  $74 = $72;
  $75 = $74;$76 = $$pre$i14;
 }
 HEAP32[$0>>2] = $75;
 HEAP32[$4>>2] = $40;
 HEAP32[$2>>2] = $43;
 $77 = ($76|0)==(0);
 if ($77) {
  return;
 }
 $78 = $76;
 __ZdlPv($78);
 return;
}
function __ZN3osg10CullingSet8isCulledERKNS_15BoundingBoxImplINS_5Vec3fEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$01527$i = 0, $$1 = 0, $$sink$i$i$i = 0, $$sink$i3$i$i = 0, $$sink1$i$i$i = 0, $$sink1$i4$i$i = 0, $$sink2$i$i$i = 0, $$sink2$i5$i$i = 0, $$sink26$i = 0, $$sroa$06$012 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0.0, $24 = 0, $25 = 0, $26 = 0, $27 = 0.0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0.0, $32 = 0.0, $33 = 0.0, $34 = 0.0, $35 = 0, $36 = 0.0, $37 = 0.0;
 var $38 = 0.0, $39 = 0.0, $4 = 0, $40 = 0, $41 = 0.0, $42 = 0.0, $43 = 0.0, $44 = 0.0, $45 = 0, $46 = 0.0, $47 = 0.0, $48 = 0.0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0.0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0.0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0.0, $63 = 0.0, $64 = 0.0, $65 = 0.0, $66 = 0.0, $67 = 0.0, $68 = 0.0, $69 = 0.0, $7 = 0, $70 = 0.0, $71 = 0.0, $72 = 0.0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 & 7;
 $5 = ($4|0)==(0);
 L1: do {
  if (!($5)) {
   $6 = ((($0)) + 16|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($7|0)==(0);
   if (!($8)) {
    $9 = ((($0)) + 36|0);
    HEAP32[$9>>2] = $7;
    $10 = ((($0)) + 40|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ((($0)) + 44|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = ($11|0)==($13|0);
    if (!($14)) {
     $15 = ((($1)) + 12|0);
     $$01527$i = 1;$$sink26$i = $11;$17 = $7;
     L5: while(1) {
      $16 = $$01527$i & $17;
      $18 = ($16|0)==(0);
      do {
       if ($18) {
        $89 = $17;
       } else {
        $19 = ((($$sink26$i)) + 36|0);
        $20 = HEAP32[$19>>2]|0;
        $21 = $20 & 1;
        $22 = ($21|0)!=(0);
        $$sink$i$i$i = $22 ? $15 : $1;
        $23 = +HEAPF32[$$sink$i$i$i>>2];
        $24 = $20 & 2;
        $25 = ($24|0)!=(0);
        $$sink1$i$i$i = $25 ? $15 : $1;
        $26 = ((($$sink1$i$i$i)) + 4|0);
        $27 = +HEAPF32[$26>>2];
        $28 = $20 & 4;
        $29 = ($28|0)!=(0);
        $$sink2$i$i$i = $29 ? $15 : $1;
        $30 = ((($$sink2$i$i$i)) + 8|0);
        $31 = +HEAPF32[$30>>2];
        $32 = +HEAPF64[$$sink26$i>>3];
        $33 = $23;
        $34 = $33 * $32;
        $35 = ((($$sink26$i)) + 8|0);
        $36 = +HEAPF64[$35>>3];
        $37 = $27;
        $38 = $37 * $36;
        $39 = $34 + $38;
        $40 = ((($$sink26$i)) + 16|0);
        $41 = +HEAPF64[$40>>3];
        $42 = $31;
        $43 = $42 * $41;
        $44 = $39 + $43;
        $45 = ((($$sink26$i)) + 24|0);
        $46 = +HEAPF64[$45>>3];
        $47 = $46 + $44;
        $48 = $47;
        $49 = $48 > 0.0;
        if ($49) {
         $74 = $$01527$i ^ $17;
         HEAP32[$9>>2] = $74;
         $89 = $74;
         break;
        } else {
         $50 = ((($$sink26$i)) + 32|0);
         $51 = HEAP32[$50>>2]|0;
         $52 = $51 & 1;
         $53 = ($52|0)!=(0);
         $$sink$i3$i$i = $53 ? $15 : $1;
         $54 = +HEAPF32[$$sink$i3$i$i>>2];
         $55 = $51 & 2;
         $56 = ($55|0)!=(0);
         $$sink1$i4$i$i = $56 ? $15 : $1;
         $57 = ((($$sink1$i4$i$i)) + 4|0);
         $58 = +HEAPF32[$57>>2];
         $59 = $51 & 4;
         $60 = ($59|0)!=(0);
         $$sink2$i5$i$i = $60 ? $15 : $1;
         $61 = ((($$sink2$i5$i$i)) + 8|0);
         $62 = +HEAPF32[$61>>2];
         $63 = $54;
         $64 = $32 * $63;
         $65 = $58;
         $66 = $36 * $65;
         $67 = $64 + $66;
         $68 = $62;
         $69 = $41 * $68;
         $70 = $67 + $69;
         $71 = $46 + $70;
         $72 = $71;
         $73 = $72 < 0.0;
         if ($73) {
          $$1 = 1;
          break L5;
         } else {
          $89 = $17;
          break;
         }
        }
       }
      } while(0);
      $75 = $$01527$i << 1;
      $76 = ((($$sink26$i)) + 40|0);
      $77 = ($76|0)==($13|0);
      if ($77) {
       break L1;
      } else {
       $$01527$i = $75;$$sink26$i = $76;$17 = $89;
      }
     }
     return ($$1|0);
    }
   }
  }
 } while(0);
 $78 = $3 & 16;
 $79 = ($78|0)==(0);
 if ($79) {
  $$1 = 0;
  return ($$1|0);
 }
 $80 = ((($0)) + 76|0);
 $81 = HEAP32[$80>>2]|0;
 $82 = ((($0)) + 80|0);
 $83 = HEAP32[$82>>2]|0;
 $84 = ($81|0)==($83|0);
 if ($84) {
  $$1 = 0;
  return ($$1|0);
 } else {
  $$sroa$06$012 = $81;
 }
 while(1) {
  $88 = (__ZN3osg20ShadowVolumeOccluder8containsERKNS_15BoundingBoxImplINS_5Vec3fEEE($$sroa$06$012,$1)|0);
  $86 = ((($$sroa$06$012)) + 80|0);
  if ($88) {
   $$1 = 1;
   label = 14;
   break;
  }
  $85 = HEAP32[$82>>2]|0;
  $87 = ($86|0)==($85|0);
  if ($87) {
   $$1 = 0;
   label = 14;
   break;
  } else {
   $$sroa$06$012 = $86;
  }
 }
 if ((label|0) == 14) {
  return ($$1|0);
 }
 return (0)|0;
}
function __ZN7osgUtil11CullVisitorC1Ev($0) {
 $0 = $0|0;
 var $$0 = 0, $$02 = 0, $$6 = 0, $$68 = 0, $$7 = 0, $$79 = 0, $$pre$i = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $scevgep$i$i$i = 0, $scevgep5$i$i$i = 0, dest = 0;
 var label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 508|0);
 __ZN3osg10ReferencedC2Ev($1);
 HEAP32[$1>>2] = (63412);
 $2 = ((($0)) + 520|0);
 ;HEAP32[$2>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;
 $3 = ((($0)) + 532|0);
 HEAP32[$3>>2] = 2;
 $4 = ((($0)) + 536|0);
 HEAP32[$4>>2] = 0;
 __THREW__ = 0;
 invoke_viiii(3522,($0|0),((51912)|0),4,3);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $43 = ___cxa_find_matching_catch_2()|0;
  $44 = tempRet0;
  $$7 = $44;$$79 = $43;
 } else {
  $7 = ((($0)) + 56|0);
  __THREW__ = 0;
  invoke_vi(3645,($7|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if ($9) {
   $45 = ___cxa_find_matching_catch_2()|0;
   $46 = tempRet0;
   $$6 = $46;$$68 = $45;
  } else {
   HEAP32[$0>>2] = (51380);
   HEAP32[$1>>2] = (51768);
   HEAP32[$7>>2] = (51604);
   $10 = ((($0)) + 372|0);
   $11 = ((($0)) + 380|0);
   $12 = ((($0)) + 388|0);
   $13 = ((($0)) + 392|0);
   $14 = ((($0)) + 408|0);
   ;HEAP32[$10>>2]=0|0;HEAP32[$10+4>>2]=0|0;HEAP32[$10+8>>2]=0|0;HEAP32[$10+12>>2]=0|0;HEAP32[$10+16>>2]=0|0;HEAP32[$10+20>>2]=0|0;HEAP32[$10+24>>2]=0|0;HEAP32[$10+28>>2]=0|0;
   HEAPF64[$14>>3] = 3.4028234663852886E+38;
   $15 = ((($0)) + 416|0);
   HEAPF64[$15>>3] = -3.4028234663852886E+38;
   $16 = ((($0)) + 424|0);
   $17 = ((($0)) + 428|0);
   $18 = ((($0)) + 444|0);
   $19 = ((($0)) + 480|0);
   $20 = ((($0)) + 484|0);
   HEAP32[$20>>2] = 0;
   $21 = ((($0)) + 488|0);
   HEAP32[$21>>2] = 0;
   $22 = ((($0)) + 484|0);
   dest=$16; stop=dest+56|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
   HEAP32[$19>>2] = $22;
   $23 = ((($0)) + 492|0);
   $24 = ((($0)) + 496|0);
   HEAP32[$24>>2] = 0;
   $25 = ((($0)) + 500|0);
   HEAP32[$25>>2] = 0;
   $26 = ((($0)) + 496|0);
   HEAP32[$23>>2] = $26;
   $27 = ((($0)) + 504|0);
   HEAP32[$27>>2] = 0;
   __THREW__ = 0;
   $28 = (invoke_ii(3276,12)|0);
   $29 = __THREW__; __THREW__ = 0;
   $30 = $29&1;
   do {
    if ($30) {
     label = 12;
    } else {
     __THREW__ = 0;
     invoke_vi(3282,($28|0));
     $31 = __THREW__; __THREW__ = 0;
     $32 = $31&1;
     if ($32) {
      $49 = ___cxa_find_matching_catch_2()|0;
      $50 = tempRet0;
      __ZdlPv($28);
      $$0 = $50;$$02 = $49;
      break;
     }
     HEAP32[$28>>2] = (41960);
     $33 = HEAP32[$27>>2]|0;
     $34 = ($33|0)==($28|0);
     if ($34) {
      return;
     }
     HEAP32[$27>>2] = $28;
     $35 = ((($28)) + 8|0);
     $36 = HEAP32[$35>>2]|0;HEAP32[$35>>2] = (($36+1)|0);
     $37 = ($33|0)==(0|0);
     if ($37) {
      return;
     }
     $38 = ((($33)) + 8|0);
     $39 = HEAP32[$38>>2]|0;HEAP32[$38>>2] = (($39-1)|0);
     $40 = ($39|0)==(1);
     if (!($40)) {
      return;
     }
     __THREW__ = 0;
     invoke_viii(3262,($33|0),1,1);
     $41 = __THREW__; __THREW__ = 0;
     $42 = $41&1;
     if ($42) {
      label = 12;
     } else {
      return;
     }
    }
   } while(0);
   if ((label|0) == 12) {
    $47 = ___cxa_find_matching_catch_2()|0;
    $48 = tempRet0;
    $$0 = $48;$$02 = $47;
   }
   $51 = HEAP32[$27>>2]|0;
   $52 = ($51|0)==(0|0);
   if (!($52)) {
    $53 = ((($51)) + 8|0);
    $54 = HEAP32[$53>>2]|0;HEAP32[$53>>2] = (($54-1)|0);
    $55 = ($54|0)==(1);
    if ($55) {
     __THREW__ = 0;
     invoke_viii(3262,($51|0),1,1);
     $56 = __THREW__; __THREW__ = 0;
     $57 = $56&1;
     if ($57) {
      $109 = ___cxa_find_matching_catch_3(0|0)|0;
      $110 = tempRet0;
      ___clang_call_terminate($109);
      // unreachable;
     }
    }
   }
   HEAP32[$27>>2] = 0;
   $58 = HEAP32[$26>>2]|0;
   __ZNSt3__26__treeINS_12__value_typeIdN7osgUtil11CullVisitor21MatrixPlanesDrawablesEEENS_19__map_value_compareIdS5_NS_4lessIdEELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($23,$58);
   $59 = HEAP32[$22>>2]|0;
   __ZNSt3__26__treeINS_12__value_typeIdN7osgUtil11CullVisitor21MatrixPlanesDrawablesEEENS_19__map_value_compareIdS5_NS_4lessIdEELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($19,$59);
   __THREW__ = 0;
   invoke_vi(3504,($18|0));
   $60 = __THREW__; __THREW__ = 0;
   $61 = $60&1;
   if ($61) {
    $109 = ___cxa_find_matching_catch_3(0|0)|0;
    $110 = tempRet0;
    ___clang_call_terminate($109);
    // unreachable;
   }
   $62 = HEAP32[$16>>2]|0;
   $63 = ($62|0)==(0|0);
   if (!($63)) {
    $64 = HEAP32[$17>>2]|0;
    $65 = ($64|0)==($62|0);
    do {
     if ($65) {
      $79 = $62;
     } else {
      $67 = $64;
      while(1) {
       $66 = ((($67)) + -4|0);
       HEAP32[$17>>2] = $66;
       $68 = HEAP32[$66>>2]|0;
       $69 = ($68|0)==(0|0);
       if (!($69)) {
        $70 = ((($68)) + 8|0);
        $71 = HEAP32[$70>>2]|0;HEAP32[$70>>2] = (($71-1)|0);
        $72 = ($71|0)==(1);
        if ($72) {
         __THREW__ = 0;
         invoke_viii(3262,($68|0),1,1);
         $73 = __THREW__; __THREW__ = 0;
         $74 = $73&1;
         if ($74) {
          label = 24;
          break;
         }
        }
       }
       HEAP32[$66>>2] = 0;
       $75 = HEAP32[$17>>2]|0;
       $76 = ($75|0)==($62|0);
       if ($76) {
        label = 25;
        break;
       } else {
        $67 = $75;
       }
      }
      if ((label|0) == 24) {
       $77 = ___cxa_find_matching_catch_2()|0;
       $78 = tempRet0;
       ___cxa_call_unexpected(($77|0));
       // unreachable;
      }
      else if ((label|0) == 25) {
       $$pre$i = HEAP32[$16>>2]|0;
       $79 = $$pre$i;
       break;
      }
     }
    } while(0);
    __ZdlPv($79);
   }
   $80 = HEAP32[$12>>2]|0;
   $81 = ($80|0)==(0|0);
   if (!($81)) {
    $82 = HEAP32[$13>>2]|0;
    $83 = ($82|0)==($80|0);
    if (!($83)) {
     $scevgep$i$i$i = ((($82)) + -4|0);
     $84 = $scevgep$i$i$i;
     $85 = $80;
     $86 = (($84) - ($85))|0;
     $87 = $86 >>> 2;
     $88 = $87 ^ -1;
     $scevgep5$i$i$i = (($82) + ($88<<2)|0);
     HEAP32[$13>>2] = $scevgep5$i$i$i;
    }
    __ZdlPv($80);
   }
   $89 = HEAP32[$11>>2]|0;
   $90 = ($89|0)==(0|0);
   if (!($90)) {
    $91 = ((($89)) + 8|0);
    $92 = HEAP32[$91>>2]|0;HEAP32[$91>>2] = (($92-1)|0);
    $93 = ($92|0)==(1);
    if ($93) {
     __THREW__ = 0;
     invoke_viii(3262,($89|0),1,1);
     $94 = __THREW__; __THREW__ = 0;
     $95 = $94&1;
     if ($95) {
      $109 = ___cxa_find_matching_catch_3(0|0)|0;
      $110 = tempRet0;
      ___clang_call_terminate($109);
      // unreachable;
     }
    }
   }
   HEAP32[$11>>2] = 0;
   $96 = HEAP32[$10>>2]|0;
   $97 = ($96|0)==(0|0);
   if (!($97)) {
    $98 = ((($96)) + 8|0);
    $99 = HEAP32[$98>>2]|0;HEAP32[$98>>2] = (($99-1)|0);
    $100 = ($99|0)==(1);
    if ($100) {
     __THREW__ = 0;
     invoke_viii(3262,($96|0),1,1);
     $101 = __THREW__; __THREW__ = 0;
     $102 = $101&1;
     if ($102) {
      $109 = ___cxa_find_matching_catch_3(0|0)|0;
      $110 = tempRet0;
      ___clang_call_terminate($109);
      // unreachable;
     }
    }
   }
   HEAP32[$10>>2] = 0;
   __THREW__ = 0;
   invoke_vi(1621,($7|0));
   $103 = __THREW__; __THREW__ = 0;
   $104 = $103&1;
   if ($104) {
    $109 = ___cxa_find_matching_catch_3(0|0)|0;
    $110 = tempRet0;
    ___clang_call_terminate($109);
    // unreachable;
   } else {
    $$6 = $$0;$$68 = $$02;
   }
  }
  __THREW__ = 0;
  invoke_vii(3284,($0|0),((51912)|0));
  $105 = __THREW__; __THREW__ = 0;
  $106 = $105&1;
  if ($106) {
   $109 = ___cxa_find_matching_catch_3(0|0)|0;
   $110 = tempRet0;
   ___clang_call_terminate($109);
   // unreachable;
  } else {
   $$7 = $$6;$$79 = $$68;
  }
 }
 __THREW__ = 0;
 invoke_vi(388,($1|0));
 $107 = __THREW__; __THREW__ = 0;
 $108 = $107&1;
 if ($108) {
  $109 = ___cxa_find_matching_catch_3(0|0)|0;
  $110 = tempRet0;
  ___clang_call_terminate($109);
  // unreachable;
 } else {
  ___resumeException($$79|0);
  // unreachable;
 }
}
function __ZN7osgUtil11CullVisitor9prototypeEv() {
 var $$0 = 0, $$01 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[206000]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  return (208016|0);
 }
 $2 = (___cxa_guard_acquire(206000)|0);
 $3 = ($2|0)==(0);
 if ($3) {
  return (208016|0);
 }
 __THREW__ = 0;
 $4 = (invoke_ii(3276,544)|0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $15 = ___cxa_find_matching_catch_2()|0;
  $16 = tempRet0;
  $$0 = $16;$$01 = $15;
  ___resumeException($$01|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_vi(3646,($4|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $17 = ___cxa_find_matching_catch_2()|0;
  $18 = tempRet0;
  __ZdlPv($4);
  $$0 = $18;$$01 = $17;
  ___resumeException($$01|0);
  // unreachable;
 } else {
  HEAP32[52004] = $4;
  $9 = HEAP32[$4>>2]|0;
  $10 = ((($9)) + -12|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (($4) + ($11)|0);
  $13 = ((($12)) + 8|0);
  $14 = HEAP32[$13>>2]|0;HEAP32[$13>>2] = (($14+1)|0);
  (___cxa_atexit((3647|0),(208016|0),(___dso_handle|0))|0);
  return (208016|0);
 }
 return (0)|0;
}
function __ZN3osg7ref_ptrIN7osgUtil11CullVisitorEED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  HEAP32[$0>>2] = 0;
  return;
 }
 $3 = HEAP32[$1>>2]|0;
 $4 = ((($3)) + -12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($1) + ($5)|0);
 $7 = ((($6)) + 8|0);
 $8 = HEAP32[$7>>2]|0;HEAP32[$7>>2] = (($8-1)|0);
 $9 = ($8|0)==(1);
 if (!($9)) {
  HEAP32[$0>>2] = 0;
  return;
 }
 __ZNK3osg10Referenced24signalObserversAndDeleteEbb($6,1,1);
 HEAP32[$0>>2] = 0;
 return;
}
function __ZN7osgUtil11CullVisitor6createEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN7osgUtil11CullVisitor9prototypeEv()|0);
 $0 = HEAP32[52004]|0;
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  (__ZN7osgUtil11CullVisitor9prototypeEv()|0);
  $2 = HEAP32[52004]|0;
  $3 = HEAP32[$2>>2]|0;
  $4 = ((($3)) + 200|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (FUNCTION_TABLE_ii[$5 & 8191]($2)|0);
  $10 = $6;
  return ($10|0);
 }
 $7 = (__Znwj(544)|0);
 __THREW__ = 0;
 invoke_vi(3646,($7|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $11 = ___cxa_find_matching_catch_2()|0;
  $12 = tempRet0;
  __ZdlPv($7);
  ___resumeException($11|0);
  // unreachable;
 } else {
  $10 = $7;
  return ($10|0);
 }
 return (0)|0;
}
function __ZN3osg11MixinVectorIjED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i = 0, $scevgep5$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (52520);
 $1 = ((($0)) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  return;
 }
 $4 = ((($0)) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==($2|0);
 if (!($6)) {
  $scevgep$i$i$i = ((($5)) + -4|0);
  $7 = $scevgep$i$i$i;
  $8 = $2;
  $9 = (($7) - ($8))|0;
  $10 = $9 >>> 2;
  $11 = $10 ^ -1;
  $scevgep5$i$i$i = (($5) + ($11<<2)|0);
  HEAP32[$4>>2] = $scevgep5$i$i$i;
 }
 __ZdlPv($2);
 return;
}
function __ZN3osg11MixinVectorIjED0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i = 0, $scevgep5$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (52520);
 $1 = ((($0)) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  __ZdlPv($0);
  return;
 }
 $4 = ((($0)) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==($2|0);
 if (!($6)) {
  $scevgep$i$i$i$i = ((($5)) + -4|0);
  $7 = $scevgep$i$i$i$i;
  $8 = $2;
  $9 = (($7) - ($8))|0;
  $10 = $9 >>> 2;
  $11 = $10 ^ -1;
  $scevgep5$i$i$i$i = (($5) + ($11<<2)|0);
  HEAP32[$4>>2] = $scevgep5$i$i$i$i;
 }
 __ZdlPv($2);
 __ZdlPv($0);
 return;
}
function __ZN3osg12DrawElementsD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1265,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK3osg12PrimitiveSet12isSameKindAsEPKNS_6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,26360,0)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK3osg12PrimitiveSet11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175113|0);
}
function __ZNK3osg12PrimitiveSet9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (116291|0);
}
function __ZNK3osg12PrimitiveSet14getDataPointerEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZNK3osg12PrimitiveSet16getTotalDataSizeEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function __ZN3osg10BufferData7asArrayEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZNK3osg10BufferData7asArrayEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZN3osg12PrimitiveSet14asPrimitiveSetEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ($0|0);
}
function __ZNK3osg12PrimitiveSet14asPrimitiveSetEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ($0|0);
}
function __ZNK3osg12PrimitiveSet20supportsBufferObjectEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function __ZN3osg12DrawElements15getDrawElementsEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ($0|0);
}
function __ZNK3osg12DrawElements15getDrawElementsEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ($0|0);
}
function __ZNK3osg12PrimitiveSet12computeRangeEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN3osg21PrimitiveIndexFunctorD2Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZNSt3__26vectorIjNS_9allocatorIjEEE8__appendEjRKj($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$i = 0, $$0$i17 = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i = 0, $scevgep$i18 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) - ($6))|0;
 $8 = $7 >> 2;
 $9 = ($8>>>0)<($1>>>0);
 $10 = $6;
 if (!($9)) {
  $$0$i = $1;$12 = $10;
  while(1) {
   $11 = HEAP32[$2>>2]|0;
   HEAP32[$12>>2] = $11;
   $13 = ((($12)) + 4|0);
   $14 = (($$0$i) + -1)|0;
   $15 = ($14|0)==(0);
   if ($15) {
    break;
   } else {
    $$0$i = $14;$12 = $13;
   }
  }
  $scevgep$i = (($10) + ($1<<2)|0);
  HEAP32[$5>>2] = $scevgep$i;
  return;
 }
 $16 = HEAP32[$0>>2]|0;
 $17 = (($6) - ($16))|0;
 $18 = $17 >> 2;
 $19 = (($18) + ($1))|0;
 $20 = ($19>>>0)>(1073741823);
 if ($20) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $21 = (($4) - ($16))|0;
 $22 = $21 >> 2;
 $23 = ($22>>>0)<(536870911);
 $24 = $21 >> 1;
 $25 = ($24>>>0)<($19>>>0);
 $$sroa$speculated$i = $25 ? $19 : $24;
 $$sroa$speculated$$i = $23 ? $$sroa$speculated$i : 1073741823;
 $26 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($26) {
   $36 = 0;
  } else {
   $27 = ($$sroa$speculated$$i>>>0)>(1073741823);
   if (!($27)) {
    $33 = $$sroa$speculated$$i << 2;
    $34 = (__Znwj($33)|0);
    $36 = $34;
    break;
   }
   $28 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($28|0),(204840|0));
   $29 = __THREW__; __THREW__ = 0;
   $30 = $29&1;
   if ($30) {
    $31 = ___cxa_find_matching_catch_2()|0;
    $32 = tempRet0;
    ___cxa_free_exception(($28|0));
    ___resumeException($31|0);
    // unreachable;
   } else {
    HEAP32[$28>>2] = (99824);
    ___cxa_throw(($28|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $35 = (($36) + ($18<<2)|0);
 $37 = (($36) + ($$sroa$speculated$$i<<2)|0);
 $$0$i17 = $1;$39 = $35;
 while(1) {
  $38 = HEAP32[$2>>2]|0;
  HEAP32[$39>>2] = $38;
  $40 = ((($39)) + 4|0);
  $41 = (($$0$i17) + -1)|0;
  $42 = ($41|0)==(0);
  if ($42) {
   break;
  } else {
   $$0$i17 = $41;$39 = $40;
  }
 }
 $43 = $37;
 $scevgep$i18 = (($35) + ($1<<2)|0);
 $44 = $scevgep$i18;
 $45 = (0 - ($18))|0;
 $46 = (($35) + ($45<<2)|0);
 $47 = $46;
 $48 = ($17|0)>(0);
 if ($48) {
  $49 = $16;
  _memcpy(($46|0),($49|0),($17|0))|0;
 }
 HEAP32[$0>>2] = $47;
 HEAP32[$5>>2] = $44;
 HEAP32[$3>>2] = $43;
 $50 = ($16|0)==(0);
 if ($50) {
  return;
 }
 $51 = $16;
 __ZdlPv($51);
 return;
}
function __ZN3osg13TemplateArrayINS_5Vec3fELNS_5Array4TypeE28ELi3ELi5126EEC2Ej($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i$i = 0, $$sroa$5$0$$sroa_idx = 0, $$sroa$6$0$$sroa_idx = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg10ReferencedC2Eb($0,1);
 $2 = ((($0)) + 12|0);
 ;HEAP32[$2>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;
 $3 = ((($0)) + 24|0);
 HEAP32[$3>>2] = 2;
 $4 = ((($0)) + 28|0);
 ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;HEAP32[$4+12>>2]=0|0;HEAP32[$4+16>>2]=0|0;HEAP32[$4+20>>2]=0|0;
 HEAP32[$0>>2] = (54500);
 $5 = ((($0)) + 52|0);
 HEAP32[$5>>2] = 28;
 $6 = ((($0)) + 56|0);
 HEAP32[$6>>2] = 3;
 $7 = ((($0)) + 60|0);
 HEAP32[$7>>2] = 5126;
 $8 = ((($0)) + 64|0);
 HEAP32[$8>>2] = -1;
 $9 = ((($0)) + 68|0);
 HEAP8[$9>>0] = 0;
 $10 = ((($0)) + 69|0);
 HEAP8[$10>>0] = 0;
 $11 = ((($0)) + 72|0);
 HEAP32[$11>>2] = (38552);
 $12 = ((($0)) + 76|0);
 HEAP32[$12>>2] = 0;
 $13 = ((($0)) + 80|0);
 HEAP32[$13>>2] = 0;
 $14 = ((($0)) + 84|0);
 HEAP32[$14>>2] = 0;
 $15 = ($1|0)==(0);
 if ($15) {
  HEAP32[$0>>2] = (37800);
  HEAP32[$11>>2] = (38024);
  return;
 }
 $16 = ($1>>>0)>(357913941);
 if ($16) {
  __THREW__ = 0;
  invoke_vi(3307,($12|0));
  $17 = __THREW__; __THREW__ = 0;
 } else {
  $18 = ($1*12)|0;
  __THREW__ = 0;
  $19 = (invoke_ii(3276,($18|0))|0);
  $20 = __THREW__; __THREW__ = 0;
  $21 = $20&1;
  if (!($21)) {
   HEAP32[$13>>2] = $19;
   HEAP32[$12>>2] = $19;
   $22 = (($19) + (($1*12)|0)|0);
   $23 = ((($0)) + 84|0);
   HEAP32[$23>>2] = $22;
   $$0$i$i$i = $1;$24 = $19;
   while(1) {
    HEAPF32[$24>>2] = 0.0;
    $$sroa$5$0$$sroa_idx = ((($24)) + 4|0);
    HEAPF32[$$sroa$5$0$$sroa_idx>>2] = 0.0;
    $$sroa$6$0$$sroa_idx = ((($24)) + 8|0);
    HEAPF32[$$sroa$6$0$$sroa_idx>>2] = 0.0;
    $25 = HEAP32[$13>>2]|0;
    $26 = ((($25)) + 12|0);
    HEAP32[$13>>2] = $26;
    $27 = (($$0$i$i$i) + -1)|0;
    $28 = ($27|0)==(0);
    if ($28) {
     break;
    } else {
     $$0$i$i$i = $27;$24 = $26;
    }
   }
   HEAP32[$0>>2] = (37800);
   HEAP32[$11>>2] = (38024);
   return;
  }
 }
 $29 = ___cxa_find_matching_catch_2()|0;
 $30 = tempRet0;
 $31 = HEAP32[$12>>2]|0;
 $32 = ($31|0)==(0|0);
 if (!($32)) {
  $33 = HEAP32[$13>>2]|0;
  $34 = ($33|0)==($31|0);
  if (!($34)) {
   $scevgep$i$i$i$i$i = ((($33)) + -12|0);
   $35 = $scevgep$i$i$i$i$i;
   $36 = $31;
   $37 = (($35) - ($36))|0;
   $38 = (($37>>>0) / 12)&-1;
   $39 = $38 ^ -1;
   $scevgep5$i$i$i$i$i = (($33) + (($39*12)|0)|0);
   HEAP32[$13>>2] = $scevgep5$i$i$i$i$i;
  }
  __ZdlPv($31);
 }
 __THREW__ = 0;
 invoke_vi(1265,($0|0));
 $40 = __THREW__; __THREW__ = 0;
 $41 = $40&1;
 if ($41) {
  $42 = ___cxa_find_matching_catch_3(0|0)|0;
  $43 = tempRet0;
  ___clang_call_terminate($42);
  // unreachable;
 } else {
  ___resumeException($29|0);
  // unreachable;
 }
}
function __ZN3osg13TemplateArrayIdLNS_5Array4TypeE8ELi1ELi5130EED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i = 0, $scevgep5$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 72|0);
 HEAP32[$1>>2] = (52536);
 $2 = ((($0)) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  __ZN3osg10BufferDataD2Ev($0);
  return;
 }
 $5 = ((($0)) + 80|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==($3|0);
 if (!($7)) {
  $scevgep$i$i$i$i = ((($6)) + -8|0);
  $8 = $scevgep$i$i$i$i;
  $9 = $3;
  $10 = (($8) - ($9))|0;
  $11 = $10 >>> 3;
  $12 = $11 ^ -1;
  $scevgep5$i$i$i$i = (($6) + ($12<<3)|0);
  HEAP32[$5>>2] = $scevgep5$i$i$i$i;
 }
 __ZdlPv($3);
 __ZN3osg10BufferDataD2Ev($0);
 return;
}
function __ZN3osg13TemplateArrayIdLNS_5Array4TypeE8ELi1ELi5130EED0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 72|0);
 HEAP32[$1>>2] = (52536);
 $2 = ((($0)) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = ((($0)) + 80|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==($3|0);
  if (!($7)) {
   $scevgep$i$i$i$i$i = ((($6)) + -8|0);
   $8 = $scevgep$i$i$i$i$i;
   $9 = $3;
   $10 = (($8) - ($9))|0;
   $11 = $10 >>> 3;
   $12 = $11 ^ -1;
   $scevgep5$i$i$i$i$i = (($6) + ($12<<3)|0);
   HEAP32[$5>>2] = $scevgep5$i$i$i$i$i;
  }
  __ZdlPv($3);
 }
 __THREW__ = 0;
 invoke_vi(1265,($0|0));
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 if ($14) {
  $15 = ___cxa_find_matching_catch_2()|0;
  $16 = tempRet0;
  __ZdlPv($0);
  ___resumeException($15|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK3osg13TemplateArrayIdLNS_5Array4TypeE8ELi1ELi5130EE9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(88)|0);
 __THREW__ = 0;
 invoke_vii(3435,($1|0),1);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $17 = ___cxa_find_matching_catch_2()|0;
  $18 = tempRet0;
  __ZdlPv($1);
  ___resumeException($17|0);
  // unreachable;
 } else {
  $4 = ((($1)) + 12|0);
  ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;
  $5 = ((($1)) + 24|0);
  HEAP32[$5>>2] = 2;
  $6 = ((($1)) + 28|0);
  ;HEAP32[$6>>2]=0|0;HEAP32[$6+4>>2]=0|0;HEAP32[$6+8>>2]=0|0;HEAP32[$6+12>>2]=0|0;HEAP32[$6+16>>2]=0|0;HEAP32[$6+20>>2]=0|0;
  $7 = ((($1)) + 52|0);
  HEAP32[$7>>2] = 8;
  $8 = ((($1)) + 56|0);
  HEAP32[$8>>2] = 1;
  $9 = ((($1)) + 60|0);
  HEAP32[$9>>2] = 5130;
  $10 = ((($1)) + 64|0);
  HEAP32[$10>>2] = -1;
  $11 = ((($1)) + 68|0);
  HEAP8[$11>>0] = 0;
  $12 = ((($1)) + 69|0);
  HEAP8[$12>>0] = 0;
  $13 = ((($1)) + 72|0);
  $14 = ((($1)) + 76|0);
  HEAP32[$14>>2] = 0;
  $15 = ((($1)) + 80|0);
  HEAP32[$15>>2] = 0;
  $16 = ((($1)) + 84|0);
  HEAP32[$16>>2] = 0;
  HEAP32[$1>>2] = (52552);
  HEAP32[$13>>2] = (52776);
  return ($1|0);
 }
 return (0)|0;
}
function __ZNK3osg13TemplateArrayIdLNS_5Array4TypeE8ELi1ELi5130EE5cloneERKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(88)|0);
 __THREW__ = 0;
 invoke_viii(3648,($2|0),($0|0),($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch_2()|0;
  $6 = tempRet0;
  __ZdlPv($2);
  ___resumeException($5|0);
  // unreachable;
 } else {
  return ($2|0);
 }
 return (0)|0;
}
function __ZNK3osg13TemplateArrayIdLNS_5Array4TypeE8ELi1ELi5130EE14getDataPointerEv($0) {
 $0 = $0|0;
 var $$ = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 76|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 80|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2|0)==($4|0);
 $$ = $5 ? 0 : $2;
 return ($$|0);
}
function __ZNK3osg13TemplateArrayIdLNS_5Array4TypeE8ELi1ELi5130EE16getTotalDataSizeEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 76|0);
 $2 = ((($0)) + 80|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$1>>2]|0;
 $5 = (($3) - ($4))|0;
 return ($5|0);
}
function __ZN3osg13TemplateArrayIdLNS_5Array4TypeE8ELi1ELi5130EE6acceptERNS_12ArrayVisitorE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 40|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 8191]($1,$0);
 return;
}
function __ZNK3osg13TemplateArrayIdLNS_5Array4TypeE8ELi1ELi5130EE6acceptERNS_17ConstArrayVisitorE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 40|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 8191]($1,$0);
 return;
}
function __ZN3osg13TemplateArrayIdLNS_5Array4TypeE8ELi1ELi5130EE6acceptEjRNS_12ValueVisitorE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + 36|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($0)) + 76|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($1<<3)|0);
 FUNCTION_TABLE_vii[$5 & 8191]($2,$8);
 return;
}
function __ZNK3osg13TemplateArrayIdLNS_5Array4TypeE8ELi1ELi5130EE6acceptEjRNS_17ConstValueVisitorE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + 36|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($0)) + 76|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($1<<3)|0);
 FUNCTION_TABLE_vii[$5 & 8191]($2,$8);
 return;
}
function __ZNK3osg13TemplateArrayIdLNS_5Array4TypeE8ELi1ELi5130EE7compareEjj($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$ = 0, $$0 = 0, $10 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0.0, $8 = 0.0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 76|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + ($1<<3)|0);
 $6 = (($4) + ($2<<3)|0);
 $7 = +HEAPF64[$5>>3];
 $8 = +HEAPF64[$6>>3];
 $9 = $7 < $8;
 $10 = $8 < $7;
 $$ = $10&1;
 $$0 = $9 ? -1 : $$;
 return ($$0|0);
}
function __ZNK3osg13TemplateArrayIdLNS_5Array4TypeE8ELi1ELi5130EE14getElementSizeEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 8;
}
function __ZNK3osg13TemplateArrayIdLNS_5Array4TypeE8ELi1ELi5130EE14getDataPointerEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$ = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 80|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 $7 = (($3) + ($1<<3)|0);
 $$ = $6 ? 0 : $7;
 return ($$|0);
}
function __ZNK3osg13TemplateArrayIdLNS_5Array4TypeE8ELi1ELi5130EE14getNumElementsEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 76|0);
 $2 = ((($0)) + 80|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$1>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 3;
 return ($6|0);
}
function __ZN3osg13TemplateArrayIdLNS_5Array4TypeE8ELi1ELi5130EE12reserveArrayEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 76|0);
 __ZNSt3__26vectorIdNS_9allocatorIdEEE7reserveEj($2,$1);
 return;
}
function __ZN3osg13TemplateArrayIdLNS_5Array4TypeE8ELi1ELi5130EE11resizeArrayEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i = 0;
 var $scevgep5$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 HEAPF64[$2>>3] = 0.0;
 $3 = ((($0)) + 76|0);
 $4 = ((($0)) + 80|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$3>>2]|0;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 3;
 $9 = ($8>>>0)<($1>>>0);
 $10 = $6;
 $11 = $5;
 if ($9) {
  $12 = (($1) - ($8))|0;
  __ZNSt3__26vectorIdNS_9allocatorIdEEE8__appendEjRKd($3,$12,$2);
  STACKTOP = sp;return;
 }
 $13 = ($8>>>0)>($1>>>0);
 if (!($13)) {
  STACKTOP = sp;return;
 }
 $14 = (($10) + ($1<<3)|0);
 $15 = ($11|0)==($14|0);
 if ($15) {
  STACKTOP = sp;return;
 }
 $scevgep$i$i$i$i = ((($11)) + -8|0);
 $16 = $scevgep$i$i$i$i;
 $17 = $14;
 $18 = (($16) - ($17))|0;
 $19 = $18 >>> 3;
 $20 = $19 ^ -1;
 $scevgep5$i$i$i$i = (($11) + ($20<<3)|0);
 HEAP32[$4>>2] = $scevgep5$i$i$i$i;
 STACKTOP = sp;return;
}
function __ZN3osg13TemplateArrayIdLNS_5Array4TypeE8ELi1ELi5130EE4trimEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $scevgep$i$i$i$i = 0, $scevgep5$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 HEAP32[$1>>2] = (52536);
 $2 = ((($1)) + 4|0);
 $3 = ((($0)) + 76|0);
 __ZNSt3__26vectorIdNS_9allocatorIdEEEC2ERKS3_($2,$3);
 $4 = HEAP32[$2>>2]|0;
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$2>>2] = $5;
 HEAP32[$3>>2] = $4;
 $6 = ((($1)) + 8|0);
 $7 = ((($0)) + 80|0);
 $8 = HEAP32[$6>>2]|0;
 $9 = HEAP32[$7>>2]|0;
 HEAP32[$6>>2] = $9;
 HEAP32[$7>>2] = $8;
 $10 = ((($1)) + 12|0);
 $11 = ((($0)) + 84|0);
 $12 = HEAP32[$10>>2]|0;
 $13 = HEAP32[$11>>2]|0;
 HEAP32[$10>>2] = $13;
 HEAP32[$11>>2] = $12;
 HEAP32[$1>>2] = (52536);
 $14 = ($5|0)==(0);
 $15 = $5;
 $16 = $9;
 if ($14) {
  STACKTOP = sp;return;
 }
 $17 = $5;
 $18 = ($16|0)==($17|0);
 if (!($18)) {
  $scevgep$i$i$i$i = ((($16)) + -8|0);
  $19 = $scevgep$i$i$i$i;
  $20 = (($19) - ($5))|0;
  $21 = $20 >>> 3;
  $22 = $21 ^ -1;
  $scevgep5$i$i$i$i = (($16) + ($22<<3)|0);
  HEAP32[$6>>2] = $scevgep5$i$i$i$i;
 }
 __ZdlPv($15);
 STACKTOP = sp;return;
}
function __ZThn72_N3osg13TemplateArrayIdLNS_5Array4TypeE8ELi1ELi5130EED1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -72|0);
 $2 = ((($1)) + 72|0);
 HEAP32[$2>>2] = (52536);
 $3 = ((($1)) + 76|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  __ZN3osg10BufferDataD2Ev($1);
  return;
 }
 $6 = ((($1)) + 80|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==($4|0);
 if (!($8)) {
  $scevgep$i$i$i$i$i = ((($7)) + -8|0);
  $9 = $scevgep$i$i$i$i$i;
  $10 = $4;
  $11 = (($9) - ($10))|0;
  $12 = $11 >>> 3;
  $13 = $12 ^ -1;
  $scevgep5$i$i$i$i$i = (($7) + ($13<<3)|0);
  HEAP32[$6>>2] = $scevgep5$i$i$i$i$i;
 }
 __ZdlPv($4);
 __ZN3osg10BufferDataD2Ev($1);
 return;
}
function __ZThn72_N3osg13TemplateArrayIdLNS_5Array4TypeE8ELi1ELi5130EED0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -72|0);
 $2 = ((($1)) + 72|0);
 HEAP32[$2>>2] = (52536);
 $3 = ((($1)) + 76|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if (!($5)) {
  $6 = ((($1)) + 80|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)==($4|0);
  if (!($8)) {
   $scevgep$i$i$i$i$i$i = ((($7)) + -8|0);
   $9 = $scevgep$i$i$i$i$i$i;
   $10 = $4;
   $11 = (($9) - ($10))|0;
   $12 = $11 >>> 3;
   $13 = $12 ^ -1;
   $scevgep5$i$i$i$i$i$i = (($7) + ($13<<3)|0);
   HEAP32[$6>>2] = $scevgep5$i$i$i$i$i$i;
  }
  __ZdlPv($4);
 }
 __THREW__ = 0;
 invoke_vi(1265,($1|0));
 $14 = __THREW__; __THREW__ = 0;
 $15 = $14&1;
 if ($15) {
  $16 = ___cxa_find_matching_catch_2()|0;
  $17 = tempRet0;
  __ZdlPv($1);
  ___resumeException($16|0);
  // unreachable;
 } else {
  __ZdlPv($1);
  return;
 }
}
function __ZNSt3__26vectorIdNS_9allocatorIdEEE8__appendEjRKd($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$i = 0, $$0$i17 = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0.0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0.0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i = 0, $scevgep$i18 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) - ($6))|0;
 $8 = $7 >> 3;
 $9 = ($8>>>0)<($1>>>0);
 $10 = $6;
 if (!($9)) {
  $$0$i = $1;$12 = $10;
  while(1) {
   $11 = +HEAPF64[$2>>3];
   HEAPF64[$12>>3] = $11;
   $13 = ((($12)) + 8|0);
   $14 = (($$0$i) + -1)|0;
   $15 = ($14|0)==(0);
   if ($15) {
    break;
   } else {
    $$0$i = $14;$12 = $13;
   }
  }
  $scevgep$i = (($10) + ($1<<3)|0);
  HEAP32[$5>>2] = $scevgep$i;
  return;
 }
 $16 = HEAP32[$0>>2]|0;
 $17 = (($6) - ($16))|0;
 $18 = $17 >> 3;
 $19 = (($18) + ($1))|0;
 $20 = ($19>>>0)>(536870911);
 if ($20) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $21 = (($4) - ($16))|0;
 $22 = $21 >> 3;
 $23 = ($22>>>0)<(268435455);
 $24 = $21 >> 2;
 $25 = ($24>>>0)<($19>>>0);
 $$sroa$speculated$i = $25 ? $19 : $24;
 $$sroa$speculated$$i = $23 ? $$sroa$speculated$i : 536870911;
 $26 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($26) {
   $36 = 0;
  } else {
   $27 = ($$sroa$speculated$$i>>>0)>(536870911);
   if (!($27)) {
    $33 = $$sroa$speculated$$i << 3;
    $34 = (__Znwj($33)|0);
    $36 = $34;
    break;
   }
   $28 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($28|0),(204840|0));
   $29 = __THREW__; __THREW__ = 0;
   $30 = $29&1;
   if ($30) {
    $31 = ___cxa_find_matching_catch_2()|0;
    $32 = tempRet0;
    ___cxa_free_exception(($28|0));
    ___resumeException($31|0);
    // unreachable;
   } else {
    HEAP32[$28>>2] = (99824);
    ___cxa_throw(($28|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $35 = (($36) + ($18<<3)|0);
 $37 = (($36) + ($$sroa$speculated$$i<<3)|0);
 $$0$i17 = $1;$39 = $35;
 while(1) {
  $38 = +HEAPF64[$2>>3];
  HEAPF64[$39>>3] = $38;
  $40 = ((($39)) + 8|0);
  $41 = (($$0$i17) + -1)|0;
  $42 = ($41|0)==(0);
  if ($42) {
   break;
  } else {
   $$0$i17 = $41;$39 = $40;
  }
 }
 $43 = $37;
 $scevgep$i18 = (($35) + ($1<<3)|0);
 $44 = $scevgep$i18;
 $45 = (0 - ($18))|0;
 $46 = (($35) + ($45<<3)|0);
 $47 = $46;
 $48 = ($17|0)>(0);
 if ($48) {
  $49 = $16;
  _memcpy(($46|0),($49|0),($17|0))|0;
 }
 HEAP32[$0>>2] = $47;
 HEAP32[$5>>2] = $44;
 HEAP32[$3>>2] = $43;
 $50 = ($16|0)==(0);
 if ($50) {
  return;
 }
 $51 = $16;
 __ZdlPv($51);
 return;
}
function __ZNSt3__26vectorIdNS_9allocatorIdEEE7reserveEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 3;
 $7 = ($6>>>0)<($1>>>0);
 if (!($7)) {
  return;
 }
 $8 = ((($0)) + 4|0);
 $9 = ($1>>>0)>(536870911);
 if ($9) {
  $10 = (___cxa_allocate_exception(8)|0);
  __THREW__ = 0;
  invoke_vii(3366,($10|0),(204840|0));
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if ($12) {
   $13 = ___cxa_find_matching_catch_2()|0;
   $14 = tempRet0;
   ___cxa_free_exception(($10|0));
   ___resumeException($13|0);
   // unreachable;
  } else {
   HEAP32[$10>>2] = (99824);
   ___cxa_throw(($10|0),(34608|0),(3230|0));
   // unreachable;
  }
 }
 $15 = HEAP32[$8>>2]|0;
 $16 = (($15) - ($4))|0;
 $17 = $16 >> 3;
 $18 = $1 << 3;
 $19 = (__Znwj($18)|0);
 $20 = (($19) + ($17<<3)|0);
 $21 = $20;
 $22 = (($19) + ($1<<3)|0);
 $23 = $22;
 $24 = (0 - ($17))|0;
 $25 = (($20) + ($24<<3)|0);
 $26 = $25;
 $27 = ($16|0)>(0);
 if ($27) {
  $28 = $4;
  _memcpy(($25|0),($28|0),($16|0))|0;
 }
 HEAP32[$0>>2] = $26;
 HEAP32[$8>>2] = $21;
 HEAP32[$2>>2] = $23;
 $29 = ($4|0)==(0);
 if ($29) {
  return;
 }
 $30 = $4;
 __ZdlPv($30);
 return;
}
function __ZN3osg13TemplateArrayIdLNS_5Array4TypeE8ELi1ELi5130EEC2ERKS3_RKNS_6CopyOpE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg6ObjectC2ERKS0_RKNS_6CopyOpE($0,$1,$2);
 HEAP32[$0>>2] = (55116);
 $3 = ((($0)) + 32|0);
 HEAP32[$3>>2] = 0;
 $4 = ((($0)) + 36|0);
 HEAP32[$4>>2] = 0;
 $5 = ((($0)) + 40|0);
 HEAP32[$5>>2] = 0;
 $6 = ((($0)) + 44|0);
 $7 = ((($1)) + 44|0);
 $8 = HEAP32[$7>>2]|0;
 HEAP32[$6>>2] = $8;
 $9 = ($8|0)==(0|0);
 if (!($9)) {
  $10 = HEAP32[$8>>2]|0;
  $11 = ((($10)) + -12|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($8) + ($12)|0);
  $14 = ((($13)) + 8|0);
  $15 = HEAP32[$14>>2]|0;HEAP32[$14>>2] = (($15+1)|0);
 }
 $16 = ((($0)) + 48|0);
 HEAP32[$16>>2] = 0;
 HEAP32[$0>>2] = (54500);
 $17 = ((($0)) + 52|0);
 $18 = ((($1)) + 52|0);
 $19 = HEAP32[$18>>2]|0;
 HEAP32[$17>>2] = $19;
 $20 = ((($0)) + 56|0);
 $21 = ((($1)) + 56|0);
 $22 = HEAP32[$21>>2]|0;
 HEAP32[$20>>2] = $22;
 $23 = ((($0)) + 60|0);
 $24 = ((($1)) + 60|0);
 $25 = HEAP32[$24>>2]|0;
 HEAP32[$23>>2] = $25;
 $26 = ((($0)) + 64|0);
 $27 = ((($1)) + 64|0);
 $28 = HEAP32[$27>>2]|0;
 HEAP32[$26>>2] = $28;
 $29 = ((($0)) + 68|0);
 $30 = ((($1)) + 68|0);
 $31 = HEAP8[$30>>0]|0;
 HEAP8[$29>>0] = $31;
 $32 = ((($0)) + 69|0);
 $33 = ((($1)) + 69|0);
 $34 = HEAP8[$33>>0]|0;
 HEAP8[$32>>0] = $34;
 $35 = ((($0)) + 72|0);
 HEAP32[$35>>2] = (52536);
 $36 = ((($0)) + 76|0);
 $37 = ((($1)) + 76|0);
 __THREW__ = 0;
 invoke_vii(3318,($36|0),($37|0));
 $38 = __THREW__; __THREW__ = 0;
 $39 = $38&1;
 if (!($39)) {
  HEAP32[$0>>2] = (52552);
  HEAP32[$35>>2] = (52776);
  return;
 }
 $40 = ___cxa_find_matching_catch_2()|0;
 $41 = tempRet0;
 __THREW__ = 0;
 invoke_vi(1265,($0|0));
 $42 = __THREW__; __THREW__ = 0;
 $43 = $42&1;
 if ($43) {
  $44 = ___cxa_find_matching_catch_3(0|0)|0;
  $45 = tempRet0;
  ___clang_call_terminate($44);
  // unreachable;
 } else {
  ___resumeException($40|0);
  // unreachable;
 }
}
function __ZN3osg11MixinVectorIdED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i = 0, $scevgep5$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (52536);
 $1 = ((($0)) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  return;
 }
 $4 = ((($0)) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==($2|0);
 if (!($6)) {
  $scevgep$i$i$i = ((($5)) + -8|0);
  $7 = $scevgep$i$i$i;
  $8 = $2;
  $9 = (($7) - ($8))|0;
  $10 = $9 >>> 3;
  $11 = $10 ^ -1;
  $scevgep5$i$i$i = (($5) + ($11<<3)|0);
  HEAP32[$4>>2] = $scevgep5$i$i$i;
 }
 __ZdlPv($2);
 return;
}
function __ZN3osg11MixinVectorIdED0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i = 0, $scevgep5$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (52536);
 $1 = ((($0)) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  __ZdlPv($0);
  return;
 }
 $4 = ((($0)) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==($2|0);
 if (!($6)) {
  $scevgep$i$i$i$i = ((($5)) + -8|0);
  $7 = $scevgep$i$i$i$i;
  $8 = $2;
  $9 = (($7) - ($8))|0;
  $10 = $9 >>> 3;
  $11 = $10 ^ -1;
  $scevgep5$i$i$i$i = (($5) + ($11<<3)|0);
  HEAP32[$4>>2] = $scevgep5$i$i$i$i;
 }
 __ZdlPv($2);
 __ZdlPv($0);
 return;
}
function __ZN3osg13TemplateArrayIfLNS_5Array4TypeE7ELi1ELi5126EED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i = 0, $scevgep5$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 72|0);
 HEAP32[$1>>2] = (52792);
 $2 = ((($0)) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  __ZN3osg10BufferDataD2Ev($0);
  return;
 }
 $5 = ((($0)) + 80|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==($3|0);
 if (!($7)) {
  $scevgep$i$i$i$i = ((($6)) + -4|0);
  $8 = $scevgep$i$i$i$i;
  $9 = $3;
  $10 = (($8) - ($9))|0;
  $11 = $10 >>> 2;
  $12 = $11 ^ -1;
  $scevgep5$i$i$i$i = (($6) + ($12<<2)|0);
  HEAP32[$5>>2] = $scevgep5$i$i$i$i;
 }
 __ZdlPv($3);
 __ZN3osg10BufferDataD2Ev($0);
 return;
}
function __ZN3osg13TemplateArrayIfLNS_5Array4TypeE7ELi1ELi5126EED0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 72|0);
 HEAP32[$1>>2] = (52792);
 $2 = ((($0)) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = ((($0)) + 80|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==($3|0);
  if (!($7)) {
   $scevgep$i$i$i$i$i = ((($6)) + -4|0);
   $8 = $scevgep$i$i$i$i$i;
   $9 = $3;
   $10 = (($8) - ($9))|0;
   $11 = $10 >>> 2;
   $12 = $11 ^ -1;
   $scevgep5$i$i$i$i$i = (($6) + ($12<<2)|0);
   HEAP32[$5>>2] = $scevgep5$i$i$i$i$i;
  }
  __ZdlPv($3);
 }
 __THREW__ = 0;
 invoke_vi(1265,($0|0));
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 if ($14) {
  $15 = ___cxa_find_matching_catch_2()|0;
  $16 = tempRet0;
  __ZdlPv($0);
  ___resumeException($15|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK3osg13TemplateArrayIfLNS_5Array4TypeE7ELi1ELi5126EE9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(88)|0);
 __THREW__ = 0;
 invoke_vii(3435,($1|0),1);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $17 = ___cxa_find_matching_catch_2()|0;
  $18 = tempRet0;
  __ZdlPv($1);
  ___resumeException($17|0);
  // unreachable;
 } else {
  $4 = ((($1)) + 12|0);
  ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;
  $5 = ((($1)) + 24|0);
  HEAP32[$5>>2] = 2;
  $6 = ((($1)) + 28|0);
  ;HEAP32[$6>>2]=0|0;HEAP32[$6+4>>2]=0|0;HEAP32[$6+8>>2]=0|0;HEAP32[$6+12>>2]=0|0;HEAP32[$6+16>>2]=0|0;HEAP32[$6+20>>2]=0|0;
  $7 = ((($1)) + 52|0);
  HEAP32[$7>>2] = 7;
  $8 = ((($1)) + 56|0);
  HEAP32[$8>>2] = 1;
  $9 = ((($1)) + 60|0);
  HEAP32[$9>>2] = 5126;
  $10 = ((($1)) + 64|0);
  HEAP32[$10>>2] = -1;
  $11 = ((($1)) + 68|0);
  HEAP8[$11>>0] = 0;
  $12 = ((($1)) + 69|0);
  HEAP8[$12>>0] = 0;
  $13 = ((($1)) + 72|0);
  $14 = ((($1)) + 76|0);
  HEAP32[$14>>2] = 0;
  $15 = ((($1)) + 80|0);
  HEAP32[$15>>2] = 0;
  $16 = ((($1)) + 84|0);
  HEAP32[$16>>2] = 0;
  HEAP32[$1>>2] = (52808);
  HEAP32[$13>>2] = (53032);
  return ($1|0);
 }
 return (0)|0;
}
function __ZNK3osg13TemplateArrayIfLNS_5Array4TypeE7ELi1ELi5126EE5cloneERKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(88)|0);
 __THREW__ = 0;
 invoke_viii(3649,($2|0),($0|0),($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch_2()|0;
  $6 = tempRet0;
  __ZdlPv($2);
  ___resumeException($5|0);
  // unreachable;
 } else {
  return ($2|0);
 }
 return (0)|0;
}
function __ZNK3osg13TemplateArrayIfLNS_5Array4TypeE7ELi1ELi5126EE14getDataPointerEv($0) {
 $0 = $0|0;
 var $$ = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 76|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 80|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2|0)==($4|0);
 $$ = $5 ? 0 : $2;
 return ($$|0);
}
function __ZNK3osg13TemplateArrayIfLNS_5Array4TypeE7ELi1ELi5126EE16getTotalDataSizeEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 76|0);
 $2 = ((($0)) + 80|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$1>>2]|0;
 $5 = (($3) - ($4))|0;
 return ($5|0);
}
function __ZN3osg13TemplateArrayIfLNS_5Array4TypeE7ELi1ELi5126EE6acceptERNS_12ArrayVisitorE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 36|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 8191]($1,$0);
 return;
}
function __ZNK3osg13TemplateArrayIfLNS_5Array4TypeE7ELi1ELi5126EE6acceptERNS_17ConstArrayVisitorE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 36|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 8191]($1,$0);
 return;
}
function __ZN3osg13TemplateArrayIfLNS_5Array4TypeE7ELi1ELi5126EE6acceptEjRNS_12ValueVisitorE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + 32|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($0)) + 76|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($1<<2)|0);
 FUNCTION_TABLE_vii[$5 & 8191]($2,$8);
 return;
}
function __ZNK3osg13TemplateArrayIfLNS_5Array4TypeE7ELi1ELi5126EE6acceptEjRNS_17ConstValueVisitorE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + 32|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($0)) + 76|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($1<<2)|0);
 FUNCTION_TABLE_vii[$5 & 8191]($2,$8);
 return;
}
function __ZNK3osg13TemplateArrayIfLNS_5Array4TypeE7ELi1ELi5126EE7compareEjj($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$ = 0, $$0 = 0, $10 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0.0, $8 = 0.0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 76|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + ($1<<2)|0);
 $6 = (($4) + ($2<<2)|0);
 $7 = +HEAPF32[$5>>2];
 $8 = +HEAPF32[$6>>2];
 $9 = $7 < $8;
 $10 = $8 < $7;
 $$ = $10&1;
 $$0 = $9 ? -1 : $$;
 return ($$0|0);
}
function __ZNK3osg13TemplateArrayIfLNS_5Array4TypeE7ELi1ELi5126EE14getElementSizeEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 4;
}
function __ZNK3osg13TemplateArrayIfLNS_5Array4TypeE7ELi1ELi5126EE14getDataPointerEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$ = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 80|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 $7 = (($3) + ($1<<2)|0);
 $$ = $6 ? 0 : $7;
 return ($$|0);
}
function __ZNK3osg13TemplateArrayIfLNS_5Array4TypeE7ELi1ELi5126EE14getNumElementsEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 76|0);
 $2 = ((($0)) + 80|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$1>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 return ($6|0);
}
function __ZN3osg13TemplateArrayIfLNS_5Array4TypeE7ELi1ELi5126EE12reserveArrayEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 76|0);
 __ZNSt3__26vectorIfNS_9allocatorIfEEE7reserveEj($2,$1);
 return;
}
function __ZN3osg13TemplateArrayIfLNS_5Array4TypeE7ELi1ELi5126EE11resizeArrayEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i = 0;
 var $scevgep5$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 HEAPF32[$2>>2] = 0.0;
 $3 = ((($0)) + 76|0);
 $4 = ((($0)) + 80|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$3>>2]|0;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 2;
 $9 = ($8>>>0)<($1>>>0);
 $10 = $6;
 $11 = $5;
 if ($9) {
  $12 = (($1) - ($8))|0;
  __ZNSt3__26vectorIfNS_9allocatorIfEEE8__appendEjRKf($3,$12,$2);
  STACKTOP = sp;return;
 }
 $13 = ($8>>>0)>($1>>>0);
 if (!($13)) {
  STACKTOP = sp;return;
 }
 $14 = (($10) + ($1<<2)|0);
 $15 = ($11|0)==($14|0);
 if ($15) {
  STACKTOP = sp;return;
 }
 $scevgep$i$i$i$i = ((($11)) + -4|0);
 $16 = $scevgep$i$i$i$i;
 $17 = $14;
 $18 = (($16) - ($17))|0;
 $19 = $18 >>> 2;
 $20 = $19 ^ -1;
 $scevgep5$i$i$i$i = (($11) + ($20<<2)|0);
 HEAP32[$4>>2] = $scevgep5$i$i$i$i;
 STACKTOP = sp;return;
}
function __ZN3osg13TemplateArrayIfLNS_5Array4TypeE7ELi1ELi5126EE4trimEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $scevgep$i$i$i$i = 0, $scevgep5$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 HEAP32[$1>>2] = (52792);
 $2 = ((($1)) + 4|0);
 $3 = ((($0)) + 76|0);
 __ZNSt3__26vectorIfNS_9allocatorIfEEEC2ERKS3_($2,$3);
 $4 = HEAP32[$2>>2]|0;
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$2>>2] = $5;
 HEAP32[$3>>2] = $4;
 $6 = ((($1)) + 8|0);
 $7 = ((($0)) + 80|0);
 $8 = HEAP32[$6>>2]|0;
 $9 = HEAP32[$7>>2]|0;
 HEAP32[$6>>2] = $9;
 HEAP32[$7>>2] = $8;
 $10 = ((($1)) + 12|0);
 $11 = ((($0)) + 84|0);
 $12 = HEAP32[$10>>2]|0;
 $13 = HEAP32[$11>>2]|0;
 HEAP32[$10>>2] = $13;
 HEAP32[$11>>2] = $12;
 HEAP32[$1>>2] = (52792);
 $14 = ($5|0)==(0);
 $15 = $5;
 $16 = $9;
 if ($14) {
  STACKTOP = sp;return;
 }
 $17 = $5;
 $18 = ($16|0)==($17|0);
 if (!($18)) {
  $scevgep$i$i$i$i = ((($16)) + -4|0);
  $19 = $scevgep$i$i$i$i;
  $20 = (($19) - ($5))|0;
  $21 = $20 >>> 2;
  $22 = $21 ^ -1;
  $scevgep5$i$i$i$i = (($16) + ($22<<2)|0);
  HEAP32[$6>>2] = $scevgep5$i$i$i$i;
 }
 __ZdlPv($15);
 STACKTOP = sp;return;
}
function __ZThn72_N3osg13TemplateArrayIfLNS_5Array4TypeE7ELi1ELi5126EED1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -72|0);
 $2 = ((($1)) + 72|0);
 HEAP32[$2>>2] = (52792);
 $3 = ((($1)) + 76|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  __ZN3osg10BufferDataD2Ev($1);
  return;
 }
 $6 = ((($1)) + 80|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==($4|0);
 if (!($8)) {
  $scevgep$i$i$i$i$i = ((($7)) + -4|0);
  $9 = $scevgep$i$i$i$i$i;
  $10 = $4;
  $11 = (($9) - ($10))|0;
  $12 = $11 >>> 2;
  $13 = $12 ^ -1;
  $scevgep5$i$i$i$i$i = (($7) + ($13<<2)|0);
  HEAP32[$6>>2] = $scevgep5$i$i$i$i$i;
 }
 __ZdlPv($4);
 __ZN3osg10BufferDataD2Ev($1);
 return;
}
function __ZThn72_N3osg13TemplateArrayIfLNS_5Array4TypeE7ELi1ELi5126EED0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -72|0);
 $2 = ((($1)) + 72|0);
 HEAP32[$2>>2] = (52792);
 $3 = ((($1)) + 76|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if (!($5)) {
  $6 = ((($1)) + 80|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)==($4|0);
  if (!($8)) {
   $scevgep$i$i$i$i$i$i = ((($7)) + -4|0);
   $9 = $scevgep$i$i$i$i$i$i;
   $10 = $4;
   $11 = (($9) - ($10))|0;
   $12 = $11 >>> 2;
   $13 = $12 ^ -1;
   $scevgep5$i$i$i$i$i$i = (($7) + ($13<<2)|0);
   HEAP32[$6>>2] = $scevgep5$i$i$i$i$i$i;
  }
  __ZdlPv($4);
 }
 __THREW__ = 0;
 invoke_vi(1265,($1|0));
 $14 = __THREW__; __THREW__ = 0;
 $15 = $14&1;
 if ($15) {
  $16 = ___cxa_find_matching_catch_2()|0;
  $17 = tempRet0;
  __ZdlPv($1);
  ___resumeException($16|0);
  // unreachable;
 } else {
  __ZdlPv($1);
  return;
 }
}
function __ZNSt3__26vectorIfNS_9allocatorIfEEEC2ERKS3_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i = 0, $scevgep5$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = 0;
 $2 = ((($0)) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = ((($0)) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$1>>2]|0;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 2;
 $9 = ($8|0)==(0);
 if ($9) {
  return;
 }
 $10 = ($8>>>0)>(1073741823);
 if ($10) {
  __THREW__ = 0;
  invoke_vi(3307,($0|0));
  $11 = __THREW__; __THREW__ = 0;
 } else {
  __THREW__ = 0;
  $12 = (invoke_ii(3276,($7|0))|0);
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if (!($14)) {
   HEAP32[$2>>2] = $12;
   HEAP32[$0>>2] = $12;
   $15 = (($12) + ($8<<2)|0);
   $16 = ((($0)) + 8|0);
   HEAP32[$16>>2] = $15;
   $17 = HEAP32[$1>>2]|0;
   $18 = HEAP32[$4>>2]|0;
   $19 = $17;
   $20 = (($18) - ($19))|0;
   $21 = ($20|0)>(0);
   if (!($21)) {
    return;
   }
   $22 = $20 >>> 2;
   _memcpy(($12|0),($17|0),($20|0))|0;
   $23 = (($12) + ($22<<2)|0);
   HEAP32[$2>>2] = $23;
   return;
  }
 }
 $24 = ___cxa_find_matching_catch_2()|0;
 $25 = tempRet0;
 $26 = HEAP32[$0>>2]|0;
 $27 = ($26|0)==(0|0);
 if ($27) {
  ___resumeException($24|0);
  // unreachable;
 }
 $28 = HEAP32[$2>>2]|0;
 $29 = ($28|0)==($26|0);
 if (!($29)) {
  $scevgep$i$i$i = ((($28)) + -4|0);
  $30 = $scevgep$i$i$i;
  $31 = $26;
  $32 = (($30) - ($31))|0;
  $33 = $32 >>> 2;
  $34 = $33 ^ -1;
  $scevgep5$i$i$i = (($28) + ($34<<2)|0);
  HEAP32[$2>>2] = $scevgep5$i$i$i;
 }
 __ZdlPv($26);
 ___resumeException($24|0);
 // unreachable;
}
function __ZNSt3__26vectorIfNS_9allocatorIfEEE8__appendEjRKf($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$i = 0, $$0$i18 = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep = 0, $scevgep43 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) - ($6))|0;
 $8 = $7 >> 2;
 $9 = ($8>>>0)<($1>>>0);
 if (!($9)) {
  $10 = $6;
  $11 = $6;
  $scevgep43 = (($10) + ($1<<2)|0);
  $$0$i = $1;$13 = $11;
  while(1) {
   $12 = HEAP32[$2>>2]|0;
   HEAP32[$13>>2] = $12;
   $14 = ((($13)) + 4|0);
   $15 = (($$0$i) + -1)|0;
   $16 = ($15|0)==(0);
   if ($16) {
    break;
   } else {
    $$0$i = $15;$13 = $14;
   }
  }
  HEAP32[$5>>2] = $scevgep43;
  return;
 }
 $17 = HEAP32[$0>>2]|0;
 $18 = (($6) - ($17))|0;
 $19 = $18 >> 2;
 $20 = (($19) + ($1))|0;
 $21 = ($20>>>0)>(1073741823);
 if ($21) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $22 = (($4) - ($17))|0;
 $23 = $22 >> 2;
 $24 = ($23>>>0)<(536870911);
 $25 = $22 >> 1;
 $26 = ($25>>>0)<($20>>>0);
 $$sroa$speculated$i = $26 ? $20 : $25;
 $$sroa$speculated$$i = $24 ? $$sroa$speculated$i : 1073741823;
 $27 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($27) {
   $37 = 0;
  } else {
   $28 = ($$sroa$speculated$$i>>>0)>(1073741823);
   if (!($28)) {
    $34 = $$sroa$speculated$$i << 2;
    $35 = (__Znwj($34)|0);
    $37 = $35;
    break;
   }
   $29 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($29|0),(204840|0));
   $30 = __THREW__; __THREW__ = 0;
   $31 = $30&1;
   if ($31) {
    $32 = ___cxa_find_matching_catch_2()|0;
    $33 = tempRet0;
    ___cxa_free_exception(($29|0));
    ___resumeException($32|0);
    // unreachable;
   } else {
    HEAP32[$29>>2] = (99824);
    ___cxa_throw(($29|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $36 = (($37) + ($19<<2)|0);
 $38 = (($37) + ($$sroa$speculated$$i<<2)|0);
 $$0$i18 = $1;$40 = $36;
 while(1) {
  $39 = HEAP32[$2>>2]|0;
  HEAP32[$40>>2] = $39;
  $41 = ((($40)) + 4|0);
  $42 = (($$0$i18) + -1)|0;
  $43 = ($42|0)==(0);
  if ($43) {
   break;
  } else {
   $$0$i18 = $42;$40 = $41;
  }
 }
 $44 = $38;
 $scevgep = (($37) + ($20<<2)|0);
 $45 = $scevgep;
 $46 = (0 - ($19))|0;
 $47 = (($36) + ($46<<2)|0);
 $48 = $47;
 $49 = ($18|0)>(0);
 if ($49) {
  $50 = $17;
  _memcpy(($47|0),($50|0),($18|0))|0;
 }
 HEAP32[$0>>2] = $48;
 HEAP32[$5>>2] = $45;
 HEAP32[$3>>2] = $44;
 $51 = ($17|0)==(0);
 if ($51) {
  return;
 }
 $52 = $17;
 __ZdlPv($52);
 return;
}
function __ZNSt3__26vectorIfNS_9allocatorIfEEE7reserveEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 $7 = ($6>>>0)<($1>>>0);
 if (!($7)) {
  return;
 }
 $8 = ((($0)) + 4|0);
 $9 = ($1>>>0)>(1073741823);
 if ($9) {
  $10 = (___cxa_allocate_exception(8)|0);
  __THREW__ = 0;
  invoke_vii(3366,($10|0),(204840|0));
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if ($12) {
   $13 = ___cxa_find_matching_catch_2()|0;
   $14 = tempRet0;
   ___cxa_free_exception(($10|0));
   ___resumeException($13|0);
   // unreachable;
  } else {
   HEAP32[$10>>2] = (99824);
   ___cxa_throw(($10|0),(34608|0),(3230|0));
   // unreachable;
  }
 }
 $15 = HEAP32[$8>>2]|0;
 $16 = (($15) - ($4))|0;
 $17 = $16 >> 2;
 $18 = $1 << 2;
 $19 = (__Znwj($18)|0);
 $20 = (($19) + ($17<<2)|0);
 $21 = $20;
 $22 = (($19) + ($1<<2)|0);
 $23 = $22;
 $24 = (0 - ($17))|0;
 $25 = (($20) + ($24<<2)|0);
 $26 = $25;
 $27 = ($16|0)>(0);
 if ($27) {
  $28 = $4;
  _memcpy(($25|0),($28|0),($16|0))|0;
 }
 HEAP32[$0>>2] = $26;
 HEAP32[$8>>2] = $21;
 HEAP32[$2>>2] = $23;
 $29 = ($4|0)==(0);
 if ($29) {
  return;
 }
 $30 = $4;
 __ZdlPv($30);
 return;
}
function __ZN3osg13TemplateArrayIfLNS_5Array4TypeE7ELi1ELi5126EEC2ERKS3_RKNS_6CopyOpE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg6ObjectC2ERKS0_RKNS_6CopyOpE($0,$1,$2);
 HEAP32[$0>>2] = (55116);
 $3 = ((($0)) + 32|0);
 HEAP32[$3>>2] = 0;
 $4 = ((($0)) + 36|0);
 HEAP32[$4>>2] = 0;
 $5 = ((($0)) + 40|0);
 HEAP32[$5>>2] = 0;
 $6 = ((($0)) + 44|0);
 $7 = ((($1)) + 44|0);
 $8 = HEAP32[$7>>2]|0;
 HEAP32[$6>>2] = $8;
 $9 = ($8|0)==(0|0);
 if (!($9)) {
  $10 = HEAP32[$8>>2]|0;
  $11 = ((($10)) + -12|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($8) + ($12)|0);
  $14 = ((($13)) + 8|0);
  $15 = HEAP32[$14>>2]|0;HEAP32[$14>>2] = (($15+1)|0);
 }
 $16 = ((($0)) + 48|0);
 HEAP32[$16>>2] = 0;
 HEAP32[$0>>2] = (54500);
 $17 = ((($0)) + 52|0);
 $18 = ((($1)) + 52|0);
 $19 = HEAP32[$18>>2]|0;
 HEAP32[$17>>2] = $19;
 $20 = ((($0)) + 56|0);
 $21 = ((($1)) + 56|0);
 $22 = HEAP32[$21>>2]|0;
 HEAP32[$20>>2] = $22;
 $23 = ((($0)) + 60|0);
 $24 = ((($1)) + 60|0);
 $25 = HEAP32[$24>>2]|0;
 HEAP32[$23>>2] = $25;
 $26 = ((($0)) + 64|0);
 $27 = ((($1)) + 64|0);
 $28 = HEAP32[$27>>2]|0;
 HEAP32[$26>>2] = $28;
 $29 = ((($0)) + 68|0);
 $30 = ((($1)) + 68|0);
 $31 = HEAP8[$30>>0]|0;
 HEAP8[$29>>0] = $31;
 $32 = ((($0)) + 69|0);
 $33 = ((($1)) + 69|0);
 $34 = HEAP8[$33>>0]|0;
 HEAP8[$32>>0] = $34;
 $35 = ((($0)) + 72|0);
 HEAP32[$35>>2] = (52792);
 $36 = ((($0)) + 76|0);
 $37 = ((($1)) + 76|0);
 __THREW__ = 0;
 invoke_vii(3650,($36|0),($37|0));
 $38 = __THREW__; __THREW__ = 0;
 $39 = $38&1;
 if (!($39)) {
  HEAP32[$0>>2] = (52808);
  HEAP32[$35>>2] = (53032);
  return;
 }
 $40 = ___cxa_find_matching_catch_2()|0;
 $41 = tempRet0;
 __THREW__ = 0;
 invoke_vi(1265,($0|0));
 $42 = __THREW__; __THREW__ = 0;
 $43 = $42&1;
 if ($43) {
  $44 = ___cxa_find_matching_catch_3(0|0)|0;
  $45 = tempRet0;
  ___clang_call_terminate($44);
  // unreachable;
 } else {
  ___resumeException($40|0);
  // unreachable;
 }
}
function __ZN3osg11MixinVectorIfED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i = 0, $scevgep5$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (52792);
 $1 = ((($0)) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  return;
 }
 $4 = ((($0)) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==($2|0);
 if (!($6)) {
  $scevgep$i$i$i = ((($5)) + -4|0);
  $7 = $scevgep$i$i$i;
  $8 = $2;
  $9 = (($7) - ($8))|0;
  $10 = $9 >>> 2;
  $11 = $10 ^ -1;
  $scevgep5$i$i$i = (($5) + ($11<<2)|0);
  HEAP32[$4>>2] = $scevgep5$i$i$i;
 }
 __ZdlPv($2);
 return;
}
function __ZN3osg11MixinVectorIfED0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i = 0, $scevgep5$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (52792);
 $1 = ((($0)) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  __ZdlPv($0);
  return;
 }
 $4 = ((($0)) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==($2|0);
 if (!($6)) {
  $scevgep$i$i$i$i = ((($5)) + -4|0);
  $7 = $scevgep$i$i$i$i;
  $8 = $2;
  $9 = (($7) - ($8))|0;
  $10 = $9 >>> 2;
  $11 = $10 ^ -1;
  $scevgep5$i$i$i$i = (($5) + ($11<<2)|0);
  HEAP32[$4>>2] = $scevgep5$i$i$i$i;
 }
 __ZdlPv($2);
 __ZdlPv($0);
 return;
}
function __ZN3osg18TemplateIndexArrayIjLNS_5Array4TypeE6ELi1ELi5125EED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i = 0, $scevgep5$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 72|0);
 HEAP32[$1>>2] = (52520);
 $2 = ((($0)) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  __ZN3osg10BufferDataD2Ev($0);
  return;
 }
 $5 = ((($0)) + 80|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==($3|0);
 if (!($7)) {
  $scevgep$i$i$i$i = ((($6)) + -4|0);
  $8 = $scevgep$i$i$i$i;
  $9 = $3;
  $10 = (($8) - ($9))|0;
  $11 = $10 >>> 2;
  $12 = $11 ^ -1;
  $scevgep5$i$i$i$i = (($6) + ($12<<2)|0);
  HEAP32[$5>>2] = $scevgep5$i$i$i$i;
 }
 __ZdlPv($3);
 __ZN3osg10BufferDataD2Ev($0);
 return;
}
function __ZN3osg18TemplateIndexArrayIjLNS_5Array4TypeE6ELi1ELi5125EED0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 72|0);
 HEAP32[$1>>2] = (52520);
 $2 = ((($0)) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = ((($0)) + 80|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==($3|0);
  if (!($7)) {
   $scevgep$i$i$i$i$i = ((($6)) + -4|0);
   $8 = $scevgep$i$i$i$i$i;
   $9 = $3;
   $10 = (($8) - ($9))|0;
   $11 = $10 >>> 2;
   $12 = $11 ^ -1;
   $scevgep5$i$i$i$i$i = (($6) + ($12<<2)|0);
   HEAP32[$5>>2] = $scevgep5$i$i$i$i$i;
  }
  __ZdlPv($3);
 }
 __THREW__ = 0;
 invoke_vi(1265,($0|0));
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 if ($14) {
  $15 = ___cxa_find_matching_catch_2()|0;
  $16 = tempRet0;
  __ZdlPv($0);
  ___resumeException($15|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK3osg18TemplateIndexArrayIjLNS_5Array4TypeE6ELi1ELi5125EE9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(88)|0);
 __THREW__ = 0;
 invoke_vii(3435,($1|0),1);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $17 = ___cxa_find_matching_catch_2()|0;
  $18 = tempRet0;
  __ZdlPv($1);
  ___resumeException($17|0);
  // unreachable;
 } else {
  $4 = ((($1)) + 12|0);
  ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;
  $5 = ((($1)) + 24|0);
  HEAP32[$5>>2] = 2;
  $6 = ((($1)) + 28|0);
  ;HEAP32[$6>>2]=0|0;HEAP32[$6+4>>2]=0|0;HEAP32[$6+8>>2]=0|0;HEAP32[$6+12>>2]=0|0;HEAP32[$6+16>>2]=0|0;HEAP32[$6+20>>2]=0|0;
  $7 = ((($1)) + 52|0);
  HEAP32[$7>>2] = 6;
  $8 = ((($1)) + 56|0);
  HEAP32[$8>>2] = 1;
  $9 = ((($1)) + 60|0);
  HEAP32[$9>>2] = 5125;
  $10 = ((($1)) + 64|0);
  HEAP32[$10>>2] = -1;
  $11 = ((($1)) + 68|0);
  HEAP8[$11>>0] = 0;
  $12 = ((($1)) + 69|0);
  HEAP8[$12>>0] = 0;
  $13 = ((($1)) + 72|0);
  $14 = ((($1)) + 76|0);
  HEAP32[$14>>2] = 0;
  $15 = ((($1)) + 80|0);
  HEAP32[$15>>2] = 0;
  $16 = ((($1)) + 84|0);
  HEAP32[$16>>2] = 0;
  HEAP32[$1>>2] = (53276);
  HEAP32[$13>>2] = (53504);
  return ($1|0);
 }
 return (0)|0;
}
function __ZNK3osg18TemplateIndexArrayIjLNS_5Array4TypeE6ELi1ELi5125EE5cloneERKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(88)|0);
 __THREW__ = 0;
 invoke_viii(3651,($2|0),($0|0),($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch_2()|0;
  $6 = tempRet0;
  __ZdlPv($2);
  ___resumeException($5|0);
  // unreachable;
 } else {
  return ($2|0);
 }
 return (0)|0;
}
function __ZNK3osg10IndexArray12isSameKindAsEPKNS_6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,22736,0)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK3osg18TemplateIndexArrayIjLNS_5Array4TypeE6ELi1ELi5125EE14getDataPointerEv($0) {
 $0 = $0|0;
 var $$ = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 76|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 80|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2|0)==($4|0);
 $$ = $5 ? 0 : $2;
 return ($$|0);
}
function __ZNK3osg18TemplateIndexArrayIjLNS_5Array4TypeE6ELi1ELi5125EE16getTotalDataSizeEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 76|0);
 $2 = ((($0)) + 80|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$1>>2]|0;
 $5 = (($3) - ($4))|0;
 return ($5|0);
}
function __ZN3osg18TemplateIndexArrayIjLNS_5Array4TypeE6ELi1ELi5125EE6acceptERNS_12ArrayVisitorE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 32|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 8191]($1,$0);
 return;
}
function __ZNK3osg18TemplateIndexArrayIjLNS_5Array4TypeE6ELi1ELi5125EE6acceptERNS_17ConstArrayVisitorE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 32|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 8191]($1,$0);
 return;
}
function __ZN3osg18TemplateIndexArrayIjLNS_5Array4TypeE6ELi1ELi5125EE6acceptEjRNS_12ValueVisitorE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($0)) + 76|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($1<<2)|0);
 FUNCTION_TABLE_vii[$5 & 8191]($2,$8);
 return;
}
function __ZNK3osg18TemplateIndexArrayIjLNS_5Array4TypeE6ELi1ELi5125EE6acceptEjRNS_17ConstValueVisitorE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($0)) + 76|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($1<<2)|0);
 FUNCTION_TABLE_vii[$5 & 8191]($2,$8);
 return;
}
function __ZNK3osg18TemplateIndexArrayIjLNS_5Array4TypeE6ELi1ELi5125EE7compareEjj($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$ = 0, $$0 = 0, $10 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 76|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + ($1<<2)|0);
 $6 = (($4) + ($2<<2)|0);
 $7 = HEAP32[$5>>2]|0;
 $8 = HEAP32[$6>>2]|0;
 $9 = ($7>>>0)<($8>>>0);
 $10 = ($8>>>0)<($7>>>0);
 $$ = $10&1;
 $$0 = $9 ? -1 : $$;
 return ($$0|0);
}
function __ZNK3osg18TemplateIndexArrayIjLNS_5Array4TypeE6ELi1ELi5125EE14getElementSizeEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 4;
}
function __ZNK3osg18TemplateIndexArrayIjLNS_5Array4TypeE6ELi1ELi5125EE14getDataPointerEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$ = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 80|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 $7 = (($3) + ($1<<2)|0);
 $$ = $6 ? 0 : $7;
 return ($$|0);
}
function __ZNK3osg18TemplateIndexArrayIjLNS_5Array4TypeE6ELi1ELi5125EE14getNumElementsEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 76|0);
 $2 = ((($0)) + 80|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$1>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 return ($6|0);
}
function __ZN3osg18TemplateIndexArrayIjLNS_5Array4TypeE6ELi1ELi5125EE12reserveArrayEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 76|0);
 __ZNSt3__26vectorIjNS_9allocatorIjEEE7reserveEj($2,$1);
 return;
}
function __ZN3osg18TemplateIndexArrayIjLNS_5Array4TypeE6ELi1ELi5125EE11resizeArrayEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i = 0;
 var $scevgep5$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 HEAP32[$2>>2] = 0;
 $3 = ((($0)) + 76|0);
 $4 = ((($0)) + 80|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$3>>2]|0;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 2;
 $9 = ($8>>>0)<($1>>>0);
 $10 = $6;
 $11 = $5;
 if ($9) {
  $12 = (($1) - ($8))|0;
  __ZNSt3__26vectorIjNS_9allocatorIjEEE8__appendEjRKj($3,$12,$2);
  STACKTOP = sp;return;
 }
 $13 = ($8>>>0)>($1>>>0);
 if (!($13)) {
  STACKTOP = sp;return;
 }
 $14 = (($10) + ($1<<2)|0);
 $15 = ($11|0)==($14|0);
 if ($15) {
  STACKTOP = sp;return;
 }
 $scevgep$i$i$i$i = ((($11)) + -4|0);
 $16 = $scevgep$i$i$i$i;
 $17 = $14;
 $18 = (($16) - ($17))|0;
 $19 = $18 >>> 2;
 $20 = $19 ^ -1;
 $scevgep5$i$i$i$i = (($11) + ($20<<2)|0);
 HEAP32[$4>>2] = $scevgep5$i$i$i$i;
 STACKTOP = sp;return;
}
function __ZN3osg18TemplateIndexArrayIjLNS_5Array4TypeE6ELi1ELi5125EE4trimEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $scevgep$i$i$i$i = 0, $scevgep5$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 HEAP32[$1>>2] = (52520);
 $2 = ((($1)) + 4|0);
 $3 = ((($0)) + 76|0);
 __ZNSt3__26vectorIjNS_9allocatorIjEEEC2ERKS3_($2,$3);
 $4 = HEAP32[$2>>2]|0;
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$2>>2] = $5;
 HEAP32[$3>>2] = $4;
 $6 = ((($1)) + 8|0);
 $7 = ((($0)) + 80|0);
 $8 = HEAP32[$6>>2]|0;
 $9 = HEAP32[$7>>2]|0;
 HEAP32[$6>>2] = $9;
 HEAP32[$7>>2] = $8;
 $10 = ((($1)) + 12|0);
 $11 = ((($0)) + 84|0);
 $12 = HEAP32[$10>>2]|0;
 $13 = HEAP32[$11>>2]|0;
 HEAP32[$10>>2] = $13;
 HEAP32[$11>>2] = $12;
 HEAP32[$1>>2] = (52520);
 $14 = ($5|0)==(0);
 $15 = $5;
 $16 = $9;
 if ($14) {
  STACKTOP = sp;return;
 }
 $17 = $5;
 $18 = ($16|0)==($17|0);
 if (!($18)) {
  $scevgep$i$i$i$i = ((($16)) + -4|0);
  $19 = $scevgep$i$i$i$i;
  $20 = (($19) - ($5))|0;
  $21 = $20 >>> 2;
  $22 = $21 ^ -1;
  $scevgep5$i$i$i$i = (($16) + ($22<<2)|0);
  HEAP32[$6>>2] = $scevgep5$i$i$i$i;
 }
 __ZdlPv($15);
 STACKTOP = sp;return;
}
function __ZNK3osg18TemplateIndexArrayIjLNS_5Array4TypeE6ELi1ELi5125EE5indexEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + ($1<<2)|0);
 $5 = HEAP32[$4>>2]|0;
 return ($5|0);
}
function __ZThn72_N3osg18TemplateIndexArrayIjLNS_5Array4TypeE6ELi1ELi5125EED1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -72|0);
 $2 = ((($1)) + 72|0);
 HEAP32[$2>>2] = (52520);
 $3 = ((($1)) + 76|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  __ZN3osg10BufferDataD2Ev($1);
  return;
 }
 $6 = ((($1)) + 80|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==($4|0);
 if (!($8)) {
  $scevgep$i$i$i$i$i = ((($7)) + -4|0);
  $9 = $scevgep$i$i$i$i$i;
  $10 = $4;
  $11 = (($9) - ($10))|0;
  $12 = $11 >>> 2;
  $13 = $12 ^ -1;
  $scevgep5$i$i$i$i$i = (($7) + ($13<<2)|0);
  HEAP32[$6>>2] = $scevgep5$i$i$i$i$i;
 }
 __ZdlPv($4);
 __ZN3osg10BufferDataD2Ev($1);
 return;
}
function __ZThn72_N3osg18TemplateIndexArrayIjLNS_5Array4TypeE6ELi1ELi5125EED0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -72|0);
 $2 = ((($1)) + 72|0);
 HEAP32[$2>>2] = (52520);
 $3 = ((($1)) + 76|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if (!($5)) {
  $6 = ((($1)) + 80|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)==($4|0);
  if (!($8)) {
   $scevgep$i$i$i$i$i$i = ((($7)) + -4|0);
   $9 = $scevgep$i$i$i$i$i$i;
   $10 = $4;
   $11 = (($9) - ($10))|0;
   $12 = $11 >>> 2;
   $13 = $12 ^ -1;
   $scevgep5$i$i$i$i$i$i = (($7) + ($13<<2)|0);
   HEAP32[$6>>2] = $scevgep5$i$i$i$i$i$i;
  }
  __ZdlPv($4);
 }
 __THREW__ = 0;
 invoke_vi(1265,($1|0));
 $14 = __THREW__; __THREW__ = 0;
 $15 = $14&1;
 if ($15) {
  $16 = ___cxa_find_matching_catch_2()|0;
  $17 = tempRet0;
  __ZdlPv($1);
  ___resumeException($16|0);
  // unreachable;
 } else {
  __ZdlPv($1);
  return;
 }
}
function __ZN3osg18TemplateIndexArrayIjLNS_5Array4TypeE6ELi1ELi5125EEC2ERKS3_RKNS_6CopyOpE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg6ObjectC2ERKS0_RKNS_6CopyOpE($0,$1,$2);
 HEAP32[$0>>2] = (55116);
 $3 = ((($0)) + 32|0);
 HEAP32[$3>>2] = 0;
 $4 = ((($0)) + 36|0);
 HEAP32[$4>>2] = 0;
 $5 = ((($0)) + 40|0);
 HEAP32[$5>>2] = 0;
 $6 = ((($0)) + 44|0);
 $7 = ((($1)) + 44|0);
 $8 = HEAP32[$7>>2]|0;
 HEAP32[$6>>2] = $8;
 $9 = ($8|0)==(0|0);
 if (!($9)) {
  $10 = HEAP32[$8>>2]|0;
  $11 = ((($10)) + -12|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($8) + ($12)|0);
  $14 = ((($13)) + 8|0);
  $15 = HEAP32[$14>>2]|0;HEAP32[$14>>2] = (($15+1)|0);
 }
 $16 = ((($0)) + 48|0);
 HEAP32[$16>>2] = 0;
 $17 = ((($0)) + 52|0);
 $18 = ((($1)) + 52|0);
 $19 = HEAP32[$18>>2]|0;
 HEAP32[$17>>2] = $19;
 $20 = ((($0)) + 56|0);
 $21 = ((($1)) + 56|0);
 $22 = HEAP32[$21>>2]|0;
 HEAP32[$20>>2] = $22;
 $23 = ((($0)) + 60|0);
 $24 = ((($1)) + 60|0);
 $25 = HEAP32[$24>>2]|0;
 HEAP32[$23>>2] = $25;
 $26 = ((($0)) + 64|0);
 $27 = ((($1)) + 64|0);
 $28 = HEAP32[$27>>2]|0;
 HEAP32[$26>>2] = $28;
 $29 = ((($0)) + 68|0);
 $30 = ((($1)) + 68|0);
 $31 = HEAP8[$30>>0]|0;
 HEAP8[$29>>0] = $31;
 $32 = ((($0)) + 69|0);
 $33 = ((($1)) + 69|0);
 $34 = HEAP8[$33>>0]|0;
 HEAP8[$32>>0] = $34;
 HEAP32[$0>>2] = (53048);
 $35 = ((($0)) + 72|0);
 HEAP32[$35>>2] = (52520);
 $36 = ((($0)) + 76|0);
 $37 = ((($1)) + 76|0);
 __THREW__ = 0;
 invoke_vii(3317,($36|0),($37|0));
 $38 = __THREW__; __THREW__ = 0;
 $39 = $38&1;
 if (!($39)) {
  HEAP32[$0>>2] = (53276);
  HEAP32[$35>>2] = (53504);
  return;
 }
 $40 = ___cxa_find_matching_catch_2()|0;
 $41 = tempRet0;
 __THREW__ = 0;
 invoke_vi(1265,($0|0));
 $42 = __THREW__; __THREW__ = 0;
 $43 = $42&1;
 if ($43) {
  $44 = ___cxa_find_matching_catch_3(0|0)|0;
  $45 = tempRet0;
  ___clang_call_terminate($44);
  // unreachable;
 } else {
  ___resumeException($40|0);
  // unreachable;
 }
}
function __ZN3osg10IndexArrayD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1265,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZN3osg5Array4trimEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZNSt3__26vectorItNS_9allocatorItEEEC2ERKS3_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i = 0, $scevgep5$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = 0;
 $2 = ((($0)) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = ((($0)) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$1>>2]|0;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 1;
 $9 = ($8|0)==(0);
 if ($9) {
  return;
 }
 $10 = ($7|0)<(0);
 if ($10) {
  __THREW__ = 0;
  invoke_vi(3307,($0|0));
  $11 = __THREW__; __THREW__ = 0;
 } else {
  __THREW__ = 0;
  $12 = (invoke_ii(3276,($7|0))|0);
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if (!($14)) {
   HEAP32[$2>>2] = $12;
   HEAP32[$0>>2] = $12;
   $15 = (($12) + ($8<<1)|0);
   $16 = ((($0)) + 8|0);
   HEAP32[$16>>2] = $15;
   $17 = HEAP32[$1>>2]|0;
   $18 = HEAP32[$4>>2]|0;
   $19 = $17;
   $20 = (($18) - ($19))|0;
   $21 = ($20|0)>(0);
   if (!($21)) {
    return;
   }
   $22 = $20 >>> 1;
   _memcpy(($12|0),($17|0),($20|0))|0;
   $23 = (($12) + ($22<<1)|0);
   HEAP32[$2>>2] = $23;
   return;
  }
 }
 $24 = ___cxa_find_matching_catch_2()|0;
 $25 = tempRet0;
 $26 = HEAP32[$0>>2]|0;
 $27 = ($26|0)==(0|0);
 if ($27) {
  ___resumeException($24|0);
  // unreachable;
 }
 $28 = HEAP32[$2>>2]|0;
 $29 = ($28|0)==($26|0);
 if (!($29)) {
  $scevgep$i$i$i = ((($28)) + -2|0);
  $30 = $scevgep$i$i$i;
  $31 = $26;
  $32 = (($30) - ($31))|0;
  $33 = $32 >>> 1;
  $34 = $33 ^ -1;
  $scevgep5$i$i$i = (($28) + ($34<<1)|0);
  HEAP32[$2>>2] = $scevgep5$i$i$i;
 }
 __ZdlPv($26);
 ___resumeException($24|0);
 // unreachable;
}
function __ZNSt3__26vectorItNS_9allocatorItEEE8__appendEjRKt($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$i = 0, $$0$i17 = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i = 0, $scevgep$i18 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) - ($6))|0;
 $8 = $7 >> 1;
 $9 = ($8>>>0)<($1>>>0);
 $10 = $6;
 if (!($9)) {
  $$0$i = $1;$12 = $10;
  while(1) {
   $11 = HEAP16[$2>>1]|0;
   HEAP16[$12>>1] = $11;
   $13 = ((($12)) + 2|0);
   $14 = (($$0$i) + -1)|0;
   $15 = ($14|0)==(0);
   if ($15) {
    break;
   } else {
    $$0$i = $14;$12 = $13;
   }
  }
  $scevgep$i = (($10) + ($1<<1)|0);
  HEAP32[$5>>2] = $scevgep$i;
  return;
 }
 $16 = HEAP32[$0>>2]|0;
 $17 = (($6) - ($16))|0;
 $18 = $17 >> 1;
 $19 = (($18) + ($1))|0;
 $20 = ($19|0)<(0);
 if ($20) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $21 = (($4) - ($16))|0;
 $22 = $21 >> 1;
 $23 = ($22>>>0)<(1073741823);
 $24 = ($21>>>0)<($19>>>0);
 $$sroa$speculated$i = $24 ? $19 : $21;
 $$sroa$speculated$$i = $23 ? $$sroa$speculated$i : 2147483647;
 $25 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($25) {
   $35 = 0;
  } else {
   $26 = ($$sroa$speculated$$i|0)<(0);
   if (!($26)) {
    $32 = $$sroa$speculated$$i << 1;
    $33 = (__Znwj($32)|0);
    $35 = $33;
    break;
   }
   $27 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($27|0),(204840|0));
   $28 = __THREW__; __THREW__ = 0;
   $29 = $28&1;
   if ($29) {
    $30 = ___cxa_find_matching_catch_2()|0;
    $31 = tempRet0;
    ___cxa_free_exception(($27|0));
    ___resumeException($30|0);
    // unreachable;
   } else {
    HEAP32[$27>>2] = (99824);
    ___cxa_throw(($27|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $34 = (($35) + ($18<<1)|0);
 $36 = (($35) + ($$sroa$speculated$$i<<1)|0);
 $$0$i17 = $1;$38 = $34;
 while(1) {
  $37 = HEAP16[$2>>1]|0;
  HEAP16[$38>>1] = $37;
  $39 = ((($38)) + 2|0);
  $40 = (($$0$i17) + -1)|0;
  $41 = ($40|0)==(0);
  if ($41) {
   break;
  } else {
   $$0$i17 = $40;$38 = $39;
  }
 }
 $42 = $36;
 $scevgep$i18 = (($34) + ($1<<1)|0);
 $43 = $scevgep$i18;
 $44 = (0 - ($18))|0;
 $45 = (($34) + ($44<<1)|0);
 $46 = $45;
 $47 = ($17|0)>(0);
 if ($47) {
  $48 = $16;
  _memcpy(($45|0),($48|0),($17|0))|0;
 }
 HEAP32[$0>>2] = $46;
 HEAP32[$5>>2] = $43;
 HEAP32[$3>>2] = $42;
 $49 = ($16|0)==(0);
 if ($49) {
  return;
 }
 $50 = $16;
 __ZdlPv($50);
 return;
}
function __ZN3osg11MixinVectorItED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i = 0, $scevgep5$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (53520);
 $1 = ((($0)) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  return;
 }
 $4 = ((($0)) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==($2|0);
 if (!($6)) {
  $scevgep$i$i$i = ((($5)) + -2|0);
  $7 = $scevgep$i$i$i;
  $8 = $2;
  $9 = (($7) - ($8))|0;
  $10 = $9 >>> 1;
  $11 = $10 ^ -1;
  $scevgep5$i$i$i = (($5) + ($11<<1)|0);
  HEAP32[$4>>2] = $scevgep5$i$i$i;
 }
 __ZdlPv($2);
 return;
}
function __ZN3osg11MixinVectorItED0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i = 0, $scevgep5$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (53520);
 $1 = ((($0)) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  __ZdlPv($0);
  return;
 }
 $4 = ((($0)) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==($2|0);
 if (!($6)) {
  $scevgep$i$i$i$i = ((($5)) + -2|0);
  $7 = $scevgep$i$i$i$i;
  $8 = $2;
  $9 = (($7) - ($8))|0;
  $10 = $9 >>> 1;
  $11 = $10 ^ -1;
  $scevgep5$i$i$i$i = (($5) + ($11<<1)|0);
  HEAP32[$4>>2] = $scevgep5$i$i$i$i;
 }
 __ZdlPv($2);
 __ZdlPv($0);
 return;
}
function __ZNSt3__26vectorIhNS_9allocatorIhEEE8__appendEjRKh($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$i = 0, $$0$i16 = 0, $$sroa$15$0 = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) - ($6))|0;
 $8 = ($7>>>0)<($1>>>0);
 if (!($8)) {
  $9 = $6;
  $$0$i = $1;$11 = $9;
  while(1) {
   $10 = HEAP8[$2>>0]|0;
   HEAP8[$11>>0] = $10;
   $12 = HEAP32[$5>>2]|0;
   $13 = ((($12)) + 1|0);
   HEAP32[$5>>2] = $13;
   $14 = (($$0$i) + -1)|0;
   $15 = ($14|0)==(0);
   if ($15) {
    break;
   } else {
    $$0$i = $14;$11 = $13;
   }
  }
  return;
 }
 $16 = HEAP32[$0>>2]|0;
 $17 = (($6) - ($16))|0;
 $18 = (($17) + ($1))|0;
 $19 = ($18|0)<(0);
 if ($19) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $20 = (($4) - ($16))|0;
 $21 = ($20>>>0)<(1073741823);
 $22 = $20 << 1;
 $23 = ($22>>>0)<($18>>>0);
 $$sroa$speculated$i = $23 ? $18 : $22;
 $$sroa$speculated$$i = $21 ? $$sroa$speculated$i : 2147483647;
 $24 = ($$sroa$speculated$$i|0)==(0);
 if ($24) {
  $27 = 0;
 } else {
  $25 = (__Znwj($$sroa$speculated$$i)|0);
  $27 = $25;
 }
 $26 = (($27) + ($17)|0);
 $28 = $26;
 $29 = (($27) + ($$sroa$speculated$$i)|0);
 $$0$i16 = $1;$$sroa$15$0 = $28;$31 = $26;
 while(1) {
  $30 = HEAP8[$2>>0]|0;
  HEAP8[$31>>0] = $30;
  $32 = $$sroa$15$0;
  $33 = ((($32)) + 1|0);
  $34 = $33;
  $35 = (($$0$i16) + -1)|0;
  $36 = ($35|0)==(0);
  if ($36) {
   break;
  } else {
   $$0$i16 = $35;$$sroa$15$0 = $34;$31 = $33;
  }
 }
 $37 = $29;
 $38 = HEAP32[$0>>2]|0;
 $39 = HEAP32[$5>>2]|0;
 $40 = $38;
 $41 = (($39) - ($40))|0;
 $42 = (0 - ($41))|0;
 $43 = (($26) + ($42)|0);
 $44 = $43;
 $45 = ($41|0)>(0);
 if ($45) {
  _memcpy(($43|0),($38|0),($41|0))|0;
 }
 HEAP32[$0>>2] = $44;
 HEAP32[$5>>2] = $34;
 HEAP32[$3>>2] = $37;
 $46 = ($38|0)==(0|0);
 if ($46) {
  return;
 }
 __ZdlPv($38);
 return;
}
function __ZN3osg11MixinVectorIhED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (53536);
 $1 = ((($0)) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  return;
 }
 $4 = ((($0)) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==($2|0);
 if (!($6)) {
  HEAP32[$4>>2] = $2;
 }
 __ZdlPv($2);
 return;
}
function __ZN3osg11MixinVectorIhED0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (53536);
 $1 = ((($0)) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  __ZdlPv($0);
  return;
 }
 $4 = ((($0)) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==($2|0);
 if (!($6)) {
  HEAP32[$4>>2] = $2;
 }
 __ZdlPv($2);
 __ZdlPv($0);
 return;
}
function __ZN3osg18TemplateIndexArrayIiLNS_5Array4TypeE3ELi1ELi5124EED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i = 0, $scevgep5$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 72|0);
 HEAP32[$1>>2] = (53552);
 $2 = ((($0)) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  __ZN3osg10BufferDataD2Ev($0);
  return;
 }
 $5 = ((($0)) + 80|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==($3|0);
 if (!($7)) {
  $scevgep$i$i$i$i = ((($6)) + -4|0);
  $8 = $scevgep$i$i$i$i;
  $9 = $3;
  $10 = (($8) - ($9))|0;
  $11 = $10 >>> 2;
  $12 = $11 ^ -1;
  $scevgep5$i$i$i$i = (($6) + ($12<<2)|0);
  HEAP32[$5>>2] = $scevgep5$i$i$i$i;
 }
 __ZdlPv($3);
 __ZN3osg10BufferDataD2Ev($0);
 return;
}
function __ZN3osg18TemplateIndexArrayIiLNS_5Array4TypeE3ELi1ELi5124EED0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 72|0);
 HEAP32[$1>>2] = (53552);
 $2 = ((($0)) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = ((($0)) + 80|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==($3|0);
  if (!($7)) {
   $scevgep$i$i$i$i$i = ((($6)) + -4|0);
   $8 = $scevgep$i$i$i$i$i;
   $9 = $3;
   $10 = (($8) - ($9))|0;
   $11 = $10 >>> 2;
   $12 = $11 ^ -1;
   $scevgep5$i$i$i$i$i = (($6) + ($12<<2)|0);
   HEAP32[$5>>2] = $scevgep5$i$i$i$i$i;
  }
  __ZdlPv($3);
 }
 __THREW__ = 0;
 invoke_vi(1265,($0|0));
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 if ($14) {
  $15 = ___cxa_find_matching_catch_2()|0;
  $16 = tempRet0;
  __ZdlPv($0);
  ___resumeException($15|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK3osg18TemplateIndexArrayIiLNS_5Array4TypeE3ELi1ELi5124EE9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(88)|0);
 __THREW__ = 0;
 invoke_vii(3435,($1|0),1);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $17 = ___cxa_find_matching_catch_2()|0;
  $18 = tempRet0;
  __ZdlPv($1);
  ___resumeException($17|0);
  // unreachable;
 } else {
  $4 = ((($1)) + 12|0);
  ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;
  $5 = ((($1)) + 24|0);
  HEAP32[$5>>2] = 2;
  $6 = ((($1)) + 28|0);
  ;HEAP32[$6>>2]=0|0;HEAP32[$6+4>>2]=0|0;HEAP32[$6+8>>2]=0|0;HEAP32[$6+12>>2]=0|0;HEAP32[$6+16>>2]=0|0;HEAP32[$6+20>>2]=0|0;
  $7 = ((($1)) + 52|0);
  HEAP32[$7>>2] = 3;
  $8 = ((($1)) + 56|0);
  HEAP32[$8>>2] = 1;
  $9 = ((($1)) + 60|0);
  HEAP32[$9>>2] = 5124;
  $10 = ((($1)) + 64|0);
  HEAP32[$10>>2] = -1;
  $11 = ((($1)) + 68|0);
  HEAP8[$11>>0] = 0;
  $12 = ((($1)) + 69|0);
  HEAP8[$12>>0] = 0;
  $13 = ((($1)) + 72|0);
  $14 = ((($1)) + 76|0);
  HEAP32[$14>>2] = 0;
  $15 = ((($1)) + 80|0);
  HEAP32[$15>>2] = 0;
  $16 = ((($1)) + 84|0);
  HEAP32[$16>>2] = 0;
  HEAP32[$1>>2] = (53568);
  HEAP32[$13>>2] = (53796);
  return ($1|0);
 }
 return (0)|0;
}
function __ZNK3osg18TemplateIndexArrayIiLNS_5Array4TypeE3ELi1ELi5124EE5cloneERKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(88)|0);
 __THREW__ = 0;
 invoke_viii(3652,($2|0),($0|0),($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch_2()|0;
  $6 = tempRet0;
  __ZdlPv($2);
  ___resumeException($5|0);
  // unreachable;
 } else {
  return ($2|0);
 }
 return (0)|0;
}
function __ZNK3osg18TemplateIndexArrayIiLNS_5Array4TypeE3ELi1ELi5124EE14getDataPointerEv($0) {
 $0 = $0|0;
 var $$ = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 76|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 80|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2|0)==($4|0);
 $$ = $5 ? 0 : $2;
 return ($$|0);
}
function __ZNK3osg18TemplateIndexArrayIiLNS_5Array4TypeE3ELi1ELi5124EE16getTotalDataSizeEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 76|0);
 $2 = ((($0)) + 80|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$1>>2]|0;
 $5 = (($3) - ($4))|0;
 return ($5|0);
}
function __ZN3osg18TemplateIndexArrayIiLNS_5Array4TypeE3ELi1ELi5124EE6acceptERNS_12ArrayVisitorE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 8191]($1,$0);
 return;
}
function __ZNK3osg18TemplateIndexArrayIiLNS_5Array4TypeE3ELi1ELi5124EE6acceptERNS_17ConstArrayVisitorE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 8191]($1,$0);
 return;
}
function __ZN3osg18TemplateIndexArrayIiLNS_5Array4TypeE3ELi1ELi5124EE6acceptEjRNS_12ValueVisitorE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + 16|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($0)) + 76|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($1<<2)|0);
 FUNCTION_TABLE_vii[$5 & 8191]($2,$8);
 return;
}
function __ZNK3osg18TemplateIndexArrayIiLNS_5Array4TypeE3ELi1ELi5124EE6acceptEjRNS_17ConstValueVisitorE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + 16|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($0)) + 76|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($1<<2)|0);
 FUNCTION_TABLE_vii[$5 & 8191]($2,$8);
 return;
}
function __ZNK3osg18TemplateIndexArrayIiLNS_5Array4TypeE3ELi1ELi5124EE7compareEjj($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$ = 0, $$0 = 0, $10 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 76|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + ($1<<2)|0);
 $6 = (($4) + ($2<<2)|0);
 $7 = HEAP32[$5>>2]|0;
 $8 = HEAP32[$6>>2]|0;
 $9 = ($7|0)<($8|0);
 $10 = ($8|0)<($7|0);
 $$ = $10&1;
 $$0 = $9 ? -1 : $$;
 return ($$0|0);
}
function __ZNK3osg18TemplateIndexArrayIiLNS_5Array4TypeE3ELi1ELi5124EE14getElementSizeEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 4;
}
function __ZNK3osg18TemplateIndexArrayIiLNS_5Array4TypeE3ELi1ELi5124EE14getDataPointerEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$ = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 80|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 $7 = (($3) + ($1<<2)|0);
 $$ = $6 ? 0 : $7;
 return ($$|0);
}
function __ZNK3osg18TemplateIndexArrayIiLNS_5Array4TypeE3ELi1ELi5124EE14getNumElementsEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 76|0);
 $2 = ((($0)) + 80|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$1>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 return ($6|0);
}
function __ZN3osg18TemplateIndexArrayIiLNS_5Array4TypeE3ELi1ELi5124EE12reserveArrayEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 76|0);
 __ZNSt3__26vectorIiNS_9allocatorIiEEE7reserveEj($2,$1);
 return;
}
function __ZN3osg18TemplateIndexArrayIiLNS_5Array4TypeE3ELi1ELi5124EE11resizeArrayEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i = 0;
 var $scevgep5$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 HEAP32[$2>>2] = 0;
 $3 = ((($0)) + 76|0);
 $4 = ((($0)) + 80|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$3>>2]|0;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 2;
 $9 = ($8>>>0)<($1>>>0);
 $10 = $6;
 $11 = $5;
 if ($9) {
  $12 = (($1) - ($8))|0;
  __ZNSt3__26vectorIiNS_9allocatorIiEEE8__appendEjRKi($3,$12,$2);
  STACKTOP = sp;return;
 }
 $13 = ($8>>>0)>($1>>>0);
 if (!($13)) {
  STACKTOP = sp;return;
 }
 $14 = (($10) + ($1<<2)|0);
 $15 = ($11|0)==($14|0);
 if ($15) {
  STACKTOP = sp;return;
 }
 $scevgep$i$i$i$i = ((($11)) + -4|0);
 $16 = $scevgep$i$i$i$i;
 $17 = $14;
 $18 = (($16) - ($17))|0;
 $19 = $18 >>> 2;
 $20 = $19 ^ -1;
 $scevgep5$i$i$i$i = (($11) + ($20<<2)|0);
 HEAP32[$4>>2] = $scevgep5$i$i$i$i;
 STACKTOP = sp;return;
}
function __ZN3osg18TemplateIndexArrayIiLNS_5Array4TypeE3ELi1ELi5124EE4trimEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $scevgep$i$i$i$i = 0, $scevgep5$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 HEAP32[$1>>2] = (53552);
 $2 = ((($1)) + 4|0);
 $3 = ((($0)) + 76|0);
 __ZNSt3__26vectorIiNS_9allocatorIiEEEC2ERKS3_($2,$3);
 $4 = HEAP32[$2>>2]|0;
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$2>>2] = $5;
 HEAP32[$3>>2] = $4;
 $6 = ((($1)) + 8|0);
 $7 = ((($0)) + 80|0);
 $8 = HEAP32[$6>>2]|0;
 $9 = HEAP32[$7>>2]|0;
 HEAP32[$6>>2] = $9;
 HEAP32[$7>>2] = $8;
 $10 = ((($1)) + 12|0);
 $11 = ((($0)) + 84|0);
 $12 = HEAP32[$10>>2]|0;
 $13 = HEAP32[$11>>2]|0;
 HEAP32[$10>>2] = $13;
 HEAP32[$11>>2] = $12;
 HEAP32[$1>>2] = (53552);
 $14 = ($5|0)==(0);
 $15 = $5;
 $16 = $9;
 if ($14) {
  STACKTOP = sp;return;
 }
 $17 = $5;
 $18 = ($16|0)==($17|0);
 if (!($18)) {
  $scevgep$i$i$i$i = ((($16)) + -4|0);
  $19 = $scevgep$i$i$i$i;
  $20 = (($19) - ($5))|0;
  $21 = $20 >>> 2;
  $22 = $21 ^ -1;
  $scevgep5$i$i$i$i = (($16) + ($22<<2)|0);
  HEAP32[$6>>2] = $scevgep5$i$i$i$i;
 }
 __ZdlPv($15);
 STACKTOP = sp;return;
}
function __ZNK3osg18TemplateIndexArrayIiLNS_5Array4TypeE3ELi1ELi5124EE5indexEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + ($1<<2)|0);
 $5 = HEAP32[$4>>2]|0;
 return ($5|0);
}
function __ZThn72_N3osg18TemplateIndexArrayIiLNS_5Array4TypeE3ELi1ELi5124EED1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -72|0);
 $2 = ((($1)) + 72|0);
 HEAP32[$2>>2] = (53552);
 $3 = ((($1)) + 76|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  __ZN3osg10BufferDataD2Ev($1);
  return;
 }
 $6 = ((($1)) + 80|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==($4|0);
 if (!($8)) {
  $scevgep$i$i$i$i$i = ((($7)) + -4|0);
  $9 = $scevgep$i$i$i$i$i;
  $10 = $4;
  $11 = (($9) - ($10))|0;
  $12 = $11 >>> 2;
  $13 = $12 ^ -1;
  $scevgep5$i$i$i$i$i = (($7) + ($13<<2)|0);
  HEAP32[$6>>2] = $scevgep5$i$i$i$i$i;
 }
 __ZdlPv($4);
 __ZN3osg10BufferDataD2Ev($1);
 return;
}
function __ZThn72_N3osg18TemplateIndexArrayIiLNS_5Array4TypeE3ELi1ELi5124EED0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -72|0);
 $2 = ((($1)) + 72|0);
 HEAP32[$2>>2] = (53552);
 $3 = ((($1)) + 76|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if (!($5)) {
  $6 = ((($1)) + 80|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)==($4|0);
  if (!($8)) {
   $scevgep$i$i$i$i$i$i = ((($7)) + -4|0);
   $9 = $scevgep$i$i$i$i$i$i;
   $10 = $4;
   $11 = (($9) - ($10))|0;
   $12 = $11 >>> 2;
   $13 = $12 ^ -1;
   $scevgep5$i$i$i$i$i$i = (($7) + ($13<<2)|0);
   HEAP32[$6>>2] = $scevgep5$i$i$i$i$i$i;
  }
  __ZdlPv($4);
 }
 __THREW__ = 0;
 invoke_vi(1265,($1|0));
 $14 = __THREW__; __THREW__ = 0;
 $15 = $14&1;
 if ($15) {
  $16 = ___cxa_find_matching_catch_2()|0;
  $17 = tempRet0;
  __ZdlPv($1);
  ___resumeException($16|0);
  // unreachable;
 } else {
  __ZdlPv($1);
  return;
 }
}
function __ZNSt3__26vectorIiNS_9allocatorIiEEEC2ERKS3_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i = 0, $scevgep5$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = 0;
 $2 = ((($0)) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = ((($0)) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$1>>2]|0;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 2;
 $9 = ($8|0)==(0);
 if ($9) {
  return;
 }
 $10 = ($8>>>0)>(1073741823);
 if ($10) {
  __THREW__ = 0;
  invoke_vi(3307,($0|0));
  $11 = __THREW__; __THREW__ = 0;
 } else {
  __THREW__ = 0;
  $12 = (invoke_ii(3276,($7|0))|0);
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if (!($14)) {
   HEAP32[$2>>2] = $12;
   HEAP32[$0>>2] = $12;
   $15 = (($12) + ($8<<2)|0);
   $16 = ((($0)) + 8|0);
   HEAP32[$16>>2] = $15;
   $17 = HEAP32[$1>>2]|0;
   $18 = HEAP32[$4>>2]|0;
   $19 = $17;
   $20 = (($18) - ($19))|0;
   $21 = ($20|0)>(0);
   if (!($21)) {
    return;
   }
   $22 = $20 >>> 2;
   _memcpy(($12|0),($17|0),($20|0))|0;
   $23 = (($12) + ($22<<2)|0);
   HEAP32[$2>>2] = $23;
   return;
  }
 }
 $24 = ___cxa_find_matching_catch_2()|0;
 $25 = tempRet0;
 $26 = HEAP32[$0>>2]|0;
 $27 = ($26|0)==(0|0);
 if ($27) {
  ___resumeException($24|0);
  // unreachable;
 }
 $28 = HEAP32[$2>>2]|0;
 $29 = ($28|0)==($26|0);
 if (!($29)) {
  $scevgep$i$i$i = ((($28)) + -4|0);
  $30 = $scevgep$i$i$i;
  $31 = $26;
  $32 = (($30) - ($31))|0;
  $33 = $32 >>> 2;
  $34 = $33 ^ -1;
  $scevgep5$i$i$i = (($28) + ($34<<2)|0);
  HEAP32[$2>>2] = $scevgep5$i$i$i;
 }
 __ZdlPv($26);
 ___resumeException($24|0);
 // unreachable;
}
function __ZNSt3__26vectorIiNS_9allocatorIiEEE8__appendEjRKi($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$i = 0, $$0$i17 = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i = 0, $scevgep$i18 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) - ($6))|0;
 $8 = $7 >> 2;
 $9 = ($8>>>0)<($1>>>0);
 $10 = $6;
 if (!($9)) {
  $$0$i = $1;$12 = $10;
  while(1) {
   $11 = HEAP32[$2>>2]|0;
   HEAP32[$12>>2] = $11;
   $13 = ((($12)) + 4|0);
   $14 = (($$0$i) + -1)|0;
   $15 = ($14|0)==(0);
   if ($15) {
    break;
   } else {
    $$0$i = $14;$12 = $13;
   }
  }
  $scevgep$i = (($10) + ($1<<2)|0);
  HEAP32[$5>>2] = $scevgep$i;
  return;
 }
 $16 = HEAP32[$0>>2]|0;
 $17 = (($6) - ($16))|0;
 $18 = $17 >> 2;
 $19 = (($18) + ($1))|0;
 $20 = ($19>>>0)>(1073741823);
 if ($20) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $21 = (($4) - ($16))|0;
 $22 = $21 >> 2;
 $23 = ($22>>>0)<(536870911);
 $24 = $21 >> 1;
 $25 = ($24>>>0)<($19>>>0);
 $$sroa$speculated$i = $25 ? $19 : $24;
 $$sroa$speculated$$i = $23 ? $$sroa$speculated$i : 1073741823;
 $26 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($26) {
   $36 = 0;
  } else {
   $27 = ($$sroa$speculated$$i>>>0)>(1073741823);
   if (!($27)) {
    $33 = $$sroa$speculated$$i << 2;
    $34 = (__Znwj($33)|0);
    $36 = $34;
    break;
   }
   $28 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($28|0),(204840|0));
   $29 = __THREW__; __THREW__ = 0;
   $30 = $29&1;
   if ($30) {
    $31 = ___cxa_find_matching_catch_2()|0;
    $32 = tempRet0;
    ___cxa_free_exception(($28|0));
    ___resumeException($31|0);
    // unreachable;
   } else {
    HEAP32[$28>>2] = (99824);
    ___cxa_throw(($28|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $35 = (($36) + ($18<<2)|0);
 $37 = (($36) + ($$sroa$speculated$$i<<2)|0);
 $$0$i17 = $1;$39 = $35;
 while(1) {
  $38 = HEAP32[$2>>2]|0;
  HEAP32[$39>>2] = $38;
  $40 = ((($39)) + 4|0);
  $41 = (($$0$i17) + -1)|0;
  $42 = ($41|0)==(0);
  if ($42) {
   break;
  } else {
   $$0$i17 = $41;$39 = $40;
  }
 }
 $43 = $37;
 $scevgep$i18 = (($35) + ($1<<2)|0);
 $44 = $scevgep$i18;
 $45 = (0 - ($18))|0;
 $46 = (($35) + ($45<<2)|0);
 $47 = $46;
 $48 = ($17|0)>(0);
 if ($48) {
  $49 = $16;
  _memcpy(($46|0),($49|0),($17|0))|0;
 }
 HEAP32[$0>>2] = $47;
 HEAP32[$5>>2] = $44;
 HEAP32[$3>>2] = $43;
 $50 = ($16|0)==(0);
 if ($50) {
  return;
 }
 $51 = $16;
 __ZdlPv($51);
 return;
}
function __ZNSt3__26vectorIiNS_9allocatorIiEEE7reserveEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 $7 = ($6>>>0)<($1>>>0);
 if (!($7)) {
  return;
 }
 $8 = ((($0)) + 4|0);
 $9 = ($1>>>0)>(1073741823);
 if ($9) {
  $10 = (___cxa_allocate_exception(8)|0);
  __THREW__ = 0;
  invoke_vii(3366,($10|0),(204840|0));
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if ($12) {
   $13 = ___cxa_find_matching_catch_2()|0;
   $14 = tempRet0;
   ___cxa_free_exception(($10|0));
   ___resumeException($13|0);
   // unreachable;
  } else {
   HEAP32[$10>>2] = (99824);
   ___cxa_throw(($10|0),(34608|0),(3230|0));
   // unreachable;
  }
 }
 $15 = HEAP32[$8>>2]|0;
 $16 = (($15) - ($4))|0;
 $17 = $16 >> 2;
 $18 = $1 << 2;
 $19 = (__Znwj($18)|0);
 $20 = (($19) + ($17<<2)|0);
 $21 = $20;
 $22 = (($19) + ($1<<2)|0);
 $23 = $22;
 $24 = (0 - ($17))|0;
 $25 = (($20) + ($24<<2)|0);
 $26 = $25;
 $27 = ($16|0)>(0);
 if ($27) {
  $28 = $4;
  _memcpy(($25|0),($28|0),($16|0))|0;
 }
 HEAP32[$0>>2] = $26;
 HEAP32[$8>>2] = $21;
 HEAP32[$2>>2] = $23;
 $29 = ($4|0)==(0);
 if ($29) {
  return;
 }
 $30 = $4;
 __ZdlPv($30);
 return;
}
function __ZN3osg18TemplateIndexArrayIiLNS_5Array4TypeE3ELi1ELi5124EEC2ERKS3_RKNS_6CopyOpE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg6ObjectC2ERKS0_RKNS_6CopyOpE($0,$1,$2);
 HEAP32[$0>>2] = (55116);
 $3 = ((($0)) + 32|0);
 HEAP32[$3>>2] = 0;
 $4 = ((($0)) + 36|0);
 HEAP32[$4>>2] = 0;
 $5 = ((($0)) + 40|0);
 HEAP32[$5>>2] = 0;
 $6 = ((($0)) + 44|0);
 $7 = ((($1)) + 44|0);
 $8 = HEAP32[$7>>2]|0;
 HEAP32[$6>>2] = $8;
 $9 = ($8|0)==(0|0);
 if (!($9)) {
  $10 = HEAP32[$8>>2]|0;
  $11 = ((($10)) + -12|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($8) + ($12)|0);
  $14 = ((($13)) + 8|0);
  $15 = HEAP32[$14>>2]|0;HEAP32[$14>>2] = (($15+1)|0);
 }
 $16 = ((($0)) + 48|0);
 HEAP32[$16>>2] = 0;
 $17 = ((($0)) + 52|0);
 $18 = ((($1)) + 52|0);
 $19 = HEAP32[$18>>2]|0;
 HEAP32[$17>>2] = $19;
 $20 = ((($0)) + 56|0);
 $21 = ((($1)) + 56|0);
 $22 = HEAP32[$21>>2]|0;
 HEAP32[$20>>2] = $22;
 $23 = ((($0)) + 60|0);
 $24 = ((($1)) + 60|0);
 $25 = HEAP32[$24>>2]|0;
 HEAP32[$23>>2] = $25;
 $26 = ((($0)) + 64|0);
 $27 = ((($1)) + 64|0);
 $28 = HEAP32[$27>>2]|0;
 HEAP32[$26>>2] = $28;
 $29 = ((($0)) + 68|0);
 $30 = ((($1)) + 68|0);
 $31 = HEAP8[$30>>0]|0;
 HEAP8[$29>>0] = $31;
 $32 = ((($0)) + 69|0);
 $33 = ((($1)) + 69|0);
 $34 = HEAP8[$33>>0]|0;
 HEAP8[$32>>0] = $34;
 HEAP32[$0>>2] = (53048);
 $35 = ((($0)) + 72|0);
 HEAP32[$35>>2] = (53552);
 $36 = ((($0)) + 76|0);
 $37 = ((($1)) + 76|0);
 __THREW__ = 0;
 invoke_vii(3653,($36|0),($37|0));
 $38 = __THREW__; __THREW__ = 0;
 $39 = $38&1;
 if (!($39)) {
  HEAP32[$0>>2] = (53568);
  HEAP32[$35>>2] = (53796);
  return;
 }
 $40 = ___cxa_find_matching_catch_2()|0;
 $41 = tempRet0;
 __THREW__ = 0;
 invoke_vi(1265,($0|0));
 $42 = __THREW__; __THREW__ = 0;
 $43 = $42&1;
 if ($43) {
  $44 = ___cxa_find_matching_catch_3(0|0)|0;
  $45 = tempRet0;
  ___clang_call_terminate($44);
  // unreachable;
 } else {
  ___resumeException($40|0);
  // unreachable;
 }
}
function __ZN3osg11MixinVectorIiED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i = 0, $scevgep5$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (53552);
 $1 = ((($0)) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  return;
 }
 $4 = ((($0)) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==($2|0);
 if (!($6)) {
  $scevgep$i$i$i = ((($5)) + -4|0);
  $7 = $scevgep$i$i$i;
  $8 = $2;
  $9 = (($7) - ($8))|0;
  $10 = $9 >>> 2;
  $11 = $10 ^ -1;
  $scevgep5$i$i$i = (($5) + ($11<<2)|0);
  HEAP32[$4>>2] = $scevgep5$i$i$i;
 }
 __ZdlPv($2);
 return;
}
function __ZN3osg11MixinVectorIiED0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i = 0, $scevgep5$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (53552);
 $1 = ((($0)) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  __ZdlPv($0);
  return;
 }
 $4 = ((($0)) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==($2|0);
 if (!($6)) {
  $scevgep$i$i$i$i = ((($5)) + -4|0);
  $7 = $scevgep$i$i$i$i;
  $8 = $2;
  $9 = (($7) - ($8))|0;
  $10 = $9 >>> 2;
  $11 = $10 ^ -1;
  $scevgep5$i$i$i$i = (($5) + ($11<<2)|0);
  HEAP32[$4>>2] = $scevgep5$i$i$i$i;
 }
 __ZdlPv($2);
 __ZdlPv($0);
 return;
}
function __ZN7osgUtil24PositionalStateContainerD2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (53812);
 $1 = ((($0)) + 44|0);
 $2 = ((($0)) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIjNS_6vectorINS_4pairIN3osg7ref_ptrIKNS4_14StateAttributeEEENS5_INS4_10RefMatrixdEEEEENS_9allocatorISB_EEEEEENS_19__map_value_compareIjSF_NS_4lessIjEELb1EEENSC_ISF_EEE7destroyEPNS_11__tree_nodeISF_PvEE($1,$3);
 $4 = ((($0)) + 32|0);
 __THREW__ = 0;
 invoke_vi(3654,($4|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if (!($6)) {
  __ZN3osg6ObjectD2Ev($0);
  return;
 }
 $7 = ___cxa_find_matching_catch_2()|0;
 $8 = tempRet0;
 __THREW__ = 0;
 invoke_vi(388,($0|0));
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if ($10) {
  $11 = ___cxa_find_matching_catch_3(0|0)|0;
  $12 = tempRet0;
  ___clang_call_terminate($11);
  // unreachable;
 } else {
  ___resumeException($7|0);
  // unreachable;
 }
}
function __ZN7osgUtil24PositionalStateContainerD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (53812);
 $1 = ((($0)) + 44|0);
 $2 = ((($0)) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIjNS_6vectorINS_4pairIN3osg7ref_ptrIKNS4_14StateAttributeEEENS5_INS4_10RefMatrixdEEEEENS_9allocatorISB_EEEEEENS_19__map_value_compareIjSF_NS_4lessIjEELb1EEENSC_ISF_EEE7destroyEPNS_11__tree_nodeISF_PvEE($1,$3);
 $4 = ((($0)) + 32|0);
 __THREW__ = 0;
 invoke_vi(3654,($4|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $9 = ___cxa_find_matching_catch_2()|0;
  $10 = tempRet0;
  __THREW__ = 0;
  invoke_vi(388,($0|0));
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if ($12) {
   $13 = ___cxa_find_matching_catch_3(0|0)|0;
   $14 = tempRet0;
   ___clang_call_terminate($13);
   // unreachable;
  } else {
   $eh$lpad$body$index2Z2D = $10;$eh$lpad$body$indexZ2D = $9;
   __ZdlPv($0);
   ___resumeException($eh$lpad$body$indexZ2D|0);
   // unreachable;
  }
 }
 __THREW__ = 0;
 invoke_vi(388,($0|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if (!($8)) {
  __ZdlPv($0);
  return;
 }
 $15 = ___cxa_find_matching_catch_2()|0;
 $16 = tempRet0;
 $eh$lpad$body$index2Z2D = $16;$eh$lpad$body$indexZ2D = $15;
 __ZdlPv($0);
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
}
function __ZNK7osgUtil24PositionalStateContainer9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(56)|0);
 __THREW__ = 0;
 invoke_vi(3282,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $13 = ___cxa_find_matching_catch_2()|0;
  $14 = tempRet0;
  __ZdlPv($1);
  ___resumeException($13|0);
  // unreachable;
 } else {
  $4 = ((($1)) + 12|0);
  ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;
  $5 = ((($1)) + 24|0);
  HEAP32[$5>>2] = 2;
  $6 = ((($1)) + 28|0);
  HEAP32[$6>>2] = 0;
  HEAP32[$1>>2] = (53812);
  $7 = ((($1)) + 32|0);
  HEAP32[$7>>2] = 0;
  $8 = ((($1)) + 36|0);
  HEAP32[$8>>2] = 0;
  $9 = ((($1)) + 40|0);
  HEAP32[$9>>2] = 0;
  $10 = ((($1)) + 48|0);
  HEAP32[$10>>2] = 0;
  $11 = ((($1)) + 52|0);
  HEAP32[$11>>2] = 0;
  $12 = ((($1)) + 44|0);
  HEAP32[$12>>2] = $10;
  return ($1|0);
 }
 return (0)|0;
}
function __ZNK7osgUtil24PositionalStateContainer5cloneERKN3osg6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(56)|0);
 __THREW__ = 0;
 invoke_vi(3282,($2|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $14 = ___cxa_find_matching_catch_2()|0;
  $15 = tempRet0;
  __ZdlPv($2);
  ___resumeException($14|0);
  // unreachable;
 } else {
  $5 = ((($2)) + 12|0);
  ;HEAP32[$5>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;
  $6 = ((($2)) + 24|0);
  HEAP32[$6>>2] = 2;
  $7 = ((($2)) + 28|0);
  HEAP32[$7>>2] = 0;
  HEAP32[$2>>2] = (53812);
  $8 = ((($2)) + 32|0);
  HEAP32[$8>>2] = 0;
  $9 = ((($2)) + 36|0);
  HEAP32[$9>>2] = 0;
  $10 = ((($2)) + 40|0);
  HEAP32[$10>>2] = 0;
  $11 = ((($2)) + 48|0);
  HEAP32[$11>>2] = 0;
  $12 = ((($2)) + 52|0);
  HEAP32[$12>>2] = 0;
  $13 = ((($2)) + 44|0);
  HEAP32[$13>>2] = $11;
  return ($2|0);
 }
 return (0)|0;
}
function __ZNK7osgUtil24PositionalStateContainer12isSameKindAsEPKN3osg6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,22808,0)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK7osgUtil24PositionalStateContainer11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (116801|0);
}
function __ZNK7osgUtil24PositionalStateContainer9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (116608|0);
}
function __ZN7osgUtil24PositionalStateContainer5resetEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $eh$lpad$body$i$i$i$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 32|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 36|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==($2|0);
 L1: do {
  if (!($5)) {
   $7 = $4;
   while(1) {
    $6 = ((($7)) + -8|0);
    HEAP32[$3>>2] = $6;
    $8 = ((($7)) + -4|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = ($9|0)==(0|0);
    if (!($10)) {
     $11 = ((($9)) + 8|0);
     $12 = HEAP32[$11>>2]|0;HEAP32[$11>>2] = (($12-1)|0);
     $13 = ($12|0)==(1);
     if ($13) {
      __THREW__ = 0;
      invoke_viii(3262,($9|0),1,1);
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if ($15) {
       break;
      }
     }
    }
    HEAP32[$8>>2] = 0;
    $16 = HEAP32[$6>>2]|0;
    $17 = ($16|0)==(0|0);
    if (!($17)) {
     $18 = ((($16)) + 8|0);
     $19 = HEAP32[$18>>2]|0;HEAP32[$18>>2] = (($19-1)|0);
     $20 = ($19|0)==(1);
     if ($20) {
      __THREW__ = 0;
      invoke_viii(3262,($16|0),1,1);
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if ($22) {
       label = 14;
       break;
      }
     }
    }
    HEAP32[$6>>2] = 0;
    $34 = HEAP32[$3>>2]|0;
    $35 = ($34|0)==($2|0);
    if ($35) {
     break L1;
    } else {
     $7 = $34;
    }
   }
   if ((label|0) == 14) {
    $36 = ___cxa_find_matching_catch_2()|0;
    $37 = tempRet0;
    $eh$lpad$body$i$i$i$indexZ2D = $36;
    ___cxa_call_unexpected(($eh$lpad$body$i$i$i$indexZ2D|0));
    // unreachable;
   }
   $23 = ___cxa_find_matching_catch_2()|0;
   $24 = tempRet0;
   $25 = HEAP32[$6>>2]|0;
   $26 = ($25|0)==(0|0);
   if (!($26)) {
    $27 = ((($25)) + 8|0);
    $28 = HEAP32[$27>>2]|0;HEAP32[$27>>2] = (($28-1)|0);
    $29 = ($28|0)==(1);
    if ($29) {
     __THREW__ = 0;
     invoke_viii(3262,($25|0),1,1);
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      $32 = ___cxa_find_matching_catch_3(0|0)|0;
      $33 = tempRet0;
      ___clang_call_terminate($32);
      // unreachable;
     }
    }
   }
   HEAP32[$6>>2] = 0;
   $eh$lpad$body$i$i$i$indexZ2D = $23;
   ___cxa_call_unexpected(($eh$lpad$body$i$i$i$indexZ2D|0));
   // unreachable;
  }
 } while(0);
 $38 = ((($0)) + 44|0);
 $39 = ((($0)) + 48|0);
 $40 = HEAP32[$39>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIjNS_6vectorINS_4pairIN3osg7ref_ptrIKNS4_14StateAttributeEEENS5_INS4_10RefMatrixdEEEEENS_9allocatorISB_EEEEEENS_19__map_value_compareIjSF_NS_4lessIjEELb1EEENSC_ISF_EEE7destroyEPNS_11__tree_nodeISF_PvEE($38,$40);
 $41 = ((($0)) + 52|0);
 HEAP32[$41>>2] = 0;
 HEAP32[$38>>2] = $39;
 HEAP32[$39>>2] = 0;
 return;
}
function __ZN7osgUtil24PositionalStateContainer22addPositionedAttributeEPN3osg10RefMatrixdEPKNS1_14StateAttributeE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$04 = 0, $$1 = 0, $$15 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, $eh$lpad$body14$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = ((($0)) + 32|0);
 $5 = ($2|0)==(0|0);
 if (!($5)) {
  $6 = ((($2)) + 8|0);
  $7 = HEAP32[$6>>2]|0;HEAP32[$6>>2] = (($7+1)|0);
 }
 $8 = ($1|0)==(0|0);
 if (!($8)) {
  $9 = ((($1)) + 8|0);
  $10 = HEAP32[$9>>2]|0;HEAP32[$9>>2] = (($10+1)|0);
 }
 HEAP32[$3>>2] = $2;
 if (!($5)) {
  $11 = ((($2)) + 8|0);
  $12 = HEAP32[$11>>2]|0;HEAP32[$11>>2] = (($12+1)|0);
 }
 $13 = ((($3)) + 4|0);
 HEAP32[$13>>2] = $1;
 if (!($8)) {
  $14 = ((($1)) + 8|0);
  $15 = HEAP32[$14>>2]|0;HEAP32[$14>>2] = (($15+1)|0);
 }
 $16 = ((($0)) + 36|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ((($0)) + 40|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($17|0)==($19|0);
 do {
  if ($20) {
   __THREW__ = 0;
   invoke_vii(3655,($4|0),($3|0));
   $32 = __THREW__; __THREW__ = 0;
   $33 = $32&1;
   if ($33) {
    $71 = ___cxa_find_matching_catch_2()|0;
    $72 = tempRet0;
    $73 = HEAP32[$13>>2]|0;
    $74 = ($73|0)==(0|0);
    if (!($74)) {
     $75 = ((($73)) + 8|0);
     $76 = HEAP32[$75>>2]|0;HEAP32[$75>>2] = (($76-1)|0);
     $77 = ($76|0)==(1);
     if ($77) {
      __THREW__ = 0;
      invoke_viii(3262,($73|0),1,1);
      $78 = __THREW__; __THREW__ = 0;
      $79 = $78&1;
      if ($79) {
       $87 = ___cxa_find_matching_catch_3(0|0)|0;
       $88 = tempRet0;
       $89 = HEAP32[$3>>2]|0;
       $90 = ($89|0)==(0|0);
       if (!($90)) {
        $91 = ((($89)) + 8|0);
        $92 = HEAP32[$91>>2]|0;HEAP32[$91>>2] = (($92-1)|0);
        $93 = ($92|0)==(1);
        if ($93) {
         __THREW__ = 0;
         invoke_viii(3262,($89|0),1,1);
         $94 = __THREW__; __THREW__ = 0;
         $95 = $94&1;
         if ($95) {
          $96 = ___cxa_find_matching_catch_3(0|0)|0;
          $97 = tempRet0;
          ___clang_call_terminate($96);
          // unreachable;
         }
        }
       }
       HEAP32[$3>>2] = 0;
       $eh$lpad$body14$indexZ2D = $87;
       ___clang_call_terminate($eh$lpad$body14$indexZ2D);
       // unreachable;
      }
     }
    }
    HEAP32[$13>>2] = 0;
    $80 = HEAP32[$3>>2]|0;
    $81 = ($80|0)==(0|0);
    if (!($81)) {
     $82 = ((($80)) + 8|0);
     $83 = HEAP32[$82>>2]|0;HEAP32[$82>>2] = (($83-1)|0);
     $84 = ($83|0)==(1);
     if ($84) {
      __THREW__ = 0;
      invoke_viii(3262,($80|0),1,1);
      $85 = __THREW__; __THREW__ = 0;
      $86 = $85&1;
      if ($86) {
       break;
      }
     }
    }
    HEAP32[$3>>2] = 0;
    $$0 = $72;$$04 = $71;
    label = 49;
   } else {
    label = 16;
   }
  } else {
   $21 = HEAP32[$3>>2]|0;
   HEAP32[$17>>2] = $21;
   $22 = ($21|0)==(0|0);
   if (!($22)) {
    $23 = ((($21)) + 8|0);
    $24 = HEAP32[$23>>2]|0;HEAP32[$23>>2] = (($24+1)|0);
   }
   $25 = ((($17)) + 4|0);
   $26 = HEAP32[$13>>2]|0;
   HEAP32[$25>>2] = $26;
   $27 = ($26|0)==(0|0);
   if (!($27)) {
    $28 = ((($26)) + 8|0);
    $29 = HEAP32[$28>>2]|0;HEAP32[$28>>2] = (($29+1)|0);
   }
   $30 = HEAP32[$16>>2]|0;
   $31 = ((($30)) + 8|0);
   HEAP32[$16>>2] = $31;
   label = 16;
  }
 } while(0);
 L38: do {
  if ((label|0) == 16) {
   $34 = HEAP32[$13>>2]|0;
   $35 = ($34|0)==(0|0);
   if ($35) {
    label = 19;
   } else {
    $36 = ((($34)) + 8|0);
    $37 = HEAP32[$36>>2]|0;HEAP32[$36>>2] = (($37-1)|0);
    $38 = ($37|0)==(1);
    if ($38) {
     __THREW__ = 0;
     invoke_viii(3262,($34|0),1,1);
     $39 = __THREW__; __THREW__ = 0;
     $40 = $39&1;
     if ($40) {
      $48 = ___cxa_find_matching_catch_2()|0;
      $49 = tempRet0;
      $50 = HEAP32[$3>>2]|0;
      $51 = ($50|0)==(0|0);
      if (!($51)) {
       $52 = ((($50)) + 8|0);
       $53 = HEAP32[$52>>2]|0;HEAP32[$52>>2] = (($53-1)|0);
       $54 = ($53|0)==(1);
       if ($54) {
        __THREW__ = 0;
        invoke_viii(3262,($50|0),1,1);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         $57 = ___cxa_find_matching_catch_3(0|0)|0;
         $58 = tempRet0;
         ___clang_call_terminate($57);
         // unreachable;
        }
       }
      }
      HEAP32[$3>>2] = 0;
      $eh$lpad$body$index2Z2D = $49;$eh$lpad$body$indexZ2D = $48;
     } else {
      label = 19;
     }
    } else {
     label = 19;
    }
   }
   do {
    if ((label|0) == 19) {
     HEAP32[$13>>2] = 0;
     $41 = HEAP32[$3>>2]|0;
     $42 = ($41|0)==(0|0);
     if (!($42)) {
      $43 = ((($41)) + 8|0);
      $44 = HEAP32[$43>>2]|0;HEAP32[$43>>2] = (($44-1)|0);
      $45 = ($44|0)==(1);
      if ($45) {
       __THREW__ = 0;
       invoke_viii(3262,($41|0),1,1);
       $46 = __THREW__; __THREW__ = 0;
       $47 = $46&1;
       if ($47) {
        $69 = ___cxa_find_matching_catch_2()|0;
        $70 = tempRet0;
        $eh$lpad$body$index2Z2D = $70;$eh$lpad$body$indexZ2D = $69;
        break;
       }
      }
     }
     HEAP32[$3>>2] = 0;
     if (!($8)) {
      $59 = ((($1)) + 8|0);
      $60 = HEAP32[$59>>2]|0;HEAP32[$59>>2] = (($60-1)|0);
      $61 = ($60|0)==(1);
      if ($61) {
       __THREW__ = 0;
       invoke_viii(3262,($1|0),1,1);
       $62 = __THREW__; __THREW__ = 0;
       $63 = $62&1;
       if ($63) {
        $67 = ___cxa_find_matching_catch_2()|0;
        $68 = tempRet0;
        $$1 = $68;$$15 = $67;
        label = 52;
        break L38;
       }
      }
     }
     if ($5) {
      STACKTOP = sp;return;
     }
     $64 = ((($2)) + 8|0);
     $65 = HEAP32[$64>>2]|0;HEAP32[$64>>2] = (($65-1)|0);
     $66 = ($65|0)==(1);
     if (!($66)) {
      STACKTOP = sp;return;
     }
     __ZNK3osg10Referenced24signalObserversAndDeleteEbb($2,1,1);
     STACKTOP = sp;return;
    }
   } while(0);
   $$0 = $eh$lpad$body$index2Z2D;$$04 = $eh$lpad$body$indexZ2D;
   label = 49;
  }
 } while(0);
 if ((label|0) == 49) {
  if ($8) {
   $$1 = $$0;$$15 = $$04;
   label = 52;
  } else {
   $98 = ((($1)) + 8|0);
   $99 = HEAP32[$98>>2]|0;HEAP32[$98>>2] = (($99-1)|0);
   $100 = ($99|0)==(1);
   if ($100) {
    __THREW__ = 0;
    invoke_viii(3262,($1|0),1,1);
    $101 = __THREW__; __THREW__ = 0;
    $102 = $101&1;
    if (!($102)) {
     $$1 = $$0;$$15 = $$04;
     label = 52;
    }
   } else {
    $$1 = $$0;$$15 = $$04;
    label = 52;
   }
  }
 }
 if ((label|0) == 52) {
  if ($5) {
   ___resumeException($$15|0);
   // unreachable;
  }
  $103 = ((($2)) + 8|0);
  $104 = HEAP32[$103>>2]|0;HEAP32[$103>>2] = (($104-1)|0);
  $105 = ($104|0)==(1);
  if (!($105)) {
   ___resumeException($$15|0);
   // unreachable;
  }
  __THREW__ = 0;
  invoke_viii(3262,($2|0),1,1);
  $106 = __THREW__; __THREW__ = 0;
  $107 = $106&1;
  if (!($107)) {
   ___resumeException($$15|0);
   // unreachable;
  }
 }
 $108 = ___cxa_find_matching_catch_3(0|0)|0;
 $109 = tempRet0;
 $eh$lpad$body14$indexZ2D = $108;
 ___clang_call_terminate($eh$lpad$body14$indexZ2D);
 // unreachable;
}
function __ZN7osgUtil24PositionalStateContainer29addPositionedTextureAttributeEjPN3osg10RefMatrixdEPKNS1_14StateAttributeE($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $$0$i$i = 0, $$0$ph$i$i = 0, $$014$i = 0, $$024$i$i = 0, $$025$i$i = 0, $$025$i53$i = 0, $$037$i = 0, $$03752$i = 0, $$04 = 0, $$1 = 0, $$15 = 0, $$in$i$i = 0, $$pre$i$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0;
 var $141 = 0, $142 = 0, $143 = 0, $144 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, $eh$lpad$body12$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $4 = sp;
 $5 = ((($0)) + 44|0);
 $6 = ((($0)) + 48|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 do {
  if ($8) {
   $$025$i$i = $6;$$037$i = $6;$19 = $7;
   label = 12;
  } else {
   $9 = ((($0)) + 48|0);
   $$0$i$i = $9;$$024$i$i = $7;$144 = $7;
   while(1) {
    $10 = ((($$024$i$i)) + 16|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11>>>0)>($1>>>0);
    if ($12) {
     $13 = HEAP32[$$024$i$i>>2]|0;
     $14 = ($13|0)==(0|0);
     if ($14) {
      label = 6;
      break;
     } else {
      $$0$ph$i$i = $$024$i$i;$$in$i$i = $13;
     }
    } else {
     $15 = ($11>>>0)<($1>>>0);
     if (!($15)) {
      label = 10;
      break;
     }
     $16 = ((($$024$i$i)) + 4|0);
     $17 = HEAP32[$16>>2]|0;
     $18 = ($17|0)==(0|0);
     if ($18) {
      label = 9;
      break;
     } else {
      $$0$ph$i$i = $16;$$in$i$i = $17;
     }
    }
    $$0$i$i = $$0$ph$i$i;$$024$i$i = $$in$i$i;$144 = $$in$i$i;
   }
   if ((label|0) == 6) {
    $$025$i53$i = $$024$i$i;$$03752$i = $$024$i$i;
    label = 13;
    break;
   }
   else if ((label|0) == 9) {
    $$025$i53$i = $16;$$03752$i = $$024$i$i;
    label = 13;
    break;
   }
   else if ((label|0) == 10) {
    $$025$i$i = $$0$i$i;$$037$i = $$024$i$i;$19 = $144;
    label = 12;
    break;
   }
  }
 } while(0);
 if ((label|0) == 12) {
  $20 = ($19|0)==(0|0);
  if ($20) {
   $$025$i53$i = $$025$i$i;$$03752$i = $$037$i;
   label = 13;
  } else {
   $$014$i = $19;
  }
 }
 if ((label|0) == 13) {
  $21 = (__Znwj(32)|0);
  $22 = ((($21)) + 16|0);
  HEAP32[$22>>2] = $1;
  $23 = ((($21)) + 20|0);
  HEAP32[$23>>2] = 0;
  $24 = ((($21)) + 24|0);
  HEAP32[$24>>2] = 0;
  $25 = ((($21)) + 28|0);
  HEAP32[$25>>2] = 0;
  HEAP32[$21>>2] = 0;
  $26 = ((($21)) + 4|0);
  HEAP32[$26>>2] = 0;
  $27 = ((($21)) + 8|0);
  HEAP32[$27>>2] = $$03752$i;
  HEAP32[$$025$i53$i>>2] = $21;
  $28 = HEAP32[$5>>2]|0;
  $29 = HEAP32[$28>>2]|0;
  $30 = ($29|0)==(0|0);
  if ($30) {
   $34 = $21;
  } else {
   $31 = $29;
   HEAP32[$5>>2] = $31;
   $$pre$i$i = HEAP32[$$025$i53$i>>2]|0;
   $34 = $$pre$i$i;
  }
  $32 = ((($0)) + 48|0);
  $33 = HEAP32[$32>>2]|0;
  __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($33,$34);
  $35 = ((($0)) + 52|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = (($36) + 1)|0;
  HEAP32[$35>>2] = $37;
  $$014$i = $21;
 }
 $38 = ((($$014$i)) + 20|0);
 $39 = ($3|0)==(0|0);
 if (!($39)) {
  $40 = ((($3)) + 8|0);
  $41 = HEAP32[$40>>2]|0;HEAP32[$40>>2] = (($41+1)|0);
 }
 $42 = ($2|0)==(0|0);
 if (!($42)) {
  $43 = ((($2)) + 8|0);
  $44 = HEAP32[$43>>2]|0;HEAP32[$43>>2] = (($44+1)|0);
 }
 HEAP32[$4>>2] = $3;
 if (!($39)) {
  $45 = ((($3)) + 8|0);
  $46 = HEAP32[$45>>2]|0;HEAP32[$45>>2] = (($46+1)|0);
 }
 $47 = ((($4)) + 4|0);
 HEAP32[$47>>2] = $2;
 if (!($42)) {
  $48 = ((($2)) + 8|0);
  $49 = HEAP32[$48>>2]|0;HEAP32[$48>>2] = (($49+1)|0);
 }
 $50 = ((($$014$i)) + 24|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = ((($$014$i)) + 28|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = ($51|0)==($53|0);
 do {
  if ($54) {
   __THREW__ = 0;
   invoke_vii(3655,($38|0),($4|0));
   $66 = __THREW__; __THREW__ = 0;
   $67 = $66&1;
   if ($67) {
    $105 = ___cxa_find_matching_catch_2()|0;
    $106 = tempRet0;
    $107 = HEAP32[$47>>2]|0;
    $108 = ($107|0)==(0|0);
    if (!($108)) {
     $109 = ((($107)) + 8|0);
     $110 = HEAP32[$109>>2]|0;HEAP32[$109>>2] = (($110-1)|0);
     $111 = ($110|0)==(1);
     if ($111) {
      __THREW__ = 0;
      invoke_viii(3262,($107|0),1,1);
      $112 = __THREW__; __THREW__ = 0;
      $113 = $112&1;
      if ($113) {
       $121 = ___cxa_find_matching_catch_3(0|0)|0;
       $122 = tempRet0;
       $123 = HEAP32[$4>>2]|0;
       $124 = ($123|0)==(0|0);
       if (!($124)) {
        $125 = ((($123)) + 8|0);
        $126 = HEAP32[$125>>2]|0;HEAP32[$125>>2] = (($126-1)|0);
        $127 = ($126|0)==(1);
        if ($127) {
         __THREW__ = 0;
         invoke_viii(3262,($123|0),1,1);
         $128 = __THREW__; __THREW__ = 0;
         $129 = $128&1;
         if ($129) {
          $130 = ___cxa_find_matching_catch_3(0|0)|0;
          $131 = tempRet0;
          ___clang_call_terminate($130);
          // unreachable;
         }
        }
       }
       HEAP32[$4>>2] = 0;
       $eh$lpad$body12$indexZ2D = $121;
       ___clang_call_terminate($eh$lpad$body12$indexZ2D);
       // unreachable;
      }
     }
    }
    HEAP32[$47>>2] = 0;
    $114 = HEAP32[$4>>2]|0;
    $115 = ($114|0)==(0|0);
    if (!($115)) {
     $116 = ((($114)) + 8|0);
     $117 = HEAP32[$116>>2]|0;HEAP32[$116>>2] = (($117-1)|0);
     $118 = ($117|0)==(1);
     if ($118) {
      __THREW__ = 0;
      invoke_viii(3262,($114|0),1,1);
      $119 = __THREW__; __THREW__ = 0;
      $120 = $119&1;
      if ($120) {
       break;
      }
     }
    }
    HEAP32[$4>>2] = 0;
    $$0 = $106;$$04 = $105;
    label = 64;
   } else {
    label = 31;
   }
  } else {
   $55 = HEAP32[$4>>2]|0;
   HEAP32[$51>>2] = $55;
   $56 = ($55|0)==(0|0);
   if (!($56)) {
    $57 = ((($55)) + 8|0);
    $58 = HEAP32[$57>>2]|0;HEAP32[$57>>2] = (($58+1)|0);
   }
   $59 = ((($51)) + 4|0);
   $60 = HEAP32[$47>>2]|0;
   HEAP32[$59>>2] = $60;
   $61 = ($60|0)==(0|0);
   if (!($61)) {
    $62 = ((($60)) + 8|0);
    $63 = HEAP32[$62>>2]|0;HEAP32[$62>>2] = (($63+1)|0);
   }
   $64 = HEAP32[$50>>2]|0;
   $65 = ((($64)) + 8|0);
   HEAP32[$50>>2] = $65;
   label = 31;
  }
 } while(0);
 L60: do {
  if ((label|0) == 31) {
   $68 = HEAP32[$47>>2]|0;
   $69 = ($68|0)==(0|0);
   if ($69) {
    label = 34;
   } else {
    $70 = ((($68)) + 8|0);
    $71 = HEAP32[$70>>2]|0;HEAP32[$70>>2] = (($71-1)|0);
    $72 = ($71|0)==(1);
    if ($72) {
     __THREW__ = 0;
     invoke_viii(3262,($68|0),1,1);
     $73 = __THREW__; __THREW__ = 0;
     $74 = $73&1;
     if ($74) {
      $82 = ___cxa_find_matching_catch_2()|0;
      $83 = tempRet0;
      $84 = HEAP32[$4>>2]|0;
      $85 = ($84|0)==(0|0);
      if (!($85)) {
       $86 = ((($84)) + 8|0);
       $87 = HEAP32[$86>>2]|0;HEAP32[$86>>2] = (($87-1)|0);
       $88 = ($87|0)==(1);
       if ($88) {
        __THREW__ = 0;
        invoke_viii(3262,($84|0),1,1);
        $89 = __THREW__; __THREW__ = 0;
        $90 = $89&1;
        if ($90) {
         $91 = ___cxa_find_matching_catch_3(0|0)|0;
         $92 = tempRet0;
         ___clang_call_terminate($91);
         // unreachable;
        }
       }
      }
      HEAP32[$4>>2] = 0;
      $eh$lpad$body$index2Z2D = $83;$eh$lpad$body$indexZ2D = $82;
     } else {
      label = 34;
     }
    } else {
     label = 34;
    }
   }
   do {
    if ((label|0) == 34) {
     HEAP32[$47>>2] = 0;
     $75 = HEAP32[$4>>2]|0;
     $76 = ($75|0)==(0|0);
     if (!($76)) {
      $77 = ((($75)) + 8|0);
      $78 = HEAP32[$77>>2]|0;HEAP32[$77>>2] = (($78-1)|0);
      $79 = ($78|0)==(1);
      if ($79) {
       __THREW__ = 0;
       invoke_viii(3262,($75|0),1,1);
       $80 = __THREW__; __THREW__ = 0;
       $81 = $80&1;
       if ($81) {
        $103 = ___cxa_find_matching_catch_2()|0;
        $104 = tempRet0;
        $eh$lpad$body$index2Z2D = $104;$eh$lpad$body$indexZ2D = $103;
        break;
       }
      }
     }
     HEAP32[$4>>2] = 0;
     if (!($42)) {
      $93 = ((($2)) + 8|0);
      $94 = HEAP32[$93>>2]|0;HEAP32[$93>>2] = (($94-1)|0);
      $95 = ($94|0)==(1);
      if ($95) {
       __THREW__ = 0;
       invoke_viii(3262,($2|0),1,1);
       $96 = __THREW__; __THREW__ = 0;
       $97 = $96&1;
       if ($97) {
        $101 = ___cxa_find_matching_catch_2()|0;
        $102 = tempRet0;
        $$1 = $102;$$15 = $101;
        label = 67;
        break L60;
       }
      }
     }
     if ($39) {
      STACKTOP = sp;return;
     }
     $98 = ((($3)) + 8|0);
     $99 = HEAP32[$98>>2]|0;HEAP32[$98>>2] = (($99-1)|0);
     $100 = ($99|0)==(1);
     if (!($100)) {
      STACKTOP = sp;return;
     }
     __ZNK3osg10Referenced24signalObserversAndDeleteEbb($3,1,1);
     STACKTOP = sp;return;
    }
   } while(0);
   $$0 = $eh$lpad$body$index2Z2D;$$04 = $eh$lpad$body$indexZ2D;
   label = 64;
  }
 } while(0);
 if ((label|0) == 64) {
  if ($42) {
   $$1 = $$0;$$15 = $$04;
   label = 67;
  } else {
   $132 = ((($2)) + 8|0);
   $133 = HEAP32[$132>>2]|0;HEAP32[$132>>2] = (($133-1)|0);
   $134 = ($133|0)==(1);
   if ($134) {
    __THREW__ = 0;
    invoke_viii(3262,($2|0),1,1);
    $135 = __THREW__; __THREW__ = 0;
    $136 = $135&1;
    if (!($136)) {
     $$1 = $$0;$$15 = $$04;
     label = 67;
    }
   } else {
    $$1 = $$0;$$15 = $$04;
    label = 67;
   }
  }
 }
 if ((label|0) == 67) {
  if ($39) {
   ___resumeException($$15|0);
   // unreachable;
  }
  $137 = ((($3)) + 8|0);
  $138 = HEAP32[$137>>2]|0;HEAP32[$137>>2] = (($138-1)|0);
  $139 = ($138|0)==(1);
  if (!($139)) {
   ___resumeException($$15|0);
   // unreachable;
  }
  __THREW__ = 0;
  invoke_viii(3262,($3|0),1,1);
  $140 = __THREW__; __THREW__ = 0;
  $141 = $140&1;
  if (!($141)) {
   ___resumeException($$15|0);
   // unreachable;
  }
 }
 $142 = ___cxa_find_matching_catch_3(0|0)|0;
 $143 = tempRet0;
 $eh$lpad$body12$indexZ2D = $142;
 ___clang_call_terminate($eh$lpad$body12$indexZ2D);
 // unreachable;
}
function __ZN7osgUtil24PositionalStateContainer4drawERN3osg5StateERPNS_10RenderLeafEPKNS1_7MatrixdE($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0$i$i$i$i = 0, $$02876 = 0, $$03075 = 0, $$04$i = 0, $$23279 = 0, $$280 = 0, $$3 = 0, $$333 = 0, $$4 = 0, $$434 = 0, $$sroa$045$0101 = 0, $$sroa$056$0$be = 0, $$sroa$056$0102 = 0, $$sroa$066$0105 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0.0, $112 = 0, $113 = 0.0, $114 = 0, $115 = 0.0, $116 = 0, $117 = 0.0, $118 = 0, $119 = 0.0, $12 = 0, $120 = 0, $121 = 0.0, $122 = 0;
 var $123 = 0.0, $124 = 0, $125 = 0.0, $126 = 0, $127 = 0.0, $128 = 0, $129 = 0.0, $13 = 0, $130 = 0, $131 = 0.0, $132 = 0, $133 = 0.0, $134 = 0, $135 = 0.0, $136 = 0, $137 = 0.0, $138 = 0, $139 = 0.0, $14 = 0, $140 = 0;
 var $141 = 0.0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0.0, $155 = 0, $156 = 0.0, $157 = 0, $158 = 0.0, $159 = 0;
 var $16 = 0, $160 = 0.0, $161 = 0, $162 = 0.0, $163 = 0, $164 = 0.0, $165 = 0, $166 = 0.0, $167 = 0, $168 = 0.0, $169 = 0, $17 = 0, $170 = 0.0, $171 = 0, $172 = 0.0, $173 = 0, $174 = 0.0, $175 = 0, $176 = 0.0, $177 = 0;
 var $178 = 0.0, $179 = 0, $18 = 0, $180 = 0.0, $181 = 0, $182 = 0.0, $183 = 0, $184 = 0.0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0;
 var $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0;
 var $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0;
 var $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0.0, $249 = 0, $25 = 0;
 var $250 = 0.0, $251 = 0, $252 = 0.0, $253 = 0, $254 = 0.0, $255 = 0, $256 = 0.0, $257 = 0, $258 = 0.0, $259 = 0, $26 = 0, $260 = 0.0, $261 = 0, $262 = 0.0, $263 = 0, $264 = 0.0, $265 = 0, $266 = 0.0, $267 = 0, $268 = 0.0;
 var $269 = 0, $27 = 0, $270 = 0.0, $271 = 0, $272 = 0.0, $273 = 0, $274 = 0.0, $275 = 0, $276 = 0.0, $277 = 0, $278 = 0.0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0;
 var $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0.0, $297 = 0, $298 = 0.0, $299 = 0, $30 = 0, $300 = 0.0, $301 = 0, $302 = 0.0, $303 = 0, $304 = 0.0;
 var $305 = 0, $306 = 0.0, $307 = 0, $308 = 0.0, $309 = 0, $31 = 0, $310 = 0.0, $311 = 0, $312 = 0.0, $313 = 0, $314 = 0.0, $315 = 0, $316 = 0.0, $317 = 0, $318 = 0.0, $319 = 0, $32 = 0, $320 = 0.0, $321 = 0, $322 = 0.0;
 var $323 = 0, $324 = 0.0, $325 = 0, $326 = 0.0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0;
 var $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 272|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(272|0);
 $4 = sp + 128|0;
 $5 = sp + 256|0;
 $6 = sp;
 $7 = HEAP32[$2>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = ((($7)) + 12|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10|0)==(0|0);
  if (!($11)) {
   $$04$i = $10;
   while(1) {
    $12 = ((($$04$i)) + 16|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = ($13|0)==(0|0);
    if (!($14)) {
     __ZN3osg5State11popStateSetEv($1);
    }
    $15 = ((($$04$i)) + 12|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = ($16|0)==(0|0);
    if ($17) {
     break;
    } else {
     $$04$i = $16;
    }
   }
  }
  __ZN3osg5State5applyEv($1);
  HEAP32[$2>>2] = 0;
 }
 $18 = ((($0)) + 32|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ((($0)) + 36|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($19|0)==($21|0);
 L11: do {
  if (!($22)) {
   $23 = ($3|0)==(0|0);
   $24 = ((($3)) + 8|0);
   $25 = ((($3)) + 16|0);
   $26 = ((($3)) + 24|0);
   $27 = ((($3)) + 32|0);
   $28 = ((($3)) + 40|0);
   $29 = ((($3)) + 48|0);
   $30 = ((($3)) + 56|0);
   $31 = ((($3)) + 64|0);
   $32 = ((($3)) + 72|0);
   $33 = ((($3)) + 80|0);
   $34 = ((($3)) + 88|0);
   $35 = ((($3)) + 96|0);
   $36 = ((($3)) + 104|0);
   $37 = ((($3)) + 112|0);
   $38 = ((($3)) + 120|0);
   $39 = ((($4)) + 8|0);
   $40 = ((($4)) + 16|0);
   $41 = ((($4)) + 24|0);
   $42 = ((($4)) + 32|0);
   $43 = ((($4)) + 40|0);
   $44 = ((($4)) + 48|0);
   $45 = ((($4)) + 56|0);
   $46 = ((($4)) + 64|0);
   $47 = ((($4)) + 72|0);
   $48 = ((($4)) + 80|0);
   $49 = ((($4)) + 88|0);
   $50 = ((($4)) + 96|0);
   $51 = ((($4)) + 104|0);
   $52 = ((($4)) + 112|0);
   $53 = ((($4)) + 120|0);
   $$sroa$066$0105 = $19;
   L13: while(1) {
    $94 = ((($$sroa$066$0105)) + 4|0);
    $95 = HEAP32[$94>>2]|0;
    do {
     if ($23) {
      __ZN3osg5State20applyModelViewMatrixEPKNS_10RefMatrixdE($1,$95);
     } else {
      $96 = ($95|0)==(0|0);
      $97 = (__Znwj(160)|0);
      if ($96) {
       __THREW__ = 0;
       invoke_vii(3435,($97|0),0);
       $149 = __THREW__; __THREW__ = 0;
       $150 = $149&1;
       if ($150) {
        label = 24;
        break L13;
       }
       $151 = ((($97)) + 12|0);
       ;HEAP32[$151>>2]=0|0;HEAP32[$151+4>>2]=0|0;HEAP32[$151+8>>2]=0|0;
       $152 = ((($97)) + 24|0);
       HEAP32[$152>>2] = 2;
       $153 = ((($97)) + 28|0);
       HEAP32[$153>>2] = 0;
       $154 = +HEAPF64[$3>>3];
       $155 = ((($97)) + 32|0);
       HEAPF64[$155>>3] = $154;
       $156 = +HEAPF64[$24>>3];
       $157 = ((($97)) + 40|0);
       HEAPF64[$157>>3] = $156;
       $158 = +HEAPF64[$25>>3];
       $159 = ((($97)) + 48|0);
       HEAPF64[$159>>3] = $158;
       $160 = +HEAPF64[$26>>3];
       $161 = ((($97)) + 56|0);
       HEAPF64[$161>>3] = $160;
       $162 = +HEAPF64[$27>>3];
       $163 = ((($97)) + 64|0);
       HEAPF64[$163>>3] = $162;
       $164 = +HEAPF64[$28>>3];
       $165 = ((($97)) + 72|0);
       HEAPF64[$165>>3] = $164;
       $166 = +HEAPF64[$29>>3];
       $167 = ((($97)) + 80|0);
       HEAPF64[$167>>3] = $166;
       $168 = +HEAPF64[$30>>3];
       $169 = ((($97)) + 88|0);
       HEAPF64[$169>>3] = $168;
       $170 = +HEAPF64[$31>>3];
       $171 = ((($97)) + 96|0);
       HEAPF64[$171>>3] = $170;
       $172 = +HEAPF64[$32>>3];
       $173 = ((($97)) + 104|0);
       HEAPF64[$173>>3] = $172;
       $174 = +HEAPF64[$33>>3];
       $175 = ((($97)) + 112|0);
       HEAPF64[$175>>3] = $174;
       $176 = +HEAPF64[$34>>3];
       $177 = ((($97)) + 120|0);
       HEAPF64[$177>>3] = $176;
       $178 = +HEAPF64[$35>>3];
       $179 = ((($97)) + 128|0);
       HEAPF64[$179>>3] = $178;
       $180 = +HEAPF64[$36>>3];
       $181 = ((($97)) + 136|0);
       HEAPF64[$181>>3] = $180;
       $182 = +HEAPF64[$37>>3];
       $183 = ((($97)) + 144|0);
       HEAPF64[$183>>3] = $182;
       $184 = +HEAPF64[$38>>3];
       $185 = ((($97)) + 152|0);
       HEAPF64[$185>>3] = $184;
       HEAP32[$97>>2] = (47588);
       __ZN3osg5State20applyModelViewMatrixEPKNS_10RefMatrixdE($1,$97);
       break;
      }
      $98 = HEAP32[$94>>2]|0;
      __THREW__ = 0;
      invoke_vi(3299,($4|0));
      $99 = __THREW__; __THREW__ = 0;
      $100 = $99&1;
      if ($100) {
       label = 19;
       break L13;
      }
      $101 = ((($98)) + 32|0);
      __THREW__ = 0;
      invoke_viii(3300,($4|0),($101|0),($3|0));
      $102 = __THREW__; __THREW__ = 0;
      $103 = $102&1;
      if ($103) {
       label = 19;
       break L13;
      }
      __THREW__ = 0;
      invoke_vii(3435,($97|0),0);
      $104 = __THREW__; __THREW__ = 0;
      $105 = $104&1;
      if ($105) {
       label = 16;
       break L13;
      }
      $108 = ((($97)) + 12|0);
      ;HEAP32[$108>>2]=0|0;HEAP32[$108+4>>2]=0|0;HEAP32[$108+8>>2]=0|0;
      $109 = ((($97)) + 24|0);
      HEAP32[$109>>2] = 2;
      $110 = ((($97)) + 28|0);
      HEAP32[$110>>2] = 0;
      $111 = +HEAPF64[$4>>3];
      $112 = ((($97)) + 32|0);
      HEAPF64[$112>>3] = $111;
      $113 = +HEAPF64[$39>>3];
      $114 = ((($97)) + 40|0);
      HEAPF64[$114>>3] = $113;
      $115 = +HEAPF64[$40>>3];
      $116 = ((($97)) + 48|0);
      HEAPF64[$116>>3] = $115;
      $117 = +HEAPF64[$41>>3];
      $118 = ((($97)) + 56|0);
      HEAPF64[$118>>3] = $117;
      $119 = +HEAPF64[$42>>3];
      $120 = ((($97)) + 64|0);
      HEAPF64[$120>>3] = $119;
      $121 = +HEAPF64[$43>>3];
      $122 = ((($97)) + 72|0);
      HEAPF64[$122>>3] = $121;
      $123 = +HEAPF64[$44>>3];
      $124 = ((($97)) + 80|0);
      HEAPF64[$124>>3] = $123;
      $125 = +HEAPF64[$45>>3];
      $126 = ((($97)) + 88|0);
      HEAPF64[$126>>3] = $125;
      $127 = +HEAPF64[$46>>3];
      $128 = ((($97)) + 96|0);
      HEAPF64[$128>>3] = $127;
      $129 = +HEAPF64[$47>>3];
      $130 = ((($97)) + 104|0);
      HEAPF64[$130>>3] = $129;
      $131 = +HEAPF64[$48>>3];
      $132 = ((($97)) + 112|0);
      HEAPF64[$132>>3] = $131;
      $133 = +HEAPF64[$49>>3];
      $134 = ((($97)) + 120|0);
      HEAPF64[$134>>3] = $133;
      $135 = +HEAPF64[$50>>3];
      $136 = ((($97)) + 128|0);
      HEAPF64[$136>>3] = $135;
      $137 = +HEAPF64[$51>>3];
      $138 = ((($97)) + 136|0);
      HEAPF64[$138>>3] = $137;
      $139 = +HEAPF64[$52>>3];
      $140 = ((($97)) + 144|0);
      HEAPF64[$140>>3] = $139;
      $141 = +HEAPF64[$53>>3];
      $142 = ((($97)) + 152|0);
      HEAPF64[$142>>3] = $141;
      HEAP32[$97>>2] = (47588);
      __THREW__ = 0;
      invoke_vii(3656,($1|0),($97|0));
      $143 = __THREW__; __THREW__ = 0;
      $144 = $143&1;
      if ($144) {
       label = 20;
       break L13;
      }
     }
    } while(0);
    $188 = HEAP32[$$sroa$066$0105>>2]|0;
    $189 = HEAP32[$188>>2]|0;
    $190 = ((($189)) + 172|0);
    $191 = HEAP32[$190>>2]|0;
    FUNCTION_TABLE_vii[$191 & 8191]($188,$1);
    $192 = HEAP32[$$sroa$066$0105>>2]|0;
    __ZN3osg5State20haveAppliedAttributeEPKNS_14StateAttributeE($1,$192);
    $193 = HEAP32[$$sroa$066$0105>>2]|0;
    __ZN3osg5State25setGlobalDefaultAttributeEPKNS_14StateAttributeE($1,$193);
    $194 = ((($$sroa$066$0105)) + 8|0);
    $195 = HEAP32[$20>>2]|0;
    $196 = ($194|0)==($195|0);
    if ($196) {
     break L11;
    } else {
     $$sroa$066$0105 = $194;
    }
   }
   if ((label|0) == 16) {
    $106 = ___cxa_find_matching_catch_2()|0;
    $107 = tempRet0;
    $$02876 = $107;$$03075 = $106;
   }
   else if ((label|0) == 19) {
    $145 = ___cxa_find_matching_catch_2()|0;
    $146 = tempRet0;
    $$02876 = $146;$$03075 = $145;
   }
   else if ((label|0) == 20) {
    $147 = ___cxa_find_matching_catch_2()|0;
    $148 = tempRet0;
    $$4 = $148;$$434 = $147;
    ___resumeException($$434|0);
    // unreachable;
   }
   else if ((label|0) == 24) {
    $186 = ___cxa_find_matching_catch_2()|0;
    $187 = tempRet0;
    __ZdlPv($97);
    $$4 = $187;$$434 = $186;
    ___resumeException($$434|0);
    // unreachable;
   }
   __ZdlPv($97);
   $$4 = $$02876;$$434 = $$03075;
   ___resumeException($$434|0);
   // unreachable;
  }
 } while(0);
 $54 = ((($0)) + 44|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = ((($0)) + 48|0);
 $57 = ($55|0)==($56|0);
 if ($57) {
  STACKTOP = sp;return;
 }
 $58 = ((($1)) + 688|0);
 $59 = ((($5)) + 4|0);
 $60 = ($3|0)==(0|0);
 $61 = ((($3)) + 8|0);
 $62 = ((($3)) + 16|0);
 $63 = ((($3)) + 24|0);
 $64 = ((($3)) + 32|0);
 $65 = ((($3)) + 40|0);
 $66 = ((($3)) + 48|0);
 $67 = ((($3)) + 56|0);
 $68 = ((($3)) + 64|0);
 $69 = ((($3)) + 72|0);
 $70 = ((($3)) + 80|0);
 $71 = ((($3)) + 88|0);
 $72 = ((($3)) + 96|0);
 $73 = ((($3)) + 104|0);
 $74 = ((($3)) + 112|0);
 $75 = ((($3)) + 120|0);
 $76 = ((($6)) + 8|0);
 $77 = ((($6)) + 16|0);
 $78 = ((($6)) + 24|0);
 $79 = ((($6)) + 32|0);
 $80 = ((($6)) + 40|0);
 $81 = ((($6)) + 48|0);
 $82 = ((($6)) + 56|0);
 $83 = ((($6)) + 64|0);
 $84 = ((($6)) + 72|0);
 $85 = ((($6)) + 80|0);
 $86 = ((($6)) + 88|0);
 $87 = ((($6)) + 96|0);
 $88 = ((($6)) + 104|0);
 $89 = ((($6)) + 112|0);
 $90 = ((($6)) + 120|0);
 $91 = ((($1)) + 728|0);
 $92 = ((($1)) + 716|0);
 $93 = ((($1)) + 720|0);
 $$sroa$056$0102 = $55;
 L40: while(1) {
  $197 = ((($$sroa$056$0102)) + 16|0);
  $198 = HEAP32[$197>>2]|0;
  $199 = HEAP32[$58>>2]|0;
  $200 = ($199|0)==($198|0);
  if (!($200)) {
   $201 = HEAP32[$91>>2]|0;
   $202 = ($201|0)==(0|0);
   if (!($202)) {
    $203 = HEAP32[$92>>2]|0;
    $204 = HEAP32[$93>>2]|0;
    $205 = ($203|0)>($204|0);
    $206 = $205 ? $203 : $204;
    $207 = ($206>>>0)>($198>>>0);
    if ($207) {
     $208 = (($198) + 33984)|0;
     FUNCTION_TABLE_vi[$201 & 8191]($208);
     HEAP32[$58>>2] = $198;
    }
   }
  }
  $209 = ((($$sroa$056$0102)) + 20|0);
  __ZNSt3__26vectorINS_4pairIN3osg7ref_ptrIKNS2_14StateAttributeEEENS3_INS2_10RefMatrixdEEEEENS_9allocatorIS9_EEEC2ERKSC_($5,$209);
  $210 = HEAP32[$5>>2]|0;
  $211 = HEAP32[$59>>2]|0;
  $212 = ($210|0)==($211|0);
  if (!($212)) {
   $$sroa$045$0101 = $210;
   while(1) {
    $229 = ((($$sroa$045$0101)) + 4|0);
    $230 = HEAP32[$229>>2]|0;
    do {
     if ($60) {
      __THREW__ = 0;
      invoke_vii(3656,($1|0),($230|0));
      $332 = __THREW__; __THREW__ = 0;
      $333 = $332&1;
      if ($333) {
       label = 48;
       break L40;
      }
     } else {
      $231 = ($230|0)==(0|0);
      if ($231) {
       __THREW__ = 0;
       $288 = (invoke_ii(3276,160)|0);
       $289 = __THREW__; __THREW__ = 0;
       $290 = $289&1;
       if ($290) {
        label = 48;
        break L40;
       }
       __THREW__ = 0;
       invoke_vii(3435,($288|0),0);
       $291 = __THREW__; __THREW__ = 0;
       $292 = $291&1;
       if ($292) {
        label = 55;
        break L40;
       }
       $293 = ((($288)) + 12|0);
       ;HEAP32[$293>>2]=0|0;HEAP32[$293+4>>2]=0|0;HEAP32[$293+8>>2]=0|0;
       $294 = ((($288)) + 24|0);
       HEAP32[$294>>2] = 2;
       $295 = ((($288)) + 28|0);
       HEAP32[$295>>2] = 0;
       $296 = +HEAPF64[$3>>3];
       $297 = ((($288)) + 32|0);
       HEAPF64[$297>>3] = $296;
       $298 = +HEAPF64[$61>>3];
       $299 = ((($288)) + 40|0);
       HEAPF64[$299>>3] = $298;
       $300 = +HEAPF64[$62>>3];
       $301 = ((($288)) + 48|0);
       HEAPF64[$301>>3] = $300;
       $302 = +HEAPF64[$63>>3];
       $303 = ((($288)) + 56|0);
       HEAPF64[$303>>3] = $302;
       $304 = +HEAPF64[$64>>3];
       $305 = ((($288)) + 64|0);
       HEAPF64[$305>>3] = $304;
       $306 = +HEAPF64[$65>>3];
       $307 = ((($288)) + 72|0);
       HEAPF64[$307>>3] = $306;
       $308 = +HEAPF64[$66>>3];
       $309 = ((($288)) + 80|0);
       HEAPF64[$309>>3] = $308;
       $310 = +HEAPF64[$67>>3];
       $311 = ((($288)) + 88|0);
       HEAPF64[$311>>3] = $310;
       $312 = +HEAPF64[$68>>3];
       $313 = ((($288)) + 96|0);
       HEAPF64[$313>>3] = $312;
       $314 = +HEAPF64[$69>>3];
       $315 = ((($288)) + 104|0);
       HEAPF64[$315>>3] = $314;
       $316 = +HEAPF64[$70>>3];
       $317 = ((($288)) + 112|0);
       HEAPF64[$317>>3] = $316;
       $318 = +HEAPF64[$71>>3];
       $319 = ((($288)) + 120|0);
       HEAPF64[$319>>3] = $318;
       $320 = +HEAPF64[$72>>3];
       $321 = ((($288)) + 128|0);
       HEAPF64[$321>>3] = $320;
       $322 = +HEAPF64[$73>>3];
       $323 = ((($288)) + 136|0);
       HEAPF64[$323>>3] = $322;
       $324 = +HEAPF64[$74>>3];
       $325 = ((($288)) + 144|0);
       HEAPF64[$325>>3] = $324;
       $326 = +HEAPF64[$75>>3];
       $327 = ((($288)) + 152|0);
       HEAPF64[$327>>3] = $326;
       HEAP32[$288>>2] = (47588);
       __THREW__ = 0;
       invoke_vii(3656,($1|0),($288|0));
       $328 = __THREW__; __THREW__ = 0;
       $329 = $328&1;
       if ($329) {
        label = 48;
        break L40;
       } else {
        break;
       }
      }
      __THREW__ = 0;
      $232 = (invoke_ii(3276,160)|0);
      $233 = __THREW__; __THREW__ = 0;
      $234 = $233&1;
      if ($234) {
       label = 48;
       break L40;
      }
      $235 = HEAP32[$229>>2]|0;
      __THREW__ = 0;
      invoke_vi(3299,($6|0));
      $236 = __THREW__; __THREW__ = 0;
      $237 = $236&1;
      if ($237) {
       label = 49;
       break L40;
      }
      $238 = ((($235)) + 32|0);
      __THREW__ = 0;
      invoke_viii(3300,($6|0),($238|0),($3|0));
      $239 = __THREW__; __THREW__ = 0;
      $240 = $239&1;
      if ($240) {
       label = 49;
       break L40;
      }
      __THREW__ = 0;
      invoke_vii(3435,($232|0),0);
      $241 = __THREW__; __THREW__ = 0;
      $242 = $241&1;
      if ($242) {
       label = 45;
       break L40;
      }
      $245 = ((($232)) + 12|0);
      ;HEAP32[$245>>2]=0|0;HEAP32[$245+4>>2]=0|0;HEAP32[$245+8>>2]=0|0;
      $246 = ((($232)) + 24|0);
      HEAP32[$246>>2] = 2;
      $247 = ((($232)) + 28|0);
      HEAP32[$247>>2] = 0;
      $248 = +HEAPF64[$6>>3];
      $249 = ((($232)) + 32|0);
      HEAPF64[$249>>3] = $248;
      $250 = +HEAPF64[$76>>3];
      $251 = ((($232)) + 40|0);
      HEAPF64[$251>>3] = $250;
      $252 = +HEAPF64[$77>>3];
      $253 = ((($232)) + 48|0);
      HEAPF64[$253>>3] = $252;
      $254 = +HEAPF64[$78>>3];
      $255 = ((($232)) + 56|0);
      HEAPF64[$255>>3] = $254;
      $256 = +HEAPF64[$79>>3];
      $257 = ((($232)) + 64|0);
      HEAPF64[$257>>3] = $256;
      $258 = +HEAPF64[$80>>3];
      $259 = ((($232)) + 72|0);
      HEAPF64[$259>>3] = $258;
      $260 = +HEAPF64[$81>>3];
      $261 = ((($232)) + 80|0);
      HEAPF64[$261>>3] = $260;
      $262 = +HEAPF64[$82>>3];
      $263 = ((($232)) + 88|0);
      HEAPF64[$263>>3] = $262;
      $264 = +HEAPF64[$83>>3];
      $265 = ((($232)) + 96|0);
      HEAPF64[$265>>3] = $264;
      $266 = +HEAPF64[$84>>3];
      $267 = ((($232)) + 104|0);
      HEAPF64[$267>>3] = $266;
      $268 = +HEAPF64[$85>>3];
      $269 = ((($232)) + 112|0);
      HEAPF64[$269>>3] = $268;
      $270 = +HEAPF64[$86>>3];
      $271 = ((($232)) + 120|0);
      HEAPF64[$271>>3] = $270;
      $272 = +HEAPF64[$87>>3];
      $273 = ((($232)) + 128|0);
      HEAPF64[$273>>3] = $272;
      $274 = +HEAPF64[$88>>3];
      $275 = ((($232)) + 136|0);
      HEAPF64[$275>>3] = $274;
      $276 = +HEAPF64[$89>>3];
      $277 = ((($232)) + 144|0);
      HEAPF64[$277>>3] = $276;
      $278 = +HEAPF64[$90>>3];
      $279 = ((($232)) + 152|0);
      HEAPF64[$279>>3] = $278;
      HEAP32[$232>>2] = (47588);
      __THREW__ = 0;
      invoke_vii(3656,($1|0),($232|0));
      $280 = __THREW__; __THREW__ = 0;
      $281 = $280&1;
      if ($281) {
       label = 50;
       break L40;
      }
     }
    } while(0);
    $334 = HEAP32[$$sroa$045$0101>>2]|0;
    $335 = HEAP32[$334>>2]|0;
    $336 = ((($335)) + 172|0);
    $337 = HEAP32[$336>>2]|0;
    __THREW__ = 0;
    invoke_vii($337|0,($334|0),($1|0));
    $338 = __THREW__; __THREW__ = 0;
    $339 = $338&1;
    if ($339) {
     label = 48;
     break L40;
    }
    $340 = HEAP32[$197>>2]|0;
    $341 = HEAP32[$$sroa$045$0101>>2]|0;
    __THREW__ = 0;
    invoke_viii(3657,($1|0),($340|0),($341|0));
    $342 = __THREW__; __THREW__ = 0;
    $343 = $342&1;
    if ($343) {
     label = 48;
     break L40;
    }
    $344 = HEAP32[$197>>2]|0;
    $345 = HEAP32[$$sroa$045$0101>>2]|0;
    __THREW__ = 0;
    invoke_viii(3658,($1|0),($344|0),($345|0));
    $346 = __THREW__; __THREW__ = 0;
    $347 = $346&1;
    if ($347) {
     label = 48;
     break L40;
    }
    $348 = ((($$sroa$045$0101)) + 8|0);
    $349 = HEAP32[$59>>2]|0;
    $350 = ($348|0)==($349|0);
    if ($350) {
     break;
    } else {
     $$sroa$045$0101 = $348;
    }
   }
  }
  __ZNSt3__213__vector_baseINS_4pairIN3osg7ref_ptrIKNS2_14StateAttributeEEENS3_INS2_10RefMatrixdEEEEENS_9allocatorIS9_EEED2Ev($5);
  $213 = ((($$sroa$056$0102)) + 4|0);
  $214 = HEAP32[$213>>2]|0;
  $215 = ($214|0)==(0|0);
  if ($215) {
   $216 = ((($$sroa$056$0102)) + 8|0);
   $217 = HEAP32[$216>>2]|0;
   $218 = HEAP32[$217>>2]|0;
   $219 = ($218|0)==($$sroa$056$0102|0);
   if ($219) {
    $$sroa$056$0$be = $217;
   } else {
    $224 = $216;
    while(1) {
     $223 = HEAP32[$224>>2]|0;
     $225 = ((($223)) + 8|0);
     $226 = HEAP32[$225>>2]|0;
     $227 = HEAP32[$226>>2]|0;
     $228 = ($227|0)==($223|0);
     if ($228) {
      $$sroa$056$0$be = $226;
      break;
     } else {
      $224 = $225;
     }
    }
   }
  } else {
   $$0$i$i$i$i = $214;
   while(1) {
    $221 = HEAP32[$$0$i$i$i$i>>2]|0;
    $222 = ($221|0)==(0|0);
    if ($222) {
     break;
    } else {
     $$0$i$i$i$i = $221;
    }
   }
   $$sroa$056$0$be = $$0$i$i$i$i;
  }
  $220 = ($$sroa$056$0$be|0)==($56|0);
  if ($220) {
   label = 27;
   break;
  } else {
   $$sroa$056$0102 = $$sroa$056$0$be;
  }
 }
 if ((label|0) == 27) {
  STACKTOP = sp;return;
 }
 else if ((label|0) == 45) {
  $243 = ___cxa_find_matching_catch_2()|0;
  $244 = tempRet0;
  $$23279 = $243;$$280 = $244;
  label = 51;
 }
 else if ((label|0) == 48) {
  $282 = ___cxa_find_matching_catch_2()|0;
  $283 = tempRet0;
  $$3 = $283;$$333 = $282;
 }
 else if ((label|0) == 49) {
  $284 = ___cxa_find_matching_catch_2()|0;
  $285 = tempRet0;
  $$23279 = $284;$$280 = $285;
  label = 51;
 }
 else if ((label|0) == 50) {
  $286 = ___cxa_find_matching_catch_2()|0;
  $287 = tempRet0;
  $$3 = $287;$$333 = $286;
 }
 else if ((label|0) == 55) {
  $330 = ___cxa_find_matching_catch_2()|0;
  $331 = tempRet0;
  __ZdlPv($288);
  $$3 = $331;$$333 = $330;
 }
 if ((label|0) == 51) {
  __ZdlPv($232);
  $$3 = $$280;$$333 = $$23279;
 }
 __THREW__ = 0;
 invoke_vi(3654,($5|0));
 $351 = __THREW__; __THREW__ = 0;
 $352 = $351&1;
 if ($352) {
  $353 = ___cxa_find_matching_catch_3(0|0)|0;
  $354 = tempRet0;
  ___clang_call_terminate($353);
  // unreachable;
 }
 $$4 = $$3;$$434 = $$333;
 ___resumeException($$434|0);
 // unreachable;
}
function __ZN3osg5State25setGlobalDefaultAttributeEPKNS_14StateAttributeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i = 0, $$0$ph$i$i = 0, $$014$i = 0, $$024$i$i = 0, $$025$i$i = 0, $$025$i68$i = 0, $$052$i = 0, $$05267$i = 0, $$in$i$i = 0, $$pre$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 588|0);
 $3 = HEAP32[$1>>2]|0;
 $4 = ((($3)) + 148|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_ii[$5 & 8191]($1)|0);
 $7 = HEAP32[$1>>2]|0;
 $8 = ((($7)) + 152|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (FUNCTION_TABLE_ii[$9 & 8191]($1)|0);
 $11 = ((($0)) + 592|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0|0);
 do {
  if ($13) {
   $$025$i$i = $11;$$052$i = $11;$28 = $12;
   label = 14;
  } else {
   $14 = ((($0)) + 592|0);
   $$0$i$i = $14;$$024$i$i = $12;$60 = $12;
   L4: while(1) {
    $15 = ((($$024$i$i)) + 16|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = ($6|0)<($16|0);
    do {
     if ($17) {
      label = 7;
     } else {
      $18 = ($16|0)<($6|0);
      if (!($18)) {
       $19 = ((($$024$i$i)) + 20|0);
       $20 = HEAP32[$19>>2]|0;
       $21 = ($10>>>0)<($20>>>0);
       if ($21) {
        label = 7;
        break;
       }
       $24 = ($20>>>0)<($10>>>0);
       if (!($24)) {
        label = 12;
        break L4;
       }
      }
      $25 = ((($$024$i$i)) + 4|0);
      $26 = HEAP32[$25>>2]|0;
      $27 = ($26|0)==(0|0);
      if ($27) {
       label = 11;
       break L4;
      } else {
       $$0$ph$i$i = $25;$$in$i$i = $26;
      }
     }
    } while(0);
    if ((label|0) == 7) {
     label = 0;
     $22 = HEAP32[$$024$i$i>>2]|0;
     $23 = ($22|0)==(0|0);
     if ($23) {
      label = 8;
      break;
     } else {
      $$0$ph$i$i = $$024$i$i;$$in$i$i = $22;
     }
    }
    $$0$i$i = $$0$ph$i$i;$$024$i$i = $$in$i$i;$60 = $$in$i$i;
   }
   if ((label|0) == 8) {
    $$025$i68$i = $$024$i$i;$$05267$i = $$024$i$i;
    label = 15;
    break;
   }
   else if ((label|0) == 11) {
    $$025$i68$i = $25;$$05267$i = $$024$i$i;
    label = 15;
    break;
   }
   else if ((label|0) == 12) {
    $$025$i$i = $$0$i$i;$$052$i = $$024$i$i;$28 = $60;
    label = 14;
    break;
   }
  }
 } while(0);
 if ((label|0) == 14) {
  $29 = ($28|0)==(0|0);
  if ($29) {
   $$025$i68$i = $$025$i$i;$$05267$i = $$052$i;
   label = 15;
  } else {
   $$014$i = $28;
  }
 }
 if ((label|0) == 15) {
  $30 = (__Znwj(52)|0);
  $31 = ((($30)) + 16|0);
  $32 = $31;
  $33 = $32;
  HEAP32[$33>>2] = $6;
  $34 = (($32) + 4)|0;
  $35 = $34;
  HEAP32[$35>>2] = $10;
  $36 = ((($30)) + 24|0);
  HEAP8[$36>>0] = 0;
  $37 = ((($30)) + 28|0);
  ;HEAP32[$37>>2]=0|0;HEAP32[$37+4>>2]=0|0;HEAP32[$37+8>>2]=0|0;HEAP32[$37+12>>2]=0|0;HEAP32[$37+16>>2]=0|0;HEAP32[$37+20>>2]=0|0;
  HEAP32[$30>>2] = 0;
  $38 = ((($30)) + 4|0);
  HEAP32[$38>>2] = 0;
  $39 = ((($30)) + 8|0);
  HEAP32[$39>>2] = $$05267$i;
  HEAP32[$$025$i68$i>>2] = $30;
  $40 = HEAP32[$2>>2]|0;
  $41 = HEAP32[$40>>2]|0;
  $42 = ($41|0)==(0|0);
  if ($42) {
   $46 = $30;
  } else {
   $43 = $41;
   HEAP32[$2>>2] = $43;
   $$pre$i$i = HEAP32[$$025$i68$i>>2]|0;
   $46 = $$pre$i$i;
  }
  $44 = ((($0)) + 592|0);
  $45 = HEAP32[$44>>2]|0;
  __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($45,$46);
  $47 = ((($0)) + 596|0);
  $48 = HEAP32[$47>>2]|0;
  $49 = (($48) + 1)|0;
  HEAP32[$47>>2] = $49;
  $$014$i = $30;
 }
 $50 = ((($$014$i)) + 36|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = ($51|0)==($1|0);
 if ($52) {
  return;
 }
 HEAP32[$50>>2] = $1;
 $53 = ($1|0)==(0|0);
 if (!($53)) {
  $54 = ((($1)) + 8|0);
  $55 = HEAP32[$54>>2]|0;HEAP32[$54>>2] = (($55+1)|0);
 }
 $56 = ($51|0)==(0|0);
 if ($56) {
  return;
 }
 $57 = ((($51)) + 8|0);
 $58 = HEAP32[$57>>2]|0;HEAP32[$57>>2] = (($58-1)|0);
 $59 = ($58|0)==(1);
 if (!($59)) {
  return;
 }
 __ZNK3osg10Referenced24signalObserversAndDeleteEbb($51,1,1);
 return;
}
function __ZNSt3__26vectorINS_4pairIN3osg7ref_ptrIKNS2_14StateAttributeEEENS3_INS2_10RefMatrixdEEEEENS_9allocatorIS9_EEEC2ERKSC_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$07$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = 0;
 $2 = ((($0)) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = ((($0)) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$1>>2]|0;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 3;
 $9 = ($8|0)==(0);
 if ($9) {
  return;
 }
 $10 = ($8>>>0)>(536870911);
 if ($10) {
  __THREW__ = 0;
  invoke_vi(3307,($0|0));
  $11 = __THREW__; __THREW__ = 0;
 } else {
  __THREW__ = 0;
  $12 = (invoke_ii(3276,($7|0))|0);
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if (!($14)) {
   HEAP32[$2>>2] = $12;
   HEAP32[$0>>2] = $12;
   $15 = (($12) + ($8<<3)|0);
   $16 = ((($0)) + 8|0);
   HEAP32[$16>>2] = $15;
   $17 = HEAP32[$1>>2]|0;
   $18 = HEAP32[$4>>2]|0;
   $19 = ($17|0)==($18|0);
   if ($19) {
    return;
   }
   $$07$i$i = $17;$21 = $12;
   while(1) {
    $20 = HEAP32[$$07$i$i>>2]|0;
    HEAP32[$21>>2] = $20;
    $22 = ($20|0)==(0|0);
    if (!($22)) {
     $23 = ((($20)) + 8|0);
     $24 = HEAP32[$23>>2]|0;HEAP32[$23>>2] = (($24+1)|0);
    }
    $25 = ((($21)) + 4|0);
    $26 = ((($$07$i$i)) + 4|0);
    $27 = HEAP32[$26>>2]|0;
    HEAP32[$25>>2] = $27;
    $28 = ($27|0)==(0|0);
    if (!($28)) {
     $29 = ((($27)) + 8|0);
     $30 = HEAP32[$29>>2]|0;HEAP32[$29>>2] = (($30+1)|0);
    }
    $31 = ((($$07$i$i)) + 8|0);
    $32 = HEAP32[$2>>2]|0;
    $33 = ((($32)) + 8|0);
    HEAP32[$2>>2] = $33;
    $34 = ($31|0)==($18|0);
    if ($34) {
     break;
    } else {
     $$07$i$i = $31;$21 = $33;
    }
   }
   return;
  }
 }
 $35 = ___cxa_find_matching_catch_2()|0;
 $36 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3654,($0|0));
 $37 = __THREW__; __THREW__ = 0;
 $38 = $37&1;
 if ($38) {
  $39 = ___cxa_find_matching_catch_3(0|0)|0;
  $40 = tempRet0;
  ___clang_call_terminate($39);
  // unreachable;
 } else {
  ___resumeException($35|0);
  // unreachable;
 }
}
function __ZNSt3__213__vector_baseINS_4pairIN3osg7ref_ptrIKNS2_14StateAttributeEEENS3_INS2_10RefMatrixdEEEEENS_9allocatorIS9_EEED2Ev($0) {
 $0 = $0|0;
 var $$pre = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$i$i$indexZ2D = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 }
 $3 = ((($0)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==($1|0);
 do {
  if ($5) {
   $38 = $1;
  } else {
   $7 = $4;
   while(1) {
    $6 = ((($7)) + -8|0);
    HEAP32[$3>>2] = $6;
    $8 = ((($7)) + -4|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = ($9|0)==(0|0);
    if (!($10)) {
     $11 = ((($9)) + 8|0);
     $12 = HEAP32[$11>>2]|0;HEAP32[$11>>2] = (($12-1)|0);
     $13 = ($12|0)==(1);
     if ($13) {
      __THREW__ = 0;
      invoke_viii(3262,($9|0),1,1);
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if ($15) {
       label = 9;
       break;
      }
     }
    }
    HEAP32[$8>>2] = 0;
    $16 = HEAP32[$6>>2]|0;
    $17 = ($16|0)==(0|0);
    if (!($17)) {
     $18 = ((($16)) + 8|0);
     $19 = HEAP32[$18>>2]|0;HEAP32[$18>>2] = (($19-1)|0);
     $20 = ($19|0)==(1);
     if ($20) {
      __THREW__ = 0;
      invoke_viii(3262,($16|0),1,1);
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if ($22) {
       label = 15;
       break;
      }
     }
    }
    HEAP32[$6>>2] = 0;
    $34 = HEAP32[$3>>2]|0;
    $35 = ($34|0)==($1|0);
    if ($35) {
     label = 17;
     break;
    } else {
     $7 = $34;
    }
   }
   if ((label|0) == 9) {
    $23 = ___cxa_find_matching_catch_2()|0;
    $24 = tempRet0;
    $25 = HEAP32[$6>>2]|0;
    $26 = ($25|0)==(0|0);
    if (!($26)) {
     $27 = ((($25)) + 8|0);
     $28 = HEAP32[$27>>2]|0;HEAP32[$27>>2] = (($28-1)|0);
     $29 = ($28|0)==(1);
     if ($29) {
      __THREW__ = 0;
      invoke_viii(3262,($25|0),1,1);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       $32 = ___cxa_find_matching_catch_3(0|0)|0;
       $33 = tempRet0;
       ___clang_call_terminate($32);
       // unreachable;
      }
     }
    }
    HEAP32[$6>>2] = 0;
    $eh$lpad$body$i$i$indexZ2D = $23;
    ___cxa_call_unexpected(($eh$lpad$body$i$i$indexZ2D|0));
    // unreachable;
   }
   else if ((label|0) == 15) {
    $36 = ___cxa_find_matching_catch_2()|0;
    $37 = tempRet0;
    $eh$lpad$body$i$i$indexZ2D = $36;
    ___cxa_call_unexpected(($eh$lpad$body$i$i$indexZ2D|0));
    // unreachable;
   }
   else if ((label|0) == 17) {
    $$pre = HEAP32[$0>>2]|0;
    $38 = $$pre;
    break;
   }
  }
 } while(0);
 __ZdlPv($38);
 return;
}
function __ZN3osg5State32setGlobalDefaultTextureAttributeEjPKNS_14StateAttributeE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$i$i = 0, $$0$ph$i$i = 0, $$014$i = 0, $$024$i$i = 0, $$025$i$i = 0, $$025$i68$i = 0, $$052$i = 0, $$05267$i = 0, $$in$i$i = 0, $$pre$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 652|0);
 $4 = ((($0)) + 656|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$3>>2]|0;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 12)&-1;
 $9 = ($8>>>0)>($1>>>0);
 do {
  if (!($9)) {
   $10 = (($1) + 1)|0;
   $11 = ($10>>>0)>($8>>>0);
   $12 = $6;
   $13 = $5;
   if ($11) {
    $14 = (($10) - ($8))|0;
    __ZNSt3__26vectorINS_3mapINS_4pairIN3osg14StateAttribute4TypeEjEENS3_5State14AttributeStackENS_4lessIS6_EENS_9allocatorINS2_IKS6_S8_EEEEEENSB_ISF_EEE8__appendEj($3,$14);
    break;
   }
   $15 = ($10>>>0)<($8>>>0);
   if ($15) {
    $16 = (($12) + (($10*12)|0)|0);
    $17 = ($13|0)==($16|0);
    if (!($17)) {
     $19 = $13;
     while(1) {
      $18 = ((($19)) + -12|0);
      HEAP32[$4>>2] = $18;
      $20 = ((($19)) + -8|0);
      $21 = HEAP32[$20>>2]|0;
      __ZNSt3__26__treeINS_12__value_typeINS_4pairIN3osg14StateAttribute4TypeEjEENS3_5State14AttributeStackEEENS_19__map_value_compareIS6_S9_NS_4lessIS6_EELb1EEENS_9allocatorIS9_EEE7destroyEPNS_11__tree_nodeIS9_PvEE($18,$21);
      $22 = HEAP32[$4>>2]|0;
      $23 = ($22|0)==($16|0);
      if ($23) {
       break;
      } else {
       $19 = $22;
      }
     }
    }
   }
  }
 } while(0);
 $24 = HEAP32[$3>>2]|0;
 $25 = (($24) + (($1*12)|0)|0);
 $26 = HEAP32[$2>>2]|0;
 $27 = ((($26)) + 148|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (FUNCTION_TABLE_ii[$28 & 8191]($2)|0);
 $30 = HEAP32[$2>>2]|0;
 $31 = ((($30)) + 152|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (FUNCTION_TABLE_ii[$32 & 8191]($2)|0);
 $34 = (((($24) + (($1*12)|0)|0)) + 4|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = ($35|0)==(0|0);
 do {
  if ($36) {
   $$025$i$i = $34;$$052$i = $34;$51 = $35;
   label = 20;
  } else {
   $37 = (((($24) + (($1*12)|0)|0)) + 4|0);
   $$0$i$i = $37;$$024$i$i = $35;$83 = $35;
   L13: while(1) {
    $38 = ((($$024$i$i)) + 16|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = ($29|0)<($39|0);
    do {
     if ($40) {
      label = 13;
     } else {
      $41 = ($39|0)<($29|0);
      if (!($41)) {
       $42 = ((($$024$i$i)) + 20|0);
       $43 = HEAP32[$42>>2]|0;
       $44 = ($33>>>0)<($43>>>0);
       if ($44) {
        label = 13;
        break;
       }
       $47 = ($43>>>0)<($33>>>0);
       if (!($47)) {
        label = 18;
        break L13;
       }
      }
      $48 = ((($$024$i$i)) + 4|0);
      $49 = HEAP32[$48>>2]|0;
      $50 = ($49|0)==(0|0);
      if ($50) {
       label = 17;
       break L13;
      } else {
       $$0$ph$i$i = $48;$$in$i$i = $49;
      }
     }
    } while(0);
    if ((label|0) == 13) {
     label = 0;
     $45 = HEAP32[$$024$i$i>>2]|0;
     $46 = ($45|0)==(0|0);
     if ($46) {
      label = 14;
      break;
     } else {
      $$0$ph$i$i = $$024$i$i;$$in$i$i = $45;
     }
    }
    $$0$i$i = $$0$ph$i$i;$$024$i$i = $$in$i$i;$83 = $$in$i$i;
   }
   if ((label|0) == 14) {
    $$025$i68$i = $$024$i$i;$$05267$i = $$024$i$i;
    label = 21;
    break;
   }
   else if ((label|0) == 17) {
    $$025$i68$i = $48;$$05267$i = $$024$i$i;
    label = 21;
    break;
   }
   else if ((label|0) == 18) {
    $$025$i$i = $$0$i$i;$$052$i = $$024$i$i;$51 = $83;
    label = 20;
    break;
   }
  }
 } while(0);
 if ((label|0) == 20) {
  $52 = ($51|0)==(0|0);
  if ($52) {
   $$025$i68$i = $$025$i$i;$$05267$i = $$052$i;
   label = 21;
  } else {
   $$014$i = $51;
  }
 }
 if ((label|0) == 21) {
  $53 = (__Znwj(52)|0);
  $54 = ((($53)) + 16|0);
  $55 = $54;
  $56 = $55;
  HEAP32[$56>>2] = $29;
  $57 = (($55) + 4)|0;
  $58 = $57;
  HEAP32[$58>>2] = $33;
  $59 = ((($53)) + 24|0);
  HEAP8[$59>>0] = 0;
  $60 = ((($53)) + 28|0);
  ;HEAP32[$60>>2]=0|0;HEAP32[$60+4>>2]=0|0;HEAP32[$60+8>>2]=0|0;HEAP32[$60+12>>2]=0|0;HEAP32[$60+16>>2]=0|0;HEAP32[$60+20>>2]=0|0;
  HEAP32[$53>>2] = 0;
  $61 = ((($53)) + 4|0);
  HEAP32[$61>>2] = 0;
  $62 = ((($53)) + 8|0);
  HEAP32[$62>>2] = $$05267$i;
  HEAP32[$$025$i68$i>>2] = $53;
  $63 = HEAP32[$25>>2]|0;
  $64 = HEAP32[$63>>2]|0;
  $65 = ($64|0)==(0|0);
  if ($65) {
   $69 = $53;
  } else {
   $66 = $64;
   HEAP32[$25>>2] = $66;
   $$pre$i$i = HEAP32[$$025$i68$i>>2]|0;
   $69 = $$pre$i$i;
  }
  $67 = (((($24) + (($1*12)|0)|0)) + 4|0);
  $68 = HEAP32[$67>>2]|0;
  __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($68,$69);
  $70 = (((($24) + (($1*12)|0)|0)) + 8|0);
  $71 = HEAP32[$70>>2]|0;
  $72 = (($71) + 1)|0;
  HEAP32[$70>>2] = $72;
  $$014$i = $53;
 }
 $73 = ((($$014$i)) + 36|0);
 $74 = HEAP32[$73>>2]|0;
 $75 = ($74|0)==($2|0);
 if ($75) {
  return;
 }
 HEAP32[$73>>2] = $2;
 $76 = ($2|0)==(0|0);
 if (!($76)) {
  $77 = ((($2)) + 8|0);
  $78 = HEAP32[$77>>2]|0;HEAP32[$77>>2] = (($78+1)|0);
 }
 $79 = ($74|0)==(0|0);
 if ($79) {
  return;
 }
 $80 = ((($74)) + 8|0);
 $81 = HEAP32[$80>>2]|0;HEAP32[$80>>2] = (($81-1)|0);
 $82 = ($81|0)==(1);
 if (!($82)) {
  return;
 }
 __ZNK3osg10Referenced24signalObserversAndDeleteEbb($74,1,1);
 return;
}
function __ZNSt3__26vectorINS_4pairIN3osg7ref_ptrIKNS2_14StateAttributeEEENS3_INS2_10RefMatrixdEEEEENS_9allocatorIS9_EEE21__push_back_slow_pathIKS9_EEvRT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$06$i$i = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$phi11$iZ2D = 0, $$pre8$i = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $2 = sp;
 $3 = ((($0)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$0>>2]|0;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 3;
 $8 = (($7) + 1)|0;
 $9 = ($8>>>0)>(536870911);
 if ($9) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $10 = ((($0)) + 8|0);
 $11 = ((($0)) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) - ($5))|0;
 $14 = $13 >> 3;
 $15 = ($14>>>0)<(268435455);
 $16 = $13 >> 2;
 $17 = ($16>>>0)<($8>>>0);
 $$sroa$speculated$i = $17 ? $8 : $16;
 $$sroa$speculated$$i = $15 ? $$sroa$speculated$i : 536870911;
 $18 = ((($2)) + 12|0);
 HEAP32[$18>>2] = 0;
 $19 = ((($2)) + 16|0);
 HEAP32[$19>>2] = $10;
 $20 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($20) {
   $29 = 0;
  } else {
   $21 = ($$sroa$speculated$$i>>>0)>(536870911);
   if (!($21)) {
    $27 = $$sroa$speculated$$i << 3;
    $28 = (__Znwj($27)|0);
    $29 = $28;
    break;
   }
   $22 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($22|0),(204840|0));
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if ($24) {
    $25 = ___cxa_find_matching_catch_2()|0;
    $26 = tempRet0;
    ___cxa_free_exception(($22|0));
    ___resumeException($25|0);
    // unreachable;
   } else {
    HEAP32[$22>>2] = (99824);
    ___cxa_throw(($22|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 HEAP32[$2>>2] = $29;
 $30 = (($29) + ($7<<3)|0);
 $31 = ((($2)) + 8|0);
 HEAP32[$31>>2] = $30;
 $32 = ((($2)) + 4|0);
 HEAP32[$32>>2] = $30;
 $33 = (($29) + ($$sroa$speculated$$i<<3)|0);
 $34 = ((($2)) + 12|0);
 HEAP32[$34>>2] = $33;
 $35 = HEAP32[$1>>2]|0;
 HEAP32[$30>>2] = $35;
 $36 = ($35|0)==(0|0);
 if (!($36)) {
  $37 = ((($35)) + 8|0);
  $38 = HEAP32[$37>>2]|0;HEAP32[$37>>2] = (($38+1)|0);
 }
 $39 = (((($29) + ($7<<3)|0)) + 4|0);
 $40 = ((($1)) + 4|0);
 $41 = HEAP32[$40>>2]|0;
 HEAP32[$39>>2] = $41;
 $42 = ($41|0)==(0|0);
 if (!($42)) {
  $43 = ((($41)) + 8|0);
  $44 = HEAP32[$43>>2]|0;HEAP32[$43>>2] = (($44+1)|0);
 }
 $45 = HEAP32[$31>>2]|0;
 $46 = ((($45)) + 8|0);
 HEAP32[$31>>2] = $46;
 $47 = HEAP32[$0>>2]|0;
 $48 = HEAP32[$3>>2]|0;
 $49 = ($48|0)==($47|0);
 if ($49) {
  $50 = $48;
  $51 = $47;
  $$pre8$i = HEAP32[$32>>2]|0;
  $$pre$phi11$iZ2D = $32;$69 = $$pre8$i;$70 = $51;$72 = $50;
  HEAP32[$0>>2] = $69;
  HEAP32[$$pre$phi11$iZ2D>>2] = $70;
  $71 = HEAP32[$31>>2]|0;
  HEAP32[$3>>2] = $71;
  HEAP32[$31>>2] = $72;
  $73 = HEAP32[$11>>2]|0;
  $74 = HEAP32[$34>>2]|0;
  HEAP32[$11>>2] = $74;
  HEAP32[$34>>2] = $73;
  $75 = HEAP32[$$pre$phi11$iZ2D>>2]|0;
  HEAP32[$2>>2] = $75;
  __ZNSt3__214__split_bufferINS_4pairIN3osg7ref_ptrIKNS2_14StateAttributeEEENS3_INS2_10RefMatrixdEEEEERNS_9allocatorIS9_EEED2Ev($2);
  STACKTOP = sp;return;
 }
 $$pre$i$i = HEAP32[$32>>2]|0;
 $$06$i$i = $48;$54 = $$pre$i$i;
 while(1) {
  $52 = ((($$06$i$i)) + -8|0);
  $53 = ((($54)) + -8|0);
  $55 = HEAP32[$52>>2]|0;
  HEAP32[$53>>2] = $55;
  $56 = ($55|0)==(0|0);
  if (!($56)) {
   $57 = ((($55)) + 8|0);
   $58 = HEAP32[$57>>2]|0;HEAP32[$57>>2] = (($58+1)|0);
  }
  $59 = ((($54)) + -4|0);
  $60 = ((($$06$i$i)) + -4|0);
  $61 = HEAP32[$60>>2]|0;
  HEAP32[$59>>2] = $61;
  $62 = ($61|0)==(0|0);
  if (!($62)) {
   $63 = ((($61)) + 8|0);
   $64 = HEAP32[$63>>2]|0;HEAP32[$63>>2] = (($64+1)|0);
  }
  $65 = HEAP32[$32>>2]|0;
  $66 = ((($65)) + -8|0);
  HEAP32[$32>>2] = $66;
  $67 = ($52|0)==($47|0);
  if ($67) {
   break;
  } else {
   $$06$i$i = $52;$54 = $66;
  }
 }
 $68 = $66;
 $$pre$i = HEAP32[$0>>2]|0;
 $$pre = HEAP32[$3>>2]|0;
 $$pre$phi11$iZ2D = $32;$69 = $68;$70 = $$pre$i;$72 = $$pre;
 HEAP32[$0>>2] = $69;
 HEAP32[$$pre$phi11$iZ2D>>2] = $70;
 $71 = HEAP32[$31>>2]|0;
 HEAP32[$3>>2] = $71;
 HEAP32[$31>>2] = $72;
 $73 = HEAP32[$11>>2]|0;
 $74 = HEAP32[$34>>2]|0;
 HEAP32[$11>>2] = $74;
 HEAP32[$34>>2] = $73;
 $75 = HEAP32[$$pre$phi11$iZ2D>>2]|0;
 HEAP32[$2>>2] = $75;
 __ZNSt3__214__split_bufferINS_4pairIN3osg7ref_ptrIKNS2_14StateAttributeEEENS3_INS2_10RefMatrixdEEEEERNS_9allocatorIS9_EEED2Ev($2);
 STACKTOP = sp;return;
}
function __ZNSt3__214__split_bufferINS_4pairIN3osg7ref_ptrIKNS2_14StateAttributeEEENS3_INS2_10RefMatrixdEEEEERNS_9allocatorIS9_EEED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$i$i$i$indexZ2D = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==($2|0);
 L1: do {
  if (!($5)) {
   $7 = $4;
   while(1) {
    $6 = ((($7)) + -8|0);
    HEAP32[$3>>2] = $6;
    $8 = ((($7)) + -4|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = ($9|0)==(0|0);
    if (!($10)) {
     $11 = ((($9)) + 8|0);
     $12 = HEAP32[$11>>2]|0;HEAP32[$11>>2] = (($12-1)|0);
     $13 = ($12|0)==(1);
     if ($13) {
      __THREW__ = 0;
      invoke_viii(3262,($9|0),1,1);
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if ($15) {
       break;
      }
     }
    }
    HEAP32[$8>>2] = 0;
    $16 = HEAP32[$6>>2]|0;
    $17 = ($16|0)==(0|0);
    if (!($17)) {
     $18 = ((($16)) + 8|0);
     $19 = HEAP32[$18>>2]|0;HEAP32[$18>>2] = (($19-1)|0);
     $20 = ($19|0)==(1);
     if ($20) {
      __THREW__ = 0;
      invoke_viii(3262,($16|0),1,1);
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if ($22) {
       label = 14;
       break;
      }
     }
    }
    HEAP32[$6>>2] = 0;
    $34 = HEAP32[$3>>2]|0;
    $35 = ($34|0)==($2|0);
    if ($35) {
     break L1;
    } else {
     $7 = $34;
    }
   }
   if ((label|0) == 14) {
    $36 = ___cxa_find_matching_catch_2()|0;
    $37 = tempRet0;
    $eh$lpad$body$i$i$i$indexZ2D = $36;
    ___cxa_call_unexpected(($eh$lpad$body$i$i$i$indexZ2D|0));
    // unreachable;
   }
   $23 = ___cxa_find_matching_catch_2()|0;
   $24 = tempRet0;
   $25 = HEAP32[$6>>2]|0;
   $26 = ($25|0)==(0|0);
   if (!($26)) {
    $27 = ((($25)) + 8|0);
    $28 = HEAP32[$27>>2]|0;HEAP32[$27>>2] = (($28-1)|0);
    $29 = ($28|0)==(1);
    if ($29) {
     __THREW__ = 0;
     invoke_viii(3262,($25|0),1,1);
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      $32 = ___cxa_find_matching_catch_3(0|0)|0;
      $33 = tempRet0;
      ___clang_call_terminate($32);
      // unreachable;
     }
    }
   }
   HEAP32[$6>>2] = 0;
   $eh$lpad$body$i$i$i$indexZ2D = $23;
   ___cxa_call_unexpected(($eh$lpad$body$i$i$i$indexZ2D|0));
   // unreachable;
  }
 } while(0);
 $38 = HEAP32[$0>>2]|0;
 $39 = ($38|0)==(0|0);
 if ($39) {
  return;
 }
 __ZdlPv($38);
 return;
}
function __ZNSt3__26__treeINS_12__value_typeIjNS_6vectorINS_4pairIN3osg7ref_ptrIKNS4_14StateAttributeEEENS5_INS4_10RefMatrixdEEEEENS_9allocatorISB_EEEEEENS_19__map_value_compareIjSF_NS_4lessIjEELb1EEENSC_ISF_EEE7destroyEPNS_11__tree_nodeISF_PvEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 }
 $3 = HEAP32[$1>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIjNS_6vectorINS_4pairIN3osg7ref_ptrIKNS4_14StateAttributeEEENS5_INS4_10RefMatrixdEEEEENS_9allocatorISB_EEEEEENS_19__map_value_compareIjSF_NS_4lessIjEELb1EEENSC_ISF_EEE7destroyEPNS_11__tree_nodeISF_PvEE($0,$3);
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIjNS_6vectorINS_4pairIN3osg7ref_ptrIKNS4_14StateAttributeEEENS5_INS4_10RefMatrixdEEEEENS_9allocatorISB_EEEEEENS_19__map_value_compareIjSF_NS_4lessIjEELb1EEENSC_ISF_EEE7destroyEPNS_11__tree_nodeISF_PvEE($0,$5);
 $6 = ((($1)) + 20|0);
 __THREW__ = 0;
 invoke_vi(3654,($6|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch_2()|0;
  $10 = tempRet0;
  ___cxa_call_unexpected(($9|0));
  // unreachable;
 }
 __ZdlPv($1);
 return;
}
function __ZN7osgUtil24PositionalStateContainerC2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg10ReferencedC2Ev($0);
 $1 = ((($0)) + 12|0);
 ;HEAP32[$1>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;
 $2 = ((($0)) + 24|0);
 HEAP32[$2>>2] = 2;
 $3 = ((($0)) + 28|0);
 HEAP32[$3>>2] = 0;
 HEAP32[$0>>2] = (53812);
 $4 = ((($0)) + 32|0);
 HEAP32[$4>>2] = 0;
 $5 = ((($0)) + 36|0);
 HEAP32[$5>>2] = 0;
 $6 = ((($0)) + 40|0);
 HEAP32[$6>>2] = 0;
 $7 = ((($0)) + 48|0);
 HEAP32[$7>>2] = 0;
 $8 = ((($0)) + 52|0);
 HEAP32[$8>>2] = 0;
 $9 = ((($0)) + 48|0);
 $10 = ((($0)) + 44|0);
 HEAP32[$10>>2] = $9;
 return;
}
function __ZN7osgUtil9RenderBinD2Ev($0) {
 $0 = $0|0;
 var $$0 = 0, $$02 = 0, $$1 = 0, $$13 = 0, $1 = 0, $10 = 0, $100 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i16 = 0, $scevgep$i$i$i21 = 0, $scevgep$i$i$i9 = 0, $scevgep5$i$i$i = 0, $scevgep5$i$i$i10 = 0, $scevgep5$i$i$i17 = 0, $scevgep5$i$i$i22 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (53976);
 $1 = ((($0)) + 96|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  label = 4;
 } else {
  $4 = ((($2)) + 8|0);
  $5 = HEAP32[$4>>2]|0;HEAP32[$4>>2] = (($5-1)|0);
  $6 = ($5|0)==(1);
  if ($6) {
   __THREW__ = 0;
   invoke_viii(3262,($2|0),1,1);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $50 = ___cxa_find_matching_catch_2()|0;
    $51 = tempRet0;
    $52 = ((($0)) + 92|0);
    $53 = HEAP32[$52>>2]|0;
    $54 = ($53|0)==(0|0);
    if (!($54)) {
     $55 = ((($53)) + 8|0);
     $56 = HEAP32[$55>>2]|0;HEAP32[$55>>2] = (($56-1)|0);
     $57 = ($56|0)==(1);
     if ($57) {
      __THREW__ = 0;
      invoke_viii(3262,($53|0),1,1);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       $99 = ___cxa_find_matching_catch_3(0|0)|0;
       $100 = tempRet0;
       ___clang_call_terminate($99);
       // unreachable;
      }
     }
    }
    HEAP32[$52>>2] = 0;
    $$0 = $51;$$02 = $50;
    label = 25;
   } else {
    label = 4;
   }
  } else {
   label = 4;
  }
 }
 do {
  if ((label|0) == 4) {
   HEAP32[$1>>2] = 0;
   $9 = ((($0)) + 92|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($10|0)==(0|0);
   if (!($11)) {
    $12 = ((($10)) + 8|0);
    $13 = HEAP32[$12>>2]|0;HEAP32[$12>>2] = (($13-1)|0);
    $14 = ($13|0)==(1);
    if ($14) {
     __THREW__ = 0;
     invoke_viii(3262,($10|0),1,1);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      $60 = ___cxa_find_matching_catch_2()|0;
      $61 = tempRet0;
      $$0 = $61;$$02 = $60;
      label = 25;
      break;
     }
    }
   }
   HEAP32[$9>>2] = 0;
   $17 = ((($0)) + 88|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = ($18|0)==(0|0);
   if (!($19)) {
    $20 = ((($18)) + 8|0);
    $21 = HEAP32[$20>>2]|0;HEAP32[$20>>2] = (($21-1)|0);
    $22 = ($21|0)==(1);
    if ($22) {
     __THREW__ = 0;
     invoke_viii(3262,($18|0),1,1);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      $62 = ___cxa_find_matching_catch_2()|0;
      $63 = tempRet0;
      $$1 = $63;$$13 = $62;
      break;
     }
    }
   }
   HEAP32[$17>>2] = 0;
   $25 = ((($0)) + 68|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = ($26|0)==(0|0);
   if (!($27)) {
    $28 = ((($0)) + 72|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = ($29|0)==($26|0);
    if (!($30)) {
     $scevgep$i$i$i = ((($29)) + -4|0);
     $31 = $scevgep$i$i$i;
     $32 = $26;
     $33 = (($31) - ($32))|0;
     $34 = $33 >>> 2;
     $35 = $34 ^ -1;
     $scevgep5$i$i$i = (($29) + ($35<<2)|0);
     HEAP32[$28>>2] = $scevgep5$i$i$i;
    }
    __ZdlPv($26);
   }
   $36 = ((($0)) + 56|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = ($37|0)==(0|0);
   if ($38) {
    $47 = ((($0)) + 44|0);
    $48 = ((($0)) + 48|0);
    $49 = HEAP32[$48>>2]|0;
    __ZNSt3__26__treeINS_12__value_typeIiN3osg7ref_ptrIN7osgUtil9RenderBinEEEEENS_19__map_value_compareIiS7_NS_4lessIiEELb1EEENS_9allocatorIS7_EEE7destroyEPNS_11__tree_nodeIS7_PvEE($47,$49);
    __ZN3osg6ObjectD2Ev($0);
    return;
   }
   $39 = ((($0)) + 60|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = ($40|0)==($37|0);
   if (!($41)) {
    $scevgep$i$i$i9 = ((($40)) + -4|0);
    $42 = $scevgep$i$i$i9;
    $43 = $37;
    $44 = (($42) - ($43))|0;
    $45 = $44 >>> 2;
    $46 = $45 ^ -1;
    $scevgep5$i$i$i10 = (($40) + ($46<<2)|0);
    HEAP32[$39>>2] = $scevgep5$i$i$i10;
   }
   __ZdlPv($37);
   $47 = ((($0)) + 44|0);
   $48 = ((($0)) + 48|0);
   $49 = HEAP32[$48>>2]|0;
   __ZNSt3__26__treeINS_12__value_typeIiN3osg7ref_ptrIN7osgUtil9RenderBinEEEEENS_19__map_value_compareIiS7_NS_4lessIiEELb1EEENS_9allocatorIS7_EEE7destroyEPNS_11__tree_nodeIS7_PvEE($47,$49);
   __ZN3osg6ObjectD2Ev($0);
   return;
  }
 } while(0);
 if ((label|0) == 25) {
  $64 = ((($0)) + 88|0);
  $65 = HEAP32[$64>>2]|0;
  $66 = ($65|0)==(0|0);
  if (!($66)) {
   $67 = ((($65)) + 8|0);
   $68 = HEAP32[$67>>2]|0;HEAP32[$67>>2] = (($68-1)|0);
   $69 = ($68|0)==(1);
   if ($69) {
    __THREW__ = 0;
    invoke_viii(3262,($65|0),1,1);
    $70 = __THREW__; __THREW__ = 0;
    $71 = $70&1;
    if ($71) {
     $99 = ___cxa_find_matching_catch_3(0|0)|0;
     $100 = tempRet0;
     ___clang_call_terminate($99);
     // unreachable;
    }
   }
  }
  HEAP32[$64>>2] = 0;
  $$1 = $$0;$$13 = $$02;
 }
 $72 = ((($0)) + 68|0);
 $73 = HEAP32[$72>>2]|0;
 $74 = ($73|0)==(0|0);
 if (!($74)) {
  $75 = ((($0)) + 72|0);
  $76 = HEAP32[$75>>2]|0;
  $77 = ($76|0)==($73|0);
  if (!($77)) {
   $scevgep$i$i$i16 = ((($76)) + -4|0);
   $78 = $scevgep$i$i$i16;
   $79 = $73;
   $80 = (($78) - ($79))|0;
   $81 = $80 >>> 2;
   $82 = $81 ^ -1;
   $scevgep5$i$i$i17 = (($76) + ($82<<2)|0);
   HEAP32[$75>>2] = $scevgep5$i$i$i17;
  }
  __ZdlPv($73);
 }
 $83 = ((($0)) + 56|0);
 $84 = HEAP32[$83>>2]|0;
 $85 = ($84|0)==(0|0);
 if (!($85)) {
  $86 = ((($0)) + 60|0);
  $87 = HEAP32[$86>>2]|0;
  $88 = ($87|0)==($84|0);
  if (!($88)) {
   $scevgep$i$i$i21 = ((($87)) + -4|0);
   $89 = $scevgep$i$i$i21;
   $90 = $84;
   $91 = (($89) - ($90))|0;
   $92 = $91 >>> 2;
   $93 = $92 ^ -1;
   $scevgep5$i$i$i22 = (($87) + ($93<<2)|0);
   HEAP32[$86>>2] = $scevgep5$i$i$i22;
  }
  __ZdlPv($84);
 }
 $94 = ((($0)) + 44|0);
 $95 = ((($0)) + 48|0);
 $96 = HEAP32[$95>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIiN3osg7ref_ptrIN7osgUtil9RenderBinEEEEENS_19__map_value_compareIiS7_NS_4lessIiEELb1EEENS_9allocatorIS7_EEE7destroyEPNS_11__tree_nodeIS7_PvEE($94,$96);
 __THREW__ = 0;
 invoke_vi(388,($0|0));
 $97 = __THREW__; __THREW__ = 0;
 $98 = $97&1;
 if ($98) {
  $99 = ___cxa_find_matching_catch_3(0|0)|0;
  $100 = tempRet0;
  ___clang_call_terminate($99);
  // unreachable;
 } else {
  ___resumeException($$13|0);
  // unreachable;
 }
}
function __ZN7osgUtil9RenderBinD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1385,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK7osgUtil9RenderBin9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(100)|0);
 __THREW__ = 0;
 invoke_vi(3282,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $19 = ___cxa_find_matching_catch_2()|0;
  $20 = tempRet0;
  __ZdlPv($1);
  ___resumeException($19|0);
  // unreachable;
 } else {
  $4 = ((($1)) + 12|0);
  ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;
  $5 = ((($1)) + 24|0);
  HEAP32[$5>>2] = 2;
  $6 = ((($1)) + 28|0);
  HEAP32[$6>>2] = 0;
  HEAP32[$1>>2] = (53976);
  $7 = ((($1)) + 48|0);
  HEAP32[$7>>2] = 0;
  $8 = ((($1)) + 52|0);
  HEAP32[$8>>2] = 0;
  $9 = ((($1)) + 44|0);
  HEAP32[$9>>2] = $7;
  $10 = ((($1)) + 56|0);
  $11 = ((($1)) + 88|0);
  HEAP32[$11>>2] = 0;
  $12 = ((($1)) + 92|0);
  HEAP32[$12>>2] = 0;
  $13 = ((($1)) + 96|0);
  HEAP32[$13>>2] = 0;
  $14 = ((($1)) + 32|0);
  HEAP32[$14>>2] = 0;
  $15 = ((($1)) + 36|0);
  HEAP32[$15>>2] = 0;
  $16 = ((($1)) + 40|0);
  HEAP32[$16>>2] = 0;
  ;HEAP32[$10>>2]=0|0;HEAP32[$10+4>>2]=0|0;HEAP32[$10+8>>2]=0|0;HEAP32[$10+12>>2]=0|0;HEAP32[$10+16>>2]=0|0;HEAP32[$10+20>>2]=0|0;HEAP8[$10+24>>0]=0|0;
  $17 = (__ZN7osgUtil9RenderBin27getDefaultRenderBinSortModeEv()|0);
  $18 = ((($1)) + 84|0);
  HEAP32[$18>>2] = $17;
  return ($1|0);
 }
 return (0)|0;
}
function __ZNK7osgUtil9RenderBin5cloneERKN3osg6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(100)|0);
 __THREW__ = 0;
 invoke_viii(3659,($2|0),($0|0),($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch_2()|0;
  $6 = tempRet0;
  __ZdlPv($2);
  ___resumeException($5|0);
  // unreachable;
 } else {
  return ($2|0);
 }
 return (0)|0;
}
function __ZNK7osgUtil9RenderBin12isSameKindAsEPKN3osg6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,22824,0)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK7osgUtil9RenderBin11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (116801|0);
}
function __ZNK7osgUtil9RenderBin9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (116791|0);
}
function __ZNK7osgUtil9RenderBin16releaseGLObjectsEPN3osg5StateE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i$i$i = 0, $$sroa$04$0$be = 0, $$sroa$04$08 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 96|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = HEAP32[$3>>2]|0;
  $6 = ((($5)) + 136|0);
  $7 = HEAP32[$6>>2]|0;
  FUNCTION_TABLE_vii[$7 & 8191]($3,$1);
 }
 $8 = ((($0)) + 44|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($0)) + 48|0);
 $11 = ($9|0)==($10|0);
 if ($11) {
  return;
 } else {
  $$sroa$04$08 = $9;
 }
 while(1) {
  $12 = ((($$sroa$04$08)) + 20|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = HEAP32[$13>>2]|0;
  $15 = ((($14)) + 136|0);
  $16 = HEAP32[$15>>2]|0;
  FUNCTION_TABLE_vii[$16 & 8191]($13,$1);
  $17 = ((($$sroa$04$08)) + 4|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = ($18|0)==(0|0);
  if ($19) {
   $20 = ((($$sroa$04$08)) + 8|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = HEAP32[$21>>2]|0;
   $23 = ($22|0)==($$sroa$04$08|0);
   if ($23) {
    $$sroa$04$0$be = $21;
   } else {
    $28 = $20;
    while(1) {
     $27 = HEAP32[$28>>2]|0;
     $29 = ((($27)) + 8|0);
     $30 = HEAP32[$29>>2]|0;
     $31 = HEAP32[$30>>2]|0;
     $32 = ($31|0)==($27|0);
     if ($32) {
      $$sroa$04$0$be = $30;
      break;
     } else {
      $28 = $29;
     }
    }
   }
  } else {
   $$0$i$i$i$i = $18;
   while(1) {
    $25 = HEAP32[$$0$i$i$i$i>>2]|0;
    $26 = ($25|0)==(0|0);
    if ($26) {
     break;
    } else {
     $$0$i$i$i$i = $25;
    }
   }
   $$sroa$04$0$be = $$0$i$i$i$i;
  }
  $24 = ($$sroa$04$0$be|0)==($10|0);
  if ($24) {
   break;
  } else {
   $$sroa$04$08 = $$sroa$04$0$be;
  }
 }
 return;
}
function __ZN7osgUtil9RenderBin5resetEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i1 = 0, $scevgep5$i$i$i = 0, $scevgep5$i$i$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 56|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==($2|0);
 if (!($5)) {
  $scevgep$i$i$i = ((($4)) + -4|0);
  $6 = $scevgep$i$i$i;
  $7 = $2;
  $8 = (($6) - ($7))|0;
  $9 = $8 >>> 2;
  $10 = $9 ^ -1;
  $scevgep5$i$i$i = (($4) + ($10<<2)|0);
  HEAP32[$3>>2] = $scevgep5$i$i$i;
 }
 $11 = ((($0)) + 68|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ((($0)) + 72|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==($12|0);
 if (!($15)) {
  $scevgep$i$i$i1 = ((($14)) + -4|0);
  $16 = $scevgep$i$i$i1;
  $17 = $12;
  $18 = (($16) - ($17))|0;
  $19 = $18 >>> 2;
  $20 = $19 ^ -1;
  $scevgep5$i$i$i2 = (($14) + ($20<<2)|0);
  HEAP32[$13>>2] = $scevgep5$i$i$i2;
 }
 $21 = ((($0)) + 44|0);
 $22 = ((($0)) + 48|0);
 $23 = HEAP32[$22>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIiN3osg7ref_ptrIN7osgUtil9RenderBinEEEEENS_19__map_value_compareIiS7_NS_4lessIiEELb1EEENS_9allocatorIS7_EEE7destroyEPNS_11__tree_nodeIS7_PvEE($21,$23);
 $24 = ((($0)) + 52|0);
 HEAP32[$24>>2] = 0;
 HEAP32[$21>>2] = $22;
 HEAP32[$22>>2] = 0;
 $25 = ((($0)) + 80|0);
 HEAP8[$25>>0] = 0;
 return;
}
function __ZN7osgUtil9RenderBin4sortEv($0) {
 $0 = $0|0;
 var $$0$i$i$i$i = 0, $$sroa$02$0$be = 0, $$sroa$02$06 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 80|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if (!($3)) {
  return;
 }
 $4 = ((($0)) + 44|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($0)) + 48|0);
 $7 = ($5|0)==($6|0);
 if (!($7)) {
  $$sroa$02$06 = $5;
  while(1) {
   $11 = ((($$sroa$02$06)) + 20|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = HEAP32[$12>>2]|0;
   $14 = ((($13)) + 144|0);
   $15 = HEAP32[$14>>2]|0;
   FUNCTION_TABLE_vi[$15 & 8191]($12);
   $16 = ((($$sroa$02$06)) + 4|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = ($17|0)==(0|0);
   if ($18) {
    $19 = ((($$sroa$02$06)) + 8|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = HEAP32[$20>>2]|0;
    $22 = ($21|0)==($$sroa$02$06|0);
    if ($22) {
     $$sroa$02$0$be = $20;
    } else {
     $27 = $19;
     while(1) {
      $26 = HEAP32[$27>>2]|0;
      $28 = ((($26)) + 8|0);
      $29 = HEAP32[$28>>2]|0;
      $30 = HEAP32[$29>>2]|0;
      $31 = ($30|0)==($26|0);
      if ($31) {
       $$sroa$02$0$be = $29;
       break;
      } else {
       $27 = $28;
      }
     }
    }
   } else {
    $$0$i$i$i$i = $17;
    while(1) {
     $24 = HEAP32[$$0$i$i$i$i>>2]|0;
     $25 = ($24|0)==(0|0);
     if ($25) {
      break;
     } else {
      $$0$i$i$i$i = $24;
     }
    }
    $$sroa$02$0$be = $$0$i$i$i$i;
   }
   $23 = ($$sroa$02$0$be|0)==($6|0);
   if ($23) {
    break;
   } else {
    $$sroa$02$06 = $$sroa$02$0$be;
   }
  }
 }
 $8 = ((($0)) + 88|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if ($10) {
  $35 = HEAP32[$0>>2]|0;
  $36 = ((($35)) + 148|0);
  $37 = HEAP32[$36>>2]|0;
  FUNCTION_TABLE_vi[$37 & 8191]($0);
 } else {
  $32 = HEAP32[$9>>2]|0;
  $33 = ((($32)) + 12|0);
  $34 = HEAP32[$33>>2]|0;
  FUNCTION_TABLE_vii[$34 & 8191]($9,$0);
 }
 HEAP8[$1>>0] = 1;
 return;
}
function __ZN7osgUtil9RenderBin18sortImplementationEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 84|0);
 $2 = HEAP32[$1>>2]|0;
 switch ($2|0) {
 case 0:  {
  $3 = HEAP32[$0>>2]|0;
  $4 = ((($3)) + 152|0);
  $5 = HEAP32[$4>>2]|0;
  FUNCTION_TABLE_vi[$5 & 8191]($0);
  return;
  break;
 }
 case 1:  {
  $6 = HEAP32[$0>>2]|0;
  $7 = ((($6)) + 156|0);
  $8 = HEAP32[$7>>2]|0;
  FUNCTION_TABLE_vi[$8 & 8191]($0);
  return;
  break;
 }
 case 2:  {
  $9 = HEAP32[$0>>2]|0;
  $10 = ((($9)) + 160|0);
  $11 = HEAP32[$10>>2]|0;
  FUNCTION_TABLE_vi[$11 & 8191]($0);
  return;
  break;
 }
 case 3:  {
  $12 = HEAP32[$0>>2]|0;
  $13 = ((($12)) + 164|0);
  $14 = HEAP32[$13>>2]|0;
  FUNCTION_TABLE_vi[$14 & 8191]($0);
  return;
  break;
 }
 case 4:  {
  $15 = HEAP32[$0>>2]|0;
  $16 = ((($15)) + 168|0);
  $17 = HEAP32[$16>>2]|0;
  FUNCTION_TABLE_vi[$17 & 8191]($0);
  return;
  break;
 }
 default: {
  return;
 }
 }
}
function __ZN7osgUtil9RenderBin11sortByStateEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN7osgUtil9RenderBin26sortByStateThenFrontToBackEv($0) {
 $0 = $0|0;
 var $$lcssa16 = 0, $$pre = 0, $$sink$i = 0, $$sink$in$in$i = 0, $$sroa$02$0$sink$i = 0, $$sroa$02$0$sink$ph$i = 0, $$sroa$05$017 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0.0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0.0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0.0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp + 8|0;
 $2 = sp;
 $3 = ((($0)) + 56|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 60|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4|0)==($6|0);
 if ($7) {
  $$lcssa16 = $4;$8 = $4;
  __ZNSt3__26__sortIR32StateGraphFrontToBackSortFunctorPPN7osgUtil10StateGraphEEEvT0_S7_T_($8,$$lcssa16,$1);
  STACKTOP = sp;return;
 }
 $$sroa$05$017 = $4;
 while(1) {
  $9 = HEAP32[$$sroa$05$017>>2]|0;
  $10 = ((($9)) + 36|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ((($9)) + 40|0);
  $13 = HEAP32[$12>>2]|0;
  __ZNSt3__26__sortIRN7osgUtil20LessDepthSortFunctorEPN3osg7ref_ptrINS1_10RenderLeafEEEEEvT0_S9_T_($11,$13,$2);
  $14 = HEAP32[$$sroa$05$017>>2]|0;
  $15 = ((($14)) + 52|0);
  $16 = +HEAPF32[$15>>2];
  $17 = $16 == 3.4028234663852886E+38;
  if ($17) {
   $18 = ((($14)) + 36|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ((($14)) + 40|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = ($19|0)==($21|0);
   if (!($22)) {
    $23 = HEAP32[$19>>2]|0;
    $24 = ((($23)) + 28|0);
    $$sink$in$in$i = $24;$$sroa$02$0$sink$ph$i = $19;
    L9: while(1) {
     $$sink$i = HEAP32[$$sink$in$in$i>>2]|0;
     $25 = (HEAP32[tempDoublePtr>>2]=$$sink$i,+HEAPF32[tempDoublePtr>>2]);
     $$sroa$02$0$sink$i = $$sroa$02$0$sink$ph$i;
     while(1) {
      $26 = ((($$sroa$02$0$sink$i)) + 4|0);
      $27 = ($26|0)==($21|0);
      if ($27) {
       break L9;
      }
      $28 = HEAP32[$26>>2]|0;
      $29 = ((($28)) + 28|0);
      $30 = +HEAPF32[$29>>2];
      $31 = $30 < $25;
      if ($31) {
       $$sink$in$in$i = $29;$$sroa$02$0$sink$ph$i = $26;
       continue L9;
      } else {
       $$sroa$02$0$sink$i = $26;
      }
     }
    }
    HEAP32[$15>>2] = $$sink$i;
   }
  }
  $32 = ((($$sroa$05$017)) + 4|0);
  $33 = HEAP32[$5>>2]|0;
  $34 = ($32|0)==($33|0);
  if ($34) {
   break;
  } else {
   $$sroa$05$017 = $32;
  }
 }
 $$pre = HEAP32[$3>>2]|0;
 $$lcssa16 = $32;$8 = $$pre;
 __ZNSt3__26__sortIR32StateGraphFrontToBackSortFunctorPPN7osgUtil10StateGraphEEEvT0_S7_T_($8,$$lcssa16,$1);
 STACKTOP = sp;return;
}
function __ZN7osgUtil9RenderBin15sortFrontToBackEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 __ZN7osgUtil9RenderBin44copyLeavesFromStateGraphListToRenderLeafListEv($0);
 $2 = ((($0)) + 68|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 72|0);
 $5 = HEAP32[$4>>2]|0;
 __ZNSt3__26__sortIR22FrontToBackSortFunctorPPN7osgUtil10RenderLeafEEEvT0_S7_T_($3,$5,$1);
 STACKTOP = sp;return;
}
function __ZN7osgUtil9RenderBin15sortBackToFrontEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 __ZN7osgUtil9RenderBin44copyLeavesFromStateGraphListToRenderLeafListEv($0);
 $2 = ((($0)) + 68|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 72|0);
 $5 = HEAP32[$4>>2]|0;
 __ZNSt3__26__sortIR22BackToFrontSortFunctorPPN7osgUtil10RenderLeafEEEvT0_S7_T_($3,$5,$1);
 STACKTOP = sp;return;
}
function __ZN7osgUtil9RenderBin18sortTraversalOrderEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 __ZN7osgUtil9RenderBin44copyLeavesFromStateGraphListToRenderLeafListEv($0);
 $2 = ((($0)) + 68|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 72|0);
 $5 = HEAP32[$4>>2]|0;
 __ZNSt3__26__sortIR21TraversalOrderFunctorPPN7osgUtil10RenderLeafEEEvT0_S7_T_($3,$5,$1);
 STACKTOP = sp;return;
}
function __ZN7osgUtil9RenderBin4drawERN3osg10RenderInfoERPNS_10RenderLeafE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 HEAP32[$3>>2] = $0;
 $4 = ((($1)) + 24|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($1)) + 28|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5|0)==($7|0);
 if ($8) {
  $12 = ((($1)) + 20|0);
  __ZNSt3__26vectorIPN7osgUtil9RenderBinENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_($12,$3);
 } else {
  $9 = $0;
  HEAP32[$5>>2] = $9;
  $10 = HEAP32[$4>>2]|0;
  $11 = ((($10)) + 4|0);
  HEAP32[$4>>2] = $11;
 }
 $13 = ((($0)) + 92|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(0|0);
 if ($15) {
  $19 = HEAP32[$0>>2]|0;
  $20 = ((($19)) + 176|0);
  $21 = HEAP32[$20>>2]|0;
  FUNCTION_TABLE_viii[$21 & 8191]($0,$1,$2);
  $22 = HEAP32[$4>>2]|0;
  $23 = ((($22)) + -4|0);
  HEAP32[$4>>2] = $23;
  STACKTOP = sp;return;
 } else {
  $16 = HEAP32[$14>>2]|0;
  $17 = ((($16)) + 12|0);
  $18 = HEAP32[$17>>2]|0;
  FUNCTION_TABLE_viiii[$18 & 8191]($14,$0,$1,$2);
  $22 = HEAP32[$4>>2]|0;
  $23 = ((($22)) + -4|0);
  HEAP32[$4>>2] = $23;
  STACKTOP = sp;return;
 }
}
function __ZN7osgUtil9RenderBin18drawImplementationERN3osg10RenderInfoERPNS_10RenderLeafE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$$neg = 0, $$0$$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i44 = 0, $$056$i = 0, $$07$i = 0, $$neg81 = 0, $$pre = 0, $$pre100 = 0, $$pre101 = 0, $$sroa$053$085 = 0, $$sroa$059$087 = 0, $$sroa$066$090 = 0, $$sroa$073$0$be = 0, $$sroa$073$0$lcssa = 0, $$sroa$073$093 = 0, $$sroa$073$1$be = 0, $$sroa$073$184 = 0, $10 = 0, $100 = 0;
 var $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $12 = 0, $13 = 0, $14 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $not$$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = HEAP32[$1>>2]|0;
 $4 = HEAP32[$2>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  $15 = 0;
 } else {
  $6 = ((($4)) + 12|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)==(0|0);
  if ($8) {
   $15 = 0;
  } else {
   $$056$i = $7;$$07$i = 0;
   while(1) {
    $9 = ((($$056$i)) + 16|0);
    $10 = HEAP32[$9>>2]|0;
    $not$$i = ($10|0)!=(0|0);
    $11 = $not$$i&1;
    $$0$$i = (($11) + ($$07$i))|0;
    $12 = ((($$056$i)) + 12|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = ($13|0)==(0|0);
    if ($14) {
     $15 = $$0$$i;
     break;
    } else {
     $$056$i = $13;$$07$i = $$0$$i;
    }
   }
  }
 }
 $16 = ($15>>>0)>(1);
 $17 = ((($3)) + 668|0);
 $18 = ((($3)) + 672|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$17>>2]|0;
 $21 = (($19) - ($20))|0;
 $22 = $21 >> 2;
 $$neg81 = $16&1;
 $$$neg = (($$neg81) - ($15))|0;
 $23 = (($$$neg) + ($22))|0;
 $24 = ((($0)) + 96|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)==(0|0);
 if (!($26)) {
  __ZN3osg5State14insertStateSetEjPKNS_8StateSetE($3,$23,$25);
 }
 $27 = ((($0)) + 44|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = ((($0)) + 48|0);
 $30 = ($28|0)==($29|0);
 L9: do {
  if ($30) {
   $$sroa$073$0$lcssa = $28;
  } else {
   $$sroa$073$093 = $28;
   while(1) {
    $31 = ((($$sroa$073$093)) + 16|0);
    $32 = HEAP32[$31>>2]|0;
    $33 = ($32|0)<(0);
    if (!($33)) {
     $$sroa$073$0$lcssa = $$sroa$073$093;
     break L9;
    }
    $34 = ((($$sroa$073$093)) + 20|0);
    $35 = HEAP32[$34>>2]|0;
    $36 = HEAP32[$35>>2]|0;
    $37 = ((($36)) + 172|0);
    $38 = HEAP32[$37>>2]|0;
    FUNCTION_TABLE_viii[$38 & 8191]($35,$1,$2);
    $39 = ((($$sroa$073$093)) + 4|0);
    $40 = HEAP32[$39>>2]|0;
    $41 = ($40|0)==(0|0);
    if ($41) {
     $42 = ((($$sroa$073$093)) + 8|0);
     $43 = HEAP32[$42>>2]|0;
     $44 = HEAP32[$43>>2]|0;
     $45 = ($44|0)==($$sroa$073$093|0);
     if ($45) {
      $$sroa$073$0$be = $43;
     } else {
      $50 = $42;
      while(1) {
       $49 = HEAP32[$50>>2]|0;
       $51 = ((($49)) + 8|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = HEAP32[$52>>2]|0;
       $54 = ($53|0)==($49|0);
       if ($54) {
        $$sroa$073$0$be = $52;
        break;
       } else {
        $50 = $51;
       }
      }
     }
    } else {
     $$0$i$i$i$i44 = $40;
     while(1) {
      $47 = HEAP32[$$0$i$i$i$i44>>2]|0;
      $48 = ($47|0)==(0|0);
      if ($48) {
       break;
      } else {
       $$0$i$i$i$i44 = $47;
      }
     }
     $$sroa$073$0$be = $$0$i$i$i$i44;
    }
    $46 = ($$sroa$073$0$be|0)==($29|0);
    if ($46) {
     $$sroa$073$0$lcssa = $29;
     break;
    } else {
     $$sroa$073$093 = $$sroa$073$0$be;
    }
   }
  }
 } while(0);
 $55 = ((($0)) + 68|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = ((($0)) + 72|0);
 $58 = HEAP32[$57>>2]|0;
 $59 = ($56|0)==($58|0);
 if (!($59)) {
  $$pre = HEAP32[$2>>2]|0;
  $$sroa$066$090 = $56;$69 = $$pre;
  while(1) {
   $65 = HEAP32[$$sroa$066$090>>2]|0;
   $66 = HEAP32[$65>>2]|0;
   $67 = ((($66)) + 12|0);
   $68 = HEAP32[$67>>2]|0;
   FUNCTION_TABLE_viii[$68 & 8191]($65,$1,$69);
   HEAP32[$2>>2] = $65;
   $70 = ((($$sroa$066$090)) + 4|0);
   $71 = HEAP32[$57>>2]|0;
   $72 = ($70|0)==($71|0);
   if ($72) {
    break;
   } else {
    $$sroa$066$090 = $70;$69 = $65;
   }
  }
 }
 $60 = ((($0)) + 56|0);
 $61 = HEAP32[$60>>2]|0;
 $62 = ((($0)) + 60|0);
 $63 = HEAP32[$62>>2]|0;
 $64 = ($61|0)==($63|0);
 if (!($64)) {
  $$sroa$059$087 = $61;$116 = $63;
  while(1) {
   $74 = HEAP32[$$sroa$059$087>>2]|0;
   $75 = ((($74)) + 36|0);
   $76 = HEAP32[$75>>2]|0;
   $77 = ((($74)) + 40|0);
   $78 = HEAP32[$77>>2]|0;
   $79 = ($76|0)==($78|0);
   if ($79) {
    $82 = $116;
   } else {
    $$pre100 = HEAP32[$2>>2]|0;
    $$sroa$053$085 = $76;$87 = $$pre100;
    while(1) {
     $83 = HEAP32[$$sroa$053$085>>2]|0;
     $84 = HEAP32[$83>>2]|0;
     $85 = ((($84)) + 12|0);
     $86 = HEAP32[$85>>2]|0;
     FUNCTION_TABLE_viii[$86 & 8191]($83,$1,$87);
     HEAP32[$2>>2] = $83;
     $88 = ((($$sroa$053$085)) + 4|0);
     $89 = HEAP32[$$sroa$059$087>>2]|0;
     $90 = ((($89)) + 40|0);
     $91 = HEAP32[$90>>2]|0;
     $92 = ($88|0)==($91|0);
     if ($92) {
      break;
     } else {
      $$sroa$053$085 = $88;$87 = $83;
     }
    }
    $$pre101 = HEAP32[$62>>2]|0;
    $82 = $$pre101;
   }
   $80 = ((($$sroa$059$087)) + 4|0);
   $81 = ($80|0)==($82|0);
   if ($81) {
    break;
   } else {
    $$sroa$059$087 = $80;$116 = $82;
   }
  }
 }
 $73 = ($$sroa$073$0$lcssa|0)==($29|0);
 if (!($73)) {
  $$sroa$073$184 = $$sroa$073$0$lcssa;
  while(1) {
   $93 = ((($$sroa$073$184)) + 20|0);
   $94 = HEAP32[$93>>2]|0;
   $95 = HEAP32[$94>>2]|0;
   $96 = ((($95)) + 172|0);
   $97 = HEAP32[$96>>2]|0;
   FUNCTION_TABLE_viii[$97 & 8191]($94,$1,$2);
   $98 = ((($$sroa$073$184)) + 4|0);
   $99 = HEAP32[$98>>2]|0;
   $100 = ($99|0)==(0|0);
   if ($100) {
    $101 = ((($$sroa$073$184)) + 8|0);
    $102 = HEAP32[$101>>2]|0;
    $103 = HEAP32[$102>>2]|0;
    $104 = ($103|0)==($$sroa$073$184|0);
    if ($104) {
     $$sroa$073$1$be = $102;
    } else {
     $109 = $101;
     while(1) {
      $108 = HEAP32[$109>>2]|0;
      $110 = ((($108)) + 8|0);
      $111 = HEAP32[$110>>2]|0;
      $112 = HEAP32[$111>>2]|0;
      $113 = ($112|0)==($108|0);
      if ($113) {
       $$sroa$073$1$be = $111;
       break;
      } else {
       $109 = $110;
      }
     }
    }
   } else {
    $$0$i$i$i$i = $99;
    while(1) {
     $106 = HEAP32[$$0$i$i$i$i>>2]|0;
     $107 = ($106|0)==(0|0);
     if ($107) {
      break;
     } else {
      $$0$i$i$i$i = $106;
     }
    }
    $$sroa$073$1$be = $$0$i$i$i$i;
   }
   $105 = ($$sroa$073$1$be|0)==($29|0);
   if ($105) {
    break;
   } else {
    $$sroa$073$184 = $$sroa$073$1$be;
   }
  }
 }
 $114 = HEAP32[$24>>2]|0;
 $115 = ($114|0)==(0|0);
 if ($115) {
  return;
 }
 __ZN3osg5State14removeStateSetEj($3,$23);
 return;
}
function __ZNK7osgUtil9RenderBin34computeNumberOfDynamicRenderLeavesEv($0) {
 $0 = $0|0;
 var $$0$i$i$i$i = 0, $$0$i$i$i$i14 = 0, $$0$lcssa = 0, $$072 = 0, $$1$ = 0, $$1$lcssa = 0, $$167 = 0, $$3$lcssa = 0, $$362 = 0, $$4$ = 0, $$4$lcssa = 0, $$458 = 0, $$6$lcssa = 0, $$656 = 0, $$sink57 = 0, $$sroa$031$061 = 0, $$sroa$038$066 = 0, $$sroa$045$0$be = 0, $$sroa$045$0$lcssa = 0, $$sroa$045$071 = 0;
 var $$sroa$045$1$be = 0, $$sroa$045$155 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 44|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 48|0);
 $4 = ($2|0)==($3|0);
 L1: do {
  if ($4) {
   $$0$lcssa = 0;$$sroa$045$0$lcssa = $2;
  } else {
   $$072 = 0;$$sroa$045$071 = $2;
   while(1) {
    $5 = ((($$sroa$045$071)) + 16|0);
    $6 = HEAP32[$5>>2]|0;
    $7 = ($6|0)<(0);
    if (!($7)) {
     $$0$lcssa = $$072;$$sroa$045$0$lcssa = $$sroa$045$071;
     break L1;
    }
    $8 = ((($$sroa$045$071)) + 20|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = HEAP32[$9>>2]|0;
    $11 = ((($10)) + 180|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (FUNCTION_TABLE_ii[$12 & 8191]($9)|0);
    $14 = (($13) + ($$072))|0;
    $15 = ((($$sroa$045$071)) + 4|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = ($16|0)==(0|0);
    if ($17) {
     $18 = ((($$sroa$045$071)) + 8|0);
     $19 = HEAP32[$18>>2]|0;
     $20 = HEAP32[$19>>2]|0;
     $21 = ($20|0)==($$sroa$045$071|0);
     if ($21) {
      $$sroa$045$0$be = $19;
     } else {
      $26 = $18;
      while(1) {
       $25 = HEAP32[$26>>2]|0;
       $27 = ((($25)) + 8|0);
       $28 = HEAP32[$27>>2]|0;
       $29 = HEAP32[$28>>2]|0;
       $30 = ($29|0)==($25|0);
       if ($30) {
        $$sroa$045$0$be = $28;
        break;
       } else {
        $26 = $27;
       }
      }
     }
    } else {
     $$0$i$i$i$i14 = $16;
     while(1) {
      $23 = HEAP32[$$0$i$i$i$i14>>2]|0;
      $24 = ($23|0)==(0|0);
      if ($24) {
       break;
      } else {
       $$0$i$i$i$i14 = $23;
      }
     }
     $$sroa$045$0$be = $$0$i$i$i$i14;
    }
    $22 = ($$sroa$045$0$be|0)==($3|0);
    if ($22) {
     $$0$lcssa = $14;$$sroa$045$0$lcssa = $3;
     break;
    } else {
     $$072 = $14;$$sroa$045$071 = $$sroa$045$0$be;
    }
   }
  }
 } while(0);
 $31 = ((($0)) + 68|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = ((($0)) + 72|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($32|0)==($34|0);
 if ($35) {
  $$1$lcssa = $$0$lcssa;
 } else {
  $$167 = $$0$lcssa;$$sroa$038$066 = $32;
  while(1) {
   $41 = HEAP32[$$sroa$038$066>>2]|0;
   $42 = ((($41)) + 32|0);
   $43 = HEAP8[$42>>0]|0;
   $44 = $43&255;
   $$1$ = (($44) + ($$167))|0;
   $45 = ((($$sroa$038$066)) + 4|0);
   $46 = ($45|0)==($34|0);
   if ($46) {
    $$1$lcssa = $$1$;
    break;
   } else {
    $$167 = $$1$;$$sroa$038$066 = $45;
   }
  }
 }
 $36 = ((($0)) + 56|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = ((($0)) + 60|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = ($37|0)==($39|0);
 if ($40) {
  $$3$lcssa = $$1$lcssa;
 } else {
  $$362 = $$1$lcssa;$$sroa$031$061 = $37;
  while(1) {
   $48 = HEAP32[$$sroa$031$061>>2]|0;
   $49 = ((($48)) + 36|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = ((($48)) + 40|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = ($50|0)==($52|0);
   if ($53) {
    $$4$lcssa = $$362;
   } else {
    $$458 = $$362;$$sink57 = $50;
    while(1) {
     $56 = HEAP32[$$sink57>>2]|0;
     $57 = ((($56)) + 32|0);
     $58 = HEAP8[$57>>0]|0;
     $59 = $58&255;
     $$4$ = (($59) + ($$458))|0;
     $60 = ((($$sink57)) + 4|0);
     $61 = ($60|0)==($52|0);
     if ($61) {
      $$4$lcssa = $$4$;
      break;
     } else {
      $$458 = $$4$;$$sink57 = $60;
     }
    }
   }
   $54 = ((($$sroa$031$061)) + 4|0);
   $55 = ($54|0)==($39|0);
   if ($55) {
    $$3$lcssa = $$4$lcssa;
    break;
   } else {
    $$362 = $$4$lcssa;$$sroa$031$061 = $54;
   }
  }
 }
 $47 = ($$sroa$045$0$lcssa|0)==($3|0);
 if ($47) {
  $$6$lcssa = $$3$lcssa;
  return ($$6$lcssa|0);
 } else {
  $$656 = $$3$lcssa;$$sroa$045$155 = $$sroa$045$0$lcssa;
 }
 while(1) {
  $62 = ((($$sroa$045$155)) + 20|0);
  $63 = HEAP32[$62>>2]|0;
  $64 = HEAP32[$63>>2]|0;
  $65 = ((($64)) + 180|0);
  $66 = HEAP32[$65>>2]|0;
  $67 = (FUNCTION_TABLE_ii[$66 & 8191]($63)|0);
  $68 = (($67) + ($$656))|0;
  $69 = ((($$sroa$045$155)) + 4|0);
  $70 = HEAP32[$69>>2]|0;
  $71 = ($70|0)==(0|0);
  if ($71) {
   $72 = ((($$sroa$045$155)) + 8|0);
   $73 = HEAP32[$72>>2]|0;
   $74 = HEAP32[$73>>2]|0;
   $75 = ($74|0)==($$sroa$045$155|0);
   if ($75) {
    $$sroa$045$1$be = $73;
   } else {
    $80 = $72;
    while(1) {
     $79 = HEAP32[$80>>2]|0;
     $81 = ((($79)) + 8|0);
     $82 = HEAP32[$81>>2]|0;
     $83 = HEAP32[$82>>2]|0;
     $84 = ($83|0)==($79|0);
     if ($84) {
      $$sroa$045$1$be = $82;
      break;
     } else {
      $80 = $81;
     }
    }
   }
  } else {
   $$0$i$i$i$i = $70;
   while(1) {
    $77 = HEAP32[$$0$i$i$i$i>>2]|0;
    $78 = ($77|0)==(0|0);
    if ($78) {
     break;
    } else {
     $$0$i$i$i$i = $77;
    }
   }
   $$sroa$045$1$be = $$0$i$i$i$i;
  }
  $76 = ($$sroa$045$1$be|0)==($3|0);
  if ($76) {
   $$6$lcssa = $68;
   break;
  } else {
   $$656 = $68;$$sroa$045$155 = $$sroa$045$1$be;
  }
 }
 return ($$6$lcssa|0);
}
function __ZN7osgUtil9RenderBin44copyLeavesFromStateGraphListToRenderLeafListEv($0) {
 $0 = $0|0;
 var $$0$lcssa = 0, $$041 = 0, $$07$off035 = 0, $$1$off0$lcssa = 0, $$1$off033 = 0, $$2$off0 = 0, $$pre = 0, $$sroa$015$032 = 0, $$sroa$024$040 = 0, $$sroa$024$134 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $9 = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i11 = 0, $scevgep5$i$i$i = 0;
 var $scevgep5$i$i$i12 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp + 4|0;
 $2 = sp;
 $3 = ((($0)) + 68|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 72|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==($4|0);
 if (!($7)) {
  $scevgep$i$i$i = ((($6)) + -4|0);
  $8 = $scevgep$i$i$i;
  $9 = $4;
  $10 = (($8) - ($9))|0;
  $11 = $10 >>> 2;
  $12 = $11 ^ -1;
  $scevgep5$i$i$i = (($6) + ($12<<2)|0);
  HEAP32[$5>>2] = $scevgep5$i$i$i;
 }
 $13 = ((($0)) + 56|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ((($0)) + 60|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($14|0)==($16|0);
 if ($17) {
  $$0$lcssa = 0;
 } else {
  $$041 = 0;$$sroa$024$040 = $14;
  while(1) {
   $18 = HEAP32[$$sroa$024$040>>2]|0;
   $19 = ((($18)) + 36|0);
   $20 = ((($18)) + 40|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = HEAP32[$19>>2]|0;
   $23 = (($21) - ($22))|0;
   $24 = $23 >> 2;
   $25 = (($24) + ($$041))|0;
   $26 = ((($$sroa$024$040)) + 4|0);
   $27 = ($26|0)==($16|0);
   if ($27) {
    $$0$lcssa = $25;
    break;
   } else {
    $$041 = $25;$$sroa$024$040 = $26;
   }
  }
 }
 __ZNSt3__26vectorIPN7osgUtil10RenderLeafENS_9allocatorIS3_EEE7reserveEj($3,$$0$lcssa);
 $28 = HEAP32[$13>>2]|0;
 $29 = HEAP32[$15>>2]|0;
 $30 = ($28|0)==($29|0);
 do {
  if (!($30)) {
   $31 = ((($0)) + 76|0);
   $$07$off035 = 0;$$sroa$024$134 = $28;
   while(1) {
    $32 = HEAP32[$$sroa$024$134>>2]|0;
    $33 = ((($32)) + 36|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = ((($32)) + 40|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = ($34|0)==($36|0);
    if ($37) {
     $$1$off0$lcssa = $$07$off035;
    } else {
     $$1$off033 = $$07$off035;$$sroa$015$032 = $34;$87 = $32;
     while(1) {
      $41 = HEAP32[$$sroa$015$032>>2]|0;
      $42 = ((($41)) + 28|0);
      $43 = HEAP32[$42>>2]|0;
      $44 = $43 & 2147483647;
      $45 = ($44>>>0)>(2139095040);
      $46 = $41;
      if ($45) {
       $$2$off0 = 1;$54 = $87;
      } else {
       HEAP32[$2>>2] = $46;
       $47 = HEAP32[$5>>2]|0;
       $48 = HEAP32[$31>>2]|0;
       $49 = ($47|0)==($48|0);
       if ($49) {
        __ZNSt3__26vectorIPN7osgUtil10RenderLeafENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_($3,$2);
       } else {
        HEAP32[$47>>2] = $46;
        $50 = HEAP32[$5>>2]|0;
        $51 = ((($50)) + 4|0);
        HEAP32[$5>>2] = $51;
       }
       $$pre = HEAP32[$$sroa$024$134>>2]|0;
       $$2$off0 = $$1$off033;$54 = $$pre;
      }
      $52 = ((($$sroa$015$032)) + 4|0);
      $53 = ((($54)) + 40|0);
      $55 = HEAP32[$53>>2]|0;
      $56 = ($52|0)==($55|0);
      if ($56) {
       $$1$off0$lcssa = $$2$off0;
       break;
      } else {
       $$1$off033 = $$2$off0;$$sroa$015$032 = $52;$87 = $54;
      }
     }
    }
    $38 = ((($$sroa$024$134)) + 4|0);
    $39 = HEAP32[$15>>2]|0;
    $40 = ($38|0)==($39|0);
    if ($40) {
     break;
    } else {
     $$07$off035 = $$1$off0$lcssa;$$sroa$024$134 = $38;
    }
   }
   if ($$1$off0$lcssa) {
    $57 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
    if ($57) {
     $58 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
     $59 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($58,116670,120)|0);
     $60 = HEAP32[$59>>2]|0;
     $61 = ((($60)) + -12|0);
     $62 = HEAP32[$61>>2]|0;
     $63 = (($59) + ($62)|0);
     __ZNKSt3__28ios_base6getlocEv($1,$63);
     __THREW__ = 0;
     $64 = (invoke_iii(3255,($1|0),(215188|0))|0);
     $65 = __THREW__; __THREW__ = 0;
     $66 = $65&1;
     if (!($66)) {
      $67 = HEAP32[$64>>2]|0;
      $68 = ((($67)) + 28|0);
      $69 = HEAP32[$68>>2]|0;
      __THREW__ = 0;
      $70 = (invoke_iii($69|0,($64|0),10)|0);
      $71 = __THREW__; __THREW__ = 0;
      $72 = $71&1;
      if (!($72)) {
       __ZNSt3__26localeD2Ev($1);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($59,$70)|0);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($59)|0);
       break;
      }
     }
     $73 = ___cxa_find_matching_catch_2()|0;
     $74 = tempRet0;
     __THREW__ = 0;
     invoke_vi(3263,($1|0));
     $75 = __THREW__; __THREW__ = 0;
     $76 = $75&1;
     if ($76) {
      $77 = ___cxa_find_matching_catch_3(0|0)|0;
      $78 = tempRet0;
      ___clang_call_terminate($77);
      // unreachable;
     } else {
      ___resumeException($73|0);
      // unreachable;
     }
    }
   }
  }
 } while(0);
 $79 = HEAP32[$13>>2]|0;
 $80 = HEAP32[$15>>2]|0;
 $81 = ($80|0)==($79|0);
 if ($81) {
  STACKTOP = sp;return;
 }
 $scevgep$i$i$i11 = ((($80)) + -4|0);
 $82 = $scevgep$i$i$i11;
 $83 = $79;
 $84 = (($82) - ($83))|0;
 $85 = $84 >>> 2;
 $86 = $85 ^ -1;
 $scevgep5$i$i$i12 = (($80) + ($86<<2)|0);
 HEAP32[$15>>2] = $scevgep5$i$i$i12;
 STACKTOP = sp;return;
}
function __ZNSt3__26__sortIR21TraversalOrderFunctorPPN7osgUtil10RenderLeafEEEvT0_S7_T_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$$0174 = 0, $$0 = 0, $$0$i189 = 0, $$0$ph = 0, $$0154 = 0, $$0160241 = 0, $$0167 = 0, $$0174 = 0, $$0180$ph = 0, $$02933$i = 0, $$03032$i = 0, $$03032$i$phi = 0, $$1 = 0, $$1$i = 0, $$1$i$phi = 0, $$1155 = 0, $$1161 = 0, $$2156 = 0, $$2162 = 0, $$2176 = 0;
 var $$3157 = 0, $$3163 = 0, $$3170 = 0, $$4158 = 0, $$4164 = 0, $$4171 = 0, $$5159 = 0, $$5165 = 0, $$5172 = 0, $$6166 = 0, $$6173 = 0, $$pre$i190 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0;
 var $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0;
 var $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0;
 var $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0;
 var $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0;
 var $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0;
 var $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0;
 var $252 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$0$ph = $0;$$0180$ph = $1;
 L1: while(1) {
  $3 = $$0180$ph;
  $4 = ((($$0180$ph)) + -4|0);
  $$0 = $$0$ph;
  while(1) {
   $$1 = $$0;
   L5: while(1) {
    $5 = $$1;
    $6 = (($3) - ($5))|0;
    $7 = $6 >> 2;
    switch ($7|0) {
    case 2:  {
     label = 5;
     break L1;
     break;
    }
    case 3:  {
     label = 7;
     break L1;
     break;
    }
    case 4:  {
     label = 15;
     break L1;
     break;
    }
    case 5:  {
     label = 27;
     break L1;
     break;
    }
    case 1: case 0:  {
     label = 87;
     break L1;
     break;
    }
    default: {
    }
    }
    $90 = ($6|0)<(124);
    if ($90) {
     label = 29;
     break L1;
    }
    $128 = ($6|0)>(3996);
    $129 = (($7|0) / 2)&-1;
    $130 = (($$1) + ($129<<2)|0);
    do {
     if ($128) {
      $131 = (($7|0) / 4)&-1;
      $132 = (($$1) + ($131<<2)|0);
      $133 = (($130) + ($131<<2)|0);
      $134 = (__ZNSt3__27__sort5IR21TraversalOrderFunctorPPN7osgUtil10RenderLeafEEEjT0_S7_S7_S7_S7_T_($$1,$132,$130,$133,$4,$2)|0);
      $$0167 = $134;
     } else {
      $135 = HEAP32[$130>>2]|0;
      $136 = HEAP32[$$1>>2]|0;
      $137 = ((($135)) + 36|0);
      $138 = HEAP32[$137>>2]|0;
      $139 = ((($136)) + 36|0);
      $140 = HEAP32[$139>>2]|0;
      $141 = ($138>>>0)<($140>>>0);
      $142 = HEAP32[$4>>2]|0;
      $143 = ((($142)) + 36|0);
      $144 = HEAP32[$143>>2]|0;
      $145 = ($144>>>0)<($138>>>0);
      $146 = $135;
      $147 = $142;
      $148 = $136;
      if (!($141)) {
       if (!($145)) {
        $$0167 = 0;
        break;
       }
       HEAP32[$130>>2] = $147;
       HEAP32[$4>>2] = $146;
       $149 = HEAP32[$130>>2]|0;
       $150 = HEAP32[$$1>>2]|0;
       $151 = ((($149)) + 36|0);
       $152 = HEAP32[$151>>2]|0;
       $153 = ((($150)) + 36|0);
       $154 = HEAP32[$153>>2]|0;
       $155 = ($152>>>0)<($154>>>0);
       if (!($155)) {
        $$0167 = 1;
        break;
       }
       $156 = $149;
       $157 = $150;
       HEAP32[$$1>>2] = $156;
       HEAP32[$130>>2] = $157;
       $$0167 = 2;
       break;
      }
      if ($145) {
       HEAP32[$$1>>2] = $147;
       HEAP32[$4>>2] = $148;
       $$0167 = 1;
       break;
      }
      HEAP32[$$1>>2] = $146;
      HEAP32[$130>>2] = $148;
      $158 = HEAP32[$4>>2]|0;
      $159 = ((($158)) + 36|0);
      $160 = HEAP32[$159>>2]|0;
      $161 = ($160>>>0)<($140>>>0);
      if ($161) {
       $162 = $158;
       HEAP32[$130>>2] = $162;
       HEAP32[$4>>2] = $148;
       $$0167 = 2;
      } else {
       $$0167 = 1;
      }
     }
    } while(0);
    $163 = HEAP32[$$1>>2]|0;
    $164 = HEAP32[$130>>2]|0;
    $165 = ((($163)) + 36|0);
    $166 = HEAP32[$165>>2]|0;
    $167 = ((($164)) + 36|0);
    $168 = HEAP32[$167>>2]|0;
    $169 = ($166>>>0)<($168>>>0);
    if ($169) {
     $$3157 = $4;$$3170 = $$0167;
     break;
    } else {
     $$0154 = $4;
    }
    while(1) {
     $170 = ((($$0154)) + -4|0);
     $171 = ($$1|0)==($170|0);
     if ($171) {
      break;
     }
     $204 = HEAP32[$170>>2]|0;
     $205 = ((($204)) + 36|0);
     $206 = HEAP32[$205>>2]|0;
     $207 = ($206>>>0)<($168>>>0);
     if ($207) {
      label = 69;
      break L5;
     } else {
      $$0154 = $170;
     }
    }
    $172 = ((($$1)) + 4|0);
    $173 = HEAP32[$4>>2]|0;
    $174 = ((($173)) + 36|0);
    $175 = HEAP32[$174>>2]|0;
    $176 = ($166>>>0)<($175>>>0);
    $177 = $173;
    if ($176) {
     $$1161 = $172;
    } else {
     $178 = ($172|0)==($4|0);
     if ($178) {
      label = 87;
      break L1;
     } else {
      $$0160241 = $172;
     }
     while(1) {
      $179 = HEAP32[$$0160241>>2]|0;
      $180 = ((($179)) + 36|0);
      $181 = HEAP32[$180>>2]|0;
      $182 = ($166>>>0)<($181>>>0);
      if ($182) {
       break;
      }
      $185 = ((($$0160241)) + 4|0);
      $186 = ($185|0)==($4|0);
      if ($186) {
       label = 87;
       break L1;
      } else {
       $$0160241 = $185;
      }
     }
     $183 = $179;
     HEAP32[$$0160241>>2] = $177;
     HEAP32[$4>>2] = $183;
     $184 = ((($$0160241)) + 4|0);
     $$1161 = $184;
    }
    $187 = ($$1161|0)==($4|0);
    if ($187) {
     label = 87;
     break L1;
    } else {
     $$1155 = $4;$$2162 = $$1161;
    }
    while(1) {
     $188 = HEAP32[$$1>>2]|0;
     $189 = ((($188)) + 36|0);
     $190 = HEAP32[$189>>2]|0;
     $$3163 = $$2162;
     while(1) {
      $191 = HEAP32[$$3163>>2]|0;
      $192 = ((($191)) + 36|0);
      $193 = HEAP32[$192>>2]|0;
      $194 = ($190>>>0)<($193>>>0);
      $195 = ((($$3163)) + 4|0);
      if ($194) {
       break;
      } else {
       $$3163 = $195;
      }
     }
     $196 = $191;
     $$2156 = $$1155;
     while(1) {
      $197 = ((($$2156)) + -4|0);
      $198 = HEAP32[$197>>2]|0;
      $199 = ((($198)) + 36|0);
      $200 = HEAP32[$199>>2]|0;
      $201 = ($190>>>0)<($200>>>0);
      if ($201) {
       $$2156 = $197;
      } else {
       break;
      }
     }
     $202 = ($$3163>>>0)<($197>>>0);
     if (!($202)) {
      $$1 = $$3163;
      continue L5;
     }
     $203 = $198;
     HEAP32[$$3163>>2] = $203;
     HEAP32[$197>>2] = $196;
     $$1155 = $197;$$2162 = $195;
    }
   }
   if ((label|0) == 69) {
    label = 0;
    $208 = $163;
    $209 = $204;
    HEAP32[$$1>>2] = $209;
    HEAP32[$170>>2] = $208;
    $210 = (($$0167) + 1)|0;
    $$3157 = $170;$$3170 = $210;
   }
   $211 = ((($$1)) + 4|0);
   $212 = ($211>>>0)<($$3157>>>0);
   L45: do {
    if ($212) {
     $$0174 = $130;$$4158 = $$3157;$$4164 = $211;$$4171 = $$3170;
     while(1) {
      $213 = HEAP32[$$0174>>2]|0;
      $214 = ((($213)) + 36|0);
      $215 = HEAP32[$214>>2]|0;
      $$5165 = $$4164;
      while(1) {
       $216 = HEAP32[$$5165>>2]|0;
       $217 = ((($216)) + 36|0);
       $218 = HEAP32[$217>>2]|0;
       $219 = ($218>>>0)<($215>>>0);
       $220 = ((($$5165)) + 4|0);
       if ($219) {
        $$5165 = $220;
       } else {
        break;
       }
      }
      $221 = $216;
      $$5159 = $$4158;
      while(1) {
       $222 = ((($$5159)) + -4|0);
       $223 = HEAP32[$222>>2]|0;
       $224 = ((($223)) + 36|0);
       $225 = HEAP32[$224>>2]|0;
       $226 = ($225>>>0)<($215>>>0);
       if ($226) {
        break;
       } else {
        $$5159 = $222;
       }
      }
      $227 = ($$5165>>>0)>($222>>>0);
      if ($227) {
       $$2176 = $$0174;$$5172 = $$4171;$$6166 = $$5165;
       break L45;
      }
      $228 = $223;
      HEAP32[$$5165>>2] = $228;
      HEAP32[$222>>2] = $221;
      $229 = (($$4171) + 1)|0;
      $230 = ($$0174|0)==($$5165|0);
      $$$0174 = $230 ? $222 : $$0174;
      $$0174 = $$$0174;$$4158 = $222;$$4164 = $220;$$4171 = $229;
     }
    } else {
     $$2176 = $130;$$5172 = $$3170;$$6166 = $211;
    }
   } while(0);
   $231 = ($$6166|0)==($$2176|0);
   if ($231) {
    $$6173 = $$5172;
   } else {
    $232 = HEAP32[$$2176>>2]|0;
    $233 = HEAP32[$$6166>>2]|0;
    $234 = ((($232)) + 36|0);
    $235 = HEAP32[$234>>2]|0;
    $236 = ((($233)) + 36|0);
    $237 = HEAP32[$236>>2]|0;
    $238 = ($235>>>0)<($237>>>0);
    if ($238) {
     $239 = $232;
     $240 = $233;
     $241 = (($$5172) + 1)|0;
     HEAP32[$$6166>>2] = $239;
     HEAP32[$$2176>>2] = $240;
     $$6173 = $241;
    } else {
     $$6173 = $$5172;
    }
   }
   $242 = ($$6173|0)==(0);
   if ($242) {
    $243 = (__ZNSt3__227__insertion_sort_incompleteIR21TraversalOrderFunctorPPN7osgUtil10RenderLeafEEEbT0_S7_T_($$1,$$6166,$2)|0);
    $244 = ((($$6166)) + 4|0);
    $245 = (__ZNSt3__227__insertion_sort_incompleteIR21TraversalOrderFunctorPPN7osgUtil10RenderLeafEEEbT0_S7_T_($244,$$0180$ph,$2)|0);
    if ($245) {
     label = 86;
     break;
    }
    if ($243) {
     $$0 = $244;
     continue;
    }
   }
   $246 = $$6166;
   $247 = (($246) - ($5))|0;
   $248 = (($3) - ($246))|0;
   $249 = ($247|0)<($248|0);
   if (!($249)) {
    label = 85;
    break;
   }
   __ZNSt3__26__sortIR21TraversalOrderFunctorPPN7osgUtil10RenderLeafEEEvT0_S7_T_($$1,$$6166,$2);
   $250 = ((($$6166)) + 4|0);
   $$0 = $250;
  }
  if ((label|0) == 85) {
   label = 0;
   $251 = ((($$6166)) + 4|0);
   __ZNSt3__26__sortIR21TraversalOrderFunctorPPN7osgUtil10RenderLeafEEEvT0_S7_T_($251,$$0180$ph,$2);
   $$0$ph = $$1;$$0180$ph = $$6166;
   continue;
  }
  else if ((label|0) == 86) {
   label = 0;
   if ($243) {
    label = 87;
    break;
   } else {
    $$0$ph = $$1;$$0180$ph = $$6166;
    continue;
   }
  }
 }
 if ((label|0) == 5) {
  $8 = HEAP32[$4>>2]|0;
  $9 = HEAP32[$$1>>2]|0;
  $10 = ((($8)) + 36|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ((($9)) + 36|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($11>>>0)<($13>>>0);
  if (!($14)) {
   return;
  }
  $15 = $8;
  $16 = $9;
  HEAP32[$$1>>2] = $15;
  HEAP32[$4>>2] = $16;
  return;
 }
 else if ((label|0) == 7) {
  $17 = ((($$1)) + 4|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = HEAP32[$$1>>2]|0;
  $20 = ((($18)) + 36|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = ((($19)) + 36|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = ($21>>>0)<($23>>>0);
  $25 = HEAP32[$4>>2]|0;
  $26 = ((($25)) + 36|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = ($27>>>0)<($21>>>0);
  $29 = $18;
  $30 = $25;
  $31 = $19;
  if (!($24)) {
   if (!($28)) {
    return;
   }
   HEAP32[$17>>2] = $30;
   HEAP32[$4>>2] = $29;
   $32 = HEAP32[$17>>2]|0;
   $33 = HEAP32[$$1>>2]|0;
   $34 = ((($32)) + 36|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ((($33)) + 36|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = ($35>>>0)<($37>>>0);
   if (!($38)) {
    return;
   }
   $39 = $32;
   $40 = $33;
   HEAP32[$$1>>2] = $39;
   HEAP32[$17>>2] = $40;
   return;
  }
  if ($28) {
   HEAP32[$$1>>2] = $30;
   HEAP32[$4>>2] = $31;
   return;
  }
  HEAP32[$$1>>2] = $29;
  HEAP32[$17>>2] = $31;
  $41 = HEAP32[$4>>2]|0;
  $42 = ((($41)) + 36|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = ($43>>>0)<($23>>>0);
  if (!($44)) {
   return;
  }
  $45 = $41;
  HEAP32[$17>>2] = $45;
  HEAP32[$4>>2] = $31;
  return;
 }
 else if ((label|0) == 15) {
  $46 = ((($$1)) + 4|0);
  $47 = ((($$1)) + 8|0);
  $48 = HEAP32[$46>>2]|0;
  $49 = HEAP32[$$1>>2]|0;
  $50 = ((($48)) + 36|0);
  $51 = HEAP32[$50>>2]|0;
  $52 = ((($49)) + 36|0);
  $53 = HEAP32[$52>>2]|0;
  $54 = ($51>>>0)<($53>>>0);
  $55 = HEAP32[$47>>2]|0;
  $56 = ((($55)) + 36|0);
  $57 = HEAP32[$56>>2]|0;
  $58 = ($57>>>0)<($51>>>0);
  $59 = $48;
  $60 = $55;
  $61 = $49;
  do {
   if ($54) {
    if ($58) {
     HEAP32[$$1>>2] = $60;
     HEAP32[$47>>2] = $61;
     $68 = $49;$72 = $61;
     break;
    }
    HEAP32[$$1>>2] = $59;
    HEAP32[$46>>2] = $61;
    $63 = ($57>>>0)<($53>>>0);
    if ($63) {
     HEAP32[$46>>2] = $60;
     HEAP32[$47>>2] = $61;
     $68 = $49;$72 = $61;
    } else {
     $68 = $55;$72 = $60;
    }
   } else {
    if ($58) {
     HEAP32[$46>>2] = $60;
     HEAP32[$47>>2] = $59;
     $62 = ($57>>>0)<($53>>>0);
     if ($62) {
      HEAP32[$$1>>2] = $60;
      HEAP32[$46>>2] = $61;
      $68 = $48;$72 = $59;
     } else {
      $68 = $48;$72 = $59;
     }
    } else {
     $68 = $55;$72 = $60;
    }
   }
  } while(0);
  $64 = HEAP32[$4>>2]|0;
  $65 = ((($64)) + 36|0);
  $66 = HEAP32[$65>>2]|0;
  $67 = ((($68)) + 36|0);
  $69 = HEAP32[$67>>2]|0;
  $70 = ($66>>>0)<($69>>>0);
  if (!($70)) {
   return;
  }
  $71 = $64;
  HEAP32[$47>>2] = $71;
  HEAP32[$4>>2] = $72;
  $73 = HEAP32[$47>>2]|0;
  $74 = HEAP32[$46>>2]|0;
  $75 = ((($73)) + 36|0);
  $76 = HEAP32[$75>>2]|0;
  $77 = ((($74)) + 36|0);
  $78 = HEAP32[$77>>2]|0;
  $79 = ($76>>>0)<($78>>>0);
  if (!($79)) {
   return;
  }
  $80 = $73;
  $81 = $74;
  HEAP32[$46>>2] = $80;
  HEAP32[$47>>2] = $81;
  $82 = HEAP32[$$1>>2]|0;
  $83 = ((($82)) + 36|0);
  $84 = HEAP32[$83>>2]|0;
  $85 = ($76>>>0)<($84>>>0);
  if (!($85)) {
   return;
  }
  $86 = $82;
  HEAP32[$$1>>2] = $80;
  HEAP32[$46>>2] = $86;
  return;
 }
 else if ((label|0) == 27) {
  $87 = ((($$1)) + 4|0);
  $88 = ((($$1)) + 8|0);
  $89 = ((($$1)) + 12|0);
  (__ZNSt3__27__sort5IR21TraversalOrderFunctorPPN7osgUtil10RenderLeafEEEjT0_S7_S7_S7_S7_T_($$1,$87,$88,$89,$4,$2)|0);
  return;
 }
 else if ((label|0) == 29) {
  $91 = ((($$1)) + 8|0);
  $92 = ((($$1)) + 4|0);
  $93 = HEAP32[$92>>2]|0;
  $94 = HEAP32[$$1>>2]|0;
  $95 = ((($93)) + 36|0);
  $96 = HEAP32[$95>>2]|0;
  $97 = ((($94)) + 36|0);
  $98 = HEAP32[$97>>2]|0;
  $99 = ($96>>>0)<($98>>>0);
  $100 = HEAP32[$91>>2]|0;
  $101 = ((($100)) + 36|0);
  $102 = HEAP32[$101>>2]|0;
  $103 = ($102>>>0)<($96>>>0);
  $104 = $93;
  $105 = $100;
  $106 = $94;
  do {
   if ($99) {
    if ($103) {
     HEAP32[$$1>>2] = $105;
     HEAP32[$91>>2] = $106;
     $252 = $94;
     break;
    }
    HEAP32[$$1>>2] = $104;
    HEAP32[$92>>2] = $106;
    $108 = ($102>>>0)<($98>>>0);
    if ($108) {
     HEAP32[$92>>2] = $105;
     HEAP32[$91>>2] = $106;
     $252 = $94;
    } else {
     $252 = $100;
    }
   } else {
    if ($103) {
     HEAP32[$92>>2] = $105;
     HEAP32[$91>>2] = $104;
     $107 = ($102>>>0)<($98>>>0);
     if ($107) {
      HEAP32[$$1>>2] = $105;
      HEAP32[$92>>2] = $106;
      $252 = $93;
     } else {
      $252 = $93;
     }
    } else {
     $252 = $100;
    }
   }
  } while(0);
  $109 = ((($$1)) + 12|0);
  $110 = ($109|0)==($$0180$ph|0);
  if ($110) {
   return;
  } else {
   $$02933$i = $109;$$03032$i = $91;$115 = $252;
  }
  while(1) {
   $111 = HEAP32[$$02933$i>>2]|0;
   $112 = ((($111)) + 36|0);
   $113 = HEAP32[$112>>2]|0;
   $114 = ((($115)) + 36|0);
   $116 = HEAP32[$114>>2]|0;
   $117 = ($113>>>0)<($116>>>0);
   $118 = $111;
   if ($117) {
    $$0$i189 = $$03032$i;$$1$i = $$02933$i;
    while(1) {
     $119 = HEAP32[$$0$i189>>2]|0;
     HEAP32[$$1$i>>2] = $119;
     $120 = ($$0$i189|0)==($$1|0);
     if ($120) {
      break;
     }
     $121 = ((($$0$i189)) + -4|0);
     $122 = HEAP32[$121>>2]|0;
     $123 = ((($122)) + 36|0);
     $124 = HEAP32[$123>>2]|0;
     $125 = ($113>>>0)<($124>>>0);
     if ($125) {
      $$1$i$phi = $$0$i189;$$0$i189 = $121;$$1$i = $$1$i$phi;
     } else {
      break;
     }
    }
    HEAP32[$$0$i189>>2] = $118;
   }
   $126 = ((($$02933$i)) + 4|0);
   $127 = ($126|0)==($$0180$ph|0);
   if ($127) {
    break;
   }
   $$pre$i190 = HEAP32[$$02933$i>>2]|0;
   $$03032$i$phi = $$02933$i;$$02933$i = $126;$115 = $$pre$i190;$$03032$i = $$03032$i$phi;
  }
  return;
 }
 else if ((label|0) == 87) {
  return;
 }
}
function __ZNSt3__27__sort5IR21TraversalOrderFunctorPPN7osgUtil10RenderLeafEEEjT0_S7_S7_S7_S7_T_($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$0 = 0, $$0$i = 0, $$026$i$i = 0, $$pre$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $6 = HEAP32[$1>>2]|0;
 $7 = HEAP32[$0>>2]|0;
 $8 = ((($6)) + 36|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($7)) + 36|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($9>>>0)<($11>>>0);
 $13 = HEAP32[$2>>2]|0;
 $14 = ((($13)) + 36|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15>>>0)<($9>>>0);
 $17 = $6;
 $18 = $13;
 $19 = $7;
 do {
  if ($12) {
   if ($16) {
    HEAP32[$0>>2] = $18;
    HEAP32[$2>>2] = $19;
    $$026$i$i = 1;$39 = $7;$43 = $19;
    break;
   }
   HEAP32[$0>>2] = $17;
   HEAP32[$1>>2] = $19;
   $30 = HEAP32[$2>>2]|0;
   $31 = ((($30)) + 36|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ($32>>>0)<($11>>>0);
   $34 = $30;
   if ($33) {
    HEAP32[$1>>2] = $34;
    HEAP32[$2>>2] = $19;
    $$026$i$i = 2;$39 = $7;$43 = $19;
   } else {
    $$026$i$i = 1;$39 = $30;$43 = $34;
   }
  } else {
   if ($16) {
    HEAP32[$1>>2] = $18;
    HEAP32[$2>>2] = $17;
    $20 = HEAP32[$1>>2]|0;
    $21 = HEAP32[$0>>2]|0;
    $22 = ((($20)) + 36|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = ((($21)) + 36|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = ($23>>>0)<($25>>>0);
    if ($26) {
     $27 = $20;
     $28 = $21;
     HEAP32[$0>>2] = $27;
     HEAP32[$1>>2] = $28;
     $$pre$i = HEAP32[$2>>2]|0;
     $29 = $$pre$i;
     $$026$i$i = 2;$39 = $$pre$i;$43 = $29;
    } else {
     $$026$i$i = 1;$39 = $6;$43 = $17;
    }
   } else {
    $$026$i$i = 0;$39 = $13;$43 = $18;
   }
  }
 } while(0);
 $35 = HEAP32[$3>>2]|0;
 $36 = ((($35)) + 36|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = ((($39)) + 36|0);
 $40 = HEAP32[$38>>2]|0;
 $41 = ($37>>>0)<($40>>>0);
 if ($41) {
  $42 = $35;
  HEAP32[$2>>2] = $42;
  HEAP32[$3>>2] = $43;
  $44 = (($$026$i$i) + 1)|0;
  $45 = HEAP32[$2>>2]|0;
  $46 = HEAP32[$1>>2]|0;
  $47 = ((($45)) + 36|0);
  $48 = HEAP32[$47>>2]|0;
  $49 = ((($46)) + 36|0);
  $50 = HEAP32[$49>>2]|0;
  $51 = ($48>>>0)<($50>>>0);
  if ($51) {
   $52 = $45;
   $53 = $46;
   HEAP32[$1>>2] = $52;
   HEAP32[$2>>2] = $53;
   $54 = (($$026$i$i) + 2)|0;
   $55 = HEAP32[$1>>2]|0;
   $56 = HEAP32[$0>>2]|0;
   $57 = ((($55)) + 36|0);
   $58 = HEAP32[$57>>2]|0;
   $59 = ((($56)) + 36|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = ($58>>>0)<($60>>>0);
   if ($61) {
    $62 = (($$026$i$i) + 3)|0;
    $63 = $56;
    $64 = $55;
    HEAP32[$0>>2] = $64;
    HEAP32[$1>>2] = $63;
    $$0$i = $62;
   } else {
    $$0$i = $54;
   }
  } else {
   $$0$i = $44;
  }
 } else {
  $$0$i = $$026$i$i;
 }
 $65 = HEAP32[$4>>2]|0;
 $66 = HEAP32[$3>>2]|0;
 $67 = ((($65)) + 36|0);
 $68 = HEAP32[$67>>2]|0;
 $69 = ((($66)) + 36|0);
 $70 = HEAP32[$69>>2]|0;
 $71 = ($68>>>0)<($70>>>0);
 if (!($71)) {
  $$0 = $$0$i;
  return ($$0|0);
 }
 $72 = $65;
 $73 = $66;
 HEAP32[$3>>2] = $72;
 HEAP32[$4>>2] = $73;
 $74 = (($$0$i) + 1)|0;
 $75 = HEAP32[$3>>2]|0;
 $76 = HEAP32[$2>>2]|0;
 $77 = ((($75)) + 36|0);
 $78 = HEAP32[$77>>2]|0;
 $79 = ((($76)) + 36|0);
 $80 = HEAP32[$79>>2]|0;
 $81 = ($78>>>0)<($80>>>0);
 if (!($81)) {
  $$0 = $74;
  return ($$0|0);
 }
 $82 = $75;
 $83 = $76;
 HEAP32[$2>>2] = $82;
 HEAP32[$3>>2] = $83;
 $84 = (($$0$i) + 2)|0;
 $85 = HEAP32[$2>>2]|0;
 $86 = HEAP32[$1>>2]|0;
 $87 = ((($85)) + 36|0);
 $88 = HEAP32[$87>>2]|0;
 $89 = ((($86)) + 36|0);
 $90 = HEAP32[$89>>2]|0;
 $91 = ($88>>>0)<($90>>>0);
 if (!($91)) {
  $$0 = $84;
  return ($$0|0);
 }
 $92 = $85;
 $93 = $86;
 HEAP32[$1>>2] = $92;
 HEAP32[$2>>2] = $93;
 $94 = (($$0$i) + 3)|0;
 $95 = HEAP32[$1>>2]|0;
 $96 = HEAP32[$0>>2]|0;
 $97 = ((($95)) + 36|0);
 $98 = HEAP32[$97>>2]|0;
 $99 = ((($96)) + 36|0);
 $100 = HEAP32[$99>>2]|0;
 $101 = ($98>>>0)<($100>>>0);
 if (!($101)) {
  $$0 = $94;
  return ($$0|0);
 }
 $102 = $95;
 $103 = $96;
 $104 = (($$0$i) + 4)|0;
 HEAP32[$0>>2] = $102;
 HEAP32[$1>>2] = $103;
 $$0 = $104;
 return ($$0|0);
}
function __ZNSt3__227__insertion_sort_incompleteIR21TraversalOrderFunctorPPN7osgUtil10RenderLeafEEEbT0_S7_T_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$$3 = 0, $$0 = 0, $$06277 = 0, $$06476 = 0, $$06974 = 0, $$06974$phi = 0, $$1 = 0, $$165 = 0, $$170 = 0, $$170$phi = 0, $$3 = 0, $$5 = 0, $$pre = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = $1;
 $4 = $0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 switch ($6|0) {
 case 2:  {
  $7 = ((($1)) + -4|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = HEAP32[$0>>2]|0;
  $10 = ((($8)) + 36|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ((($9)) + 36|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($11>>>0)<($13>>>0);
  if (!($14)) {
   $$5 = 1;
   return ($$5|0);
  }
  $15 = $8;
  $16 = $9;
  HEAP32[$0>>2] = $15;
  HEAP32[$7>>2] = $16;
  $$5 = 1;
  return ($$5|0);
  break;
 }
 case 3:  {
  $17 = ((($0)) + 4|0);
  $18 = ((($1)) + -4|0);
  $19 = HEAP32[$17>>2]|0;
  $20 = HEAP32[$0>>2]|0;
  $21 = ((($19)) + 36|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = ((($20)) + 36|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = ($22>>>0)<($24>>>0);
  $26 = HEAP32[$18>>2]|0;
  $27 = ((($26)) + 36|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = ($28>>>0)<($22>>>0);
  $30 = $19;
  $31 = $26;
  $32 = $20;
  if (!($25)) {
   if (!($29)) {
    $$5 = 1;
    return ($$5|0);
   }
   HEAP32[$17>>2] = $31;
   HEAP32[$18>>2] = $30;
   $33 = HEAP32[$17>>2]|0;
   $34 = HEAP32[$0>>2]|0;
   $35 = ((($33)) + 36|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = ((($34)) + 36|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = ($36>>>0)<($38>>>0);
   if (!($39)) {
    $$5 = 1;
    return ($$5|0);
   }
   $40 = $33;
   $41 = $34;
   HEAP32[$0>>2] = $40;
   HEAP32[$17>>2] = $41;
   $$5 = 1;
   return ($$5|0);
  }
  if ($29) {
   HEAP32[$0>>2] = $31;
   HEAP32[$18>>2] = $32;
   $$5 = 1;
   return ($$5|0);
  }
  HEAP32[$0>>2] = $30;
  HEAP32[$17>>2] = $32;
  $42 = HEAP32[$18>>2]|0;
  $43 = ((($42)) + 36|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = ($44>>>0)<($24>>>0);
  if (!($45)) {
   $$5 = 1;
   return ($$5|0);
  }
  $46 = $42;
  HEAP32[$17>>2] = $46;
  HEAP32[$18>>2] = $32;
  $$5 = 1;
  return ($$5|0);
  break;
 }
 case 4:  {
  $47 = ((($0)) + 4|0);
  $48 = ((($0)) + 8|0);
  $49 = ((($1)) + -4|0);
  $50 = HEAP32[$47>>2]|0;
  $51 = HEAP32[$0>>2]|0;
  $52 = ((($50)) + 36|0);
  $53 = HEAP32[$52>>2]|0;
  $54 = ((($51)) + 36|0);
  $55 = HEAP32[$54>>2]|0;
  $56 = ($53>>>0)<($55>>>0);
  $57 = HEAP32[$48>>2]|0;
  $58 = ((($57)) + 36|0);
  $59 = HEAP32[$58>>2]|0;
  $60 = ($59>>>0)<($53>>>0);
  $61 = $50;
  $62 = $57;
  $63 = $51;
  do {
   if ($56) {
    if ($60) {
     HEAP32[$0>>2] = $62;
     HEAP32[$48>>2] = $63;
     $70 = $51;$74 = $63;
     break;
    }
    HEAP32[$0>>2] = $61;
    HEAP32[$47>>2] = $63;
    $65 = ($59>>>0)<($55>>>0);
    if ($65) {
     HEAP32[$47>>2] = $62;
     HEAP32[$48>>2] = $63;
     $70 = $51;$74 = $63;
    } else {
     $70 = $57;$74 = $62;
    }
   } else {
    if ($60) {
     HEAP32[$47>>2] = $62;
     HEAP32[$48>>2] = $61;
     $64 = ($59>>>0)<($55>>>0);
     if ($64) {
      HEAP32[$0>>2] = $62;
      HEAP32[$47>>2] = $63;
      $70 = $50;$74 = $61;
     } else {
      $70 = $50;$74 = $61;
     }
    } else {
     $70 = $57;$74 = $62;
    }
   }
  } while(0);
  $66 = HEAP32[$49>>2]|0;
  $67 = ((($66)) + 36|0);
  $68 = HEAP32[$67>>2]|0;
  $69 = ((($70)) + 36|0);
  $71 = HEAP32[$69>>2]|0;
  $72 = ($68>>>0)<($71>>>0);
  if (!($72)) {
   $$5 = 1;
   return ($$5|0);
  }
  $73 = $66;
  HEAP32[$48>>2] = $73;
  HEAP32[$49>>2] = $74;
  $75 = HEAP32[$48>>2]|0;
  $76 = HEAP32[$47>>2]|0;
  $77 = ((($75)) + 36|0);
  $78 = HEAP32[$77>>2]|0;
  $79 = ((($76)) + 36|0);
  $80 = HEAP32[$79>>2]|0;
  $81 = ($78>>>0)<($80>>>0);
  if (!($81)) {
   $$5 = 1;
   return ($$5|0);
  }
  $82 = $75;
  $83 = $76;
  HEAP32[$47>>2] = $82;
  HEAP32[$48>>2] = $83;
  $84 = HEAP32[$0>>2]|0;
  $85 = ((($84)) + 36|0);
  $86 = HEAP32[$85>>2]|0;
  $87 = ($78>>>0)<($86>>>0);
  if (!($87)) {
   $$5 = 1;
   return ($$5|0);
  }
  $88 = $84;
  HEAP32[$0>>2] = $82;
  HEAP32[$47>>2] = $88;
  $$5 = 1;
  return ($$5|0);
  break;
 }
 case 5:  {
  $89 = ((($0)) + 4|0);
  $90 = ((($0)) + 8|0);
  $91 = ((($0)) + 12|0);
  $92 = ((($1)) + -4|0);
  (__ZNSt3__27__sort5IR21TraversalOrderFunctorPPN7osgUtil10RenderLeafEEEjT0_S7_S7_S7_S7_T_($0,$89,$90,$91,$92,$2)|0);
  $$5 = 1;
  return ($$5|0);
  break;
 }
 case 1: case 0:  {
  $$5 = 1;
  return ($$5|0);
  break;
 }
 default: {
  $93 = ((($0)) + 8|0);
  $94 = ((($0)) + 4|0);
  $95 = HEAP32[$94>>2]|0;
  $96 = HEAP32[$0>>2]|0;
  $97 = ((($95)) + 36|0);
  $98 = HEAP32[$97>>2]|0;
  $99 = ((($96)) + 36|0);
  $100 = HEAP32[$99>>2]|0;
  $101 = ($98>>>0)<($100>>>0);
  $102 = HEAP32[$93>>2]|0;
  $103 = ((($102)) + 36|0);
  $104 = HEAP32[$103>>2]|0;
  $105 = ($104>>>0)<($98>>>0);
  $106 = $95;
  $107 = $102;
  $108 = $96;
  do {
   if ($101) {
    if ($105) {
     HEAP32[$0>>2] = $107;
     HEAP32[$93>>2] = $108;
     $134 = $96;
     break;
    }
    HEAP32[$0>>2] = $106;
    HEAP32[$94>>2] = $108;
    $110 = ($104>>>0)<($100>>>0);
    if ($110) {
     HEAP32[$94>>2] = $107;
     HEAP32[$93>>2] = $108;
     $134 = $96;
    } else {
     $134 = $102;
    }
   } else {
    if ($105) {
     HEAP32[$94>>2] = $107;
     HEAP32[$93>>2] = $106;
     $109 = ($104>>>0)<($100>>>0);
     if ($109) {
      HEAP32[$0>>2] = $107;
      HEAP32[$94>>2] = $108;
      $134 = $95;
     } else {
      $134 = $95;
     }
    } else {
     $134 = $102;
    }
   }
  } while(0);
  $111 = ((($0)) + 12|0);
  $112 = ($111|0)==($1|0);
  L13: do {
   if ($112) {
    $$1 = 1;$$3 = 0;
   } else {
    $$06277 = $111;$$06476 = 0;$$06974 = $93;$117 = $134;
    while(1) {
     $113 = HEAP32[$$06277>>2]|0;
     $114 = ((($113)) + 36|0);
     $115 = HEAP32[$114>>2]|0;
     $116 = ((($117)) + 36|0);
     $118 = HEAP32[$116>>2]|0;
     $119 = ($115>>>0)<($118>>>0);
     $120 = $113;
     if ($119) {
      $$0 = $$06974;$$170 = $$06277;
      while(1) {
       $121 = HEAP32[$$0>>2]|0;
       HEAP32[$$170>>2] = $121;
       $122 = ($$0|0)==($0|0);
       if ($122) {
        break;
       }
       $123 = ((($$0)) + -4|0);
       $124 = HEAP32[$123>>2]|0;
       $125 = ((($124)) + 36|0);
       $126 = HEAP32[$125>>2]|0;
       $127 = ($115>>>0)<($126>>>0);
       if ($127) {
        $$170$phi = $$0;$$0 = $123;$$170 = $$170$phi;
       } else {
        break;
       }
      }
      HEAP32[$$0>>2] = $120;
      $128 = (($$06476) + 1)|0;
      $129 = ($128|0)==(8);
      $130 = ((($$06277)) + 4|0);
      $131 = ($130|0)==($1|0);
      if ($129) {
       $$1 = 0;$$3 = $131;
       break L13;
      } else {
       $$165 = $128;
      }
     } else {
      $$165 = $$06476;
     }
     $132 = ((($$06277)) + 4|0);
     $133 = ($132|0)==($1|0);
     if ($133) {
      $$1 = 1;$$3 = 0;
      break L13;
     }
     $$pre = HEAP32[$$06277>>2]|0;
     $$06974$phi = $$06277;$$06277 = $132;$$06476 = $$165;$117 = $$pre;$$06974 = $$06974$phi;
    }
   }
  } while(0);
  $$$3 = $$3 | $$1;
  $$5 = $$$3;
  return ($$5|0);
 }
 }
 return (0)|0;
}
function __ZNSt3__26vectorIPN7osgUtil10RenderLeafENS_9allocatorIS3_EEE7reserveEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 $7 = ($6>>>0)<($1>>>0);
 if (!($7)) {
  return;
 }
 $8 = ((($0)) + 4|0);
 $9 = ($1>>>0)>(1073741823);
 if ($9) {
  $10 = (___cxa_allocate_exception(8)|0);
  __THREW__ = 0;
  invoke_vii(3366,($10|0),(204840|0));
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if ($12) {
   $13 = ___cxa_find_matching_catch_2()|0;
   $14 = tempRet0;
   ___cxa_free_exception(($10|0));
   ___resumeException($13|0);
   // unreachable;
  } else {
   HEAP32[$10>>2] = (99824);
   ___cxa_throw(($10|0),(34608|0),(3230|0));
   // unreachable;
  }
 }
 $15 = HEAP32[$8>>2]|0;
 $16 = (($15) - ($4))|0;
 $17 = $16 >> 2;
 $18 = $1 << 2;
 $19 = (__Znwj($18)|0);
 $20 = (($19) + ($17<<2)|0);
 $21 = $20;
 $22 = (($19) + ($1<<2)|0);
 $23 = $22;
 $24 = (0 - ($17))|0;
 $25 = (($20) + ($24<<2)|0);
 $26 = $25;
 $27 = ($16|0)>(0);
 if ($27) {
  $28 = $4;
  _memcpy(($25|0),($28|0),($16|0))|0;
 }
 HEAP32[$0>>2] = $26;
 HEAP32[$8>>2] = $21;
 HEAP32[$2>>2] = $23;
 $29 = ($4|0)==(0);
 if ($29) {
  return;
 }
 $30 = $4;
 __ZdlPv($30);
 return;
}
function __ZNSt3__26vectorIPN7osgUtil10RenderLeafENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(1073741823);
 if ($8) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $9 = ((($0)) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) - ($4))|0;
 $12 = $11 >> 2;
 $13 = ($12>>>0)<(536870911);
 $14 = $11 >> 1;
 $15 = ($14>>>0)<($7>>>0);
 $$sroa$speculated$i = $15 ? $7 : $14;
 $$sroa$speculated$$i = $13 ? $$sroa$speculated$i : 1073741823;
 $16 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($16) {
   $26 = 0;
  } else {
   $17 = ($$sroa$speculated$$i>>>0)>(1073741823);
   if (!($17)) {
    $23 = $$sroa$speculated$$i << 2;
    $24 = (__Znwj($23)|0);
    $26 = $24;
    break;
   }
   $18 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($18|0),(204840|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if ($20) {
    $21 = ___cxa_find_matching_catch_2()|0;
    $22 = tempRet0;
    ___cxa_free_exception(($18|0));
    ___resumeException($21|0);
    // unreachable;
   } else {
    HEAP32[$18>>2] = (99824);
    ___cxa_throw(($18|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $25 = (($26) + ($6<<2)|0);
 $27 = (($26) + ($$sroa$speculated$$i<<2)|0);
 $28 = $27;
 $29 = HEAP32[$1>>2]|0;
 HEAP32[$25>>2] = $29;
 $30 = ((($25)) + 4|0);
 $31 = $30;
 $32 = (0 - ($6))|0;
 $33 = (($25) + ($32<<2)|0);
 $34 = $33;
 $35 = ($5|0)>(0);
 if ($35) {
  $36 = $4;
  _memcpy(($33|0),($36|0),($5|0))|0;
 }
 HEAP32[$0>>2] = $34;
 HEAP32[$2>>2] = $31;
 HEAP32[$9>>2] = $28;
 $37 = ($4|0)==(0);
 if ($37) {
  return;
 }
 $38 = $4;
 __ZdlPv($38);
 return;
}
function __ZNSt3__26__sortIR22BackToFrontSortFunctorPPN7osgUtil10RenderLeafEEEvT0_S7_T_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$$0174 = 0, $$0 = 0, $$0$i189 = 0, $$0$ph = 0, $$0154 = 0, $$0160241 = 0, $$0167 = 0, $$0174 = 0, $$0180$ph = 0, $$02933$i = 0, $$03032$i = 0, $$03032$i$phi = 0, $$1 = 0, $$1$i = 0, $$1$i$phi = 0, $$1155 = 0, $$1161 = 0, $$2156 = 0, $$2162 = 0, $$2176 = 0;
 var $$3157 = 0, $$3163 = 0, $$3170 = 0, $$4158 = 0, $$4164 = 0, $$4171 = 0, $$5159 = 0, $$5165 = 0, $$5172 = 0, $$6166 = 0, $$6173 = 0, $$pre$i190 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0.0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0.0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0.0, $115 = 0, $116 = 0.0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0.0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0.0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0.0, $139 = 0, $14 = 0, $140 = 0.0, $141 = 0, $142 = 0;
 var $143 = 0, $144 = 0.0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0.0, $153 = 0, $154 = 0.0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0.0;
 var $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0.0, $167 = 0, $168 = 0.0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0.0, $176 = 0, $177 = 0, $178 = 0, $179 = 0;
 var $18 = 0, $180 = 0, $181 = 0.0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0.0, $191 = 0, $192 = 0, $193 = 0.0, $194 = 0, $195 = 0, $196 = 0, $197 = 0;
 var $198 = 0, $199 = 0, $20 = 0, $200 = 0.0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0.0, $207 = 0, $208 = 0, $209 = 0, $21 = 0.0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0.0;
 var $216 = 0, $217 = 0, $218 = 0.0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0.0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0.0, $230 = 0, $231 = 0, $232 = 0, $233 = 0;
 var $234 = 0, $235 = 0.0, $236 = 0, $237 = 0.0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0;
 var $252 = 0, $26 = 0, $27 = 0.0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0.0, $36 = 0, $37 = 0.0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0.0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0.0, $52 = 0, $53 = 0.0, $54 = 0, $55 = 0, $56 = 0, $57 = 0.0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0.0, $68 = 0, $69 = 0.0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0.0, $77 = 0, $78 = 0.0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0.0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0.0, $97 = 0;
 var $98 = 0.0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$0$ph = $0;$$0180$ph = $1;
 L1: while(1) {
  $3 = $$0180$ph;
  $4 = ((($$0180$ph)) + -4|0);
  $$0 = $$0$ph;
  while(1) {
   $$1 = $$0;
   L5: while(1) {
    $5 = $$1;
    $6 = (($3) - ($5))|0;
    $7 = $6 >> 2;
    switch ($7|0) {
    case 2:  {
     label = 5;
     break L1;
     break;
    }
    case 3:  {
     label = 7;
     break L1;
     break;
    }
    case 4:  {
     label = 15;
     break L1;
     break;
    }
    case 5:  {
     label = 27;
     break L1;
     break;
    }
    case 1: case 0:  {
     label = 87;
     break L1;
     break;
    }
    default: {
    }
    }
    $90 = ($6|0)<(124);
    if ($90) {
     label = 29;
     break L1;
    }
    $128 = ($6|0)>(3996);
    $129 = (($7|0) / 2)&-1;
    $130 = (($$1) + ($129<<2)|0);
    do {
     if ($128) {
      $131 = (($7|0) / 4)&-1;
      $132 = (($$1) + ($131<<2)|0);
      $133 = (($130) + ($131<<2)|0);
      $134 = (__ZNSt3__27__sort5IR22BackToFrontSortFunctorPPN7osgUtil10RenderLeafEEEjT0_S7_S7_S7_S7_T_($$1,$132,$130,$133,$4,$2)|0);
      $$0167 = $134;
     } else {
      $135 = HEAP32[$130>>2]|0;
      $136 = HEAP32[$$1>>2]|0;
      $137 = ((($136)) + 28|0);
      $138 = +HEAPF32[$137>>2];
      $139 = ((($135)) + 28|0);
      $140 = +HEAPF32[$139>>2];
      $141 = $138 < $140;
      $142 = HEAP32[$4>>2]|0;
      $143 = ((($142)) + 28|0);
      $144 = +HEAPF32[$143>>2];
      $145 = $140 < $144;
      $146 = $135;
      $147 = $142;
      $148 = $136;
      if (!($141)) {
       if (!($145)) {
        $$0167 = 0;
        break;
       }
       HEAP32[$130>>2] = $147;
       HEAP32[$4>>2] = $146;
       $149 = HEAP32[$130>>2]|0;
       $150 = HEAP32[$$1>>2]|0;
       $151 = ((($150)) + 28|0);
       $152 = +HEAPF32[$151>>2];
       $153 = ((($149)) + 28|0);
       $154 = +HEAPF32[$153>>2];
       $155 = $152 < $154;
       if (!($155)) {
        $$0167 = 1;
        break;
       }
       $156 = $149;
       $157 = $150;
       HEAP32[$$1>>2] = $156;
       HEAP32[$130>>2] = $157;
       $$0167 = 2;
       break;
      }
      if ($145) {
       HEAP32[$$1>>2] = $147;
       HEAP32[$4>>2] = $148;
       $$0167 = 1;
       break;
      }
      HEAP32[$$1>>2] = $146;
      HEAP32[$130>>2] = $148;
      $158 = HEAP32[$4>>2]|0;
      $159 = ((($158)) + 28|0);
      $160 = +HEAPF32[$159>>2];
      $161 = $138 < $160;
      if ($161) {
       $162 = $158;
       HEAP32[$130>>2] = $162;
       HEAP32[$4>>2] = $148;
       $$0167 = 2;
      } else {
       $$0167 = 1;
      }
     }
    } while(0);
    $163 = HEAP32[$$1>>2]|0;
    $164 = HEAP32[$130>>2]|0;
    $165 = ((($164)) + 28|0);
    $166 = +HEAPF32[$165>>2];
    $167 = ((($163)) + 28|0);
    $168 = +HEAPF32[$167>>2];
    $169 = $166 < $168;
    if ($169) {
     $$3157 = $4;$$3170 = $$0167;
     break;
    } else {
     $$0154 = $4;
    }
    while(1) {
     $170 = ((($$0154)) + -4|0);
     $171 = ($$1|0)==($170|0);
     if ($171) {
      break;
     }
     $204 = HEAP32[$170>>2]|0;
     $205 = ((($204)) + 28|0);
     $206 = +HEAPF32[$205>>2];
     $207 = $166 < $206;
     if ($207) {
      label = 69;
      break L5;
     } else {
      $$0154 = $170;
     }
    }
    $172 = ((($$1)) + 4|0);
    $173 = HEAP32[$4>>2]|0;
    $174 = ((($173)) + 28|0);
    $175 = +HEAPF32[$174>>2];
    $176 = $175 < $168;
    $177 = $173;
    if ($176) {
     $$1161 = $172;
    } else {
     $178 = ($172|0)==($4|0);
     if ($178) {
      label = 87;
      break L1;
     } else {
      $$0160241 = $172;
     }
     while(1) {
      $179 = HEAP32[$$0160241>>2]|0;
      $180 = ((($179)) + 28|0);
      $181 = +HEAPF32[$180>>2];
      $182 = $181 < $168;
      if ($182) {
       break;
      }
      $185 = ((($$0160241)) + 4|0);
      $186 = ($185|0)==($4|0);
      if ($186) {
       label = 87;
       break L1;
      } else {
       $$0160241 = $185;
      }
     }
     $183 = $179;
     HEAP32[$$0160241>>2] = $177;
     HEAP32[$4>>2] = $183;
     $184 = ((($$0160241)) + 4|0);
     $$1161 = $184;
    }
    $187 = ($$1161|0)==($4|0);
    if ($187) {
     label = 87;
     break L1;
    } else {
     $$1155 = $4;$$2162 = $$1161;
    }
    while(1) {
     $188 = HEAP32[$$1>>2]|0;
     $189 = ((($188)) + 28|0);
     $190 = +HEAPF32[$189>>2];
     $$3163 = $$2162;
     while(1) {
      $191 = HEAP32[$$3163>>2]|0;
      $192 = ((($191)) + 28|0);
      $193 = +HEAPF32[$192>>2];
      $194 = $193 < $190;
      $195 = ((($$3163)) + 4|0);
      if ($194) {
       break;
      } else {
       $$3163 = $195;
      }
     }
     $196 = $191;
     $$2156 = $$1155;
     while(1) {
      $197 = ((($$2156)) + -4|0);
      $198 = HEAP32[$197>>2]|0;
      $199 = ((($198)) + 28|0);
      $200 = +HEAPF32[$199>>2];
      $201 = $200 < $190;
      if ($201) {
       $$2156 = $197;
      } else {
       break;
      }
     }
     $202 = ($$3163>>>0)<($197>>>0);
     if (!($202)) {
      $$1 = $$3163;
      continue L5;
     }
     $203 = $198;
     HEAP32[$$3163>>2] = $203;
     HEAP32[$197>>2] = $196;
     $$1155 = $197;$$2162 = $195;
    }
   }
   if ((label|0) == 69) {
    label = 0;
    $208 = $163;
    $209 = $204;
    HEAP32[$$1>>2] = $209;
    HEAP32[$170>>2] = $208;
    $210 = (($$0167) + 1)|0;
    $$3157 = $170;$$3170 = $210;
   }
   $211 = ((($$1)) + 4|0);
   $212 = ($211>>>0)<($$3157>>>0);
   L45: do {
    if ($212) {
     $$0174 = $130;$$4158 = $$3157;$$4164 = $211;$$4171 = $$3170;
     while(1) {
      $213 = HEAP32[$$0174>>2]|0;
      $214 = ((($213)) + 28|0);
      $215 = +HEAPF32[$214>>2];
      $$5165 = $$4164;
      while(1) {
       $216 = HEAP32[$$5165>>2]|0;
       $217 = ((($216)) + 28|0);
       $218 = +HEAPF32[$217>>2];
       $219 = $215 < $218;
       $220 = ((($$5165)) + 4|0);
       if ($219) {
        $$5165 = $220;
       } else {
        break;
       }
      }
      $221 = $216;
      $$5159 = $$4158;
      while(1) {
       $222 = ((($$5159)) + -4|0);
       $223 = HEAP32[$222>>2]|0;
       $224 = ((($223)) + 28|0);
       $225 = +HEAPF32[$224>>2];
       $226 = $215 < $225;
       if ($226) {
        break;
       } else {
        $$5159 = $222;
       }
      }
      $227 = ($$5165>>>0)>($222>>>0);
      if ($227) {
       $$2176 = $$0174;$$5172 = $$4171;$$6166 = $$5165;
       break L45;
      }
      $228 = $223;
      HEAP32[$$5165>>2] = $228;
      HEAP32[$222>>2] = $221;
      $229 = (($$4171) + 1)|0;
      $230 = ($$0174|0)==($$5165|0);
      $$$0174 = $230 ? $222 : $$0174;
      $$0174 = $$$0174;$$4158 = $222;$$4164 = $220;$$4171 = $229;
     }
    } else {
     $$2176 = $130;$$5172 = $$3170;$$6166 = $211;
    }
   } while(0);
   $231 = ($$6166|0)==($$2176|0);
   if ($231) {
    $$6173 = $$5172;
   } else {
    $232 = HEAP32[$$2176>>2]|0;
    $233 = HEAP32[$$6166>>2]|0;
    $234 = ((($233)) + 28|0);
    $235 = +HEAPF32[$234>>2];
    $236 = ((($232)) + 28|0);
    $237 = +HEAPF32[$236>>2];
    $238 = $235 < $237;
    if ($238) {
     $239 = $232;
     $240 = $233;
     $241 = (($$5172) + 1)|0;
     HEAP32[$$6166>>2] = $239;
     HEAP32[$$2176>>2] = $240;
     $$6173 = $241;
    } else {
     $$6173 = $$5172;
    }
   }
   $242 = ($$6173|0)==(0);
   if ($242) {
    $243 = (__ZNSt3__227__insertion_sort_incompleteIR22BackToFrontSortFunctorPPN7osgUtil10RenderLeafEEEbT0_S7_T_($$1,$$6166,$2)|0);
    $244 = ((($$6166)) + 4|0);
    $245 = (__ZNSt3__227__insertion_sort_incompleteIR22BackToFrontSortFunctorPPN7osgUtil10RenderLeafEEEbT0_S7_T_($244,$$0180$ph,$2)|0);
    if ($245) {
     label = 86;
     break;
    }
    if ($243) {
     $$0 = $244;
     continue;
    }
   }
   $246 = $$6166;
   $247 = (($246) - ($5))|0;
   $248 = (($3) - ($246))|0;
   $249 = ($247|0)<($248|0);
   if (!($249)) {
    label = 85;
    break;
   }
   __ZNSt3__26__sortIR22BackToFrontSortFunctorPPN7osgUtil10RenderLeafEEEvT0_S7_T_($$1,$$6166,$2);
   $250 = ((($$6166)) + 4|0);
   $$0 = $250;
  }
  if ((label|0) == 85) {
   label = 0;
   $251 = ((($$6166)) + 4|0);
   __ZNSt3__26__sortIR22BackToFrontSortFunctorPPN7osgUtil10RenderLeafEEEvT0_S7_T_($251,$$0180$ph,$2);
   $$0$ph = $$1;$$0180$ph = $$6166;
   continue;
  }
  else if ((label|0) == 86) {
   label = 0;
   if ($243) {
    label = 87;
    break;
   } else {
    $$0$ph = $$1;$$0180$ph = $$6166;
    continue;
   }
  }
 }
 if ((label|0) == 5) {
  $8 = HEAP32[$4>>2]|0;
  $9 = HEAP32[$$1>>2]|0;
  $10 = ((($9)) + 28|0);
  $11 = +HEAPF32[$10>>2];
  $12 = ((($8)) + 28|0);
  $13 = +HEAPF32[$12>>2];
  $14 = $11 < $13;
  if (!($14)) {
   return;
  }
  $15 = $8;
  $16 = $9;
  HEAP32[$$1>>2] = $15;
  HEAP32[$4>>2] = $16;
  return;
 }
 else if ((label|0) == 7) {
  $17 = ((($$1)) + 4|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = HEAP32[$$1>>2]|0;
  $20 = ((($19)) + 28|0);
  $21 = +HEAPF32[$20>>2];
  $22 = ((($18)) + 28|0);
  $23 = +HEAPF32[$22>>2];
  $24 = $21 < $23;
  $25 = HEAP32[$4>>2]|0;
  $26 = ((($25)) + 28|0);
  $27 = +HEAPF32[$26>>2];
  $28 = $23 < $27;
  $29 = $18;
  $30 = $25;
  $31 = $19;
  if (!($24)) {
   if (!($28)) {
    return;
   }
   HEAP32[$17>>2] = $30;
   HEAP32[$4>>2] = $29;
   $32 = HEAP32[$17>>2]|0;
   $33 = HEAP32[$$1>>2]|0;
   $34 = ((($33)) + 28|0);
   $35 = +HEAPF32[$34>>2];
   $36 = ((($32)) + 28|0);
   $37 = +HEAPF32[$36>>2];
   $38 = $35 < $37;
   if (!($38)) {
    return;
   }
   $39 = $32;
   $40 = $33;
   HEAP32[$$1>>2] = $39;
   HEAP32[$17>>2] = $40;
   return;
  }
  if ($28) {
   HEAP32[$$1>>2] = $30;
   HEAP32[$4>>2] = $31;
   return;
  }
  HEAP32[$$1>>2] = $29;
  HEAP32[$17>>2] = $31;
  $41 = HEAP32[$4>>2]|0;
  $42 = ((($41)) + 28|0);
  $43 = +HEAPF32[$42>>2];
  $44 = $21 < $43;
  if (!($44)) {
   return;
  }
  $45 = $41;
  HEAP32[$17>>2] = $45;
  HEAP32[$4>>2] = $31;
  return;
 }
 else if ((label|0) == 15) {
  $46 = ((($$1)) + 4|0);
  $47 = ((($$1)) + 8|0);
  $48 = HEAP32[$46>>2]|0;
  $49 = HEAP32[$$1>>2]|0;
  $50 = ((($49)) + 28|0);
  $51 = +HEAPF32[$50>>2];
  $52 = ((($48)) + 28|0);
  $53 = +HEAPF32[$52>>2];
  $54 = $51 < $53;
  $55 = HEAP32[$47>>2]|0;
  $56 = ((($55)) + 28|0);
  $57 = +HEAPF32[$56>>2];
  $58 = $53 < $57;
  $59 = $48;
  $60 = $55;
  $61 = $49;
  do {
   if ($54) {
    if ($58) {
     HEAP32[$$1>>2] = $60;
     HEAP32[$47>>2] = $61;
     $66 = $49;$72 = $61;
     break;
    }
    HEAP32[$$1>>2] = $59;
    HEAP32[$46>>2] = $61;
    $63 = $51 < $57;
    if ($63) {
     HEAP32[$46>>2] = $60;
     HEAP32[$47>>2] = $61;
     $66 = $49;$72 = $61;
    } else {
     $66 = $55;$72 = $60;
    }
   } else {
    if ($58) {
     HEAP32[$46>>2] = $60;
     HEAP32[$47>>2] = $59;
     $62 = $51 < $57;
     if ($62) {
      HEAP32[$$1>>2] = $60;
      HEAP32[$46>>2] = $61;
      $66 = $48;$72 = $59;
     } else {
      $66 = $48;$72 = $59;
     }
    } else {
     $66 = $55;$72 = $60;
    }
   }
  } while(0);
  $64 = HEAP32[$4>>2]|0;
  $65 = ((($66)) + 28|0);
  $67 = +HEAPF32[$65>>2];
  $68 = ((($64)) + 28|0);
  $69 = +HEAPF32[$68>>2];
  $70 = $67 < $69;
  if (!($70)) {
   return;
  }
  $71 = $64;
  HEAP32[$47>>2] = $71;
  HEAP32[$4>>2] = $72;
  $73 = HEAP32[$47>>2]|0;
  $74 = HEAP32[$46>>2]|0;
  $75 = ((($74)) + 28|0);
  $76 = +HEAPF32[$75>>2];
  $77 = ((($73)) + 28|0);
  $78 = +HEAPF32[$77>>2];
  $79 = $76 < $78;
  if (!($79)) {
   return;
  }
  $80 = $73;
  $81 = $74;
  HEAP32[$46>>2] = $80;
  HEAP32[$47>>2] = $81;
  $82 = HEAP32[$$1>>2]|0;
  $83 = ((($82)) + 28|0);
  $84 = +HEAPF32[$83>>2];
  $85 = $84 < $78;
  if (!($85)) {
   return;
  }
  $86 = $82;
  HEAP32[$$1>>2] = $80;
  HEAP32[$46>>2] = $86;
  return;
 }
 else if ((label|0) == 27) {
  $87 = ((($$1)) + 4|0);
  $88 = ((($$1)) + 8|0);
  $89 = ((($$1)) + 12|0);
  (__ZNSt3__27__sort5IR22BackToFrontSortFunctorPPN7osgUtil10RenderLeafEEEjT0_S7_S7_S7_S7_T_($$1,$87,$88,$89,$4,$2)|0);
  return;
 }
 else if ((label|0) == 29) {
  $91 = ((($$1)) + 8|0);
  $92 = ((($$1)) + 4|0);
  $93 = HEAP32[$92>>2]|0;
  $94 = HEAP32[$$1>>2]|0;
  $95 = ((($94)) + 28|0);
  $96 = +HEAPF32[$95>>2];
  $97 = ((($93)) + 28|0);
  $98 = +HEAPF32[$97>>2];
  $99 = $96 < $98;
  $100 = HEAP32[$91>>2]|0;
  $101 = ((($100)) + 28|0);
  $102 = +HEAPF32[$101>>2];
  $103 = $98 < $102;
  $104 = $93;
  $105 = $100;
  $106 = $94;
  do {
   if ($99) {
    if ($103) {
     HEAP32[$$1>>2] = $105;
     HEAP32[$91>>2] = $106;
     $252 = $94;
     break;
    }
    HEAP32[$$1>>2] = $104;
    HEAP32[$92>>2] = $106;
    $108 = $96 < $102;
    if ($108) {
     HEAP32[$92>>2] = $105;
     HEAP32[$91>>2] = $106;
     $252 = $94;
    } else {
     $252 = $100;
    }
   } else {
    if ($103) {
     HEAP32[$92>>2] = $105;
     HEAP32[$91>>2] = $104;
     $107 = $96 < $102;
     if ($107) {
      HEAP32[$$1>>2] = $105;
      HEAP32[$92>>2] = $106;
      $252 = $93;
     } else {
      $252 = $93;
     }
    } else {
     $252 = $100;
    }
   }
  } while(0);
  $109 = ((($$1)) + 12|0);
  $110 = ($109|0)==($$0180$ph|0);
  if ($110) {
   return;
  } else {
   $$02933$i = $109;$$03032$i = $91;$113 = $252;
  }
  while(1) {
   $111 = HEAP32[$$02933$i>>2]|0;
   $112 = ((($113)) + 28|0);
   $114 = +HEAPF32[$112>>2];
   $115 = ((($111)) + 28|0);
   $116 = +HEAPF32[$115>>2];
   $117 = $114 < $116;
   $118 = $111;
   if ($117) {
    $$0$i189 = $$03032$i;$$1$i = $$02933$i;
    while(1) {
     $119 = HEAP32[$$0$i189>>2]|0;
     HEAP32[$$1$i>>2] = $119;
     $120 = ($$0$i189|0)==($$1|0);
     if ($120) {
      break;
     }
     $121 = ((($$0$i189)) + -4|0);
     $122 = HEAP32[$121>>2]|0;
     $123 = ((($122)) + 28|0);
     $124 = +HEAPF32[$123>>2];
     $125 = $124 < $116;
     if ($125) {
      $$1$i$phi = $$0$i189;$$0$i189 = $121;$$1$i = $$1$i$phi;
     } else {
      break;
     }
    }
    HEAP32[$$0$i189>>2] = $118;
   }
   $126 = ((($$02933$i)) + 4|0);
   $127 = ($126|0)==($$0180$ph|0);
   if ($127) {
    break;
   }
   $$pre$i190 = HEAP32[$$02933$i>>2]|0;
   $$03032$i$phi = $$02933$i;$$02933$i = $126;$113 = $$pre$i190;$$03032$i = $$03032$i$phi;
  }
  return;
 }
 else if ((label|0) == 87) {
  return;
 }
}
function __ZNSt3__27__sort5IR22BackToFrontSortFunctorPPN7osgUtil10RenderLeafEEEjT0_S7_S7_S7_S7_T_($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$0 = 0, $$0$i = 0, $$026$i$i = 0, $$pre$i = 0, $10 = 0, $100 = 0.0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $11 = 0.0, $12 = 0, $13 = 0, $14 = 0, $15 = 0.0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0.0, $24 = 0, $25 = 0.0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0.0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0.0, $39 = 0, $40 = 0.0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0.0, $49 = 0, $50 = 0.0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0.0, $59 = 0, $6 = 0;
 var $60 = 0.0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0.0, $69 = 0, $7 = 0, $70 = 0.0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0.0;
 var $79 = 0, $8 = 0, $80 = 0.0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0.0, $89 = 0, $9 = 0.0, $90 = 0.0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0.0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $6 = HEAP32[$1>>2]|0;
 $7 = HEAP32[$0>>2]|0;
 $8 = ((($7)) + 28|0);
 $9 = +HEAPF32[$8>>2];
 $10 = ((($6)) + 28|0);
 $11 = +HEAPF32[$10>>2];
 $12 = $9 < $11;
 $13 = HEAP32[$2>>2]|0;
 $14 = ((($13)) + 28|0);
 $15 = +HEAPF32[$14>>2];
 $16 = $11 < $15;
 $17 = $6;
 $18 = $13;
 $19 = $7;
 do {
  if ($12) {
   if ($16) {
    HEAP32[$0>>2] = $18;
    HEAP32[$2>>2] = $19;
    $$026$i$i = 1;$37 = $7;$43 = $19;
    break;
   }
   HEAP32[$0>>2] = $17;
   HEAP32[$1>>2] = $19;
   $30 = HEAP32[$2>>2]|0;
   $31 = ((($30)) + 28|0);
   $32 = +HEAPF32[$31>>2];
   $33 = $9 < $32;
   $34 = $30;
   if ($33) {
    HEAP32[$1>>2] = $34;
    HEAP32[$2>>2] = $19;
    $$026$i$i = 2;$37 = $7;$43 = $19;
   } else {
    $$026$i$i = 1;$37 = $30;$43 = $34;
   }
  } else {
   if ($16) {
    HEAP32[$1>>2] = $18;
    HEAP32[$2>>2] = $17;
    $20 = HEAP32[$1>>2]|0;
    $21 = HEAP32[$0>>2]|0;
    $22 = ((($21)) + 28|0);
    $23 = +HEAPF32[$22>>2];
    $24 = ((($20)) + 28|0);
    $25 = +HEAPF32[$24>>2];
    $26 = $23 < $25;
    if ($26) {
     $27 = $20;
     $28 = $21;
     HEAP32[$0>>2] = $27;
     HEAP32[$1>>2] = $28;
     $$pre$i = HEAP32[$2>>2]|0;
     $29 = $$pre$i;
     $$026$i$i = 2;$37 = $$pre$i;$43 = $29;
    } else {
     $$026$i$i = 1;$37 = $6;$43 = $17;
    }
   } else {
    $$026$i$i = 0;$37 = $13;$43 = $18;
   }
  }
 } while(0);
 $35 = HEAP32[$3>>2]|0;
 $36 = ((($37)) + 28|0);
 $38 = +HEAPF32[$36>>2];
 $39 = ((($35)) + 28|0);
 $40 = +HEAPF32[$39>>2];
 $41 = $38 < $40;
 if ($41) {
  $42 = $35;
  HEAP32[$2>>2] = $42;
  HEAP32[$3>>2] = $43;
  $44 = (($$026$i$i) + 1)|0;
  $45 = HEAP32[$2>>2]|0;
  $46 = HEAP32[$1>>2]|0;
  $47 = ((($46)) + 28|0);
  $48 = +HEAPF32[$47>>2];
  $49 = ((($45)) + 28|0);
  $50 = +HEAPF32[$49>>2];
  $51 = $48 < $50;
  if ($51) {
   $52 = $45;
   $53 = $46;
   HEAP32[$1>>2] = $52;
   HEAP32[$2>>2] = $53;
   $54 = (($$026$i$i) + 2)|0;
   $55 = HEAP32[$1>>2]|0;
   $56 = HEAP32[$0>>2]|0;
   $57 = ((($56)) + 28|0);
   $58 = +HEAPF32[$57>>2];
   $59 = ((($55)) + 28|0);
   $60 = +HEAPF32[$59>>2];
   $61 = $58 < $60;
   if ($61) {
    $62 = (($$026$i$i) + 3)|0;
    $63 = $56;
    $64 = $55;
    HEAP32[$0>>2] = $64;
    HEAP32[$1>>2] = $63;
    $$0$i = $62;
   } else {
    $$0$i = $54;
   }
  } else {
   $$0$i = $44;
  }
 } else {
  $$0$i = $$026$i$i;
 }
 $65 = HEAP32[$4>>2]|0;
 $66 = HEAP32[$3>>2]|0;
 $67 = ((($66)) + 28|0);
 $68 = +HEAPF32[$67>>2];
 $69 = ((($65)) + 28|0);
 $70 = +HEAPF32[$69>>2];
 $71 = $68 < $70;
 if (!($71)) {
  $$0 = $$0$i;
  return ($$0|0);
 }
 $72 = $65;
 $73 = $66;
 HEAP32[$3>>2] = $72;
 HEAP32[$4>>2] = $73;
 $74 = (($$0$i) + 1)|0;
 $75 = HEAP32[$3>>2]|0;
 $76 = HEAP32[$2>>2]|0;
 $77 = ((($76)) + 28|0);
 $78 = +HEAPF32[$77>>2];
 $79 = ((($75)) + 28|0);
 $80 = +HEAPF32[$79>>2];
 $81 = $78 < $80;
 if (!($81)) {
  $$0 = $74;
  return ($$0|0);
 }
 $82 = $75;
 $83 = $76;
 HEAP32[$2>>2] = $82;
 HEAP32[$3>>2] = $83;
 $84 = (($$0$i) + 2)|0;
 $85 = HEAP32[$2>>2]|0;
 $86 = HEAP32[$1>>2]|0;
 $87 = ((($86)) + 28|0);
 $88 = +HEAPF32[$87>>2];
 $89 = ((($85)) + 28|0);
 $90 = +HEAPF32[$89>>2];
 $91 = $88 < $90;
 if (!($91)) {
  $$0 = $84;
  return ($$0|0);
 }
 $92 = $85;
 $93 = $86;
 HEAP32[$1>>2] = $92;
 HEAP32[$2>>2] = $93;
 $94 = (($$0$i) + 3)|0;
 $95 = HEAP32[$1>>2]|0;
 $96 = HEAP32[$0>>2]|0;
 $97 = ((($96)) + 28|0);
 $98 = +HEAPF32[$97>>2];
 $99 = ((($95)) + 28|0);
 $100 = +HEAPF32[$99>>2];
 $101 = $98 < $100;
 if (!($101)) {
  $$0 = $94;
  return ($$0|0);
 }
 $102 = $95;
 $103 = $96;
 $104 = (($$0$i) + 4)|0;
 HEAP32[$0>>2] = $102;
 HEAP32[$1>>2] = $103;
 $$0 = $104;
 return ($$0|0);
}
function __ZNSt3__227__insertion_sort_incompleteIR22BackToFrontSortFunctorPPN7osgUtil10RenderLeafEEEbT0_S7_T_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$$3 = 0, $$0 = 0, $$06277 = 0, $$06476 = 0, $$06974 = 0, $$06974$phi = 0, $$1 = 0, $$165 = 0, $$170 = 0, $$170$phi = 0, $$3 = 0, $$5 = 0, $$pre = 0, $10 = 0, $100 = 0.0, $101 = 0, $102 = 0, $103 = 0, $104 = 0.0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0.0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0.0, $117 = 0, $118 = 0.0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0.0, $127 = 0, $128 = 0, $129 = 0, $13 = 0.0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0;
 var $22 = 0.0, $23 = 0, $24 = 0.0, $25 = 0, $26 = 0, $27 = 0, $28 = 0.0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0.0, $37 = 0, $38 = 0.0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0.0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0.0, $54 = 0, $55 = 0.0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0.0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0.0, $7 = 0, $70 = 0, $71 = 0.0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0.0, $79 = 0, $8 = 0, $80 = 0.0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0.0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0.0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = $1;
 $4 = $0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 switch ($6|0) {
 case 2:  {
  $7 = ((($1)) + -4|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = HEAP32[$0>>2]|0;
  $10 = ((($9)) + 28|0);
  $11 = +HEAPF32[$10>>2];
  $12 = ((($8)) + 28|0);
  $13 = +HEAPF32[$12>>2];
  $14 = $11 < $13;
  if (!($14)) {
   $$5 = 1;
   return ($$5|0);
  }
  $15 = $8;
  $16 = $9;
  HEAP32[$0>>2] = $15;
  HEAP32[$7>>2] = $16;
  $$5 = 1;
  return ($$5|0);
  break;
 }
 case 3:  {
  $17 = ((($0)) + 4|0);
  $18 = ((($1)) + -4|0);
  $19 = HEAP32[$17>>2]|0;
  $20 = HEAP32[$0>>2]|0;
  $21 = ((($20)) + 28|0);
  $22 = +HEAPF32[$21>>2];
  $23 = ((($19)) + 28|0);
  $24 = +HEAPF32[$23>>2];
  $25 = $22 < $24;
  $26 = HEAP32[$18>>2]|0;
  $27 = ((($26)) + 28|0);
  $28 = +HEAPF32[$27>>2];
  $29 = $24 < $28;
  $30 = $19;
  $31 = $26;
  $32 = $20;
  if (!($25)) {
   if (!($29)) {
    $$5 = 1;
    return ($$5|0);
   }
   HEAP32[$17>>2] = $31;
   HEAP32[$18>>2] = $30;
   $33 = HEAP32[$17>>2]|0;
   $34 = HEAP32[$0>>2]|0;
   $35 = ((($34)) + 28|0);
   $36 = +HEAPF32[$35>>2];
   $37 = ((($33)) + 28|0);
   $38 = +HEAPF32[$37>>2];
   $39 = $36 < $38;
   if (!($39)) {
    $$5 = 1;
    return ($$5|0);
   }
   $40 = $33;
   $41 = $34;
   HEAP32[$0>>2] = $40;
   HEAP32[$17>>2] = $41;
   $$5 = 1;
   return ($$5|0);
  }
  if ($29) {
   HEAP32[$0>>2] = $31;
   HEAP32[$18>>2] = $32;
   $$5 = 1;
   return ($$5|0);
  }
  HEAP32[$0>>2] = $30;
  HEAP32[$17>>2] = $32;
  $42 = HEAP32[$18>>2]|0;
  $43 = ((($42)) + 28|0);
  $44 = +HEAPF32[$43>>2];
  $45 = $22 < $44;
  if (!($45)) {
   $$5 = 1;
   return ($$5|0);
  }
  $46 = $42;
  HEAP32[$17>>2] = $46;
  HEAP32[$18>>2] = $32;
  $$5 = 1;
  return ($$5|0);
  break;
 }
 case 4:  {
  $47 = ((($0)) + 4|0);
  $48 = ((($0)) + 8|0);
  $49 = ((($1)) + -4|0);
  $50 = HEAP32[$47>>2]|0;
  $51 = HEAP32[$0>>2]|0;
  $52 = ((($51)) + 28|0);
  $53 = +HEAPF32[$52>>2];
  $54 = ((($50)) + 28|0);
  $55 = +HEAPF32[$54>>2];
  $56 = $53 < $55;
  $57 = HEAP32[$48>>2]|0;
  $58 = ((($57)) + 28|0);
  $59 = +HEAPF32[$58>>2];
  $60 = $55 < $59;
  $61 = $50;
  $62 = $57;
  $63 = $51;
  do {
   if ($56) {
    if ($60) {
     HEAP32[$0>>2] = $62;
     HEAP32[$48>>2] = $63;
     $68 = $51;$74 = $63;
     break;
    }
    HEAP32[$0>>2] = $61;
    HEAP32[$47>>2] = $63;
    $65 = $53 < $59;
    if ($65) {
     HEAP32[$47>>2] = $62;
     HEAP32[$48>>2] = $63;
     $68 = $51;$74 = $63;
    } else {
     $68 = $57;$74 = $62;
    }
   } else {
    if ($60) {
     HEAP32[$47>>2] = $62;
     HEAP32[$48>>2] = $61;
     $64 = $53 < $59;
     if ($64) {
      HEAP32[$0>>2] = $62;
      HEAP32[$47>>2] = $63;
      $68 = $50;$74 = $61;
     } else {
      $68 = $50;$74 = $61;
     }
    } else {
     $68 = $57;$74 = $62;
    }
   }
  } while(0);
  $66 = HEAP32[$49>>2]|0;
  $67 = ((($68)) + 28|0);
  $69 = +HEAPF32[$67>>2];
  $70 = ((($66)) + 28|0);
  $71 = +HEAPF32[$70>>2];
  $72 = $69 < $71;
  if (!($72)) {
   $$5 = 1;
   return ($$5|0);
  }
  $73 = $66;
  HEAP32[$48>>2] = $73;
  HEAP32[$49>>2] = $74;
  $75 = HEAP32[$48>>2]|0;
  $76 = HEAP32[$47>>2]|0;
  $77 = ((($76)) + 28|0);
  $78 = +HEAPF32[$77>>2];
  $79 = ((($75)) + 28|0);
  $80 = +HEAPF32[$79>>2];
  $81 = $78 < $80;
  if (!($81)) {
   $$5 = 1;
   return ($$5|0);
  }
  $82 = $75;
  $83 = $76;
  HEAP32[$47>>2] = $82;
  HEAP32[$48>>2] = $83;
  $84 = HEAP32[$0>>2]|0;
  $85 = ((($84)) + 28|0);
  $86 = +HEAPF32[$85>>2];
  $87 = $86 < $80;
  if (!($87)) {
   $$5 = 1;
   return ($$5|0);
  }
  $88 = $84;
  HEAP32[$0>>2] = $82;
  HEAP32[$47>>2] = $88;
  $$5 = 1;
  return ($$5|0);
  break;
 }
 case 5:  {
  $89 = ((($0)) + 4|0);
  $90 = ((($0)) + 8|0);
  $91 = ((($0)) + 12|0);
  $92 = ((($1)) + -4|0);
  (__ZNSt3__27__sort5IR22BackToFrontSortFunctorPPN7osgUtil10RenderLeafEEEjT0_S7_S7_S7_S7_T_($0,$89,$90,$91,$92,$2)|0);
  $$5 = 1;
  return ($$5|0);
  break;
 }
 case 1: case 0:  {
  $$5 = 1;
  return ($$5|0);
  break;
 }
 default: {
  $93 = ((($0)) + 8|0);
  $94 = ((($0)) + 4|0);
  $95 = HEAP32[$94>>2]|0;
  $96 = HEAP32[$0>>2]|0;
  $97 = ((($96)) + 28|0);
  $98 = +HEAPF32[$97>>2];
  $99 = ((($95)) + 28|0);
  $100 = +HEAPF32[$99>>2];
  $101 = $98 < $100;
  $102 = HEAP32[$93>>2]|0;
  $103 = ((($102)) + 28|0);
  $104 = +HEAPF32[$103>>2];
  $105 = $100 < $104;
  $106 = $95;
  $107 = $102;
  $108 = $96;
  do {
   if ($101) {
    if ($105) {
     HEAP32[$0>>2] = $107;
     HEAP32[$93>>2] = $108;
     $134 = $96;
     break;
    }
    HEAP32[$0>>2] = $106;
    HEAP32[$94>>2] = $108;
    $110 = $98 < $104;
    if ($110) {
     HEAP32[$94>>2] = $107;
     HEAP32[$93>>2] = $108;
     $134 = $96;
    } else {
     $134 = $102;
    }
   } else {
    if ($105) {
     HEAP32[$94>>2] = $107;
     HEAP32[$93>>2] = $106;
     $109 = $98 < $104;
     if ($109) {
      HEAP32[$0>>2] = $107;
      HEAP32[$94>>2] = $108;
      $134 = $95;
     } else {
      $134 = $95;
     }
    } else {
     $134 = $102;
    }
   }
  } while(0);
  $111 = ((($0)) + 12|0);
  $112 = ($111|0)==($1|0);
  L13: do {
   if ($112) {
    $$1 = 1;$$3 = 0;
   } else {
    $$06277 = $111;$$06476 = 0;$$06974 = $93;$115 = $134;
    while(1) {
     $113 = HEAP32[$$06277>>2]|0;
     $114 = ((($115)) + 28|0);
     $116 = +HEAPF32[$114>>2];
     $117 = ((($113)) + 28|0);
     $118 = +HEAPF32[$117>>2];
     $119 = $116 < $118;
     $120 = $113;
     if ($119) {
      $$0 = $$06974;$$170 = $$06277;
      while(1) {
       $121 = HEAP32[$$0>>2]|0;
       HEAP32[$$170>>2] = $121;
       $122 = ($$0|0)==($0|0);
       if ($122) {
        break;
       }
       $123 = ((($$0)) + -4|0);
       $124 = HEAP32[$123>>2]|0;
       $125 = ((($124)) + 28|0);
       $126 = +HEAPF32[$125>>2];
       $127 = $126 < $118;
       if ($127) {
        $$170$phi = $$0;$$0 = $123;$$170 = $$170$phi;
       } else {
        break;
       }
      }
      HEAP32[$$0>>2] = $120;
      $128 = (($$06476) + 1)|0;
      $129 = ($128|0)==(8);
      $130 = ((($$06277)) + 4|0);
      $131 = ($130|0)==($1|0);
      if ($129) {
       $$1 = 0;$$3 = $131;
       break L13;
      } else {
       $$165 = $128;
      }
     } else {
      $$165 = $$06476;
     }
     $132 = ((($$06277)) + 4|0);
     $133 = ($132|0)==($1|0);
     if ($133) {
      $$1 = 1;$$3 = 0;
      break L13;
     }
     $$pre = HEAP32[$$06277>>2]|0;
     $$06974$phi = $$06277;$$06277 = $132;$$06476 = $$165;$115 = $$pre;$$06974 = $$06974$phi;
    }
   }
  } while(0);
  $$$3 = $$3 | $$1;
  $$5 = $$$3;
  return ($$5|0);
 }
 }
 return (0)|0;
}
function __ZNSt3__26__sortIR22FrontToBackSortFunctorPPN7osgUtil10RenderLeafEEEvT0_S7_T_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$$0174 = 0, $$0 = 0, $$0$i189 = 0, $$0$ph = 0, $$0154 = 0, $$0160241 = 0, $$0167 = 0, $$0174 = 0, $$0180$ph = 0, $$02933$i = 0, $$03032$i = 0, $$03032$i$phi = 0, $$1 = 0, $$1$i = 0, $$1$i$phi = 0, $$1155 = 0, $$1161 = 0, $$2156 = 0, $$2162 = 0, $$2176 = 0;
 var $$3157 = 0, $$3163 = 0, $$3170 = 0, $$4158 = 0, $$4164 = 0, $$4171 = 0, $$5159 = 0, $$5165 = 0, $$5172 = 0, $$6166 = 0, $$6173 = 0, $$pre$i190 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0.0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0.0, $110 = 0, $111 = 0, $112 = 0, $113 = 0.0, $114 = 0, $115 = 0, $116 = 0.0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0.0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0.0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0.0, $139 = 0, $14 = 0, $140 = 0.0, $141 = 0, $142 = 0;
 var $143 = 0, $144 = 0.0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0.0, $153 = 0, $154 = 0.0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0.0;
 var $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0.0, $167 = 0, $168 = 0.0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0.0, $176 = 0, $177 = 0, $178 = 0, $179 = 0;
 var $18 = 0, $180 = 0, $181 = 0.0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0.0, $191 = 0, $192 = 0, $193 = 0.0, $194 = 0, $195 = 0, $196 = 0, $197 = 0;
 var $198 = 0, $199 = 0, $20 = 0, $200 = 0.0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0.0, $207 = 0, $208 = 0, $209 = 0, $21 = 0.0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0.0;
 var $216 = 0, $217 = 0, $218 = 0.0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0.0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0.0, $230 = 0, $231 = 0, $232 = 0, $233 = 0;
 var $234 = 0, $235 = 0.0, $236 = 0, $237 = 0.0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0;
 var $252 = 0, $26 = 0, $27 = 0.0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0.0, $36 = 0, $37 = 0.0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0.0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0.0, $52 = 0, $53 = 0.0, $54 = 0, $55 = 0, $56 = 0, $57 = 0.0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0.0, $67 = 0, $68 = 0, $69 = 0.0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0.0, $77 = 0, $78 = 0.0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0.0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0.0, $97 = 0;
 var $98 = 0.0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$0$ph = $0;$$0180$ph = $1;
 L1: while(1) {
  $3 = $$0180$ph;
  $4 = ((($$0180$ph)) + -4|0);
  $$0 = $$0$ph;
  while(1) {
   $$1 = $$0;
   L5: while(1) {
    $5 = $$1;
    $6 = (($3) - ($5))|0;
    $7 = $6 >> 2;
    switch ($7|0) {
    case 2:  {
     label = 5;
     break L1;
     break;
    }
    case 3:  {
     label = 7;
     break L1;
     break;
    }
    case 4:  {
     label = 15;
     break L1;
     break;
    }
    case 5:  {
     label = 27;
     break L1;
     break;
    }
    case 1: case 0:  {
     label = 87;
     break L1;
     break;
    }
    default: {
    }
    }
    $90 = ($6|0)<(124);
    if ($90) {
     label = 29;
     break L1;
    }
    $128 = ($6|0)>(3996);
    $129 = (($7|0) / 2)&-1;
    $130 = (($$1) + ($129<<2)|0);
    do {
     if ($128) {
      $131 = (($7|0) / 4)&-1;
      $132 = (($$1) + ($131<<2)|0);
      $133 = (($130) + ($131<<2)|0);
      $134 = (__ZNSt3__27__sort5IR22FrontToBackSortFunctorPPN7osgUtil10RenderLeafEEEjT0_S7_S7_S7_S7_T_($$1,$132,$130,$133,$4,$2)|0);
      $$0167 = $134;
     } else {
      $135 = HEAP32[$130>>2]|0;
      $136 = HEAP32[$$1>>2]|0;
      $137 = ((($135)) + 28|0);
      $138 = +HEAPF32[$137>>2];
      $139 = ((($136)) + 28|0);
      $140 = +HEAPF32[$139>>2];
      $141 = $138 < $140;
      $142 = HEAP32[$4>>2]|0;
      $143 = ((($142)) + 28|0);
      $144 = +HEAPF32[$143>>2];
      $145 = $144 < $138;
      $146 = $135;
      $147 = $142;
      $148 = $136;
      if (!($141)) {
       if (!($145)) {
        $$0167 = 0;
        break;
       }
       HEAP32[$130>>2] = $147;
       HEAP32[$4>>2] = $146;
       $149 = HEAP32[$130>>2]|0;
       $150 = HEAP32[$$1>>2]|0;
       $151 = ((($149)) + 28|0);
       $152 = +HEAPF32[$151>>2];
       $153 = ((($150)) + 28|0);
       $154 = +HEAPF32[$153>>2];
       $155 = $152 < $154;
       if (!($155)) {
        $$0167 = 1;
        break;
       }
       $156 = $149;
       $157 = $150;
       HEAP32[$$1>>2] = $156;
       HEAP32[$130>>2] = $157;
       $$0167 = 2;
       break;
      }
      if ($145) {
       HEAP32[$$1>>2] = $147;
       HEAP32[$4>>2] = $148;
       $$0167 = 1;
       break;
      }
      HEAP32[$$1>>2] = $146;
      HEAP32[$130>>2] = $148;
      $158 = HEAP32[$4>>2]|0;
      $159 = ((($158)) + 28|0);
      $160 = +HEAPF32[$159>>2];
      $161 = $160 < $140;
      if ($161) {
       $162 = $158;
       HEAP32[$130>>2] = $162;
       HEAP32[$4>>2] = $148;
       $$0167 = 2;
      } else {
       $$0167 = 1;
      }
     }
    } while(0);
    $163 = HEAP32[$$1>>2]|0;
    $164 = HEAP32[$130>>2]|0;
    $165 = ((($163)) + 28|0);
    $166 = +HEAPF32[$165>>2];
    $167 = ((($164)) + 28|0);
    $168 = +HEAPF32[$167>>2];
    $169 = $166 < $168;
    if ($169) {
     $$3157 = $4;$$3170 = $$0167;
     break;
    } else {
     $$0154 = $4;
    }
    while(1) {
     $170 = ((($$0154)) + -4|0);
     $171 = ($$1|0)==($170|0);
     if ($171) {
      break;
     }
     $204 = HEAP32[$170>>2]|0;
     $205 = ((($204)) + 28|0);
     $206 = +HEAPF32[$205>>2];
     $207 = $206 < $168;
     if ($207) {
      label = 69;
      break L5;
     } else {
      $$0154 = $170;
     }
    }
    $172 = ((($$1)) + 4|0);
    $173 = HEAP32[$4>>2]|0;
    $174 = ((($173)) + 28|0);
    $175 = +HEAPF32[$174>>2];
    $176 = $166 < $175;
    $177 = $173;
    if ($176) {
     $$1161 = $172;
    } else {
     $178 = ($172|0)==($4|0);
     if ($178) {
      label = 87;
      break L1;
     } else {
      $$0160241 = $172;
     }
     while(1) {
      $179 = HEAP32[$$0160241>>2]|0;
      $180 = ((($179)) + 28|0);
      $181 = +HEAPF32[$180>>2];
      $182 = $166 < $181;
      if ($182) {
       break;
      }
      $185 = ((($$0160241)) + 4|0);
      $186 = ($185|0)==($4|0);
      if ($186) {
       label = 87;
       break L1;
      } else {
       $$0160241 = $185;
      }
     }
     $183 = $179;
     HEAP32[$$0160241>>2] = $177;
     HEAP32[$4>>2] = $183;
     $184 = ((($$0160241)) + 4|0);
     $$1161 = $184;
    }
    $187 = ($$1161|0)==($4|0);
    if ($187) {
     label = 87;
     break L1;
    } else {
     $$1155 = $4;$$2162 = $$1161;
    }
    while(1) {
     $188 = HEAP32[$$1>>2]|0;
     $189 = ((($188)) + 28|0);
     $190 = +HEAPF32[$189>>2];
     $$3163 = $$2162;
     while(1) {
      $191 = HEAP32[$$3163>>2]|0;
      $192 = ((($191)) + 28|0);
      $193 = +HEAPF32[$192>>2];
      $194 = $190 < $193;
      $195 = ((($$3163)) + 4|0);
      if ($194) {
       break;
      } else {
       $$3163 = $195;
      }
     }
     $196 = $191;
     $$2156 = $$1155;
     while(1) {
      $197 = ((($$2156)) + -4|0);
      $198 = HEAP32[$197>>2]|0;
      $199 = ((($198)) + 28|0);
      $200 = +HEAPF32[$199>>2];
      $201 = $190 < $200;
      if ($201) {
       $$2156 = $197;
      } else {
       break;
      }
     }
     $202 = ($$3163>>>0)<($197>>>0);
     if (!($202)) {
      $$1 = $$3163;
      continue L5;
     }
     $203 = $198;
     HEAP32[$$3163>>2] = $203;
     HEAP32[$197>>2] = $196;
     $$1155 = $197;$$2162 = $195;
    }
   }
   if ((label|0) == 69) {
    label = 0;
    $208 = $163;
    $209 = $204;
    HEAP32[$$1>>2] = $209;
    HEAP32[$170>>2] = $208;
    $210 = (($$0167) + 1)|0;
    $$3157 = $170;$$3170 = $210;
   }
   $211 = ((($$1)) + 4|0);
   $212 = ($211>>>0)<($$3157>>>0);
   L45: do {
    if ($212) {
     $$0174 = $130;$$4158 = $$3157;$$4164 = $211;$$4171 = $$3170;
     while(1) {
      $213 = HEAP32[$$0174>>2]|0;
      $214 = ((($213)) + 28|0);
      $215 = +HEAPF32[$214>>2];
      $$5165 = $$4164;
      while(1) {
       $216 = HEAP32[$$5165>>2]|0;
       $217 = ((($216)) + 28|0);
       $218 = +HEAPF32[$217>>2];
       $219 = $218 < $215;
       $220 = ((($$5165)) + 4|0);
       if ($219) {
        $$5165 = $220;
       } else {
        break;
       }
      }
      $221 = $216;
      $$5159 = $$4158;
      while(1) {
       $222 = ((($$5159)) + -4|0);
       $223 = HEAP32[$222>>2]|0;
       $224 = ((($223)) + 28|0);
       $225 = +HEAPF32[$224>>2];
       $226 = $225 < $215;
       if ($226) {
        break;
       } else {
        $$5159 = $222;
       }
      }
      $227 = ($$5165>>>0)>($222>>>0);
      if ($227) {
       $$2176 = $$0174;$$5172 = $$4171;$$6166 = $$5165;
       break L45;
      }
      $228 = $223;
      HEAP32[$$5165>>2] = $228;
      HEAP32[$222>>2] = $221;
      $229 = (($$4171) + 1)|0;
      $230 = ($$0174|0)==($$5165|0);
      $$$0174 = $230 ? $222 : $$0174;
      $$0174 = $$$0174;$$4158 = $222;$$4164 = $220;$$4171 = $229;
     }
    } else {
     $$2176 = $130;$$5172 = $$3170;$$6166 = $211;
    }
   } while(0);
   $231 = ($$6166|0)==($$2176|0);
   if ($231) {
    $$6173 = $$5172;
   } else {
    $232 = HEAP32[$$2176>>2]|0;
    $233 = HEAP32[$$6166>>2]|0;
    $234 = ((($232)) + 28|0);
    $235 = +HEAPF32[$234>>2];
    $236 = ((($233)) + 28|0);
    $237 = +HEAPF32[$236>>2];
    $238 = $235 < $237;
    if ($238) {
     $239 = $232;
     $240 = $233;
     $241 = (($$5172) + 1)|0;
     HEAP32[$$6166>>2] = $239;
     HEAP32[$$2176>>2] = $240;
     $$6173 = $241;
    } else {
     $$6173 = $$5172;
    }
   }
   $242 = ($$6173|0)==(0);
   if ($242) {
    $243 = (__ZNSt3__227__insertion_sort_incompleteIR22FrontToBackSortFunctorPPN7osgUtil10RenderLeafEEEbT0_S7_T_($$1,$$6166,$2)|0);
    $244 = ((($$6166)) + 4|0);
    $245 = (__ZNSt3__227__insertion_sort_incompleteIR22FrontToBackSortFunctorPPN7osgUtil10RenderLeafEEEbT0_S7_T_($244,$$0180$ph,$2)|0);
    if ($245) {
     label = 86;
     break;
    }
    if ($243) {
     $$0 = $244;
     continue;
    }
   }
   $246 = $$6166;
   $247 = (($246) - ($5))|0;
   $248 = (($3) - ($246))|0;
   $249 = ($247|0)<($248|0);
   if (!($249)) {
    label = 85;
    break;
   }
   __ZNSt3__26__sortIR22FrontToBackSortFunctorPPN7osgUtil10RenderLeafEEEvT0_S7_T_($$1,$$6166,$2);
   $250 = ((($$6166)) + 4|0);
   $$0 = $250;
  }
  if ((label|0) == 85) {
   label = 0;
   $251 = ((($$6166)) + 4|0);
   __ZNSt3__26__sortIR22FrontToBackSortFunctorPPN7osgUtil10RenderLeafEEEvT0_S7_T_($251,$$0180$ph,$2);
   $$0$ph = $$1;$$0180$ph = $$6166;
   continue;
  }
  else if ((label|0) == 86) {
   label = 0;
   if ($243) {
    label = 87;
    break;
   } else {
    $$0$ph = $$1;$$0180$ph = $$6166;
    continue;
   }
  }
 }
 if ((label|0) == 5) {
  $8 = HEAP32[$4>>2]|0;
  $9 = HEAP32[$$1>>2]|0;
  $10 = ((($8)) + 28|0);
  $11 = +HEAPF32[$10>>2];
  $12 = ((($9)) + 28|0);
  $13 = +HEAPF32[$12>>2];
  $14 = $11 < $13;
  if (!($14)) {
   return;
  }
  $15 = $8;
  $16 = $9;
  HEAP32[$$1>>2] = $15;
  HEAP32[$4>>2] = $16;
  return;
 }
 else if ((label|0) == 7) {
  $17 = ((($$1)) + 4|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = HEAP32[$$1>>2]|0;
  $20 = ((($18)) + 28|0);
  $21 = +HEAPF32[$20>>2];
  $22 = ((($19)) + 28|0);
  $23 = +HEAPF32[$22>>2];
  $24 = $21 < $23;
  $25 = HEAP32[$4>>2]|0;
  $26 = ((($25)) + 28|0);
  $27 = +HEAPF32[$26>>2];
  $28 = $27 < $21;
  $29 = $18;
  $30 = $25;
  $31 = $19;
  if (!($24)) {
   if (!($28)) {
    return;
   }
   HEAP32[$17>>2] = $30;
   HEAP32[$4>>2] = $29;
   $32 = HEAP32[$17>>2]|0;
   $33 = HEAP32[$$1>>2]|0;
   $34 = ((($32)) + 28|0);
   $35 = +HEAPF32[$34>>2];
   $36 = ((($33)) + 28|0);
   $37 = +HEAPF32[$36>>2];
   $38 = $35 < $37;
   if (!($38)) {
    return;
   }
   $39 = $32;
   $40 = $33;
   HEAP32[$$1>>2] = $39;
   HEAP32[$17>>2] = $40;
   return;
  }
  if ($28) {
   HEAP32[$$1>>2] = $30;
   HEAP32[$4>>2] = $31;
   return;
  }
  HEAP32[$$1>>2] = $29;
  HEAP32[$17>>2] = $31;
  $41 = HEAP32[$4>>2]|0;
  $42 = ((($41)) + 28|0);
  $43 = +HEAPF32[$42>>2];
  $44 = $43 < $23;
  if (!($44)) {
   return;
  }
  $45 = $41;
  HEAP32[$17>>2] = $45;
  HEAP32[$4>>2] = $31;
  return;
 }
 else if ((label|0) == 15) {
  $46 = ((($$1)) + 4|0);
  $47 = ((($$1)) + 8|0);
  $48 = HEAP32[$46>>2]|0;
  $49 = HEAP32[$$1>>2]|0;
  $50 = ((($48)) + 28|0);
  $51 = +HEAPF32[$50>>2];
  $52 = ((($49)) + 28|0);
  $53 = +HEAPF32[$52>>2];
  $54 = $51 < $53;
  $55 = HEAP32[$47>>2]|0;
  $56 = ((($55)) + 28|0);
  $57 = +HEAPF32[$56>>2];
  $58 = $57 < $51;
  $59 = $48;
  $60 = $55;
  $61 = $49;
  do {
   if ($54) {
    if ($58) {
     HEAP32[$$1>>2] = $60;
     HEAP32[$47>>2] = $61;
     $68 = $49;$72 = $61;
     break;
    }
    HEAP32[$$1>>2] = $59;
    HEAP32[$46>>2] = $61;
    $63 = $57 < $53;
    if ($63) {
     HEAP32[$46>>2] = $60;
     HEAP32[$47>>2] = $61;
     $68 = $49;$72 = $61;
    } else {
     $68 = $55;$72 = $60;
    }
   } else {
    if ($58) {
     HEAP32[$46>>2] = $60;
     HEAP32[$47>>2] = $59;
     $62 = $57 < $53;
     if ($62) {
      HEAP32[$$1>>2] = $60;
      HEAP32[$46>>2] = $61;
      $68 = $48;$72 = $59;
     } else {
      $68 = $48;$72 = $59;
     }
    } else {
     $68 = $55;$72 = $60;
    }
   }
  } while(0);
  $64 = HEAP32[$4>>2]|0;
  $65 = ((($64)) + 28|0);
  $66 = +HEAPF32[$65>>2];
  $67 = ((($68)) + 28|0);
  $69 = +HEAPF32[$67>>2];
  $70 = $66 < $69;
  if (!($70)) {
   return;
  }
  $71 = $64;
  HEAP32[$47>>2] = $71;
  HEAP32[$4>>2] = $72;
  $73 = HEAP32[$47>>2]|0;
  $74 = HEAP32[$46>>2]|0;
  $75 = ((($73)) + 28|0);
  $76 = +HEAPF32[$75>>2];
  $77 = ((($74)) + 28|0);
  $78 = +HEAPF32[$77>>2];
  $79 = $76 < $78;
  if (!($79)) {
   return;
  }
  $80 = $73;
  $81 = $74;
  HEAP32[$46>>2] = $80;
  HEAP32[$47>>2] = $81;
  $82 = HEAP32[$$1>>2]|0;
  $83 = ((($82)) + 28|0);
  $84 = +HEAPF32[$83>>2];
  $85 = $76 < $84;
  if (!($85)) {
   return;
  }
  $86 = $82;
  HEAP32[$$1>>2] = $80;
  HEAP32[$46>>2] = $86;
  return;
 }
 else if ((label|0) == 27) {
  $87 = ((($$1)) + 4|0);
  $88 = ((($$1)) + 8|0);
  $89 = ((($$1)) + 12|0);
  (__ZNSt3__27__sort5IR22FrontToBackSortFunctorPPN7osgUtil10RenderLeafEEEjT0_S7_S7_S7_S7_T_($$1,$87,$88,$89,$4,$2)|0);
  return;
 }
 else if ((label|0) == 29) {
  $91 = ((($$1)) + 8|0);
  $92 = ((($$1)) + 4|0);
  $93 = HEAP32[$92>>2]|0;
  $94 = HEAP32[$$1>>2]|0;
  $95 = ((($93)) + 28|0);
  $96 = +HEAPF32[$95>>2];
  $97 = ((($94)) + 28|0);
  $98 = +HEAPF32[$97>>2];
  $99 = $96 < $98;
  $100 = HEAP32[$91>>2]|0;
  $101 = ((($100)) + 28|0);
  $102 = +HEAPF32[$101>>2];
  $103 = $102 < $96;
  $104 = $93;
  $105 = $100;
  $106 = $94;
  do {
   if ($99) {
    if ($103) {
     HEAP32[$$1>>2] = $105;
     HEAP32[$91>>2] = $106;
     $252 = $94;
     break;
    }
    HEAP32[$$1>>2] = $104;
    HEAP32[$92>>2] = $106;
    $108 = $102 < $98;
    if ($108) {
     HEAP32[$92>>2] = $105;
     HEAP32[$91>>2] = $106;
     $252 = $94;
    } else {
     $252 = $100;
    }
   } else {
    if ($103) {
     HEAP32[$92>>2] = $105;
     HEAP32[$91>>2] = $104;
     $107 = $102 < $98;
     if ($107) {
      HEAP32[$$1>>2] = $105;
      HEAP32[$92>>2] = $106;
      $252 = $93;
     } else {
      $252 = $93;
     }
    } else {
     $252 = $100;
    }
   }
  } while(0);
  $109 = ((($$1)) + 12|0);
  $110 = ($109|0)==($$0180$ph|0);
  if ($110) {
   return;
  } else {
   $$02933$i = $109;$$03032$i = $91;$115 = $252;
  }
  while(1) {
   $111 = HEAP32[$$02933$i>>2]|0;
   $112 = ((($111)) + 28|0);
   $113 = +HEAPF32[$112>>2];
   $114 = ((($115)) + 28|0);
   $116 = +HEAPF32[$114>>2];
   $117 = $113 < $116;
   $118 = $111;
   if ($117) {
    $$0$i189 = $$03032$i;$$1$i = $$02933$i;
    while(1) {
     $119 = HEAP32[$$0$i189>>2]|0;
     HEAP32[$$1$i>>2] = $119;
     $120 = ($$0$i189|0)==($$1|0);
     if ($120) {
      break;
     }
     $121 = ((($$0$i189)) + -4|0);
     $122 = HEAP32[$121>>2]|0;
     $123 = ((($122)) + 28|0);
     $124 = +HEAPF32[$123>>2];
     $125 = $113 < $124;
     if ($125) {
      $$1$i$phi = $$0$i189;$$0$i189 = $121;$$1$i = $$1$i$phi;
     } else {
      break;
     }
    }
    HEAP32[$$0$i189>>2] = $118;
   }
   $126 = ((($$02933$i)) + 4|0);
   $127 = ($126|0)==($$0180$ph|0);
   if ($127) {
    break;
   }
   $$pre$i190 = HEAP32[$$02933$i>>2]|0;
   $$03032$i$phi = $$02933$i;$$02933$i = $126;$115 = $$pre$i190;$$03032$i = $$03032$i$phi;
  }
  return;
 }
 else if ((label|0) == 87) {
  return;
 }
}
function __ZNSt3__27__sort5IR22FrontToBackSortFunctorPPN7osgUtil10RenderLeafEEEjT0_S7_S7_S7_S7_T_($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$0 = 0, $$0$i = 0, $$026$i$i = 0, $$pre$i = 0, $10 = 0, $100 = 0.0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $11 = 0.0, $12 = 0, $13 = 0, $14 = 0, $15 = 0.0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0.0, $24 = 0, $25 = 0.0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0.0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0.0, $38 = 0, $39 = 0, $40 = 0.0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0.0, $49 = 0, $50 = 0.0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0.0, $59 = 0, $6 = 0;
 var $60 = 0.0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0.0, $69 = 0, $7 = 0, $70 = 0.0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0.0;
 var $79 = 0, $8 = 0, $80 = 0.0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0.0, $89 = 0, $9 = 0.0, $90 = 0.0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0.0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $6 = HEAP32[$1>>2]|0;
 $7 = HEAP32[$0>>2]|0;
 $8 = ((($6)) + 28|0);
 $9 = +HEAPF32[$8>>2];
 $10 = ((($7)) + 28|0);
 $11 = +HEAPF32[$10>>2];
 $12 = $9 < $11;
 $13 = HEAP32[$2>>2]|0;
 $14 = ((($13)) + 28|0);
 $15 = +HEAPF32[$14>>2];
 $16 = $15 < $9;
 $17 = $6;
 $18 = $13;
 $19 = $7;
 do {
  if ($12) {
   if ($16) {
    HEAP32[$0>>2] = $18;
    HEAP32[$2>>2] = $19;
    $$026$i$i = 1;$39 = $7;$43 = $19;
    break;
   }
   HEAP32[$0>>2] = $17;
   HEAP32[$1>>2] = $19;
   $30 = HEAP32[$2>>2]|0;
   $31 = ((($30)) + 28|0);
   $32 = +HEAPF32[$31>>2];
   $33 = $32 < $11;
   $34 = $30;
   if ($33) {
    HEAP32[$1>>2] = $34;
    HEAP32[$2>>2] = $19;
    $$026$i$i = 2;$39 = $7;$43 = $19;
   } else {
    $$026$i$i = 1;$39 = $30;$43 = $34;
   }
  } else {
   if ($16) {
    HEAP32[$1>>2] = $18;
    HEAP32[$2>>2] = $17;
    $20 = HEAP32[$1>>2]|0;
    $21 = HEAP32[$0>>2]|0;
    $22 = ((($20)) + 28|0);
    $23 = +HEAPF32[$22>>2];
    $24 = ((($21)) + 28|0);
    $25 = +HEAPF32[$24>>2];
    $26 = $23 < $25;
    if ($26) {
     $27 = $20;
     $28 = $21;
     HEAP32[$0>>2] = $27;
     HEAP32[$1>>2] = $28;
     $$pre$i = HEAP32[$2>>2]|0;
     $29 = $$pre$i;
     $$026$i$i = 2;$39 = $$pre$i;$43 = $29;
    } else {
     $$026$i$i = 1;$39 = $6;$43 = $17;
    }
   } else {
    $$026$i$i = 0;$39 = $13;$43 = $18;
   }
  }
 } while(0);
 $35 = HEAP32[$3>>2]|0;
 $36 = ((($35)) + 28|0);
 $37 = +HEAPF32[$36>>2];
 $38 = ((($39)) + 28|0);
 $40 = +HEAPF32[$38>>2];
 $41 = $37 < $40;
 if ($41) {
  $42 = $35;
  HEAP32[$2>>2] = $42;
  HEAP32[$3>>2] = $43;
  $44 = (($$026$i$i) + 1)|0;
  $45 = HEAP32[$2>>2]|0;
  $46 = HEAP32[$1>>2]|0;
  $47 = ((($45)) + 28|0);
  $48 = +HEAPF32[$47>>2];
  $49 = ((($46)) + 28|0);
  $50 = +HEAPF32[$49>>2];
  $51 = $48 < $50;
  if ($51) {
   $52 = $45;
   $53 = $46;
   HEAP32[$1>>2] = $52;
   HEAP32[$2>>2] = $53;
   $54 = (($$026$i$i) + 2)|0;
   $55 = HEAP32[$1>>2]|0;
   $56 = HEAP32[$0>>2]|0;
   $57 = ((($55)) + 28|0);
   $58 = +HEAPF32[$57>>2];
   $59 = ((($56)) + 28|0);
   $60 = +HEAPF32[$59>>2];
   $61 = $58 < $60;
   if ($61) {
    $62 = (($$026$i$i) + 3)|0;
    $63 = $56;
    $64 = $55;
    HEAP32[$0>>2] = $64;
    HEAP32[$1>>2] = $63;
    $$0$i = $62;
   } else {
    $$0$i = $54;
   }
  } else {
   $$0$i = $44;
  }
 } else {
  $$0$i = $$026$i$i;
 }
 $65 = HEAP32[$4>>2]|0;
 $66 = HEAP32[$3>>2]|0;
 $67 = ((($65)) + 28|0);
 $68 = +HEAPF32[$67>>2];
 $69 = ((($66)) + 28|0);
 $70 = +HEAPF32[$69>>2];
 $71 = $68 < $70;
 if (!($71)) {
  $$0 = $$0$i;
  return ($$0|0);
 }
 $72 = $65;
 $73 = $66;
 HEAP32[$3>>2] = $72;
 HEAP32[$4>>2] = $73;
 $74 = (($$0$i) + 1)|0;
 $75 = HEAP32[$3>>2]|0;
 $76 = HEAP32[$2>>2]|0;
 $77 = ((($75)) + 28|0);
 $78 = +HEAPF32[$77>>2];
 $79 = ((($76)) + 28|0);
 $80 = +HEAPF32[$79>>2];
 $81 = $78 < $80;
 if (!($81)) {
  $$0 = $74;
  return ($$0|0);
 }
 $82 = $75;
 $83 = $76;
 HEAP32[$2>>2] = $82;
 HEAP32[$3>>2] = $83;
 $84 = (($$0$i) + 2)|0;
 $85 = HEAP32[$2>>2]|0;
 $86 = HEAP32[$1>>2]|0;
 $87 = ((($85)) + 28|0);
 $88 = +HEAPF32[$87>>2];
 $89 = ((($86)) + 28|0);
 $90 = +HEAPF32[$89>>2];
 $91 = $88 < $90;
 if (!($91)) {
  $$0 = $84;
  return ($$0|0);
 }
 $92 = $85;
 $93 = $86;
 HEAP32[$1>>2] = $92;
 HEAP32[$2>>2] = $93;
 $94 = (($$0$i) + 3)|0;
 $95 = HEAP32[$1>>2]|0;
 $96 = HEAP32[$0>>2]|0;
 $97 = ((($95)) + 28|0);
 $98 = +HEAPF32[$97>>2];
 $99 = ((($96)) + 28|0);
 $100 = +HEAPF32[$99>>2];
 $101 = $98 < $100;
 if (!($101)) {
  $$0 = $94;
  return ($$0|0);
 }
 $102 = $95;
 $103 = $96;
 $104 = (($$0$i) + 4)|0;
 HEAP32[$0>>2] = $102;
 HEAP32[$1>>2] = $103;
 $$0 = $104;
 return ($$0|0);
}
function __ZNSt3__227__insertion_sort_incompleteIR22FrontToBackSortFunctorPPN7osgUtil10RenderLeafEEEbT0_S7_T_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$$3 = 0, $$0 = 0, $$06277 = 0, $$06476 = 0, $$06974 = 0, $$06974$phi = 0, $$1 = 0, $$165 = 0, $$170 = 0, $$170$phi = 0, $$3 = 0, $$5 = 0, $$pre = 0, $10 = 0, $100 = 0.0, $101 = 0, $102 = 0, $103 = 0, $104 = 0.0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0.0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0.0, $116 = 0, $117 = 0, $118 = 0.0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0.0, $127 = 0, $128 = 0, $129 = 0, $13 = 0.0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0;
 var $22 = 0.0, $23 = 0, $24 = 0.0, $25 = 0, $26 = 0, $27 = 0, $28 = 0.0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0.0, $37 = 0, $38 = 0.0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0.0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0.0, $54 = 0, $55 = 0.0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0.0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0.0, $69 = 0, $7 = 0, $70 = 0, $71 = 0.0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0.0, $79 = 0, $8 = 0, $80 = 0.0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0.0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0.0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = $1;
 $4 = $0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 switch ($6|0) {
 case 2:  {
  $7 = ((($1)) + -4|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = HEAP32[$0>>2]|0;
  $10 = ((($8)) + 28|0);
  $11 = +HEAPF32[$10>>2];
  $12 = ((($9)) + 28|0);
  $13 = +HEAPF32[$12>>2];
  $14 = $11 < $13;
  if (!($14)) {
   $$5 = 1;
   return ($$5|0);
  }
  $15 = $8;
  $16 = $9;
  HEAP32[$0>>2] = $15;
  HEAP32[$7>>2] = $16;
  $$5 = 1;
  return ($$5|0);
  break;
 }
 case 3:  {
  $17 = ((($0)) + 4|0);
  $18 = ((($1)) + -4|0);
  $19 = HEAP32[$17>>2]|0;
  $20 = HEAP32[$0>>2]|0;
  $21 = ((($19)) + 28|0);
  $22 = +HEAPF32[$21>>2];
  $23 = ((($20)) + 28|0);
  $24 = +HEAPF32[$23>>2];
  $25 = $22 < $24;
  $26 = HEAP32[$18>>2]|0;
  $27 = ((($26)) + 28|0);
  $28 = +HEAPF32[$27>>2];
  $29 = $28 < $22;
  $30 = $19;
  $31 = $26;
  $32 = $20;
  if (!($25)) {
   if (!($29)) {
    $$5 = 1;
    return ($$5|0);
   }
   HEAP32[$17>>2] = $31;
   HEAP32[$18>>2] = $30;
   $33 = HEAP32[$17>>2]|0;
   $34 = HEAP32[$0>>2]|0;
   $35 = ((($33)) + 28|0);
   $36 = +HEAPF32[$35>>2];
   $37 = ((($34)) + 28|0);
   $38 = +HEAPF32[$37>>2];
   $39 = $36 < $38;
   if (!($39)) {
    $$5 = 1;
    return ($$5|0);
   }
   $40 = $33;
   $41 = $34;
   HEAP32[$0>>2] = $40;
   HEAP32[$17>>2] = $41;
   $$5 = 1;
   return ($$5|0);
  }
  if ($29) {
   HEAP32[$0>>2] = $31;
   HEAP32[$18>>2] = $32;
   $$5 = 1;
   return ($$5|0);
  }
  HEAP32[$0>>2] = $30;
  HEAP32[$17>>2] = $32;
  $42 = HEAP32[$18>>2]|0;
  $43 = ((($42)) + 28|0);
  $44 = +HEAPF32[$43>>2];
  $45 = $44 < $24;
  if (!($45)) {
   $$5 = 1;
   return ($$5|0);
  }
  $46 = $42;
  HEAP32[$17>>2] = $46;
  HEAP32[$18>>2] = $32;
  $$5 = 1;
  return ($$5|0);
  break;
 }
 case 4:  {
  $47 = ((($0)) + 4|0);
  $48 = ((($0)) + 8|0);
  $49 = ((($1)) + -4|0);
  $50 = HEAP32[$47>>2]|0;
  $51 = HEAP32[$0>>2]|0;
  $52 = ((($50)) + 28|0);
  $53 = +HEAPF32[$52>>2];
  $54 = ((($51)) + 28|0);
  $55 = +HEAPF32[$54>>2];
  $56 = $53 < $55;
  $57 = HEAP32[$48>>2]|0;
  $58 = ((($57)) + 28|0);
  $59 = +HEAPF32[$58>>2];
  $60 = $59 < $53;
  $61 = $50;
  $62 = $57;
  $63 = $51;
  do {
   if ($56) {
    if ($60) {
     HEAP32[$0>>2] = $62;
     HEAP32[$48>>2] = $63;
     $70 = $51;$74 = $63;
     break;
    }
    HEAP32[$0>>2] = $61;
    HEAP32[$47>>2] = $63;
    $65 = $59 < $55;
    if ($65) {
     HEAP32[$47>>2] = $62;
     HEAP32[$48>>2] = $63;
     $70 = $51;$74 = $63;
    } else {
     $70 = $57;$74 = $62;
    }
   } else {
    if ($60) {
     HEAP32[$47>>2] = $62;
     HEAP32[$48>>2] = $61;
     $64 = $59 < $55;
     if ($64) {
      HEAP32[$0>>2] = $62;
      HEAP32[$47>>2] = $63;
      $70 = $50;$74 = $61;
     } else {
      $70 = $50;$74 = $61;
     }
    } else {
     $70 = $57;$74 = $62;
    }
   }
  } while(0);
  $66 = HEAP32[$49>>2]|0;
  $67 = ((($66)) + 28|0);
  $68 = +HEAPF32[$67>>2];
  $69 = ((($70)) + 28|0);
  $71 = +HEAPF32[$69>>2];
  $72 = $68 < $71;
  if (!($72)) {
   $$5 = 1;
   return ($$5|0);
  }
  $73 = $66;
  HEAP32[$48>>2] = $73;
  HEAP32[$49>>2] = $74;
  $75 = HEAP32[$48>>2]|0;
  $76 = HEAP32[$47>>2]|0;
  $77 = ((($75)) + 28|0);
  $78 = +HEAPF32[$77>>2];
  $79 = ((($76)) + 28|0);
  $80 = +HEAPF32[$79>>2];
  $81 = $78 < $80;
  if (!($81)) {
   $$5 = 1;
   return ($$5|0);
  }
  $82 = $75;
  $83 = $76;
  HEAP32[$47>>2] = $82;
  HEAP32[$48>>2] = $83;
  $84 = HEAP32[$0>>2]|0;
  $85 = ((($84)) + 28|0);
  $86 = +HEAPF32[$85>>2];
  $87 = $78 < $86;
  if (!($87)) {
   $$5 = 1;
   return ($$5|0);
  }
  $88 = $84;
  HEAP32[$0>>2] = $82;
  HEAP32[$47>>2] = $88;
  $$5 = 1;
  return ($$5|0);
  break;
 }
 case 5:  {
  $89 = ((($0)) + 4|0);
  $90 = ((($0)) + 8|0);
  $91 = ((($0)) + 12|0);
  $92 = ((($1)) + -4|0);
  (__ZNSt3__27__sort5IR22FrontToBackSortFunctorPPN7osgUtil10RenderLeafEEEjT0_S7_S7_S7_S7_T_($0,$89,$90,$91,$92,$2)|0);
  $$5 = 1;
  return ($$5|0);
  break;
 }
 case 1: case 0:  {
  $$5 = 1;
  return ($$5|0);
  break;
 }
 default: {
  $93 = ((($0)) + 8|0);
  $94 = ((($0)) + 4|0);
  $95 = HEAP32[$94>>2]|0;
  $96 = HEAP32[$0>>2]|0;
  $97 = ((($95)) + 28|0);
  $98 = +HEAPF32[$97>>2];
  $99 = ((($96)) + 28|0);
  $100 = +HEAPF32[$99>>2];
  $101 = $98 < $100;
  $102 = HEAP32[$93>>2]|0;
  $103 = ((($102)) + 28|0);
  $104 = +HEAPF32[$103>>2];
  $105 = $104 < $98;
  $106 = $95;
  $107 = $102;
  $108 = $96;
  do {
   if ($101) {
    if ($105) {
     HEAP32[$0>>2] = $107;
     HEAP32[$93>>2] = $108;
     $134 = $96;
     break;
    }
    HEAP32[$0>>2] = $106;
    HEAP32[$94>>2] = $108;
    $110 = $104 < $100;
    if ($110) {
     HEAP32[$94>>2] = $107;
     HEAP32[$93>>2] = $108;
     $134 = $96;
    } else {
     $134 = $102;
    }
   } else {
    if ($105) {
     HEAP32[$94>>2] = $107;
     HEAP32[$93>>2] = $106;
     $109 = $104 < $100;
     if ($109) {
      HEAP32[$0>>2] = $107;
      HEAP32[$94>>2] = $108;
      $134 = $95;
     } else {
      $134 = $95;
     }
    } else {
     $134 = $102;
    }
   }
  } while(0);
  $111 = ((($0)) + 12|0);
  $112 = ($111|0)==($1|0);
  L13: do {
   if ($112) {
    $$1 = 1;$$3 = 0;
   } else {
    $$06277 = $111;$$06476 = 0;$$06974 = $93;$117 = $134;
    while(1) {
     $113 = HEAP32[$$06277>>2]|0;
     $114 = ((($113)) + 28|0);
     $115 = +HEAPF32[$114>>2];
     $116 = ((($117)) + 28|0);
     $118 = +HEAPF32[$116>>2];
     $119 = $115 < $118;
     $120 = $113;
     if ($119) {
      $$0 = $$06974;$$170 = $$06277;
      while(1) {
       $121 = HEAP32[$$0>>2]|0;
       HEAP32[$$170>>2] = $121;
       $122 = ($$0|0)==($0|0);
       if ($122) {
        break;
       }
       $123 = ((($$0)) + -4|0);
       $124 = HEAP32[$123>>2]|0;
       $125 = ((($124)) + 28|0);
       $126 = +HEAPF32[$125>>2];
       $127 = $115 < $126;
       if ($127) {
        $$170$phi = $$0;$$0 = $123;$$170 = $$170$phi;
       } else {
        break;
       }
      }
      HEAP32[$$0>>2] = $120;
      $128 = (($$06476) + 1)|0;
      $129 = ($128|0)==(8);
      $130 = ((($$06277)) + 4|0);
      $131 = ($130|0)==($1|0);
      if ($129) {
       $$1 = 0;$$3 = $131;
       break L13;
      } else {
       $$165 = $128;
      }
     } else {
      $$165 = $$06476;
     }
     $132 = ((($$06277)) + 4|0);
     $133 = ($132|0)==($1|0);
     if ($133) {
      $$1 = 1;$$3 = 0;
      break L13;
     }
     $$pre = HEAP32[$$06277>>2]|0;
     $$06974$phi = $$06277;$$06277 = $132;$$06476 = $$165;$117 = $$pre;$$06974 = $$06974$phi;
    }
   }
  } while(0);
  $$$3 = $$3 | $$1;
  $$5 = $$$3;
  return ($$5|0);
 }
 }
 return (0)|0;
}
function __ZNSt3__26__sortIR32StateGraphFrontToBackSortFunctorPPN7osgUtil10StateGraphEEEvT0_S7_T_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$$0174 = 0, $$0 = 0, $$0$i189 = 0, $$0$ph = 0, $$0154 = 0, $$0160241 = 0, $$0167 = 0, $$0174 = 0, $$0180$ph = 0, $$02933$i = 0, $$03032$i = 0, $$03032$i$phi = 0, $$1 = 0, $$1$i = 0, $$1$i$phi = 0, $$1155 = 0, $$1161 = 0, $$2156 = 0, $$2162 = 0, $$2176 = 0;
 var $$3157 = 0, $$3163 = 0, $$3170 = 0, $$4158 = 0, $$4164 = 0, $$4171 = 0, $$5159 = 0, $$5165 = 0, $$5172 = 0, $$6166 = 0, $$6173 = 0, $$pre$i190 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0.0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0.0, $110 = 0, $111 = 0, $112 = 0, $113 = 0.0, $114 = 0, $115 = 0, $116 = 0.0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0.0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0.0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0.0, $139 = 0, $14 = 0, $140 = 0.0, $141 = 0, $142 = 0;
 var $143 = 0, $144 = 0.0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0.0, $153 = 0, $154 = 0.0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0.0;
 var $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0.0, $167 = 0, $168 = 0.0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0.0, $176 = 0, $177 = 0, $178 = 0, $179 = 0;
 var $18 = 0, $180 = 0, $181 = 0.0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0.0, $191 = 0, $192 = 0, $193 = 0.0, $194 = 0, $195 = 0, $196 = 0, $197 = 0;
 var $198 = 0, $199 = 0, $20 = 0, $200 = 0.0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0.0, $207 = 0, $208 = 0, $209 = 0, $21 = 0.0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0.0;
 var $216 = 0, $217 = 0, $218 = 0.0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0.0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0.0, $230 = 0, $231 = 0, $232 = 0, $233 = 0;
 var $234 = 0, $235 = 0.0, $236 = 0, $237 = 0.0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0;
 var $252 = 0, $26 = 0, $27 = 0.0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0.0, $36 = 0, $37 = 0.0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0.0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0.0, $52 = 0, $53 = 0.0, $54 = 0, $55 = 0, $56 = 0, $57 = 0.0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0.0, $67 = 0, $68 = 0, $69 = 0.0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0.0, $77 = 0, $78 = 0.0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0.0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0.0, $97 = 0;
 var $98 = 0.0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$0$ph = $0;$$0180$ph = $1;
 L1: while(1) {
  $3 = $$0180$ph;
  $4 = ((($$0180$ph)) + -4|0);
  $$0 = $$0$ph;
  while(1) {
   $$1 = $$0;
   L5: while(1) {
    $5 = $$1;
    $6 = (($3) - ($5))|0;
    $7 = $6 >> 2;
    switch ($7|0) {
    case 2:  {
     label = 5;
     break L1;
     break;
    }
    case 3:  {
     label = 7;
     break L1;
     break;
    }
    case 4:  {
     label = 15;
     break L1;
     break;
    }
    case 5:  {
     label = 27;
     break L1;
     break;
    }
    case 1: case 0:  {
     label = 87;
     break L1;
     break;
    }
    default: {
    }
    }
    $90 = ($6|0)<(124);
    if ($90) {
     label = 29;
     break L1;
    }
    $128 = ($6|0)>(3996);
    $129 = (($7|0) / 2)&-1;
    $130 = (($$1) + ($129<<2)|0);
    do {
     if ($128) {
      $131 = (($7|0) / 4)&-1;
      $132 = (($$1) + ($131<<2)|0);
      $133 = (($130) + ($131<<2)|0);
      $134 = (__ZNSt3__27__sort5IR32StateGraphFrontToBackSortFunctorPPN7osgUtil10StateGraphEEEjT0_S7_S7_S7_S7_T_($$1,$132,$130,$133,$4,$2)|0);
      $$0167 = $134;
     } else {
      $135 = HEAP32[$130>>2]|0;
      $136 = HEAP32[$$1>>2]|0;
      $137 = ((($135)) + 52|0);
      $138 = +HEAPF32[$137>>2];
      $139 = ((($136)) + 52|0);
      $140 = +HEAPF32[$139>>2];
      $141 = $138 < $140;
      $142 = HEAP32[$4>>2]|0;
      $143 = ((($142)) + 52|0);
      $144 = +HEAPF32[$143>>2];
      $145 = $144 < $138;
      $146 = $135;
      $147 = $142;
      $148 = $136;
      if (!($141)) {
       if (!($145)) {
        $$0167 = 0;
        break;
       }
       HEAP32[$130>>2] = $147;
       HEAP32[$4>>2] = $146;
       $149 = HEAP32[$130>>2]|0;
       $150 = HEAP32[$$1>>2]|0;
       $151 = ((($149)) + 52|0);
       $152 = +HEAPF32[$151>>2];
       $153 = ((($150)) + 52|0);
       $154 = +HEAPF32[$153>>2];
       $155 = $152 < $154;
       if (!($155)) {
        $$0167 = 1;
        break;
       }
       $156 = $149;
       $157 = $150;
       HEAP32[$$1>>2] = $156;
       HEAP32[$130>>2] = $157;
       $$0167 = 2;
       break;
      }
      if ($145) {
       HEAP32[$$1>>2] = $147;
       HEAP32[$4>>2] = $148;
       $$0167 = 1;
       break;
      }
      HEAP32[$$1>>2] = $146;
      HEAP32[$130>>2] = $148;
      $158 = HEAP32[$4>>2]|0;
      $159 = ((($158)) + 52|0);
      $160 = +HEAPF32[$159>>2];
      $161 = $160 < $140;
      if ($161) {
       $162 = $158;
       HEAP32[$130>>2] = $162;
       HEAP32[$4>>2] = $148;
       $$0167 = 2;
      } else {
       $$0167 = 1;
      }
     }
    } while(0);
    $163 = HEAP32[$$1>>2]|0;
    $164 = HEAP32[$130>>2]|0;
    $165 = ((($163)) + 52|0);
    $166 = +HEAPF32[$165>>2];
    $167 = ((($164)) + 52|0);
    $168 = +HEAPF32[$167>>2];
    $169 = $166 < $168;
    if ($169) {
     $$3157 = $4;$$3170 = $$0167;
     break;
    } else {
     $$0154 = $4;
    }
    while(1) {
     $170 = ((($$0154)) + -4|0);
     $171 = ($$1|0)==($170|0);
     if ($171) {
      break;
     }
     $204 = HEAP32[$170>>2]|0;
     $205 = ((($204)) + 52|0);
     $206 = +HEAPF32[$205>>2];
     $207 = $206 < $168;
     if ($207) {
      label = 69;
      break L5;
     } else {
      $$0154 = $170;
     }
    }
    $172 = ((($$1)) + 4|0);
    $173 = HEAP32[$4>>2]|0;
    $174 = ((($173)) + 52|0);
    $175 = +HEAPF32[$174>>2];
    $176 = $166 < $175;
    $177 = $173;
    if ($176) {
     $$1161 = $172;
    } else {
     $178 = ($172|0)==($4|0);
     if ($178) {
      label = 87;
      break L1;
     } else {
      $$0160241 = $172;
     }
     while(1) {
      $179 = HEAP32[$$0160241>>2]|0;
      $180 = ((($179)) + 52|0);
      $181 = +HEAPF32[$180>>2];
      $182 = $166 < $181;
      if ($182) {
       break;
      }
      $185 = ((($$0160241)) + 4|0);
      $186 = ($185|0)==($4|0);
      if ($186) {
       label = 87;
       break L1;
      } else {
       $$0160241 = $185;
      }
     }
     $183 = $179;
     HEAP32[$$0160241>>2] = $177;
     HEAP32[$4>>2] = $183;
     $184 = ((($$0160241)) + 4|0);
     $$1161 = $184;
    }
    $187 = ($$1161|0)==($4|0);
    if ($187) {
     label = 87;
     break L1;
    } else {
     $$1155 = $4;$$2162 = $$1161;
    }
    while(1) {
     $188 = HEAP32[$$1>>2]|0;
     $189 = ((($188)) + 52|0);
     $190 = +HEAPF32[$189>>2];
     $$3163 = $$2162;
     while(1) {
      $191 = HEAP32[$$3163>>2]|0;
      $192 = ((($191)) + 52|0);
      $193 = +HEAPF32[$192>>2];
      $194 = $190 < $193;
      $195 = ((($$3163)) + 4|0);
      if ($194) {
       break;
      } else {
       $$3163 = $195;
      }
     }
     $196 = $191;
     $$2156 = $$1155;
     while(1) {
      $197 = ((($$2156)) + -4|0);
      $198 = HEAP32[$197>>2]|0;
      $199 = ((($198)) + 52|0);
      $200 = +HEAPF32[$199>>2];
      $201 = $190 < $200;
      if ($201) {
       $$2156 = $197;
      } else {
       break;
      }
     }
     $202 = ($$3163>>>0)<($197>>>0);
     if (!($202)) {
      $$1 = $$3163;
      continue L5;
     }
     $203 = $198;
     HEAP32[$$3163>>2] = $203;
     HEAP32[$197>>2] = $196;
     $$1155 = $197;$$2162 = $195;
    }
   }
   if ((label|0) == 69) {
    label = 0;
    $208 = $163;
    $209 = $204;
    HEAP32[$$1>>2] = $209;
    HEAP32[$170>>2] = $208;
    $210 = (($$0167) + 1)|0;
    $$3157 = $170;$$3170 = $210;
   }
   $211 = ((($$1)) + 4|0);
   $212 = ($211>>>0)<($$3157>>>0);
   L45: do {
    if ($212) {
     $$0174 = $130;$$4158 = $$3157;$$4164 = $211;$$4171 = $$3170;
     while(1) {
      $213 = HEAP32[$$0174>>2]|0;
      $214 = ((($213)) + 52|0);
      $215 = +HEAPF32[$214>>2];
      $$5165 = $$4164;
      while(1) {
       $216 = HEAP32[$$5165>>2]|0;
       $217 = ((($216)) + 52|0);
       $218 = +HEAPF32[$217>>2];
       $219 = $218 < $215;
       $220 = ((($$5165)) + 4|0);
       if ($219) {
        $$5165 = $220;
       } else {
        break;
       }
      }
      $221 = $216;
      $$5159 = $$4158;
      while(1) {
       $222 = ((($$5159)) + -4|0);
       $223 = HEAP32[$222>>2]|0;
       $224 = ((($223)) + 52|0);
       $225 = +HEAPF32[$224>>2];
       $226 = $225 < $215;
       if ($226) {
        break;
       } else {
        $$5159 = $222;
       }
      }
      $227 = ($$5165>>>0)>($222>>>0);
      if ($227) {
       $$2176 = $$0174;$$5172 = $$4171;$$6166 = $$5165;
       break L45;
      }
      $228 = $223;
      HEAP32[$$5165>>2] = $228;
      HEAP32[$222>>2] = $221;
      $229 = (($$4171) + 1)|0;
      $230 = ($$0174|0)==($$5165|0);
      $$$0174 = $230 ? $222 : $$0174;
      $$0174 = $$$0174;$$4158 = $222;$$4164 = $220;$$4171 = $229;
     }
    } else {
     $$2176 = $130;$$5172 = $$3170;$$6166 = $211;
    }
   } while(0);
   $231 = ($$6166|0)==($$2176|0);
   if ($231) {
    $$6173 = $$5172;
   } else {
    $232 = HEAP32[$$2176>>2]|0;
    $233 = HEAP32[$$6166>>2]|0;
    $234 = ((($232)) + 52|0);
    $235 = +HEAPF32[$234>>2];
    $236 = ((($233)) + 52|0);
    $237 = +HEAPF32[$236>>2];
    $238 = $235 < $237;
    if ($238) {
     $239 = $232;
     $240 = $233;
     $241 = (($$5172) + 1)|0;
     HEAP32[$$6166>>2] = $239;
     HEAP32[$$2176>>2] = $240;
     $$6173 = $241;
    } else {
     $$6173 = $$5172;
    }
   }
   $242 = ($$6173|0)==(0);
   if ($242) {
    $243 = (__ZNSt3__227__insertion_sort_incompleteIR32StateGraphFrontToBackSortFunctorPPN7osgUtil10StateGraphEEEbT0_S7_T_($$1,$$6166,$2)|0);
    $244 = ((($$6166)) + 4|0);
    $245 = (__ZNSt3__227__insertion_sort_incompleteIR32StateGraphFrontToBackSortFunctorPPN7osgUtil10StateGraphEEEbT0_S7_T_($244,$$0180$ph,$2)|0);
    if ($245) {
     label = 86;
     break;
    }
    if ($243) {
     $$0 = $244;
     continue;
    }
   }
   $246 = $$6166;
   $247 = (($246) - ($5))|0;
   $248 = (($3) - ($246))|0;
   $249 = ($247|0)<($248|0);
   if (!($249)) {
    label = 85;
    break;
   }
   __ZNSt3__26__sortIR32StateGraphFrontToBackSortFunctorPPN7osgUtil10StateGraphEEEvT0_S7_T_($$1,$$6166,$2);
   $250 = ((($$6166)) + 4|0);
   $$0 = $250;
  }
  if ((label|0) == 85) {
   label = 0;
   $251 = ((($$6166)) + 4|0);
   __ZNSt3__26__sortIR32StateGraphFrontToBackSortFunctorPPN7osgUtil10StateGraphEEEvT0_S7_T_($251,$$0180$ph,$2);
   $$0$ph = $$1;$$0180$ph = $$6166;
   continue;
  }
  else if ((label|0) == 86) {
   label = 0;
   if ($243) {
    label = 87;
    break;
   } else {
    $$0$ph = $$1;$$0180$ph = $$6166;
    continue;
   }
  }
 }
 if ((label|0) == 5) {
  $8 = HEAP32[$4>>2]|0;
  $9 = HEAP32[$$1>>2]|0;
  $10 = ((($8)) + 52|0);
  $11 = +HEAPF32[$10>>2];
  $12 = ((($9)) + 52|0);
  $13 = +HEAPF32[$12>>2];
  $14 = $11 < $13;
  if (!($14)) {
   return;
  }
  $15 = $8;
  $16 = $9;
  HEAP32[$$1>>2] = $15;
  HEAP32[$4>>2] = $16;
  return;
 }
 else if ((label|0) == 7) {
  $17 = ((($$1)) + 4|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = HEAP32[$$1>>2]|0;
  $20 = ((($18)) + 52|0);
  $21 = +HEAPF32[$20>>2];
  $22 = ((($19)) + 52|0);
  $23 = +HEAPF32[$22>>2];
  $24 = $21 < $23;
  $25 = HEAP32[$4>>2]|0;
  $26 = ((($25)) + 52|0);
  $27 = +HEAPF32[$26>>2];
  $28 = $27 < $21;
  $29 = $18;
  $30 = $25;
  $31 = $19;
  if (!($24)) {
   if (!($28)) {
    return;
   }
   HEAP32[$17>>2] = $30;
   HEAP32[$4>>2] = $29;
   $32 = HEAP32[$17>>2]|0;
   $33 = HEAP32[$$1>>2]|0;
   $34 = ((($32)) + 52|0);
   $35 = +HEAPF32[$34>>2];
   $36 = ((($33)) + 52|0);
   $37 = +HEAPF32[$36>>2];
   $38 = $35 < $37;
   if (!($38)) {
    return;
   }
   $39 = $32;
   $40 = $33;
   HEAP32[$$1>>2] = $39;
   HEAP32[$17>>2] = $40;
   return;
  }
  if ($28) {
   HEAP32[$$1>>2] = $30;
   HEAP32[$4>>2] = $31;
   return;
  }
  HEAP32[$$1>>2] = $29;
  HEAP32[$17>>2] = $31;
  $41 = HEAP32[$4>>2]|0;
  $42 = ((($41)) + 52|0);
  $43 = +HEAPF32[$42>>2];
  $44 = $43 < $23;
  if (!($44)) {
   return;
  }
  $45 = $41;
  HEAP32[$17>>2] = $45;
  HEAP32[$4>>2] = $31;
  return;
 }
 else if ((label|0) == 15) {
  $46 = ((($$1)) + 4|0);
  $47 = ((($$1)) + 8|0);
  $48 = HEAP32[$46>>2]|0;
  $49 = HEAP32[$$1>>2]|0;
  $50 = ((($48)) + 52|0);
  $51 = +HEAPF32[$50>>2];
  $52 = ((($49)) + 52|0);
  $53 = +HEAPF32[$52>>2];
  $54 = $51 < $53;
  $55 = HEAP32[$47>>2]|0;
  $56 = ((($55)) + 52|0);
  $57 = +HEAPF32[$56>>2];
  $58 = $57 < $51;
  $59 = $48;
  $60 = $55;
  $61 = $49;
  do {
   if ($54) {
    if ($58) {
     HEAP32[$$1>>2] = $60;
     HEAP32[$47>>2] = $61;
     $68 = $49;$72 = $61;
     break;
    }
    HEAP32[$$1>>2] = $59;
    HEAP32[$46>>2] = $61;
    $63 = $57 < $53;
    if ($63) {
     HEAP32[$46>>2] = $60;
     HEAP32[$47>>2] = $61;
     $68 = $49;$72 = $61;
    } else {
     $68 = $55;$72 = $60;
    }
   } else {
    if ($58) {
     HEAP32[$46>>2] = $60;
     HEAP32[$47>>2] = $59;
     $62 = $57 < $53;
     if ($62) {
      HEAP32[$$1>>2] = $60;
      HEAP32[$46>>2] = $61;
      $68 = $48;$72 = $59;
     } else {
      $68 = $48;$72 = $59;
     }
    } else {
     $68 = $55;$72 = $60;
    }
   }
  } while(0);
  $64 = HEAP32[$4>>2]|0;
  $65 = ((($64)) + 52|0);
  $66 = +HEAPF32[$65>>2];
  $67 = ((($68)) + 52|0);
  $69 = +HEAPF32[$67>>2];
  $70 = $66 < $69;
  if (!($70)) {
   return;
  }
  $71 = $64;
  HEAP32[$47>>2] = $71;
  HEAP32[$4>>2] = $72;
  $73 = HEAP32[$47>>2]|0;
  $74 = HEAP32[$46>>2]|0;
  $75 = ((($73)) + 52|0);
  $76 = +HEAPF32[$75>>2];
  $77 = ((($74)) + 52|0);
  $78 = +HEAPF32[$77>>2];
  $79 = $76 < $78;
  if (!($79)) {
   return;
  }
  $80 = $73;
  $81 = $74;
  HEAP32[$46>>2] = $80;
  HEAP32[$47>>2] = $81;
  $82 = HEAP32[$$1>>2]|0;
  $83 = ((($82)) + 52|0);
  $84 = +HEAPF32[$83>>2];
  $85 = $76 < $84;
  if (!($85)) {
   return;
  }
  $86 = $82;
  HEAP32[$$1>>2] = $80;
  HEAP32[$46>>2] = $86;
  return;
 }
 else if ((label|0) == 27) {
  $87 = ((($$1)) + 4|0);
  $88 = ((($$1)) + 8|0);
  $89 = ((($$1)) + 12|0);
  (__ZNSt3__27__sort5IR32StateGraphFrontToBackSortFunctorPPN7osgUtil10StateGraphEEEjT0_S7_S7_S7_S7_T_($$1,$87,$88,$89,$4,$2)|0);
  return;
 }
 else if ((label|0) == 29) {
  $91 = ((($$1)) + 8|0);
  $92 = ((($$1)) + 4|0);
  $93 = HEAP32[$92>>2]|0;
  $94 = HEAP32[$$1>>2]|0;
  $95 = ((($93)) + 52|0);
  $96 = +HEAPF32[$95>>2];
  $97 = ((($94)) + 52|0);
  $98 = +HEAPF32[$97>>2];
  $99 = $96 < $98;
  $100 = HEAP32[$91>>2]|0;
  $101 = ((($100)) + 52|0);
  $102 = +HEAPF32[$101>>2];
  $103 = $102 < $96;
  $104 = $93;
  $105 = $100;
  $106 = $94;
  do {
   if ($99) {
    if ($103) {
     HEAP32[$$1>>2] = $105;
     HEAP32[$91>>2] = $106;
     $252 = $94;
     break;
    }
    HEAP32[$$1>>2] = $104;
    HEAP32[$92>>2] = $106;
    $108 = $102 < $98;
    if ($108) {
     HEAP32[$92>>2] = $105;
     HEAP32[$91>>2] = $106;
     $252 = $94;
    } else {
     $252 = $100;
    }
   } else {
    if ($103) {
     HEAP32[$92>>2] = $105;
     HEAP32[$91>>2] = $104;
     $107 = $102 < $98;
     if ($107) {
      HEAP32[$$1>>2] = $105;
      HEAP32[$92>>2] = $106;
      $252 = $93;
     } else {
      $252 = $93;
     }
    } else {
     $252 = $100;
    }
   }
  } while(0);
  $109 = ((($$1)) + 12|0);
  $110 = ($109|0)==($$0180$ph|0);
  if ($110) {
   return;
  } else {
   $$02933$i = $109;$$03032$i = $91;$115 = $252;
  }
  while(1) {
   $111 = HEAP32[$$02933$i>>2]|0;
   $112 = ((($111)) + 52|0);
   $113 = +HEAPF32[$112>>2];
   $114 = ((($115)) + 52|0);
   $116 = +HEAPF32[$114>>2];
   $117 = $113 < $116;
   $118 = $111;
   if ($117) {
    $$0$i189 = $$03032$i;$$1$i = $$02933$i;
    while(1) {
     $119 = HEAP32[$$0$i189>>2]|0;
     HEAP32[$$1$i>>2] = $119;
     $120 = ($$0$i189|0)==($$1|0);
     if ($120) {
      break;
     }
     $121 = ((($$0$i189)) + -4|0);
     $122 = HEAP32[$121>>2]|0;
     $123 = ((($122)) + 52|0);
     $124 = +HEAPF32[$123>>2];
     $125 = $113 < $124;
     if ($125) {
      $$1$i$phi = $$0$i189;$$0$i189 = $121;$$1$i = $$1$i$phi;
     } else {
      break;
     }
    }
    HEAP32[$$0$i189>>2] = $118;
   }
   $126 = ((($$02933$i)) + 4|0);
   $127 = ($126|0)==($$0180$ph|0);
   if ($127) {
    break;
   }
   $$pre$i190 = HEAP32[$$02933$i>>2]|0;
   $$03032$i$phi = $$02933$i;$$02933$i = $126;$115 = $$pre$i190;$$03032$i = $$03032$i$phi;
  }
  return;
 }
 else if ((label|0) == 87) {
  return;
 }
}
function __ZNSt3__26__sortIRN7osgUtil20LessDepthSortFunctorEPN3osg7ref_ptrINS1_10RenderLeafEEEEEvT0_S9_T_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$$0174 = 0, $$0 = 0, $$0$ph = 0, $$0154 = 0, $$0160236 = 0, $$0167 = 0, $$0174 = 0, $$0180$ph = 0, $$1 = 0, $$1155 = 0, $$1161 = 0, $$2156 = 0, $$2162 = 0, $$2176 = 0, $$3157 = 0, $$3163 = 0, $$3170 = 0, $$4158 = 0, $$4164 = 0, $$4171 = 0;
 var $$5159 = 0, $$5165 = 0, $$5172 = 0, $$6166 = 0, $$6173 = 0, $$pre$phi268Z2D = 0, $$pre$phiZ2D = 0, $10 = 0.0, $100 = 0.0, $101 = 0, $102 = 0, $103 = 0.0, $104 = 0, $105 = 0, $106 = 0, $107 = 0.0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0.0, $115 = 0, $116 = 0, $117 = 0.0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0.0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0.0, $129 = 0;
 var $13 = 0.0, $130 = 0, $131 = 0.0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0.0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0.0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0.0, $154 = 0, $155 = 0, $156 = 0.0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0.0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0.0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0.0, $179 = 0, $18 = 0, $180 = 0, $181 = 0.0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0.0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0.0, $198 = 0, $199 = 0, $20 = 0.0, $200 = 0.0, $201 = 0;
 var $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $22 = 0, $23 = 0.0, $24 = 0, $25 = 0, $26 = 0, $27 = 0.0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0.0, $35 = 0, $36 = 0, $37 = 0.0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0.0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0.0, $51 = 0, $52 = 0, $53 = 0.0, $54 = 0, $55 = 0, $56 = 0, $57 = 0.0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0.0, $67 = 0, $68 = 0, $69 = 0.0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0.0, $76 = 0, $77 = 0, $78 = 0.0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0.0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $$0$ph = $0;$$0180$ph = $1;
 L1: while(1) {
  $3 = $$0180$ph;
  $4 = ((($$0180$ph)) + -4|0);
  $$0 = $$0$ph;
  while(1) {
   $$1 = $$0;
   L5: while(1) {
    $5 = $$1;
    $6 = (($3) - ($5))|0;
    $7 = $6 >> 2;
    switch ($7|0) {
    case 2:  {
     label = 5;
     break L1;
     break;
    }
    case 3:  {
     label = 7;
     break L1;
     break;
    }
    case 4:  {
     label = 15;
     break L1;
     break;
    }
    case 5:  {
     label = 27;
     break L1;
     break;
    }
    case 1: case 0:  {
     label = 73;
     break L1;
     break;
    }
    default: {
    }
    }
    $90 = ($6|0)<(28);
    if ($90) {
     label = 29;
     break L1;
    }
    $91 = ($6|0)>(3996);
    $92 = (($7|0) / 2)&-1;
    $93 = (($$1) + ($92<<2)|0);
    do {
     if ($91) {
      $94 = (($7|0) / 4)&-1;
      $95 = (($$1) + ($94<<2)|0);
      $96 = (($93) + ($94<<2)|0);
      $97 = (__ZNSt3__27__sort5IRN7osgUtil20LessDepthSortFunctorEPN3osg7ref_ptrINS1_10RenderLeafEEEEEjT0_S9_S9_S9_S9_T_($$1,$95,$93,$96,$4,$2)|0);
      $$0167 = $97;$$pre$phi268Z2D = $93;$$pre$phiZ2D = $$1;
     } else {
      $98 = HEAP32[$93>>2]|0;
      $99 = ((($98)) + 28|0);
      $100 = +HEAPF32[$99>>2];
      $101 = HEAP32[$$1>>2]|0;
      $102 = ((($101)) + 28|0);
      $103 = +HEAPF32[$102>>2];
      $104 = $100 < $103;
      $105 = HEAP32[$4>>2]|0;
      $106 = ((($105)) + 28|0);
      $107 = +HEAPF32[$106>>2];
      $108 = $107 < $100;
      $109 = $98;
      $110 = $105;
      $111 = $101;
      if (!($104)) {
       if (!($108)) {
        $$0167 = 0;$$pre$phi268Z2D = $93;$$pre$phiZ2D = $$1;
        break;
       }
       HEAP32[$93>>2] = $110;
       HEAP32[$4>>2] = $109;
       $112 = HEAP32[$93>>2]|0;
       $113 = ((($112)) + 28|0);
       $114 = +HEAPF32[$113>>2];
       $115 = HEAP32[$$1>>2]|0;
       $116 = ((($115)) + 28|0);
       $117 = +HEAPF32[$116>>2];
       $118 = $114 < $117;
       if (!($118)) {
        $$0167 = 1;$$pre$phi268Z2D = $93;$$pre$phiZ2D = $$1;
        break;
       }
       $119 = $112;
       $120 = $115;
       HEAP32[$$1>>2] = $119;
       HEAP32[$93>>2] = $120;
       $$0167 = 2;$$pre$phi268Z2D = $93;$$pre$phiZ2D = $$1;
       break;
      }
      if ($108) {
       HEAP32[$$1>>2] = $110;
       HEAP32[$4>>2] = $111;
       $$0167 = 1;$$pre$phi268Z2D = $93;$$pre$phiZ2D = $$1;
       break;
      }
      HEAP32[$$1>>2] = $109;
      HEAP32[$93>>2] = $111;
      $121 = HEAP32[$4>>2]|0;
      $122 = ((($121)) + 28|0);
      $123 = +HEAPF32[$122>>2];
      $124 = $123 < $103;
      if ($124) {
       $125 = $121;
       HEAP32[$93>>2] = $125;
       HEAP32[$4>>2] = $111;
       $$0167 = 2;$$pre$phi268Z2D = $93;$$pre$phiZ2D = $$1;
      } else {
       $$0167 = 1;$$pre$phi268Z2D = $93;$$pre$phiZ2D = $$1;
      }
     }
    } while(0);
    $126 = HEAP32[$$pre$phiZ2D>>2]|0;
    $127 = ((($126)) + 28|0);
    $128 = +HEAPF32[$127>>2];
    $129 = HEAP32[$$pre$phi268Z2D>>2]|0;
    $130 = ((($129)) + 28|0);
    $131 = +HEAPF32[$130>>2];
    $132 = $128 < $131;
    if ($132) {
     $$3157 = $4;$$3170 = $$0167;
     break;
    } else {
     $$0154 = $4;
    }
    while(1) {
     $133 = ((($$0154)) + -4|0);
     $134 = ($$1|0)==($133|0);
     if ($134) {
      break;
     }
     $167 = HEAP32[$133>>2]|0;
     $168 = ((($167)) + 28|0);
     $169 = +HEAPF32[$168>>2];
     $170 = $169 < $131;
     if ($170) {
      label = 55;
      break L5;
     } else {
      $$0154 = $133;
     }
    }
    $135 = ((($$1)) + 4|0);
    $136 = HEAP32[$4>>2]|0;
    $137 = ((($136)) + 28|0);
    $138 = +HEAPF32[$137>>2];
    $139 = $128 < $138;
    $140 = $136;
    if ($139) {
     $$1161 = $135;
    } else {
     $141 = ($135|0)==($4|0);
     if ($141) {
      label = 73;
      break L1;
     } else {
      $$0160236 = $135;
     }
     while(1) {
      $142 = HEAP32[$$0160236>>2]|0;
      $143 = ((($142)) + 28|0);
      $144 = +HEAPF32[$143>>2];
      $145 = $128 < $144;
      if ($145) {
       break;
      }
      $148 = ((($$0160236)) + 4|0);
      $149 = ($148|0)==($4|0);
      if ($149) {
       label = 73;
       break L1;
      } else {
       $$0160236 = $148;
      }
     }
     $146 = $142;
     HEAP32[$$0160236>>2] = $140;
     HEAP32[$4>>2] = $146;
     $147 = ((($$0160236)) + 4|0);
     $$1161 = $147;
    }
    $150 = ($$1161|0)==($4|0);
    if ($150) {
     label = 73;
     break L1;
    } else {
     $$1155 = $4;$$2162 = $$1161;
    }
    while(1) {
     $151 = HEAP32[$$pre$phiZ2D>>2]|0;
     $152 = ((($151)) + 28|0);
     $153 = +HEAPF32[$152>>2];
     $$3163 = $$2162;
     while(1) {
      $154 = HEAP32[$$3163>>2]|0;
      $155 = ((($154)) + 28|0);
      $156 = +HEAPF32[$155>>2];
      $157 = $153 < $156;
      $158 = ((($$3163)) + 4|0);
      if ($157) {
       break;
      } else {
       $$3163 = $158;
      }
     }
     $159 = $154;
     $$2156 = $$1155;
     while(1) {
      $160 = ((($$2156)) + -4|0);
      $161 = HEAP32[$160>>2]|0;
      $162 = ((($161)) + 28|0);
      $163 = +HEAPF32[$162>>2];
      $164 = $153 < $163;
      if ($164) {
       $$2156 = $160;
      } else {
       break;
      }
     }
     $165 = ($$3163>>>0)<($160>>>0);
     if (!($165)) {
      $$1 = $$3163;
      continue L5;
     }
     $166 = $161;
     HEAP32[$$3163>>2] = $166;
     HEAP32[$160>>2] = $159;
     $$1155 = $160;$$2162 = $158;
    }
   }
   if ((label|0) == 55) {
    label = 0;
    $171 = $126;
    $172 = $167;
    HEAP32[$$1>>2] = $172;
    HEAP32[$133>>2] = $171;
    $173 = (($$0167) + 1)|0;
    $$3157 = $133;$$3170 = $173;
   }
   $174 = ((($$1)) + 4|0);
   $175 = ($174>>>0)<($$3157>>>0);
   L45: do {
    if ($175) {
     $$0174 = $93;$$4158 = $$3157;$$4164 = $174;$$4171 = $$3170;
     while(1) {
      $176 = HEAP32[$$0174>>2]|0;
      $177 = ((($176)) + 28|0);
      $178 = +HEAPF32[$177>>2];
      $$5165 = $$4164;
      while(1) {
       $179 = HEAP32[$$5165>>2]|0;
       $180 = ((($179)) + 28|0);
       $181 = +HEAPF32[$180>>2];
       $182 = $181 < $178;
       $183 = ((($$5165)) + 4|0);
       if ($182) {
        $$5165 = $183;
       } else {
        break;
       }
      }
      $184 = $179;
      $$5159 = $$4158;
      while(1) {
       $185 = ((($$5159)) + -4|0);
       $186 = HEAP32[$185>>2]|0;
       $187 = ((($186)) + 28|0);
       $188 = +HEAPF32[$187>>2];
       $189 = $188 < $178;
       if ($189) {
        break;
       } else {
        $$5159 = $185;
       }
      }
      $190 = ($$5165>>>0)>($185>>>0);
      if ($190) {
       $$2176 = $$0174;$$5172 = $$4171;$$6166 = $$5165;
       break L45;
      }
      $191 = $186;
      HEAP32[$$5165>>2] = $191;
      HEAP32[$185>>2] = $184;
      $192 = (($$4171) + 1)|0;
      $193 = ($$0174|0)==($$5165|0);
      $$$0174 = $193 ? $185 : $$0174;
      $$0174 = $$$0174;$$4158 = $185;$$4164 = $183;$$4171 = $192;
     }
    } else {
     $$2176 = $93;$$5172 = $$3170;$$6166 = $174;
    }
   } while(0);
   $194 = ($$6166|0)==($$2176|0);
   if ($194) {
    $$6173 = $$5172;
   } else {
    $195 = HEAP32[$$2176>>2]|0;
    $196 = ((($195)) + 28|0);
    $197 = +HEAPF32[$196>>2];
    $198 = HEAP32[$$6166>>2]|0;
    $199 = ((($198)) + 28|0);
    $200 = +HEAPF32[$199>>2];
    $201 = $197 < $200;
    if ($201) {
     $202 = $195;
     $203 = $198;
     $204 = (($$5172) + 1)|0;
     HEAP32[$$6166>>2] = $202;
     HEAP32[$$2176>>2] = $203;
     $$6173 = $204;
    } else {
     $$6173 = $$5172;
    }
   }
   $205 = ($$6173|0)==(0);
   if ($205) {
    $206 = (__ZNSt3__227__insertion_sort_incompleteIRN7osgUtil20LessDepthSortFunctorEPN3osg7ref_ptrINS1_10RenderLeafEEEEEbT0_S9_T_($$1,$$6166,$2)|0);
    $207 = ((($$6166)) + 4|0);
    $208 = (__ZNSt3__227__insertion_sort_incompleteIRN7osgUtil20LessDepthSortFunctorEPN3osg7ref_ptrINS1_10RenderLeafEEEEEbT0_S9_T_($207,$$0180$ph,$2)|0);
    if ($208) {
     label = 72;
     break;
    }
    if ($206) {
     $$0 = $207;
     continue;
    }
   }
   $209 = $$6166;
   $210 = (($209) - ($5))|0;
   $211 = (($3) - ($209))|0;
   $212 = ($210|0)<($211|0);
   if (!($212)) {
    label = 71;
    break;
   }
   __ZNSt3__26__sortIRN7osgUtil20LessDepthSortFunctorEPN3osg7ref_ptrINS1_10RenderLeafEEEEEvT0_S9_T_($$1,$$6166,$2);
   $213 = ((($$6166)) + 4|0);
   $$0 = $213;
  }
  if ((label|0) == 71) {
   label = 0;
   $214 = ((($$6166)) + 4|0);
   __ZNSt3__26__sortIRN7osgUtil20LessDepthSortFunctorEPN3osg7ref_ptrINS1_10RenderLeafEEEEEvT0_S9_T_($214,$$0180$ph,$2);
   $$0$ph = $$1;$$0180$ph = $$6166;
   continue;
  }
  else if ((label|0) == 72) {
   label = 0;
   if ($206) {
    label = 73;
    break;
   } else {
    $$0$ph = $$1;$$0180$ph = $$6166;
    continue;
   }
  }
 }
 if ((label|0) == 5) {
  $8 = HEAP32[$4>>2]|0;
  $9 = ((($8)) + 28|0);
  $10 = +HEAPF32[$9>>2];
  $11 = HEAP32[$$1>>2]|0;
  $12 = ((($11)) + 28|0);
  $13 = +HEAPF32[$12>>2];
  $14 = $10 < $13;
  if (!($14)) {
   return;
  }
  $15 = $8;
  $16 = $11;
  HEAP32[$$1>>2] = $15;
  HEAP32[$4>>2] = $16;
  return;
 }
 else if ((label|0) == 7) {
  $17 = ((($$1)) + 4|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = ((($18)) + 28|0);
  $20 = +HEAPF32[$19>>2];
  $21 = HEAP32[$$1>>2]|0;
  $22 = ((($21)) + 28|0);
  $23 = +HEAPF32[$22>>2];
  $24 = $20 < $23;
  $25 = HEAP32[$4>>2]|0;
  $26 = ((($25)) + 28|0);
  $27 = +HEAPF32[$26>>2];
  $28 = $27 < $20;
  $29 = $18;
  $30 = $25;
  $31 = $21;
  if (!($24)) {
   if (!($28)) {
    return;
   }
   HEAP32[$17>>2] = $30;
   HEAP32[$4>>2] = $29;
   $32 = HEAP32[$17>>2]|0;
   $33 = ((($32)) + 28|0);
   $34 = +HEAPF32[$33>>2];
   $35 = HEAP32[$$1>>2]|0;
   $36 = ((($35)) + 28|0);
   $37 = +HEAPF32[$36>>2];
   $38 = $34 < $37;
   if (!($38)) {
    return;
   }
   $39 = $32;
   $40 = $35;
   HEAP32[$$1>>2] = $39;
   HEAP32[$17>>2] = $40;
   return;
  }
  if ($28) {
   HEAP32[$$1>>2] = $30;
   HEAP32[$4>>2] = $31;
   return;
  }
  HEAP32[$$1>>2] = $29;
  HEAP32[$17>>2] = $31;
  $41 = HEAP32[$4>>2]|0;
  $42 = ((($41)) + 28|0);
  $43 = +HEAPF32[$42>>2];
  $44 = $43 < $23;
  if (!($44)) {
   return;
  }
  $45 = $41;
  HEAP32[$17>>2] = $45;
  HEAP32[$4>>2] = $31;
  return;
 }
 else if ((label|0) == 15) {
  $46 = ((($$1)) + 4|0);
  $47 = ((($$1)) + 8|0);
  $48 = HEAP32[$46>>2]|0;
  $49 = ((($48)) + 28|0);
  $50 = +HEAPF32[$49>>2];
  $51 = HEAP32[$$1>>2]|0;
  $52 = ((($51)) + 28|0);
  $53 = +HEAPF32[$52>>2];
  $54 = $50 < $53;
  $55 = HEAP32[$47>>2]|0;
  $56 = ((($55)) + 28|0);
  $57 = +HEAPF32[$56>>2];
  $58 = $57 < $50;
  $59 = $48;
  $60 = $55;
  $61 = $51;
  do {
   if ($54) {
    if ($58) {
     HEAP32[$$1>>2] = $60;
     HEAP32[$47>>2] = $61;
     $68 = $51;$72 = $61;
     break;
    }
    HEAP32[$$1>>2] = $59;
    HEAP32[$46>>2] = $61;
    $63 = $57 < $53;
    if ($63) {
     HEAP32[$46>>2] = $60;
     HEAP32[$47>>2] = $61;
     $68 = $51;$72 = $61;
    } else {
     $68 = $55;$72 = $60;
    }
   } else {
    if ($58) {
     HEAP32[$46>>2] = $60;
     HEAP32[$47>>2] = $59;
     $62 = $57 < $53;
     if ($62) {
      HEAP32[$$1>>2] = $60;
      HEAP32[$46>>2] = $61;
      $68 = $48;$72 = $59;
     } else {
      $68 = $48;$72 = $59;
     }
    } else {
     $68 = $55;$72 = $60;
    }
   }
  } while(0);
  $64 = HEAP32[$4>>2]|0;
  $65 = ((($64)) + 28|0);
  $66 = +HEAPF32[$65>>2];
  $67 = ((($68)) + 28|0);
  $69 = +HEAPF32[$67>>2];
  $70 = $66 < $69;
  if (!($70)) {
   return;
  }
  $71 = $64;
  HEAP32[$47>>2] = $71;
  HEAP32[$4>>2] = $72;
  $73 = HEAP32[$47>>2]|0;
  $74 = ((($73)) + 28|0);
  $75 = +HEAPF32[$74>>2];
  $76 = HEAP32[$46>>2]|0;
  $77 = ((($76)) + 28|0);
  $78 = +HEAPF32[$77>>2];
  $79 = $75 < $78;
  if (!($79)) {
   return;
  }
  $80 = $73;
  $81 = $76;
  HEAP32[$46>>2] = $80;
  HEAP32[$47>>2] = $81;
  $82 = HEAP32[$$1>>2]|0;
  $83 = ((($82)) + 28|0);
  $84 = +HEAPF32[$83>>2];
  $85 = $75 < $84;
  if (!($85)) {
   return;
  }
  $86 = $82;
  HEAP32[$$1>>2] = $80;
  HEAP32[$46>>2] = $86;
  return;
 }
 else if ((label|0) == 27) {
  $87 = ((($$1)) + 4|0);
  $88 = ((($$1)) + 8|0);
  $89 = ((($$1)) + 12|0);
  (__ZNSt3__27__sort5IRN7osgUtil20LessDepthSortFunctorEPN3osg7ref_ptrINS1_10RenderLeafEEEEEjT0_S9_S9_S9_S9_T_($$1,$87,$88,$89,$4,$2)|0);
  return;
 }
 else if ((label|0) == 29) {
  __ZNSt3__218__insertion_sort_3IRN7osgUtil20LessDepthSortFunctorEPN3osg7ref_ptrINS1_10RenderLeafEEEEEvT0_S9_T_($$1,$$0180$ph,$2);
  return;
 }
 else if ((label|0) == 73) {
  return;
 }
}
function __ZNSt3__27__sort5IRN7osgUtil20LessDepthSortFunctorEPN3osg7ref_ptrINS1_10RenderLeafEEEEEjT0_S9_S9_S9_S9_T_($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$0 = 0, $$0$i = 0, $$026$i$i = 0, $$pre$i = 0, $10 = 0, $100 = 0.0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $11 = 0.0, $12 = 0, $13 = 0, $14 = 0, $15 = 0.0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0;
 var $21 = 0, $22 = 0.0, $23 = 0, $24 = 0, $25 = 0.0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0.0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0.0, $38 = 0, $39 = 0, $40 = 0.0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0.0, $48 = 0, $49 = 0, $50 = 0.0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0.0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0.0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0.0, $68 = 0, $69 = 0, $7 = 0, $70 = 0.0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0.0, $78 = 0;
 var $79 = 0, $8 = 0.0, $80 = 0.0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0.0, $88 = 0, $89 = 0, $9 = 0, $90 = 0.0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0.0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $6 = HEAP32[$1>>2]|0;
 $7 = ((($6)) + 28|0);
 $8 = +HEAPF32[$7>>2];
 $9 = HEAP32[$0>>2]|0;
 $10 = ((($9)) + 28|0);
 $11 = +HEAPF32[$10>>2];
 $12 = $8 < $11;
 $13 = HEAP32[$2>>2]|0;
 $14 = ((($13)) + 28|0);
 $15 = +HEAPF32[$14>>2];
 $16 = $15 < $8;
 $17 = $6;
 $18 = $13;
 $19 = $9;
 do {
  if ($12) {
   if ($16) {
    HEAP32[$0>>2] = $18;
    HEAP32[$2>>2] = $19;
    $$026$i$i = 1;$39 = $9;$43 = $19;
    break;
   }
   HEAP32[$0>>2] = $17;
   HEAP32[$1>>2] = $19;
   $30 = HEAP32[$2>>2]|0;
   $31 = ((($30)) + 28|0);
   $32 = +HEAPF32[$31>>2];
   $33 = $32 < $11;
   $34 = $30;
   if ($33) {
    HEAP32[$1>>2] = $34;
    HEAP32[$2>>2] = $19;
    $$026$i$i = 2;$39 = $9;$43 = $19;
   } else {
    $$026$i$i = 1;$39 = $30;$43 = $34;
   }
  } else {
   if ($16) {
    HEAP32[$1>>2] = $18;
    HEAP32[$2>>2] = $17;
    $20 = HEAP32[$1>>2]|0;
    $21 = ((($20)) + 28|0);
    $22 = +HEAPF32[$21>>2];
    $23 = HEAP32[$0>>2]|0;
    $24 = ((($23)) + 28|0);
    $25 = +HEAPF32[$24>>2];
    $26 = $22 < $25;
    if ($26) {
     $27 = $20;
     $28 = $23;
     HEAP32[$0>>2] = $27;
     HEAP32[$1>>2] = $28;
     $$pre$i = HEAP32[$2>>2]|0;
     $29 = $$pre$i;
     $$026$i$i = 2;$39 = $$pre$i;$43 = $29;
    } else {
     $$026$i$i = 1;$39 = $6;$43 = $17;
    }
   } else {
    $$026$i$i = 0;$39 = $13;$43 = $18;
   }
  }
 } while(0);
 $35 = HEAP32[$3>>2]|0;
 $36 = ((($35)) + 28|0);
 $37 = +HEAPF32[$36>>2];
 $38 = ((($39)) + 28|0);
 $40 = +HEAPF32[$38>>2];
 $41 = $37 < $40;
 if ($41) {
  $42 = $35;
  HEAP32[$2>>2] = $42;
  HEAP32[$3>>2] = $43;
  $44 = (($$026$i$i) + 1)|0;
  $45 = HEAP32[$2>>2]|0;
  $46 = ((($45)) + 28|0);
  $47 = +HEAPF32[$46>>2];
  $48 = HEAP32[$1>>2]|0;
  $49 = ((($48)) + 28|0);
  $50 = +HEAPF32[$49>>2];
  $51 = $47 < $50;
  if ($51) {
   $52 = $45;
   $53 = $48;
   HEAP32[$1>>2] = $52;
   HEAP32[$2>>2] = $53;
   $54 = (($$026$i$i) + 2)|0;
   $55 = HEAP32[$1>>2]|0;
   $56 = ((($55)) + 28|0);
   $57 = +HEAPF32[$56>>2];
   $58 = HEAP32[$0>>2]|0;
   $59 = ((($58)) + 28|0);
   $60 = +HEAPF32[$59>>2];
   $61 = $57 < $60;
   if ($61) {
    $62 = (($$026$i$i) + 3)|0;
    $63 = $58;
    $64 = $55;
    HEAP32[$0>>2] = $64;
    HEAP32[$1>>2] = $63;
    $$0$i = $62;
   } else {
    $$0$i = $54;
   }
  } else {
   $$0$i = $44;
  }
 } else {
  $$0$i = $$026$i$i;
 }
 $65 = HEAP32[$4>>2]|0;
 $66 = ((($65)) + 28|0);
 $67 = +HEAPF32[$66>>2];
 $68 = HEAP32[$3>>2]|0;
 $69 = ((($68)) + 28|0);
 $70 = +HEAPF32[$69>>2];
 $71 = $67 < $70;
 if (!($71)) {
  $$0 = $$0$i;
  return ($$0|0);
 }
 $72 = $65;
 $73 = $68;
 HEAP32[$3>>2] = $72;
 HEAP32[$4>>2] = $73;
 $74 = (($$0$i) + 1)|0;
 $75 = HEAP32[$3>>2]|0;
 $76 = ((($75)) + 28|0);
 $77 = +HEAPF32[$76>>2];
 $78 = HEAP32[$2>>2]|0;
 $79 = ((($78)) + 28|0);
 $80 = +HEAPF32[$79>>2];
 $81 = $77 < $80;
 if (!($81)) {
  $$0 = $74;
  return ($$0|0);
 }
 $82 = $75;
 $83 = $78;
 HEAP32[$2>>2] = $82;
 HEAP32[$3>>2] = $83;
 $84 = (($$0$i) + 2)|0;
 $85 = HEAP32[$2>>2]|0;
 $86 = ((($85)) + 28|0);
 $87 = +HEAPF32[$86>>2];
 $88 = HEAP32[$1>>2]|0;
 $89 = ((($88)) + 28|0);
 $90 = +HEAPF32[$89>>2];
 $91 = $87 < $90;
 if (!($91)) {
  $$0 = $84;
  return ($$0|0);
 }
 $92 = $85;
 $93 = $88;
 HEAP32[$1>>2] = $92;
 HEAP32[$2>>2] = $93;
 $94 = (($$0$i) + 3)|0;
 $95 = HEAP32[$1>>2]|0;
 $96 = ((($95)) + 28|0);
 $97 = +HEAPF32[$96>>2];
 $98 = HEAP32[$0>>2]|0;
 $99 = ((($98)) + 28|0);
 $100 = +HEAPF32[$99>>2];
 $101 = $97 < $100;
 if (!($101)) {
  $$0 = $94;
  return ($$0|0);
 }
 $102 = $95;
 $103 = $98;
 $104 = (($$0$i) + 4)|0;
 HEAP32[$0>>2] = $102;
 HEAP32[$1>>2] = $103;
 $$0 = $104;
 return ($$0|0);
}
function __ZNSt3__218__insertion_sort_3IRN7osgUtil20LessDepthSortFunctorEPN3osg7ref_ptrINS1_10RenderLeafEEEEEvT0_S9_T_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$03348 = 0, $$034 = 0, $$049 = 0, $$049$phi = 0, $$1 = 0, $$1$phi = 0, $$pre = 0, $$pre55$pre = 0, $$pre5557 = 0, $$pre5558 = 0, $10 = 0.0, $11 = 0, $12 = 0, $13 = 0, $14 = 0.0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0.0, $26 = 0, $27 = 0.0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0.0, $47 = 0, $48 = 0, $49 = 0.0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0.0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 8|0);
 $4 = ((($0)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($5)) + 28|0);
 $7 = +HEAPF32[$6>>2];
 $8 = HEAP32[$0>>2]|0;
 $9 = ((($8)) + 28|0);
 $10 = +HEAPF32[$9>>2];
 $11 = $7 < $10;
 $12 = HEAP32[$3>>2]|0;
 $13 = ((($12)) + 28|0);
 $14 = +HEAPF32[$13>>2];
 $15 = $14 < $7;
 $16 = $5;
 $17 = $12;
 $18 = $8;
 do {
  if ($11) {
   if ($15) {
    HEAP32[$0>>2] = $17;
    HEAP32[$3>>2] = $18;
    $$pre5558 = $8;
    break;
   }
   HEAP32[$0>>2] = $16;
   HEAP32[$4>>2] = $18;
   $20 = $14 < $10;
   if ($20) {
    HEAP32[$4>>2] = $17;
    HEAP32[$3>>2] = $18;
    $$pre5558 = $8;
   } else {
    $$pre5558 = $12;
   }
  } else {
   if ($15) {
    HEAP32[$4>>2] = $17;
    HEAP32[$3>>2] = $16;
    $19 = $14 < $10;
    if ($19) {
     HEAP32[$0>>2] = $17;
     HEAP32[$4>>2] = $18;
     $$pre5558 = $5;
    } else {
     $$pre5558 = $5;
    }
   } else {
    $$pre5558 = $12;
   }
  }
 } while(0);
 $21 = ((($0)) + 12|0);
 $22 = ($21|0)==($1|0);
 if ($22) {
  return;
 } else {
  $$03348 = $21;$$049 = $3;$$pre5557 = $$pre5558;
 }
 L13: while(1) {
  $23 = HEAP32[$$03348>>2]|0;
  $24 = ((($23)) + 28|0);
  $25 = +HEAPF32[$24>>2];
  $26 = ((($$pre5557)) + 28|0);
  $27 = +HEAPF32[$26>>2];
  $28 = $25 < $27;
  if ($28) {
   $29 = ($23|0)==(0|0);
   if ($29) {
    $$034 = $$049;$$1 = $$03348;$34 = $$pre5557;
   } else {
    $30 = ((($23)) + 8|0);
    $31 = HEAP32[$30>>2]|0;HEAP32[$30>>2] = (($31+1)|0);
    $$pre55$pre = HEAP32[$$049>>2]|0;
    $$034 = $$049;$$1 = $$03348;$34 = $$pre55$pre;
   }
   while(1) {
    $32 = HEAP32[$$1>>2]|0;
    $33 = ($32|0)==($34|0);
    if (!($33)) {
     HEAP32[$$1>>2] = $34;
     $35 = ($34|0)==(0|0);
     if (!($35)) {
      $36 = ((($34)) + 8|0);
      $37 = HEAP32[$36>>2]|0;HEAP32[$36>>2] = (($37+1)|0);
     }
     $38 = ($32|0)==(0|0);
     if (!($38)) {
      $39 = ((($32)) + 8|0);
      $40 = HEAP32[$39>>2]|0;HEAP32[$39>>2] = (($40-1)|0);
      $41 = ($40|0)==(1);
      if ($41) {
       __THREW__ = 0;
       invoke_viii(3262,($32|0),1,1);
       $42 = __THREW__; __THREW__ = 0;
       $43 = $42&1;
       if ($43) {
        break L13;
       }
      }
     }
    }
    $44 = ($$034|0)==($0|0);
    if ($44) {
     break;
    }
    $45 = ((($$034)) + -4|0);
    $46 = +HEAPF32[$24>>2];
    $47 = HEAP32[$45>>2]|0;
    $48 = ((($47)) + 28|0);
    $49 = +HEAPF32[$48>>2];
    $50 = $46 < $49;
    if ($50) {
     $$1$phi = $$034;$$034 = $45;$34 = $47;$$1 = $$1$phi;
    } else {
     break;
    }
   }
   $51 = HEAP32[$$034>>2]|0;
   $52 = ($51|0)==($23|0);
   if (!($52)) {
    HEAP32[$$034>>2] = $23;
    if (!($29)) {
     $53 = ((($23)) + 8|0);
     $54 = HEAP32[$53>>2]|0;HEAP32[$53>>2] = (($54+1)|0);
    }
    $55 = ($51|0)==(0|0);
    if (!($55)) {
     $56 = ((($51)) + 8|0);
     $57 = HEAP32[$56>>2]|0;HEAP32[$56>>2] = (($57-1)|0);
     $58 = ($57|0)==(1);
     if ($58) {
      __THREW__ = 0;
      invoke_viii(3262,($51|0),1,1);
      $59 = __THREW__; __THREW__ = 0;
      $60 = $59&1;
      if ($60) {
       break;
      }
     }
    }
   }
   if (!($29)) {
    $61 = ((($23)) + 8|0);
    $62 = HEAP32[$61>>2]|0;HEAP32[$61>>2] = (($62-1)|0);
    $63 = ($62|0)==(1);
    if ($63) {
     __ZNK3osg10Referenced24signalObserversAndDeleteEbb($23,1,1);
    }
   }
  }
  $71 = ((($$03348)) + 4|0);
  $72 = ($71|0)==($1|0);
  if ($72) {
   label = 10;
   break;
  }
  $$pre = HEAP32[$$03348>>2]|0;
  $$049$phi = $$03348;$$03348 = $71;$$pre5557 = $$pre;$$049 = $$049$phi;
 }
 if ((label|0) == 10) {
  return;
 }
 $64 = ___cxa_find_matching_catch_2()|0;
 $65 = tempRet0;
 if ($29) {
  ___resumeException($64|0);
  // unreachable;
 }
 $66 = ((($23)) + 8|0);
 $67 = HEAP32[$66>>2]|0;HEAP32[$66>>2] = (($67-1)|0);
 $68 = ($67|0)==(1);
 if (!($68)) {
  ___resumeException($64|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(3262,($23|0),1,1);
 $69 = __THREW__; __THREW__ = 0;
 $70 = $69&1;
 if ($70) {
  $73 = ___cxa_find_matching_catch_3(0|0)|0;
  $74 = tempRet0;
  ___clang_call_terminate($73);
  // unreachable;
 } else {
  ___resumeException($64|0);
  // unreachable;
 }
}
function __ZNSt3__227__insertion_sort_incompleteIRN7osgUtil20LessDepthSortFunctorEPN3osg7ref_ptrINS1_10RenderLeafEEEEEbT0_S9_T_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$$3 = 0, $$068 = 0, $$07195 = 0, $$07494 = 0, $$07693 = 0, $$07693$phi = 0, $$170 = 0, $$175 = 0, $$177 = 0, $$177$phi = 0, $$3 = 0, $$5 = 0, $$pre = 0, $$pre105$pre = 0, $$pre105107 = 0, $$pre105108 = 0, $10 = 0.0, $100 = 0.0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0.0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0.0, $116 = 0, $117 = 0.0, $118 = 0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0.0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0.0, $137 = 0, $138 = 0, $139 = 0.0;
 var $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0;
 var $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0.0, $22 = 0, $23 = 0, $24 = 0.0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0.0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0.0, $36 = 0, $37 = 0, $38 = 0.0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0.0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0.0, $53 = 0, $54 = 0, $55 = 0.0, $56 = 0, $57 = 0, $58 = 0, $59 = 0.0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0.0, $69 = 0, $7 = 0, $70 = 0, $71 = 0.0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0.0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0.0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0.0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0.0;
 var $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = $1;
 $4 = $0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 switch ($6|0) {
 case 2:  {
  $7 = ((($1)) + -4|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ((($8)) + 28|0);
  $10 = +HEAPF32[$9>>2];
  $11 = HEAP32[$0>>2]|0;
  $12 = ((($11)) + 28|0);
  $13 = +HEAPF32[$12>>2];
  $14 = $10 < $13;
  if (!($14)) {
   $$5 = 1;
   return ($$5|0);
  }
  $15 = $8;
  $16 = $11;
  HEAP32[$0>>2] = $15;
  HEAP32[$7>>2] = $16;
  $$5 = 1;
  return ($$5|0);
  break;
 }
 case 3:  {
  $17 = ((($0)) + 4|0);
  $18 = ((($1)) + -4|0);
  $19 = HEAP32[$17>>2]|0;
  $20 = ((($19)) + 28|0);
  $21 = +HEAPF32[$20>>2];
  $22 = HEAP32[$0>>2]|0;
  $23 = ((($22)) + 28|0);
  $24 = +HEAPF32[$23>>2];
  $25 = $21 < $24;
  $26 = HEAP32[$18>>2]|0;
  $27 = ((($26)) + 28|0);
  $28 = +HEAPF32[$27>>2];
  $29 = $28 < $21;
  $30 = $19;
  $31 = $26;
  $32 = $22;
  if (!($25)) {
   if (!($29)) {
    $$5 = 1;
    return ($$5|0);
   }
   HEAP32[$17>>2] = $31;
   HEAP32[$18>>2] = $30;
   $33 = HEAP32[$17>>2]|0;
   $34 = ((($33)) + 28|0);
   $35 = +HEAPF32[$34>>2];
   $36 = HEAP32[$0>>2]|0;
   $37 = ((($36)) + 28|0);
   $38 = +HEAPF32[$37>>2];
   $39 = $35 < $38;
   if (!($39)) {
    $$5 = 1;
    return ($$5|0);
   }
   $40 = $33;
   $41 = $36;
   HEAP32[$0>>2] = $40;
   HEAP32[$17>>2] = $41;
   $$5 = 1;
   return ($$5|0);
  }
  if ($29) {
   HEAP32[$0>>2] = $31;
   HEAP32[$18>>2] = $32;
   $$5 = 1;
   return ($$5|0);
  }
  HEAP32[$0>>2] = $30;
  HEAP32[$17>>2] = $32;
  $42 = HEAP32[$18>>2]|0;
  $43 = ((($42)) + 28|0);
  $44 = +HEAPF32[$43>>2];
  $45 = $44 < $24;
  if (!($45)) {
   $$5 = 1;
   return ($$5|0);
  }
  $46 = $42;
  HEAP32[$17>>2] = $46;
  HEAP32[$18>>2] = $32;
  $$5 = 1;
  return ($$5|0);
  break;
 }
 case 4:  {
  $47 = ((($0)) + 4|0);
  $48 = ((($0)) + 8|0);
  $49 = ((($1)) + -4|0);
  $50 = HEAP32[$47>>2]|0;
  $51 = ((($50)) + 28|0);
  $52 = +HEAPF32[$51>>2];
  $53 = HEAP32[$0>>2]|0;
  $54 = ((($53)) + 28|0);
  $55 = +HEAPF32[$54>>2];
  $56 = $52 < $55;
  $57 = HEAP32[$48>>2]|0;
  $58 = ((($57)) + 28|0);
  $59 = +HEAPF32[$58>>2];
  $60 = $59 < $52;
  $61 = $50;
  $62 = $57;
  $63 = $53;
  do {
   if ($56) {
    if ($60) {
     HEAP32[$0>>2] = $62;
     HEAP32[$48>>2] = $63;
     $70 = $53;$74 = $63;
     break;
    }
    HEAP32[$0>>2] = $61;
    HEAP32[$47>>2] = $63;
    $65 = $59 < $55;
    if ($65) {
     HEAP32[$47>>2] = $62;
     HEAP32[$48>>2] = $63;
     $70 = $53;$74 = $63;
    } else {
     $70 = $57;$74 = $62;
    }
   } else {
    if ($60) {
     HEAP32[$47>>2] = $62;
     HEAP32[$48>>2] = $61;
     $64 = $59 < $55;
     if ($64) {
      HEAP32[$0>>2] = $62;
      HEAP32[$47>>2] = $63;
      $70 = $50;$74 = $61;
     } else {
      $70 = $50;$74 = $61;
     }
    } else {
     $70 = $57;$74 = $62;
    }
   }
  } while(0);
  $66 = HEAP32[$49>>2]|0;
  $67 = ((($66)) + 28|0);
  $68 = +HEAPF32[$67>>2];
  $69 = ((($70)) + 28|0);
  $71 = +HEAPF32[$69>>2];
  $72 = $68 < $71;
  if (!($72)) {
   $$5 = 1;
   return ($$5|0);
  }
  $73 = $66;
  HEAP32[$48>>2] = $73;
  HEAP32[$49>>2] = $74;
  $75 = HEAP32[$48>>2]|0;
  $76 = ((($75)) + 28|0);
  $77 = +HEAPF32[$76>>2];
  $78 = HEAP32[$47>>2]|0;
  $79 = ((($78)) + 28|0);
  $80 = +HEAPF32[$79>>2];
  $81 = $77 < $80;
  if (!($81)) {
   $$5 = 1;
   return ($$5|0);
  }
  $82 = $75;
  $83 = $78;
  HEAP32[$47>>2] = $82;
  HEAP32[$48>>2] = $83;
  $84 = HEAP32[$0>>2]|0;
  $85 = ((($84)) + 28|0);
  $86 = +HEAPF32[$85>>2];
  $87 = $77 < $86;
  if (!($87)) {
   $$5 = 1;
   return ($$5|0);
  }
  $88 = $84;
  HEAP32[$0>>2] = $82;
  HEAP32[$47>>2] = $88;
  $$5 = 1;
  return ($$5|0);
  break;
 }
 case 5:  {
  $89 = ((($0)) + 4|0);
  $90 = ((($0)) + 8|0);
  $91 = ((($0)) + 12|0);
  $92 = ((($1)) + -4|0);
  (__ZNSt3__27__sort5IRN7osgUtil20LessDepthSortFunctorEPN3osg7ref_ptrINS1_10RenderLeafEEEEEjT0_S9_S9_S9_S9_T_($0,$89,$90,$91,$92,$2)|0);
  $$5 = 1;
  return ($$5|0);
  break;
 }
 case 1: case 0:  {
  $$5 = 1;
  return ($$5|0);
  break;
 }
 default: {
  $93 = ((($0)) + 8|0);
  $94 = ((($0)) + 4|0);
  $95 = HEAP32[$94>>2]|0;
  $96 = ((($95)) + 28|0);
  $97 = +HEAPF32[$96>>2];
  $98 = HEAP32[$0>>2]|0;
  $99 = ((($98)) + 28|0);
  $100 = +HEAPF32[$99>>2];
  $101 = $97 < $100;
  $102 = HEAP32[$93>>2]|0;
  $103 = ((($102)) + 28|0);
  $104 = +HEAPF32[$103>>2];
  $105 = $104 < $97;
  $106 = $95;
  $107 = $102;
  $108 = $98;
  do {
   if ($101) {
    if ($105) {
     HEAP32[$0>>2] = $107;
     HEAP32[$93>>2] = $108;
     $$pre105108 = $98;
     break;
    }
    HEAP32[$0>>2] = $106;
    HEAP32[$94>>2] = $108;
    $110 = $104 < $100;
    if ($110) {
     HEAP32[$94>>2] = $107;
     HEAP32[$93>>2] = $108;
     $$pre105108 = $98;
    } else {
     $$pre105108 = $102;
    }
   } else {
    if ($105) {
     HEAP32[$94>>2] = $107;
     HEAP32[$93>>2] = $106;
     $109 = $104 < $100;
     if ($109) {
      HEAP32[$0>>2] = $107;
      HEAP32[$94>>2] = $108;
      $$pre105108 = $95;
     } else {
      $$pre105108 = $95;
     }
    } else {
     $$pre105108 = $102;
    }
   }
  } while(0);
  $111 = ((($0)) + 12|0);
  $112 = ($111|0)==($1|0);
  L13: do {
   if ($112) {
    $$170 = 1;$$3 = 0;
   } else {
    $$07195 = $111;$$07494 = 0;$$07693 = $93;$$pre105107 = $$pre105108;
    L14: while(1) {
     $113 = HEAP32[$$07195>>2]|0;
     $114 = ((($113)) + 28|0);
     $115 = +HEAPF32[$114>>2];
     $116 = ((($$pre105107)) + 28|0);
     $117 = +HEAPF32[$116>>2];
     $118 = $115 < $117;
     if ($118) {
      $119 = ($113|0)==(0|0);
      if ($119) {
       $$068 = $$07693;$$177 = $$07195;$124 = $$pre105107;
      } else {
       $120 = ((($113)) + 8|0);
       $121 = HEAP32[$120>>2]|0;HEAP32[$120>>2] = (($121+1)|0);
       $$pre105$pre = HEAP32[$$07693>>2]|0;
       $$068 = $$07693;$$177 = $$07195;$124 = $$pre105$pre;
      }
      while(1) {
       $122 = HEAP32[$$177>>2]|0;
       $123 = ($122|0)==($124|0);
       if (!($123)) {
        HEAP32[$$177>>2] = $124;
        $125 = ($124|0)==(0|0);
        if (!($125)) {
         $126 = ((($124)) + 8|0);
         $127 = HEAP32[$126>>2]|0;HEAP32[$126>>2] = (($127+1)|0);
        }
        $128 = ($122|0)==(0|0);
        if (!($128)) {
         $129 = ((($122)) + 8|0);
         $130 = HEAP32[$129>>2]|0;HEAP32[$129>>2] = (($130-1)|0);
         $131 = ($130|0)==(1);
         if ($131) {
          __THREW__ = 0;
          invoke_viii(3262,($122|0),1,1);
          $132 = __THREW__; __THREW__ = 0;
          $133 = $132&1;
          if ($133) {
           break L14;
          }
         }
        }
       }
       $134 = ($$068|0)==($0|0);
       if ($134) {
        break;
       }
       $135 = ((($$068)) + -4|0);
       $136 = +HEAPF32[$114>>2];
       $137 = HEAP32[$135>>2]|0;
       $138 = ((($137)) + 28|0);
       $139 = +HEAPF32[$138>>2];
       $140 = $136 < $139;
       if ($140) {
        $$177$phi = $$068;$$068 = $135;$124 = $137;$$177 = $$177$phi;
       } else {
        break;
       }
      }
      $141 = HEAP32[$$068>>2]|0;
      $142 = ($141|0)==($113|0);
      if (!($142)) {
       HEAP32[$$068>>2] = $113;
       if (!($119)) {
        $143 = ((($113)) + 8|0);
        $144 = HEAP32[$143>>2]|0;HEAP32[$143>>2] = (($144+1)|0);
       }
       $145 = ($141|0)==(0|0);
       if (!($145)) {
        $146 = ((($141)) + 8|0);
        $147 = HEAP32[$146>>2]|0;HEAP32[$146>>2] = (($147-1)|0);
        $148 = ($147|0)==(1);
        if ($148) {
         __THREW__ = 0;
         invoke_viii(3262,($141|0),1,1);
         $149 = __THREW__; __THREW__ = 0;
         $150 = $149&1;
         if ($150) {
          break;
         }
        }
       }
      }
      $151 = (($$07494) + 1)|0;
      $152 = ($151|0)==(8);
      $153 = ((($$07195)) + 4|0);
      $154 = ($153|0)==($1|0);
      if (!($119)) {
       $155 = ((($113)) + 8|0);
       $156 = HEAP32[$155>>2]|0;HEAP32[$155>>2] = (($156-1)|0);
       $157 = ($156|0)==(1);
       if ($157) {
        __ZNK3osg10Referenced24signalObserversAndDeleteEbb($113,1,1);
       }
      }
      if ($152) {
       $$170 = 0;$$3 = $154;
       break L13;
      } else {
       $$175 = $151;
      }
     } else {
      $$175 = $$07494;
     }
     $165 = ((($$07195)) + 4|0);
     $166 = ($165|0)==($1|0);
     if ($166) {
      $$170 = 1;$$3 = 0;
      break L13;
     }
     $$pre = HEAP32[$$07195>>2]|0;
     $$07693$phi = $$07195;$$07195 = $165;$$07494 = $$175;$$pre105107 = $$pre;$$07693 = $$07693$phi;
    }
    $158 = ___cxa_find_matching_catch_2()|0;
    $159 = tempRet0;
    if ($119) {
     ___resumeException($158|0);
     // unreachable;
    }
    $160 = ((($113)) + 8|0);
    $161 = HEAP32[$160>>2]|0;HEAP32[$160>>2] = (($161-1)|0);
    $162 = ($161|0)==(1);
    if (!($162)) {
     ___resumeException($158|0);
     // unreachable;
    }
    __THREW__ = 0;
    invoke_viii(3262,($113|0),1,1);
    $163 = __THREW__; __THREW__ = 0;
    $164 = $163&1;
    if ($164) {
     $167 = ___cxa_find_matching_catch_3(0|0)|0;
     $168 = tempRet0;
     ___clang_call_terminate($167);
     // unreachable;
    } else {
     ___resumeException($158|0);
     // unreachable;
    }
   }
  } while(0);
  $$$3 = $$170 | $$3;
  $$5 = $$$3;
  return ($$5|0);
 }
 }
 return (0)|0;
}
function __ZNSt3__27__sort5IR32StateGraphFrontToBackSortFunctorPPN7osgUtil10StateGraphEEEjT0_S7_S7_S7_S7_T_($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$0 = 0, $$0$i = 0, $$026$i$i = 0, $$pre$i = 0, $10 = 0, $100 = 0.0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $11 = 0.0, $12 = 0, $13 = 0, $14 = 0, $15 = 0.0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0.0, $24 = 0, $25 = 0.0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0.0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0.0, $38 = 0, $39 = 0, $40 = 0.0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0.0, $49 = 0, $50 = 0.0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0.0, $59 = 0, $6 = 0;
 var $60 = 0.0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0.0, $69 = 0, $7 = 0, $70 = 0.0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0.0;
 var $79 = 0, $8 = 0, $80 = 0.0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0.0, $89 = 0, $9 = 0.0, $90 = 0.0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0.0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $6 = HEAP32[$1>>2]|0;
 $7 = HEAP32[$0>>2]|0;
 $8 = ((($6)) + 52|0);
 $9 = +HEAPF32[$8>>2];
 $10 = ((($7)) + 52|0);
 $11 = +HEAPF32[$10>>2];
 $12 = $9 < $11;
 $13 = HEAP32[$2>>2]|0;
 $14 = ((($13)) + 52|0);
 $15 = +HEAPF32[$14>>2];
 $16 = $15 < $9;
 $17 = $6;
 $18 = $13;
 $19 = $7;
 do {
  if ($12) {
   if ($16) {
    HEAP32[$0>>2] = $18;
    HEAP32[$2>>2] = $19;
    $$026$i$i = 1;$39 = $7;$43 = $19;
    break;
   }
   HEAP32[$0>>2] = $17;
   HEAP32[$1>>2] = $19;
   $30 = HEAP32[$2>>2]|0;
   $31 = ((($30)) + 52|0);
   $32 = +HEAPF32[$31>>2];
   $33 = $32 < $11;
   $34 = $30;
   if ($33) {
    HEAP32[$1>>2] = $34;
    HEAP32[$2>>2] = $19;
    $$026$i$i = 2;$39 = $7;$43 = $19;
   } else {
    $$026$i$i = 1;$39 = $30;$43 = $34;
   }
  } else {
   if ($16) {
    HEAP32[$1>>2] = $18;
    HEAP32[$2>>2] = $17;
    $20 = HEAP32[$1>>2]|0;
    $21 = HEAP32[$0>>2]|0;
    $22 = ((($20)) + 52|0);
    $23 = +HEAPF32[$22>>2];
    $24 = ((($21)) + 52|0);
    $25 = +HEAPF32[$24>>2];
    $26 = $23 < $25;
    if ($26) {
     $27 = $20;
     $28 = $21;
     HEAP32[$0>>2] = $27;
     HEAP32[$1>>2] = $28;
     $$pre$i = HEAP32[$2>>2]|0;
     $29 = $$pre$i;
     $$026$i$i = 2;$39 = $$pre$i;$43 = $29;
    } else {
     $$026$i$i = 1;$39 = $6;$43 = $17;
    }
   } else {
    $$026$i$i = 0;$39 = $13;$43 = $18;
   }
  }
 } while(0);
 $35 = HEAP32[$3>>2]|0;
 $36 = ((($35)) + 52|0);
 $37 = +HEAPF32[$36>>2];
 $38 = ((($39)) + 52|0);
 $40 = +HEAPF32[$38>>2];
 $41 = $37 < $40;
 if ($41) {
  $42 = $35;
  HEAP32[$2>>2] = $42;
  HEAP32[$3>>2] = $43;
  $44 = (($$026$i$i) + 1)|0;
  $45 = HEAP32[$2>>2]|0;
  $46 = HEAP32[$1>>2]|0;
  $47 = ((($45)) + 52|0);
  $48 = +HEAPF32[$47>>2];
  $49 = ((($46)) + 52|0);
  $50 = +HEAPF32[$49>>2];
  $51 = $48 < $50;
  if ($51) {
   $52 = $45;
   $53 = $46;
   HEAP32[$1>>2] = $52;
   HEAP32[$2>>2] = $53;
   $54 = (($$026$i$i) + 2)|0;
   $55 = HEAP32[$1>>2]|0;
   $56 = HEAP32[$0>>2]|0;
   $57 = ((($55)) + 52|0);
   $58 = +HEAPF32[$57>>2];
   $59 = ((($56)) + 52|0);
   $60 = +HEAPF32[$59>>2];
   $61 = $58 < $60;
   if ($61) {
    $62 = (($$026$i$i) + 3)|0;
    $63 = $56;
    $64 = $55;
    HEAP32[$0>>2] = $64;
    HEAP32[$1>>2] = $63;
    $$0$i = $62;
   } else {
    $$0$i = $54;
   }
  } else {
   $$0$i = $44;
  }
 } else {
  $$0$i = $$026$i$i;
 }
 $65 = HEAP32[$4>>2]|0;
 $66 = HEAP32[$3>>2]|0;
 $67 = ((($65)) + 52|0);
 $68 = +HEAPF32[$67>>2];
 $69 = ((($66)) + 52|0);
 $70 = +HEAPF32[$69>>2];
 $71 = $68 < $70;
 if (!($71)) {
  $$0 = $$0$i;
  return ($$0|0);
 }
 $72 = $65;
 $73 = $66;
 HEAP32[$3>>2] = $72;
 HEAP32[$4>>2] = $73;
 $74 = (($$0$i) + 1)|0;
 $75 = HEAP32[$3>>2]|0;
 $76 = HEAP32[$2>>2]|0;
 $77 = ((($75)) + 52|0);
 $78 = +HEAPF32[$77>>2];
 $79 = ((($76)) + 52|0);
 $80 = +HEAPF32[$79>>2];
 $81 = $78 < $80;
 if (!($81)) {
  $$0 = $74;
  return ($$0|0);
 }
 $82 = $75;
 $83 = $76;
 HEAP32[$2>>2] = $82;
 HEAP32[$3>>2] = $83;
 $84 = (($$0$i) + 2)|0;
 $85 = HEAP32[$2>>2]|0;
 $86 = HEAP32[$1>>2]|0;
 $87 = ((($85)) + 52|0);
 $88 = +HEAPF32[$87>>2];
 $89 = ((($86)) + 52|0);
 $90 = +HEAPF32[$89>>2];
 $91 = $88 < $90;
 if (!($91)) {
  $$0 = $84;
  return ($$0|0);
 }
 $92 = $85;
 $93 = $86;
 HEAP32[$1>>2] = $92;
 HEAP32[$2>>2] = $93;
 $94 = (($$0$i) + 3)|0;
 $95 = HEAP32[$1>>2]|0;
 $96 = HEAP32[$0>>2]|0;
 $97 = ((($95)) + 52|0);
 $98 = +HEAPF32[$97>>2];
 $99 = ((($96)) + 52|0);
 $100 = +HEAPF32[$99>>2];
 $101 = $98 < $100;
 if (!($101)) {
  $$0 = $94;
  return ($$0|0);
 }
 $102 = $95;
 $103 = $96;
 $104 = (($$0$i) + 4)|0;
 HEAP32[$0>>2] = $102;
 HEAP32[$1>>2] = $103;
 $$0 = $104;
 return ($$0|0);
}
function __ZNSt3__227__insertion_sort_incompleteIR32StateGraphFrontToBackSortFunctorPPN7osgUtil10StateGraphEEEbT0_S7_T_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$$3 = 0, $$0 = 0, $$06277 = 0, $$06476 = 0, $$06974 = 0, $$06974$phi = 0, $$1 = 0, $$165 = 0, $$170 = 0, $$170$phi = 0, $$3 = 0, $$5 = 0, $$pre = 0, $10 = 0, $100 = 0.0, $101 = 0, $102 = 0, $103 = 0, $104 = 0.0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0.0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0.0, $116 = 0, $117 = 0, $118 = 0.0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0.0, $127 = 0, $128 = 0, $129 = 0, $13 = 0.0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0;
 var $22 = 0.0, $23 = 0, $24 = 0.0, $25 = 0, $26 = 0, $27 = 0, $28 = 0.0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0.0, $37 = 0, $38 = 0.0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0.0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0.0, $54 = 0, $55 = 0.0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0.0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0.0, $69 = 0, $7 = 0, $70 = 0, $71 = 0.0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0.0, $79 = 0, $8 = 0, $80 = 0.0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0.0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0.0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = $1;
 $4 = $0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 switch ($6|0) {
 case 2:  {
  $7 = ((($1)) + -4|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = HEAP32[$0>>2]|0;
  $10 = ((($8)) + 52|0);
  $11 = +HEAPF32[$10>>2];
  $12 = ((($9)) + 52|0);
  $13 = +HEAPF32[$12>>2];
  $14 = $11 < $13;
  if (!($14)) {
   $$5 = 1;
   return ($$5|0);
  }
  $15 = $8;
  $16 = $9;
  HEAP32[$0>>2] = $15;
  HEAP32[$7>>2] = $16;
  $$5 = 1;
  return ($$5|0);
  break;
 }
 case 3:  {
  $17 = ((($0)) + 4|0);
  $18 = ((($1)) + -4|0);
  $19 = HEAP32[$17>>2]|0;
  $20 = HEAP32[$0>>2]|0;
  $21 = ((($19)) + 52|0);
  $22 = +HEAPF32[$21>>2];
  $23 = ((($20)) + 52|0);
  $24 = +HEAPF32[$23>>2];
  $25 = $22 < $24;
  $26 = HEAP32[$18>>2]|0;
  $27 = ((($26)) + 52|0);
  $28 = +HEAPF32[$27>>2];
  $29 = $28 < $22;
  $30 = $19;
  $31 = $26;
  $32 = $20;
  if (!($25)) {
   if (!($29)) {
    $$5 = 1;
    return ($$5|0);
   }
   HEAP32[$17>>2] = $31;
   HEAP32[$18>>2] = $30;
   $33 = HEAP32[$17>>2]|0;
   $34 = HEAP32[$0>>2]|0;
   $35 = ((($33)) + 52|0);
   $36 = +HEAPF32[$35>>2];
   $37 = ((($34)) + 52|0);
   $38 = +HEAPF32[$37>>2];
   $39 = $36 < $38;
   if (!($39)) {
    $$5 = 1;
    return ($$5|0);
   }
   $40 = $33;
   $41 = $34;
   HEAP32[$0>>2] = $40;
   HEAP32[$17>>2] = $41;
   $$5 = 1;
   return ($$5|0);
  }
  if ($29) {
   HEAP32[$0>>2] = $31;
   HEAP32[$18>>2] = $32;
   $$5 = 1;
   return ($$5|0);
  }
  HEAP32[$0>>2] = $30;
  HEAP32[$17>>2] = $32;
  $42 = HEAP32[$18>>2]|0;
  $43 = ((($42)) + 52|0);
  $44 = +HEAPF32[$43>>2];
  $45 = $44 < $24;
  if (!($45)) {
   $$5 = 1;
   return ($$5|0);
  }
  $46 = $42;
  HEAP32[$17>>2] = $46;
  HEAP32[$18>>2] = $32;
  $$5 = 1;
  return ($$5|0);
  break;
 }
 case 4:  {
  $47 = ((($0)) + 4|0);
  $48 = ((($0)) + 8|0);
  $49 = ((($1)) + -4|0);
  $50 = HEAP32[$47>>2]|0;
  $51 = HEAP32[$0>>2]|0;
  $52 = ((($50)) + 52|0);
  $53 = +HEAPF32[$52>>2];
  $54 = ((($51)) + 52|0);
  $55 = +HEAPF32[$54>>2];
  $56 = $53 < $55;
  $57 = HEAP32[$48>>2]|0;
  $58 = ((($57)) + 52|0);
  $59 = +HEAPF32[$58>>2];
  $60 = $59 < $53;
  $61 = $50;
  $62 = $57;
  $63 = $51;
  do {
   if ($56) {
    if ($60) {
     HEAP32[$0>>2] = $62;
     HEAP32[$48>>2] = $63;
     $70 = $51;$74 = $63;
     break;
    }
    HEAP32[$0>>2] = $61;
    HEAP32[$47>>2] = $63;
    $65 = $59 < $55;
    if ($65) {
     HEAP32[$47>>2] = $62;
     HEAP32[$48>>2] = $63;
     $70 = $51;$74 = $63;
    } else {
     $70 = $57;$74 = $62;
    }
   } else {
    if ($60) {
     HEAP32[$47>>2] = $62;
     HEAP32[$48>>2] = $61;
     $64 = $59 < $55;
     if ($64) {
      HEAP32[$0>>2] = $62;
      HEAP32[$47>>2] = $63;
      $70 = $50;$74 = $61;
     } else {
      $70 = $50;$74 = $61;
     }
    } else {
     $70 = $57;$74 = $62;
    }
   }
  } while(0);
  $66 = HEAP32[$49>>2]|0;
  $67 = ((($66)) + 52|0);
  $68 = +HEAPF32[$67>>2];
  $69 = ((($70)) + 52|0);
  $71 = +HEAPF32[$69>>2];
  $72 = $68 < $71;
  if (!($72)) {
   $$5 = 1;
   return ($$5|0);
  }
  $73 = $66;
  HEAP32[$48>>2] = $73;
  HEAP32[$49>>2] = $74;
  $75 = HEAP32[$48>>2]|0;
  $76 = HEAP32[$47>>2]|0;
  $77 = ((($75)) + 52|0);
  $78 = +HEAPF32[$77>>2];
  $79 = ((($76)) + 52|0);
  $80 = +HEAPF32[$79>>2];
  $81 = $78 < $80;
  if (!($81)) {
   $$5 = 1;
   return ($$5|0);
  }
  $82 = $75;
  $83 = $76;
  HEAP32[$47>>2] = $82;
  HEAP32[$48>>2] = $83;
  $84 = HEAP32[$0>>2]|0;
  $85 = ((($84)) + 52|0);
  $86 = +HEAPF32[$85>>2];
  $87 = $78 < $86;
  if (!($87)) {
   $$5 = 1;
   return ($$5|0);
  }
  $88 = $84;
  HEAP32[$0>>2] = $82;
  HEAP32[$47>>2] = $88;
  $$5 = 1;
  return ($$5|0);
  break;
 }
 case 5:  {
  $89 = ((($0)) + 4|0);
  $90 = ((($0)) + 8|0);
  $91 = ((($0)) + 12|0);
  $92 = ((($1)) + -4|0);
  (__ZNSt3__27__sort5IR32StateGraphFrontToBackSortFunctorPPN7osgUtil10StateGraphEEEjT0_S7_S7_S7_S7_T_($0,$89,$90,$91,$92,$2)|0);
  $$5 = 1;
  return ($$5|0);
  break;
 }
 case 1: case 0:  {
  $$5 = 1;
  return ($$5|0);
  break;
 }
 default: {
  $93 = ((($0)) + 8|0);
  $94 = ((($0)) + 4|0);
  $95 = HEAP32[$94>>2]|0;
  $96 = HEAP32[$0>>2]|0;
  $97 = ((($95)) + 52|0);
  $98 = +HEAPF32[$97>>2];
  $99 = ((($96)) + 52|0);
  $100 = +HEAPF32[$99>>2];
  $101 = $98 < $100;
  $102 = HEAP32[$93>>2]|0;
  $103 = ((($102)) + 52|0);
  $104 = +HEAPF32[$103>>2];
  $105 = $104 < $98;
  $106 = $95;
  $107 = $102;
  $108 = $96;
  do {
   if ($101) {
    if ($105) {
     HEAP32[$0>>2] = $107;
     HEAP32[$93>>2] = $108;
     $134 = $96;
     break;
    }
    HEAP32[$0>>2] = $106;
    HEAP32[$94>>2] = $108;
    $110 = $104 < $100;
    if ($110) {
     HEAP32[$94>>2] = $107;
     HEAP32[$93>>2] = $108;
     $134 = $96;
    } else {
     $134 = $102;
    }
   } else {
    if ($105) {
     HEAP32[$94>>2] = $107;
     HEAP32[$93>>2] = $106;
     $109 = $104 < $100;
     if ($109) {
      HEAP32[$0>>2] = $107;
      HEAP32[$94>>2] = $108;
      $134 = $95;
     } else {
      $134 = $95;
     }
    } else {
     $134 = $102;
    }
   }
  } while(0);
  $111 = ((($0)) + 12|0);
  $112 = ($111|0)==($1|0);
  L13: do {
   if ($112) {
    $$1 = 1;$$3 = 0;
   } else {
    $$06277 = $111;$$06476 = 0;$$06974 = $93;$117 = $134;
    while(1) {
     $113 = HEAP32[$$06277>>2]|0;
     $114 = ((($113)) + 52|0);
     $115 = +HEAPF32[$114>>2];
     $116 = ((($117)) + 52|0);
     $118 = +HEAPF32[$116>>2];
     $119 = $115 < $118;
     $120 = $113;
     if ($119) {
      $$0 = $$06974;$$170 = $$06277;
      while(1) {
       $121 = HEAP32[$$0>>2]|0;
       HEAP32[$$170>>2] = $121;
       $122 = ($$0|0)==($0|0);
       if ($122) {
        break;
       }
       $123 = ((($$0)) + -4|0);
       $124 = HEAP32[$123>>2]|0;
       $125 = ((($124)) + 52|0);
       $126 = +HEAPF32[$125>>2];
       $127 = $115 < $126;
       if ($127) {
        $$170$phi = $$0;$$0 = $123;$$170 = $$170$phi;
       } else {
        break;
       }
      }
      HEAP32[$$0>>2] = $120;
      $128 = (($$06476) + 1)|0;
      $129 = ($128|0)==(8);
      $130 = ((($$06277)) + 4|0);
      $131 = ($130|0)==($1|0);
      if ($129) {
       $$1 = 0;$$3 = $131;
       break L13;
      } else {
       $$165 = $128;
      }
     } else {
      $$165 = $$06476;
     }
     $132 = ((($$06277)) + 4|0);
     $133 = ($132|0)==($1|0);
     if ($133) {
      $$1 = 1;$$3 = 0;
      break L13;
     }
     $$pre = HEAP32[$$06277>>2]|0;
     $$06974$phi = $$06277;$$06277 = $132;$$06476 = $$165;$117 = $$pre;$$06974 = $$06974$phi;
    }
   }
  } while(0);
  $$$3 = $$3 | $$1;
  $$5 = $$$3;
  return ($$5|0);
 }
 }
 return (0)|0;
}
function __ZNSt3__26__treeINS_12__value_typeIiN3osg7ref_ptrIN7osgUtil9RenderBinEEEEENS_19__map_value_compareIiS7_NS_4lessIiEELb1EEENS_9allocatorIS7_EEE7destroyEPNS_11__tree_nodeIS7_PvEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 }
 $3 = HEAP32[$1>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIiN3osg7ref_ptrIN7osgUtil9RenderBinEEEEENS_19__map_value_compareIiS7_NS_4lessIiEELb1EEENS_9allocatorIS7_EEE7destroyEPNS_11__tree_nodeIS7_PvEE($0,$3);
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIiN3osg7ref_ptrIN7osgUtil9RenderBinEEEEENS_19__map_value_compareIiS7_NS_4lessIiEELb1EEENS_9allocatorIS7_EEE7destroyEPNS_11__tree_nodeIS7_PvEE($0,$5);
 $6 = ((($1)) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = ((($7)) + 8|0);
  $10 = HEAP32[$9>>2]|0;HEAP32[$9>>2] = (($10-1)|0);
  $11 = ($10|0)==(1);
  if ($11) {
   __THREW__ = 0;
   invoke_viii(3262,($7|0),1,1);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if ($13) {
    $14 = ___cxa_find_matching_catch_2()|0;
    $15 = tempRet0;
    ___cxa_call_unexpected(($14|0));
    // unreachable;
   }
  }
 }
 __ZdlPv($1);
 return;
}
function __ZN7osgUtil9RenderBinC2ERKS0_RKN3osg6CopyOpE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i$i = 0, $$3 = 0, $$318 = 0, $$4 = 0, $$419 = 0, $$byval_copy = 0, $$pre$i$i$i$i$i$i = 0, $$sroa$07$0$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $scevgep$i$i$i21 = 0, $scevgep5$i$i$i22 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy = sp + 12|0;
 $3 = sp + 8|0;
 $4 = sp + 4|0;
 $5 = sp;
 __ZN3osg6ObjectC2ERKS0_RKNS_6CopyOpE($0,$1,$2);
 HEAP32[$0>>2] = (53976);
 $6 = ((($0)) + 32|0);
 $7 = ((($1)) + 32|0);
 $8 = HEAP32[$7>>2]|0;
 HEAP32[$6>>2] = $8;
 $9 = ((($0)) + 36|0);
 $10 = ((($1)) + 36|0);
 $11 = HEAP32[$10>>2]|0;
 HEAP32[$9>>2] = $11;
 $12 = ((($0)) + 40|0);
 $13 = ((($1)) + 40|0);
 $14 = HEAP32[$13>>2]|0;
 HEAP32[$12>>2] = $14;
 $15 = ((($0)) + 44|0);
 $16 = ((($0)) + 48|0);
 HEAP32[$16>>2] = 0;
 $17 = ((($0)) + 52|0);
 HEAP32[$17>>2] = 0;
 $18 = ((($0)) + 48|0);
 HEAP32[$15>>2] = $18;
 $19 = ((($1)) + 44|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ((($1)) + 48|0);
 $22 = ($20|0)==($21|0);
 L1: do {
  if ($22) {
   label = 17;
  } else {
   $23 = $18;
   $$sroa$07$0$i = $20;
   while(1) {
    $24 = ((($$sroa$07$0$i)) + 16|0);
    HEAP32[$5>>2] = $23;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy>>2]=HEAP32[$5>>2]|0;
    $25 = (invoke_iiiiii(3660,($15|0),($$byval_copy|0),($3|0),($4|0),($24|0))|0);
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if ($27) {
     break;
    }
    $28 = HEAP32[$25>>2]|0;
    $29 = ($28|0)==(0|0);
    if ($29) {
     __THREW__ = 0;
     $30 = (invoke_ii(3276,24)|0);
     $31 = __THREW__; __THREW__ = 0;
     $32 = $31&1;
     if ($32) {
      break;
     }
     $33 = ((($30)) + 16|0);
     $34 = HEAP32[$24>>2]|0;
     HEAP32[$33>>2] = $34;
     $35 = ((($30)) + 20|0);
     $36 = ((($$sroa$07$0$i)) + 20|0);
     $37 = HEAP32[$36>>2]|0;
     HEAP32[$35>>2] = $37;
     $38 = ($37|0)==(0|0);
     if (!($38)) {
      $39 = ((($37)) + 8|0);
      $40 = HEAP32[$39>>2]|0;HEAP32[$39>>2] = (($40+1)|0);
     }
     $41 = HEAP32[$3>>2]|0;
     HEAP32[$30>>2] = 0;
     $42 = ((($30)) + 4|0);
     HEAP32[$42>>2] = 0;
     $43 = ((($30)) + 8|0);
     HEAP32[$43>>2] = $41;
     HEAP32[$25>>2] = $30;
     $44 = HEAP32[$15>>2]|0;
     $45 = HEAP32[$44>>2]|0;
     $46 = ($45|0)==(0|0);
     if ($46) {
      $49 = $30;
     } else {
      $47 = $45;
      HEAP32[$15>>2] = $47;
      $$pre$i$i$i$i$i$i = HEAP32[$25>>2]|0;
      $49 = $$pre$i$i$i$i$i$i;
     }
     $48 = HEAP32[$16>>2]|0;
     __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($48,$49);
     $50 = HEAP32[$17>>2]|0;
     $51 = (($50) + 1)|0;
     HEAP32[$17>>2] = $51;
    }
    $52 = ((($$sroa$07$0$i)) + 4|0);
    $53 = HEAP32[$52>>2]|0;
    $54 = ($53|0)==(0|0);
    if ($54) {
     $55 = ((($$sroa$07$0$i)) + 8|0);
     $56 = HEAP32[$55>>2]|0;
     $57 = HEAP32[$56>>2]|0;
     $58 = ($57|0)==($$sroa$07$0$i|0);
     if ($58) {
      $$0$i$i$i$i$i = $56;
     } else {
      $62 = $55;
      while(1) {
       $61 = HEAP32[$62>>2]|0;
       $63 = ((($61)) + 8|0);
       $64 = HEAP32[$63>>2]|0;
       $65 = HEAP32[$64>>2]|0;
       $66 = ($65|0)==($61|0);
       if ($66) {
        $$0$i$i$i$i$i = $64;
        break;
       } else {
        $62 = $63;
       }
      }
     }
    } else {
     $$0$i$i$i$i$i$i = $53;
     while(1) {
      $59 = HEAP32[$$0$i$i$i$i$i$i>>2]|0;
      $60 = ($59|0)==(0|0);
      if ($60) {
       break;
      } else {
       $$0$i$i$i$i$i$i = $59;
      }
     }
     $$0$i$i$i$i$i = $$0$i$i$i$i$i$i;
    }
    $67 = ($$0$i$i$i$i$i|0)==($21|0);
    if ($67) {
     label = 17;
     break L1;
    } else {
     $$sroa$07$0$i = $$0$i$i$i$i$i;
    }
   }
   $100 = ___cxa_find_matching_catch_2()|0;
   $101 = tempRet0;
   $102 = HEAP32[$18>>2]|0;
   __ZNSt3__26__treeINS_12__value_typeIiN3osg7ref_ptrIN7osgUtil9RenderBinEEEEENS_19__map_value_compareIiS7_NS_4lessIiEELb1EEENS_9allocatorIS7_EEE7destroyEPNS_11__tree_nodeIS7_PvEE($15,$102);
   $$4 = $101;$$419 = $100;
  }
 } while(0);
 if ((label|0) == 17) {
  $68 = ((($0)) + 56|0);
  $69 = ((($1)) + 56|0);
  __THREW__ = 0;
  invoke_vii(3661,($68|0),($69|0));
  $70 = __THREW__; __THREW__ = 0;
  $71 = $70&1;
  do {
   if ($71) {
    $103 = ___cxa_find_matching_catch_2()|0;
    $104 = tempRet0;
    $$3 = $104;$$318 = $103;
   } else {
    $72 = ((($0)) + 68|0);
    $73 = ((($1)) + 68|0);
    __THREW__ = 0;
    invoke_vii(3662,($72|0),($73|0));
    $74 = __THREW__; __THREW__ = 0;
    $75 = $74&1;
    if ($75) {
     $105 = ___cxa_find_matching_catch_2()|0;
     $106 = tempRet0;
     $107 = HEAP32[$68>>2]|0;
     $108 = ($107|0)==(0|0);
     if ($108) {
      $$3 = $106;$$318 = $105;
      break;
     }
     $109 = ((($0)) + 60|0);
     $110 = HEAP32[$109>>2]|0;
     $111 = ($110|0)==($107|0);
     if (!($111)) {
      $scevgep$i$i$i21 = ((($110)) + -4|0);
      $112 = $scevgep$i$i$i21;
      $113 = $107;
      $114 = (($112) - ($113))|0;
      $115 = $114 >>> 2;
      $116 = $115 ^ -1;
      $scevgep5$i$i$i22 = (($110) + ($116<<2)|0);
      HEAP32[$109>>2] = $scevgep5$i$i$i22;
     }
     __ZdlPv($107);
     $$3 = $106;$$318 = $105;
     break;
    }
    $76 = ((($0)) + 80|0);
    $77 = ((($1)) + 80|0);
    $78 = HEAP8[$77>>0]|0;
    HEAP8[$76>>0] = $78;
    $79 = ((($0)) + 84|0);
    $80 = ((($1)) + 84|0);
    $81 = HEAP32[$80>>2]|0;
    HEAP32[$79>>2] = $81;
    $82 = ((($0)) + 88|0);
    $83 = ((($1)) + 88|0);
    $84 = HEAP32[$83>>2]|0;
    HEAP32[$82>>2] = $84;
    $85 = ($84|0)==(0|0);
    if (!($85)) {
     $86 = ((($84)) + 8|0);
     $87 = HEAP32[$86>>2]|0;HEAP32[$86>>2] = (($87+1)|0);
    }
    $88 = ((($0)) + 92|0);
    $89 = ((($1)) + 92|0);
    $90 = HEAP32[$89>>2]|0;
    HEAP32[$88>>2] = $90;
    $91 = ($90|0)==(0|0);
    if (!($91)) {
     $92 = ((($90)) + 8|0);
     $93 = HEAP32[$92>>2]|0;HEAP32[$92>>2] = (($93+1)|0);
    }
    $94 = ((($0)) + 96|0);
    $95 = ((($1)) + 96|0);
    $96 = HEAP32[$95>>2]|0;
    HEAP32[$94>>2] = $96;
    $97 = ($96|0)==(0|0);
    if ($97) {
     STACKTOP = sp;return;
    }
    $98 = ((($96)) + 8|0);
    $99 = HEAP32[$98>>2]|0;HEAP32[$98>>2] = (($99+1)|0);
    STACKTOP = sp;return;
   }
  } while(0);
  $117 = HEAP32[$18>>2]|0;
  __ZNSt3__26__treeINS_12__value_typeIiN3osg7ref_ptrIN7osgUtil9RenderBinEEEEENS_19__map_value_compareIiS7_NS_4lessIiEELb1EEENS_9allocatorIS7_EEE7destroyEPNS_11__tree_nodeIS7_PvEE($15,$117);
  $$4 = $$3;$$419 = $$318;
 }
 __THREW__ = 0;
 invoke_vi(388,($0|0));
 $118 = __THREW__; __THREW__ = 0;
 $119 = $118&1;
 if ($119) {
  $120 = ___cxa_find_matching_catch_3(0|0)|0;
  $121 = tempRet0;
  ___clang_call_terminate($120);
  // unreachable;
 } else {
  ___resumeException($$419|0);
  // unreachable;
 }
}
function __ZNSt3__26__treeINS_12__value_typeIiN3osg7ref_ptrIN7osgUtil9RenderBinEEEEENS_19__map_value_compareIiS7_NS_4lessIiEELb1EEENS_9allocatorIS7_EEE12__find_equalIiEERPNS_16__tree_node_baseIPvEENS_21__tree_const_iteratorIS7_PNS_11__tree_nodeIS7_SH_EEiEERPNS_15__tree_end_nodeISJ_EESK_RKT_($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0$i = 0, $$0$i$i = 0, $$0$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i$i = 0, $$0$i26 = 0, $$0$ph$i = 0, $$0$ph$i23 = 0, $$024$i = 0, $$024$i25 = 0, $$08$i$i = 0, $$2 = 0, $$in$i = 0, $$in$i22 = 0, $$pre = 0, $$sroa$043$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = ((($0)) + 4|0);
 $6 = HEAP32[$1>>2]|0;
 $7 = ($6|0)==($5|0);
 $8 = $6;
 if (!($7)) {
  $9 = ((($6)) + 16|0);
  $10 = HEAP32[$4>>2]|0;
  $11 = HEAP32[$9>>2]|0;
  $12 = ($10|0)<($11|0);
  if (!($12)) {
   $43 = ($11|0)<($10|0);
   if (!($43)) {
    HEAP32[$2>>2] = $8;
    HEAP32[$3>>2] = $8;
    $$2 = $3;
    return ($$2|0);
   }
   $44 = ((($6)) + 4|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = ($45|0)==(0|0);
   if ($46) {
    $47 = ((($6)) + 8|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = HEAP32[$48>>2]|0;
    $50 = ($49|0)==($6|0);
    if ($50) {
     $$0$i$i$i$i$i = $48;
    } else {
     $54 = $47;
     while(1) {
      $53 = HEAP32[$54>>2]|0;
      $55 = ((($53)) + 8|0);
      $56 = HEAP32[$55>>2]|0;
      $57 = HEAP32[$56>>2]|0;
      $58 = ($57|0)==($53|0);
      if ($58) {
       $$0$i$i$i$i$i = $56;
       break;
      } else {
       $54 = $55;
      }
     }
    }
   } else {
    $$0$i$i$i$i$i$i = $45;
    while(1) {
     $51 = HEAP32[$$0$i$i$i$i$i$i>>2]|0;
     $52 = ($51|0)==(0|0);
     if ($52) {
      break;
     } else {
      $$0$i$i$i$i$i$i = $51;
     }
    }
    $$0$i$i$i$i$i = $$0$i$i$i$i$i$i;
   }
   $59 = ($$0$i$i$i$i$i|0)==($5|0);
   if (!($59)) {
    $60 = ((($$0$i$i$i$i$i)) + 16|0);
    $61 = HEAP32[$60>>2]|0;
    $62 = ($10|0)<($61|0);
    if (!($62)) {
     $66 = HEAP32[$5>>2]|0;
     $67 = ($66|0)==(0|0);
     if ($67) {
      HEAP32[$2>>2] = $5;
      $$2 = $5;
      return ($$2|0);
     }
     $68 = ((($0)) + 4|0);
     $$0$i = $68;$$024$i = $66;
     while(1) {
      $69 = ((($$024$i)) + 16|0);
      $70 = HEAP32[$69>>2]|0;
      $71 = ($10|0)<($70|0);
      if ($71) {
       $72 = HEAP32[$$024$i>>2]|0;
       $73 = ($72|0)==(0|0);
       if ($73) {
        label = 39;
        break;
       } else {
        $$0$ph$i = $$024$i;$$in$i = $72;
       }
      } else {
       $74 = ($70|0)<($10|0);
       if (!($74)) {
        label = 43;
        break;
       }
       $75 = ((($$024$i)) + 4|0);
       $76 = HEAP32[$75>>2]|0;
       $77 = ($76|0)==(0|0);
       if ($77) {
        label = 42;
        break;
       } else {
        $$0$ph$i = $75;$$in$i = $76;
       }
      }
      $$0$i = $$0$ph$i;$$024$i = $$in$i;
     }
     if ((label|0) == 39) {
      HEAP32[$2>>2] = $$024$i;
      $$2 = $$024$i;
      return ($$2|0);
     }
     else if ((label|0) == 42) {
      HEAP32[$2>>2] = $$024$i;
      $$2 = $75;
      return ($$2|0);
     }
     else if ((label|0) == 43) {
      HEAP32[$2>>2] = $$024$i;
      $$2 = $$0$i;
      return ($$2|0);
     }
    }
   }
   $63 = ((($6)) + 4|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = ($64|0)==(0|0);
   if ($65) {
    HEAP32[$2>>2] = $8;
    $$2 = $44;
    return ($$2|0);
   } else {
    HEAP32[$2>>2] = $$0$i$i$i$i$i;
    $$2 = $$0$i$i$i$i$i;
    return ($$2|0);
   }
  }
 }
 $13 = HEAP32[$0>>2]|0;
 $14 = ($6|0)==($13|0);
 $$pre = HEAP32[$6>>2]|0;
 if ($14) {
  $$sroa$043$0 = $8;
 } else {
  $15 = ($$pre|0)==(0|0);
  if ($15) {
   $$0$i$i = $6;
   while(1) {
    $19 = ((($$0$i$i)) + 8|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = HEAP32[$20>>2]|0;
    $22 = ($21|0)==($$0$i$i|0);
    if ($22) {
     $$0$i$i = $20;
    } else {
     $$08$i$i = $20;
     break;
    }
   }
  } else {
   $$0$i$i$i = $$pre;
   while(1) {
    $16 = ((($$0$i$i$i)) + 4|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = ($17|0)==(0|0);
    if ($18) {
     $$08$i$i = $$0$i$i$i;
     break;
    } else {
     $$0$i$i$i = $17;
    }
   }
  }
  $23 = $$08$i$i;
  $24 = ((($$08$i$i)) + 16|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = HEAP32[$4>>2]|0;
  $27 = ($25|0)<($26|0);
  if ($27) {
   $$sroa$043$0 = $23;
  } else {
   $31 = HEAP32[$5>>2]|0;
   $32 = ($31|0)==(0|0);
   if ($32) {
    HEAP32[$2>>2] = $5;
    $$2 = $5;
    return ($$2|0);
   }
   $33 = ((($0)) + 4|0);
   $$0$i26 = $33;$$024$i25 = $31;
   while(1) {
    $34 = ((($$024$i25)) + 16|0);
    $35 = HEAP32[$34>>2]|0;
    $36 = ($26|0)<($35|0);
    if ($36) {
     $37 = HEAP32[$$024$i25>>2]|0;
     $38 = ($37|0)==(0|0);
     if ($38) {
      label = 17;
      break;
     } else {
      $$0$ph$i23 = $$024$i25;$$in$i22 = $37;
     }
    } else {
     $39 = ($35|0)<($26|0);
     if (!($39)) {
      label = 21;
      break;
     }
     $40 = ((($$024$i25)) + 4|0);
     $41 = HEAP32[$40>>2]|0;
     $42 = ($41|0)==(0|0);
     if ($42) {
      label = 20;
      break;
     } else {
      $$0$ph$i23 = $40;$$in$i22 = $41;
     }
    }
    $$0$i26 = $$0$ph$i23;$$024$i25 = $$in$i22;
   }
   if ((label|0) == 17) {
    HEAP32[$2>>2] = $$024$i25;
    $$2 = $$024$i25;
    return ($$2|0);
   }
   else if ((label|0) == 20) {
    HEAP32[$2>>2] = $$024$i25;
    $$2 = $40;
    return ($$2|0);
   }
   else if ((label|0) == 21) {
    HEAP32[$2>>2] = $$024$i25;
    $$2 = $$0$i26;
    return ($$2|0);
   }
  }
 }
 $28 = ($$pre|0)==(0|0);
 if ($28) {
  HEAP32[$2>>2] = $6;
  $$2 = $6;
  return ($$2|0);
 } else {
  $29 = $$sroa$043$0;
  HEAP32[$2>>2] = $29;
  $30 = ((($29)) + 4|0);
  $$2 = $30;
  return ($$2|0);
 }
 return (0)|0;
}
function __ZNSt3__26vectorIPN7osgUtil10StateGraphENS_9allocatorIS3_EEEC2ERKS6_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i = 0, $scevgep5$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = 0;
 $2 = ((($0)) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = ((($0)) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$1>>2]|0;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 2;
 $9 = ($8|0)==(0);
 if ($9) {
  return;
 }
 $10 = ($8>>>0)>(1073741823);
 if ($10) {
  __THREW__ = 0;
  invoke_vi(3307,($0|0));
  $11 = __THREW__; __THREW__ = 0;
 } else {
  __THREW__ = 0;
  $12 = (invoke_ii(3276,($7|0))|0);
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if (!($14)) {
   HEAP32[$2>>2] = $12;
   HEAP32[$0>>2] = $12;
   $15 = (($12) + ($8<<2)|0);
   $16 = ((($0)) + 8|0);
   HEAP32[$16>>2] = $15;
   $17 = HEAP32[$1>>2]|0;
   $18 = HEAP32[$4>>2]|0;
   $19 = $17;
   $20 = (($18) - ($19))|0;
   $21 = ($20|0)>(0);
   if (!($21)) {
    return;
   }
   $22 = $20 >>> 2;
   _memcpy(($12|0),($17|0),($20|0))|0;
   $23 = (($12) + ($22<<2)|0);
   HEAP32[$2>>2] = $23;
   return;
  }
 }
 $24 = ___cxa_find_matching_catch_2()|0;
 $25 = tempRet0;
 $26 = HEAP32[$0>>2]|0;
 $27 = ($26|0)==(0|0);
 if ($27) {
  ___resumeException($24|0);
  // unreachable;
 }
 $28 = HEAP32[$2>>2]|0;
 $29 = ($28|0)==($26|0);
 if (!($29)) {
  $scevgep$i$i$i = ((($28)) + -4|0);
  $30 = $scevgep$i$i$i;
  $31 = $26;
  $32 = (($30) - ($31))|0;
  $33 = $32 >>> 2;
  $34 = $33 ^ -1;
  $scevgep5$i$i$i = (($28) + ($34<<2)|0);
  HEAP32[$2>>2] = $scevgep5$i$i$i;
 }
 __ZdlPv($26);
 ___resumeException($24|0);
 // unreachable;
}
function __ZNSt3__26vectorIPN7osgUtil10RenderLeafENS_9allocatorIS3_EEEC2ERKS6_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i = 0, $scevgep5$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = 0;
 $2 = ((($0)) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = ((($0)) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$1>>2]|0;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 2;
 $9 = ($8|0)==(0);
 if ($9) {
  return;
 }
 $10 = ($8>>>0)>(1073741823);
 if ($10) {
  __THREW__ = 0;
  invoke_vi(3307,($0|0));
  $11 = __THREW__; __THREW__ = 0;
 } else {
  __THREW__ = 0;
  $12 = (invoke_ii(3276,($7|0))|0);
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if (!($14)) {
   HEAP32[$2>>2] = $12;
   HEAP32[$0>>2] = $12;
   $15 = (($12) + ($8<<2)|0);
   $16 = ((($0)) + 8|0);
   HEAP32[$16>>2] = $15;
   $17 = HEAP32[$1>>2]|0;
   $18 = HEAP32[$4>>2]|0;
   $19 = $17;
   $20 = (($18) - ($19))|0;
   $21 = ($20|0)>(0);
   if (!($21)) {
    return;
   }
   $22 = $20 >>> 2;
   _memcpy(($12|0),($17|0),($20|0))|0;
   $23 = (($12) + ($22<<2)|0);
   HEAP32[$2>>2] = $23;
   return;
  }
 }
 $24 = ___cxa_find_matching_catch_2()|0;
 $25 = tempRet0;
 $26 = HEAP32[$0>>2]|0;
 $27 = ($26|0)==(0|0);
 if ($27) {
  ___resumeException($24|0);
  // unreachable;
 }
 $28 = HEAP32[$2>>2]|0;
 $29 = ($28|0)==($26|0);
 if (!($29)) {
  $scevgep$i$i$i = ((($28)) + -4|0);
  $30 = $scevgep$i$i$i;
  $31 = $26;
  $32 = (($30) - ($31))|0;
  $33 = $32 >>> 2;
  $34 = $33 ^ -1;
  $scevgep5$i$i$i = (($28) + ($34<<2)|0);
  HEAP32[$2>>2] = $scevgep5$i$i$i;
 }
 __ZdlPv($26);
 ___resumeException($24|0);
 // unreachable;
}
function __ZN7osgUtil9RenderBin27getDefaultRenderBinSortModeEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[217117]|0;
 $1 = ($0<<24>>24)==(0);
 do {
  if ($1) {
   HEAP8[217117] = 1;
   $2 = (_getenv((116809|0))|0);
   $3 = ($2|0)==(0|0);
   if (!($3)) {
    $4 = (_strcmp($2,116835)|0);
    $5 = ($4|0)==(0);
    if ($5) {
     HEAP32[52005] = 0;
     break;
    }
    $6 = (_strcmp($2,116849)|0);
    $7 = ($6|0)==(0);
    if ($7) {
     HEAP32[52005] = 1;
     break;
    }
    $8 = (_strcmp($2,116882)|0);
    $9 = ($8|0)==(0);
    if ($9) {
     HEAP32[52005] = 2;
     break;
    }
    $10 = (_strcmp($2,116901)|0);
    $11 = ($10|0)==(0);
    if ($11) {
     HEAP32[52005] = 3;
     break;
    }
    $12 = (_strcmp($2,116920)|0);
    $13 = ($12|0)==(0);
    if ($13) {
     HEAP32[52005] = 4;
    }
   }
  }
 } while(0);
 $14 = HEAP32[52005]|0;
 return ($14|0);
}
function __GLOBAL__sub_I_RenderBin_cpp() {
 var $$0$i = 0, $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0;
 var label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $0 = sp + 12|0;
 $1 = sp;
 HEAPF32[52006] = 1.0;
 HEAPF32[(208028)>>2] = 0.0;
 HEAPF32[(208032)>>2] = 0.0;
 HEAPF32[52009] = 0.0;
 HEAPF32[(208040)>>2] = 1.0;
 HEAPF32[(208044)>>2] = 0.0;
 HEAPF32[52012] = 0.0;
 HEAPF32[(208052)>>2] = 0.0;
 HEAPF32[(208056)>>2] = 1.0;
 (__ZL22renderBinPrototypeListv()|0);
 $2 = (__Znwj(48)|0);
 HEAP32[$0>>2] = $2;
 $3 = ((($0)) + 8|0);
 HEAP32[$3>>2] = -2147483600;
 $4 = ((($0)) + 4|0);
 HEAP32[$4>>2] = 32;
 dest=$2; src=116957; stop=dest+32|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $5 = ((($2)) + 32|0);
 HEAP8[$5>>0] = 0;
 ;HEAP32[$1>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;
 __THREW__ = 0;
 $6 = (invoke_ii(3276,96)|0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $25 = ___cxa_find_matching_catch_2()|0;
  $26 = tempRet0;
  $$0$i = $26;$$01$i = $25;
 } else {
  HEAP32[$1>>2] = $6;
  $9 = ((($1)) + 8|0);
  HEAP32[$9>>2] = -2147483552;
  $10 = ((($1)) + 4|0);
  HEAP32[$10>>2] = 90;
  dest=$6; src=116990; stop=dest+90|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
  $11 = ((($6)) + 90|0);
  HEAP8[$11>>0] = 0;
  __THREW__ = 0;
  $12 = (invoke_i(3459)|0);
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if (!($14)) {
   __THREW__ = 0;
   invoke_viiii(3460,($12|0),2,($0|0),($1|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    $17 = ((($1)) + 11|0);
    $18 = HEAP8[$17>>0]|0;
    $19 = ($18<<24>>24)<(0);
    if ($19) {
     $20 = HEAP32[$1>>2]|0;
     __ZdlPv($20);
    }
    $21 = ((($0)) + 11|0);
    $22 = HEAP8[$21>>0]|0;
    $23 = ($22<<24>>24)<(0);
    if (!($23)) {
     STACKTOP = sp;return;
    }
    $24 = HEAP32[$0>>2]|0;
    __ZdlPv($24);
    STACKTOP = sp;return;
   }
  }
  $27 = ___cxa_find_matching_catch_2()|0;
  $28 = tempRet0;
  $29 = ((($1)) + 11|0);
  $30 = HEAP8[$29>>0]|0;
  $31 = ($30<<24>>24)<(0);
  if ($31) {
   $32 = HEAP32[$1>>2]|0;
   __ZdlPv($32);
   $$0$i = $28;$$01$i = $27;
  } else {
   $$0$i = $28;$$01$i = $27;
  }
 }
 $33 = ((($0)) + 11|0);
 $34 = HEAP8[$33>>0]|0;
 $35 = ($34<<24>>24)<(0);
 if (!($35)) {
  ___resumeException($$01$i|0);
  // unreachable;
 }
 $36 = HEAP32[$0>>2]|0;
 __ZdlPv($36);
 ___resumeException($$01$i|0);
 // unreachable;
}
function __ZL22renderBinPrototypeListv() {
 var $$0 = 0, $$01 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[206008]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  $11 = HEAP32[52015]|0;
  return ($11|0);
 }
 $2 = (___cxa_guard_acquire(206008)|0);
 $3 = ($2|0)==(0);
 if ($3) {
  $11 = HEAP32[52015]|0;
  return ($11|0);
 }
 __THREW__ = 0;
 $4 = (invoke_ii(3276,24)|0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $12 = ___cxa_find_matching_catch_2()|0;
  $13 = tempRet0;
  $$0 = $13;$$01 = $12;
  ___resumeException($$01|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_vi(3663,($4|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $14 = ___cxa_find_matching_catch_2()|0;
  $15 = tempRet0;
  __ZdlPv($4);
  $$0 = $15;$$01 = $14;
  ___resumeException($$01|0);
  // unreachable;
 } else {
  HEAP32[52015] = $4;
  $9 = ((($4)) + 8|0);
  $10 = HEAP32[$9>>2]|0;HEAP32[$9>>2] = (($10+1)|0);
  (___cxa_atexit((3664|0),(208060|0),(___dso_handle|0))|0);
  $11 = HEAP32[52015]|0;
  return ($11|0);
 }
 return (0)|0;
}
function __ZN22RenderBinPrototypeListC2Ev($0) {
 $0 = $0|0;
 var $$0 = 0, $$02 = 0, $$10 = 0, $$1013 = 0, $$11 = 0, $$1114 = 0, $$12 = 0, $$1215 = 0, $$2 = 0, $$25 = 0, $$3 = 0, $$36 = 0, $$4 = 0, $$47 = 0, $$5 = 0, $$58 = 0, $$6 = 0, $$69 = 0, $$7 = 0, $$710 = 0;
 var $$8 = 0, $$811 = 0, $$9 = 0, $$912 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0;
 var $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0;
 var $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0;
 var $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0;
 var $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0;
 var $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, dest = 0;
 var label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(80|0);
 $1 = sp + 60|0;
 $2 = sp + 48|0;
 $3 = sp + 36|0;
 $4 = sp + 24|0;
 $5 = sp + 12|0;
 $6 = sp;
 (__ZN3osg10Referenced24getGlobalReferencedMutexEv()|0);
 __ZN3osg10ReferencedC2Ev($0);
 $7 = ((($0)) + 12|0);
 $8 = ((($0)) + 16|0);
 HEAP32[$8>>2] = 0;
 $9 = ((($0)) + 20|0);
 HEAP32[$9>>2] = 0;
 $10 = ((($0)) + 16|0);
 HEAP32[$7>>2] = $10;
 HEAP32[$0>>2] = (54168);
 ;HEAP32[$1>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;
 $11 = ((($1)) + 11|0);
 HEAP8[$11>>0] = 9;
 dest=$1; src=116791; stop=dest+9|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $12 = ((($1)) + 9|0);
 HEAP8[$12>>0] = 0;
 __THREW__ = 0;
 $13 = (invoke_ii(3276,100)|0);
 $14 = __THREW__; __THREW__ = 0;
 $15 = $14&1;
 L1: do {
  if ($15) {
   label = 61;
  } else {
   $16 = (__ZN7osgUtil9RenderBin27getDefaultRenderBinSortModeEv()|0);
   __THREW__ = 0;
   invoke_vii(3665,($13|0),($16|0));
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if ($18) {
    $216 = ___cxa_find_matching_catch_2()|0;
    $217 = tempRet0;
    __ZdlPv($13);
    $$0 = $217;$$02 = $216;
    label = 63;
    break;
   }
   __THREW__ = 0;
   $19 = (invoke_iii(3666,($7|0),($1|0))|0);
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if ($21) {
    label = 61;
   } else {
    $22 = HEAP32[$19>>2]|0;
    $23 = ($22|0)==($13|0);
    if (!($23)) {
     HEAP32[$19>>2] = $13;
     $24 = ((($13)) + 8|0);
     $25 = HEAP32[$24>>2]|0;HEAP32[$24>>2] = (($25+1)|0);
     $26 = ($22|0)==(0|0);
     if (!($26)) {
      $27 = ((($22)) + 8|0);
      $28 = HEAP32[$27>>2]|0;HEAP32[$27>>2] = (($28-1)|0);
      $29 = ($28|0)==(1);
      if ($29) {
       __THREW__ = 0;
       invoke_viii(3262,($22|0),1,1);
       $30 = __THREW__; __THREW__ = 0;
       $31 = $30&1;
       if ($31) {
        label = 61;
        break;
       }
      }
     }
    }
    $32 = HEAP8[$11>>0]|0;
    $33 = ($32<<24>>24)<(0);
    if ($33) {
     $34 = HEAP32[$1>>2]|0;
     __ZdlPv($34);
    }
    ;HEAP32[$2>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;
    __THREW__ = 0;
    $35 = (invoke_ii(3276,16)|0);
    $36 = __THREW__; __THREW__ = 0;
    $37 = $36&1;
    if ($37) {
     $221 = ___cxa_find_matching_catch_2()|0;
     $222 = tempRet0;
     $$3 = $222;$$36 = $221;
    } else {
     HEAP32[$2>>2] = $35;
     $38 = ((($2)) + 8|0);
     HEAP32[$38>>2] = -2147483632;
     $39 = ((($2)) + 4|0);
     HEAP32[$39>>2] = 14;
     dest=$35; src=117081; stop=dest+14|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
     $40 = ((($35)) + 14|0);
     HEAP8[$40>>0] = 0;
     __THREW__ = 0;
     $41 = (invoke_ii(3276,100)|0);
     $42 = __THREW__; __THREW__ = 0;
     $43 = $42&1;
     do {
      if ($43) {
       label = 67;
      } else {
       __THREW__ = 0;
       invoke_vi(3282,($41|0));
       $44 = __THREW__; __THREW__ = 0;
       $45 = $44&1;
       if ($45) {
        $225 = ___cxa_find_matching_catch_2()|0;
        $226 = tempRet0;
        __ZdlPv($41);
        $$2 = $226;$$25 = $225;
        break;
       }
       $46 = ((($41)) + 12|0);
       ;HEAP32[$46>>2]=0|0;HEAP32[$46+4>>2]=0|0;HEAP32[$46+8>>2]=0|0;
       $47 = ((($41)) + 24|0);
       HEAP32[$47>>2] = 2;
       $48 = ((($41)) + 28|0);
       HEAP32[$48>>2] = 0;
       HEAP32[$41>>2] = (53976);
       $49 = ((($41)) + 44|0);
       $50 = ((($41)) + 48|0);
       HEAP32[$50>>2] = 0;
       $51 = ((($41)) + 52|0);
       HEAP32[$51>>2] = 0;
       HEAP32[$49>>2] = $50;
       $52 = ((($41)) + 56|0);
       $53 = ((($41)) + 32|0);
       HEAP32[$53>>2] = 0;
       $54 = ((($41)) + 36|0);
       HEAP32[$54>>2] = 0;
       $55 = ((($41)) + 40|0);
       HEAP32[$55>>2] = 0;
       $56 = ((($41)) + 84|0);
       ;HEAP32[$52>>2]=0|0;HEAP32[$52+4>>2]=0|0;HEAP32[$52+8>>2]=0|0;HEAP32[$52+12>>2]=0|0;HEAP32[$52+16>>2]=0|0;HEAP32[$52+20>>2]=0|0;HEAP8[$52+24>>0]=0|0;
       ;HEAP32[$56>>2]=0|0;HEAP32[$56+4>>2]=0|0;HEAP32[$56+8>>2]=0|0;HEAP32[$56+12>>2]=0|0;
       __THREW__ = 0;
       $57 = (invoke_iii(3666,($7|0),($2|0))|0);
       $58 = __THREW__; __THREW__ = 0;
       $59 = $58&1;
       if ($59) {
        label = 67;
       } else {
        $60 = HEAP32[$57>>2]|0;
        $61 = ($60|0)==($41|0);
        if (!($61)) {
         HEAP32[$57>>2] = $41;
         $62 = ((($41)) + 8|0);
         $63 = HEAP32[$62>>2]|0;HEAP32[$62>>2] = (($63+1)|0);
         $64 = ($60|0)==(0|0);
         if (!($64)) {
          $65 = ((($60)) + 8|0);
          $66 = HEAP32[$65>>2]|0;HEAP32[$65>>2] = (($66-1)|0);
          $67 = ($66|0)==(1);
          if ($67) {
           __THREW__ = 0;
           invoke_viii(3262,($60|0),1,1);
           $68 = __THREW__; __THREW__ = 0;
           $69 = $68&1;
           if ($69) {
            label = 67;
            break;
           }
          }
         }
        }
        $70 = ((($2)) + 11|0);
        $71 = HEAP8[$70>>0]|0;
        $72 = ($71<<24>>24)<(0);
        if ($72) {
         $73 = HEAP32[$2>>2]|0;
         __ZdlPv($73);
        }
        ;HEAP32[$3>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;
        __THREW__ = 0;
        $74 = (invoke_ii(3276,16)|0);
        $75 = __THREW__; __THREW__ = 0;
        $76 = $75&1;
        if ($76) {
         $231 = ___cxa_find_matching_catch_2()|0;
         $232 = tempRet0;
         $$5 = $232;$$58 = $231;
        } else {
         HEAP32[$3>>2] = $74;
         $77 = ((($3)) + 8|0);
         HEAP32[$77>>2] = -2147483632;
         $78 = ((($3)) + 4|0);
         HEAP32[$78>>2] = 14;
         dest=$74; src=117096; stop=dest+14|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
         $79 = ((($74)) + 14|0);
         HEAP8[$79>>0] = 0;
         __THREW__ = 0;
         $80 = (invoke_ii(3276,100)|0);
         $81 = __THREW__; __THREW__ = 0;
         $82 = $81&1;
         L35: do {
          if ($82) {
           label = 73;
          } else {
           __THREW__ = 0;
           invoke_vii(3665,($80|0),3);
           $83 = __THREW__; __THREW__ = 0;
           $84 = $83&1;
           if ($84) {
            $235 = ___cxa_find_matching_catch_2()|0;
            $236 = tempRet0;
            __ZdlPv($80);
            $$4 = $236;$$47 = $235;
            break;
           }
           __THREW__ = 0;
           $85 = (invoke_iii(3666,($7|0),($3|0))|0);
           $86 = __THREW__; __THREW__ = 0;
           $87 = $86&1;
           if ($87) {
            label = 73;
           } else {
            $88 = HEAP32[$85>>2]|0;
            $89 = ($88|0)==($80|0);
            do {
             if (!($89)) {
              HEAP32[$85>>2] = $80;
              $90 = ((($80)) + 8|0);
              $91 = HEAP32[$90>>2]|0;HEAP32[$90>>2] = (($91+1)|0);
              $92 = ($88|0)==(0|0);
              if ($92) {
               break;
              }
              $93 = ((($88)) + 8|0);
              $94 = HEAP32[$93>>2]|0;HEAP32[$93>>2] = (($94-1)|0);
              $95 = ($94|0)==(1);
              if (!($95)) {
               break;
              }
              __THREW__ = 0;
              invoke_viii(3262,($88|0),1,1);
              $96 = __THREW__; __THREW__ = 0;
              $97 = $96&1;
              if ($97) {
               label = 73;
               break L35;
              }
             }
            } while(0);
            $98 = ((($3)) + 11|0);
            $99 = HEAP8[$98>>0]|0;
            $100 = ($99<<24>>24)<(0);
            if ($100) {
             $101 = HEAP32[$3>>2]|0;
             __ZdlPv($101);
            }
            ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;
            __THREW__ = 0;
            $102 = (invoke_ii(3276,32)|0);
            $103 = __THREW__; __THREW__ = 0;
            $104 = $103&1;
            do {
             if ($104) {
              $241 = ___cxa_find_matching_catch_2()|0;
              $242 = tempRet0;
              $$7 = $242;$$710 = $241;
             } else {
              HEAP32[$4>>2] = $102;
              $105 = ((($4)) + 8|0);
              HEAP32[$105>>2] = -2147483616;
              $106 = ((($4)) + 4|0);
              HEAP32[$106>>2] = 18;
              dest=$102; src=116901; stop=dest+18|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
              $107 = ((($102)) + 18|0);
              HEAP8[$107>>0] = 0;
              __THREW__ = 0;
              $108 = (invoke_ii(3276,100)|0);
              $109 = __THREW__; __THREW__ = 0;
              $110 = $109&1;
              L52: do {
               if ($110) {
                label = 79;
               } else {
                __THREW__ = 0;
                invoke_vii(3665,($108|0),3);
                $111 = __THREW__; __THREW__ = 0;
                $112 = $111&1;
                if ($112) {
                 $245 = ___cxa_find_matching_catch_2()|0;
                 $246 = tempRet0;
                 __ZdlPv($108);
                 $$6 = $246;$$69 = $245;
                 break;
                }
                __THREW__ = 0;
                $113 = (invoke_iii(3666,($7|0),($4|0))|0);
                $114 = __THREW__; __THREW__ = 0;
                $115 = $114&1;
                if ($115) {
                 label = 79;
                 break;
                }
                $116 = HEAP32[$113>>2]|0;
                $117 = ($116|0)==($108|0);
                do {
                 if (!($117)) {
                  HEAP32[$113>>2] = $108;
                  $118 = ((($108)) + 8|0);
                  $119 = HEAP32[$118>>2]|0;HEAP32[$118>>2] = (($119+1)|0);
                  $120 = ($116|0)==(0|0);
                  if ($120) {
                   break;
                  }
                  $121 = ((($116)) + 8|0);
                  $122 = HEAP32[$121>>2]|0;HEAP32[$121>>2] = (($122-1)|0);
                  $123 = ($122|0)==(1);
                  if (!($123)) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_viii(3262,($116|0),1,1);
                  $124 = __THREW__; __THREW__ = 0;
                  $125 = $124&1;
                  if ($125) {
                   label = 79;
                   break L52;
                  }
                 }
                } while(0);
                $126 = ((($4)) + 11|0);
                $127 = HEAP8[$126>>0]|0;
                $128 = ($127<<24>>24)<(0);
                if ($128) {
                 $129 = HEAP32[$4>>2]|0;
                 __ZdlPv($129);
                }
                ;HEAP32[$5>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;
                __THREW__ = 0;
                $130 = (invoke_ii(3276,32)|0);
                $131 = __THREW__; __THREW__ = 0;
                $132 = $131&1;
                do {
                 if ($132) {
                  $251 = ___cxa_find_matching_catch_2()|0;
                  $252 = tempRet0;
                  $$9 = $252;$$912 = $251;
                 } else {
                  HEAP32[$5>>2] = $130;
                  $133 = ((($5)) + 8|0);
                  HEAP32[$133>>2] = -2147483616;
                  $134 = ((($5)) + 4|0);
                  HEAP32[$134>>2] = 18;
                  dest=$130; src=116882; stop=dest+18|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                  $135 = ((($130)) + 18|0);
                  HEAP8[$135>>0] = 0;
                  __THREW__ = 0;
                  $136 = (invoke_ii(3276,100)|0);
                  $137 = __THREW__; __THREW__ = 0;
                  $138 = $137&1;
                  L69: do {
                   if ($138) {
                    label = 85;
                   } else {
                    __THREW__ = 0;
                    invoke_vi(3282,($136|0));
                    $139 = __THREW__; __THREW__ = 0;
                    $140 = $139&1;
                    if ($140) {
                     $255 = ___cxa_find_matching_catch_2()|0;
                     $256 = tempRet0;
                     __ZdlPv($136);
                     $$8 = $256;$$811 = $255;
                     break;
                    }
                    $141 = ((($136)) + 12|0);
                    ;HEAP32[$141>>2]=0|0;HEAP32[$141+4>>2]=0|0;HEAP32[$141+8>>2]=0|0;
                    $142 = ((($136)) + 24|0);
                    HEAP32[$142>>2] = 2;
                    $143 = ((($136)) + 28|0);
                    HEAP32[$143>>2] = 0;
                    HEAP32[$136>>2] = (53976);
                    $144 = ((($136)) + 44|0);
                    $145 = ((($136)) + 48|0);
                    HEAP32[$145>>2] = 0;
                    $146 = ((($136)) + 52|0);
                    HEAP32[$146>>2] = 0;
                    HEAP32[$144>>2] = $145;
                    $147 = ((($136)) + 56|0);
                    $148 = ((($136)) + 88|0);
                    HEAP32[$148>>2] = 0;
                    $149 = ((($136)) + 92|0);
                    HEAP32[$149>>2] = 0;
                    $150 = ((($136)) + 96|0);
                    HEAP32[$150>>2] = 0;
                    $151 = ((($136)) + 32|0);
                    HEAP32[$151>>2] = 0;
                    $152 = ((($136)) + 36|0);
                    HEAP32[$152>>2] = 0;
                    $153 = ((($136)) + 40|0);
                    HEAP32[$153>>2] = 0;
                    $154 = ((($136)) + 84|0);
                    ;HEAP32[$147>>2]=0|0;HEAP32[$147+4>>2]=0|0;HEAP32[$147+8>>2]=0|0;HEAP32[$147+12>>2]=0|0;HEAP32[$147+16>>2]=0|0;HEAP32[$147+20>>2]=0|0;HEAP8[$147+24>>0]=0|0;
                    HEAP32[$154>>2] = 2;
                    __THREW__ = 0;
                    $155 = (invoke_iii(3666,($7|0),($5|0))|0);
                    $156 = __THREW__; __THREW__ = 0;
                    $157 = $156&1;
                    if ($157) {
                     label = 85;
                     break;
                    }
                    $158 = HEAP32[$155>>2]|0;
                    $159 = ($158|0)==($136|0);
                    do {
                     if (!($159)) {
                      HEAP32[$155>>2] = $136;
                      $160 = ((($136)) + 8|0);
                      $161 = HEAP32[$160>>2]|0;HEAP32[$160>>2] = (($161+1)|0);
                      $162 = ($158|0)==(0|0);
                      if ($162) {
                       break;
                      }
                      $163 = ((($158)) + 8|0);
                      $164 = HEAP32[$163>>2]|0;HEAP32[$163>>2] = (($164-1)|0);
                      $165 = ($164|0)==(1);
                      if (!($165)) {
                       break;
                      }
                      __THREW__ = 0;
                      invoke_viii(3262,($158|0),1,1);
                      $166 = __THREW__; __THREW__ = 0;
                      $167 = $166&1;
                      if ($167) {
                       label = 85;
                       break L69;
                      }
                     }
                    } while(0);
                    $168 = ((($5)) + 11|0);
                    $169 = HEAP8[$168>>0]|0;
                    $170 = ($169<<24>>24)<(0);
                    if ($170) {
                     $171 = HEAP32[$5>>2]|0;
                     __ZdlPv($171);
                    }
                    ;HEAP32[$6>>2]=0|0;HEAP32[$6+4>>2]=0|0;HEAP32[$6+8>>2]=0|0;
                    __THREW__ = 0;
                    $172 = (invoke_ii(3276,32)|0);
                    $173 = __THREW__; __THREW__ = 0;
                    $174 = $173&1;
                    do {
                     if ($174) {
                      $261 = ___cxa_find_matching_catch_2()|0;
                      $262 = tempRet0;
                      $$11 = $262;$$1114 = $261;
                     } else {
                      HEAP32[$6>>2] = $172;
                      $175 = ((($6)) + 8|0);
                      HEAP32[$175>>2] = -2147483616;
                      $176 = ((($6)) + 4|0);
                      HEAP32[$176>>2] = 17;
                      dest=$172; src=117111; stop=dest+17|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                      $177 = ((($172)) + 17|0);
                      HEAP8[$177>>0] = 0;
                      __THREW__ = 0;
                      $178 = (invoke_ii(3276,100)|0);
                      $179 = __THREW__; __THREW__ = 0;
                      $180 = $179&1;
                      L86: do {
                       if ($180) {
                        label = 91;
                       } else {
                        __THREW__ = 0;
                        invoke_vi(3282,($178|0));
                        $181 = __THREW__; __THREW__ = 0;
                        $182 = $181&1;
                        if ($182) {
                         $265 = ___cxa_find_matching_catch_2()|0;
                         $266 = tempRet0;
                         __ZdlPv($178);
                         $$10 = $266;$$1013 = $265;
                         break;
                        }
                        $183 = ((($178)) + 12|0);
                        ;HEAP32[$183>>2]=0|0;HEAP32[$183+4>>2]=0|0;HEAP32[$183+8>>2]=0|0;
                        $184 = ((($178)) + 24|0);
                        HEAP32[$184>>2] = 2;
                        $185 = ((($178)) + 28|0);
                        HEAP32[$185>>2] = 0;
                        HEAP32[$178>>2] = (53976);
                        $186 = ((($178)) + 44|0);
                        $187 = ((($178)) + 48|0);
                        HEAP32[$187>>2] = 0;
                        $188 = ((($178)) + 52|0);
                        HEAP32[$188>>2] = 0;
                        HEAP32[$186>>2] = $187;
                        $189 = ((($178)) + 56|0);
                        $190 = ((($178)) + 88|0);
                        HEAP32[$190>>2] = 0;
                        $191 = ((($178)) + 92|0);
                        HEAP32[$191>>2] = 0;
                        $192 = ((($178)) + 96|0);
                        HEAP32[$192>>2] = 0;
                        $193 = ((($178)) + 32|0);
                        HEAP32[$193>>2] = 0;
                        $194 = ((($178)) + 36|0);
                        HEAP32[$194>>2] = 0;
                        $195 = ((($178)) + 40|0);
                        HEAP32[$195>>2] = 0;
                        $196 = ((($178)) + 84|0);
                        ;HEAP32[$189>>2]=0|0;HEAP32[$189+4>>2]=0|0;HEAP32[$189+8>>2]=0|0;HEAP32[$189+12>>2]=0|0;HEAP32[$189+16>>2]=0|0;HEAP32[$189+20>>2]=0|0;HEAP8[$189+24>>0]=0|0;
                        HEAP32[$196>>2] = 4;
                        __THREW__ = 0;
                        $197 = (invoke_iii(3666,($7|0),($6|0))|0);
                        $198 = __THREW__; __THREW__ = 0;
                        $199 = $198&1;
                        if ($199) {
                         label = 91;
                         break;
                        }
                        $200 = HEAP32[$197>>2]|0;
                        $201 = ($200|0)==($178|0);
                        do {
                         if (!($201)) {
                          HEAP32[$197>>2] = $178;
                          $202 = ((($178)) + 8|0);
                          $203 = HEAP32[$202>>2]|0;HEAP32[$202>>2] = (($203+1)|0);
                          $204 = ($200|0)==(0|0);
                          if ($204) {
                           break;
                          }
                          $205 = ((($200)) + 8|0);
                          $206 = HEAP32[$205>>2]|0;HEAP32[$205>>2] = (($206-1)|0);
                          $207 = ($206|0)==(1);
                          if (!($207)) {
                           break;
                          }
                          __THREW__ = 0;
                          invoke_viii(3262,($200|0),1,1);
                          $208 = __THREW__; __THREW__ = 0;
                          $209 = $208&1;
                          if ($209) {
                           label = 91;
                           break L86;
                          }
                         }
                        } while(0);
                        $210 = ((($6)) + 11|0);
                        $211 = HEAP8[$210>>0]|0;
                        $212 = ($211<<24>>24)<(0);
                        if (!($212)) {
                         STACKTOP = sp;return;
                        }
                        $213 = HEAP32[$6>>2]|0;
                        __ZdlPv($213);
                        STACKTOP = sp;return;
                       }
                      } while(0);
                      if ((label|0) == 91) {
                       $263 = ___cxa_find_matching_catch_2()|0;
                       $264 = tempRet0;
                       $$10 = $264;$$1013 = $263;
                      }
                      $267 = ((($6)) + 11|0);
                      $268 = HEAP8[$267>>0]|0;
                      $269 = ($268<<24>>24)<(0);
                      if (!($269)) {
                       $$11 = $$10;$$1114 = $$1013;
                       break;
                      }
                      $270 = HEAP32[$6>>2]|0;
                      __ZdlPv($270);
                      $$11 = $$10;$$1114 = $$1013;
                     }
                    } while(0);
                    $$12 = $$11;$$1215 = $$1114;
                    break L1;
                   }
                  } while(0);
                  if ((label|0) == 85) {
                   $253 = ___cxa_find_matching_catch_2()|0;
                   $254 = tempRet0;
                   $$8 = $254;$$811 = $253;
                  }
                  $257 = ((($5)) + 11|0);
                  $258 = HEAP8[$257>>0]|0;
                  $259 = ($258<<24>>24)<(0);
                  if (!($259)) {
                   $$9 = $$8;$$912 = $$811;
                   break;
                  }
                  $260 = HEAP32[$5>>2]|0;
                  __ZdlPv($260);
                  $$9 = $$8;$$912 = $$811;
                 }
                } while(0);
                $$12 = $$9;$$1215 = $$912;
                break L1;
               }
              } while(0);
              if ((label|0) == 79) {
               $243 = ___cxa_find_matching_catch_2()|0;
               $244 = tempRet0;
               $$6 = $244;$$69 = $243;
              }
              $247 = ((($4)) + 11|0);
              $248 = HEAP8[$247>>0]|0;
              $249 = ($248<<24>>24)<(0);
              if (!($249)) {
               $$7 = $$6;$$710 = $$69;
               break;
              }
              $250 = HEAP32[$4>>2]|0;
              __ZdlPv($250);
              $$7 = $$6;$$710 = $$69;
             }
            } while(0);
            $$12 = $$7;$$1215 = $$710;
            break L1;
           }
          }
         } while(0);
         if ((label|0) == 73) {
          $233 = ___cxa_find_matching_catch_2()|0;
          $234 = tempRet0;
          $$4 = $234;$$47 = $233;
         }
         $237 = ((($3)) + 11|0);
         $238 = HEAP8[$237>>0]|0;
         $239 = ($238<<24>>24)<(0);
         if ($239) {
          $240 = HEAP32[$3>>2]|0;
          __ZdlPv($240);
          $$5 = $$4;$$58 = $$47;
         } else {
          $$5 = $$4;$$58 = $$47;
         }
        }
        $$12 = $$5;$$1215 = $$58;
        break L1;
       }
      }
     } while(0);
     if ((label|0) == 67) {
      $223 = ___cxa_find_matching_catch_2()|0;
      $224 = tempRet0;
      $$2 = $224;$$25 = $223;
     }
     $227 = ((($2)) + 11|0);
     $228 = HEAP8[$227>>0]|0;
     $229 = ($228<<24>>24)<(0);
     if ($229) {
      $230 = HEAP32[$2>>2]|0;
      __ZdlPv($230);
      $$3 = $$2;$$36 = $$25;
     } else {
      $$3 = $$2;$$36 = $$25;
     }
    }
    $$12 = $$3;$$1215 = $$36;
   }
  }
 } while(0);
 if ((label|0) == 61) {
  $214 = ___cxa_find_matching_catch_2()|0;
  $215 = tempRet0;
  $$0 = $215;$$02 = $214;
  label = 63;
 }
 if ((label|0) == 63) {
  $218 = HEAP8[$11>>0]|0;
  $219 = ($218<<24>>24)<(0);
  if ($219) {
   $220 = HEAP32[$1>>2]|0;
   __ZdlPv($220);
  }
  $$12 = $$0;$$1215 = $$02;
 }
 $271 = HEAP32[$10>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7ref_ptrIN7osgUtil9RenderBinEEEEENS_19__map_value_compareIS7_SD_NS_4lessIS7_EELb1EEENS5_ISD_EEE7destroyEPNS_11__tree_nodeISD_PvEE($7,$271);
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $272 = __THREW__; __THREW__ = 0;
 $273 = $272&1;
 if ($273) {
  $274 = ___cxa_find_matching_catch_3(0|0)|0;
  $275 = tempRet0;
  ___clang_call_terminate($274);
  // unreachable;
 } else {
  ___resumeException($$1215|0);
  // unreachable;
 }
}
function __ZN3osg7ref_ptrI22RenderBinPrototypeListED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = ((($1)) + 8|0);
  $4 = HEAP32[$3>>2]|0;HEAP32[$3>>2] = (($4-1)|0);
  $5 = ($4|0)==(1);
  if ($5) {
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($1,1,1);
  }
 }
 HEAP32[$0>>2] = 0;
 return;
}
function __ZN7osgUtil9RenderBinC2ENS0_8SortModeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$03 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $9 = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i7 = 0, $scevgep5$i$i$i = 0, $scevgep5$i$i$i8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg10ReferencedC2Ev($0);
 $2 = ((($0)) + 12|0);
 ;HEAP32[$2>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;
 $3 = ((($0)) + 24|0);
 HEAP32[$3>>2] = 2;
 $4 = ((($0)) + 28|0);
 HEAP32[$4>>2] = 0;
 HEAP32[$0>>2] = (53976);
 $5 = ((($0)) + 44|0);
 $6 = ((($0)) + 48|0);
 HEAP32[$6>>2] = 0;
 $7 = ((($0)) + 52|0);
 HEAP32[$7>>2] = 0;
 $8 = ((($0)) + 48|0);
 HEAP32[$5>>2] = $8;
 $9 = ((($0)) + 56|0);
 $10 = ((($0)) + 60|0);
 $11 = ((($0)) + 68|0);
 $12 = ((($0)) + 72|0);
 $13 = ((($0)) + 88|0);
 HEAP32[$13>>2] = 0;
 $14 = ((($0)) + 92|0);
 HEAP32[$14>>2] = 0;
 $15 = ((($0)) + 96|0);
 HEAP32[$15>>2] = 0;
 $16 = ((($0)) + 32|0);
 HEAP32[$16>>2] = 0;
 $17 = ((($0)) + 36|0);
 HEAP32[$17>>2] = 0;
 $18 = ((($0)) + 40|0);
 HEAP32[$18>>2] = 0;
 $19 = ((($0)) + 84|0);
 ;HEAP32[$9>>2]=0|0;HEAP32[$9+4>>2]=0|0;HEAP32[$9+8>>2]=0|0;HEAP32[$9+12>>2]=0|0;HEAP32[$9+16>>2]=0|0;HEAP32[$9+20>>2]=0|0;HEAP8[$9+24>>0]=0|0;
 HEAP32[$19>>2] = $1;
 $20 = ($1|0)==(3);
 if (!($20)) {
  return;
 }
 __THREW__ = 0;
 $21 = (invoke_ii(3276,160)|0);
 $22 = __THREW__; __THREW__ = 0;
 $23 = $22&1;
 do {
  if ($23) {
   label = 9;
  } else {
   __THREW__ = 0;
   invoke_vi(3572,($21|0));
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   if ($25) {
    $43 = ___cxa_find_matching_catch_2()|0;
    $44 = tempRet0;
    __ZdlPv($21);
    $$0 = $44;$$03 = $43;
    break;
   }
   $26 = HEAP32[$15>>2]|0;
   $27 = ($26|0)==($21|0);
   if (!($27)) {
    HEAP32[$15>>2] = $21;
    $28 = ((($21)) + 8|0);
    $29 = HEAP32[$28>>2]|0;HEAP32[$28>>2] = (($29+1)|0);
    $30 = ($26|0)==(0|0);
    if (!($30)) {
     $31 = ((($26)) + 8|0);
     $32 = HEAP32[$31>>2]|0;HEAP32[$31>>2] = (($32-1)|0);
     $33 = ($32|0)==(1);
     if ($33) {
      __THREW__ = 0;
      invoke_viii(3262,($26|0),1,1);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       label = 9;
       break;
      }
     }
    }
   }
   $36 = HEAP32[$15>>2]|0;
   $37 = HEAP32[$36>>2]|0;
   $38 = HEAP32[$37>>2]|0;
   __THREW__ = 0;
   invoke_vii($38|0,($36|0),1);
   $39 = __THREW__; __THREW__ = 0;
   $40 = $39&1;
   if ($40) {
    label = 9;
   } else {
    return;
   }
  }
 } while(0);
 if ((label|0) == 9) {
  $41 = ___cxa_find_matching_catch_2()|0;
  $42 = tempRet0;
  $$0 = $42;$$03 = $41;
 }
 $45 = HEAP32[$15>>2]|0;
 $46 = ($45|0)==(0|0);
 if (!($46)) {
  $47 = ((($45)) + 8|0);
  $48 = HEAP32[$47>>2]|0;HEAP32[$47>>2] = (($48-1)|0);
  $49 = ($48|0)==(1);
  if ($49) {
   __THREW__ = 0;
   invoke_viii(3262,($45|0),1,1);
   $50 = __THREW__; __THREW__ = 0;
   $51 = $50&1;
   if ($51) {
    $87 = ___cxa_find_matching_catch_3(0|0)|0;
    $88 = tempRet0;
    ___clang_call_terminate($87);
    // unreachable;
   }
  }
 }
 HEAP32[$15>>2] = 0;
 $52 = HEAP32[$14>>2]|0;
 $53 = ($52|0)==(0|0);
 if (!($53)) {
  $54 = ((($52)) + 8|0);
  $55 = HEAP32[$54>>2]|0;HEAP32[$54>>2] = (($55-1)|0);
  $56 = ($55|0)==(1);
  if ($56) {
   __THREW__ = 0;
   invoke_viii(3262,($52|0),1,1);
   $57 = __THREW__; __THREW__ = 0;
   $58 = $57&1;
   if ($58) {
    $87 = ___cxa_find_matching_catch_3(0|0)|0;
    $88 = tempRet0;
    ___clang_call_terminate($87);
    // unreachable;
   }
  }
 }
 HEAP32[$14>>2] = 0;
 $59 = HEAP32[$13>>2]|0;
 $60 = ($59|0)==(0|0);
 if (!($60)) {
  $61 = ((($59)) + 8|0);
  $62 = HEAP32[$61>>2]|0;HEAP32[$61>>2] = (($62-1)|0);
  $63 = ($62|0)==(1);
  if ($63) {
   __THREW__ = 0;
   invoke_viii(3262,($59|0),1,1);
   $64 = __THREW__; __THREW__ = 0;
   $65 = $64&1;
   if ($65) {
    $87 = ___cxa_find_matching_catch_3(0|0)|0;
    $88 = tempRet0;
    ___clang_call_terminate($87);
    // unreachable;
   }
  }
 }
 HEAP32[$13>>2] = 0;
 $66 = HEAP32[$11>>2]|0;
 $67 = ($66|0)==(0|0);
 if (!($67)) {
  $68 = HEAP32[$12>>2]|0;
  $69 = ($68|0)==($66|0);
  if (!($69)) {
   $scevgep$i$i$i7 = ((($68)) + -4|0);
   $70 = $scevgep$i$i$i7;
   $71 = $66;
   $72 = (($70) - ($71))|0;
   $73 = $72 >>> 2;
   $74 = $73 ^ -1;
   $scevgep5$i$i$i8 = (($68) + ($74<<2)|0);
   HEAP32[$12>>2] = $scevgep5$i$i$i8;
  }
  __ZdlPv($66);
 }
 $75 = HEAP32[$9>>2]|0;
 $76 = ($75|0)==(0|0);
 if (!($76)) {
  $77 = HEAP32[$10>>2]|0;
  $78 = ($77|0)==($75|0);
  if (!($78)) {
   $scevgep$i$i$i = ((($77)) + -4|0);
   $79 = $scevgep$i$i$i;
   $80 = $75;
   $81 = (($79) - ($80))|0;
   $82 = $81 >>> 2;
   $83 = $82 ^ -1;
   $scevgep5$i$i$i = (($77) + ($83<<2)|0);
   HEAP32[$10>>2] = $scevgep5$i$i$i;
  }
  __ZdlPv($75);
 }
 $84 = HEAP32[$8>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIiN3osg7ref_ptrIN7osgUtil9RenderBinEEEEENS_19__map_value_compareIiS7_NS_4lessIiEELb1EEENS_9allocatorIS7_EEE7destroyEPNS_11__tree_nodeIS7_PvEE($5,$84);
 __THREW__ = 0;
 invoke_vi(388,($0|0));
 $85 = __THREW__; __THREW__ = 0;
 $86 = $85&1;
 if ($86) {
  $87 = ___cxa_find_matching_catch_3(0|0)|0;
  $88 = tempRet0;
  ___clang_call_terminate($87);
  // unreachable;
 } else {
  ___resumeException($$03|0);
  // unreachable;
 }
}
function __ZNSt3__23mapINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7ref_ptrIN7osgUtil9RenderBinEEENS_4lessIS6_EENS4_INS_4pairIKS6_SB_EEEEEixERSF_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$014 = 0, $$pre$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = (__ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7ref_ptrIN7osgUtil9RenderBinEEEEENS_19__map_value_compareIS7_SD_NS_4lessIS7_EELb1EEENS5_ISD_EEE12__find_equalIS7_EERPNS_16__tree_node_baseIPvEERPNS_15__tree_end_nodeISO_EERKT_($0,$2,$1)|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if (!($5)) {
  $$014 = $4;
  $26 = ((($$014)) + 28|0);
  STACKTOP = sp;return ($26|0);
 }
 $6 = (__Znwj(32)|0);
 $7 = ((($6)) + 16|0);
 __THREW__ = 0;
 invoke_vii(3457,($7|0),($1|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $10 = ___cxa_find_matching_catch_2()|0;
  $11 = tempRet0;
  __ZdlPv($6);
  ___resumeException($10|0);
  // unreachable;
 }
 $12 = ((($6)) + 28|0);
 HEAP32[$12>>2] = 0;
 $13 = HEAP32[$2>>2]|0;
 HEAP32[$6>>2] = 0;
 $14 = ((($6)) + 4|0);
 HEAP32[$14>>2] = 0;
 $15 = ((($6)) + 8|0);
 HEAP32[$15>>2] = $13;
 HEAP32[$3>>2] = $6;
 $16 = HEAP32[$0>>2]|0;
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==(0|0);
 if ($18) {
  $22 = $6;
 } else {
  $19 = $17;
  HEAP32[$0>>2] = $19;
  $$pre$i = HEAP32[$3>>2]|0;
  $22 = $$pre$i;
 }
 $20 = ((($0)) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($21,$22);
 $23 = ((($0)) + 8|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (($24) + 1)|0;
 HEAP32[$23>>2] = $25;
 $$014 = $6;
 $26 = ((($$014)) + 28|0);
 STACKTOP = sp;return ($26|0);
}
function __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7ref_ptrIN7osgUtil9RenderBinEEEEENS_19__map_value_compareIS7_SD_NS_4lessIS7_EELb1EEENS5_ISD_EEE7destroyEPNS_11__tree_nodeISD_PvEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 }
 $3 = HEAP32[$1>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7ref_ptrIN7osgUtil9RenderBinEEEEENS_19__map_value_compareIS7_SD_NS_4lessIS7_EELb1EEENS5_ISD_EEE7destroyEPNS_11__tree_nodeISD_PvEE($0,$3);
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7ref_ptrIN7osgUtil9RenderBinEEEEENS_19__map_value_compareIS7_SD_NS_4lessIS7_EELb1EEENS5_ISD_EEE7destroyEPNS_11__tree_nodeISD_PvEE($0,$5);
 $6 = ((($1)) + 16|0);
 $7 = ((($1)) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if (!($9)) {
  $10 = ((($8)) + 8|0);
  $11 = HEAP32[$10>>2]|0;HEAP32[$10>>2] = (($11-1)|0);
  $12 = ($11|0)==(1);
  if ($12) {
   __THREW__ = 0;
   invoke_viii(3262,($8|0),1,1);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if ($14) {
    $19 = ___cxa_find_matching_catch_2()|0;
    $20 = tempRet0;
    $21 = ((($6)) + 11|0);
    $22 = HEAP8[$21>>0]|0;
    $23 = ($22<<24>>24)<(0);
    if (!($23)) {
     ___cxa_call_unexpected(($19|0));
     // unreachable;
    }
    $24 = HEAP32[$6>>2]|0;
    __ZdlPv($24);
    ___cxa_call_unexpected(($19|0));
    // unreachable;
   }
  }
 }
 HEAP32[$7>>2] = 0;
 $15 = ((($6)) + 11|0);
 $16 = HEAP8[$15>>0]|0;
 $17 = ($16<<24>>24)<(0);
 if ($17) {
  $18 = HEAP32[$6>>2]|0;
  __ZdlPv($18);
 }
 __ZdlPv($1);
 return;
}
function __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7ref_ptrIN7osgUtil9RenderBinEEEEENS_19__map_value_compareIS7_SD_NS_4lessIS7_EELb1EEENS5_ISD_EEE12__find_equalIS7_EERPNS_16__tree_node_baseIPvEERPNS_15__tree_end_nodeISO_EERKT_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$0$ph = 0, $$024 = 0, $$025 = 0, $$in = 0, $$sroa$speculated$i$i$i$i$i = 0, $$sroa$speculated$i$i$i$i$i26 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  HEAP32[$1>>2] = $3;
  $$025 = $3;
  return ($$025|0);
 }
 $6 = ((($0)) + 4|0);
 $7 = ((($2)) + 11|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = ($8<<24>>24)<(0);
 $10 = ((($2)) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $8&255;
 $13 = $9 ? $11 : $12;
 $14 = HEAP32[$2>>2]|0;
 $15 = $9 ? $14 : $2;
 $$0 = $6;$$024 = $4;
 while(1) {
  $16 = ((($$024)) + 16|0);
  $17 = ((($16)) + 11|0);
  $18 = HEAP8[$17>>0]|0;
  $19 = ($18<<24>>24)<(0);
  $20 = ((($$024)) + 20|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = $18&255;
  $23 = $19 ? $21 : $22;
  $24 = ($23>>>0)<($13>>>0);
  $$sroa$speculated$i$i$i$i$i26 = $24 ? $23 : $13;
  $25 = ($$sroa$speculated$i$i$i$i$i26|0)==(0);
  if ($25) {
   label = 6;
  } else {
   $26 = HEAP32[$16>>2]|0;
   $27 = $19 ? $26 : $16;
   $28 = (_memcmp($15,$27,$$sroa$speculated$i$i$i$i$i26)|0);
   $29 = ($28|0)==(0);
   if ($29) {
    label = 6;
   } else {
    $31 = ($28|0)<(0);
    if ($31) {
     label = 8;
    } else {
     label = 10;
    }
   }
  }
  if ((label|0) == 6) {
   label = 0;
   $30 = ($13>>>0)<($23>>>0);
   if ($30) {
    label = 8;
   } else {
    label = 10;
   }
  }
  if ((label|0) == 8) {
   label = 0;
   $32 = HEAP32[$$024>>2]|0;
   $33 = ($32|0)==(0|0);
   if ($33) {
    label = 9;
    break;
   } else {
    $$0$ph = $$024;$$in = $32;
   }
  }
  else if ((label|0) == 10) {
   label = 0;
   $34 = ($13>>>0)<($23>>>0);
   $$sroa$speculated$i$i$i$i$i = $34 ? $13 : $23;
   $35 = ($$sroa$speculated$i$i$i$i$i|0)==(0);
   if ($35) {
    label = 12;
   } else {
    $36 = HEAP32[$16>>2]|0;
    $37 = $19 ? $36 : $16;
    $38 = (_memcmp($37,$15,$$sroa$speculated$i$i$i$i$i)|0);
    $39 = ($38|0)==(0);
    if ($39) {
     label = 12;
    } else {
     $40 = ($38|0)<(0);
     if (!($40)) {
      label = 16;
      break;
     }
    }
   }
   if ((label|0) == 12) {
    label = 0;
    if (!($24)) {
     label = 16;
     break;
    }
   }
   $41 = ((($$024)) + 4|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = ($42|0)==(0|0);
   if ($43) {
    label = 15;
    break;
   } else {
    $$0$ph = $41;$$in = $42;
   }
  }
  $$0 = $$0$ph;$$024 = $$in;
 }
 if ((label|0) == 9) {
  HEAP32[$1>>2] = $$024;
  $$025 = $$024;
  return ($$025|0);
 }
 else if ((label|0) == 15) {
  HEAP32[$1>>2] = $$024;
  $$025 = $41;
  return ($$025|0);
 }
 else if ((label|0) == 16) {
  HEAP32[$1>>2] = $$024;
  $$025 = $$0;
  return ($$025|0);
 }
 return (0)|0;
}
function __ZN22RenderBinPrototypeListD2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 12|0);
 $2 = ((($0)) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7ref_ptrIN7osgUtil9RenderBinEEEEENS_19__map_value_compareIS7_SD_NS_4lessIS7_EELb1EEENS5_ISD_EEE7destroyEPNS_11__tree_nodeISD_PvEE($1,$3);
 __ZN3osg10ReferencedD2Ev($0);
 return;
}
function __ZN22RenderBinPrototypeListD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 12|0);
 $2 = ((($0)) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7ref_ptrIN7osgUtil9RenderBinEEEEENS_19__map_value_compareIS7_SD_NS_4lessIS7_EELb1EEENS5_ISD_EEE7destroyEPNS_11__tree_nodeISD_PvEE($1,$3);
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch_2()|0;
  $7 = tempRet0;
  __ZdlPv($0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7ref_ptrIN7osgUtil9RenderBinEEEEENS_19__map_value_compareIS7_SD_NS_4lessIS7_EELb1EEENS5_ISD_EEE4findIS7_EENS_15__tree_iteratorISD_PNS_11__tree_nodeISD_PvEEiEERKT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$ph$lcssa$i = 0, $$0$ph15$i = 0, $$07$ph14$i = 0, $$0711$i = 0, $$sroa$0$0 = 0, $$sroa$speculated$i$i$i$i$i = 0, $$sroa$speculated$i$i$i$i$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 do {
  if (!($4)) {
   $5 = ((($1)) + 11|0);
   $6 = HEAP8[$5>>0]|0;
   $7 = ($6<<24>>24)<(0);
   $8 = ((($1)) + 4|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = $6&255;
   $11 = $7 ? $9 : $10;
   $12 = HEAP32[$1>>2]|0;
   $13 = $7 ? $12 : $1;
   $$0$ph15$i = $2;$$07$ph14$i = $3;
   L3: while(1) {
    $$0711$i = $$07$ph14$i;
    while(1) {
     $14 = ((($$0711$i)) + 16|0);
     $15 = ((($14)) + 11|0);
     $16 = HEAP8[$15>>0]|0;
     $17 = ($16<<24>>24)<(0);
     $18 = ((($$0711$i)) + 20|0);
     $19 = HEAP32[$18>>2]|0;
     $20 = $16&255;
     $21 = $17 ? $19 : $20;
     $22 = ($11>>>0)<($21>>>0);
     $$sroa$speculated$i$i$i$i$i$i = $22 ? $11 : $21;
     $23 = ($$sroa$speculated$i$i$i$i$i$i|0)==(0);
     if ($23) {
      label = 6;
     } else {
      $24 = HEAP32[$14>>2]|0;
      $25 = $17 ? $24 : $14;
      $26 = (_memcmp($25,$13,$$sroa$speculated$i$i$i$i$i$i)|0);
      $27 = ($26|0)==(0);
      if ($27) {
       label = 6;
      } else {
       $29 = ($26|0)<(0);
       if (!($29)) {
        break;
       }
      }
     }
     if ((label|0) == 6) {
      label = 0;
      $28 = ($21>>>0)<($11>>>0);
      if (!($28)) {
       break;
      }
     }
     $32 = ((($$0711$i)) + 4|0);
     $33 = HEAP32[$32>>2]|0;
     $34 = ($33|0)==(0|0);
     if ($34) {
      $$0$ph$lcssa$i = $$0$ph15$i;
      break L3;
     } else {
      $$0711$i = $33;
     }
    }
    $30 = HEAP32[$$0711$i>>2]|0;
    $31 = ($30|0)==(0|0);
    if ($31) {
     $$0$ph$lcssa$i = $$0711$i;
     break;
    } else {
     $$0$ph15$i = $$0711$i;$$07$ph14$i = $30;
    }
   }
   $35 = ($$0$ph$lcssa$i|0)==($2|0);
   if (!($35)) {
    $36 = ((($$0$ph$lcssa$i)) + 16|0);
    $37 = ((($36)) + 11|0);
    $38 = HEAP8[$37>>0]|0;
    $39 = ($38<<24>>24)<(0);
    $40 = ((($$0$ph$lcssa$i)) + 20|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = $38&255;
    $43 = $39 ? $41 : $42;
    $44 = ($43>>>0)<($11>>>0);
    $$sroa$speculated$i$i$i$i$i = $44 ? $43 : $11;
    $45 = ($$sroa$speculated$i$i$i$i$i|0)==(0);
    if (!($45)) {
     $46 = HEAP32[$36>>2]|0;
     $47 = $39 ? $46 : $36;
     $48 = (_memcmp($13,$47,$$sroa$speculated$i$i$i$i$i)|0);
     $49 = ($48|0)==(0);
     if (!($49)) {
      $51 = ($48|0)<(0);
      if ($51) {
       break;
      } else {
       $$sroa$0$0 = $$0$ph$lcssa$i;
      }
      return ($$sroa$0$0|0);
     }
    }
    $50 = ($11>>>0)<($43>>>0);
    if (!($50)) {
     $$sroa$0$0 = $$0$ph$lcssa$i;
     return ($$sroa$0$0|0);
    }
   }
  }
 } while(0);
 $$sroa$0$0 = $2;
 return ($$sroa$0$0|0);
}
function __ZN7osgUtil9RenderBin15createRenderBinERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE($0) {
 $0 = $0|0;
 var $$013 = 0, $$014 = 0, $$1 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp + 8|0;
 $2 = sp;
 $3 = (__ZL22renderBinPrototypeListv()|0);
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = (__ZL22renderBinPrototypeListv()|0);
  $6 = ($5|0)==(0|0);
  if (!($6)) {
   $7 = ((($5)) + 12|0);
   $8 = (__ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7ref_ptrIN7osgUtil9RenderBinEEEEENS_19__map_value_compareIS7_SD_NS_4lessIS7_EELb1EEENS5_ISD_EEE4findIS7_EENS_15__tree_iteratorISD_PNS_11__tree_nodeISD_PvEEiEERKT_($7,$0)|0);
   $9 = ((($5)) + 16|0);
   $10 = ($8|0)==($9|0);
   if (!($10)) {
    $11 = ((($8)) + 28|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ($12|0)==(0|0);
    if (!($13)) {
     $14 = HEAP32[$12>>2]|0;
     $15 = ((($14)) + 16|0);
     $16 = HEAP32[$15>>2]|0;
     HEAP32[$2>>2] = (58136);
     $17 = ((($2)) + 4|0);
     HEAP32[$17>>2] = 2147483647;
     __THREW__ = 0;
     $18 = (invoke_iii($16|0,($12|0),($2|0))|0);
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      $23 = ___cxa_find_matching_catch_2()|0;
      $24 = tempRet0;
      $$013 = $24;$$014 = $23;
      ___resumeException($$014|0);
      // unreachable;
     }
     $21 = ($18|0)==(0|0);
     if ($21) {
      $78 = 0;
     } else {
      $22 = (___dynamic_cast($18,26112,22824,0)|0);
      $78 = $22;
     }
     $$1 = $78;
     STACKTOP = sp;return ($$1|0);
    }
   }
  }
 }
 $25 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
 do {
  if ($25) {
   $26 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
   $27 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($26,117396,20)|0);
   $28 = ((($0)) + 11|0);
   $29 = HEAP8[$28>>0]|0;
   $30 = ($29<<24>>24)<(0);
   $31 = HEAP32[$0>>2]|0;
   $32 = $30 ? $31 : $0;
   $33 = ((($0)) + 4|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = $29&255;
   $36 = $30 ? $34 : $35;
   $37 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($27,$32,$36)|0);
   $38 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($37,117417,66)|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = ((($39)) + -12|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = (($38) + ($41)|0);
   __ZNKSt3__28ios_base6getlocEv($1,$42);
   __THREW__ = 0;
   $43 = (invoke_iii(3255,($1|0),(215188|0))|0);
   $44 = __THREW__; __THREW__ = 0;
   $45 = $44&1;
   if (!($45)) {
    $46 = HEAP32[$43>>2]|0;
    $47 = ((($46)) + 28|0);
    $48 = HEAP32[$47>>2]|0;
    __THREW__ = 0;
    $49 = (invoke_iii($48|0,($43|0),10)|0);
    $50 = __THREW__; __THREW__ = 0;
    $51 = $50&1;
    if (!($51)) {
     __ZNSt3__26localeD2Ev($1);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($38,$49)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($38)|0);
     break;
    }
   }
   $52 = ___cxa_find_matching_catch_2()|0;
   $53 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($1|0));
   $54 = __THREW__; __THREW__ = 0;
   $55 = $54&1;
   if ($55) {
    $56 = ___cxa_find_matching_catch_3(0|0)|0;
    $57 = tempRet0;
    ___clang_call_terminate($56);
    // unreachable;
   } else {
    ___resumeException($52|0);
    // unreachable;
   }
  }
 } while(0);
 $58 = (__Znwj(100)|0);
 __THREW__ = 0;
 invoke_vi(3282,($58|0));
 $59 = __THREW__; __THREW__ = 0;
 $60 = $59&1;
 if ($60) {
  $76 = ___cxa_find_matching_catch_2()|0;
  $77 = tempRet0;
  __ZdlPv($58);
  $$013 = $77;$$014 = $76;
  ___resumeException($$014|0);
  // unreachable;
 } else {
  $61 = ((($58)) + 12|0);
  ;HEAP32[$61>>2]=0|0;HEAP32[$61+4>>2]=0|0;HEAP32[$61+8>>2]=0|0;
  $62 = ((($58)) + 24|0);
  HEAP32[$62>>2] = 2;
  $63 = ((($58)) + 28|0);
  HEAP32[$63>>2] = 0;
  HEAP32[$58>>2] = (53976);
  $64 = ((($58)) + 48|0);
  HEAP32[$64>>2] = 0;
  $65 = ((($58)) + 52|0);
  HEAP32[$65>>2] = 0;
  $66 = ((($58)) + 44|0);
  HEAP32[$66>>2] = $64;
  $67 = ((($58)) + 56|0);
  $68 = ((($58)) + 88|0);
  HEAP32[$68>>2] = 0;
  $69 = ((($58)) + 92|0);
  HEAP32[$69>>2] = 0;
  $70 = ((($58)) + 96|0);
  HEAP32[$70>>2] = 0;
  $71 = ((($58)) + 32|0);
  HEAP32[$71>>2] = 0;
  $72 = ((($58)) + 36|0);
  HEAP32[$72>>2] = 0;
  $73 = ((($58)) + 40|0);
  HEAP32[$73>>2] = 0;
  ;HEAP32[$67>>2]=0|0;HEAP32[$67+4>>2]=0|0;HEAP32[$67+8>>2]=0|0;HEAP32[$67+12>>2]=0|0;HEAP32[$67+16>>2]=0|0;HEAP32[$67+20>>2]=0|0;HEAP8[$67+24>>0]=0|0;
  $74 = (__ZN7osgUtil9RenderBin27getDefaultRenderBinSortModeEv()|0);
  $75 = ((($58)) + 84|0);
  HEAP32[$75>>2] = $74;
  $$1 = $58;
  STACKTOP = sp;return ($$1|0);
 }
 return (0)|0;
}
function __ZN7osgUtil9RenderBin14find_or_insertEiRKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$0$i$i = 0, $$0$ph$i$i = 0, $$0$ph$lcssa$i$i$i = 0, $$0$ph13$i$i$i = 0, $$014$i = 0, $$024$i$i = 0, $$025$i$i = 0, $$025$i53$i = 0, $$037$i = 0, $$03752$i = 0, $$07$ph12$i$i$i = 0, $$0710$i$i$i = 0, $$in$i$i = 0, $$pre$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 44|0);
 $4 = ((($0)) + 48|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $$0$ph13$i$i$i = $4;$$07$ph12$i$i$i = $5;
  L2: while(1) {
   $$0710$i$i$i = $$07$ph12$i$i$i;
   while(1) {
    $7 = ((($$0710$i$i$i)) + 16|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = ($8|0)<($1|0);
    if (!($9)) {
     break;
    }
    $12 = ((($$0710$i$i$i)) + 4|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = ($13|0)==(0|0);
    if ($14) {
     $$0$ph$lcssa$i$i$i = $$0$ph13$i$i$i;
     break L2;
    } else {
     $$0710$i$i$i = $13;
    }
   }
   $10 = HEAP32[$$0710$i$i$i>>2]|0;
   $11 = ($10|0)==(0|0);
   if ($11) {
    $$0$ph$lcssa$i$i$i = $$0710$i$i$i;
    break;
   } else {
    $$0$ph13$i$i$i = $$0710$i$i$i;$$07$ph12$i$i$i = $10;
   }
  }
  $15 = ($$0$ph$lcssa$i$i$i|0)==($4|0);
  if (!($15)) {
   $16 = ((($$0$ph$lcssa$i$i$i)) + 16|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = ($17|0)>($1|0);
   if (!($18)) {
    $19 = ((($$0$ph$lcssa$i$i$i)) + 20|0);
    $20 = HEAP32[$19>>2]|0;
    $$0 = $20;
    return ($$0|0);
   }
  }
 }
 $21 = (__ZN7osgUtil9RenderBin15createRenderBinERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE($2)|0);
 $22 = ($21|0)==(0|0);
 if ($22) {
  $$0 = 0;
  return ($$0|0);
 }
 $23 = (___dynamic_cast($21,22824,22912,0)|0);
 $24 = ($23|0)==(0|0);
 if (!($24)) {
  $25 = ((($23)) + 32|0);
  HEAP32[$25>>2] = $1;
  $26 = ((($23)) + 36|0);
  HEAP32[$26>>2] = 0;
  $27 = ((($23)) + 40|0);
  HEAP32[$27>>2] = $23;
  $28 = ((($0)) + 40|0);
  $29 = HEAP32[$28>>2]|0;
  __ZN7osgUtil11RenderStage17addPreRenderStageEPS0_i($29,$23,0);
  $$0 = $21;
  return ($$0|0);
 }
 $30 = ((($21)) + 32|0);
 HEAP32[$30>>2] = $1;
 $31 = ((($21)) + 36|0);
 HEAP32[$31>>2] = $0;
 $32 = ((($0)) + 40|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ((($21)) + 40|0);
 HEAP32[$34>>2] = $33;
 $35 = HEAP32[$4>>2]|0;
 $36 = ($35|0)==(0|0);
 do {
  if ($36) {
   $$025$i$i = $4;$$037$i = $4;$47 = $35;
   label = 23;
  } else {
   $37 = ((($0)) + 48|0);
   $$0$i$i = $37;$$024$i$i = $35;$73 = $35;
   while(1) {
    $38 = ((($$024$i$i)) + 16|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = ($39|0)>($1|0);
    if ($40) {
     $41 = HEAP32[$$024$i$i>>2]|0;
     $42 = ($41|0)==(0|0);
     if ($42) {
      label = 17;
      break;
     } else {
      $$0$ph$i$i = $$024$i$i;$$in$i$i = $41;
     }
    } else {
     $43 = ($39|0)<($1|0);
     if (!($43)) {
      label = 21;
      break;
     }
     $44 = ((($$024$i$i)) + 4|0);
     $45 = HEAP32[$44>>2]|0;
     $46 = ($45|0)==(0|0);
     if ($46) {
      label = 20;
      break;
     } else {
      $$0$ph$i$i = $44;$$in$i$i = $45;
     }
    }
    $$0$i$i = $$0$ph$i$i;$$024$i$i = $$in$i$i;$73 = $$in$i$i;
   }
   if ((label|0) == 17) {
    $$025$i53$i = $$024$i$i;$$03752$i = $$024$i$i;
    label = 24;
    break;
   }
   else if ((label|0) == 20) {
    $$025$i53$i = $44;$$03752$i = $$024$i$i;
    label = 24;
    break;
   }
   else if ((label|0) == 21) {
    $$025$i$i = $$0$i$i;$$037$i = $$024$i$i;$47 = $73;
    label = 23;
    break;
   }
  }
 } while(0);
 if ((label|0) == 23) {
  $48 = ($47|0)==(0|0);
  if ($48) {
   $$025$i53$i = $$025$i$i;$$03752$i = $$037$i;
   label = 24;
  } else {
   $$014$i = $47;
  }
 }
 if ((label|0) == 24) {
  $49 = (__Znwj(24)|0);
  $50 = ((($49)) + 16|0);
  HEAP32[$50>>2] = $1;
  $51 = ((($49)) + 20|0);
  HEAP32[$51>>2] = 0;
  HEAP32[$49>>2] = 0;
  $52 = ((($49)) + 4|0);
  HEAP32[$52>>2] = 0;
  $53 = ((($49)) + 8|0);
  HEAP32[$53>>2] = $$03752$i;
  HEAP32[$$025$i53$i>>2] = $49;
  $54 = HEAP32[$3>>2]|0;
  $55 = HEAP32[$54>>2]|0;
  $56 = ($55|0)==(0|0);
  if ($56) {
   $60 = $49;
  } else {
   $57 = $55;
   HEAP32[$3>>2] = $57;
   $$pre$i$i = HEAP32[$$025$i53$i>>2]|0;
   $60 = $$pre$i$i;
  }
  $58 = ((($0)) + 48|0);
  $59 = HEAP32[$58>>2]|0;
  __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($59,$60);
  $61 = ((($0)) + 52|0);
  $62 = HEAP32[$61>>2]|0;
  $63 = (($62) + 1)|0;
  HEAP32[$61>>2] = $63;
  $$014$i = $49;
 }
 $64 = ((($$014$i)) + 20|0);
 $65 = HEAP32[$64>>2]|0;
 $66 = ($65|0)==($21|0);
 if ($66) {
  $$0 = $21;
  return ($$0|0);
 }
 HEAP32[$64>>2] = $21;
 $67 = ((($21)) + 8|0);
 $68 = HEAP32[$67>>2]|0;HEAP32[$67>>2] = (($68+1)|0);
 $69 = ($65|0)==(0|0);
 if ($69) {
  $$0 = $21;
  return ($$0|0);
 }
 $70 = ((($65)) + 8|0);
 $71 = HEAP32[$70>>2]|0;HEAP32[$70>>2] = (($71-1)|0);
 $72 = ($71|0)==(1);
 if (!($72)) {
  $$0 = $21;
  return ($$0|0);
 }
 __ZNK3osg10Referenced24signalObserversAndDeleteEbb($65,1,1);
 $$0 = $21;
 return ($$0|0);
}
function __ZNK7osgUtil9RenderBin8getStatsERNS_10StatisticsE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$$2$off0 = 0, $$0$i$i$i$i = 0, $$0$off0$lcssa = 0, $$1$off0$lcssa = 0, $$2$off0$lcssa = 0, $$2$off064 = 0, $$pre = 0, $$sink65 = 0, $$sroa$038$0$be = 0, $$sroa$038$063 = 0, $$sroa$052$067 = 0, $$sroa$059$072 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 1)|0;
 HEAP32[$2>>2] = $4;
 $5 = ((($0)) + 68|0);
 $6 = ((($0)) + 72|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$5>>2]|0;
 $9 = (($7) - ($8))|0;
 $10 = $9 >> 2;
 $11 = ((($1)) + 44|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($10) + ($12))|0;
 HEAP32[$11>>2] = $13;
 $14 = $8;
 $15 = $7;
 $16 = ($14|0)==($15|0);
 if ($16) {
  $$0$off0$lcssa = 0;
 } else {
  $17 = ((($1)) + 4|0);
  $18 = ((($1)) + 8|0);
  $19 = ((($1)) + 20|0);
  $$sroa$059$072 = $14;
  while(1) {
   $35 = HEAP32[$$sroa$059$072>>2]|0;
   $36 = ((($35)) + 16|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = HEAP32[$17>>2]|0;
   $39 = (($38) + 1)|0;
   HEAP32[$17>>2] = $39;
   $40 = HEAP32[$37>>2]|0;
   $41 = ((($40)) + 144|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = (FUNCTION_TABLE_ii[$42 & 8191]($37)|0);
   $44 = ($43|0)==(0|0);
   if (!($44)) {
    $45 = HEAP32[$19>>2]|0;
    $46 = (($45) + 1)|0;
    HEAP32[$19>>2] = $46;
   }
   $47 = ((($35)) + 24|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = ($48|0)==(0|0);
   if (!($49)) {
    $50 = HEAP32[$18>>2]|0;
    $51 = (($50) + 1)|0;
    HEAP32[$18>>2] = $51;
   }
   $52 = HEAP32[$37>>2]|0;
   $53 = ((($52)) + 264|0);
   $54 = HEAP32[$53>>2]|0;
   FUNCTION_TABLE_vii[$54 & 8191]($37,$1);
   $55 = ((($$sroa$059$072)) + 4|0);
   $56 = HEAP32[$6>>2]|0;
   $57 = ($55|0)==($56|0);
   if ($57) {
    $$0$off0$lcssa = 1;
    break;
   } else {
    $$sroa$059$072 = $55;
   }
  }
 }
 $20 = ((($0)) + 56|0);
 $21 = ((($0)) + 60|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = HEAP32[$20>>2]|0;
 $24 = (($22) - ($23))|0;
 $25 = $24 >> 2;
 $26 = ((($1)) + 16|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (($25) + ($27))|0;
 HEAP32[$26>>2] = $28;
 $29 = $23;
 $30 = $22;
 $31 = ($29|0)==($30|0);
 if ($31) {
  $$1$off0$lcssa = $$0$off0$lcssa;
 } else {
  $32 = ((($1)) + 4|0);
  $33 = ((($1)) + 8|0);
  $34 = ((($1)) + 20|0);
  $$sroa$052$067 = $29;$115 = $30;
  while(1) {
   $62 = HEAP32[$$sroa$052$067>>2]|0;
   $63 = ((($62)) + 36|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = ((($62)) + 40|0);
   $66 = HEAP32[$65>>2]|0;
   $67 = ($64|0)==($66|0);
   if ($67) {
    $70 = $115;
   } else {
    $$sink65 = $64;
    while(1) {
     $71 = HEAP32[$$sink65>>2]|0;
     $72 = ((($71)) + 16|0);
     $73 = HEAP32[$72>>2]|0;
     $74 = HEAP32[$32>>2]|0;
     $75 = (($74) + 1)|0;
     HEAP32[$32>>2] = $75;
     $76 = HEAP32[$73>>2]|0;
     $77 = ((($76)) + 144|0);
     $78 = HEAP32[$77>>2]|0;
     $79 = (FUNCTION_TABLE_ii[$78 & 8191]($73)|0);
     $80 = ($79|0)==(0|0);
     if (!($80)) {
      $81 = HEAP32[$34>>2]|0;
      $82 = (($81) + 1)|0;
      HEAP32[$34>>2] = $82;
     }
     $83 = ((($71)) + 24|0);
     $84 = HEAP32[$83>>2]|0;
     $85 = ($84|0)==(0|0);
     if (!($85)) {
      $86 = HEAP32[$33>>2]|0;
      $87 = (($86) + 1)|0;
      HEAP32[$33>>2] = $87;
     }
     $88 = HEAP32[$73>>2]|0;
     $89 = ((($88)) + 264|0);
     $90 = HEAP32[$89>>2]|0;
     FUNCTION_TABLE_vii[$90 & 8191]($73,$1);
     $91 = ((($$sink65)) + 4|0);
     $92 = HEAP32[$$sroa$052$067>>2]|0;
     $93 = ((($92)) + 40|0);
     $94 = HEAP32[$93>>2]|0;
     $95 = ($91|0)==($94|0);
     if ($95) {
      break;
     } else {
      $$sink65 = $91;
     }
    }
    $$pre = HEAP32[$21>>2]|0;
    $70 = $$pre;
   }
   $68 = ((($$sroa$052$067)) + 4|0);
   $69 = ($68|0)==($70|0);
   if ($69) {
    $$1$off0$lcssa = 1;
    break;
   } else {
    $$sroa$052$067 = $68;$115 = $70;
   }
  }
 }
 $58 = ((($0)) + 44|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = ((($0)) + 48|0);
 $61 = ($59|0)==($60|0);
 if ($61) {
  $$2$off0$lcssa = $$1$off0$lcssa;
  return ($$2$off0$lcssa|0);
 } else {
  $$2$off064 = $$1$off0$lcssa;$$sroa$038$063 = $59;
 }
 while(1) {
  $96 = ((($$sroa$038$063)) + 20|0);
  $97 = HEAP32[$96>>2]|0;
  $98 = (__ZNK7osgUtil9RenderBin8getStatsERNS_10StatisticsE($97,$1)|0);
  $$$2$off0 = $$2$off064 | $98;
  $99 = ((($$sroa$038$063)) + 4|0);
  $100 = HEAP32[$99>>2]|0;
  $101 = ($100|0)==(0|0);
  if ($101) {
   $102 = ((($$sroa$038$063)) + 8|0);
   $103 = HEAP32[$102>>2]|0;
   $104 = HEAP32[$103>>2]|0;
   $105 = ($104|0)==($$sroa$038$063|0);
   if ($105) {
    $$sroa$038$0$be = $103;
   } else {
    $110 = $102;
    while(1) {
     $109 = HEAP32[$110>>2]|0;
     $111 = ((($109)) + 8|0);
     $112 = HEAP32[$111>>2]|0;
     $113 = HEAP32[$112>>2]|0;
     $114 = ($113|0)==($109|0);
     if ($114) {
      $$sroa$038$0$be = $112;
      break;
     } else {
      $110 = $111;
     }
    }
   }
  } else {
   $$0$i$i$i$i = $100;
   while(1) {
    $107 = HEAP32[$$0$i$i$i$i>>2]|0;
    $108 = ($107|0)==(0|0);
    if ($108) {
     break;
    } else {
     $$0$i$i$i$i = $107;
    }
   }
   $$sroa$038$0$be = $$0$i$i$i$i;
  }
  $106 = ($$sroa$038$0$be|0)==($60|0);
  if ($106) {
   $$2$off0$lcssa = $$$2$off0;
   break;
  } else {
   $$2$off064 = $$$2$off0;$$sroa$038$063 = $$sroa$038$0$be;
  }
 }
 return ($$2$off0$lcssa|0);
}
function __ZN7osgUtil10RenderLeafD2Ev($0) {
 $0 = $0|0;
 var $$0 = 0, $$02 = 0, $$1 = 0, $$13 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (54188);
 $1 = ((($0)) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  label = 4;
 } else {
  $4 = ((($2)) + 8|0);
  $5 = HEAP32[$4>>2]|0;HEAP32[$4>>2] = (($5-1)|0);
  $6 = ($5|0)==(1);
  if ($6) {
   __THREW__ = 0;
   invoke_viii(3262,($2|0),1,1);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $25 = ___cxa_find_matching_catch_2()|0;
    $26 = tempRet0;
    $27 = ((($0)) + 20|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = ($28|0)==(0|0);
    if (!($29)) {
     $30 = ((($28)) + 8|0);
     $31 = HEAP32[$30>>2]|0;HEAP32[$30>>2] = (($31-1)|0);
     $32 = ($31|0)==(1);
     if ($32) {
      __THREW__ = 0;
      invoke_viii(3262,($28|0),1,1);
      $33 = __THREW__; __THREW__ = 0;
      $34 = $33&1;
      if ($34) {
       $49 = ___cxa_find_matching_catch_3(0|0)|0;
       $50 = tempRet0;
       ___clang_call_terminate($49);
       // unreachable;
      }
     }
    }
    HEAP32[$27>>2] = 0;
    $$0 = $26;$$02 = $25;
    label = 17;
   } else {
    label = 4;
   }
  } else {
   label = 4;
  }
 }
 do {
  if ((label|0) == 4) {
   HEAP32[$1>>2] = 0;
   $9 = ((($0)) + 20|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($10|0)==(0|0);
   if (!($11)) {
    $12 = ((($10)) + 8|0);
    $13 = HEAP32[$12>>2]|0;HEAP32[$12>>2] = (($13-1)|0);
    $14 = ($13|0)==(1);
    if ($14) {
     __THREW__ = 0;
     invoke_viii(3262,($10|0),1,1);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      $35 = ___cxa_find_matching_catch_2()|0;
      $36 = tempRet0;
      $$0 = $36;$$02 = $35;
      label = 17;
      break;
     }
    }
   }
   HEAP32[$9>>2] = 0;
   $17 = ((($0)) + 16|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = ($18|0)==(0|0);
   if ($19) {
    HEAP32[$17>>2] = 0;
    __ZN3osg10ReferencedD2Ev($0);
    return;
   }
   $20 = ((($18)) + 8|0);
   $21 = HEAP32[$20>>2]|0;HEAP32[$20>>2] = (($21-1)|0);
   $22 = ($21|0)==(1);
   if (!($22)) {
    HEAP32[$17>>2] = 0;
    __ZN3osg10ReferencedD2Ev($0);
    return;
   }
   __THREW__ = 0;
   invoke_viii(3262,($18|0),1,1);
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if ($24) {
    $37 = ___cxa_find_matching_catch_2()|0;
    $38 = tempRet0;
    $$1 = $38;$$13 = $37;
    break;
   } else {
    HEAP32[$17>>2] = 0;
    __ZN3osg10ReferencedD2Ev($0);
    return;
   }
  }
 } while(0);
 if ((label|0) == 17) {
  $39 = ((($0)) + 16|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = ($40|0)==(0|0);
  if (!($41)) {
   $42 = ((($40)) + 8|0);
   $43 = HEAP32[$42>>2]|0;HEAP32[$42>>2] = (($43-1)|0);
   $44 = ($43|0)==(1);
   if ($44) {
    __THREW__ = 0;
    invoke_viii(3262,($40|0),1,1);
    $45 = __THREW__; __THREW__ = 0;
    $46 = $45&1;
    if ($46) {
     $49 = ___cxa_find_matching_catch_3(0|0)|0;
     $50 = tempRet0;
     ___clang_call_terminate($49);
     // unreachable;
    }
   }
  }
  HEAP32[$39>>2] = 0;
  $$1 = $$0;$$13 = $$02;
 }
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $47 = __THREW__; __THREW__ = 0;
 $48 = $47&1;
 if ($48) {
  $49 = ___cxa_find_matching_catch_3(0|0)|0;
  $50 = tempRet0;
  ___clang_call_terminate($49);
  // unreachable;
 } else {
  ___resumeException($$13|0);
  // unreachable;
 }
}
function __ZN7osgUtil10RenderLeafD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1406,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZN7osgUtil10RenderLeaf6renderERN3osg10RenderInfoEPS0_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = HEAP32[$1>>2]|0;
 $4 = ((($3)) + 340|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = HEAP8[$5>>0]|0;
  $8 = ($7<<24>>24)==(0);
  if (!($8)) {
   return;
  }
 }
 $9 = ($2|0)==(0|0);
 $10 = ((($0)) + 20|0);
 $11 = HEAP32[$10>>2]|0;
 __ZN3osg5State21applyProjectionMatrixEPKNS_10RefMatrixdE($3,$11);
 $12 = ((($0)) + 24|0);
 $13 = HEAP32[$12>>2]|0;
 __ZN3osg5State20applyModelViewMatrixEPKNS_10RefMatrixdE($3,$13);
 $14 = ((($0)) + 12|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ((($15)) + 12|0);
 $17 = HEAP32[$16>>2]|0;
 if ($9) {
  __ZN7osgUtil10StateGraph14moveStateGraphERN3osg5StateEPS0_S4_($3,0,$17);
  $33 = HEAP32[$14>>2]|0;
  $34 = ((($33)) + 16|0);
  $35 = HEAP32[$34>>2]|0;
  __ZN3osg5State5applyEPKNS_8StateSetE($3,$35);
  $36 = ((($3)) + 184|0);
  $37 = HEAP8[$36>>0]|0;
  $38 = ($37<<24>>24)==(0);
  if (!($38)) {
   __ZN3osg5State45applyModelViewAndProjectionUniformsIfRequiredEv($3);
  }
  $39 = ((($0)) + 16|0);
  $40 = HEAP32[$39>>2]|0;
  __ZNK3osg8Drawable4drawERNS_10RenderInfoE($40,$1);
 } else {
  $18 = ((($2)) + 12|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = ((($19)) + 12|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = ($21|0)==($17|0);
  if ($22) {
   $25 = ($15|0)==($19|0);
   if (!($25)) {
    $26 = ((($15)) + 16|0);
    $27 = HEAP32[$26>>2]|0;
    __ZN3osg5State5applyEPKNS_8StateSetE($3,$27);
   }
  } else {
   __ZN7osgUtil10StateGraph14moveStateGraphERN3osg5StateEPS0_S4_($3,$21,$17);
   $23 = ((($15)) + 16|0);
   $24 = HEAP32[$23>>2]|0;
   __ZN3osg5State5applyEPKNS_8StateSetE($3,$24);
  }
  $28 = ((($3)) + 184|0);
  $29 = HEAP8[$28>>0]|0;
  $30 = ($29<<24>>24)==(0);
  if (!($30)) {
   __ZN3osg5State45applyModelViewAndProjectionUniformsIfRequiredEv($3);
  }
  $31 = ((($0)) + 16|0);
  $32 = HEAP32[$31>>2]|0;
  __ZNK3osg8Drawable4drawERNS_10RenderInfoE($32,$1);
 }
 $41 = ((($0)) + 32|0);
 $42 = HEAP8[$41>>0]|0;
 $43 = ($42<<24>>24)==(0);
 if ($43) {
  return;
 }
 $44 = ((($3)) + 788|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = (($45) + -1)|0;
 HEAP32[$44>>2] = $46;
 $47 = ($46|0)==(0);
 if (!($47)) {
  return;
 }
 $48 = ((($3)) + 792|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = ($49|0)==(0|0);
 if ($50) {
  return;
 }
 $51 = HEAP32[$49>>2]|0;
 $52 = ((($51)) + 12|0);
 $53 = HEAP32[$52>>2]|0;
 FUNCTION_TABLE_vii[$53 & 8191]($49,$3);
 return;
}
function __ZN7osgUtil10StateGraph14moveStateGraphERN3osg5StateEPS0_S4_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$lcssa = 0, $$0102 = 0, $$198 = 0, $$4 = 0, $$434 = 0, $$cast = 0, $$cast106 = 0, $$in = 0, $$in121 = 0, $$lcssa = 0, $$pre = 0, $$pre109 = 0, $$pre111 = 0, $$pre113 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0;
 var $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0;
 var $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i35 = 0, $scevgep$i$i$i46 = 0, $scevgep$i$i$i53 = 0, $scevgep5$i$i$i = 0, $scevgep5$i$i$i36 = 0, $scevgep5$i$i$i47 = 0, $scevgep5$i$i$i54 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $3 = sp + 24|0;
 $4 = sp + 12|0;
 $5 = sp;
 HEAP32[$3>>2] = $2;
 $6 = ($2|0)==($1|0);
 $7 = ($2|0)==(0|0);
 $or$cond = $6 | $7;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 $8 = ($1|0)==(0|0);
 if ($8) {
  HEAP32[$4>>2] = 0;
  $9 = ((($4)) + 4|0);
  HEAP32[$9>>2] = 0;
  $10 = ((($4)) + 8|0);
  HEAP32[$10>>2] = 0;
  $11 = ((($2)) + 20|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($12) + 1)|0;
  __THREW__ = 0;
  invoke_vii(3667,($4|0),($13|0));
  $14 = __THREW__; __THREW__ = 0;
  $15 = $14&1;
  L6: do {
   if (!($15)) {
    $16 = ((($4)) + 8|0);
    while(1) {
     $17 = HEAP32[$9>>2]|0;
     $18 = HEAP32[$16>>2]|0;
     $19 = ($17|0)==($18|0);
     if ($19) {
      __THREW__ = 0;
      invoke_vii(3668,($4|0),($3|0));
      $23 = __THREW__; __THREW__ = 0;
      $24 = $23&1;
      if ($24) {
       break L6;
      }
     } else {
      $20 = HEAP32[$3>>2]|0;
      HEAP32[$17>>2] = $20;
      $21 = HEAP32[$9>>2]|0;
      $22 = ((($21)) + 4|0);
      HEAP32[$9>>2] = $22;
     }
     $25 = HEAP32[$3>>2]|0;
     $26 = ((($25)) + 12|0);
     $27 = HEAP32[$26>>2]|0;
     HEAP32[$3>>2] = $27;
     $28 = ($27|0)==(0|0);
     if ($28) {
      break;
     }
    }
    $29 = HEAP32[$9>>2]|0;
    $30 = HEAP32[$4>>2]|0;
    $31 = ($29|0)==($30|0);
    if ($31) {
     $32 = ($29|0)==(0|0);
     if (!($32)) {
      $$in121 = $29;
      label = 11;
     }
    } else {
     $168 = $30;$41 = $29;
     while(1) {
      $40 = ((($41)) + -4|0);
      $42 = HEAP32[$40>>2]|0;
      $43 = ((($42)) + 16|0);
      $44 = HEAP32[$43>>2]|0;
      $45 = ($44|0)==(0|0);
      if ($45) {
       $49 = $168;
      } else {
       __THREW__ = 0;
       invoke_vii(3669,($0|0),($44|0));
       $46 = __THREW__; __THREW__ = 0;
       $47 = $46&1;
       if ($47) {
        break L6;
       }
       $$pre113 = HEAP32[$4>>2]|0;
       $49 = $$pre113;
      }
      $48 = ($40|0)==($49|0);
      if ($48) {
       $$in121 = $40;
       label = 11;
       break;
      } else {
       $168 = $49;$41 = $40;
      }
     }
    }
    if ((label|0) == 11) {
     $33 = HEAP32[$9>>2]|0;
     $34 = ($33|0)==($$in121|0);
     if (!($34)) {
      $scevgep$i$i$i46 = ((($33)) + -4|0);
      $35 = $scevgep$i$i$i46;
      $36 = $$in121;
      $37 = (($35) - ($36))|0;
      $38 = $37 >>> 2;
      $39 = $38 ^ -1;
      $scevgep5$i$i$i47 = (($33) + ($39<<2)|0);
      HEAP32[$9>>2] = $scevgep5$i$i$i47;
     }
     __ZdlPv($$in121);
    }
    STACKTOP = sp;return;
   }
  } while(0);
  $50 = ___cxa_find_matching_catch_2()|0;
  $51 = tempRet0;
  $52 = HEAP32[$4>>2]|0;
  $53 = ($52|0)==(0|0);
  if (!($53)) {
   $54 = HEAP32[$9>>2]|0;
   $55 = ($54|0)==($52|0);
   if (!($55)) {
    $scevgep$i$i$i53 = ((($54)) + -4|0);
    $56 = $scevgep$i$i$i53;
    $57 = $52;
    $58 = (($56) - ($57))|0;
    $59 = $58 >>> 2;
    $60 = $59 ^ -1;
    $scevgep5$i$i$i54 = (($54) + ($60<<2)|0);
    HEAP32[$9>>2] = $scevgep5$i$i$i54;
   }
   __ZdlPv($52);
  }
  $$4 = $50;$$434 = $51;
  ___resumeException($$4|0);
  // unreachable;
 }
 $61 = ((($1)) + 12|0);
 $62 = HEAP32[$61>>2]|0;
 $63 = ((($2)) + 12|0);
 $64 = HEAP32[$63>>2]|0;
 $65 = ($62|0)==($64|0);
 if ($65) {
  $71 = ((($1)) + 16|0);
  $72 = HEAP32[$71>>2]|0;
  $73 = ($72|0)==(0|0);
  if (!($73)) {
   __ZN3osg5State11popStateSetEv($0);
  }
  $74 = ((($2)) + 16|0);
  $75 = HEAP32[$74>>2]|0;
  $76 = ($75|0)==(0|0);
  if ($76) {
   STACKTOP = sp;return;
  }
  __ZN3osg5State12pushStateSetEPKNS_8StateSetE($0,$75);
  STACKTOP = sp;return;
 }
 $66 = ((($1)) + 20|0);
 $67 = HEAP32[$66>>2]|0;
 $68 = ((($2)) + 20|0);
 $69 = HEAP32[$68>>2]|0;
 $70 = ($67|0)>($69|0);
 if ($70) {
  $$0102 = $1;$169 = $69;
  while(1) {
   $77 = ((($$0102)) + 16|0);
   $78 = HEAP32[$77>>2]|0;
   $79 = ($78|0)==(0|0);
   if ($79) {
    $85 = $169;
   } else {
    __ZN3osg5State11popStateSetEv($0);
    $$pre = HEAP32[$68>>2]|0;
    $85 = $$pre;
   }
   $80 = ((($$0102)) + 12|0);
   $81 = HEAP32[$80>>2]|0;
   $82 = ((($81)) + 20|0);
   $83 = HEAP32[$82>>2]|0;
   $84 = ($83|0)>($85|0);
   if ($84) {
    $$0102 = $81;$169 = $85;
   } else {
    $$0$lcssa = $81;$$lcssa = $82;$89 = $85;
    break;
   }
  }
 } else {
  $$0$lcssa = $1;$$lcssa = $66;$89 = $69;
 }
 HEAP32[$5>>2] = 0;
 $86 = ((($5)) + 4|0);
 HEAP32[$86>>2] = 0;
 $87 = ((($5)) + 8|0);
 HEAP32[$87>>2] = 0;
 $88 = (($89) + 1)|0;
 __THREW__ = 0;
 invoke_vii(3667,($5|0),($88|0));
 $90 = __THREW__; __THREW__ = 0;
 $91 = $90&1;
 L56: do {
  if (!($91)) {
   $92 = HEAP32[$3>>2]|0;
   $93 = ((($92)) + 20|0);
   $94 = HEAP32[$93>>2]|0;
   $95 = HEAP32[$$lcssa>>2]|0;
   $96 = ($94|0)>($95|0);
   if ($96) {
    $97 = $92;
    $98 = ((($5)) + 8|0);
    $105 = $97;$170 = $95;
    while(1) {
     $102 = HEAP32[$86>>2]|0;
     $103 = HEAP32[$98>>2]|0;
     $104 = ($102|0)==($103|0);
     if ($104) {
      __THREW__ = 0;
      invoke_vii(3668,($5|0),($3|0));
      $108 = __THREW__; __THREW__ = 0;
      $109 = $108&1;
      if ($109) {
       break L56;
      }
      $$pre109 = HEAP32[$$lcssa>>2]|0;
      $116 = $$pre109;
     } else {
      HEAP32[$102>>2] = $105;
      $106 = HEAP32[$86>>2]|0;
      $107 = ((($106)) + 4|0);
      HEAP32[$86>>2] = $107;
      $116 = $170;
     }
     $110 = HEAP32[$3>>2]|0;
     $111 = ((($110)) + 12|0);
     $112 = HEAP32[$111>>2]|0;
     HEAP32[$3>>2] = $112;
     $$cast106 = $112;
     $113 = ((($$cast106)) + 20|0);
     $114 = HEAP32[$113>>2]|0;
     $115 = ($114|0)>($116|0);
     if ($115) {
      $105 = $112;$170 = $116;
     } else {
      $100 = $$cast106;
      break;
     }
    }
   } else {
    $100 = $92;
   }
   $99 = ($$0$lcssa|0)==($100|0);
   if (!($99)) {
    $101 = ((($5)) + 8|0);
    $$198 = $$0$lcssa;
    while(1) {
     $117 = ((($$198)) + 16|0);
     $118 = HEAP32[$117>>2]|0;
     $119 = ($118|0)==(0|0);
     if (!($119)) {
      __THREW__ = 0;
      invoke_vi(3670,($0|0));
      $120 = __THREW__; __THREW__ = 0;
      $121 = $120&1;
      if ($121) {
       break L56;
      }
     }
     $122 = ((($$198)) + 12|0);
     $123 = HEAP32[$122>>2]|0;
     $124 = HEAP32[$86>>2]|0;
     $125 = HEAP32[$101>>2]|0;
     $126 = ($124|0)==($125|0);
     if ($126) {
      __THREW__ = 0;
      invoke_vii(3668,($5|0),($3|0));
      $130 = __THREW__; __THREW__ = 0;
      $131 = $130&1;
      if ($131) {
       break L56;
      }
     } else {
      $127 = HEAP32[$3>>2]|0;
      HEAP32[$124>>2] = $127;
      $128 = HEAP32[$86>>2]|0;
      $129 = ((($128)) + 4|0);
      HEAP32[$86>>2] = $129;
     }
     $132 = HEAP32[$3>>2]|0;
     $133 = ((($132)) + 12|0);
     $134 = HEAP32[$133>>2]|0;
     HEAP32[$3>>2] = $134;
     $$cast = $134;
     $135 = ($123|0)==($$cast|0);
     if ($135) {
      break;
     } else {
      $$198 = $123;
     }
    }
   }
   $136 = HEAP32[$86>>2]|0;
   $137 = HEAP32[$5>>2]|0;
   $138 = ($136|0)==($137|0);
   if ($138) {
    $139 = ($136|0)==(0|0);
    if (!($139)) {
     $$in = $136;
     label = 51;
    }
   } else {
    $148 = $136;$171 = $137;
    while(1) {
     $147 = ((($148)) + -4|0);
     $149 = HEAP32[$147>>2]|0;
     $150 = ((($149)) + 16|0);
     $151 = HEAP32[$150>>2]|0;
     $152 = ($151|0)==(0|0);
     if ($152) {
      $156 = $171;
     } else {
      __THREW__ = 0;
      invoke_vii(3669,($0|0),($151|0));
      $153 = __THREW__; __THREW__ = 0;
      $154 = $153&1;
      if ($154) {
       break L56;
      }
      $$pre111 = HEAP32[$5>>2]|0;
      $156 = $$pre111;
     }
     $155 = ($147|0)==($156|0);
     if ($155) {
      $$in = $147;
      label = 51;
      break;
     } else {
      $148 = $147;$171 = $156;
     }
    }
   }
   if ((label|0) == 51) {
    $140 = HEAP32[$86>>2]|0;
    $141 = ($140|0)==($$in|0);
    if (!($141)) {
     $scevgep$i$i$i35 = ((($140)) + -4|0);
     $142 = $scevgep$i$i$i35;
     $143 = $$in;
     $144 = (($142) - ($143))|0;
     $145 = $144 >>> 2;
     $146 = $145 ^ -1;
     $scevgep5$i$i$i36 = (($140) + ($146<<2)|0);
     HEAP32[$86>>2] = $scevgep5$i$i$i36;
    }
    __ZdlPv($$in);
   }
   STACKTOP = sp;return;
  }
 } while(0);
 $157 = ___cxa_find_matching_catch_2()|0;
 $158 = tempRet0;
 $159 = HEAP32[$5>>2]|0;
 $160 = ($159|0)==(0|0);
 if (!($160)) {
  $161 = HEAP32[$86>>2]|0;
  $162 = ($161|0)==($159|0);
  if (!($162)) {
   $scevgep$i$i$i = ((($161)) + -4|0);
   $163 = $scevgep$i$i$i;
   $164 = $159;
   $165 = (($163) - ($164))|0;
   $166 = $165 >>> 2;
   $167 = $166 ^ -1;
   $scevgep5$i$i$i = (($161) + ($167<<2)|0);
   HEAP32[$86>>2] = $scevgep5$i$i$i;
  }
  __ZdlPv($159);
 }
 $$4 = $157;$$434 = $158;
 ___resumeException($$4|0);
 // unreachable;
}
function __ZNSt3__26vectorIPN7osgUtil10StateGraphENS_9allocatorIS3_EEE7reserveEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 $7 = ($6>>>0)<($1>>>0);
 if (!($7)) {
  return;
 }
 $8 = ((($0)) + 4|0);
 $9 = ($1>>>0)>(1073741823);
 if ($9) {
  $10 = (___cxa_allocate_exception(8)|0);
  __THREW__ = 0;
  invoke_vii(3366,($10|0),(204840|0));
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if ($12) {
   $13 = ___cxa_find_matching_catch_2()|0;
   $14 = tempRet0;
   ___cxa_free_exception(($10|0));
   ___resumeException($13|0);
   // unreachable;
  } else {
   HEAP32[$10>>2] = (99824);
   ___cxa_throw(($10|0),(34608|0),(3230|0));
   // unreachable;
  }
 }
 $15 = HEAP32[$8>>2]|0;
 $16 = (($15) - ($4))|0;
 $17 = $16 >> 2;
 $18 = $1 << 2;
 $19 = (__Znwj($18)|0);
 $20 = (($19) + ($17<<2)|0);
 $21 = $20;
 $22 = (($19) + ($1<<2)|0);
 $23 = $22;
 $24 = (0 - ($17))|0;
 $25 = (($20) + ($24<<2)|0);
 $26 = $25;
 $27 = ($16|0)>(0);
 if ($27) {
  $28 = $4;
  _memcpy(($25|0),($28|0),($16|0))|0;
 }
 HEAP32[$0>>2] = $26;
 HEAP32[$8>>2] = $21;
 HEAP32[$2>>2] = $23;
 $29 = ($4|0)==(0);
 if ($29) {
  return;
 }
 $30 = $4;
 __ZdlPv($30);
 return;
}
function __ZN7osgUtil11RenderStageD2Ev($0) {
 $0 = $0|0;
 var $$0 = 0, $$02 = 0, $$023$i$i = 0, $$023$i$i29 = 0, $$023$i$i59 = 0, $$023$i$i62 = 0, $$1 = 0, $$10 = 0, $$1013 = 0, $$14 = 0, $$2 = 0, $$25 = 0, $$3 = 0, $$36 = 0, $$5 = 0, $$58 = 0, $$6 = 0, $$69 = 0, $$7 = 0, $$710 = 0;
 var $$8 = 0, $$811 = 0, $$9 = 0, $$912 = 0, $$pre$i = 0, $$pre$i55 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0;
 var $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0;
 var $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0;
 var $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0;
 var $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0;
 var $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0;
 var $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0;
 var $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0;
 var $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (54212);
 $1 = ((($0)) + 420|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  label = 4;
 } else {
  $4 = ((($2)) + 8|0);
  $5 = HEAP32[$4>>2]|0;HEAP32[$4>>2] = (($5-1)|0);
  $6 = ($5|0)==(1);
  if ($6) {
   __THREW__ = 0;
   invoke_viii(3262,($2|0),1,1);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $164 = ___cxa_find_matching_catch_2()|0;
    $165 = tempRet0;
    $166 = ((($0)) + 416|0);
    $167 = HEAP32[$166>>2]|0;
    $168 = ($167|0)==(0|0);
    if (!($168)) {
     $169 = ((($167)) + 8|0);
     $170 = HEAP32[$169>>2]|0;HEAP32[$169>>2] = (($170-1)|0);
     $171 = ($170|0)==(1);
     if ($171) {
      __THREW__ = 0;
      invoke_viii(3262,($167|0),1,1);
      $172 = __THREW__; __THREW__ = 0;
      $173 = $172&1;
      if ($173) {
       $343 = ___cxa_find_matching_catch_3(0|0)|0;
       $344 = tempRet0;
       ___clang_call_terminate($343);
       // unreachable;
      }
     }
    }
    HEAP32[$166>>2] = 0;
    $$0 = $165;$$02 = $164;
    label = 63;
   } else {
    label = 4;
   }
  } else {
   label = 4;
  }
 }
 do {
  if ((label|0) == 4) {
   HEAP32[$1>>2] = 0;
   $9 = ((($0)) + 416|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($10|0)==(0|0);
   if (!($11)) {
    $12 = ((($10)) + 8|0);
    $13 = HEAP32[$12>>2]|0;HEAP32[$12>>2] = (($13-1)|0);
    $14 = ($13|0)==(1);
    if ($14) {
     __THREW__ = 0;
     invoke_viii(3262,($10|0),1,1);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      $174 = ___cxa_find_matching_catch_2()|0;
      $175 = tempRet0;
      $$0 = $175;$$02 = $174;
      label = 63;
      break;
     }
    }
   }
   HEAP32[$9>>2] = 0;
   $17 = ((($0)) + 280|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = ($18|0)==(0|0);
   if (!($19)) {
    $20 = ((($18)) + 8|0);
    $21 = HEAP32[$20>>2]|0;HEAP32[$20>>2] = (($21-1)|0);
    $22 = ($21|0)==(1);
    if ($22) {
     __THREW__ = 0;
     invoke_viii(3262,($18|0),1,1);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      $184 = ___cxa_find_matching_catch_2()|0;
      $185 = tempRet0;
      $$1 = $185;$$14 = $184;
      label = 69;
      break;
     }
    }
   }
   HEAP32[$17>>2] = 0;
   $25 = ((($0)) + 276|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = ($26|0)==(0|0);
   if (!($27)) {
    $28 = ((($26)) + 8|0);
    $29 = HEAP32[$28>>2]|0;HEAP32[$28>>2] = (($29-1)|0);
    $30 = ($29|0)==(1);
    if ($30) {
     __THREW__ = 0;
     invoke_viii(3262,($26|0),1,1);
     $31 = __THREW__; __THREW__ = 0;
     $32 = $31&1;
     if ($32) {
      $186 = ___cxa_find_matching_catch_2()|0;
      $187 = tempRet0;
      $$2 = $187;$$25 = $186;
      label = 74;
      break;
     }
    }
   }
   HEAP32[$25>>2] = 0;
   $33 = ((($0)) + 272|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = ($34|0)==(0|0);
   if (!($35)) {
    $36 = ((($34)) + 8|0);
    $37 = HEAP32[$36>>2]|0;HEAP32[$36>>2] = (($37-1)|0);
    $38 = ($37|0)==(1);
    if ($38) {
     __THREW__ = 0;
     invoke_viii(3262,($34|0),1,1);
     $39 = __THREW__; __THREW__ = 0;
     $40 = $39&1;
     if ($40) {
      $196 = ___cxa_find_matching_catch_2()|0;
      $197 = tempRet0;
      $$3 = $197;$$36 = $196;
      label = 79;
      break;
     }
    }
   }
   HEAP32[$33>>2] = 0;
   $41 = ((($0)) + 260|0);
   $42 = ((($0)) + 264|0);
   $43 = HEAP32[$42>>2]|0;
   __ZNSt3__26__treeINS_12__value_typeIN3osg6Camera15BufferComponentEN7osgUtil11RenderStage10AttachmentEEENS_19__map_value_compareIS4_S8_NS_4lessIS4_EELb1EEENS_9allocatorIS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($41,$43);
   $44 = ((($0)) + 248|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = ($45|0)==(0|0);
   if (!($46)) {
    $47 = ((($45)) + 8|0);
    $48 = HEAP32[$47>>2]|0;HEAP32[$47>>2] = (($48-1)|0);
    $49 = ($48|0)==(1);
    if ($49) {
     __THREW__ = 0;
     invoke_viii(3262,($45|0),1,1);
     $50 = __THREW__; __THREW__ = 0;
     $51 = $50&1;
     if ($51) {
      $206 = ___cxa_find_matching_catch_2()|0;
      $207 = tempRet0;
      $$5 = $207;$$58 = $206;
      label = 84;
      break;
     }
    }
   }
   HEAP32[$44>>2] = 0;
   $52 = ((($0)) + 236|0);
   $53 = HEAP32[$52>>2]|0;
   $54 = ($53|0)==(0|0);
   if (!($54)) {
    $55 = ((($53)) + 8|0);
    $56 = HEAP32[$55>>2]|0;HEAP32[$55>>2] = (($56-1)|0);
    $57 = ($56|0)==(1);
    if ($57) {
     __THREW__ = 0;
     invoke_viii(3262,($53|0),1,1);
     $58 = __THREW__; __THREW__ = 0;
     $59 = $58&1;
     if ($59) {
      $219 = ___cxa_find_matching_catch_2()|0;
      $220 = tempRet0;
      $$6 = $220;$$69 = $219;
      label = 89;
      break;
     }
    }
   }
   HEAP32[$52>>2] = 0;
   $60 = ((($0)) + 228|0);
   $61 = HEAP32[$60>>2]|0;
   $62 = ($61|0)==(0|0);
   if (!($62)) {
    $63 = ((($61)) + 8|0);
    $64 = HEAP32[$63>>2]|0;HEAP32[$63>>2] = (($64-1)|0);
    $65 = ($64|0)==(1);
    if ($65) {
     __THREW__ = 0;
     invoke_viii(3262,($61|0),1,1);
     $66 = __THREW__; __THREW__ = 0;
     $67 = $66&1;
     if ($67) {
      $229 = ___cxa_find_matching_catch_2()|0;
      $230 = tempRet0;
      $$7 = $230;$$710 = $229;
      label = 94;
      break;
     }
    }
   }
   HEAP32[$60>>2] = 0;
   $68 = ((($0)) + 168|0);
   $69 = HEAP32[$68>>2]|0;
   $70 = ($69|0)==(0|0);
   if (!($70)) {
    $71 = ((($69)) + 8|0);
    $72 = HEAP32[$71>>2]|0;HEAP32[$71>>2] = (($72-1)|0);
    $73 = ($72|0)==(1);
    if ($73) {
     __THREW__ = 0;
     invoke_viii(3262,($69|0),1,1);
     $74 = __THREW__; __THREW__ = 0;
     $75 = $74&1;
     if ($75) {
      $239 = ___cxa_find_matching_catch_2()|0;
      $240 = tempRet0;
      $$8 = $240;$$811 = $239;
      label = 99;
      break;
     }
    }
   }
   HEAP32[$68>>2] = 0;
   $76 = ((($0)) + 144|0);
   $77 = HEAP32[$76>>2]|0;
   $78 = ($77|0)==(0|0);
   if (!($78)) {
    $79 = ((($77)) + 8|0);
    $80 = HEAP32[$79>>2]|0;HEAP32[$79>>2] = (($80-1)|0);
    $81 = ($80|0)==(1);
    if ($81) {
     __THREW__ = 0;
     invoke_viii(3262,($77|0),1,1);
     $82 = __THREW__; __THREW__ = 0;
     $83 = $82&1;
     if ($83) {
      $249 = ___cxa_find_matching_catch_2()|0;
      $250 = tempRet0;
      $$9 = $250;$$912 = $249;
      label = 104;
      break;
     }
    }
   }
   HEAP32[$76>>2] = 0;
   $84 = ((($0)) + 140|0);
   $85 = HEAP32[$84>>2]|0;
   $86 = ($85|0)==(0|0);
   if (!($86)) {
    $87 = ((($85)) + 8|0);
    $88 = HEAP32[$87>>2]|0;HEAP32[$87>>2] = (($88-1)|0);
    $89 = ($88|0)==(1);
    if ($89) {
     __THREW__ = 0;
     invoke_viii(3262,($85|0),1,1);
     $90 = __THREW__; __THREW__ = 0;
     $91 = $90&1;
     if ($91) {
      $259 = ___cxa_find_matching_catch_2()|0;
      $260 = tempRet0;
      $$10 = $260;$$1013 = $259;
      break;
     }
    }
   }
   HEAP32[$84>>2] = 0;
   $92 = ((($0)) + 128|0);
   $93 = HEAP32[$92>>2]|0;
   $94 = ($93|0)==(0|0);
   if (!($94)) {
    $95 = ((($0)) + 132|0);
    $96 = HEAP32[$95>>2]|0;
    $97 = ($96|0)==($93|0);
    do {
     if ($97) {
      $111 = $93;
     } else {
      $99 = $96;
      while(1) {
       $98 = ((($99)) + -4|0);
       HEAP32[$95>>2] = $98;
       $100 = HEAP32[$98>>2]|0;
       $101 = ($100|0)==(0|0);
       if (!($101)) {
        $102 = ((($100)) + 8|0);
        $103 = HEAP32[$102>>2]|0;HEAP32[$102>>2] = (($103-1)|0);
        $104 = ($103|0)==(1);
        if ($104) {
         __THREW__ = 0;
         invoke_viii(3262,($100|0),1,1);
         $105 = __THREW__; __THREW__ = 0;
         $106 = $105&1;
         if ($106) {
          label = 40;
          break;
         }
        }
       }
       HEAP32[$98>>2] = 0;
       $107 = HEAP32[$95>>2]|0;
       $108 = ($107|0)==($93|0);
       if ($108) {
        label = 41;
        break;
       } else {
        $99 = $107;
       }
      }
      if ((label|0) == 40) {
       $109 = ___cxa_find_matching_catch_2()|0;
       $110 = tempRet0;
       ___cxa_call_unexpected(($109|0));
       // unreachable;
      }
      else if ((label|0) == 41) {
       $$pre$i = HEAP32[$92>>2]|0;
       $111 = $$pre$i;
       break;
      }
     }
    } while(0);
    __ZdlPv($111);
   }
   $112 = ((($0)) + 116|0);
   $113 = ((($0)) + 124|0);
   $114 = HEAP32[$113>>2]|0;
   $115 = ($114|0)==(0);
   L76: do {
    if (!($115)) {
     $116 = ((($0)) + 120|0);
     $117 = HEAP32[$116>>2]|0;
     $118 = HEAP32[$112>>2]|0;
     $119 = ((($118)) + 4|0);
     $120 = HEAP32[$119>>2]|0;
     $121 = HEAP32[$117>>2]|0;
     $122 = ((($121)) + 4|0);
     HEAP32[$122>>2] = $120;
     $123 = HEAP32[$119>>2]|0;
     HEAP32[$123>>2] = $121;
     HEAP32[$113>>2] = 0;
     $124 = ($117|0)==($112|0);
     if (!($124)) {
      $$023$i$i = $117;
      while(1) {
       $125 = ((($$023$i$i)) + 4|0);
       $126 = HEAP32[$125>>2]|0;
       $127 = ((($$023$i$i)) + 12|0);
       $128 = HEAP32[$127>>2]|0;
       $129 = ($128|0)==(0|0);
       if (!($129)) {
        $130 = ((($128)) + 8|0);
        $131 = HEAP32[$130>>2]|0;HEAP32[$130>>2] = (($131-1)|0);
        $132 = ($131|0)==(1);
        if ($132) {
         __THREW__ = 0;
         invoke_viii(3262,($128|0),1,1);
         $133 = __THREW__; __THREW__ = 0;
         $134 = $133&1;
         if ($134) {
          break;
         }
        }
       }
       __ZdlPv($$023$i$i);
       $135 = ($126|0)==($112|0);
       if ($135) {
        break L76;
       } else {
        $$023$i$i = $126;
       }
      }
      $136 = ___cxa_find_matching_catch_2()|0;
      $137 = tempRet0;
      ___cxa_call_unexpected(($136|0));
      // unreachable;
     }
    }
   } while(0);
   $138 = ((($0)) + 104|0);
   $139 = ((($0)) + 112|0);
   $140 = HEAP32[$139>>2]|0;
   $141 = ($140|0)==(0);
   if ($141) {
    __ZN7osgUtil9RenderBinD2Ev($0);
    return;
   }
   $142 = ((($0)) + 108|0);
   $143 = HEAP32[$142>>2]|0;
   $144 = HEAP32[$138>>2]|0;
   $145 = ((($144)) + 4|0);
   $146 = HEAP32[$145>>2]|0;
   $147 = HEAP32[$143>>2]|0;
   $148 = ((($147)) + 4|0);
   HEAP32[$148>>2] = $146;
   $149 = HEAP32[$145>>2]|0;
   HEAP32[$149>>2] = $147;
   HEAP32[$139>>2] = 0;
   $150 = ($143|0)==($138|0);
   if ($150) {
    __ZN7osgUtil9RenderBinD2Ev($0);
    return;
   } else {
    $$023$i$i29 = $143;
   }
   while(1) {
    $151 = ((($$023$i$i29)) + 4|0);
    $152 = HEAP32[$151>>2]|0;
    $153 = ((($$023$i$i29)) + 12|0);
    $154 = HEAP32[$153>>2]|0;
    $155 = ($154|0)==(0|0);
    if (!($155)) {
     $156 = ((($154)) + 8|0);
     $157 = HEAP32[$156>>2]|0;HEAP32[$156>>2] = (($157-1)|0);
     $158 = ($157|0)==(1);
     if ($158) {
      __THREW__ = 0;
      invoke_viii(3262,($154|0),1,1);
      $159 = __THREW__; __THREW__ = 0;
      $160 = $159&1;
      if ($160) {
       label = 56;
       break;
      }
     }
    }
    __ZdlPv($$023$i$i29);
    $161 = ($152|0)==($138|0);
    if ($161) {
     label = 57;
     break;
    } else {
     $$023$i$i29 = $152;
    }
   }
   if ((label|0) == 56) {
    $162 = ___cxa_find_matching_catch_2()|0;
    $163 = tempRet0;
    ___cxa_call_unexpected(($162|0));
    // unreachable;
   }
   else if ((label|0) == 57) {
    __ZN7osgUtil9RenderBinD2Ev($0);
    return;
   }
  }
 } while(0);
 if ((label|0) == 63) {
  $176 = ((($0)) + 280|0);
  $177 = HEAP32[$176>>2]|0;
  $178 = ($177|0)==(0|0);
  if (!($178)) {
   $179 = ((($177)) + 8|0);
   $180 = HEAP32[$179>>2]|0;HEAP32[$179>>2] = (($180-1)|0);
   $181 = ($180|0)==(1);
   if ($181) {
    __THREW__ = 0;
    invoke_viii(3262,($177|0),1,1);
    $182 = __THREW__; __THREW__ = 0;
    $183 = $182&1;
    if ($183) {
     $343 = ___cxa_find_matching_catch_3(0|0)|0;
     $344 = tempRet0;
     ___clang_call_terminate($343);
     // unreachable;
    }
   }
  }
  HEAP32[$176>>2] = 0;
  $$1 = $$0;$$14 = $$02;
  label = 69;
 }
 if ((label|0) == 69) {
  $188 = ((($0)) + 276|0);
  $189 = HEAP32[$188>>2]|0;
  $190 = ($189|0)==(0|0);
  if (!($190)) {
   $191 = ((($189)) + 8|0);
   $192 = HEAP32[$191>>2]|0;HEAP32[$191>>2] = (($192-1)|0);
   $193 = ($192|0)==(1);
   if ($193) {
    __THREW__ = 0;
    invoke_viii(3262,($189|0),1,1);
    $194 = __THREW__; __THREW__ = 0;
    $195 = $194&1;
    if ($195) {
     $343 = ___cxa_find_matching_catch_3(0|0)|0;
     $344 = tempRet0;
     ___clang_call_terminate($343);
     // unreachable;
    }
   }
  }
  HEAP32[$188>>2] = 0;
  $$2 = $$1;$$25 = $$14;
  label = 74;
 }
 if ((label|0) == 74) {
  $198 = ((($0)) + 272|0);
  $199 = HEAP32[$198>>2]|0;
  $200 = ($199|0)==(0|0);
  if (!($200)) {
   $201 = ((($199)) + 8|0);
   $202 = HEAP32[$201>>2]|0;HEAP32[$201>>2] = (($202-1)|0);
   $203 = ($202|0)==(1);
   if ($203) {
    __THREW__ = 0;
    invoke_viii(3262,($199|0),1,1);
    $204 = __THREW__; __THREW__ = 0;
    $205 = $204&1;
    if ($205) {
     $343 = ___cxa_find_matching_catch_3(0|0)|0;
     $344 = tempRet0;
     ___clang_call_terminate($343);
     // unreachable;
    }
   }
  }
  HEAP32[$198>>2] = 0;
  $$3 = $$2;$$36 = $$25;
  label = 79;
 }
 if ((label|0) == 79) {
  $208 = ((($0)) + 260|0);
  $209 = ((($0)) + 264|0);
  $210 = HEAP32[$209>>2]|0;
  __ZNSt3__26__treeINS_12__value_typeIN3osg6Camera15BufferComponentEN7osgUtil11RenderStage10AttachmentEEENS_19__map_value_compareIS4_S8_NS_4lessIS4_EELb1EEENS_9allocatorIS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($208,$210);
  $211 = ((($0)) + 248|0);
  $212 = HEAP32[$211>>2]|0;
  $213 = ($212|0)==(0|0);
  if (!($213)) {
   $214 = ((($212)) + 8|0);
   $215 = HEAP32[$214>>2]|0;HEAP32[$214>>2] = (($215-1)|0);
   $216 = ($215|0)==(1);
   if ($216) {
    __THREW__ = 0;
    invoke_viii(3262,($212|0),1,1);
    $217 = __THREW__; __THREW__ = 0;
    $218 = $217&1;
    if ($218) {
     $343 = ___cxa_find_matching_catch_3(0|0)|0;
     $344 = tempRet0;
     ___clang_call_terminate($343);
     // unreachable;
    }
   }
  }
  HEAP32[$211>>2] = 0;
  $$5 = $$3;$$58 = $$36;
  label = 84;
 }
 if ((label|0) == 84) {
  $221 = ((($0)) + 236|0);
  $222 = HEAP32[$221>>2]|0;
  $223 = ($222|0)==(0|0);
  if (!($223)) {
   $224 = ((($222)) + 8|0);
   $225 = HEAP32[$224>>2]|0;HEAP32[$224>>2] = (($225-1)|0);
   $226 = ($225|0)==(1);
   if ($226) {
    __THREW__ = 0;
    invoke_viii(3262,($222|0),1,1);
    $227 = __THREW__; __THREW__ = 0;
    $228 = $227&1;
    if ($228) {
     $343 = ___cxa_find_matching_catch_3(0|0)|0;
     $344 = tempRet0;
     ___clang_call_terminate($343);
     // unreachable;
    }
   }
  }
  HEAP32[$221>>2] = 0;
  $$6 = $$5;$$69 = $$58;
  label = 89;
 }
 if ((label|0) == 89) {
  $231 = ((($0)) + 228|0);
  $232 = HEAP32[$231>>2]|0;
  $233 = ($232|0)==(0|0);
  if (!($233)) {
   $234 = ((($232)) + 8|0);
   $235 = HEAP32[$234>>2]|0;HEAP32[$234>>2] = (($235-1)|0);
   $236 = ($235|0)==(1);
   if ($236) {
    __THREW__ = 0;
    invoke_viii(3262,($232|0),1,1);
    $237 = __THREW__; __THREW__ = 0;
    $238 = $237&1;
    if ($238) {
     $343 = ___cxa_find_matching_catch_3(0|0)|0;
     $344 = tempRet0;
     ___clang_call_terminate($343);
     // unreachable;
    }
   }
  }
  HEAP32[$231>>2] = 0;
  $$7 = $$6;$$710 = $$69;
  label = 94;
 }
 if ((label|0) == 94) {
  $241 = ((($0)) + 168|0);
  $242 = HEAP32[$241>>2]|0;
  $243 = ($242|0)==(0|0);
  if (!($243)) {
   $244 = ((($242)) + 8|0);
   $245 = HEAP32[$244>>2]|0;HEAP32[$244>>2] = (($245-1)|0);
   $246 = ($245|0)==(1);
   if ($246) {
    __THREW__ = 0;
    invoke_viii(3262,($242|0),1,1);
    $247 = __THREW__; __THREW__ = 0;
    $248 = $247&1;
    if ($248) {
     $343 = ___cxa_find_matching_catch_3(0|0)|0;
     $344 = tempRet0;
     ___clang_call_terminate($343);
     // unreachable;
    }
   }
  }
  HEAP32[$241>>2] = 0;
  $$8 = $$7;$$811 = $$710;
  label = 99;
 }
 if ((label|0) == 99) {
  $251 = ((($0)) + 144|0);
  $252 = HEAP32[$251>>2]|0;
  $253 = ($252|0)==(0|0);
  if (!($253)) {
   $254 = ((($252)) + 8|0);
   $255 = HEAP32[$254>>2]|0;HEAP32[$254>>2] = (($255-1)|0);
   $256 = ($255|0)==(1);
   if ($256) {
    __THREW__ = 0;
    invoke_viii(3262,($252|0),1,1);
    $257 = __THREW__; __THREW__ = 0;
    $258 = $257&1;
    if ($258) {
     $343 = ___cxa_find_matching_catch_3(0|0)|0;
     $344 = tempRet0;
     ___clang_call_terminate($343);
     // unreachable;
    }
   }
  }
  HEAP32[$251>>2] = 0;
  $$9 = $$8;$$912 = $$811;
  label = 104;
 }
 if ((label|0) == 104) {
  $261 = ((($0)) + 140|0);
  $262 = HEAP32[$261>>2]|0;
  $263 = ($262|0)==(0|0);
  if (!($263)) {
   $264 = ((($262)) + 8|0);
   $265 = HEAP32[$264>>2]|0;HEAP32[$264>>2] = (($265-1)|0);
   $266 = ($265|0)==(1);
   if ($266) {
    __THREW__ = 0;
    invoke_viii(3262,($262|0),1,1);
    $267 = __THREW__; __THREW__ = 0;
    $268 = $267&1;
    if ($268) {
     $343 = ___cxa_find_matching_catch_3(0|0)|0;
     $344 = tempRet0;
     ___clang_call_terminate($343);
     // unreachable;
    }
   }
  }
  HEAP32[$261>>2] = 0;
  $$10 = $$9;$$1013 = $$912;
 }
 $269 = ((($0)) + 128|0);
 $270 = HEAP32[$269>>2]|0;
 $271 = ($270|0)==(0|0);
 if (!($271)) {
  $272 = ((($0)) + 132|0);
  $273 = HEAP32[$272>>2]|0;
  $274 = ($273|0)==($270|0);
  do {
   if ($274) {
    $288 = $270;
   } else {
    $276 = $273;
    while(1) {
     $275 = ((($276)) + -4|0);
     HEAP32[$272>>2] = $275;
     $277 = HEAP32[$275>>2]|0;
     $278 = ($277|0)==(0|0);
     if (!($278)) {
      $279 = ((($277)) + 8|0);
      $280 = HEAP32[$279>>2]|0;HEAP32[$279>>2] = (($280-1)|0);
      $281 = ($280|0)==(1);
      if ($281) {
       __THREW__ = 0;
       invoke_viii(3262,($277|0),1,1);
       $282 = __THREW__; __THREW__ = 0;
       $283 = $282&1;
       if ($283) {
        label = 114;
        break;
       }
      }
     }
     HEAP32[$275>>2] = 0;
     $284 = HEAP32[$272>>2]|0;
     $285 = ($284|0)==($270|0);
     if ($285) {
      label = 115;
      break;
     } else {
      $276 = $284;
     }
    }
    if ((label|0) == 114) {
     $286 = ___cxa_find_matching_catch_2()|0;
     $287 = tempRet0;
     ___cxa_call_unexpected(($286|0));
     // unreachable;
    }
    else if ((label|0) == 115) {
     $$pre$i55 = HEAP32[$269>>2]|0;
     $288 = $$pre$i55;
     break;
    }
   }
  } while(0);
  __ZdlPv($288);
 }
 $289 = ((($0)) + 116|0);
 $290 = ((($0)) + 124|0);
 $291 = HEAP32[$290>>2]|0;
 $292 = ($291|0)==(0);
 L178: do {
  if (!($292)) {
   $293 = ((($0)) + 120|0);
   $294 = HEAP32[$293>>2]|0;
   $295 = HEAP32[$289>>2]|0;
   $296 = ((($295)) + 4|0);
   $297 = HEAP32[$296>>2]|0;
   $298 = HEAP32[$294>>2]|0;
   $299 = ((($298)) + 4|0);
   HEAP32[$299>>2] = $297;
   $300 = HEAP32[$296>>2]|0;
   HEAP32[$300>>2] = $298;
   HEAP32[$290>>2] = 0;
   $301 = ($294|0)==($289|0);
   if (!($301)) {
    $$023$i$i59 = $294;
    while(1) {
     $302 = ((($$023$i$i59)) + 4|0);
     $303 = HEAP32[$302>>2]|0;
     $304 = ((($$023$i$i59)) + 12|0);
     $305 = HEAP32[$304>>2]|0;
     $306 = ($305|0)==(0|0);
     if (!($306)) {
      $307 = ((($305)) + 8|0);
      $308 = HEAP32[$307>>2]|0;HEAP32[$307>>2] = (($308-1)|0);
      $309 = ($308|0)==(1);
      if ($309) {
       __THREW__ = 0;
       invoke_viii(3262,($305|0),1,1);
       $310 = __THREW__; __THREW__ = 0;
       $311 = $310&1;
       if ($311) {
        break;
       }
      }
     }
     __ZdlPv($$023$i$i59);
     $312 = ($303|0)==($289|0);
     if ($312) {
      break L178;
     } else {
      $$023$i$i59 = $303;
     }
    }
    $313 = ___cxa_find_matching_catch_2()|0;
    $314 = tempRet0;
    ___cxa_call_unexpected(($313|0));
    // unreachable;
   }
  }
 } while(0);
 $315 = ((($0)) + 104|0);
 $316 = ((($0)) + 112|0);
 $317 = HEAP32[$316>>2]|0;
 $318 = ($317|0)==(0);
 L188: do {
  if (!($318)) {
   $319 = ((($0)) + 108|0);
   $320 = HEAP32[$319>>2]|0;
   $321 = HEAP32[$315>>2]|0;
   $322 = ((($321)) + 4|0);
   $323 = HEAP32[$322>>2]|0;
   $324 = HEAP32[$320>>2]|0;
   $325 = ((($324)) + 4|0);
   HEAP32[$325>>2] = $323;
   $326 = HEAP32[$322>>2]|0;
   HEAP32[$326>>2] = $324;
   HEAP32[$316>>2] = 0;
   $327 = ($320|0)==($315|0);
   if (!($327)) {
    $$023$i$i62 = $320;
    while(1) {
     $328 = ((($$023$i$i62)) + 4|0);
     $329 = HEAP32[$328>>2]|0;
     $330 = ((($$023$i$i62)) + 12|0);
     $331 = HEAP32[$330>>2]|0;
     $332 = ($331|0)==(0|0);
     if (!($332)) {
      $333 = ((($331)) + 8|0);
      $334 = HEAP32[$333>>2]|0;HEAP32[$333>>2] = (($334-1)|0);
      $335 = ($334|0)==(1);
      if ($335) {
       __THREW__ = 0;
       invoke_viii(3262,($331|0),1,1);
       $336 = __THREW__; __THREW__ = 0;
       $337 = $336&1;
       if ($337) {
        break;
       }
      }
     }
     __ZdlPv($$023$i$i62);
     $338 = ($329|0)==($315|0);
     if ($338) {
      break L188;
     } else {
      $$023$i$i62 = $329;
     }
    }
    $339 = ___cxa_find_matching_catch_2()|0;
    $340 = tempRet0;
    ___cxa_call_unexpected(($339|0));
    // unreachable;
   }
  }
 } while(0);
 __THREW__ = 0;
 invoke_vi(1385,($0|0));
 $341 = __THREW__; __THREW__ = 0;
 $342 = $341&1;
 if ($342) {
  $343 = ___cxa_find_matching_catch_3(0|0)|0;
  $344 = tempRet0;
  ___clang_call_terminate($343);
  // unreachable;
 } else {
  ___resumeException($$1013|0);
  // unreachable;
 }
}
function __ZN7osgUtil11RenderStageD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1409,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK7osgUtil11RenderStage9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(424)|0);
 __THREW__ = 0;
 invoke_vi(3573,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch_2()|0;
  $5 = tempRet0;
  __ZdlPv($1);
  ___resumeException($4|0);
  // unreachable;
 } else {
  return ($1|0);
 }
 return (0)|0;
}
function __ZNK7osgUtil11RenderStage5cloneERKN3osg6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(424)|0);
 __THREW__ = 0;
 invoke_viii(3671,($2|0),($0|0),($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch_2()|0;
  $6 = tempRet0;
  __ZdlPv($2);
  ___resumeException($5|0);
  // unreachable;
 } else {
  return ($2|0);
 }
 return (0)|0;
}
function __ZNK7osgUtil11RenderStage12isSameKindAsEPKN3osg6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,22912,0)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK7osgUtil11RenderStage9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (118598|0);
}
function __ZNK7osgUtil11RenderStage16releaseGLObjectsEPN3osg5StateE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$sroa$010$026 = 0, $$sroa$016$0 = 0, $$sroa$016$028 = 0, $$sroa$016$029 = 0, $$sroa$022$0 = 0, $$sroa$022$034 = 0, $$sroa$022$035 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZNK7osgUtil9RenderBin16releaseGLObjectsEPN3osg5StateE($0,$1);
 $2 = ((($0)) + 108|0);
 $$sroa$022$034 = HEAP32[$2>>2]|0;
 $3 = ((($0)) + 104|0);
 $4 = $$sroa$022$034;
 $5 = ($4|0)==($3|0);
 if (!($5)) {
  $$sroa$022$035 = $$sroa$022$034;$17 = $4;
  while(1) {
   $10 = $$sroa$022$035;
   $11 = ((($10)) + 12|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = HEAP32[$12>>2]|0;
   $14 = ((($13)) + 136|0);
   $15 = HEAP32[$14>>2]|0;
   FUNCTION_TABLE_vii[$15 & 8191]($12,$1);
   $16 = ((($17)) + 4|0);
   $$sroa$022$0 = HEAP32[$16>>2]|0;
   $18 = $$sroa$022$0;
   $19 = ($18|0)==($3|0);
   if ($19) {
    break;
   } else {
    $$sroa$022$035 = $$sroa$022$0;$17 = $18;
   }
  }
 }
 $6 = ((($0)) + 120|0);
 $$sroa$016$028 = HEAP32[$6>>2]|0;
 $7 = ((($0)) + 116|0);
 $8 = $$sroa$016$028;
 $9 = ($8|0)==($7|0);
 if (!($9)) {
  $$sroa$016$029 = $$sroa$016$028;$32 = $8;
  while(1) {
   $25 = $$sroa$016$029;
   $26 = ((($25)) + 12|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = HEAP32[$27>>2]|0;
   $29 = ((($28)) + 136|0);
   $30 = HEAP32[$29>>2]|0;
   FUNCTION_TABLE_vii[$30 & 8191]($27,$1);
   $31 = ((($32)) + 4|0);
   $$sroa$016$0 = HEAP32[$31>>2]|0;
   $33 = $$sroa$016$0;
   $34 = ($33|0)==($7|0);
   if ($34) {
    break;
   } else {
    $$sroa$016$029 = $$sroa$016$0;$32 = $33;
   }
  }
 }
 $20 = ((($0)) + 128|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ((($0)) + 132|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($21|0)==($23|0);
 if (!($24)) {
  $$sroa$010$026 = $21;
  while(1) {
   $38 = HEAP32[$$sroa$010$026>>2]|0;
   $39 = HEAP32[$38>>2]|0;
   $40 = ((($39)) + 136|0);
   $41 = HEAP32[$40>>2]|0;
   FUNCTION_TABLE_vii[$41 & 8191]($38,$1);
   $42 = ((($$sroa$010$026)) + 4|0);
   $43 = HEAP32[$22>>2]|0;
   $44 = ($42|0)==($43|0);
   if ($44) {
    break;
   } else {
    $$sroa$010$026 = $42;
   }
  }
 }
 $35 = ((($0)) + 236|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = ($36|0)==(0|0);
 if (!($37)) {
  $45 = HEAP32[$36>>2]|0;
  $46 = ((($45)) + 136|0);
  $47 = HEAP32[$46>>2]|0;
  FUNCTION_TABLE_vii[$47 & 8191]($36,$1);
 }
 $48 = ((($0)) + 272|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = ($49|0)==(0|0);
 if (!($50)) {
  $51 = HEAP32[$49>>2]|0;
  $52 = ((($51)) + 136|0);
  $53 = HEAP32[$52>>2]|0;
  FUNCTION_TABLE_vii[$53 & 8191]($49,$1);
 }
 $54 = ((($0)) + 276|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = ($55|0)==(0|0);
 if (!($56)) {
  $57 = HEAP32[$55>>2]|0;
  $58 = ((($57)) + 136|0);
  $59 = HEAP32[$58>>2]|0;
  FUNCTION_TABLE_vii[$59 & 8191]($55,$1);
 }
 $60 = ((($0)) + 280|0);
 $61 = HEAP32[$60>>2]|0;
 $62 = ($61|0)==(0|0);
 if ($62) {
  return;
 }
 $63 = HEAP32[$61>>2]|0;
 $64 = ((($63)) + 136|0);
 $65 = HEAP32[$64>>2]|0;
 FUNCTION_TABLE_vii[$65 & 8191]($61,$1);
 return;
}
function __ZN7osgUtil11RenderStage5resetEv($0) {
 $0 = $0|0;
 var $$023$i$i = 0, $$023$i$i1 = 0, $$sroa$011$0 = 0, $$sroa$011$020 = 0, $$sroa$011$021 = 0, $$sroa$05$0 = 0, $$sroa$05$017 = 0, $$sroa$05$018 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 100|0);
 HEAP8[$1>>0] = 0;
 $2 = ((($0)) + 420|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = HEAP32[$3>>2]|0;
  $6 = ((($5)) + 140|0);
  $7 = HEAP32[$6>>2]|0;
  FUNCTION_TABLE_vi[$7 & 8191]($3);
 }
 $8 = ((($0)) + 104|0);
 $9 = ((($0)) + 108|0);
 $$sroa$011$020 = HEAP32[$9>>2]|0;
 $10 = $$sroa$011$020;
 $11 = ($10|0)==($8|0);
 if (!($11)) {
  $$sroa$011$021 = $$sroa$011$020;$23 = $10;
  while(1) {
   $16 = $$sroa$011$021;
   $17 = ((($16)) + 12|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = HEAP32[$18>>2]|0;
   $20 = ((($19)) + 140|0);
   $21 = HEAP32[$20>>2]|0;
   FUNCTION_TABLE_vi[$21 & 8191]($18);
   $22 = ((($23)) + 4|0);
   $$sroa$011$0 = HEAP32[$22>>2]|0;
   $24 = $$sroa$011$0;
   $25 = ($24|0)==($8|0);
   if ($25) {
    break;
   } else {
    $$sroa$011$021 = $$sroa$011$0;$23 = $24;
   }
  }
 }
 __ZN7osgUtil9RenderBin5resetEv($0);
 $12 = ((($0)) + 116|0);
 $13 = ((($0)) + 120|0);
 $$sroa$05$017 = HEAP32[$13>>2]|0;
 $14 = $$sroa$05$017;
 $15 = ($14|0)==($12|0);
 if (!($15)) {
  $$sroa$05$018 = $$sroa$05$017;$81 = $14;
  while(1) {
   $74 = $$sroa$05$018;
   $75 = ((($74)) + 12|0);
   $76 = HEAP32[$75>>2]|0;
   $77 = HEAP32[$76>>2]|0;
   $78 = ((($77)) + 140|0);
   $79 = HEAP32[$78>>2]|0;
   FUNCTION_TABLE_vi[$79 & 8191]($76);
   $80 = ((($81)) + 4|0);
   $$sroa$05$0 = HEAP32[$80>>2]|0;
   $82 = $$sroa$05$0;
   $83 = ($82|0)==($12|0);
   if ($83) {
    break;
   } else {
    $$sroa$05$018 = $$sroa$05$0;$81 = $82;
   }
  }
 }
 $26 = ((($0)) + 112|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ($27|0)==(0);
 L12: do {
  if (!($28)) {
   $29 = HEAP32[$9>>2]|0;
   $30 = HEAP32[$8>>2]|0;
   $31 = ((($30)) + 4|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = HEAP32[$29>>2]|0;
   $34 = ((($33)) + 4|0);
   HEAP32[$34>>2] = $32;
   $35 = HEAP32[$31>>2]|0;
   HEAP32[$35>>2] = $33;
   HEAP32[$26>>2] = 0;
   $36 = ($29|0)==($8|0);
   if (!($36)) {
    $$023$i$i1 = $29;
    while(1) {
     $37 = ((($$023$i$i1)) + 4|0);
     $38 = HEAP32[$37>>2]|0;
     $39 = ((($$023$i$i1)) + 12|0);
     $40 = HEAP32[$39>>2]|0;
     $41 = ($40|0)==(0|0);
     if (!($41)) {
      $42 = ((($40)) + 8|0);
      $43 = HEAP32[$42>>2]|0;HEAP32[$42>>2] = (($43-1)|0);
      $44 = ($43|0)==(1);
      if ($44) {
       __THREW__ = 0;
       invoke_viii(3262,($40|0),1,1);
       $45 = __THREW__; __THREW__ = 0;
       $46 = $45&1;
       if ($46) {
        break;
       }
      }
     }
     __ZdlPv($$023$i$i1);
     $47 = ($38|0)==($8|0);
     if ($47) {
      break L12;
     } else {
      $$023$i$i1 = $38;
     }
    }
    $48 = ___cxa_find_matching_catch_2()|0;
    $49 = tempRet0;
    ___cxa_call_unexpected(($48|0));
    // unreachable;
   }
  }
 } while(0);
 $50 = ((($0)) + 124|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = ($51|0)==(0);
 if ($52) {
  return;
 }
 $53 = HEAP32[$13>>2]|0;
 $54 = HEAP32[$12>>2]|0;
 $55 = ((($54)) + 4|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = HEAP32[$53>>2]|0;
 $58 = ((($57)) + 4|0);
 HEAP32[$58>>2] = $56;
 $59 = HEAP32[$55>>2]|0;
 HEAP32[$59>>2] = $57;
 HEAP32[$50>>2] = 0;
 $60 = ($53|0)==($12|0);
 if ($60) {
  return;
 } else {
  $$023$i$i = $53;
 }
 while(1) {
  $61 = ((($$023$i$i)) + 4|0);
  $62 = HEAP32[$61>>2]|0;
  $63 = ((($$023$i$i)) + 12|0);
  $64 = HEAP32[$63>>2]|0;
  $65 = ($64|0)==(0|0);
  if (!($65)) {
   $66 = ((($64)) + 8|0);
   $67 = HEAP32[$66>>2]|0;HEAP32[$66>>2] = (($67-1)|0);
   $68 = ($67|0)==(1);
   if ($68) {
    __THREW__ = 0;
    invoke_viii(3262,($64|0),1,1);
    $69 = __THREW__; __THREW__ = 0;
    $70 = $69&1;
    if ($70) {
     label = 19;
     break;
    }
   }
  }
  __ZdlPv($$023$i$i);
  $71 = ($62|0)==($12|0);
  if ($71) {
   label = 20;
   break;
  } else {
   $$023$i$i = $62;
  }
 }
 if ((label|0) == 19) {
  $72 = ___cxa_find_matching_catch_2()|0;
  $73 = tempRet0;
  ___cxa_call_unexpected(($72|0));
  // unreachable;
 }
 else if ((label|0) == 20) {
  return;
 }
}
function __ZN7osgUtil11RenderStage4sortEv($0) {
 $0 = $0|0;
 var $$sroa$02$0 = 0, $$sroa$02$013 = 0, $$sroa$02$014 = 0, $$sroa$08$0 = 0, $$sroa$08$016 = 0, $$sroa$08$017 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 108|0);
 $$sroa$08$016 = HEAP32[$1>>2]|0;
 $2 = ((($0)) + 104|0);
 $3 = $$sroa$08$016;
 $4 = ($3|0)==($2|0);
 if (!($4)) {
  $$sroa$08$017 = $$sroa$08$016;$16 = $3;
  while(1) {
   $9 = $$sroa$08$017;
   $10 = ((($9)) + 12|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = HEAP32[$11>>2]|0;
   $13 = ((($12)) + 144|0);
   $14 = HEAP32[$13>>2]|0;
   FUNCTION_TABLE_vi[$14 & 8191]($11);
   $15 = ((($16)) + 4|0);
   $$sroa$08$0 = HEAP32[$15>>2]|0;
   $17 = $$sroa$08$0;
   $18 = ($17|0)==($2|0);
   if ($18) {
    break;
   } else {
    $$sroa$08$017 = $$sroa$08$0;$16 = $17;
   }
  }
 }
 __ZN7osgUtil9RenderBin4sortEv($0);
 $5 = ((($0)) + 120|0);
 $$sroa$02$013 = HEAP32[$5>>2]|0;
 $6 = ((($0)) + 116|0);
 $7 = $$sroa$02$013;
 $8 = ($7|0)==($6|0);
 if ($8) {
  return;
 } else {
  $$sroa$02$014 = $$sroa$02$013;$26 = $7;
 }
 while(1) {
  $19 = $$sroa$02$014;
  $20 = ((($19)) + 12|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = HEAP32[$21>>2]|0;
  $23 = ((($22)) + 144|0);
  $24 = HEAP32[$23>>2]|0;
  FUNCTION_TABLE_vi[$24 & 8191]($21);
  $25 = ((($26)) + 4|0);
  $$sroa$02$0 = HEAP32[$25>>2]|0;
  $27 = $$sroa$02$0;
  $28 = ($27|0)==($6|0);
  if ($28) {
   break;
  } else {
   $$sroa$02$014 = $$sroa$02$0;$26 = $27;
  }
 }
 return;
}
function __ZN7osgUtil11RenderStage4drawERN3osg10RenderInfoERPNS_10RenderLeafE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$ = 0, $$0 = 0, $$085 = 0, $$086 = 0, $$091 = 0, $$092 = 0, $$2 = 0, $$288 = 0, $$4 = 0, $$490 = 0, $$pr$pre = 0, $$pr131 = 0, $$pre = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0;
 var $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0;
 var $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0;
 var $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0;
 var $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0;
 var $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0;
 var $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0;
 var $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0;
 var $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0;
 var $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0;
 var $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0;
 var $341 = 0, $342 = 0, $343 = 0, $344 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index4Z2D = 0, $eh$lpad$body$indexZ2D = 0, $or$cond = 0, $or$cond126 = 0, $or$cond127 = 0;
 var $or$cond94 = 0, $or$cond95 = 0, $phitmp$i = 0, $phitmp$i100 = 0, $phitmp$i102 = 0, $phitmp$i106 = 0, $phitmp$i113 = 0, $phitmp$i96 = 0, $phitmp$i98 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $3 = sp + 36|0;
 $4 = sp;
 $5 = sp + 40|0;
 $6 = ((($0)) + 100|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = ($7<<24>>24)==(0);
 if (!($8)) {
  STACKTOP = sp;return;
 }
 $9 = ((($0)) + 144|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if (!($11)) {
  $12 = HEAP32[$1>>2]|0;
  __ZN3osg5State20setInitialViewMatrixEPKNS_10RefMatrixdE($12,$10);
 }
 $13 = ((($0)) + 228|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(0|0);
 do {
  if ($15) {
   HEAP8[$6>>0] = 1;
  } else {
   $16 = ((($14)) + 24|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = ($17|0)==(0|0);
   if ($18) {
    label = 11;
   } else {
    $19 = ((($0)) + 232|0);
    $20 = HEAP32[$19>>2]|0;
    $phitmp$i = ($20|0)==(0|0);
    if ($phitmp$i) {
     label = 11;
    } else {
     HEAP32[$3>>2] = $20;
     $21 = ((($1)) + 12|0);
     $22 = HEAP32[$21>>2]|0;
     $23 = ((($1)) + 16|0);
     $24 = HEAP32[$23>>2]|0;
     $25 = ($22|0)==($24|0);
     if ($25) {
      $29 = ((($1)) + 8|0);
      __ZNSt3__26vectorIPN3osg6CameraENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_($29,$3);
     } else {
      $26 = $20;
      HEAP32[$22>>2] = $26;
      $27 = HEAP32[$21>>2]|0;
      $28 = ((($27)) + 4|0);
      HEAP32[$21>>2] = $28;
     }
     $$pre = HEAP32[$13>>2]|0;
     HEAP8[$6>>0] = 1;
     $30 = ($$pre|0)==(0|0);
     if ($30) {
      break;
     } else {
      $32 = $$pre;
     }
    }
   }
   if ((label|0) == 11) {
    HEAP8[$6>>0] = 1;
    $32 = $14;
   }
   $31 = ((($32)) + 24|0);
   $33 = HEAP32[$31>>2]|0;
   $34 = ($33|0)==(0|0);
   if (!($34)) {
    $35 = ((($0)) + 232|0);
    $36 = HEAP32[$35>>2]|0;
    $phitmp$i100 = ($36|0)==(0|0);
    if (!($phitmp$i100)) {
     $37 = ((($36)) + 636|0);
     $38 = HEAP32[$37>>2]|0;
     $39 = ($38|0)==(0|0);
     if (!($39)) {
      $40 = HEAP32[$38>>2]|0;
      $41 = ((($40)) + 20|0);
      $42 = HEAP32[$41>>2]|0;
      FUNCTION_TABLE_vii[$42 & 8191]($38,$1);
     }
    }
   }
  }
 } while(0);
 $43 = HEAP32[$0>>2]|0;
 $44 = ((($43)) + 192|0);
 $45 = HEAP32[$44>>2]|0;
 FUNCTION_TABLE_viii[$45 & 8191]($0,$1,$2);
 $46 = ((($0)) + 220|0);
 $47 = HEAP8[$46>>0]|0;
 $48 = ($47<<24>>24)==(0);
 if ($48) {
  $49 = HEAP32[$13>>2]|0;
  $50 = ($49|0)==(0|0);
  if (!($50)) {
   $51 = ((($49)) + 24|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = ($52|0)==(0|0);
   if (!($53)) {
    $54 = ((($0)) + 232|0);
    $55 = HEAP32[$54>>2]|0;
    $phitmp$i106 = ($55|0)==(0|0);
    if (!($phitmp$i106)) {
     $56 = ((($0)) + 224|0);
     $57 = HEAP32[$56>>2]|0;
     $58 = ((($55)) + 604|0);
     $59 = HEAP32[$58>>2]|0;
     $60 = ($57|0)==($59|0);
     if (!($60)) {
      label = 22;
     }
    }
   }
  }
 } else {
  label = 22;
 }
 if ((label|0) == 22) {
  __ZN7osgUtil11RenderStage14runCameraSetUpERN3osg10RenderInfoE($0,$1);
 }
 $61 = HEAP32[$1>>2]|0;
 $62 = ((($61)) + 120|0);
 $63 = HEAP32[$62>>2]|0;
 __ZN3osg10RenderInfoC2ERKS0_($4,$1);
 $64 = HEAP32[$2>>2]|0;
 $65 = ((($0)) + 280|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = ($66|0)==(0|0);
 $68 = ($66|0)==($63|0);
 $or$cond126 = $67 | $68;
 L32: do {
  if ($or$cond126) {
   $$0 = $61;$$091 = $63;$$092 = 0;
   label = 48;
  } else {
   __THREW__ = 0;
   (invoke_ii(3382,($63|0))|0);
   $69 = __THREW__; __THREW__ = 0;
   $70 = $69&1;
   do {
    if (!($70)) {
     $71 = HEAP32[$65>>2]|0;
     $72 = ((($71)) + 48|0);
     $73 = HEAP32[$72>>2]|0;
     $74 = ((($71)) + 108|0);
     $75 = HEAP32[$74>>2]|0;
     $76 = HEAP32[$4>>2]|0;
     $77 = ($76|0)==($73|0);
     if (!($77)) {
      HEAP32[$4>>2] = $73;
      $78 = ($73|0)==(0|0);
      if (!($78)) {
       $79 = ((($73)) + 8|0);
       $80 = HEAP32[$79>>2]|0;HEAP32[$79>>2] = (($80+1)|0);
      }
      $81 = ($76|0)==(0|0);
      if (!($81)) {
       $82 = ((($76)) + 8|0);
       $83 = HEAP32[$82>>2]|0;HEAP32[$82>>2] = (($83-1)|0);
       $84 = ($83|0)==(1);
       if ($84) {
        __THREW__ = 0;
        invoke_viii(3262,($76|0),1,1);
        $85 = __THREW__; __THREW__ = 0;
        $86 = $85&1;
        if ($86) {
         break;
        }
       }
      }
     }
     $87 = ((($61)) + 160|0);
     $88 = HEAP32[$87>>2]|0;
     $89 = ((($73)) + 160|0);
     $90 = HEAP32[$89>>2]|0;
     $91 = ($90|0)==($88|0);
     if (!($91)) {
      HEAP32[$89>>2] = $88;
      $92 = ($88|0)==(0|0);
      if (!($92)) {
       $93 = ((($88)) + 8|0);
       $94 = HEAP32[$93>>2]|0;HEAP32[$93>>2] = (($94+1)|0);
      }
      $95 = ($90|0)==(0|0);
      if (!($95)) {
       $96 = ((($90)) + 8|0);
       $97 = HEAP32[$96>>2]|0;HEAP32[$96>>2] = (($97-1)|0);
       $98 = ($97|0)==(1);
       if ($98) {
        __THREW__ = 0;
        invoke_viii(3262,($90|0),1,1);
        $99 = __THREW__; __THREW__ = 0;
        $100 = $99&1;
        if ($100) {
         break;
        }
       }
      }
     }
     $101 = ((($61)) + 788|0);
     $102 = HEAP32[$101>>2]|0;
     $103 = ((($73)) + 788|0);
     $104 = HEAP32[$103>>2]|0;
     $105 = ($104|0)==($102|0);
     if (!($105)) {
      HEAP32[$103>>2] = $102;
     }
     $106 = ((($61)) + 792|0);
     $107 = HEAP32[$106>>2]|0;
     $108 = ((($73)) + 792|0);
     $109 = HEAP32[$108>>2]|0;
     $110 = ($109|0)==($107|0);
     if (!($110)) {
      HEAP32[$108>>2] = $107;
      $111 = ($107|0)==(0|0);
      if (!($111)) {
       $112 = ((($107)) + 8|0);
       $113 = HEAP32[$112>>2]|0;HEAP32[$112>>2] = (($113+1)|0);
      }
      $114 = ($109|0)==(0|0);
      if (!($114)) {
       $115 = ((($109)) + 8|0);
       $116 = HEAP32[$115>>2]|0;HEAP32[$115>>2] = (($116-1)|0);
       $117 = ($116|0)==(1);
       if ($117) {
        __THREW__ = 0;
        invoke_viii(3262,($109|0),1,1);
        $118 = __THREW__; __THREW__ = 0;
        $119 = $118&1;
        if ($119) {
         break;
        }
       }
      }
     }
     $120 = ($75|0)==(0|0);
     if (!($120)) {
      $$0 = $73;$$091 = $71;$$092 = $75;
      label = 48;
      break L32;
     }
     HEAP32[$2>>2] = 0;
     __THREW__ = 0;
     (invoke_ii(3381,($71|0))|0);
     $121 = __THREW__; __THREW__ = 0;
     $122 = $121&1;
     if (!($122)) {
      $$0 = $73;$$091 = $71;$$092 = $75;
      label = 48;
      break L32;
     }
    }
   } while(0);
   $123 = ___cxa_find_matching_catch_2()|0;
   $124 = tempRet0;
   $$4 = $124;$$490 = $123;
  }
 } while(0);
 do {
  if ((label|0) == 48) {
   $125 = ((($$0)) + 668|0);
   $126 = ((($$0)) + 672|0);
   $127 = HEAP32[$126>>2]|0;
   $128 = HEAP32[$125>>2]|0;
   $129 = (($127) - ($128))|0;
   $130 = $129 >> 2;
   $131 = HEAP32[$13>>2]|0;
   $132 = ($131|0)==(0|0);
   if (!($132)) {
    $133 = ((($131)) + 24|0);
    $134 = HEAP32[$133>>2]|0;
    $135 = ($134|0)==(0|0);
    if (!($135)) {
     $136 = ((($0)) + 232|0);
     $137 = HEAP32[$136>>2]|0;
     $phitmp$i113 = ($137|0)==(0|0);
     if (!($phitmp$i113)) {
      $138 = ((($137)) + 640|0);
      $139 = HEAP32[$138>>2]|0;
      $140 = ($139|0)==(0|0);
      if (!($140)) {
       $141 = HEAP32[$139>>2]|0;
       $142 = ((($141)) + 20|0);
       $143 = HEAP32[$142>>2]|0;
       __THREW__ = 0;
       invoke_vii($143|0,($139|0),($1|0));
       $144 = __THREW__; __THREW__ = 0;
       $145 = $144&1;
       if ($145) {
        $146 = ___cxa_find_matching_catch_2()|0;
        $147 = tempRet0;
        $$4 = $147;$$490 = $146;
        break;
       }
      }
     }
    }
   }
   $148 = ((($0)) + 236|0);
   $149 = HEAP32[$148>>2]|0;
   $150 = ($149|0)!=(0|0);
   $151 = ($63|0)!=($$091|0);
   $$ = $151 & $150;
   $152 = $$&1;
   HEAP8[$5>>0] = $152;
   $153 = ($$092|0)!=(0|0);
   L74: do {
    if ($153) {
     __THREW__ = 0;
     $154 = (invoke_ii(3276,56)|0);
     $155 = __THREW__; __THREW__ = 0;
     $156 = $155&1;
     if ($156) {
      label = 69;
     } else {
      __THREW__ = 0;
      invoke_vi(3672,($154|0));
      $157 = __THREW__; __THREW__ = 0;
      $158 = $157&1;
      if ($158) {
       $211 = ___cxa_find_matching_catch_2()|0;
       $212 = tempRet0;
       __ZdlPv($154);
       $$2 = $212;$$288 = $211;
       break;
      }
      $159 = HEAP32[$154>>2]|0;
      $160 = ((($159)) + -12|0);
      $161 = HEAP32[$160>>2]|0;
      $162 = (($154) + ($161)|0);
      $163 = ((($162)) + 8|0);
      $164 = HEAP32[$163>>2]|0;HEAP32[$163>>2] = (($164+1)|0);
      __THREW__ = 0;
      $165 = (invoke_ii(3276,72)|0);
      $166 = __THREW__; __THREW__ = 0;
      $167 = $166&1;
      do {
       if ($167) {
        label = 71;
       } else {
        __THREW__ = 0;
        invoke_viii(3673,($165|0),($0|0),($1|0));
        $168 = __THREW__; __THREW__ = 0;
        $169 = $168&1;
        if ($169) {
         $215 = ___cxa_find_matching_catch_2()|0;
         $216 = tempRet0;
         __ZdlPv($165);
         $$085 = $216;$$086 = $215;
         break;
        }
        __THREW__ = 0;
        invoke_vii(3449,($$092|0),($165|0));
        $170 = __THREW__; __THREW__ = 0;
        $171 = $170&1;
        if ($171) {
         label = 71;
        } else {
         __THREW__ = 0;
         invoke_vii(3449,($$092|0),($154|0));
         $172 = __THREW__; __THREW__ = 0;
         $173 = $172&1;
         if ($173) {
          label = 71;
         } else {
          $174 = ((($154)) + 20|0);
          $175 = HEAP32[$174>>2]|0;
          $176 = ((($175)) + 8|0);
          $177 = HEAP32[$176>>2]|0;
          __THREW__ = 0;
          (invoke_ii($177|0,($174|0))|0);
          $178 = __THREW__; __THREW__ = 0;
          $179 = $178&1;
          if ($179) {
           label = 71;
          } else {
           $180 = ((($154)) + 40|0);
           $181 = HEAP8[$180>>0]|0;
           $182 = ($181<<24>>24)==(0);
           if ($182) {
            $183 = ((($154)) + 32|0);
            __THREW__ = 0;
            (invoke_iii(2501,($183|0),($174|0))|0);
            $184 = __THREW__; __THREW__ = 0;
            $185 = $184&1;
            if ($185) {
             $186 = ___cxa_find_matching_catch_2()|0;
             $187 = tempRet0;
             $188 = HEAP32[$174>>2]|0;
             $189 = ((($188)) + 12|0);
             $190 = HEAP32[$189>>2]|0;
             __THREW__ = 0;
             (invoke_ii($190|0,($174|0))|0);
             $191 = __THREW__; __THREW__ = 0;
             $192 = $191&1;
             if (!($192)) {
              $eh$lpad$body$index4Z2D = $187;$eh$lpad$body$indexZ2D = $186;
              label = 72;
              break;
             }
             $198 = ___cxa_find_matching_catch_3(0|0)|0;
             $199 = tempRet0;
             ___clang_call_terminate($198);
             // unreachable;
            }
           }
           $193 = HEAP32[$174>>2]|0;
           $194 = ((($193)) + 12|0);
           $195 = HEAP32[$194>>2]|0;
           __THREW__ = 0;
           (invoke_ii($195|0,($174|0))|0);
           $196 = __THREW__; __THREW__ = 0;
           $197 = $196&1;
           if ($197) {
            label = 71;
           } else {
            HEAP8[$5>>0] = 0;
            $200 = HEAP32[$154>>2]|0;
            $201 = ((($200)) + -12|0);
            $202 = HEAP32[$201>>2]|0;
            $203 = (($154) + ($202)|0);
            $204 = ((($203)) + 8|0);
            $205 = HEAP32[$204>>2]|0;HEAP32[$204>>2] = (($205-1)|0);
            $206 = ($205|0)==(1);
            if (!($206)) {
             label = 84;
             break L74;
            }
            __THREW__ = 0;
            invoke_viii(3262,($203|0),1,1);
            $207 = __THREW__; __THREW__ = 0;
            $208 = $207&1;
            if (!($208)) {
             label = 84;
             break L74;
            }
            $217 = ___cxa_find_matching_catch_2()|0;
            $218 = tempRet0;
            $$2 = $218;$$288 = $217;
            break L74;
           }
          }
         }
        }
       }
      } while(0);
      if ((label|0) == 71) {
       $213 = ___cxa_find_matching_catch_2()|0;
       $214 = tempRet0;
       $eh$lpad$body$index4Z2D = $214;$eh$lpad$body$indexZ2D = $213;
       label = 72;
      }
      if ((label|0) == 72) {
       $$085 = $eh$lpad$body$index4Z2D;$$086 = $eh$lpad$body$indexZ2D;
      }
      $219 = HEAP32[$154>>2]|0;
      $220 = ((($219)) + -12|0);
      $221 = HEAP32[$220>>2]|0;
      $222 = (($154) + ($221)|0);
      $223 = ((($222)) + 8|0);
      $224 = HEAP32[$223>>2]|0;HEAP32[$223>>2] = (($224-1)|0);
      $225 = ($224|0)==(1);
      if ($225) {
       __THREW__ = 0;
       invoke_viii(3262,($222|0),1,1);
       $226 = __THREW__; __THREW__ = 0;
       $227 = $226&1;
       if ($227) {
        $343 = ___cxa_find_matching_catch_3(0|0)|0;
        $344 = tempRet0;
        ___clang_call_terminate($343);
        // unreachable;
       } else {
        $$2 = $$085;$$288 = $$086;
       }
      } else {
       $$2 = $$085;$$288 = $$086;
      }
     }
    } else {
     $228 = HEAP32[$0>>2]|0;
     $229 = ((($228)) + 196|0);
     $230 = HEAP32[$229>>2]|0;
     __THREW__ = 0;
     invoke_viiii($230|0,($0|0),($4|0),($2|0),($5|0));
     $231 = __THREW__; __THREW__ = 0;
     $232 = $231&1;
     if ($232) {
      label = 69;
     } else {
      $233 = ((($4)) + 32|0);
      $234 = HEAP32[$233>>2]|0;
      $235 = ((($1)) + 32|0);
      $236 = HEAP32[$235>>2]|0;
      $237 = ($234|0)==($236|0);
      if ($237) {
       label = 84;
      } else {
       HEAP32[$235>>2] = $234;
       $238 = ($234|0)==(0|0);
       if (!($238)) {
        $239 = ((($234)) + 8|0);
        $240 = HEAP32[$239>>2]|0;HEAP32[$239>>2] = (($240+1)|0);
       }
       $241 = ($236|0)==(0|0);
       if ($241) {
        label = 84;
       } else {
        $242 = ((($236)) + 8|0);
        $243 = HEAP32[$242>>2]|0;HEAP32[$242>>2] = (($243-1)|0);
        $244 = ($243|0)==(1);
        if ($244) {
         __THREW__ = 0;
         invoke_viii(3262,($236|0),1,1);
         $245 = __THREW__; __THREW__ = 0;
         $246 = $245&1;
         if ($246) {
          label = 69;
         } else {
          label = 84;
         }
        } else {
         label = 84;
        }
       }
      }
     }
    }
   } while(0);
   L111: do {
    if ((label|0) == 84) {
     $247 = ($$0|0)==($61|0);
     if (!($247)) {
      $248 = ((($$0)) + 788|0);
      $249 = HEAP32[$248>>2]|0;
      $250 = ((($61)) + 788|0);
      $251 = HEAP32[$250>>2]|0;
      $252 = ($251|0)==($249|0);
      if (!($252)) {
       HEAP32[$250>>2] = $249;
      }
      $253 = ((($$0)) + 792|0);
      $254 = HEAP32[$253>>2]|0;
      $255 = ($254|0)==(0|0);
      if (!($255)) {
       HEAP32[$253>>2] = 0;
       $256 = ((($254)) + 8|0);
       $257 = HEAP32[$256>>2]|0;HEAP32[$256>>2] = (($257-1)|0);
       $258 = ($257|0)==(1);
       if ($258) {
        __THREW__ = 0;
        invoke_viii(3262,($254|0),1,1);
        $259 = __THREW__; __THREW__ = 0;
        $260 = $259&1;
        if ($260) {
         label = 69;
         break;
        }
       }
      }
     }
     $261 = HEAP32[$148>>2]|0;
     $262 = ($261|0)!=(0|0);
     $263 = HEAP8[$5>>0]|0;
     $264 = ($263<<24>>24)==(0);
     $or$cond = $262 & $264;
     if ($or$cond) {
      $265 = ($63|0)==(0|0);
      $266 = ($$091|0)==($63|0);
      $or$cond94 = $265 | $266;
      if (!($or$cond94)) {
       __THREW__ = 0;
       (invoke_iii(3674,($63|0),($$091|0))|0);
       $267 = __THREW__; __THREW__ = 0;
       $268 = $267&1;
       if ($268) {
        label = 69;
        break;
       }
      }
      __THREW__ = 0;
      invoke_vii(3675,($0|0),($1|0));
      $269 = __THREW__; __THREW__ = 0;
      $270 = $269&1;
      if ($270) {
       label = 69;
       break;
      }
     }
     $271 = HEAP32[$13>>2]|0;
     $272 = ($271|0)==(0|0);
     if (!($272)) {
      $273 = ((($271)) + 24|0);
      $274 = HEAP32[$273>>2]|0;
      $275 = ($274|0)==(0|0);
      if (!($275)) {
       $276 = ((($0)) + 232|0);
       $277 = HEAP32[$276>>2]|0;
       $phitmp$i102 = ($277|0)==(0|0);
       if (!($phitmp$i102)) {
        $278 = ((($277)) + 644|0);
        $279 = HEAP32[$278>>2]|0;
        $280 = ($279|0)==(0|0);
        if (!($280)) {
         $281 = HEAP32[$279>>2]|0;
         $282 = ((($281)) + 20|0);
         $283 = HEAP32[$282>>2]|0;
         __THREW__ = 0;
         invoke_vii($283|0,($279|0),($1|0));
         $284 = __THREW__; __THREW__ = 0;
         $285 = $284&1;
         if ($285) {
          label = 69;
          break;
         }
        }
       }
      }
     }
     $286 = HEAP32[$65>>2]|0;
     $287 = ($286|0)==(0|0);
     $288 = ($286|0)==($63|0);
     $or$cond127 = $287 | $288;
     if (!($or$cond127)) {
      $289 = HEAP32[$126>>2]|0;
      $290 = HEAP32[$125>>2]|0;
      $291 = (($289) - ($290))|0;
      $292 = $291 >> 2;
      $293 = ($292>>>0)>($130>>>0);
      if ($293) {
       while(1) {
        __THREW__ = 0;
        invoke_vi(3670,($$0|0));
        $294 = __THREW__; __THREW__ = 0;
        $295 = $294&1;
        if ($295) {
         label = 69;
         break L111;
        }
        $296 = HEAP32[$126>>2]|0;
        $297 = HEAP32[$125>>2]|0;
        $298 = (($296) - ($297))|0;
        $299 = $298 >> 2;
        $300 = ($299>>>0)>($130>>>0);
        if (!($300)) {
         break;
        }
       }
      }
      if (!($153)) {
       __THREW__ = 0;
       invoke_v(3676);
       $301 = __THREW__; __THREW__ = 0;
       $302 = $301&1;
       if ($302) {
        label = 69;
        break;
       }
       __THREW__ = 0;
       (invoke_ii(3382,($$091|0))|0);
       $303 = __THREW__; __THREW__ = 0;
       $304 = $303&1;
       if ($304) {
        label = 69;
        break;
       }
      }
     }
     $305 = ($63|0)==(0|0);
     $306 = ($$091|0)==($63|0);
     $or$cond95 = $305 | $306;
     if (!($or$cond95)) {
      HEAP32[$2>>2] = $64;
      __THREW__ = 0;
      (invoke_ii(3381,($63|0))|0);
      $307 = __THREW__; __THREW__ = 0;
      $308 = $307&1;
      if ($308) {
       label = 69;
       break;
      }
     }
     $309 = HEAP32[$0>>2]|0;
     $310 = ((($309)) + 200|0);
     $311 = HEAP32[$310>>2]|0;
     __THREW__ = 0;
     invoke_viii($311|0,($0|0),($1|0),($2|0));
     $312 = __THREW__; __THREW__ = 0;
     $313 = $312&1;
     if ($313) {
      label = 69;
     } else {
      $314 = HEAP32[$13>>2]|0;
      $315 = ($314|0)==(0|0);
      L147: do {
       if (!($315)) {
        $316 = ((($314)) + 24|0);
        $317 = HEAP32[$316>>2]|0;
        $318 = ($317|0)==(0|0);
        do {
         if ($318) {
          $$pr131 = $314;
         } else {
          $319 = ((($0)) + 232|0);
          $320 = HEAP32[$319>>2]|0;
          $phitmp$i98 = ($320|0)==(0|0);
          if ($phitmp$i98) {
           $$pr131 = $314;
          } else {
           $321 = ((($320)) + 648|0);
           $322 = HEAP32[$321>>2]|0;
           $323 = ($322|0)==(0|0);
           if ($323) {
            $$pr131 = $314;
            break;
           }
           $324 = HEAP32[$322>>2]|0;
           $325 = ((($324)) + 20|0);
           $326 = HEAP32[$325>>2]|0;
           __THREW__ = 0;
           invoke_vii($326|0,($322|0),($1|0));
           $327 = __THREW__; __THREW__ = 0;
           $328 = $327&1;
           if ($328) {
            label = 69;
            break L111;
           }
           $$pr$pre = HEAP32[$13>>2]|0;
           $329 = ($$pr$pre|0)==(0|0);
           if ($329) {
            break L147;
           } else {
            $$pr131 = $$pr$pre;
           }
          }
         }
        } while(0);
        $330 = ((($$pr131)) + 24|0);
        $331 = HEAP32[$330>>2]|0;
        $332 = ($331|0)==(0|0);
        if (!($332)) {
         $333 = ((($0)) + 232|0);
         $334 = HEAP32[$333>>2]|0;
         $phitmp$i96 = ($334|0)==(0|0);
         if (!($phitmp$i96)) {
          $335 = ((($1)) + 8|0);
          $336 = HEAP32[$335>>2]|0;
          $337 = ((($1)) + 12|0);
          $338 = HEAP32[$337>>2]|0;
          $339 = ($336|0)==($338|0);
          if ($339) {
           break;
          }
          $340 = ((($338)) + -4|0);
          HEAP32[$337>>2] = $340;
         }
        }
       }
      } while(0);
      __ZN3osg10RenderInfoD2Ev($4);
      STACKTOP = sp;return;
     }
    }
   } while(0);
   if ((label|0) == 69) {
    $209 = ___cxa_find_matching_catch_2()|0;
    $210 = tempRet0;
    $$2 = $210;$$288 = $209;
   }
   $$4 = $$2;$$490 = $$288;
  }
 } while(0);
 __THREW__ = 0;
 invoke_vi(3504,($4|0));
 $341 = __THREW__; __THREW__ = 0;
 $342 = $341&1;
 if ($342) {
  $343 = ___cxa_find_matching_catch_3(0|0)|0;
  $344 = tempRet0;
  ___clang_call_terminate($343);
  // unreachable;
 } else {
  ___resumeException($$490|0);
  // unreachable;
 }
}
function __ZN7osgUtil11RenderStage18drawImplementationERN3osg10RenderInfoERPNS_10RenderLeafE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$pre = 0, $$pre15 = 0, $$pre16 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0.0, $33 = 0, $34 = 0, $35 = 0.0, $36 = 0, $37 = 0, $38 = 0.0, $39 = 0, $4 = 0, $40 = 0, $41 = 0.0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0.0, $56 = 0, $57 = 0.0, $58 = 0, $59 = 0.0, $6 = 0, $60 = 0, $61 = 0.0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0.0, $67 = 0.0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = HEAP32[$1>>2]|0;
 $5 = ((($0)) + 140|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $8 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(1)|0);
  if (!($8)) {
   STACKTOP = sp;return;
  }
  $9 = (__ZN3osg6notifyENS_14NotifySeverityE(1)|0);
  $10 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($9,117692,51)|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ((($11)) + -12|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($10) + ($13)|0);
  __ZNKSt3__28ios_base6getlocEv($3,$14);
  __THREW__ = 0;
  $15 = (invoke_iii(3255,($3|0),(215188|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   $18 = HEAP32[$15>>2]|0;
   $19 = ((($18)) + 28|0);
   $20 = HEAP32[$19>>2]|0;
   __THREW__ = 0;
   $21 = (invoke_iii($20|0,($15|0),10)|0);
   $22 = __THREW__; __THREW__ = 0;
   $23 = $22&1;
   if (!($23)) {
    __ZNSt3__26localeD2Ev($3);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($10,$21)|0);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($10)|0);
    STACKTOP = sp;return;
   }
  }
  $24 = ___cxa_find_matching_catch_2()|0;
  $25 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3263,($3|0));
  $26 = __THREW__; __THREW__ = 0;
  $27 = $26&1;
  if ($27) {
   $28 = ___cxa_find_matching_catch_3(0|0)|0;
   $29 = tempRet0;
   ___clang_call_terminate($28);
   // unreachable;
  } else {
   ___resumeException($24|0);
   // unreachable;
  }
 }
 (__ZN3osg5State14applyAttributeEPKNS_14StateAttributeE($4,$6)|0);
 $30 = HEAP32[$5>>2]|0;
 $31 = ((($30)) + 56|0);
 $32 = +HEAPF64[$31>>3];
 $33 = (~~(($32)));
 $34 = ((($30)) + 64|0);
 $35 = +HEAPF64[$34>>3];
 $36 = (~~(($35)));
 $37 = ((($30)) + 72|0);
 $38 = +HEAPF64[$37>>3];
 $39 = (~~(($38)));
 $40 = ((($30)) + 80|0);
 $41 = +HEAPF64[$40>>3];
 $42 = (~~(($41)));
 _glScissor(($33|0),($36|0),($39|0),($42|0));
 (__ZN3osg5State9applyModeEjb($4,3089,1)|0);
 $43 = ((($0)) + 168|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = ($44|0)==(0|0);
 if ($45) {
  _glColorMask(1,1,1,1);
 } else {
  $46 = HEAP32[$44>>2]|0;
  $47 = ((($46)) + 172|0);
  $48 = HEAP32[$47>>2]|0;
  FUNCTION_TABLE_vii[$48 & 8191]($44,$4);
 }
 $49 = ((($0)) + 164|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = ($50|0)==(0);
 if (!($51)) {
  $52 = $50 & 16384;
  $53 = ($52|0)==(0);
  if ($53) {
   $63 = $50;
  } else {
   $54 = ((($0)) + 172|0);
   $55 = +HEAPF32[$54>>2];
   $56 = ((($0)) + 176|0);
   $57 = +HEAPF32[$56>>2];
   $58 = ((($0)) + 180|0);
   $59 = +HEAPF32[$58>>2];
   $60 = ((($0)) + 184|0);
   $61 = +HEAPF32[$60>>2];
   _glClearColor((+$55),(+$57),(+$59),(+$61));
   $$pre = HEAP32[$49>>2]|0;
   $63 = $$pre;
  }
  $62 = $63 & 256;
  $64 = ($62|0)==(0);
  if ($64) {
   $69 = $63;
  } else {
   $65 = ((($0)) + 208|0);
   $66 = +HEAPF64[$65>>3];
   $67 = $66;
   _glClearDepthf((+$67));
   _glDepthMask(1);
   __ZN3osg5State20haveAppliedAttributeENS_14StateAttribute4TypeEj($4,26,0);
   $$pre15 = HEAP32[$49>>2]|0;
   $69 = $$pre15;
  }
  $68 = $69 & 1024;
  $70 = ($68|0)==(0);
  if ($70) {
   $73 = $69;
  } else {
   $71 = ((($0)) + 216|0);
   $72 = HEAP32[$71>>2]|0;
   _glClearStencil(($72|0));
   _glStencilMask(-1);
   __ZN3osg5State20haveAppliedAttributeENS_14StateAttribute4TypeEj($4,24,0);
   $$pre16 = HEAP32[$49>>2]|0;
   $73 = $$pre16;
  }
  _glClear(($73|0));
 }
 $74 = ((($0)) + 416|0);
 $75 = HEAP32[$74>>2]|0;
 $76 = ($75|0)==(0|0);
 if (!($76)) {
  $77 = HEAP32[$75>>2]|0;
  $78 = ((($77)) + 152|0);
  $79 = HEAP32[$78>>2]|0;
  $80 = ((($0)) + 288|0);
  FUNCTION_TABLE_viiii[$79 & 8191]($75,$4,$2,$80);
 }
 $81 = ((($0)) + 420|0);
 $82 = HEAP32[$81>>2]|0;
 $83 = ($82|0)==(0|0);
 if (!($83)) {
  $84 = HEAP32[$82>>2]|0;
  $85 = ((($84)) + 152|0);
  $86 = HEAP32[$85>>2]|0;
  FUNCTION_TABLE_viiii[$86 & 8191]($82,$4,$2,0);
 }
 __ZN7osgUtil9RenderBin18drawImplementationERN3osg10RenderInfoERPNS_10RenderLeafE($0,$1,$2);
 __ZN3osg5State5applyEv($4);
 STACKTOP = sp;return;
}
function __ZNK7osgUtil11RenderStage34computeNumberOfDynamicRenderLeavesEv($0) {
 $0 = $0|0;
 var $$0$lcssa = 0, $$022 = 0, $$1$lcssa = 0, $$118 = 0, $$sroa$012$0 = 0, $$sroa$012$021 = 0, $$sroa$012$023 = 0, $$sroa$06$0 = 0, $$sroa$06$017 = 0, $$sroa$06$019 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 108|0);
 $$sroa$012$021 = HEAP32[$1>>2]|0;
 $2 = ((($0)) + 104|0);
 $3 = $$sroa$012$021;
 $4 = ($3|0)==($2|0);
 if ($4) {
  $$0$lcssa = 0;
 } else {
  $$022 = 0;$$sroa$012$023 = $$sroa$012$021;$20 = $3;
  while(1) {
   $11 = $$sroa$012$023;
   $12 = ((($11)) + 12|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = HEAP32[$13>>2]|0;
   $15 = ((($14)) + 180|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (FUNCTION_TABLE_ii[$16 & 8191]($13)|0);
   $18 = (($17) + ($$022))|0;
   $19 = ((($20)) + 4|0);
   $$sroa$012$0 = HEAP32[$19>>2]|0;
   $21 = $$sroa$012$0;
   $22 = ($21|0)==($2|0);
   if ($22) {
    $$0$lcssa = $18;
    break;
   } else {
    $$022 = $18;$$sroa$012$023 = $$sroa$012$0;$20 = $21;
   }
  }
 }
 $5 = (__ZNK7osgUtil9RenderBin34computeNumberOfDynamicRenderLeavesEv($0)|0);
 $6 = (($5) + ($$0$lcssa))|0;
 $7 = ((($0)) + 120|0);
 $$sroa$06$017 = HEAP32[$7>>2]|0;
 $8 = ((($0)) + 116|0);
 $9 = $$sroa$06$017;
 $10 = ($9|0)==($8|0);
 if ($10) {
  $$1$lcssa = $6;
  return ($$1$lcssa|0);
 } else {
  $$118 = $6;$$sroa$06$019 = $$sroa$06$017;$32 = $9;
 }
 while(1) {
  $23 = $$sroa$06$019;
  $24 = ((($23)) + 12|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = HEAP32[$25>>2]|0;
  $27 = ((($26)) + 180|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (FUNCTION_TABLE_ii[$28 & 8191]($25)|0);
  $30 = (($29) + ($$118))|0;
  $31 = ((($32)) + 4|0);
  $$sroa$06$0 = HEAP32[$31>>2]|0;
  $33 = $$sroa$06$0;
  $34 = ($33|0)==($8|0);
  if ($34) {
   $$1$lcssa = $30;
   break;
  } else {
   $$118 = $30;$$sroa$06$019 = $$sroa$06$0;$32 = $33;
  }
 }
 return ($$1$lcssa|0);
}
function __ZN7osgUtil11RenderStage22addPositionedAttributeEPN3osg10RefMatrixdEPKNS1_14StateAttributeE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 420|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  $6 = (__Znwj(56)|0);
  __THREW__ = 0;
  invoke_vi(3628,($6|0));
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if ($8) {
   $17 = ___cxa_find_matching_catch_2()|0;
   $18 = tempRet0;
   __ZdlPv($6);
   ___resumeException($17|0);
   // unreachable;
  }
  $9 = HEAP32[$3>>2]|0;
  $10 = ($9|0)==($6|0);
  if (!($10)) {
   HEAP32[$3>>2] = $6;
   $11 = ((($6)) + 8|0);
   $12 = HEAP32[$11>>2]|0;HEAP32[$11>>2] = (($12+1)|0);
   $13 = ($9|0)==(0|0);
   if (!($13)) {
    $14 = ((($9)) + 8|0);
    $15 = HEAP32[$14>>2]|0;HEAP32[$14>>2] = (($15-1)|0);
    $16 = ($15|0)==(1);
    if ($16) {
     __ZNK3osg10Referenced24signalObserversAndDeleteEbb($9,1,1);
    }
   }
  }
 }
 $19 = HEAP32[$3>>2]|0;
 $20 = HEAP32[$19>>2]|0;
 $21 = ((($20)) + 144|0);
 $22 = HEAP32[$21>>2]|0;
 FUNCTION_TABLE_viii[$22 & 8191]($19,$1,$2);
 return;
}
function __ZN7osgUtil11RenderStage29addPositionedTextureAttributeEjPN3osg10RefMatrixdEPKNS1_14StateAttributeE($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ((($0)) + 420|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $7 = (__Znwj(56)|0);
  __THREW__ = 0;
  invoke_vi(3628,($7|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if ($9) {
   $18 = ___cxa_find_matching_catch_2()|0;
   $19 = tempRet0;
   __ZdlPv($7);
   ___resumeException($18|0);
   // unreachable;
  }
  $10 = HEAP32[$4>>2]|0;
  $11 = ($10|0)==($7|0);
  if (!($11)) {
   HEAP32[$4>>2] = $7;
   $12 = ((($7)) + 8|0);
   $13 = HEAP32[$12>>2]|0;HEAP32[$12>>2] = (($13+1)|0);
   $14 = ($10|0)==(0|0);
   if (!($14)) {
    $15 = ((($10)) + 8|0);
    $16 = HEAP32[$15>>2]|0;HEAP32[$15>>2] = (($16-1)|0);
    $17 = ($16|0)==(1);
    if ($17) {
     __ZNK3osg10Referenced24signalObserversAndDeleteEbb($10,1,1);
    }
   }
  }
 }
 $20 = HEAP32[$4>>2]|0;
 $21 = HEAP32[$20>>2]|0;
 $22 = ((($21)) + 148|0);
 $23 = HEAP32[$22>>2]|0;
 FUNCTION_TABLE_viiii[$23 & 8191]($20,$1,$2,$3);
 return;
}
function __ZN7osgUtil11RenderStage19drawPreRenderStagesERN3osg10RenderInfoERPNS_10RenderLeafE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$sroa$04$0 = 0, $$sroa$04$010 = 0, $$sroa$04$09 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 112|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 if ($5) {
  return;
 }
 $6 = ((($0)) + 108|0);
 $$sroa$04$09 = HEAP32[$6>>2]|0;
 $7 = ((($0)) + 104|0);
 $8 = $$sroa$04$09;
 $9 = ($8|0)==($7|0);
 if ($9) {
  return;
 } else {
  $$sroa$04$010 = $$sroa$04$09;$17 = $8;
 }
 while(1) {
  $10 = $$sroa$04$010;
  $11 = ((($10)) + 12|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = HEAP32[$12>>2]|0;
  $14 = ((($13)) + 172|0);
  $15 = HEAP32[$14>>2]|0;
  FUNCTION_TABLE_viii[$15 & 8191]($12,$1,$2);
  $16 = ((($17)) + 4|0);
  $$sroa$04$0 = HEAP32[$16>>2]|0;
  $18 = $$sroa$04$0;
  $19 = ($18|0)==($7|0);
  if ($19) {
   break;
  } else {
   $$sroa$04$010 = $$sroa$04$0;$17 = $18;
  }
 }
 return;
}
function __ZN7osgUtil11RenderStage9drawInnerERN3osg10RenderInfoERPNS_10RenderLeafERb($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$$073 = 0, $$$073$us = 0, $$$074 = 0, $$$074$us = 0, $$0 = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i80 = 0, $$0$i$i$i$i80$us = 0, $$0$i$i$i$i86 = 0, $$0$i$i$i84$sink$be = 0, $$0$i$i$i84$sink$be$us = 0, $$0$i$i$i84$sink128 = 0, $$0$i$i$i84$sink128$us = 0, $$073 = 0, $$073$us = 0, $$074 = 0, $$074$us = 0, $$076$lcssa = 0, $$076131 = 0, $$177 = 0;
 var $$pre = 0, $$sroa$0112$0$be = 0, $$sroa$0112$0130 = 0, $$sroa$092$0$be = 0, $$sroa$092$0127 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0.0, $108 = 0, $109 = 0, $11 = 0, $110 = 0.0, $111 = 0, $112 = 0;
 var $113 = 0.0, $114 = 0.0, $115 = 0, $116 = 0, $117 = 0.0, $118 = 0.0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0.0, $151 = 0, $152 = 0, $153 = 0.0, $154 = 0, $155 = 0, $156 = 0.0, $157 = 0, $158 = 0, $159 = 0.0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0;
 var $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0.0, $197 = 0, $198 = 0, $199 = 0.0, $20 = 0, $200 = 0, $201 = 0, $202 = 0.0, $203 = 0;
 var $204 = 0, $205 = 0.0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0;
 var $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0;
 var $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0;
 var $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0;
 var $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $4 = sp;
 $5 = sp + 4|0;
 $6 = HEAP32[$1>>2]|0;
 $7 = ((($0)) + 272|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if ($9) {
  $23 = 0;$25 = 0;$289 = 0;
 } else {
  $10 = ((($6)) + 784|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($11|0)==(0|0);
  if ($12) {
   $23 = 0;$25 = 0;$289 = 0;
  } else {
   $13 = ((($11)) + 1252|0);
   $14 = HEAP8[$13>>0]|0;
   $15 = ($14<<24>>24)==(0);
   if ($15) {
    $23 = 1;$25 = $11;$289 = 0;
   } else {
    $16 = HEAP32[$8>>2]|0;
    $17 = ((($16)) + 172|0);
    $18 = HEAP32[$17>>2]|0;
    FUNCTION_TABLE_vii[$18 & 8191]($8,$6);
    $23 = 1;$25 = $11;$289 = 1;
   }
  }
 }
 __ZN7osgUtil9RenderBin4drawERN3osg10RenderInfoERPNS_10RenderLeafE($0,$1,$2);
 $19 = ((($6)) + 344|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)==(0);
 do {
  if (!($21)) {
   $22 = (__ZNK3osg5State13checkGLErrorsEPKcS2_($6,117507,0)|0);
   $or$cond = $23 & $22;
   if ($or$cond) {
    $24 = ((($25)) + 1292|0);
    $26 = HEAP32[$24>>2]|0;
    $27 = (FUNCTION_TABLE_ii[$26 & 8191](36160)|0);
    $28 = ($27|0)==(36053);
    if (!($28)) {
     $29 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
     if ($29) {
      $30 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
      $31 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($30,117533,41)|0);
      $32 = HEAP32[$31>>2]|0;
      $33 = ((($32)) + -12|0);
      $34 = HEAP32[$33>>2]|0;
      $35 = (($31) + ($34)|0);
      $36 = ((($35)) + 4|0);
      $37 = HEAP32[$36>>2]|0;
      $38 = $37 & -75;
      $39 = $38 | 8;
      HEAP32[$36>>2] = $39;
      $40 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($31,$27)|0);
      $41 = HEAP32[$40>>2]|0;
      $42 = ((($41)) + -12|0);
      $43 = HEAP32[$42>>2]|0;
      $44 = (($40) + ($43)|0);
      $45 = ((($44)) + 4|0);
      $46 = HEAP32[$45>>2]|0;
      $47 = $46 & -75;
      $48 = $47 | 2;
      HEAP32[$45>>2] = $48;
      $49 = HEAP32[$40>>2]|0;
      $50 = ((($49)) + -12|0);
      $51 = HEAP32[$50>>2]|0;
      $52 = (($40) + ($51)|0);
      __ZNKSt3__28ios_base6getlocEv($4,$52);
      __THREW__ = 0;
      $53 = (invoke_iii(3255,($4|0),(215188|0))|0);
      $54 = __THREW__; __THREW__ = 0;
      $55 = $54&1;
      if (!($55)) {
       $56 = HEAP32[$53>>2]|0;
       $57 = ((($56)) + 28|0);
       $58 = HEAP32[$57>>2]|0;
       __THREW__ = 0;
       $59 = (invoke_iii($58|0,($53|0),10)|0);
       $60 = __THREW__; __THREW__ = 0;
       $61 = $60&1;
       if (!($61)) {
        __ZNSt3__26localeD2Ev($4);
        (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($40,$59)|0);
        (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($40)|0);
        break;
       }
      }
      $62 = ___cxa_find_matching_catch_2()|0;
      $63 = tempRet0;
      __THREW__ = 0;
      invoke_vi(3263,($4|0));
      $64 = __THREW__; __THREW__ = 0;
      $65 = $64&1;
      if ($65) {
       $66 = ___cxa_find_matching_catch_3(0|0)|0;
       $67 = tempRet0;
       ___clang_call_terminate($66);
       // unreachable;
      } else {
       ___resumeException($62|0);
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 if ($289) {
  $68 = HEAP32[$7>>2]|0;
  HEAP8[$5>>0] = 0;
  $69 = ((($0)) + 276|0);
  $70 = HEAP32[$69>>2]|0;
  $71 = ($70|0)==(0|0);
  if ($71) {
   $$0 = $68;
  } else {
   $72 = ((($25)) + 1328|0);
   $73 = HEAP32[$72>>2]|0;
   $74 = ($73|0)==(0|0);
   if ($74) {
    $$0 = $68;
   } else {
    $75 = ((($70)) + 56|0);
    $76 = HEAP32[$75>>2]|0;
    $77 = ((($70)) + 60|0);
    $78 = ($76|0)==($77|0);
    L23: do {
     if ($78) {
      $$076$lcssa = 0;
     } else {
      $$076131 = 0;$$sroa$0112$0130 = $76;
      while(1) {
       $81 = ((($$sroa$0112$0130)) + 16|0);
       $82 = HEAP32[$81>>2]|0;
       switch ($82|0) {
       case 0:  {
        $83 = $$076131 | 256;
        $$177 = $83;
        break;
       }
       case 1:  {
        $84 = $$076131 | 1024;
        $$177 = $84;
        break;
       }
       case 2:  {
        $85 = $$076131 | 1280;
        $$177 = $85;
        break;
       }
       case 3:  {
        $86 = $$076131 | 16384;
        $$177 = $86;
        break;
       }
       default: {
        $$177 = $$076131;
       }
       }
       $87 = ((($$sroa$0112$0130)) + 4|0);
       $88 = HEAP32[$87>>2]|0;
       $89 = ($88|0)==(0|0);
       if ($89) {
        $90 = ((($$sroa$0112$0130)) + 8|0);
        $91 = HEAP32[$90>>2]|0;
        $92 = HEAP32[$91>>2]|0;
        $93 = ($92|0)==($$sroa$0112$0130|0);
        if ($93) {
         $$sroa$0112$0$be = $91;
        } else {
         $98 = $90;
         while(1) {
          $97 = HEAP32[$98>>2]|0;
          $99 = ((($97)) + 8|0);
          $100 = HEAP32[$99>>2]|0;
          $101 = HEAP32[$100>>2]|0;
          $102 = ($101|0)==($97|0);
          if ($102) {
           $$sroa$0112$0$be = $100;
           break;
          } else {
           $98 = $99;
          }
         }
        }
       } else {
        $$0$i$i$i$i86 = $88;
        while(1) {
         $95 = HEAP32[$$0$i$i$i$i86>>2]|0;
         $96 = ($95|0)==(0|0);
         if ($96) {
          break;
         } else {
          $$0$i$i$i$i86 = $95;
         }
        }
        $$sroa$0112$0$be = $$0$i$i$i$i86;
       }
       $94 = ($$sroa$0112$0$be|0)==($77|0);
       if ($94) {
        $$076$lcssa = $$177;
        break L23;
       } else {
        $$076131 = $$177;$$sroa$0112$0130 = $$sroa$0112$0$be;
       }
      }
     }
    } while(0);
    __ZNK3osg17FrameBufferObject5applyERNS_5StateENS0_10BindTargetE($68,$6,36008);
    $79 = HEAP32[$69>>2]|0;
    __ZNK3osg17FrameBufferObject5applyERNS_5StateENS0_10BindTargetE($79,$6,36009);
    $80 = ($$076$lcssa|0)==(0);
    if (!($80)) {
     $103 = HEAP32[$72>>2]|0;
     $104 = ((($0)) + 140|0);
     $105 = HEAP32[$104>>2]|0;
     $106 = ((($105)) + 56|0);
     $107 = +HEAPF64[$106>>3];
     $108 = (~~(($107)));
     $109 = ((($105)) + 64|0);
     $110 = +HEAPF64[$109>>3];
     $111 = (~~(($110)));
     $112 = ((($105)) + 72|0);
     $113 = +HEAPF64[$112>>3];
     $114 = $107 + $113;
     $115 = (~~(($114)));
     $116 = ((($105)) + 80|0);
     $117 = +HEAPF64[$116>>3];
     $118 = $110 + $117;
     $119 = (~~(($118)));
     FUNCTION_TABLE_viiiiiiiiii[$103 & 8191]($108,$111,$115,$119,$108,$111,$115,$119,$$076$lcssa,9728);
    }
    HEAP8[$5>>0] = 1;
    $120 = HEAP32[$69>>2]|0;
    $$0 = $120;
   }
  }
 } else {
  HEAP8[$5>>0] = 0;
  $$0 = 0;
 }
 $121 = HEAP8[$3>>0]|0;
 $122 = ($121<<24>>24)==(0);
 if (!($122)) {
  $123 = ($$0|0)==(0|0);
  if (!($123)) {
   __ZZN7osgUtil11RenderStage9drawInnerERN3osg10RenderInfoERPNS_10RenderLeafERbEN7SubFunc12applyReadFBOES7_PKNS1_17FrameBufferObjectERNS1_5StateE($5,$$0,$6);
  }
  __ZN7osgUtil11RenderStage11copyTextureERN3osg10RenderInfoE($0,$1);
 }
 $124 = ((($0)) + 260|0);
 $125 = HEAP32[$124>>2]|0;
 $126 = ((($0)) + 264|0);
 $127 = ($125|0)==($126|0);
 if (!($127)) {
  $128 = ($$0|0)==(0|0);
  $129 = ((($0)) + 252|0);
  $130 = ((($0)) + 256|0);
  $131 = ((($0)) + 140|0);
  if ($128) {
   $$0$i$i$i84$sink128$us = $125;
   while(1) {
    $132 = ((($$0$i$i$i84$sink128$us)) + 20|0);
    $133 = HEAP32[$132>>2]|0;
    $134 = ($133|0)==(0|0);
    if (!($134)) {
     $135 = ((($133)) + 92|0);
     $136 = HEAP32[$135>>2]|0;
     $137 = ($136|0)==(0);
     if ($137) {
      $138 = HEAP32[$129>>2]|0;
      $$074$us = $138;
     } else {
      $$074$us = $136;
     }
     $139 = ($$074$us|0)==(0);
     $$$074$us = $139 ? 6407 : $$074$us;
     $140 = ((($133)) + 96|0);
     $141 = HEAP32[$140>>2]|0;
     $142 = ($141|0)==(0);
     if ($142) {
      $143 = HEAP32[$130>>2]|0;
      $$073$us = $143;
     } else {
      $$073$us = $141;
     }
     $144 = ($$073$us|0)==(0);
     $$$073$us = $144 ? 5121 : $$073$us;
     $145 = HEAP32[$133>>2]|0;
     $146 = ((($145)) + 184|0);
     $147 = HEAP32[$146>>2]|0;
     $148 = HEAP32[$131>>2]|0;
     $149 = ((($148)) + 56|0);
     $150 = +HEAPF64[$149>>3];
     $151 = (~~(($150)));
     $152 = ((($148)) + 64|0);
     $153 = +HEAPF64[$152>>3];
     $154 = (~~(($153)));
     $155 = ((($148)) + 72|0);
     $156 = +HEAPF64[$155>>3];
     $157 = (~~(($156)));
     $158 = ((($148)) + 80|0);
     $159 = +HEAPF64[$158>>3];
     $160 = (~~(($159)));
     FUNCTION_TABLE_viiiiiiii[$147 & 8191]($133,$151,$154,$157,$160,$$$074$us,$$$073$us,1);
    }
    $161 = ((($$0$i$i$i84$sink128$us)) + 4|0);
    $162 = HEAP32[$161>>2]|0;
    $163 = ($162|0)==(0|0);
    if ($163) {
     $166 = ((($$0$i$i$i84$sink128$us)) + 8|0);
     $167 = HEAP32[$166>>2]|0;
     $168 = HEAP32[$167>>2]|0;
     $169 = ($168|0)==($$0$i$i$i84$sink128$us|0);
     if ($169) {
      $$0$i$i$i84$sink$be$us = $167;
     } else {
      $171 = $166;
      while(1) {
       $170 = HEAP32[$171>>2]|0;
       $172 = ((($170)) + 8|0);
       $173 = HEAP32[$172>>2]|0;
       $174 = HEAP32[$173>>2]|0;
       $175 = ($174|0)==($170|0);
       if ($175) {
        $$0$i$i$i84$sink$be$us = $173;
        break;
       } else {
        $171 = $172;
       }
      }
     }
    } else {
     $$0$i$i$i$i80$us = $162;
     while(1) {
      $164 = HEAP32[$$0$i$i$i$i80$us>>2]|0;
      $165 = ($164|0)==(0|0);
      if ($165) {
       break;
      } else {
       $$0$i$i$i$i80$us = $164;
      }
     }
     $$0$i$i$i84$sink$be$us = $$0$i$i$i$i80$us;
    }
    $176 = ($$0$i$i$i84$sink$be$us|0)==($126|0);
    if ($176) {
     break;
    } else {
     $$0$i$i$i84$sink128$us = $$0$i$i$i84$sink$be$us;
    }
   }
  } else {
   $$0$i$i$i84$sink128 = $125;
   while(1) {
    $177 = ((($$0$i$i$i84$sink128)) + 20|0);
    $178 = HEAP32[$177>>2]|0;
    $179 = ($178|0)==(0|0);
    if (!($179)) {
     __ZZN7osgUtil11RenderStage9drawInnerERN3osg10RenderInfoERPNS_10RenderLeafERbEN7SubFunc12applyReadFBOES7_PKNS1_17FrameBufferObjectERNS1_5StateE($5,$$0,$6);
     $180 = HEAP32[$177>>2]|0;
     $181 = ((($180)) + 92|0);
     $182 = HEAP32[$181>>2]|0;
     $183 = ($182|0)==(0);
     if ($183) {
      $184 = HEAP32[$129>>2]|0;
      $$074 = $184;
     } else {
      $$074 = $182;
     }
     $185 = ($$074|0)==(0);
     $$$074 = $185 ? 6407 : $$074;
     $186 = ((($180)) + 96|0);
     $187 = HEAP32[$186>>2]|0;
     $188 = ($187|0)==(0);
     if ($188) {
      $189 = HEAP32[$130>>2]|0;
      $$073 = $189;
     } else {
      $$073 = $187;
     }
     $190 = ($$073|0)==(0);
     $$$073 = $190 ? 5121 : $$073;
     $191 = HEAP32[$180>>2]|0;
     $192 = ((($191)) + 184|0);
     $193 = HEAP32[$192>>2]|0;
     $194 = HEAP32[$131>>2]|0;
     $195 = ((($194)) + 56|0);
     $196 = +HEAPF64[$195>>3];
     $197 = (~~(($196)));
     $198 = ((($194)) + 64|0);
     $199 = +HEAPF64[$198>>3];
     $200 = (~~(($199)));
     $201 = ((($194)) + 72|0);
     $202 = +HEAPF64[$201>>3];
     $203 = (~~(($202)));
     $204 = ((($194)) + 80|0);
     $205 = +HEAPF64[$204>>3];
     $206 = (~~(($205)));
     FUNCTION_TABLE_viiiiiiii[$193 & 8191]($180,$197,$200,$203,$206,$$$074,$$$073,1);
    }
    $207 = ((($$0$i$i$i84$sink128)) + 4|0);
    $208 = HEAP32[$207>>2]|0;
    $209 = ($208|0)==(0|0);
    if ($209) {
     $210 = ((($$0$i$i$i84$sink128)) + 8|0);
     $211 = HEAP32[$210>>2]|0;
     $212 = HEAP32[$211>>2]|0;
     $213 = ($212|0)==($$0$i$i$i84$sink128|0);
     if ($213) {
      $$0$i$i$i84$sink$be = $211;
     } else {
      $218 = $210;
      while(1) {
       $217 = HEAP32[$218>>2]|0;
       $219 = ((($217)) + 8|0);
       $220 = HEAP32[$219>>2]|0;
       $221 = HEAP32[$220>>2]|0;
       $222 = ($221|0)==($217|0);
       if ($222) {
        $$0$i$i$i84$sink$be = $220;
        break;
       } else {
        $218 = $219;
       }
      }
     }
    } else {
     $$0$i$i$i$i80 = $208;
     while(1) {
      $215 = HEAP32[$$0$i$i$i$i80>>2]|0;
      $216 = ($215|0)==(0|0);
      if ($216) {
       break;
      } else {
       $$0$i$i$i$i80 = $215;
      }
     }
     $$0$i$i$i84$sink$be = $$0$i$i$i$i80;
    }
    $214 = ($$0$i$i$i84$sink$be|0)==($126|0);
    if ($214) {
     break;
    } else {
     $$0$i$i$i84$sink128 = $$0$i$i$i84$sink$be;
    }
   }
  }
 }
 if (!($289)) {
  STACKTOP = sp;return;
 }
 $223 = ((($0)) + 284|0);
 $224 = HEAP8[$223>>0]|0;
 $225 = ($224<<24>>24)==(0);
 if (!($225)) {
  $226 = ((($6)) + 120|0);
  $227 = HEAP32[$226>>2]|0;
  $228 = ($227|0)==(0|0);
  if ($228) {
   $233 = 0;
  } else {
   $229 = ((($227)) + 128|0);
   $230 = HEAP32[$229>>2]|0;
   $233 = $230;
  }
  $231 = ((($25)) + 1280|0);
  $232 = HEAP32[$231>>2]|0;
  FUNCTION_TABLE_vii[$232 & 8191](36160,$233);
 }
 HEAP8[$3>>0] = 1;
 $234 = ((($0)) + 228|0);
 $235 = HEAP32[$234>>2]|0;
 $236 = ($235|0)==(0|0);
 if ($236) {
  STACKTOP = sp;return;
 }
 $237 = ((($235)) + 24|0);
 $238 = HEAP32[$237>>2]|0;
 $239 = ($238|0)==(0|0);
 if ($239) {
  STACKTOP = sp;return;
 }
 $240 = ((($0)) + 232|0);
 $241 = HEAP32[$240>>2]|0;
 $phitmp$i = ($241|0)==(0|0);
 if ($phitmp$i) {
  STACKTOP = sp;return;
 }
 $242 = ((($241)) + 584|0);
 $243 = HEAP32[$242>>2]|0;
 $244 = ((($241)) + 588|0);
 $245 = ($243|0)==($244|0);
 if ($245) {
  STACKTOP = sp;return;
 }
 $246 = ((($6)) + 688|0);
 $247 = ((($25)) + 1324|0);
 $248 = ((($6)) + 728|0);
 $249 = ((($6)) + 716|0);
 $250 = ((($6)) + 720|0);
 $$sroa$092$0127 = $243;
 while(1) {
  $251 = ((($$sroa$092$0127)) + 28|0);
  $252 = HEAP32[$251>>2]|0;
  $253 = ($252|0)==(0|0);
  if (!($253)) {
   $254 = ((($$sroa$092$0127)) + 40|0);
   $255 = HEAP8[$254>>0]|0;
   $256 = ($255<<24>>24)==(0);
   if (!($256)) {
    $257 = HEAP32[$246>>2]|0;
    $258 = ($257|0)==(0);
    if ($258) {
     $266 = $252;
    } else {
     $259 = HEAP32[$248>>2]|0;
     $260 = ($259|0)==(0|0);
     if ($260) {
      $266 = $252;
     } else {
      $261 = HEAP32[$249>>2]|0;
      $262 = HEAP32[$250>>2]|0;
      $263 = ($261|0)>($262|0);
      $264 = $263 ? $261 : $262;
      $265 = ($264|0)==(0);
      if ($265) {
       $266 = $252;
      } else {
       FUNCTION_TABLE_vi[$259 & 8191](33984);
       HEAP32[$246>>2] = 0;
       $$pre = HEAP32[$251>>2]|0;
       $266 = $$pre;
      }
     }
    }
    (__ZN3osg5State21applyTextureAttributeEjPKNS_14StateAttributeE($6,0,$266)|0);
    $267 = HEAP32[$247>>2]|0;
    $268 = HEAP32[$251>>2]|0;
    $269 = HEAP32[$268>>2]|0;
    $270 = ((($269)) + 180|0);
    $271 = HEAP32[$270>>2]|0;
    $272 = (FUNCTION_TABLE_ii[$271 & 8191]($268)|0);
    FUNCTION_TABLE_vi[$267 & 8191]($272);
   }
  }
  $273 = ((($$sroa$092$0127)) + 4|0);
  $274 = HEAP32[$273>>2]|0;
  $275 = ($274|0)==(0|0);
  if ($275) {
   $276 = ((($$sroa$092$0127)) + 8|0);
   $277 = HEAP32[$276>>2]|0;
   $278 = HEAP32[$277>>2]|0;
   $279 = ($278|0)==($$sroa$092$0127|0);
   if ($279) {
    $$sroa$092$0$be = $277;
   } else {
    $284 = $276;
    while(1) {
     $283 = HEAP32[$284>>2]|0;
     $285 = ((($283)) + 8|0);
     $286 = HEAP32[$285>>2]|0;
     $287 = HEAP32[$286>>2]|0;
     $288 = ($287|0)==($283|0);
     if ($288) {
      $$sroa$092$0$be = $286;
      break;
     } else {
      $284 = $285;
     }
    }
   }
  } else {
   $$0$i$i$i$i = $274;
   while(1) {
    $281 = HEAP32[$$0$i$i$i$i>>2]|0;
    $282 = ($281|0)==(0|0);
    if ($282) {
     break;
    } else {
     $$0$i$i$i$i = $281;
    }
   }
   $$sroa$092$0$be = $$0$i$i$i$i;
  }
  $280 = ($$sroa$092$0$be|0)==($244|0);
  if ($280) {
   break;
  } else {
   $$sroa$092$0127 = $$sroa$092$0$be;
  }
 }
 STACKTOP = sp;return;
}
function __ZN7osgUtil11RenderStage20drawPostRenderStagesERN3osg10RenderInfoERPNS_10RenderLeafE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$sroa$04$0 = 0, $$sroa$04$010 = 0, $$sroa$04$09 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 124|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 if ($5) {
  return;
 }
 $6 = ((($0)) + 120|0);
 $$sroa$04$09 = HEAP32[$6>>2]|0;
 $7 = ((($0)) + 116|0);
 $8 = $$sroa$04$09;
 $9 = ($8|0)==($7|0);
 if ($9) {
  return;
 } else {
  $$sroa$04$010 = $$sroa$04$09;$17 = $8;
 }
 while(1) {
  $10 = $$sroa$04$010;
  $11 = ((($10)) + 12|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = HEAP32[$12>>2]|0;
  $14 = ((($13)) + 172|0);
  $15 = HEAP32[$14>>2]|0;
  FUNCTION_TABLE_viii[$15 & 8191]($12,$1,$2);
  $16 = ((($17)) + 4|0);
  $$sroa$04$0 = HEAP32[$16>>2]|0;
  $18 = $$sroa$04$0;
  $19 = ($18|0)==($7|0);
  if ($19) {
   break;
  } else {
   $$sroa$04$010 = $$sroa$04$0;$17 = $18;
  }
 }
 return;
}
function __ZZN7osgUtil11RenderStage9drawInnerERN3osg10RenderInfoERPNS_10RenderLeafERbEN7SubFunc12applyReadFBOES7_PKNS1_17FrameBufferObjectERNS1_5StateE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = (__ZNK3osg17FrameBufferObject13isMultisampleEv($1)|0);
 do {
  if ($4) {
   $5 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
   if ($5) {
    $6 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
    $7 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($6,117575,116)|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = ((($8)) + -12|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (($7) + ($10)|0);
    __ZNKSt3__28ios_base6getlocEv($3,$11);
    __THREW__ = 0;
    $12 = (invoke_iii(3255,($3|0),(215188|0))|0);
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if (!($14)) {
     $15 = HEAP32[$12>>2]|0;
     $16 = ((($15)) + 28|0);
     $17 = HEAP32[$16>>2]|0;
     __THREW__ = 0;
     $18 = (invoke_iii($17|0,($12|0),10)|0);
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if (!($20)) {
      __ZNSt3__26localeD2Ev($3);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($7,$18)|0);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($7)|0);
      break;
     }
    }
    $21 = ___cxa_find_matching_catch_2()|0;
    $22 = tempRet0;
    __THREW__ = 0;
    invoke_vi(3263,($3|0));
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if ($24) {
     $25 = ___cxa_find_matching_catch_3(0|0)|0;
     $26 = tempRet0;
     ___clang_call_terminate($25);
     // unreachable;
    } else {
     ___resumeException($21|0);
     // unreachable;
    }
   }
  }
 } while(0);
 $27 = HEAP8[$0>>0]|0;
 $28 = ($27<<24>>24)==(0);
 if ($28) {
  STACKTOP = sp;return;
 }
 __ZNK3osg17FrameBufferObject5applyERNS_5StateENS0_10BindTargetE($1,$2,36008);
 HEAP8[$0>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN7osgUtil11RenderStage11copyTextureERN3osg10RenderInfoE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0.0, $12 = 0, $13 = 0, $14 = 0.0, $15 = 0, $16 = 0, $17 = 0.0, $18 = 0, $19 = 0, $2 = 0, $20 = 0.0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0.0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0.0, $31 = 0, $32 = 0, $33 = 0.0, $34 = 0, $35 = 0, $36 = 0.0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0.0, $44 = 0, $45 = 0, $46 = 0.0;
 var $47 = 0, $48 = 0, $49 = 0.0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0.0, $57 = 0, $58 = 0, $59 = 0.0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0.0;
 var $65 = 0, $66 = 0, $67 = 0.0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0.0, $77 = 0, $78 = 0, $79 = 0.0, $8 = 0, $80 = 0, $81 = 0, $82 = 0.0;
 var $83 = 0, $84 = 0, $85 = 0.0, $86 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 236|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  return;
 }
 $6 = (___dynamic_cast($4,26864,26784,0)|0);
 $7 = ($6|0)==(0|0);
 if (!($7)) {
  $8 = ((($0)) + 140|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ((($9)) + 56|0);
  $11 = +HEAPF64[$10>>3];
  $12 = (~~(($11)));
  $13 = ((($9)) + 64|0);
  $14 = +HEAPF64[$13>>3];
  $15 = (~~(($14)));
  $16 = ((($9)) + 72|0);
  $17 = +HEAPF64[$16>>3];
  $18 = (~~(($17)));
  $19 = ((($9)) + 80|0);
  $20 = +HEAPF64[$19>>3];
  $21 = (~~(($20)));
  __ZN3osg9Texture2D17copyTexSubImage2DERNS_5StateEiiiiii($6,$2,$12,$15,$12,$15,$18,$21);
  return;
 }
 $22 = (___dynamic_cast($4,26864,26912,0)|0);
 $23 = ($22|0)==(0|0);
 if (!($23)) {
  $24 = ((($0)) + 140|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = ((($25)) + 56|0);
  $27 = +HEAPF64[$26>>3];
  $28 = (~~(($27)));
  $29 = ((($25)) + 64|0);
  $30 = +HEAPF64[$29>>3];
  $31 = (~~(($30)));
  $32 = ((($25)) + 72|0);
  $33 = +HEAPF64[$32>>3];
  $34 = (~~(($33)));
  $35 = ((($25)) + 80|0);
  $36 = +HEAPF64[$35>>3];
  $37 = (~~(($36)));
  __ZN3osg16TextureRectangle17copyTexSubImage2DERNS_5StateEiiiiii($22,$2,$28,$31,$28,$31,$34,$37);
  return;
 }
 $38 = (___dynamic_cast($4,26864,26752,0)|0);
 $39 = ($38|0)==(0|0);
 if (!($39)) {
  $40 = ((($0)) + 140|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = ((($41)) + 56|0);
  $43 = +HEAPF64[$42>>3];
  $44 = (~~(($43)));
  $45 = ((($41)) + 64|0);
  $46 = +HEAPF64[$45>>3];
  $47 = (~~(($46)));
  $48 = ((($41)) + 72|0);
  $49 = +HEAPF64[$48>>3];
  $50 = (~~(($49)));
  __ZN3osg9Texture1D17copyTexSubImage1DERNS_5StateEiiii($38,$2,$44,$44,$47,$50);
  return;
 }
 $51 = (___dynamic_cast($4,26864,26816,0)|0);
 $52 = ($51|0)==(0|0);
 if (!($52)) {
  $53 = ((($0)) + 140|0);
  $54 = HEAP32[$53>>2]|0;
  $55 = ((($54)) + 56|0);
  $56 = +HEAPF64[$55>>3];
  $57 = (~~(($56)));
  $58 = ((($54)) + 64|0);
  $59 = +HEAPF64[$58>>3];
  $60 = (~~(($59)));
  $61 = ((($0)) + 244|0);
  $62 = HEAP32[$61>>2]|0;
  $63 = ((($54)) + 72|0);
  $64 = +HEAPF64[$63>>3];
  $65 = (~~(($64)));
  $66 = ((($54)) + 80|0);
  $67 = +HEAPF64[$66>>3];
  $68 = (~~(($67)));
  __ZN3osg9Texture3D17copyTexSubImage3DERNS_5StateEiiiiiii($51,$2,$57,$60,$62,$57,$60,$65,$68);
  return;
 }
 $69 = (___dynamic_cast($4,26864,26896,0)|0);
 $70 = ($69|0)==(0|0);
 if ($70) {
  return;
 }
 $71 = ((($0)) + 244|0);
 $72 = HEAP32[$71>>2]|0;
 $73 = ((($0)) + 140|0);
 $74 = HEAP32[$73>>2]|0;
 $75 = ((($74)) + 56|0);
 $76 = +HEAPF64[$75>>3];
 $77 = (~~(($76)));
 $78 = ((($74)) + 64|0);
 $79 = +HEAPF64[$78>>3];
 $80 = (~~(($79)));
 $81 = ((($74)) + 72|0);
 $82 = +HEAPF64[$81>>3];
 $83 = (~~(($82)));
 $84 = ((($74)) + 80|0);
 $85 = +HEAPF64[$84>>3];
 $86 = (~~(($85)));
 __ZN3osg14TextureCubeMap22copyTexSubImageCubeMapERNS_5StateEiiiiiii($69,$2,$72,$77,$80,$77,$80,$83,$86);
 return;
}
function __ZN3osg5State9applyModeEjb($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$i = 0, $$0$i$i = 0, $$0$ph$i$i = 0, $$014$i = 0, $$024$i$i = 0, $$025$i$i = 0, $$025$i65$i = 0, $$049$i = 0, $$04964$i = 0, $$in$i$i = 0, $$pre$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 576|0);
 $4 = ((($0)) + 580|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 do {
  if ($6) {
   $$025$i$i = $4;$$049$i = $4;$17 = $5;
   label = 12;
  } else {
   $7 = ((($0)) + 580|0);
   $$0$i$i = $7;$$024$i$i = $5;$53 = $5;
   while(1) {
    $8 = ((($$024$i$i)) + 16|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = ($9>>>0)>($1>>>0);
    if ($10) {
     $11 = HEAP32[$$024$i$i>>2]|0;
     $12 = ($11|0)==(0|0);
     if ($12) {
      label = 6;
      break;
     } else {
      $$0$ph$i$i = $$024$i$i;$$in$i$i = $11;
     }
    } else {
     $13 = ($9>>>0)<($1>>>0);
     if (!($13)) {
      label = 10;
      break;
     }
     $14 = ((($$024$i$i)) + 4|0);
     $15 = HEAP32[$14>>2]|0;
     $16 = ($15|0)==(0|0);
     if ($16) {
      label = 9;
      break;
     } else {
      $$0$ph$i$i = $14;$$in$i$i = $15;
     }
    }
    $$0$i$i = $$0$ph$i$i;$$024$i$i = $$in$i$i;$53 = $$in$i$i;
   }
   if ((label|0) == 6) {
    $$025$i65$i = $$024$i$i;$$04964$i = $$024$i$i;
    label = 13;
    break;
   }
   else if ((label|0) == 9) {
    $$025$i65$i = $14;$$04964$i = $$024$i$i;
    label = 13;
    break;
   }
   else if ((label|0) == 10) {
    $$025$i$i = $$0$i$i;$$049$i = $$024$i$i;$17 = $53;
    label = 12;
    break;
   }
  }
 } while(0);
 if ((label|0) == 12) {
  $18 = ($17|0)==(0|0);
  if ($18) {
   $$025$i65$i = $$025$i$i;$$04964$i = $$049$i;
   label = 13;
  } else {
   $$014$i = $17;
  }
 }
 if ((label|0) == 13) {
  $19 = (__Znwj(36)|0);
  $20 = ((($19)) + 16|0);
  HEAP32[$20>>2] = $1;
  $21 = ((($19)) + 20|0);
  $22 = ((($19)) + 24|0);
  HEAP32[$22>>2] = 0;
  $23 = ((($19)) + 28|0);
  HEAP32[$23>>2] = 0;
  $24 = ((($19)) + 32|0);
  HEAP32[$24>>2] = 0;
  HEAP8[$21>>0] = 1;
  $25 = ((($19)) + 21|0);
  HEAP8[$25>>0] = 0;
  $26 = ((($19)) + 22|0);
  HEAP8[$26>>0] = 0;
  $27 = ((($19)) + 23|0);
  HEAP8[$27>>0] = 0;
  HEAP32[$19>>2] = 0;
  $28 = ((($19)) + 4|0);
  HEAP32[$28>>2] = 0;
  $29 = ((($19)) + 8|0);
  HEAP32[$29>>2] = $$04964$i;
  HEAP32[$$025$i65$i>>2] = $19;
  $30 = HEAP32[$3>>2]|0;
  $31 = HEAP32[$30>>2]|0;
  $32 = ($31|0)==(0|0);
  if ($32) {
   $36 = $19;
  } else {
   $33 = $31;
   HEAP32[$3>>2] = $33;
   $$pre$i$i = HEAP32[$$025$i65$i>>2]|0;
   $36 = $$pre$i$i;
  }
  $34 = ((($0)) + 580|0);
  $35 = HEAP32[$34>>2]|0;
  __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($35,$36);
  $37 = ((($0)) + 584|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = (($38) + 1)|0;
  HEAP32[$37>>2] = $39;
  $$014$i = $19;
 }
 $40 = ((($$014$i)) + 21|0);
 HEAP8[$40>>0] = 1;
 $41 = $2&1;
 $42 = ((($$014$i)) + 20|0);
 $43 = HEAP8[$42>>0]|0;
 $44 = ($43<<24>>24)==(0);
 if ($44) {
  $$0$i = 0;
  return ($$0$i|0);
 }
 $45 = ((($$014$i)) + 22|0);
 $46 = HEAP8[$45>>0]|0;
 $47 = $46&255;
 $48 = $2&1;
 $49 = ($47|0)==($48|0);
 if ($49) {
  $$0$i = 0;
  return ($$0$i|0);
 }
 HEAP8[$45>>0] = $41;
 if ($2) {
  _glEnable(($1|0));
 } else {
  _glDisable(($1|0));
 }
 $50 = ((($0)) + 344|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = ($51|0)==(2);
 if (!($52)) {
  $$0$i = 1;
  return ($$0$i|0);
 }
 (__ZNK3osg5State13checkGLErrorsEj($0,$1)|0);
 $$0$i = 1;
 return ($$0$i|0);
}
function __ZN7osgUtil11RenderStage14runCameraSetUpERN3osg10RenderInfoE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$ = 0, $$$0321 = 0, $$$0333$off0 = 0, $$$1317 = 0, $$$401 = 0, $$$i = 0, $$0$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i419 = 0, $$0$i$i$i$i488 = 0, $$0$i$i$i$i506 = 0, $$0$i$i$i$i547 = 0, $$0$i$i$i$i559 = 0, $$0$i$i445 = 0, $$0$i$i461 = 0, $$0$i$ph = 0, $$0$i413$ph = 0, $$0$i4961080 = 0, $$0$i500 = 0, $$0$ph$i$i = 0;
 var $$0$ph$i$i442 = 0, $$0$ph$i$i458 = 0, $$014$i = 0, $$014$i454 = 0, $$014$i470 = 0, $$024$i$i = 0, $$024$i$i444 = 0, $$024$i$i460 = 0, $$025$i$i = 0, $$025$i$i447 = 0, $$025$i$i463 = 0, $$025$i53$i = 0, $$025$i53$i449 = 0, $$025$i53$i465 = 0, $$0300$lcssa = 0, $$0300993 = 0, $$0301$lcssa = 0, $$0301992 = 0, $$0302$off0964 = 0, $$0305$lcssa1102 = 0;
 var $$0305$lcssa1103 = 0, $$0305963 = 0, $$0307$lcssa1100 = 0, $$0307$lcssa1101 = 0, $$0307962 = 0, $$0309$lcssa1098 = 0, $$0309$lcssa1099 = 0, $$0309961 = 0, $$0313$lcssa1096 = 0, $$0313$lcssa1097 = 0, $$0313960 = 0, $$0320 = 0, $$0321 = 0, $$0323 = 0, $$0324984 = 0, $$0327983 = 0, $$0329$off0$lcssa1086 = 0, $$0329$off0$lcssa1087 = 0, $$0329$off0977 = 0, $$0331$off0976 = 0;
 var $$0333$off0$lcssa1084 = 0, $$0333$off0$lcssa1085 = 0, $$0333$off0$lcssa10851088 = 0, $$0333$off0$lcssa10851089 = 0, $$0333$off0975 = 0, $$0369785791 = 0, $$0369785793 = 0, $$0369790 = 0, $$037$i = 0, $$037$i446 = 0, $$037$i462 = 0, $$03752$i = 0, $$03752$i450 = 0, $$03752$i466 = 0, $$1 = 0, $$10 = 0, $$10352 = 0, $$11 = 0, $$11353 = 0, $$12 = 0;
 var $$12354 = 0, $$13 = 0, $$1303$off0 = 0, $$1306 = 0, $$1308 = 0, $$1310 = 0, $$1314 = 0, $$1317 = 0, $$1322 = 0, $$1325 = 0, $$1328 = 0, $$1330$off0 = 0, $$1332$off0 = 0, $$1334$off0 = 0, $$13355 = 0, $$1338 = 0, $$1343 = 0, $$1370$off0 = 0, $$17 = 0, $$171094 = 0;
 var $$17359 = 0, $$173591093 = 0, $$18 = 0, $$18360 = 0, $$18360800 = 0, $$18802 = 0, $$2$lcssa = 0, $$2$off371 = 0, $$2$ph = 0, $$20 = 0, $$20362 = 0, $$2311 = 0, $$2315 = 0, $$2326 = 0, $$2335$off0 = 0, $$2339 = 0, $$2344 = 0, $$25 = 0, $$25367 = 0, $$26 = 0;
 var $$26368 = 0, $$2970 = 0, $$3 = 0, $$3319 = 0, $$3336$off0 = 0, $$3340 = 0, $$3345 = 0, $$401 = 0, $$403 = 0, $$403$ = 0, $$8 = 0, $$8350 = 0, $$9 = 0, $$9351 = 0, $$cast = 0, $$in$i$i = 0, $$in$i$i441 = 0, $$in$i$i457 = 0, $$not = 0, $$not394 = 0;
 var $$not397 = 0, $$phi$trans$insert$phi$trans$insert = 0, $$pr$i = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i$i452 = 0, $$pre$i$i468 = 0, $$pre$i499 = 0, $$pre$i523 = 0, $$pre$i544 = 0, $$pre$i653 = 0, $$pre1072 = 0, $$pre1073 = 0, $$pre1074 = 0, $$pre1075 = 0, $$pre1076$pre = 0, $$pre10761082 = 0, $$pre1077$pre = 0, $$sink400$index = 0;
 var $$sink400$index9 = 0, $$sroa$0657$0$be = 0, $$sroa$0657$0957 = 0, $$sroa$0667$0$be = 0, $$sroa$0667$0958 = 0, $$sroa$0702$0 = 0, $$sroa$0702$5805 = 0, $$sroa$0702$5806 = 0, $$sroa$0702$6 = 0, $$sroa$0702$9 = 0, $$sroa$0715$0$be = 0, $$sroa$0715$0974 = 0, $$sroa$0724$0$be = 0, $$sroa$0724$0982 = 0, $$sroa$0729$0 = 0, $$sroa$0729$1 = 0, $$sroa$0729$10 = 0, $$sroa$0729$101091 = 0, $$sroa$0729$3 = 0, $$sroa$0729$4 = 0;
 var $$sroa$0729$9 = 0, $$sroa$0746$1 = 0, $$sroa$0746$2784794 = 0, $$sroa$0746$2789 = 0, $$sroa$0746$3 = 0, $$sroa$0746$4 = 0, $$sroa$0746$41092 = 0, $$sroa$0746$5 = 0, $$sroa$0746$5799 = 0, $$sroa$0765$0$be = 0, $$sroa$0765$0988 = 0, $$sroa$0778$0$be = 0, $$sroa$0778$0990 = 0, $10 = 0, $100 = 0, $1000 = 0, $1001 = 0, $1002 = 0, $1003 = 0, $1004 = 0;
 var $1005 = 0, $1006 = 0, $1007 = 0, $1008 = 0, $1009 = 0, $101 = 0, $1010 = 0, $1011 = 0, $1012 = 0, $1013 = 0, $1014 = 0, $1015 = 0, $1016 = 0, $1017 = 0, $1018 = 0, $1019 = 0, $102 = 0, $1020 = 0, $1021 = 0, $1022 = 0;
 var $1023 = 0, $1024 = 0, $1025 = 0, $1026 = 0, $1027 = 0, $1028 = 0, $1029 = 0, $103 = 0, $1030 = 0, $1031 = 0, $1032 = 0, $1033 = 0, $1034 = 0, $1035 = 0, $1036 = 0, $1037 = 0, $1038 = 0, $1039 = 0, $104 = 0, $1040 = 0;
 var $1041 = 0, $1042 = 0, $1043 = 0, $1044 = 0, $1045 = 0, $1046 = 0, $1047 = 0, $1048 = 0, $1049 = 0, $105 = 0, $1050 = 0, $1051 = 0, $1052 = 0, $1053 = 0, $1054 = 0, $1055 = 0, $1056 = 0, $1057 = 0, $1058 = 0, $1059 = 0;
 var $106 = 0, $1060 = 0, $1061 = 0, $1062 = 0, $1063 = 0, $1064 = 0, $1065 = 0, $1066 = 0, $1067 = 0, $1068 = 0, $1069 = 0, $107 = 0, $1070 = 0, $1071 = 0, $1072 = 0, $1073 = 0, $1074 = 0, $1075 = 0, $1076 = 0, $1077 = 0;
 var $1078 = 0, $1079 = 0, $108 = 0, $1080 = 0, $1081 = 0, $1082 = 0, $1083 = 0, $1084 = 0, $1085 = 0, $1086 = 0, $1087 = 0, $1088 = 0, $1089 = 0, $109 = 0, $1090 = 0, $1091 = 0, $1092 = 0, $1093 = 0, $1094 = 0, $1095 = 0;
 var $1096 = 0, $1097 = 0, $1098 = 0, $1099 = 0, $11 = 0, $110 = 0, $1100 = 0, $1101 = 0, $1102 = 0, $1103 = 0, $1104 = 0, $1105 = 0, $1106 = 0, $1107 = 0, $1108 = 0, $1109 = 0, $111 = 0, $1110 = 0, $1111 = 0, $1112 = 0;
 var $1113 = 0, $1114 = 0, $1115 = 0, $1116 = 0, $1117 = 0, $1118 = 0, $1119 = 0, $112 = 0, $1120 = 0, $1121 = 0, $1122 = 0, $1123 = 0, $1124 = 0, $1125 = 0, $1126 = 0, $1127 = 0, $1128 = 0, $1129 = 0, $113 = 0, $1130 = 0;
 var $1131 = 0, $1132 = 0, $1133 = 0, $1134 = 0, $1135 = 0, $1136 = 0, $1137 = 0, $1138 = 0, $1139 = 0, $114 = 0, $1140 = 0, $1141 = 0, $1142 = 0, $1143 = 0, $1144 = 0, $1145 = 0, $1146 = 0, $1147 = 0, $1148 = 0, $1149 = 0;
 var $115 = 0, $1150 = 0, $1151 = 0, $1152 = 0, $1153 = 0, $1154 = 0, $1155 = 0, $1156 = 0, $1157 = 0, $1158 = 0, $1159 = 0, $116 = 0, $1160 = 0, $1161 = 0, $1162 = 0, $1163 = 0, $1164 = 0, $1165 = 0, $1166 = 0, $1167 = 0;
 var $1168 = 0, $1169 = 0, $117 = 0, $1170 = 0, $1171 = 0, $1172 = 0, $1173 = 0, $1174 = 0, $1175 = 0, $1176 = 0, $1177 = 0, $1178 = 0, $1179 = 0, $118 = 0, $1180 = 0, $1181 = 0, $1182 = 0, $1183 = 0, $1184 = 0, $1185 = 0;
 var $1186 = 0, $1187 = 0, $1188 = 0, $1189 = 0, $119 = 0, $1190 = 0, $1191 = 0, $1192 = 0, $1193 = 0, $1194 = 0, $1195 = 0, $1196 = 0, $1197 = 0, $1198 = 0, $1199 = 0, $12 = 0, $120 = 0, $1200 = 0, $1201 = 0, $1202 = 0;
 var $1203 = 0, $1204 = 0, $1205 = 0, $1206 = 0, $1207 = 0, $1208 = 0, $1209 = 0, $121 = 0, $1210 = 0, $1211 = 0, $1212 = 0, $1213 = 0, $1214 = 0, $1215 = 0, $1216 = 0, $1217 = 0, $1218 = 0, $1219 = 0, $122 = 0, $1220 = 0;
 var $1221 = 0, $1222 = 0, $1223 = 0, $1224 = 0, $1225 = 0, $1226 = 0, $1227 = 0, $1228 = 0, $1229 = 0, $123 = 0, $1230 = 0, $1231 = 0, $1232 = 0, $1233 = 0, $1234 = 0, $1235 = 0, $1236 = 0, $1237 = 0, $1238 = 0, $1239 = 0;
 var $124 = 0, $1240 = 0, $1241 = 0, $1242 = 0, $1243 = 0, $1244 = 0, $1245 = 0, $1246 = 0, $1247 = 0, $1248 = 0, $1249 = 0, $125 = 0, $1250 = 0, $1251 = 0, $1252 = 0, $1253 = 0, $1254 = 0, $1255 = 0, $1256 = 0, $1257 = 0;
 var $1258 = 0, $1259 = 0, $126 = 0, $1260 = 0, $1261 = 0, $1262 = 0, $1263 = 0, $1264 = 0, $1265 = 0, $1266 = 0, $1267 = 0, $1268 = 0, $1269 = 0, $127 = 0, $1270 = 0, $1271 = 0, $1272 = 0, $1273 = 0, $1274 = 0, $1275 = 0;
 var $1276 = 0, $1277 = 0, $1278 = 0, $1279 = 0, $128 = 0, $1280 = 0, $1281 = 0, $1282 = 0, $1283 = 0, $1284 = 0, $1285 = 0, $1286 = 0, $1287 = 0, $1288 = 0, $1289 = 0, $129 = 0, $1290 = 0, $1291 = 0, $1292 = 0, $1293 = 0;
 var $1294 = 0, $1295 = 0, $1296 = 0, $1297 = 0, $1298 = 0, $1299 = 0, $13 = 0, $130 = 0, $1300 = 0, $1301 = 0, $1302 = 0, $1303 = 0, $1304 = 0, $1305 = 0, $1306 = 0, $1307 = 0, $1308 = 0, $1309 = 0, $131 = 0, $1310 = 0;
 var $1311 = 0, $1312 = 0, $1313 = 0, $1314 = 0, $1315 = 0, $1316 = 0, $1317 = 0, $1318 = 0, $1319 = 0, $132 = 0, $1320 = 0, $1321 = 0, $1322 = 0, $1323 = 0, $1324 = 0, $1325 = 0, $1326 = 0, $1327 = 0, $1328 = 0, $1329 = 0;
 var $133 = 0, $1330 = 0, $1331 = 0, $1332 = 0, $1333 = 0, $1334 = 0, $1335 = 0, $1336 = 0, $1337 = 0, $1338 = 0, $1339 = 0, $134 = 0, $1340 = 0, $1341 = 0, $1342 = 0, $1343 = 0, $1344 = 0, $1345 = 0, $1346 = 0, $1347 = 0;
 var $1348 = 0, $1349 = 0, $135 = 0, $1350 = 0, $1351 = 0, $1352 = 0, $1353 = 0, $1354 = 0, $1355 = 0, $1356 = 0, $1357 = 0, $1358 = 0, $1359 = 0, $136 = 0, $1360 = 0, $1361 = 0, $1362 = 0, $1363 = 0, $1364 = 0, $1365 = 0;
 var $1366 = 0, $1367 = 0, $1368 = 0, $1369 = 0, $137 = 0, $1370 = 0, $1371 = 0, $1372 = 0, $1373 = 0, $1374 = 0, $1375 = 0, $1376 = 0, $1377 = 0, $1378 = 0, $1379 = 0, $138 = 0, $1380 = 0, $1381 = 0, $1382 = 0, $1383 = 0;
 var $1384 = 0, $1385 = 0, $1386 = 0, $1387 = 0, $1388 = 0, $1389 = 0, $139 = 0, $1390 = 0, $1391 = 0, $1392 = 0, $1393 = 0, $1394 = 0, $1395 = 0, $1396 = 0, $1397 = 0, $1398 = 0, $1399 = 0, $14 = 0, $140 = 0, $1400 = 0;
 var $1401 = 0, $1402 = 0, $1403 = 0, $1404 = 0, $1405 = 0, $1406 = 0, $1407 = 0, $1408 = 0, $1409 = 0, $141 = 0, $1410 = 0, $1411 = 0, $1412 = 0, $1413 = 0, $1414 = 0, $1415 = 0, $1416 = 0, $1417 = 0, $1418 = 0, $1419 = 0;
 var $142 = 0, $1420 = 0, $1421 = 0, $1422 = 0, $1423 = 0, $1424 = 0, $1425 = 0, $1426 = 0, $1427 = 0, $1428 = 0, $1429 = 0, $143 = 0, $1430 = 0, $1431 = 0, $1432 = 0, $1433 = 0, $1434 = 0, $1435 = 0, $1436 = 0, $1437 = 0;
 var $1438 = 0, $1439 = 0, $144 = 0, $1440 = 0, $1441 = 0, $1442 = 0, $1443 = 0, $1444 = 0, $1445 = 0, $1446 = 0, $1447 = 0, $1448 = 0, $1449 = 0, $145 = 0, $1450 = 0, $1451 = 0, $1452 = 0, $1453 = 0, $1454 = 0, $1455 = 0;
 var $1456 = 0, $1457 = 0, $1458 = 0, $1459 = 0, $146 = 0, $1460 = 0, $1461 = 0, $1462 = 0, $1463 = 0, $1464 = 0, $1465 = 0, $1466 = 0, $1467 = 0, $1468 = 0, $1469 = 0, $147 = 0, $1470 = 0, $1471 = 0, $1472 = 0, $1473 = 0;
 var $1474 = 0, $1475 = 0, $1476 = 0, $1477 = 0, $1478 = 0, $1479 = 0, $148 = 0, $1480 = 0, $1481 = 0, $1482 = 0, $1483 = 0, $1484 = 0, $1485 = 0, $1486 = 0, $1487 = 0, $1488 = 0, $1489 = 0, $149 = 0, $1490 = 0, $1491 = 0;
 var $1492 = 0, $1493 = 0, $1494 = 0, $1495 = 0, $1496 = 0, $1497 = 0, $1498 = 0, $1499 = 0, $15 = 0, $150 = 0, $1500 = 0, $1501 = 0, $1502 = 0, $1503 = 0, $1504 = 0, $1505 = 0, $1506 = 0, $1507 = 0, $1508 = 0, $1509 = 0;
 var $151 = 0, $1510 = 0, $1511 = 0, $1512 = 0, $1513 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0;
 var $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0;
 var $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0;
 var $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0;
 var $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0;
 var $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0;
 var $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0;
 var $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0;
 var $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0;
 var $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0;
 var $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0;
 var $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0;
 var $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0;
 var $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0;
 var $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0;
 var $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0;
 var $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0;
 var $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0;
 var $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0;
 var $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0;
 var $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0;
 var $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0;
 var $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0;
 var $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0;
 var $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0;
 var $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0;
 var $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0;
 var $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0;
 var $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0.0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0;
 var $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0.0, $720 = 0, $721 = 0, $722 = 0, $723 = 0;
 var $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0.0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0;
 var $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0.0;
 var $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0;
 var $779 = 0, $78 = 0.0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0.0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0;
 var $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0;
 var $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0;
 var $832 = 0, $833 = 0, $834 = 0, $835 = 0, $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0;
 var $850 = 0, $851 = 0, $852 = 0, $853 = 0, $854 = 0, $855 = 0, $856 = 0, $857 = 0, $858 = 0, $859 = 0, $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0;
 var $869 = 0, $87 = 0, $870 = 0, $871 = 0, $872 = 0, $873 = 0, $874 = 0, $875 = 0, $876 = 0, $877 = 0, $878 = 0, $879 = 0, $88 = 0, $880 = 0, $881 = 0, $882 = 0, $883 = 0, $884 = 0, $885 = 0, $886 = 0;
 var $887 = 0, $888 = 0, $889 = 0, $89 = 0, $890 = 0, $891 = 0, $892 = 0, $893 = 0, $894 = 0, $895 = 0, $896 = 0, $897 = 0, $898 = 0, $899 = 0, $9 = 0, $90 = 0, $900 = 0, $901 = 0, $902 = 0, $903 = 0;
 var $904 = 0, $905 = 0, $906 = 0, $907 = 0, $908 = 0, $909 = 0, $91 = 0, $910 = 0, $911 = 0, $912 = 0, $913 = 0, $914 = 0, $915 = 0, $916 = 0, $917 = 0, $918 = 0, $919 = 0, $92 = 0, $920 = 0, $921 = 0;
 var $922 = 0, $923 = 0, $924 = 0, $925 = 0, $926 = 0, $927 = 0, $928 = 0, $929 = 0, $93 = 0, $930 = 0, $931 = 0, $932 = 0, $933 = 0, $934 = 0, $935 = 0, $936 = 0, $937 = 0, $938 = 0, $939 = 0, $94 = 0;
 var $940 = 0, $941 = 0, $942 = 0, $943 = 0, $944 = 0, $945 = 0, $946 = 0, $947 = 0, $948 = 0, $949 = 0, $95 = 0, $950 = 0, $951 = 0, $952 = 0, $953 = 0, $954 = 0, $955 = 0, $956 = 0, $957 = 0, $958 = 0;
 var $959 = 0, $96 = 0, $960 = 0, $961 = 0, $962 = 0, $963 = 0, $964 = 0, $965 = 0, $966 = 0, $967 = 0, $968 = 0, $969 = 0, $97 = 0, $970 = 0, $971 = 0, $972 = 0, $973 = 0, $974 = 0, $975 = 0, $976 = 0;
 var $977 = 0, $978 = 0, $979 = 0, $98 = 0, $980 = 0, $981 = 0, $982 = 0, $983 = 0, $984 = 0, $985 = 0, $986 = 0, $987 = 0, $988 = 0, $989 = 0, $99 = 0, $990 = 0, $991 = 0, $992 = 0, $993 = 0, $994 = 0;
 var $995 = 0, $996 = 0, $997 = 0, $998 = 0, $999 = 0, $eh$lpad$body530$index2Z2D = 0, $eh$lpad$body530$indexZ2D = 0, $eh$lpad$body575$sink813$index22Z2D = 0, $eh$lpad$body575$sink813$indexZ2D = 0, $or$cond = 0, $or$cond396 = 0, $or$cond399 = 0, $or$cond4 = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(80|0);
 $2 = sp + 76|0;
 $3 = sp + 72|0;
 $4 = sp + 68|0;
 $5 = sp + 64|0;
 $6 = sp + 60|0;
 $7 = sp + 56|0;
 $8 = sp + 52|0;
 $9 = sp + 48|0;
 $10 = sp + 44|0;
 $11 = sp + 40|0;
 $12 = sp + 36|0;
 $13 = sp + 32|0;
 $14 = sp + 28|0;
 $15 = sp + 24|0;
 $16 = sp + 20|0;
 $17 = sp + 16|0;
 $18 = sp + 12|0;
 $19 = sp + 8|0;
 $20 = sp + 4|0;
 $21 = sp;
 $22 = ((($0)) + 220|0);
 HEAP8[$22>>0] = 0;
 $23 = ((($0)) + 228|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)==(0|0);
 if ($25) {
  STACKTOP = sp;return;
 }
 $26 = ((($24)) + 24|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  STACKTOP = sp;return;
 }
 $29 = ((($0)) + 232|0);
 $30 = HEAP32[$29>>2]|0;
 $phitmp$i = ($30|0)==(0|0);
 if ($phitmp$i) {
  STACKTOP = sp;return;
 }
 $31 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
 do {
  if ($31) {
   $32 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
   $33 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($32,117780,57)|0);
   $34 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEPKv($33,$0)|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ((($35)) + -12|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = (($34) + ($37)|0);
   __ZNKSt3__28ios_base6getlocEv($12,$38);
   __THREW__ = 0;
   $39 = (invoke_iii(3255,($12|0),(215188|0))|0);
   $40 = __THREW__; __THREW__ = 0;
   $41 = $40&1;
   if (!($41)) {
    $42 = HEAP32[$39>>2]|0;
    $43 = ((($42)) + 28|0);
    $44 = HEAP32[$43>>2]|0;
    __THREW__ = 0;
    $45 = (invoke_iii($44|0,($39|0),10)|0);
    $46 = __THREW__; __THREW__ = 0;
    $47 = $46&1;
    if (!($47)) {
     __ZNSt3__26localeD2Ev($12);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($34,$45)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($34)|0);
     break;
    }
   }
   $48 = ___cxa_find_matching_catch_2()|0;
   $49 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($12|0));
   $50 = __THREW__; __THREW__ = 0;
   $51 = $50&1;
   if ($51) {
    $52 = ___cxa_find_matching_catch_3(0|0)|0;
    $53 = tempRet0;
    ___clang_call_terminate($52);
    // unreachable;
   } else {
    ___resumeException($48|0);
    // unreachable;
   }
  }
 } while(0);
 $54 = HEAP32[$29>>2]|0;
 $55 = ((($54)) + 604|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = ((($0)) + 224|0);
 HEAP32[$57>>2] = $56;
 $58 = HEAP32[$1>>2]|0;
 $59 = ((($54)) + 576|0);
 $60 = HEAP32[$59>>2]|0;
 $61 = ((($54)) + 580|0);
 $62 = HEAP32[$61>>2]|0;
 $63 = ((($0)) + 260|0);
 $64 = ((($0)) + 264|0);
 $65 = HEAP32[$64>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIN3osg6Camera15BufferComponentEN7osgUtil11RenderStage10AttachmentEEENS_19__map_value_compareIS4_S8_NS_4lessIS4_EELb1EEENS_9allocatorIS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($63,$65);
 $66 = ((($0)) + 268|0);
 HEAP32[$66>>2] = 0;
 HEAP32[$63>>2] = $64;
 HEAP32[$64>>2] = 0;
 $67 = ((($0)) + 140|0);
 $68 = HEAP32[$67>>2]|0;
 $69 = ((($68)) + 56|0);
 $70 = +HEAPF64[$69>>3];
 $71 = ((($68)) + 72|0);
 $72 = +HEAPF64[$71>>3];
 $73 = $70 + $72;
 $74 = (~~(($73)));
 $75 = ((($68)) + 64|0);
 $76 = +HEAPF64[$75>>3];
 $77 = ((($68)) + 80|0);
 $78 = +HEAPF64[$77>>3];
 $79 = $76 + $78;
 $80 = (~~(($79)));
 $81 = ((($54)) + 584|0);
 $82 = HEAP32[$81>>2]|0;
 $83 = ((($54)) + 588|0);
 $84 = ($82|0)==($83|0);
 if ($84) {
  $$0300$lcssa = $74;$$0301$lcssa = $80;$85 = $82;
 } else {
  $$0300993 = $74;$$0301992 = $80;$$sroa$0778$0990 = $82;
  while(1) {
   $90 = ((($$sroa$0778$0990)) + 28|0);
   $91 = HEAP32[$90>>2]|0;
   $92 = ($91|0)==(0|0);
   if ($92) {
    $93 = ((($$sroa$0778$0990)) + 24|0);
    $94 = HEAP32[$93>>2]|0;
    $95 = ($94|0)==(0|0);
    if ($95) {
     $$0$i$ph = 0;
    } else {
     $96 = ((($94)) + 72|0);
     $97 = HEAP32[$96>>2]|0;
     $$0$i$ph = $97;
    }
    $98 = ($$0300993|0)>($$0$i$ph|0);
    $99 = $98 ? $$0300993 : $$0$i$ph;
    $1509 = $99;
    label = 20;
   } else {
    $100 = HEAP32[$91>>2]|0;
    $101 = ((($100)) + 184|0);
    $102 = HEAP32[$101>>2]|0;
    $103 = (FUNCTION_TABLE_ii[$102 & 8191]($91)|0);
    $$pre = HEAP32[$90>>2]|0;
    $104 = ($$0300993|0)>($103|0);
    $105 = $104 ? $$0300993 : $103;
    $106 = ($$pre|0)==(0|0);
    if ($106) {
     $1509 = $105;
     label = 20;
    } else {
     $114 = HEAP32[$$pre>>2]|0;
     $115 = ((($114)) + 188|0);
     $116 = HEAP32[$115>>2]|0;
     $117 = (FUNCTION_TABLE_ii[$116 & 8191]($$pre)|0);
     $$pre1072 = HEAP32[$90>>2]|0;
     $118 = ($$0301992|0)>($117|0);
     $119 = $118 ? $$0301992 : $117;
     $120 = ($$pre1072|0)==(0|0);
     if ($120) {
      $1507 = $119;$1508 = $105;
     } else {
      $121 = HEAP32[$$pre1072>>2]|0;
      $122 = ((($121)) + 192|0);
      $123 = HEAP32[$122>>2]|0;
      (FUNCTION_TABLE_ii[$123 & 8191]($$pre1072)|0);
      $1507 = $119;$1508 = $105;
     }
    }
   }
   if ((label|0) == 20) {
    label = 0;
    $107 = ((($$sroa$0778$0990)) + 24|0);
    $108 = HEAP32[$107>>2]|0;
    $109 = ($108|0)==(0|0);
    if ($109) {
     $$0$i413$ph = 0;
    } else {
     $110 = ((($108)) + 76|0);
     $111 = HEAP32[$110>>2]|0;
     $$0$i413$ph = $111;
    }
    $112 = ($$0301992|0)>($$0$i413$ph|0);
    $113 = $112 ? $$0301992 : $$0$i413$ph;
    $1507 = $113;$1508 = $1509;
   }
   $124 = ((($$sroa$0778$0990)) + 4|0);
   $125 = HEAP32[$124>>2]|0;
   $126 = ($125|0)==(0|0);
   if ($126) {
    $127 = ((($$sroa$0778$0990)) + 8|0);
    $128 = HEAP32[$127>>2]|0;
    $129 = HEAP32[$128>>2]|0;
    $130 = ($129|0)==($$sroa$0778$0990|0);
    if ($130) {
     $$sroa$0778$0$be = $128;
    } else {
     $135 = $127;
     while(1) {
      $134 = HEAP32[$135>>2]|0;
      $136 = ((($134)) + 8|0);
      $137 = HEAP32[$136>>2]|0;
      $138 = HEAP32[$137>>2]|0;
      $139 = ($138|0)==($134|0);
      if ($139) {
       $$sroa$0778$0$be = $137;
       break;
      } else {
       $135 = $136;
      }
     }
    }
   } else {
    $$0$i$i$i$i419 = $125;
    while(1) {
     $132 = HEAP32[$$0$i$i$i$i419>>2]|0;
     $133 = ($132|0)==(0|0);
     if ($133) {
      break;
     } else {
      $$0$i$i$i$i419 = $132;
     }
    }
    $$sroa$0778$0$be = $$0$i$i$i$i419;
   }
   $131 = ($$sroa$0778$0$be|0)==($83|0);
   if ($131) {
    break;
   } else {
    $$0300993 = $1508;$$0301992 = $1507;$$sroa$0778$0990 = $$sroa$0778$0$be;
   }
  }
  $$pre1073 = HEAP32[$81>>2]|0;
  $$0300$lcssa = $1508;$$0301$lcssa = $1507;$85 = $$pre1073;
 }
 $86 = ($85|0)==($83|0);
 if (!($86)) {
  $87 = ((($0)) + 252|0);
  $88 = ((($0)) + 256|0);
  $89 = ((($0)) + 264|0);
  $$sroa$0765$0988 = $85;
  while(1) {
   $141 = ((($$sroa$0765$0988)) + 16|0);
   $142 = ((($$sroa$0765$0988)) + 24|0);
   $143 = HEAP32[$142>>2]|0;
   $144 = ($143|0)==(0|0);
   if (!($144)) {
    $145 = ((($143)) + 92|0);
    $146 = HEAP32[$145>>2]|0;
    $147 = ((($143)) + 96|0);
    $148 = HEAP32[$147>>2]|0;
    $149 = ((($143)) + 112|0);
    $150 = HEAP32[$149>>2]|0;
    $151 = ($150|0)==(0|0);
    if ($151) {
     $152 = ($146|0)==(0);
     if ($152) {
      $153 = ((($$sroa$0765$0988)) + 20|0);
      $154 = HEAP32[$153>>2]|0;
      $155 = ($154|0)==(0);
      if ($155) {
       $156 = HEAP32[$87>>2]|0;
       $$1317 = $156;
      } else {
       $$1317 = $154;
      }
     } else {
      $$1317 = $146;
     }
     $157 = ($$1317|0)==(0);
     $$$1317 = $157 ? 6408 : $$1317;
     $158 = ($148|0)==(0);
     if ($158) {
      $159 = HEAP32[$88>>2]|0;
      $$0321 = $159;
     } else {
      $$0321 = $148;
     }
     $160 = ($$0321|0)==(0);
     $$$0321 = $160 ? 5121 : $$0321;
     $$1322 = $$$0321;$$3319 = $$$1317;
    } else {
     $$1322 = $148;$$3319 = $146;
    }
    $161 = HEAP32[$64>>2]|0;
    $162 = ($161|0)==(0|0);
    do {
     if ($162) {
      $$025$i$i = $64;$$037$i = $64;$173 = $161;
      label = 50;
     } else {
      $163 = HEAP32[$141>>2]|0;
      $$0$i$i = $89;$$024$i$i = $161;$1510 = $161;
      while(1) {
       $164 = ((($$024$i$i)) + 16|0);
       $165 = HEAP32[$164>>2]|0;
       $166 = ($163|0)<($165|0);
       if ($166) {
        $167 = HEAP32[$$024$i$i>>2]|0;
        $168 = ($167|0)==(0|0);
        if ($168) {
         label = 45;
         break;
        } else {
         $$0$ph$i$i = $$024$i$i;$$in$i$i = $167;
        }
       } else {
        $169 = ($165|0)<($163|0);
        if (!($169)) {
         label = 49;
         break;
        }
        $170 = ((($$024$i$i)) + 4|0);
        $171 = HEAP32[$170>>2]|0;
        $172 = ($171|0)==(0|0);
        if ($172) {
         label = 48;
         break;
        } else {
         $$0$ph$i$i = $170;$$in$i$i = $171;
        }
       }
       $$0$i$i = $$0$ph$i$i;$$024$i$i = $$in$i$i;$1510 = $$in$i$i;
      }
      if ((label|0) == 45) {
       label = 0;
       $$025$i53$i = $$024$i$i;$$03752$i = $$024$i$i;
       label = 51;
       break;
      }
      else if ((label|0) == 48) {
       label = 0;
       $$025$i53$i = $170;$$03752$i = $$024$i$i;
       label = 51;
       break;
      }
      else if ((label|0) == 49) {
       label = 0;
       $$025$i$i = $$0$i$i;$$037$i = $$024$i$i;$173 = $1510;
       label = 50;
       break;
      }
     }
    } while(0);
    if ((label|0) == 50) {
     label = 0;
     $174 = ($173|0)==(0|0);
     if ($174) {
      $$025$i53$i = $$025$i$i;$$03752$i = $$037$i;
      label = 51;
     } else {
      $$014$i = $173;$190 = $161;
     }
    }
    if ((label|0) == 51) {
     label = 0;
     $175 = (__Znwj(32)|0);
     $176 = ((($175)) + 16|0);
     $177 = HEAP32[$141>>2]|0;
     HEAP32[$176>>2] = $177;
     $178 = ((($175)) + 20|0);
     ;HEAP32[$178>>2]=0|0;HEAP32[$178+4>>2]=0|0;HEAP32[$178+8>>2]=0|0;
     HEAP32[$175>>2] = 0;
     $179 = ((($175)) + 4|0);
     HEAP32[$179>>2] = 0;
     $180 = ((($175)) + 8|0);
     HEAP32[$180>>2] = $$03752$i;
     HEAP32[$$025$i53$i>>2] = $175;
     $181 = HEAP32[$63>>2]|0;
     $182 = HEAP32[$181>>2]|0;
     $183 = ($182|0)==(0|0);
     if ($183) {
      $186 = $175;
     } else {
      $184 = $182;
      HEAP32[$63>>2] = $184;
      $$pre$i$i = HEAP32[$$025$i53$i>>2]|0;
      $186 = $$pre$i$i;
     }
     $185 = HEAP32[$89>>2]|0;
     __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($185,$186);
     $187 = HEAP32[$66>>2]|0;
     $188 = (($187) + 1)|0;
     HEAP32[$66>>2] = $188;
     $$pre1074 = HEAP32[$64>>2]|0;
     $$014$i = $175;$190 = $$pre1074;
    }
    $189 = ((($$014$i)) + 24|0);
    HEAP32[$189>>2] = $$3319;
    $191 = ($190|0)==(0|0);
    do {
     if ($191) {
      $$025$i$i447 = $64;$$037$i446 = $64;$202 = $190;
      label = 64;
     } else {
      $192 = HEAP32[$141>>2]|0;
      $$0$i$i445 = $89;$$024$i$i444 = $190;$1511 = $190;
      while(1) {
       $193 = ((($$024$i$i444)) + 16|0);
       $194 = HEAP32[$193>>2]|0;
       $195 = ($192|0)<($194|0);
       if ($195) {
        $196 = HEAP32[$$024$i$i444>>2]|0;
        $197 = ($196|0)==(0|0);
        if ($197) {
         label = 59;
         break;
        } else {
         $$0$ph$i$i442 = $$024$i$i444;$$in$i$i441 = $196;
        }
       } else {
        $198 = ($194|0)<($192|0);
        if (!($198)) {
         label = 63;
         break;
        }
        $199 = ((($$024$i$i444)) + 4|0);
        $200 = HEAP32[$199>>2]|0;
        $201 = ($200|0)==(0|0);
        if ($201) {
         label = 62;
         break;
        } else {
         $$0$ph$i$i442 = $199;$$in$i$i441 = $200;
        }
       }
       $$0$i$i445 = $$0$ph$i$i442;$$024$i$i444 = $$in$i$i441;$1511 = $$in$i$i441;
      }
      if ((label|0) == 59) {
       label = 0;
       $$025$i53$i449 = $$024$i$i444;$$03752$i450 = $$024$i$i444;
       label = 65;
       break;
      }
      else if ((label|0) == 62) {
       label = 0;
       $$025$i53$i449 = $199;$$03752$i450 = $$024$i$i444;
       label = 65;
       break;
      }
      else if ((label|0) == 63) {
       label = 0;
       $$025$i$i447 = $$0$i$i445;$$037$i446 = $$024$i$i444;$202 = $1511;
       label = 64;
       break;
      }
     }
    } while(0);
    if ((label|0) == 64) {
     label = 0;
     $203 = ($202|0)==(0|0);
     if ($203) {
      $$025$i53$i449 = $$025$i$i447;$$03752$i450 = $$037$i446;
      label = 65;
     } else {
      $$014$i454 = $202;$219 = $190;
     }
    }
    if ((label|0) == 65) {
     label = 0;
     $204 = (__Znwj(32)|0);
     $205 = ((($204)) + 16|0);
     $206 = HEAP32[$141>>2]|0;
     HEAP32[$205>>2] = $206;
     $207 = ((($204)) + 20|0);
     ;HEAP32[$207>>2]=0|0;HEAP32[$207+4>>2]=0|0;HEAP32[$207+8>>2]=0|0;
     HEAP32[$204>>2] = 0;
     $208 = ((($204)) + 4|0);
     HEAP32[$208>>2] = 0;
     $209 = ((($204)) + 8|0);
     HEAP32[$209>>2] = $$03752$i450;
     HEAP32[$$025$i53$i449>>2] = $204;
     $210 = HEAP32[$63>>2]|0;
     $211 = HEAP32[$210>>2]|0;
     $212 = ($211|0)==(0|0);
     if ($212) {
      $215 = $204;
     } else {
      $213 = $211;
      HEAP32[$63>>2] = $213;
      $$pre$i$i452 = HEAP32[$$025$i53$i449>>2]|0;
      $215 = $$pre$i$i452;
     }
     $214 = HEAP32[$89>>2]|0;
     __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($214,$215);
     $216 = HEAP32[$66>>2]|0;
     $217 = (($216) + 1)|0;
     HEAP32[$66>>2] = $217;
     $$pre1075 = HEAP32[$64>>2]|0;
     $$014$i454 = $204;$219 = $$pre1075;
    }
    $218 = ((($$014$i454)) + 28|0);
    HEAP32[$218>>2] = $$1322;
    $220 = ($219|0)==(0|0);
    do {
     if ($220) {
      $$025$i$i463 = $64;$$037$i462 = $64;$231 = $219;
      label = 78;
     } else {
      $221 = HEAP32[$141>>2]|0;
      $$0$i$i461 = $89;$$024$i$i460 = $219;$1512 = $219;
      while(1) {
       $222 = ((($$024$i$i460)) + 16|0);
       $223 = HEAP32[$222>>2]|0;
       $224 = ($221|0)<($223|0);
       if ($224) {
        $225 = HEAP32[$$024$i$i460>>2]|0;
        $226 = ($225|0)==(0|0);
        if ($226) {
         label = 73;
         break;
        } else {
         $$0$ph$i$i458 = $$024$i$i460;$$in$i$i457 = $225;
        }
       } else {
        $227 = ($223|0)<($221|0);
        if (!($227)) {
         label = 77;
         break;
        }
        $228 = ((($$024$i$i460)) + 4|0);
        $229 = HEAP32[$228>>2]|0;
        $230 = ($229|0)==(0|0);
        if ($230) {
         label = 76;
         break;
        } else {
         $$0$ph$i$i458 = $228;$$in$i$i457 = $229;
        }
       }
       $$0$i$i461 = $$0$ph$i$i458;$$024$i$i460 = $$in$i$i457;$1512 = $$in$i$i457;
      }
      if ((label|0) == 73) {
       label = 0;
       $$025$i53$i465 = $$024$i$i460;$$03752$i466 = $$024$i$i460;
       label = 79;
       break;
      }
      else if ((label|0) == 76) {
       label = 0;
       $$025$i53$i465 = $228;$$03752$i466 = $$024$i$i460;
       label = 79;
       break;
      }
      else if ((label|0) == 77) {
       label = 0;
       $$025$i$i463 = $$0$i$i461;$$037$i462 = $$024$i$i460;$231 = $1512;
       label = 78;
       break;
      }
     }
    } while(0);
    if ((label|0) == 78) {
     label = 0;
     $232 = ($231|0)==(0|0);
     if ($232) {
      $$025$i53$i465 = $$025$i$i463;$$03752$i466 = $$037$i462;
      label = 79;
     } else {
      $$014$i470 = $231;
     }
    }
    if ((label|0) == 79) {
     label = 0;
     $233 = (__Znwj(32)|0);
     $234 = ((($233)) + 16|0);
     $235 = HEAP32[$141>>2]|0;
     HEAP32[$234>>2] = $235;
     $236 = ((($233)) + 20|0);
     ;HEAP32[$236>>2]=0|0;HEAP32[$236+4>>2]=0|0;HEAP32[$236+8>>2]=0|0;
     HEAP32[$233>>2] = 0;
     $237 = ((($233)) + 4|0);
     HEAP32[$237>>2] = 0;
     $238 = ((($233)) + 8|0);
     HEAP32[$238>>2] = $$03752$i466;
     HEAP32[$$025$i53$i465>>2] = $233;
     $239 = HEAP32[$63>>2]|0;
     $240 = HEAP32[$239>>2]|0;
     $241 = ($240|0)==(0|0);
     if ($241) {
      $244 = $233;
     } else {
      $242 = $240;
      HEAP32[$63>>2] = $242;
      $$pre$i$i468 = HEAP32[$$025$i53$i465>>2]|0;
      $244 = $$pre$i$i468;
     }
     $243 = HEAP32[$89>>2]|0;
     __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($243,$244);
     $245 = HEAP32[$66>>2]|0;
     $246 = (($245) + 1)|0;
     HEAP32[$66>>2] = $246;
     $$014$i470 = $233;
    }
    $247 = ((($$014$i470)) + 20|0);
    $248 = HEAP32[$247>>2]|0;
    $249 = ($248|0)==($143|0);
    if (!($249)) {
     HEAP32[$247>>2] = $143;
     $250 = ((($143)) + 8|0);
     $251 = HEAP32[$250>>2]|0;HEAP32[$250>>2] = (($251+1)|0);
     $252 = ($248|0)==(0|0);
     if (!($252)) {
      $253 = ((($248)) + 8|0);
      $254 = HEAP32[$253>>2]|0;HEAP32[$253>>2] = (($254-1)|0);
      $255 = ($254|0)==(1);
      if ($255) {
       __ZNK3osg10Referenced24signalObserversAndDeleteEbb($248,1,1);
      }
     }
    }
   }
   $256 = ((($$sroa$0765$0988)) + 28|0);
   $257 = HEAP32[$256>>2]|0;
   $258 = ($257|0)==(0|0);
   do {
    if (!($258)) {
     $259 = (___dynamic_cast($257,26864,26752,0)|0);
     $260 = ($259|0)==(0|0);
     if (!($260)) {
      $261 = HEAP32[$259>>2]|0;
      $262 = ((($261)) + 184|0);
      $263 = HEAP32[$262>>2]|0;
      $264 = (FUNCTION_TABLE_ii[$263 & 8191]($259)|0);
      $265 = ($264|0)==(0);
      if (!($265)) {
       break;
      }
      $266 = ((($259)) + 244|0);
      HEAP32[$266>>2] = $$0300$lcssa;
      break;
     }
     $267 = (___dynamic_cast($257,26864,26784,0)|0);
     $268 = ($267|0)==(0|0);
     if (!($268)) {
      $269 = HEAP32[$267>>2]|0;
      $270 = ((($269)) + 184|0);
      $271 = HEAP32[$270>>2]|0;
      $272 = (FUNCTION_TABLE_ii[$271 & 8191]($267)|0);
      $273 = ($272|0)==(0);
      if (!($273)) {
       $274 = HEAP32[$267>>2]|0;
       $275 = ((($274)) + 188|0);
       $276 = HEAP32[$275>>2]|0;
       $277 = (FUNCTION_TABLE_ii[$276 & 8191]($267)|0);
       $278 = ($277|0)==(0);
       if (!($278)) {
        break;
       }
      }
      $279 = ((($267)) + 244|0);
      HEAP32[$279>>2] = $$0300$lcssa;
      $280 = ((($267)) + 248|0);
      HEAP32[$280>>2] = $$0301$lcssa;
      break;
     }
     $281 = (___dynamic_cast($257,26864,26800,0)|0);
     $282 = ($281|0)==(0|0);
     if (!($282)) {
      $283 = HEAP32[$281>>2]|0;
      $284 = ((($283)) + 184|0);
      $285 = HEAP32[$284>>2]|0;
      $286 = (FUNCTION_TABLE_ii[$285 & 8191]($281)|0);
      $287 = ($286|0)==(0);
      if (!($287)) {
       $288 = HEAP32[$281>>2]|0;
       $289 = ((($288)) + 188|0);
       $290 = HEAP32[$289>>2]|0;
       $291 = (FUNCTION_TABLE_ii[$290 & 8191]($281)|0);
       $292 = ($291|0)==(0);
       if (!($292)) {
        break;
       }
      }
      $293 = ((($281)) + 240|0);
      HEAP32[$293>>2] = $$0300$lcssa;
      $294 = ((($281)) + 244|0);
      HEAP32[$294>>2] = $$0301$lcssa;
      break;
     }
     $295 = (___dynamic_cast($257,26864,26816,0)|0);
     $296 = ($295|0)==(0|0);
     if (!($296)) {
      $297 = HEAP32[$295>>2]|0;
      $298 = ((($297)) + 184|0);
      $299 = HEAP32[$298>>2]|0;
      $300 = (FUNCTION_TABLE_ii[$299 & 8191]($295)|0);
      $301 = ($300|0)==(0);
      if (!($301)) {
       $302 = HEAP32[$295>>2]|0;
       $303 = ((($302)) + 188|0);
       $304 = HEAP32[$303>>2]|0;
       $305 = (FUNCTION_TABLE_ii[$304 & 8191]($295)|0);
       $306 = ($305|0)==(0);
       if (!($306)) {
        $307 = HEAP32[$295>>2]|0;
        $308 = ((($307)) + 192|0);
        $309 = HEAP32[$308>>2]|0;
        $310 = (FUNCTION_TABLE_ii[$309 & 8191]($295)|0);
        $311 = ($310|0)==(0);
        if (!($311)) {
         break;
        }
       }
      }
      $312 = ((($295)) + 244|0);
      HEAP32[$312>>2] = $$0300$lcssa;
      $313 = ((($295)) + 248|0);
      HEAP32[$313>>2] = $$0301$lcssa;
      $314 = ((($295)) + 252|0);
      HEAP32[$314>>2] = $$0301$lcssa;
      break;
     }
     $315 = (___dynamic_cast($257,26864,26896,0)|0);
     $316 = ($315|0)==(0|0);
     if (!($316)) {
      $317 = HEAP32[$315>>2]|0;
      $318 = ((($317)) + 184|0);
      $319 = HEAP32[$318>>2]|0;
      $320 = (FUNCTION_TABLE_ii[$319 & 8191]($315)|0);
      $321 = ($320|0)==(0);
      if (!($321)) {
       $322 = HEAP32[$315>>2]|0;
       $323 = ((($322)) + 188|0);
       $324 = HEAP32[$323>>2]|0;
       $325 = (FUNCTION_TABLE_ii[$324 & 8191]($315)|0);
       $326 = ($325|0)==(0);
       if (!($326)) {
        break;
       }
      }
      $327 = ((($315)) + 264|0);
      HEAP32[$327>>2] = $$0300$lcssa;
      $328 = ((($315)) + 268|0);
      HEAP32[$328>>2] = $$0301$lcssa;
      break;
     }
     $329 = (___dynamic_cast($257,26864,26912,0)|0);
     $330 = ($329|0)==(0|0);
     if (!($330)) {
      $331 = HEAP32[$329>>2]|0;
      $332 = ((($331)) + 184|0);
      $333 = HEAP32[$332>>2]|0;
      $334 = (FUNCTION_TABLE_ii[$333 & 8191]($329)|0);
      $335 = ($334|0)==(0);
      if (!($335)) {
       $336 = HEAP32[$329>>2]|0;
       $337 = ((($336)) + 188|0);
       $338 = HEAP32[$337>>2]|0;
       $339 = (FUNCTION_TABLE_ii[$338 & 8191]($329)|0);
       $340 = ($339|0)==(0);
       if (!($340)) {
        break;
       }
      }
      $341 = ((($329)) + 244|0);
      HEAP32[$341>>2] = $$0300$lcssa;
      $342 = ((($329)) + 248|0);
      HEAP32[$342>>2] = $$0301$lcssa;
     }
    }
   } while(0);
   $343 = ((($$sroa$0765$0988)) + 4|0);
   $344 = HEAP32[$343>>2]|0;
   $345 = ($344|0)==(0|0);
   if ($345) {
    $346 = ((($$sroa$0765$0988)) + 8|0);
    $347 = HEAP32[$346>>2]|0;
    $348 = HEAP32[$347>>2]|0;
    $349 = ($348|0)==($$sroa$0765$0988|0);
    if ($349) {
     $$sroa$0765$0$be = $347;
    } else {
     $354 = $346;
     while(1) {
      $353 = HEAP32[$354>>2]|0;
      $355 = ((($353)) + 8|0);
      $356 = HEAP32[$355>>2]|0;
      $357 = HEAP32[$356>>2]|0;
      $358 = ($357|0)==($353|0);
      if ($358) {
       $$sroa$0765$0$be = $356;
       break;
      } else {
       $354 = $355;
      }
     }
    }
   } else {
    $$0$i$i$i$i488 = $344;
    while(1) {
     $351 = HEAP32[$$0$i$i$i$i488>>2]|0;
     $352 = ($351|0)==(0|0);
     if ($352) {
      break;
     } else {
      $$0$i$i$i$i488 = $351;
     }
    }
    $$sroa$0765$0$be = $$0$i$i$i$i488;
   }
   $350 = ($$sroa$0765$0$be|0)==($83|0);
   if ($350) {
    break;
   } else {
    $$sroa$0765$0988 = $$sroa$0765$0$be;
   }
  }
 }
 $140 = ($60|0)==(0);
 L175: do {
  if ($140) {
   $359 = ((($58)) + 784|0);
   $360 = HEAP32[$359>>2]|0;
   $361 = ((($360)) + 1252|0);
   $362 = HEAP8[$361>>0]|0;
   $363 = ($362<<24>>24)==(0);
   if ($363) {
    $364 = ($62|0)>(1);
    if ($364) {
     $$2$ph = $62;
     break;
    } else {
     label = 385;
     break;
    }
   }
   $365 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
   do {
    if ($365) {
     $366 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
     $367 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($366,117838,43)|0);
     $368 = HEAP32[$367>>2]|0;
     $369 = ((($368)) + -12|0);
     $370 = HEAP32[$369>>2]|0;
     $371 = (($367) + ($370)|0);
     __ZNKSt3__28ios_base6getlocEv($7,$371);
     __THREW__ = 0;
     $372 = (invoke_iii(3255,($7|0),(215188|0))|0);
     $373 = __THREW__; __THREW__ = 0;
     $374 = $373&1;
     if (!($374)) {
      $375 = HEAP32[$372>>2]|0;
      $376 = ((($375)) + 28|0);
      $377 = HEAP32[$376>>2]|0;
      __THREW__ = 0;
      $378 = (invoke_iii($377|0,($372|0),10)|0);
      $379 = __THREW__; __THREW__ = 0;
      $380 = $379&1;
      if (!($380)) {
       __ZNSt3__26localeD2Ev($7);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($367,$378)|0);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($367)|0);
       break;
      }
     }
     $381 = ___cxa_find_matching_catch_2()|0;
     $382 = tempRet0;
     __THREW__ = 0;
     invoke_vi(3263,($7|0));
     $383 = __THREW__; __THREW__ = 0;
     $384 = $383&1;
     if ($384) {
      $385 = ___cxa_find_matching_catch_3(0|0)|0;
      $386 = tempRet0;
      ___clang_call_terminate($385);
      // unreachable;
     } else {
      ___resumeException($381|0);
      // unreachable;
     }
    }
   } while(0);
   $387 = HEAP32[$29>>2]|0;
   $388 = ((($387)) + 208|0);
   $389 = HEAP32[$388>>2]|0;
   $390 = ((($389)) + 8|0);
   $391 = HEAP32[$390>>2]|0;
   (FUNCTION_TABLE_ii[$391 & 8191]($388)|0);
   __THREW__ = 0;
   $392 = (invoke_ii(3276,116)|0);
   $393 = __THREW__; __THREW__ = 0;
   $394 = $393&1;
   L190: do {
    if ($394) {
     $431 = ___cxa_find_matching_catch_2()|0;
     $432 = tempRet0;
     $$20 = $432;$$20362 = $431;
    } else {
     __THREW__ = 0;
     invoke_vi(3677,($392|0));
     $395 = __THREW__; __THREW__ = 0;
     $396 = $395&1;
     if ($396) {
      $433 = ___cxa_find_matching_catch_2()|0;
      $434 = tempRet0;
      __ZdlPv($392);
      $$20 = $434;$$20362 = $433;
      break;
     }
     $397 = ((($392)) + 8|0);
     $398 = HEAP32[$397>>2]|0;HEAP32[$397>>2] = (($398+1)|0);
     $399 = HEAP32[$29>>2]|0;
     $400 = ((($399)) + 596|0);
     $401 = HEAP32[$400>>2]|0;
     $402 = ($401|0)==(-1);
     L196: do {
      if ($402) {
       $403 = ((($399)) + 232|0);
       $404 = HEAP32[$403>>2]|0;
       $405 = ($404|0)==(0|0);
       do {
        if ($405) {
         __THREW__ = 0;
         $408 = (invoke_i(3285)|0);
         $409 = __THREW__; __THREW__ = 0;
         $410 = $409&1;
         if ($410) {
          $435 = ___cxa_find_matching_catch_2()|0;
          $436 = tempRet0;
          $$18360800 = $435;$$18802 = $436;$$sroa$0746$5799 = $392;
          break L196;
         } else {
          $$pre$i = HEAP32[$408>>2]|0;
          $$pre1076$pre = HEAP32[$29>>2]|0;
          $$phi$trans$insert$phi$trans$insert = ((($$pre1076$pre)) + 596|0);
          $$pre1077$pre = HEAP32[$$phi$trans$insert$phi$trans$insert>>2]|0;
          $411 = ((($$pre$i)) + 124|0);
          $412 = HEAP32[$411>>2]|0;
          $413 = ($$pre1077$pre|0)==(-1);
          if ($413) {
           $$pre10761082 = $$pre1076$pre;$1513 = $412;
           break;
          } else {
           $$0$i4961080 = $412;$$0$i500 = $$pre1077$pre;
           label = 137;
           break L196;
          }
         }
        } else {
         $406 = ((($404)) + 124|0);
         $407 = HEAP32[$406>>2]|0;
         $$pre10761082 = $399;$1513 = $407;
        }
       } while(0);
       $414 = ((($$pre10761082)) + 232|0);
       $415 = HEAP32[$414>>2]|0;
       $416 = ($415|0)==(0|0);
       do {
        if ($416) {
         __THREW__ = 0;
         $417 = (invoke_i(3285)|0);
         $418 = __THREW__; __THREW__ = 0;
         $419 = $418&1;
         if ($419) {
          $437 = ___cxa_find_matching_catch_2()|0;
          $438 = tempRet0;
          $$18360800 = $437;$$18802 = $438;$$sroa$0746$5799 = $392;
          break L196;
         } else {
          $$pre$i499 = HEAP32[$417>>2]|0;
          $421 = $$pre$i499;
          break;
         }
        } else {
         $421 = $415;
        }
       } while(0);
       $420 = ((($421)) + 124|0);
       $422 = HEAP32[$420>>2]|0;
       $$0$i4961080 = $1513;$$0$i500 = $422;
       label = 137;
      } else {
       $$0$i4961080 = $401;$$0$i500 = $401;
       label = 137;
      }
     } while(0);
     L211: do {
      if ((label|0) == 137) {
       $423 = ((($360)) + 1272|0);
       $424 = HEAP32[$423>>2]|0;
       $425 = ($424|0)==(0|0);
       L213: do {
        if ($425) {
         $$0323 = $$0$i500;$$1328 = 0;$$2326 = 0;$$sroa$0729$3 = 0;
         label = 174;
        } else {
         $426 = HEAP32[$81>>2]|0;
         $427 = ($426|0)==($83|0);
         if ($427) {
          $$0323 = $$0$i500;$$1328 = 0;$$2326 = 0;$$sroa$0729$3 = 0;
          label = 174;
         } else {
          $$0324984 = 0;$$0327983 = 0;$$sroa$0724$0982 = $426;
          while(1) {
           $441 = ((($$sroa$0724$0982)) + 44|0);
           $442 = HEAP32[$441>>2]|0;
           $443 = ($$0327983>>>0)>($442>>>0);
           $430 = $443 ? $$0327983 : $442;
           $444 = ((($$sroa$0724$0982)) + 48|0);
           $445 = HEAP32[$444>>2]|0;
           $446 = ($$0324984>>>0)>($445>>>0);
           $428 = $446 ? $$0324984 : $445;
           $447 = ((($$sroa$0724$0982)) + 4|0);
           $448 = HEAP32[$447>>2]|0;
           $449 = ($448|0)==(0|0);
           do {
            if ($449) {
             $450 = ((($$sroa$0724$0982)) + 8|0);
             $451 = HEAP32[$450>>2]|0;
             $452 = HEAP32[$451>>2]|0;
             $453 = ($452|0)==($$sroa$0724$0982|0);
             if ($453) {
              $$sroa$0724$0$be = $451;
              break;
             } else {
              $458 = $450;
             }
             while(1) {
              $457 = HEAP32[$458>>2]|0;
              $459 = ((($457)) + 8|0);
              $460 = HEAP32[$459>>2]|0;
              $461 = HEAP32[$460>>2]|0;
              $462 = ($461|0)==($457|0);
              if ($462) {
               $$sroa$0724$0$be = $460;
               break;
              } else {
               $458 = $459;
              }
             }
            } else {
             $$0$i$i$i$i506 = $448;
             while(1) {
              $455 = HEAP32[$$0$i$i$i$i506>>2]|0;
              $456 = ($455|0)==(0|0);
              if ($456) {
               break;
              } else {
               $$0$i$i$i$i506 = $455;
              }
             }
             $$sroa$0724$0$be = $$0$i$i$i$i506;
            }
           } while(0);
           $454 = ($$sroa$0724$0$be|0)==($83|0);
           if ($454) {
            break;
           } else {
            $$0324984 = $428;$$0327983 = $430;$$sroa$0724$0982 = $$sroa$0724$0$be;
           }
          }
          $429 = ($428>>>0)>($430>>>0);
          L226: do {
           if ($429) {
            __THREW__ = 0;
            $463 = (invoke_ii(3265,2)|0);
            $464 = __THREW__; __THREW__ = 0;
            $465 = $464&1;
            if ($465) {
             $$sroa$0729$0 = 0;
             label = 144;
             break L213;
            }
            if (!($463)) {
             $$1325 = $430;
             break;
            }
            __THREW__ = 0;
            $466 = (invoke_ii(3266,2)|0);
            $467 = __THREW__; __THREW__ = 0;
            $468 = $467&1;
            if ($468) {
             $$sroa$0729$0 = 0;
             label = 144;
             break L213;
            }
            __THREW__ = 0;
            $469 = (invoke_iiii(3267,($466|0),(117882|0),104)|0);
            $470 = __THREW__; __THREW__ = 0;
            $471 = $470&1;
            if ($471) {
             $$sroa$0729$0 = 0;
             label = 144;
             break L213;
            }
            $472 = HEAP32[$469>>2]|0;
            $473 = ((($472)) + -12|0);
            $474 = HEAP32[$473>>2]|0;
            $475 = (($469) + ($474)|0);
            __THREW__ = 0;
            invoke_vii(3257,($6|0),($475|0));
            $476 = __THREW__; __THREW__ = 0;
            $477 = $476&1;
            if ($477) {
             $$sroa$0729$0 = 0;
             label = 144;
             break L213;
            }
            __THREW__ = 0;
            $478 = (invoke_iii(3255,($6|0),(215188|0))|0);
            $479 = __THREW__; __THREW__ = 0;
            $480 = $479&1;
            do {
             if (!($480)) {
              $481 = HEAP32[$478>>2]|0;
              $482 = ((($481)) + 28|0);
              $483 = HEAP32[$482>>2]|0;
              __THREW__ = 0;
              $484 = (invoke_iii($483|0,($478|0),10)|0);
              $485 = __THREW__; __THREW__ = 0;
              $486 = $485&1;
              if ($486) {
               break;
              }
              __THREW__ = 0;
              invoke_vi(3263,($6|0));
              $487 = __THREW__; __THREW__ = 0;
              $488 = $487&1;
              if ($488) {
               $$sroa$0729$0 = 0;
               label = 144;
               break L213;
              }
              __THREW__ = 0;
              (invoke_iii(3268,($469|0),($484|0))|0);
              $495 = __THREW__; __THREW__ = 0;
              $496 = $495&1;
              if ($496) {
               $$sroa$0729$0 = 0;
               label = 144;
               break L213;
              }
              __THREW__ = 0;
              (invoke_ii(3269,($469|0))|0);
              $497 = __THREW__; __THREW__ = 0;
              $498 = $497&1;
              if ($498) {
               $$sroa$0729$0 = 0;
               label = 144;
               break L213;
              } else {
               $$1325 = $430;
               break L226;
              }
             }
            } while(0);
            $489 = ___cxa_find_matching_catch_2()|0;
            $490 = tempRet0;
            __THREW__ = 0;
            invoke_vi(3263,($6|0));
            $491 = __THREW__; __THREW__ = 0;
            $492 = $491&1;
            if ($492) {
             $493 = ___cxa_find_matching_catch_3(0|0)|0;
             $494 = tempRet0;
             ___clang_call_terminate($493);
             // unreachable;
            } else {
             $$sroa$0729$1 = 0;$eh$lpad$body530$index2Z2D = $490;$eh$lpad$body530$indexZ2D = $489;
             label = 145;
             break L213;
            }
           } else {
            $$1325 = $428;
           }
          } while(0);
          $499 = ($430|0)==(0);
          if ($499) {
           $$0323 = $$0$i500;$$1328 = 0;$$2326 = $$1325;$$sroa$0729$3 = 0;
           label = 174;
          } else {
           __THREW__ = 0;
           $500 = (invoke_ii(3276,116)|0);
           $501 = __THREW__; __THREW__ = 0;
           $502 = $501&1;
           if ($502) {
            $$sroa$0729$0 = 0;
            label = 144;
            break;
           }
           __THREW__ = 0;
           invoke_vi(3677,($500|0));
           $503 = __THREW__; __THREW__ = 0;
           $504 = $503&1;
           if ($504) {
            $520 = ___cxa_find_matching_catch_2()|0;
            $521 = tempRet0;
            __ZdlPv($500);
            $$18360800 = $520;$$18802 = $521;$$sroa$0746$5799 = $392;
            break L211;
           }
           $505 = ((($500)) + 8|0);
           $506 = HEAP32[$505>>2]|0;HEAP32[$505>>2] = (($506+1)|0);
           $507 = HEAP32[$29>>2]|0;
           $508 = ((($507)) + 600|0);
           $509 = HEAP32[$508>>2]|0;
           $510 = ($509|0)==(-1);
           if (!($510)) {
            $$0323 = $509;$$1328 = $430;$$2326 = $$1325;$$sroa$0729$3 = $500;
            label = 174;
            break;
           }
           $511 = ((($507)) + 232|0);
           $512 = HEAP32[$511>>2]|0;
           $513 = ($512|0)==(0|0);
           if ($513) {
            __THREW__ = 0;
            $514 = (invoke_i(3285)|0);
            $515 = __THREW__; __THREW__ = 0;
            $516 = $515&1;
            if ($516) {
             $$sroa$0729$0 = $500;
             label = 144;
             break;
            }
            $$pre$i523 = HEAP32[$514>>2]|0;
            $518 = $$pre$i523;
           } else {
            $518 = $512;
           }
           $517 = ((($518)) + 128|0);
           $519 = HEAP32[$517>>2]|0;
           $$0323 = $519;$$1328 = $430;$$2326 = $$1325;$$sroa$0729$3 = $500;
           label = 174;
          }
         }
        }
       } while(0);
       L253: do {
        if ((label|0) == 174) {
         $522 = HEAP32[$81>>2]|0;
         $523 = ($522|0)==($83|0);
         L255: do {
          if ($523) {
           $$0329$off0$lcssa1086 = 0;$$0333$off0$lcssa1084 = 0;
           label = 226;
          } else {
           $524 = ($$sroa$0729$3|0)==(0|0);
           $$0329$off0977 = 0;$$0331$off0976 = 0;$$0333$off0975 = 0;$$sroa$0715$0974 = $522;
           L257: while(1) {
            $525 = ((($$sroa$0715$0974)) + 16|0);
            $526 = HEAP32[$525>>2]|0;
            $527 = ((($$sroa$0715$0974)) + 20|0);
            $528 = ((($$sroa$0715$0974)) + 28|0);
            $529 = HEAP32[$528>>2]|0;
            $530 = ($529|0)==(0|0);
            do {
             if ($530) {
              $531 = ((($$sroa$0715$0974)) + 24|0);
              $532 = HEAP32[$531>>2]|0;
              $533 = ($532|0)==(0|0);
              if (!($533)) {
               label = 179;
               break;
              }
              __THREW__ = 0;
              $546 = (invoke_ii(3276,76)|0);
              $547 = __THREW__; __THREW__ = 0;
              $548 = $547&1;
              if ($548) {
               label = 192;
               break L257;
              }
              $549 = HEAP32[$527>>2]|0;
              __THREW__ = 0;
              invoke_viiiiii(3681,($546|0),($$0300$lcssa|0),($$0301$lcssa|0),($549|0),0,0);
              $550 = __THREW__; __THREW__ = 0;
              $551 = $550&1;
              if ($551) {
               label = 193;
               break L257;
              }
              __THREW__ = 0;
              invoke_vii(3682,($14|0),($546|0));
              $552 = __THREW__; __THREW__ = 0;
              $553 = $552&1;
              if ($553) {
               label = 192;
               break L257;
              }
              __THREW__ = 0;
              invoke_viii(3679,($392|0),($526|0),($14|0));
              $554 = __THREW__; __THREW__ = 0;
              $555 = $554&1;
              if ($555) {
               label = 194;
               break L257;
              }
              __THREW__ = 0;
              invoke_vi(3680,($14|0));
              $556 = __THREW__; __THREW__ = 0;
              $557 = $556&1;
              if ($557) {
               label = 192;
               break L257;
              }
             } else {
              label = 179;
             }
            } while(0);
            if ((label|0) == 179) {
             label = 0;
             __THREW__ = 0;
             invoke_vii(3678,($13|0),($527|0));
             $534 = __THREW__; __THREW__ = 0;
             $535 = $534&1;
             if ($535) {
              label = 183;
              break;
             }
             __THREW__ = 0;
             invoke_viii(3679,($392|0),($526|0),($13|0));
             $536 = __THREW__; __THREW__ = 0;
             $537 = $536&1;
             if ($537) {
              label = 184;
              break;
             }
             __THREW__ = 0;
             invoke_vi(3680,($13|0));
             $538 = __THREW__; __THREW__ = 0;
             $539 = $538&1;
             if ($539) {
              label = 183;
              break;
             }
            }
            if (!($524)) {
             $566 = HEAP32[$527>>2]|0;
             $567 = ($566|0)==(0);
             L275: do {
              if ($567) {
               switch ($526|0) {
               case 0:  {
                $$0320 = 33190;
                break L275;
                break;
               }
               case 1:  {
                $$0320 = 36168;
                break L275;
                break;
               }
               case 2:  {
                $$0320 = 34041;
                break L275;
                break;
               }
               default: {
                $568 = HEAP32[$528>>2]|0;
                $569 = ($568|0)==(0|0);
                if ($569) {
                 $$0320 = 6408;
                 break L275;
                }
                $570 = ((($568)) + 172|0);
                $571 = HEAP32[$570>>2]|0;
                $572 = ($571|0)==(0);
                if (!($572)) {
                 $$0320 = $571;
                 break L275;
                }
                $573 = HEAP32[$568>>2]|0;
                $574 = ((($573)) + 212|0);
                $575 = HEAP32[$574>>2]|0;
                __THREW__ = 0;
                invoke_vi($575|0,($568|0));
                $576 = __THREW__; __THREW__ = 0;
                $577 = $576&1;
                if ($577) {
                 label = 205;
                 break L257;
                }
                $$pre$i544 = HEAP32[$570>>2]|0;
                $$0320 = $$pre$i544;
                break L275;
               }
               }
              } else {
               $$0320 = $566;
              }
             } while(0);
             __THREW__ = 0;
             $580 = (invoke_ii(3276,76)|0);
             $581 = __THREW__; __THREW__ = 0;
             $582 = $581&1;
             if ($582) {
              label = 212;
              break;
             }
             __THREW__ = 0;
             invoke_viiiiii(3681,($580|0),($$0300$lcssa|0),($$0301$lcssa|0),($$0320|0),($$1328|0),($$2326|0));
             $583 = __THREW__; __THREW__ = 0;
             $584 = $583&1;
             if ($584) {
              label = 213;
              break;
             }
             __THREW__ = 0;
             invoke_vii(3682,($15|0),($580|0));
             $585 = __THREW__; __THREW__ = 0;
             $586 = $585&1;
             if ($586) {
              label = 212;
              break;
             }
             __THREW__ = 0;
             invoke_viii(3679,($$sroa$0729$3|0),($526|0),($15|0));
             $587 = __THREW__; __THREW__ = 0;
             $588 = $587&1;
             if ($588) {
              label = 214;
              break;
             }
             __THREW__ = 0;
             invoke_vi(3680,($15|0));
             $589 = __THREW__; __THREW__ = 0;
             $590 = $589&1;
             if ($590) {
              label = 212;
              break;
             }
            }
            switch ($526|0) {
            case 0:  {
             $$1330$off0 = $$0329$off0977;$$1332$off0 = 1;$$1334$off0 = $$0333$off0975;
             break;
            }
            case 1:  {
             $$1330$off0 = 1;$$1332$off0 = $$0331$off0976;$$1334$off0 = $$0333$off0975;
             break;
            }
            case 2:  {
             $$1330$off0 = 1;$$1332$off0 = 1;$$1334$off0 = $$0333$off0975;
             break;
            }
            default: {
             $599 = ($526|0)>(2);
             $$$0333$off0 = $$0333$off0975 | $599;
             $$1330$off0 = $$0329$off0977;$$1332$off0 = $$0331$off0976;$$1334$off0 = $$$0333$off0;
            }
            }
            $600 = ((($$sroa$0715$0974)) + 4|0);
            $601 = HEAP32[$600>>2]|0;
            $602 = ($601|0)==(0|0);
            do {
             if ($602) {
              $603 = ((($$sroa$0715$0974)) + 8|0);
              $604 = HEAP32[$603>>2]|0;
              $605 = HEAP32[$604>>2]|0;
              $606 = ($605|0)==($$sroa$0715$0974|0);
              if ($606) {
               $$sroa$0715$0$be = $604;
               break;
              } else {
               $611 = $603;
              }
              while(1) {
               $610 = HEAP32[$611>>2]|0;
               $612 = ((($610)) + 8|0);
               $613 = HEAP32[$612>>2]|0;
               $614 = HEAP32[$613>>2]|0;
               $615 = ($614|0)==($610|0);
               if ($615) {
                $$sroa$0715$0$be = $613;
                break;
               } else {
                $611 = $612;
               }
              }
             } else {
              $$0$i$i$i$i547 = $601;
              while(1) {
               $608 = HEAP32[$$0$i$i$i$i547>>2]|0;
               $609 = ($608|0)==(0|0);
               if ($609) {
                break;
               } else {
                $$0$i$i$i$i547 = $608;
               }
              }
              $$sroa$0715$0$be = $$0$i$i$i$i547;
             }
            } while(0);
            $607 = ($$sroa$0715$0$be|0)==($83|0);
            if ($607) {
             label = 176;
             break;
            } else {
             $$0329$off0977 = $$1330$off0;$$0331$off0976 = $$1332$off0;$$0333$off0975 = $$1334$off0;$$sroa$0715$0974 = $$sroa$0715$0$be;
            }
           }
           switch (label|0) {
            case 176: {
             if ($$1332$off0) {
              $$0329$off0$lcssa1087 = $$1330$off0;$$0333$off0$lcssa1085 = $$1334$off0;
              label = 248;
              break L255;
             } else {
              $$0329$off0$lcssa1086 = $$1330$off0;$$0333$off0$lcssa1084 = $$1334$off0;
              label = 226;
              break L255;
             }
             break;
            }
            case 183: {
             $540 = ___cxa_find_matching_catch_2()|0;
             $541 = tempRet0;
             $$1338 = $541;$$1343 = $540;
             label = 185;
             break;
            }
            case 184: {
             $542 = ___cxa_find_matching_catch_2()|0;
             $543 = tempRet0;
             __THREW__ = 0;
             invoke_vi(3680,($13|0));
             $544 = __THREW__; __THREW__ = 0;
             $545 = $544&1;
             if (!($545)) {
              $$1338 = $543;$$1343 = $542;
              label = 185;
              break;
             }
             $1505 = ___cxa_find_matching_catch_3(0|0)|0;
             $1506 = tempRet0;
             ___clang_call_terminate($1505);
             // unreachable;
             break;
            }
            case 192: {
             $558 = ___cxa_find_matching_catch_2()|0;
             $559 = tempRet0;
             $$2339 = $559;$$2344 = $558;
             label = 195;
             break;
            }
            case 193: {
             $560 = ___cxa_find_matching_catch_2()|0;
             $561 = tempRet0;
             __ZdlPv($546);
             $$2339 = $561;$$2344 = $560;
             label = 195;
             break;
            }
            case 194: {
             $562 = ___cxa_find_matching_catch_2()|0;
             $563 = tempRet0;
             __THREW__ = 0;
             invoke_vi(3680,($14|0));
             $564 = __THREW__; __THREW__ = 0;
             $565 = $564&1;
             if (!($565)) {
              $$2339 = $563;$$2344 = $562;
              label = 195;
              break;
             }
             $1505 = ___cxa_find_matching_catch_3(0|0)|0;
             $1506 = tempRet0;
             ___clang_call_terminate($1505);
             // unreachable;
             break;
            }
            case 205: {
             $578 = ___cxa_find_matching_catch_2()|0;
             $579 = tempRet0;
             $$171094 = $579;$$173591093 = $578;$$sroa$0729$101091 = $$sroa$0729$3;$$sroa$0746$41092 = $392;
             label = 375;
             break L253;
             break;
            }
            case 212: {
             $591 = ___cxa_find_matching_catch_2()|0;
             $592 = tempRet0;
             $$3340 = $592;$$3345 = $591;
             label = 215;
             break;
            }
            case 213: {
             $593 = ___cxa_find_matching_catch_2()|0;
             $594 = tempRet0;
             __ZdlPv($580);
             $$3340 = $594;$$3345 = $593;
             label = 215;
             break;
            }
            case 214: {
             $595 = ___cxa_find_matching_catch_2()|0;
             $596 = tempRet0;
             __THREW__ = 0;
             invoke_vi(3680,($15|0));
             $597 = __THREW__; __THREW__ = 0;
             $598 = $597&1;
             if (!($598)) {
              $$3340 = $596;$$3345 = $595;
              label = 215;
              break;
             }
             $1505 = ___cxa_find_matching_catch_3(0|0)|0;
             $1506 = tempRet0;
             ___clang_call_terminate($1505);
             // unreachable;
             break;
            }
           }
           if ((label|0) == 185) {
            $$17 = $$1338;$$17359 = $$1343;$$sroa$0729$10 = $$sroa$0729$3;$$sroa$0746$4 = $392;
            label = 374;
            break L253;
           }
           else if ((label|0) == 195) {
            $$17 = $$2339;$$17359 = $$2344;$$sroa$0729$10 = $$sroa$0729$3;$$sroa$0746$4 = $392;
            label = 374;
            break L253;
           }
           else if ((label|0) == 215) {
            $$17 = $$3340;$$17359 = $$3345;$$sroa$0729$10 = $$sroa$0729$3;$$sroa$0746$4 = $392;
            label = 374;
            break L253;
           }
          }
         } while(0);
         L322: do {
          if ((label|0) == 226) {
           $616 = $$0323 & 1;
           $617 = ($616|0)==(0);
           L324: do {
            if (!($617)) {
             __THREW__ = 0;
             $618 = (invoke_ii(3276,76)|0);
             $619 = __THREW__; __THREW__ = 0;
             $620 = $619&1;
             do {
              if ($620) {
               label = 233;
              } else {
               __THREW__ = 0;
               invoke_viiiiii(3681,($618|0),($$0300$lcssa|0),($$0301$lcssa|0),33190,0,0);
               $621 = __THREW__; __THREW__ = 0;
               $622 = $621&1;
               if ($622) {
                $631 = ___cxa_find_matching_catch_2()|0;
                $632 = tempRet0;
                __ZdlPv($618);
                $$8 = $632;$$8350 = $631;
                break;
               }
               __THREW__ = 0;
               invoke_vii(3682,($16|0),($618|0));
               $623 = __THREW__; __THREW__ = 0;
               $624 = $623&1;
               if ($624) {
                label = 233;
                break;
               }
               __THREW__ = 0;
               invoke_viii(3679,($392|0),0,($16|0));
               $625 = __THREW__; __THREW__ = 0;
               $626 = $625&1;
               if ($626) {
                $633 = ___cxa_find_matching_catch_2()|0;
                $634 = tempRet0;
                __THREW__ = 0;
                invoke_vi(3680,($16|0));
                $635 = __THREW__; __THREW__ = 0;
                $636 = $635&1;
                if (!($636)) {
                 $$8 = $634;$$8350 = $633;
                 break;
                }
                $1505 = ___cxa_find_matching_catch_3(0|0)|0;
                $1506 = tempRet0;
                ___clang_call_terminate($1505);
                // unreachable;
               } else {
                __THREW__ = 0;
                invoke_vi(3680,($16|0));
                $627 = __THREW__; __THREW__ = 0;
                $628 = $627&1;
                if ($628) {
                 label = 233;
                 break;
                }
                break L324;
               }
              }
             } while(0);
             if ((label|0) == 233) {
              $629 = ___cxa_find_matching_catch_2()|0;
              $630 = tempRet0;
              $$8 = $630;$$8350 = $629;
             }
             $$17 = $$8;$$17359 = $$8350;$$sroa$0729$10 = $$sroa$0729$3;$$sroa$0746$4 = $392;
             label = 374;
             break L253;
            }
           } while(0);
           $$not = ($$sroa$0729$3|0)==(0|0);
           $637 = $$0$i4961080 & 1;
           $638 = ($637|0)==(0);
           $or$cond = $638 | $$not;
           if ($or$cond) {
            $$0329$off0$lcssa1087 = $$0329$off0$lcssa1086;$$0333$off0$lcssa1085 = $$0333$off0$lcssa1084;
            label = 248;
            break;
           }
           __THREW__ = 0;
           $639 = (invoke_ii(3276,76)|0);
           $640 = __THREW__; __THREW__ = 0;
           $641 = $640&1;
           do {
            if ($641) {
             label = 244;
            } else {
             __THREW__ = 0;
             invoke_viiiiii(3681,($639|0),($$0300$lcssa|0),($$0301$lcssa|0),33190,($$1328|0),($$2326|0));
             $642 = __THREW__; __THREW__ = 0;
             $643 = $642&1;
             if ($643) {
              $652 = ___cxa_find_matching_catch_2()|0;
              $653 = tempRet0;
              __ZdlPv($639);
              $$9 = $653;$$9351 = $652;
              break;
             }
             __THREW__ = 0;
             invoke_vii(3682,($17|0),($639|0));
             $644 = __THREW__; __THREW__ = 0;
             $645 = $644&1;
             if ($645) {
              label = 244;
              break;
             }
             __THREW__ = 0;
             invoke_viii(3679,($$sroa$0729$3|0),0,($17|0));
             $646 = __THREW__; __THREW__ = 0;
             $647 = $646&1;
             if ($647) {
              $654 = ___cxa_find_matching_catch_2()|0;
              $655 = tempRet0;
              __THREW__ = 0;
              invoke_vi(3680,($17|0));
              $656 = __THREW__; __THREW__ = 0;
              $657 = $656&1;
              if (!($657)) {
               $$9 = $655;$$9351 = $654;
               break;
              }
              $1505 = ___cxa_find_matching_catch_3(0|0)|0;
              $1506 = tempRet0;
              ___clang_call_terminate($1505);
              // unreachable;
             } else {
              __THREW__ = 0;
              invoke_vi(3680,($17|0));
              $648 = __THREW__; __THREW__ = 0;
              $649 = $648&1;
              if ($649) {
               label = 244;
               break;
              }
              if ($$0329$off0$lcssa1086) {
               $$0333$off0$lcssa10851089 = $$0333$off0$lcssa1084;
               label = 271;
               break L322;
              } else {
               $$0333$off0$lcssa10851088 = $$0333$off0$lcssa1084;
               label = 249;
               break L322;
              }
             }
            }
           } while(0);
           if ((label|0) == 244) {
            $650 = ___cxa_find_matching_catch_2()|0;
            $651 = tempRet0;
            $$9 = $651;$$9351 = $650;
           }
           $$17 = $$9;$$17359 = $$9351;$$sroa$0729$10 = $$sroa$0729$3;$$sroa$0746$4 = $392;
           label = 374;
           break L253;
          }
         } while(0);
         if ((label|0) == 248) {
          if ($$0329$off0$lcssa1087) {
           $$0333$off0$lcssa10851089 = $$0333$off0$lcssa1085;
           label = 271;
          } else {
           $$0333$off0$lcssa10851088 = $$0333$off0$lcssa1085;
           label = 249;
          }
         }
         L358: do {
          if ((label|0) == 249) {
           $658 = $$0323 & 2;
           $659 = ($658|0)==(0);
           L360: do {
            if (!($659)) {
             __THREW__ = 0;
             $660 = (invoke_ii(3276,76)|0);
             $661 = __THREW__; __THREW__ = 0;
             $662 = $661&1;
             do {
              if ($662) {
               label = 256;
              } else {
               __THREW__ = 0;
               invoke_viiiiii(3681,($660|0),($$0300$lcssa|0),($$0301$lcssa|0),36168,0,0);
               $663 = __THREW__; __THREW__ = 0;
               $664 = $663&1;
               if ($664) {
                $673 = ___cxa_find_matching_catch_2()|0;
                $674 = tempRet0;
                __ZdlPv($660);
                $$10 = $674;$$10352 = $673;
                break;
               }
               __THREW__ = 0;
               invoke_vii(3682,($18|0),($660|0));
               $665 = __THREW__; __THREW__ = 0;
               $666 = $665&1;
               if ($666) {
                label = 256;
                break;
               }
               __THREW__ = 0;
               invoke_viii(3679,($392|0),1,($18|0));
               $667 = __THREW__; __THREW__ = 0;
               $668 = $667&1;
               if ($668) {
                $675 = ___cxa_find_matching_catch_2()|0;
                $676 = tempRet0;
                __THREW__ = 0;
                invoke_vi(3680,($18|0));
                $677 = __THREW__; __THREW__ = 0;
                $678 = $677&1;
                if (!($678)) {
                 $$10 = $676;$$10352 = $675;
                 break;
                }
                $1505 = ___cxa_find_matching_catch_3(0|0)|0;
                $1506 = tempRet0;
                ___clang_call_terminate($1505);
                // unreachable;
               } else {
                __THREW__ = 0;
                invoke_vi(3680,($18|0));
                $669 = __THREW__; __THREW__ = 0;
                $670 = $669&1;
                if ($670) {
                 label = 256;
                 break;
                }
                break L360;
               }
              }
             } while(0);
             if ((label|0) == 256) {
              $671 = ___cxa_find_matching_catch_2()|0;
              $672 = tempRet0;
              $$10 = $672;$$10352 = $671;
             }
             $$17 = $$10;$$17359 = $$10352;$$sroa$0729$10 = $$sroa$0729$3;$$sroa$0746$4 = $392;
             label = 374;
             break L253;
            }
           } while(0);
           $$not394 = ($$sroa$0729$3|0)==(0|0);
           $679 = $$0$i4961080 & 2;
           $680 = ($679|0)==(0);
           $or$cond396 = $680 | $$not394;
           if ($or$cond396) {
            $$0333$off0$lcssa10851089 = $$0333$off0$lcssa10851088;
            label = 271;
            break;
           }
           __THREW__ = 0;
           $681 = (invoke_ii(3276,76)|0);
           $682 = __THREW__; __THREW__ = 0;
           $683 = $682&1;
           do {
            if ($683) {
             label = 267;
            } else {
             __THREW__ = 0;
             invoke_viiiiii(3681,($681|0),($$0300$lcssa|0),($$0301$lcssa|0),36168,($$1328|0),($$2326|0));
             $684 = __THREW__; __THREW__ = 0;
             $685 = $684&1;
             if ($685) {
              $694 = ___cxa_find_matching_catch_2()|0;
              $695 = tempRet0;
              __ZdlPv($681);
              $$11 = $695;$$11353 = $694;
              break;
             }
             __THREW__ = 0;
             invoke_vii(3682,($19|0),($681|0));
             $686 = __THREW__; __THREW__ = 0;
             $687 = $686&1;
             if ($687) {
              label = 267;
              break;
             }
             __THREW__ = 0;
             invoke_viii(3679,($$sroa$0729$3|0),1,($19|0));
             $688 = __THREW__; __THREW__ = 0;
             $689 = $688&1;
             if ($689) {
              $696 = ___cxa_find_matching_catch_2()|0;
              $697 = tempRet0;
              __THREW__ = 0;
              invoke_vi(3680,($19|0));
              $698 = __THREW__; __THREW__ = 0;
              $699 = $698&1;
              if (!($699)) {
               $$11 = $697;$$11353 = $696;
               break;
              }
              $1505 = ___cxa_find_matching_catch_3(0|0)|0;
              $1506 = tempRet0;
              ___clang_call_terminate($1505);
              // unreachable;
             } else {
              __THREW__ = 0;
              invoke_vi(3680,($19|0));
              $690 = __THREW__; __THREW__ = 0;
              $691 = $690&1;
              if ($691) {
               label = 267;
               break;
              }
              if ($$0333$off0$lcssa10851088) {
               $$3336$off0 = 1;
               break L358;
              } else {
               label = 272;
               break L358;
              }
             }
            }
           } while(0);
           if ((label|0) == 267) {
            $692 = ___cxa_find_matching_catch_2()|0;
            $693 = tempRet0;
            $$11 = $693;$$11353 = $692;
           }
           $$17 = $$11;$$17359 = $$11353;$$sroa$0729$10 = $$sroa$0729$3;$$sroa$0746$4 = $392;
           label = 374;
           break L253;
          }
         } while(0);
         if ((label|0) == 271) {
          if ($$0333$off0$lcssa10851089) {
           $$3336$off0 = 1;
          } else {
           label = 272;
          }
         }
         L394: do {
          if ((label|0) == 272) {
           $700 = $$0323 & 4;
           $701 = ($700|0)==(0);
           L396: do {
            if ($701) {
             $$2335$off0 = 0;
            } else {
             __THREW__ = 0;
             $702 = (invoke_ii(3276,76)|0);
             $703 = __THREW__; __THREW__ = 0;
             $704 = $703&1;
             do {
              if ($704) {
               label = 279;
              } else {
               __THREW__ = 0;
               invoke_viiiiii(3681,($702|0),($$0300$lcssa|0),($$0301$lcssa|0),6407,0,0);
               $705 = __THREW__; __THREW__ = 0;
               $706 = $705&1;
               if ($706) {
                $715 = ___cxa_find_matching_catch_2()|0;
                $716 = tempRet0;
                __ZdlPv($702);
                $$12 = $716;$$12354 = $715;
                break;
               }
               __THREW__ = 0;
               invoke_vii(3682,($20|0),($702|0));
               $707 = __THREW__; __THREW__ = 0;
               $708 = $707&1;
               if ($708) {
                label = 279;
                break;
               }
               __THREW__ = 0;
               invoke_viii(3679,($392|0),3,($20|0));
               $709 = __THREW__; __THREW__ = 0;
               $710 = $709&1;
               if ($710) {
                $717 = ___cxa_find_matching_catch_2()|0;
                $718 = tempRet0;
                __THREW__ = 0;
                invoke_vi(3680,($20|0));
                $719 = __THREW__; __THREW__ = 0;
                $720 = $719&1;
                if (!($720)) {
                 $$12 = $718;$$12354 = $717;
                 break;
                }
                $1505 = ___cxa_find_matching_catch_3(0|0)|0;
                $1506 = tempRet0;
                ___clang_call_terminate($1505);
                // unreachable;
               } else {
                __THREW__ = 0;
                invoke_vi(3680,($20|0));
                $711 = __THREW__; __THREW__ = 0;
                $712 = $711&1;
                if ($712) {
                 label = 279;
                 break;
                }
                $$2335$off0 = 1;
                break L396;
               }
              }
             } while(0);
             if ((label|0) == 279) {
              $713 = ___cxa_find_matching_catch_2()|0;
              $714 = tempRet0;
              $$12 = $714;$$12354 = $713;
             }
             $$17 = $$12;$$17359 = $$12354;$$sroa$0729$10 = $$sroa$0729$3;$$sroa$0746$4 = $392;
             label = 374;
             break L253;
            }
           } while(0);
           $$not397 = ($$sroa$0729$3|0)==(0|0);
           $721 = $$0$i4961080 & 4;
           $722 = ($721|0)==(0);
           $or$cond399 = $722 | $$not397;
           if ($or$cond399) {
            $$3336$off0 = $$2335$off0;
            break;
           }
           __THREW__ = 0;
           $723 = (invoke_ii(3276,76)|0);
           $724 = __THREW__; __THREW__ = 0;
           $725 = $724&1;
           do {
            if ($725) {
             label = 290;
            } else {
             __THREW__ = 0;
             invoke_viiiiii(3681,($723|0),($$0300$lcssa|0),($$0301$lcssa|0),6407,($$1328|0),($$2326|0));
             $726 = __THREW__; __THREW__ = 0;
             $727 = $726&1;
             if ($727) {
              $736 = ___cxa_find_matching_catch_2()|0;
              $737 = tempRet0;
              __ZdlPv($723);
              $$13 = $737;$$13355 = $736;
              break;
             }
             __THREW__ = 0;
             invoke_vii(3682,($21|0),($723|0));
             $728 = __THREW__; __THREW__ = 0;
             $729 = $728&1;
             if ($729) {
              label = 290;
              break;
             }
             __THREW__ = 0;
             invoke_viii(3679,($$sroa$0729$3|0),3,($21|0));
             $730 = __THREW__; __THREW__ = 0;
             $731 = $730&1;
             if ($731) {
              $738 = ___cxa_find_matching_catch_2()|0;
              $739 = tempRet0;
              __THREW__ = 0;
              invoke_vi(3680,($21|0));
              $740 = __THREW__; __THREW__ = 0;
              $741 = $740&1;
              if (!($741)) {
               $$13 = $739;$$13355 = $738;
               break;
              }
              $1505 = ___cxa_find_matching_catch_3(0|0)|0;
              $1506 = tempRet0;
              ___clang_call_terminate($1505);
              // unreachable;
             } else {
              __THREW__ = 0;
              invoke_vi(3680,($21|0));
              $732 = __THREW__; __THREW__ = 0;
              $733 = $732&1;
              if ($733) {
               label = 290;
               break;
              }
              $$3336$off0 = $$2335$off0;
              break L394;
             }
            }
           } while(0);
           if ((label|0) == 290) {
            $734 = ___cxa_find_matching_catch_2()|0;
            $735 = tempRet0;
            $$13 = $735;$$13355 = $734;
           }
           $$17 = $$13;$$17359 = $$13355;$$sroa$0729$10 = $$sroa$0729$3;$$sroa$0746$4 = $392;
           label = 374;
           break L253;
          }
         } while(0);
         $742 = HEAP32[$392>>2]|0;
         $743 = ((($742)) + 172|0);
         $744 = HEAP32[$743>>2]|0;
         __THREW__ = 0;
         invoke_vii($744|0,($392|0),($58|0));
         $745 = __THREW__; __THREW__ = 0;
         $746 = $745&1;
         if ($746) {
          $$sroa$0729$0 = $$sroa$0729$3;
          label = 144;
         } else {
          if (!($$3336$off0)) {
           $747 = ((($0)) + 148|0);
           HEAP32[$747>>2] = 0;
           $748 = ((($0)) + 152|0);
           HEAP8[$748>>0] = 1;
           $749 = ((($0)) + 156|0);
           HEAP32[$749>>2] = 0;
           $750 = ((($0)) + 160|0);
           HEAP8[$750>>0] = 1;
          }
          $751 = ((($360)) + 1292|0);
          $752 = HEAP32[$751>>2]|0;
          __THREW__ = 0;
          $753 = (invoke_ii($752|0,36160)|0);
          $754 = __THREW__; __THREW__ = 0;
          $755 = $754&1;
          if ($755) {
           $$sroa$0729$0 = $$sroa$0729$3;
           label = 144;
           break;
          }
          $756 = ($753|0)==(36053);
          L434: do {
           if ($756) {
            $855 = ((($0)) + 148|0);
            HEAP32[$855>>2] = 0;
            $856 = ((($0)) + 152|0);
            HEAP8[$856>>0] = 0;
            $857 = ((($0)) + 156|0);
            HEAP32[$857>>2] = 0;
            $858 = ((($0)) + 160|0);
            HEAP8[$858>>0] = 0;
            $859 = ((($0)) + 272|0);
            $860 = HEAP32[$859>>2]|0;
            $861 = ($860|0)==($392|0);
            do {
             if (!($861)) {
              HEAP32[$859>>2] = $392;
              $862 = HEAP32[$397>>2]|0;HEAP32[$397>>2] = (($862+1)|0);
              $863 = ($860|0)==(0|0);
              if ($863) {
               break;
              }
              $864 = ((($860)) + 8|0);
              $865 = HEAP32[$864>>2]|0;HEAP32[$864>>2] = (($865-1)|0);
              $866 = ($865|0)==(1);
              if (!($866)) {
               break;
              }
              __THREW__ = 0;
              invoke_viii(3262,($860|0),1,1);
              $867 = __THREW__; __THREW__ = 0;
              $868 = $867&1;
              if ($868) {
               $$sroa$0729$4 = $$sroa$0729$3;
               label = 313;
               break L434;
              }
             }
            } while(0);
            $869 = ($$sroa$0729$3|0)==(0|0);
            if ($869) {
             $990 = ((($0)) + 276|0);
             $991 = HEAP32[$990>>2]|0;
             $992 = ($991|0)==(0|0);
             if ($992) {
              $$0369785793 = $362;$$sroa$0746$2784794 = $392;
              label = 371;
              break;
             }
             HEAP32[$990>>2] = 0;
             $993 = ((($991)) + 8|0);
             $994 = HEAP32[$993>>2]|0;HEAP32[$993>>2] = (($994-1)|0);
             $995 = ($994|0)==(1);
             if (!($995)) {
              $$0369785793 = $362;$$sroa$0746$2784794 = $392;
              label = 371;
              break;
             }
             __THREW__ = 0;
             invoke_viii(3262,($991|0),1,1);
             $996 = __THREW__; __THREW__ = 0;
             $997 = $996&1;
             if ($997) {
              $$sroa$0729$4 = 0;
              label = 313;
              break;
             } else {
              $$0369785793 = $362;$$sroa$0746$2784794 = $392;
              label = 371;
              break;
             }
            }
            $870 = HEAP32[$$sroa$0729$3>>2]|0;
            $871 = ((($870)) + 172|0);
            $872 = HEAP32[$871>>2]|0;
            __THREW__ = 0;
            invoke_vii($872|0,($$sroa$0729$3|0),($58|0));
            $873 = __THREW__; __THREW__ = 0;
            $874 = $873&1;
            if ($874) {
             $$sroa$0729$4 = $$sroa$0729$3;
             label = 313;
             break;
            }
            $875 = HEAP32[$751>>2]|0;
            __THREW__ = 0;
            $876 = (invoke_ii($875|0,36160)|0);
            $877 = __THREW__; __THREW__ = 0;
            $878 = $877&1;
            if ($878) {
             $$sroa$0729$4 = $$sroa$0729$3;
             label = 313;
             break;
            }
            $879 = ($876|0)==(36053);
            if ($879) {
             $978 = ((($0)) + 276|0);
             $979 = HEAP32[$978>>2]|0;
             $980 = HEAP32[$859>>2]|0;
             HEAP32[$978>>2] = $980;
             HEAP32[$859>>2] = $979;
             $$cast = $979;
             $981 = ($$cast|0)==($$sroa$0729$3|0);
             if ($981) {
              $$0369790 = $362;$$sroa$0746$2789 = $392;
              label = 368;
              break;
             }
             HEAP32[$859>>2] = $$sroa$0729$3;
             $982 = ((($$sroa$0729$3)) + 8|0);
             $983 = HEAP32[$982>>2]|0;HEAP32[$982>>2] = (($983+1)|0);
             $984 = ($979|0)==(0);
             if ($984) {
              $$0369790 = $362;$$sroa$0746$2789 = $392;
              label = 368;
              break;
             }
             $985 = ((($$cast)) + 8|0);
             $986 = HEAP32[$985>>2]|0;HEAP32[$985>>2] = (($986-1)|0);
             $987 = ($986|0)==(1);
             if (!($987)) {
              $$0369790 = $362;$$sroa$0746$2789 = $392;
              label = 368;
              break;
             }
             __THREW__ = 0;
             invoke_viii(3262,($$cast|0),1,1);
             $988 = __THREW__; __THREW__ = 0;
             $989 = $988&1;
             if ($989) {
              $$sroa$0729$4 = $$sroa$0729$3;
              label = 313;
              break;
             } else {
              $$0369790 = $362;$$sroa$0746$2789 = $392;
              label = 368;
              break;
             }
            }
            __THREW__ = 0;
            $880 = (invoke_ii(3265,3)|0);
            $881 = __THREW__; __THREW__ = 0;
            $882 = $881&1;
            if ($882) {
             $$sroa$0729$4 = $$sroa$0729$3;
             label = 313;
             break;
            }
            L455: do {
             if ($880) {
              __THREW__ = 0;
              $883 = (invoke_ii(3266,3)|0);
              $884 = __THREW__; __THREW__ = 0;
              $885 = $884&1;
              if ($885) {
               $$sroa$0729$4 = $$sroa$0729$3;
               label = 313;
               break L434;
              }
              __THREW__ = 0;
              $886 = (invoke_iiii(3267,($883|0),(118051|0),76)|0);
              $887 = __THREW__; __THREW__ = 0;
              $888 = $887&1;
              if ($888) {
               $$sroa$0729$4 = $$sroa$0729$3;
               label = 313;
               break L434;
              }
              $889 = HEAP32[$886>>2]|0;
              $890 = ((($889)) + -12|0);
              $891 = HEAP32[$890>>2]|0;
              $892 = (($886) + ($891)|0);
              $893 = ((($892)) + 4|0);
              $894 = HEAP32[$893>>2]|0;
              $895 = $894 & -75;
              $896 = $895 | 8;
              HEAP32[$893>>2] = $896;
              __THREW__ = 0;
              $897 = (invoke_iii(3417,($886|0),($876|0))|0);
              $898 = __THREW__; __THREW__ = 0;
              $899 = $898&1;
              if ($899) {
               $$sroa$0729$4 = $$sroa$0729$3;
               label = 313;
               break L434;
              }
              $900 = HEAP32[$897>>2]|0;
              $901 = ((($900)) + -12|0);
              $902 = HEAP32[$901>>2]|0;
              $903 = (($897) + ($902)|0);
              $904 = ((($903)) + 4|0);
              $905 = HEAP32[$904>>2]|0;
              $906 = $905 & -75;
              $907 = $906 | 2;
              HEAP32[$904>>2] = $907;
              $908 = HEAP32[$897>>2]|0;
              $909 = ((($908)) + -12|0);
              $910 = HEAP32[$909>>2]|0;
              $911 = (($897) + ($910)|0);
              __THREW__ = 0;
              invoke_vii(3257,($2|0),($911|0));
              $912 = __THREW__; __THREW__ = 0;
              $913 = $912&1;
              if ($913) {
               $$sroa$0729$4 = $$sroa$0729$3;
               label = 313;
               break L434;
              }
              __THREW__ = 0;
              $914 = (invoke_iii(3255,($2|0),(215188|0))|0);
              $915 = __THREW__; __THREW__ = 0;
              $916 = $915&1;
              do {
               if (!($916)) {
                $917 = HEAP32[$914>>2]|0;
                $918 = ((($917)) + 28|0);
                $919 = HEAP32[$918>>2]|0;
                __THREW__ = 0;
                $920 = (invoke_iii($919|0,($914|0),10)|0);
                $921 = __THREW__; __THREW__ = 0;
                $922 = $921&1;
                if ($922) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3263,($2|0));
                $923 = __THREW__; __THREW__ = 0;
                $924 = $923&1;
                if ($924) {
                 $$sroa$0729$4 = $$sroa$0729$3;
                 label = 313;
                 break L434;
                }
                __THREW__ = 0;
                (invoke_iii(3268,($897|0),($920|0))|0);
                $931 = __THREW__; __THREW__ = 0;
                $932 = $931&1;
                if ($932) {
                 $$sroa$0729$4 = $$sroa$0729$3;
                 label = 313;
                 break L434;
                }
                __THREW__ = 0;
                (invoke_ii(3269,($897|0))|0);
                $933 = __THREW__; __THREW__ = 0;
                $934 = $933&1;
                if ($934) {
                 $$sroa$0729$4 = $$sroa$0729$3;
                 label = 313;
                 break L434;
                } else {
                 break L455;
                }
               }
              } while(0);
              $925 = ___cxa_find_matching_catch_2()|0;
              $926 = tempRet0;
              __THREW__ = 0;
              invoke_vi(3263,($2|0));
              $927 = __THREW__; __THREW__ = 0;
              $928 = $927&1;
              if ($928) {
               $929 = ___cxa_find_matching_catch_3(0|0)|0;
               $930 = tempRet0;
               ___clang_call_terminate($929);
               // unreachable;
              } else {
               $$sink400$index = $925;$$sink400$index9 = $926;$$sroa$0729$9 = $$sroa$0729$3;$$sroa$0746$3 = $392;
               label = 373;
               break L434;
              }
             }
            } while(0);
            $935 = HEAP32[$392>>2]|0;
            $936 = ((($935)) + 172|0);
            $937 = HEAP32[$936>>2]|0;
            __THREW__ = 0;
            invoke_vii($937|0,($392|0),($58|0));
            $938 = __THREW__; __THREW__ = 0;
            $939 = $938&1;
            if ($939) {
             $$sroa$0729$4 = $$sroa$0729$3;
             label = 313;
             break;
            }
            $940 = ((($$sroa$0729$3)) + 8|0);
            $941 = HEAP32[$940>>2]|0;HEAP32[$940>>2] = (($941-1)|0);
            $942 = ($941|0)==(1);
            if ($942) {
             __THREW__ = 0;
             invoke_viii(3262,($$sroa$0729$3|0),1,1);
             $943 = __THREW__; __THREW__ = 0;
             $944 = $943&1;
             if ($944) {
              $$sroa$0729$4 = 0;
              label = 313;
              break;
             }
            }
            $945 = ((($0)) + 276|0);
            $946 = HEAP32[$945>>2]|0;
            $947 = ($946|0)==(0|0);
            do {
             if (!($947)) {
              HEAP32[$945>>2] = 0;
              $948 = ((($946)) + 8|0);
              $949 = HEAP32[$948>>2]|0;HEAP32[$948>>2] = (($949-1)|0);
              $950 = ($949|0)==(1);
              if (!($950)) {
               break;
              }
              __THREW__ = 0;
              invoke_viii(3262,($946|0),1,1);
              $951 = __THREW__; __THREW__ = 0;
              $952 = $951&1;
              if ($952) {
               $$sroa$0729$4 = 0;
               label = 313;
               break L434;
              }
             }
            } while(0);
            $953 = ((($58)) + 124|0);
            $954 = HEAP32[$953>>2]|0;
            __THREW__ = 0;
            $955 = (invoke_ii(3683,($954|0))|0);
            $956 = __THREW__; __THREW__ = 0;
            $957 = $956&1;
            if ($957) {
             $$sroa$0729$4 = 0;
             label = 313;
             break;
            }
            __THREW__ = 0;
            $958 = (invoke_ii(3684,($955|0))|0);
            $959 = __THREW__; __THREW__ = 0;
            $960 = $959&1;
            if ($960) {
             $$sroa$0729$4 = 0;
             label = 313;
             break;
            }
            $961 = HEAP32[$958>>2]|0;
            $962 = ((($961)) + 32|0);
            $963 = HEAP32[$962>>2]|0;
            __THREW__ = 0;
            invoke_vi($963|0,($958|0));
            $964 = __THREW__; __THREW__ = 0;
            $965 = $964&1;
            if ($965) {
             $$sroa$0729$4 = 0;
             label = 313;
             break;
            }
            $966 = HEAP32[$953>>2]|0;
            __THREW__ = 0;
            $967 = (invoke_ii(3683,($966|0))|0);
            $968 = __THREW__; __THREW__ = 0;
            $969 = $968&1;
            if ($969) {
             $$sroa$0729$4 = 0;
             label = 313;
             break;
            }
            __THREW__ = 0;
            $970 = (invoke_ii(3685,($967|0))|0);
            $971 = __THREW__; __THREW__ = 0;
            $972 = $971&1;
            if ($972) {
             $$sroa$0729$4 = 0;
             label = 313;
             break;
            }
            $973 = HEAP32[$970>>2]|0;
            $974 = ((($973)) + 32|0);
            $975 = HEAP32[$974>>2]|0;
            __THREW__ = 0;
            invoke_vi($975|0,($970|0));
            $976 = __THREW__; __THREW__ = 0;
            $977 = $976&1;
            if ($977) {
             $$sroa$0729$4 = 0;
             label = 313;
            } else {
             $$0369785793 = $362;$$sroa$0746$2784794 = $392;
             label = 371;
            }
           } else {
            __THREW__ = 0;
            $757 = (invoke_ii(3265,3)|0);
            $758 = __THREW__; __THREW__ = 0;
            $759 = $758&1;
            if ($759) {
             $$sroa$0729$4 = $$sroa$0729$3;
             label = 313;
             break;
            }
            L486: do {
             if ($757) {
              __THREW__ = 0;
              $760 = (invoke_ii(3266,3)|0);
              $761 = __THREW__; __THREW__ = 0;
              $762 = $761&1;
              if ($762) {
               $$sroa$0729$4 = $$sroa$0729$3;
               label = 313;
               break L434;
              }
              __THREW__ = 0;
              $763 = (invoke_iiii(3267,($760|0),(117987|0),63)|0);
              $764 = __THREW__; __THREW__ = 0;
              $765 = $764&1;
              if ($765) {
               $$sroa$0729$4 = $$sroa$0729$3;
               label = 313;
               break L434;
              }
              $766 = HEAP32[$763>>2]|0;
              $767 = ((($766)) + -12|0);
              $768 = HEAP32[$767>>2]|0;
              $769 = (($763) + ($768)|0);
              $770 = ((($769)) + 4|0);
              $771 = HEAP32[$770>>2]|0;
              $772 = $771 & -75;
              $773 = $772 | 8;
              HEAP32[$770>>2] = $773;
              __THREW__ = 0;
              $774 = (invoke_iii(3417,($763|0),($753|0))|0);
              $775 = __THREW__; __THREW__ = 0;
              $776 = $775&1;
              if ($776) {
               $$sroa$0729$4 = $$sroa$0729$3;
               label = 313;
               break L434;
              }
              $777 = HEAP32[$774>>2]|0;
              $778 = ((($777)) + -12|0);
              $779 = HEAP32[$778>>2]|0;
              $780 = (($774) + ($779)|0);
              $781 = ((($780)) + 4|0);
              $782 = HEAP32[$781>>2]|0;
              $783 = $782 & -75;
              $784 = $783 | 2;
              HEAP32[$781>>2] = $784;
              $785 = HEAP32[$774>>2]|0;
              $786 = ((($785)) + -12|0);
              $787 = HEAP32[$786>>2]|0;
              $788 = (($774) + ($787)|0);
              __THREW__ = 0;
              invoke_vii(3257,($3|0),($788|0));
              $789 = __THREW__; __THREW__ = 0;
              $790 = $789&1;
              if ($790) {
               $$sroa$0729$4 = $$sroa$0729$3;
               label = 313;
               break L434;
              }
              __THREW__ = 0;
              $791 = (invoke_iii(3255,($3|0),(215188|0))|0);
              $792 = __THREW__; __THREW__ = 0;
              $793 = $792&1;
              do {
               if (!($793)) {
                $794 = HEAP32[$791>>2]|0;
                $795 = ((($794)) + 28|0);
                $796 = HEAP32[$795>>2]|0;
                __THREW__ = 0;
                $797 = (invoke_iii($796|0,($791|0),10)|0);
                $798 = __THREW__; __THREW__ = 0;
                $799 = $798&1;
                if ($799) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3263,($3|0));
                $800 = __THREW__; __THREW__ = 0;
                $801 = $800&1;
                if ($801) {
                 $$sroa$0729$4 = $$sroa$0729$3;
                 label = 313;
                 break L434;
                }
                __THREW__ = 0;
                (invoke_iii(3268,($774|0),($797|0))|0);
                $808 = __THREW__; __THREW__ = 0;
                $809 = $808&1;
                if ($809) {
                 $$sroa$0729$4 = $$sroa$0729$3;
                 label = 313;
                 break L434;
                }
                __THREW__ = 0;
                (invoke_ii(3269,($774|0))|0);
                $810 = __THREW__; __THREW__ = 0;
                $811 = $810&1;
                if ($811) {
                 $$sroa$0729$4 = $$sroa$0729$3;
                 label = 313;
                 break L434;
                } else {
                 break L486;
                }
               }
              } while(0);
              $802 = ___cxa_find_matching_catch_2()|0;
              $803 = tempRet0;
              __THREW__ = 0;
              invoke_vi(3263,($3|0));
              $804 = __THREW__; __THREW__ = 0;
              $805 = $804&1;
              if ($805) {
               $806 = ___cxa_find_matching_catch_3(0|0)|0;
               $807 = tempRet0;
               ___clang_call_terminate($806);
               // unreachable;
              } else {
               $$sink400$index = $802;$$sink400$index9 = $803;$$sroa$0729$9 = $$sroa$0729$3;$$sroa$0746$3 = $392;
               label = 373;
               break L434;
              }
             }
            } while(0);
            $814 = ((($58)) + 120|0);
            $815 = HEAP32[$814>>2]|0;
            $816 = ($815|0)==(0|0);
            if ($816) {
             $821 = 0;
            } else {
             $817 = ((($815)) + 128|0);
             $818 = HEAP32[$817>>2]|0;
             $821 = $818;
            }
            $819 = ((($360)) + 1280|0);
            $820 = HEAP32[$819>>2]|0;
            __THREW__ = 0;
            invoke_vii($820|0,36160,($821|0));
            $822 = __THREW__; __THREW__ = 0;
            $823 = $822&1;
            do {
             if ($823) {
              $$sroa$0746$1 = $392;
             } else {
              $824 = HEAP32[$397>>2]|0;HEAP32[$397>>2] = (($824-1)|0);
              $825 = ($824|0)==(1);
              if ($825) {
               __THREW__ = 0;
               invoke_viii(3262,($392|0),1,1);
               $826 = __THREW__; __THREW__ = 0;
               $827 = $826&1;
               if ($827) {
                $$sroa$0746$1 = 0;
                break;
               }
              }
              $828 = ((($58)) + 124|0);
              $829 = HEAP32[$828>>2]|0;
              __THREW__ = 0;
              $830 = (invoke_ii(3683,($829|0))|0);
              $831 = __THREW__; __THREW__ = 0;
              $832 = $831&1;
              if ($832) {
               $$sroa$0746$1 = 0;
               break;
              }
              __THREW__ = 0;
              $833 = (invoke_ii(3684,($830|0))|0);
              $834 = __THREW__; __THREW__ = 0;
              $835 = $834&1;
              if ($835) {
               $$sroa$0746$1 = 0;
               break;
              }
              $836 = HEAP32[$833>>2]|0;
              $837 = ((($836)) + 32|0);
              $838 = HEAP32[$837>>2]|0;
              __THREW__ = 0;
              invoke_vi($838|0,($833|0));
              $839 = __THREW__; __THREW__ = 0;
              $840 = $839&1;
              if ($840) {
               $$sroa$0746$1 = 0;
               break;
              }
              $841 = HEAP32[$828>>2]|0;
              __THREW__ = 0;
              $842 = (invoke_ii(3683,($841|0))|0);
              $843 = __THREW__; __THREW__ = 0;
              $844 = $843&1;
              if ($844) {
               $$sroa$0746$1 = 0;
               break;
              }
              __THREW__ = 0;
              $845 = (invoke_ii(3685,($842|0))|0);
              $846 = __THREW__; __THREW__ = 0;
              $847 = $846&1;
              if ($847) {
               $$sroa$0746$1 = 0;
               break;
              }
              $848 = HEAP32[$845>>2]|0;
              $849 = ((($848)) + 32|0);
              $850 = HEAP32[$849>>2]|0;
              __THREW__ = 0;
              invoke_vi($850|0,($845|0));
              $851 = __THREW__; __THREW__ = 0;
              $852 = $851&1;
              if ($852) {
               $$sroa$0746$1 = 0;
               break;
              }
              $998 = ($$sroa$0729$3|0)==(0|0);
              if ($998) {
               $$0369785791 = 0;
               break L434;
              } else {
               $$0369790 = 0;$$sroa$0746$2789 = 0;
               label = 368;
               break L434;
              }
             }
            } while(0);
            $853 = ___cxa_find_matching_catch_2()|0;
            $854 = tempRet0;
            $$sink400$index = $853;$$sink400$index9 = $854;$$sroa$0729$9 = $$sroa$0729$3;$$sroa$0746$3 = $$sroa$0746$1;
            label = 373;
           }
          } while(0);
          if ((label|0) == 313) {
           $812 = ___cxa_find_matching_catch_2()|0;
           $813 = tempRet0;
           $$sink400$index = $812;$$sink400$index9 = $813;$$sroa$0729$9 = $$sroa$0729$4;$$sroa$0746$3 = $392;
           label = 373;
          }
          else if ((label|0) == 368) {
           $999 = ((($$sroa$0729$3)) + 8|0);
           $1000 = HEAP32[$999>>2]|0;HEAP32[$999>>2] = (($1000-1)|0);
           $1001 = ($1000|0)==(1);
           do {
            if ($1001) {
             __THREW__ = 0;
             invoke_viii(3262,($$sroa$0729$3|0),1,1);
             $1002 = __THREW__; __THREW__ = 0;
             $1003 = $1002&1;
             if (!($1003)) {
              break;
             }
             $1016 = ___cxa_find_matching_catch_2()|0;
             $1017 = tempRet0;
             $$18 = $1017;$$18360 = $1016;$$sroa$0746$5 = $$sroa$0746$2789;
             break L253;
            }
           } while(0);
           $1004 = ($$sroa$0746$2789|0)==(0|0);
           if ($1004) {
            $$0369785791 = $$0369790;
           } else {
            $$0369785793 = $$0369790;$$sroa$0746$2784794 = $$sroa$0746$2789;
            label = 371;
           }
          }
          if ((label|0) == 373) {
           $$17 = $$sink400$index9;$$17359 = $$sink400$index;$$sroa$0729$10 = $$sroa$0729$9;$$sroa$0746$4 = $$sroa$0746$3;
           label = 374;
           break;
          }
          do {
           if ((label|0) == 371) {
            $1005 = ((($$sroa$0746$2784794)) + 8|0);
            $1006 = HEAP32[$1005>>2]|0;HEAP32[$1005>>2] = (($1006-1)|0);
            $1007 = ($1006|0)==(1);
            if (!($1007)) {
             $$0369785791 = $$0369785793;
             break;
            }
            __THREW__ = 0;
            invoke_viii(3262,($$sroa$0746$2784794|0),1,1);
            $1008 = __THREW__; __THREW__ = 0;
            $1009 = $1008&1;
            if (!($1009)) {
             $$0369785791 = $$0369785793;
             break;
            }
            $1024 = ___cxa_find_matching_catch_2()|0;
            $1025 = tempRet0;
            $$20 = $1025;$$20362 = $1024;
            break L190;
           }
          } while(0);
          $1031 = HEAP32[$388>>2]|0;
          $1032 = ((($1031)) + 12|0);
          $1033 = HEAP32[$1032>>2]|0;
          (FUNCTION_TABLE_ii[$1033 & 8191]($388)|0);
          $$1370$off0 = ($$0369785791<<24>>24)==(0);
          $1034 = ($62|0)>(1);
          $$ = $1034 ? $62 : 1;
          if ($$1370$off0) {
           $$1 = $$;
           label = 384;
           break L175;
          } else {
           $$2$ph = 0;
           break L175;
          }
         }
        }
       } while(0);
       if ((label|0) == 144) {
        $439 = ___cxa_find_matching_catch_2()|0;
        $440 = tempRet0;
        $$sroa$0729$1 = $$sroa$0729$0;$eh$lpad$body530$index2Z2D = $440;$eh$lpad$body530$indexZ2D = $439;
        label = 145;
       }
       if ((label|0) == 145) {
        $$17 = $eh$lpad$body530$index2Z2D;$$17359 = $eh$lpad$body530$indexZ2D;$$sroa$0729$10 = $$sroa$0729$1;$$sroa$0746$4 = $392;
        label = 374;
       }
       if ((label|0) == 374) {
        $1010 = ($$sroa$0729$10|0)==(0|0);
        if ($1010) {
         $$18 = $$17;$$18360 = $$17359;$$sroa$0746$5 = $$sroa$0746$4;
        } else {
         $$171094 = $$17;$$173591093 = $$17359;$$sroa$0729$101091 = $$sroa$0729$10;$$sroa$0746$41092 = $$sroa$0746$4;
         label = 375;
        }
       }
       if ((label|0) == 375) {
        $1011 = ((($$sroa$0729$101091)) + 8|0);
        $1012 = HEAP32[$1011>>2]|0;HEAP32[$1011>>2] = (($1012-1)|0);
        $1013 = ($1012|0)==(1);
        if ($1013) {
         __THREW__ = 0;
         invoke_viii(3262,($$sroa$0729$101091|0),1,1);
         $1014 = __THREW__; __THREW__ = 0;
         $1015 = $1014&1;
         if ($1015) {
          $1505 = ___cxa_find_matching_catch_3(0|0)|0;
          $1506 = tempRet0;
          ___clang_call_terminate($1505);
          // unreachable;
         } else {
          $$18 = $$171094;$$18360 = $$173591093;$$sroa$0746$5 = $$sroa$0746$41092;
         }
        } else {
         $$18 = $$171094;$$18360 = $$173591093;$$sroa$0746$5 = $$sroa$0746$41092;
        }
       }
       $1018 = ($$sroa$0746$5|0)==(0|0);
       if ($1018) {
        $$20 = $$18;$$20362 = $$18360;
        break L190;
       } else {
        $$18360800 = $$18360;$$18802 = $$18;$$sroa$0746$5799 = $$sroa$0746$5;
       }
      }
     } while(0);
     $1019 = ((($$sroa$0746$5799)) + 8|0);
     $1020 = HEAP32[$1019>>2]|0;HEAP32[$1019>>2] = (($1020-1)|0);
     $1021 = ($1020|0)==(1);
     if ($1021) {
      __THREW__ = 0;
      invoke_viii(3262,($$sroa$0746$5799|0),1,1);
      $1022 = __THREW__; __THREW__ = 0;
      $1023 = $1022&1;
      if ($1023) {
       $1505 = ___cxa_find_matching_catch_3(0|0)|0;
       $1506 = tempRet0;
       ___clang_call_terminate($1505);
       // unreachable;
      } else {
       $$20 = $$18802;$$20362 = $$18360800;
      }
     } else {
      $$20 = $$18802;$$20362 = $$18360800;
     }
    }
   } while(0);
   $1026 = HEAP32[$388>>2]|0;
   $1027 = ((($1026)) + 12|0);
   $1028 = HEAP32[$1027>>2]|0;
   __THREW__ = 0;
   (invoke_ii($1028|0,($388|0))|0);
   $1029 = __THREW__; __THREW__ = 0;
   $1030 = $1029&1;
   if ($1030) {
    $1505 = ___cxa_find_matching_catch_3(0|0)|0;
    $1506 = tempRet0;
    ___clang_call_terminate($1505);
    // unreachable;
   } else {
    $$26 = $$20;$$26368 = $$20362;
    ___resumeException($$26368|0);
    // unreachable;
   }
  } else {
   $$1 = $60;
   label = 384;
  }
 } while(0);
 if ((label|0) == 384) {
  $1035 = ($$1|0)==(1);
  if ($1035) {
   label = 385;
  } else {
   $$2$ph = $$1;
  }
 }
 if ((label|0) == 385) {
  $1036 = ((($58)) + 124|0);
  $1037 = HEAP32[$1036>>2]|0;
  $1038 = (__ZN3osg22isGLExtensionSupportedEjPKc($1037,118128)|0);
  $1039 = ($62|0)>(2);
  $$401 = $1039 ? $62 : 2;
  $$$401 = $1038 ? 1 : $$401;
  $$2$ph = $$$401;
 }
 $1040 = ((($0)) + 280|0);
 $1041 = HEAP32[$1040>>2]|0;
 $1042 = ($1041|0)==(0|0);
 L554: do {
  if ($1042) {
   $1043 = ((($58)) + 120|0);
   $1044 = ((($0)) + 148|0);
   $1045 = ((($0)) + 152|0);
   $1046 = ((($0)) + 156|0);
   $1047 = ((($0)) + 160|0);
   $1048 = ((($0)) + 236|0);
   $1049 = ((($0)) + 240|0);
   $1050 = ((($0)) + 244|0);
   $$2970 = $$2$ph;
   L556: while(1) {
    $1051 = ($$2970|0)==(1);
    $1052 = ($$2970|0)==(4);
    switch ($$2970|0) {
    case 3:  {
     break L554;
     break;
    }
    case 1: case 2: case 4:  {
     break;
    }
    default: {
     label = 566;
     break L556;
    }
    }
    __THREW__ = 0;
    $1053 = (invoke_ii(3276,200)|0);
    $1054 = __THREW__; __THREW__ = 0;
    $1055 = $1054&1;
    if ($1055) {
     label = 394;
     break;
    }
    __THREW__ = 0;
    invoke_vii(3419,($1053|0),(0|0));
    $1056 = __THREW__; __THREW__ = 0;
    $1057 = $1056&1;
    if ($1057) {
     label = 395;
     break;
    }
    $1058 = ((($1053)) + 8|0);
    $1059 = HEAP32[$1058>>2]|0;HEAP32[$1058>>2] = (($1059+1)|0);
    $1060 = ((($1053)) + 40|0);
    HEAP32[$1060>>2] = $$0300$lcssa;
    $1061 = ((($1053)) + 44|0);
    HEAP32[$1061>>2] = $$0301$lcssa;
    $$2$off371 = (($$2970) + -1)|0;
    $1062 = ($$2$off371>>>0)<(2);
    $1063 = ((($1053)) + 108|0);
    $1064 = $1062&1;
    HEAP8[$1063>>0] = $1064;
    $1065 = ((($1053)) + 72|0);
    $1066 = $1052&1;
    HEAP8[$1065>>0] = $1066;
    $1067 = ((($1053)) + 110|0);
    HEAP8[$1067>>0] = $1066;
    $1068 = HEAP32[$81>>2]|0;
    $1069 = ($1068|0)==($83|0);
    if ($1069) {
     $$0305$lcssa1102 = 0;$$0307$lcssa1100 = 0;$$0309$lcssa1098 = 0;$$0313$lcssa1096 = 0;
     label = 440;
    } else {
     $1070 = ((($1053)) + 92|0);
     $1071 = ((($1053)) + 96|0);
     $1072 = ((($1053)) + 112|0);
     $1073 = ((($1053)) + 116|0);
     $1074 = ((($1053)) + 120|0);
     $1075 = ((($1053)) + 124|0);
     $1076 = ((($1053)) + 128|0);
     $$0302$off0964 = 0;$$0305963 = 0;$$0307962 = 0;$$0309961 = 0;$$0313960 = 0;$$sroa$0667$0958 = $1068;
     while(1) {
      $1081 = ((($$sroa$0667$0958)) + 16|0);
      $1082 = HEAP32[$1081>>2]|0;
      switch ($1082|0) {
      case 0:  {
       HEAP32[$1070>>2] = 24;
       $$1303$off0 = 1;$$1306 = $$0305963;$$1308 = $$0307962;$$2311 = $$0309961;$$2315 = $$0313960;
       break;
      }
      case 1:  {
       HEAP32[$1071>>2] = 8;
       $$1303$off0 = $$0302$off0964;$$1306 = $$0305963;$$1308 = $$0307962;$$2311 = $$0309961;$$2315 = $$0313960;
       break;
      }
      case 2:  {
       HEAP32[$1070>>2] = 24;
       HEAP32[$1071>>2] = 8;
       $$1303$off0 = 1;$$1306 = $$0305963;$$1308 = $$0307962;$$2311 = $$0309961;$$2315 = $$0313960;
       break;
      }
      case 3:  {
       $1085 = ((($$sroa$0667$0958)) + 20|0);
       $1086 = HEAP32[$1085>>2]|0;
       $1087 = ($1086|0)==(0);
       do {
        if ($1087) {
         $1088 = ((($$sroa$0667$0958)) + 28|0);
         $1089 = HEAP32[$1088>>2]|0;
         $1090 = ($1089|0)==(0|0);
         if ($1090) {
          $1099 = ((($$sroa$0667$0958)) + 24|0);
          $1100 = HEAP32[$1099>>2]|0;
          $1101 = ($1100|0)==(0|0);
          if ($1101) {
           $$1310 = 6408;$$1314 = $$0313960;
           break;
          }
          $1102 = ((($1100)) + 88|0);
          $1103 = HEAP32[$1102>>2]|0;
          $$1310 = $1103;$$1314 = $$0313960;
          break;
         }
         $1091 = ((($1089)) + 172|0);
         $1092 = HEAP32[$1091>>2]|0;
         $1093 = ($1092|0)==(0);
         if ($1093) {
          $1094 = HEAP32[$1089>>2]|0;
          $1095 = ((($1094)) + 212|0);
          $1096 = HEAP32[$1095>>2]|0;
          __THREW__ = 0;
          invoke_vi($1096|0,($1089|0));
          $1097 = __THREW__; __THREW__ = 0;
          $1098 = $1097&1;
          if ($1098) {
           label = 398;
           break L556;
          }
          $$pre$i653 = HEAP32[$1091>>2]|0;
          $$1310 = $$pre$i653;$$1314 = $1089;
         } else {
          $$1310 = $1092;$$1314 = $1089;
         }
        } else {
         $$1310 = $1086;$$1314 = $$0313960;
        }
       } while(0);
       $1104 = ((($$sroa$0667$0958)) + 32|0);
       $1105 = HEAP32[$1104>>2]|0;
       $1106 = ((($$sroa$0667$0958)) + 36|0);
       $1107 = HEAP32[$1106>>2]|0;
       if ($1051) {
        $1108 = ((($$sroa$0667$0958)) + 28|0);
        $1109 = HEAP32[$1108>>2]|0;
        $1110 = ($1109|0)==(0|0);
        if ($1110) {
         $1117 = 0;
        } else {
         $1111 = HEAP32[$1109>>2]|0;
         $1112 = ((($1111)) + 180|0);
         $1113 = HEAP32[$1112>>2]|0;
         __THREW__ = 0;
         $1114 = (invoke_ii($1113|0,($1109|0))|0);
         $1115 = __THREW__; __THREW__ = 0;
         $1116 = $1115&1;
         if ($1116) {
          label = 398;
          break L556;
         } else {
          $1117 = $1114;
         }
        }
        HEAP32[$1072>>2] = $1117;
        HEAP32[$1073>>2] = $$1310;
        HEAP32[$1074>>2] = $1105;
        HEAP32[$1075>>2] = $1107;
        $1118 = ((($$sroa$0667$0958)) + 40|0);
        $1119 = HEAP8[$1118>>0]|0;
        $1120 = $1119&255;
        HEAP32[$1076>>2] = $1120;
        $$1303$off0 = $$0302$off0964;$$1306 = $1107;$$1308 = $1105;$$2311 = $$1310;$$2315 = $$1314;
       } else {
        $$1303$off0 = $$0302$off0964;$$1306 = $1107;$$1308 = $1105;$$2311 = $$1310;$$2315 = $$1314;
       }
       break;
      }
      default: {
       if ($1052) {
        __THREW__ = 0;
        $1121 = (invoke_ii(3265,3)|0);
        $1122 = __THREW__; __THREW__ = 0;
        $1123 = $1122&1;
        if ($1123) {
         label = 398;
         break L556;
        }
        if ($1121) {
         __THREW__ = 0;
         $1124 = (invoke_ii(3266,3)|0);
         $1125 = __THREW__; __THREW__ = 0;
         $1126 = $1125&1;
         if ($1126) {
          label = 398;
          break L556;
         }
         __THREW__ = 0;
         (invoke_iiii(3267,($1124|0),(118151|0),52)|0);
         $1127 = __THREW__; __THREW__ = 0;
         $1128 = $1127&1;
         if ($1128) {
          label = 398;
          break L556;
         }
        }
       } else {
        __THREW__ = 0;
        $1129 = (invoke_ii(3265,3)|0);
        $1130 = __THREW__; __THREW__ = 0;
        $1131 = $1130&1;
        if ($1131) {
         label = 398;
         break L556;
        }
        if ($1129) {
         __THREW__ = 0;
         $1132 = (invoke_ii(3266,3)|0);
         $1133 = __THREW__; __THREW__ = 0;
         $1134 = $1133&1;
         if ($1134) {
          label = 398;
          break L556;
         }
         __THREW__ = 0;
         (invoke_iiii(3267,($1132|0),(118204|0),53)|0);
         $1135 = __THREW__; __THREW__ = 0;
         $1136 = $1135&1;
         if ($1136) {
          label = 398;
          break L556;
         }
        }
       }
       __THREW__ = 0;
       $1137 = (invoke_ii(3265,3)|0);
       $1138 = __THREW__; __THREW__ = 0;
       $1139 = $1138&1;
       if ($1139) {
        label = 398;
        break L556;
       }
       if ($1137) {
        __THREW__ = 0;
        $1140 = (invoke_ii(3266,3)|0);
        $1141 = __THREW__; __THREW__ = 0;
        $1142 = $1141&1;
        if ($1142) {
         label = 398;
         break L556;
        }
        __THREW__ = 0;
        $1143 = (invoke_iiii(3267,($1140|0),(118258|0),40)|0);
        $1144 = __THREW__; __THREW__ = 0;
        $1145 = $1144&1;
        if ($1145) {
         label = 398;
         break L556;
        }
        $1146 = HEAP32[$1143>>2]|0;
        $1147 = ((($1146)) + -12|0);
        $1148 = HEAP32[$1147>>2]|0;
        $1149 = (($1143) + ($1148)|0);
        __THREW__ = 0;
        invoke_vii(3257,($4|0),($1149|0));
        $1150 = __THREW__; __THREW__ = 0;
        $1151 = $1150&1;
        if ($1151) {
         label = 398;
         break L556;
        }
        __THREW__ = 0;
        $1152 = (invoke_iii(3255,($4|0),(215188|0))|0);
        $1153 = __THREW__; __THREW__ = 0;
        $1154 = $1153&1;
        if ($1154) {
         label = 429;
         break L556;
        }
        $1155 = HEAP32[$1152>>2]|0;
        $1156 = ((($1155)) + 28|0);
        $1157 = HEAP32[$1156>>2]|0;
        __THREW__ = 0;
        $1158 = (invoke_iii($1157|0,($1152|0),10)|0);
        $1159 = __THREW__; __THREW__ = 0;
        $1160 = $1159&1;
        if ($1160) {
         label = 429;
         break L556;
        }
        __THREW__ = 0;
        invoke_vi(3263,($4|0));
        $1161 = __THREW__; __THREW__ = 0;
        $1162 = $1161&1;
        if ($1162) {
         label = 398;
         break L556;
        }
        __THREW__ = 0;
        (invoke_iii(3268,($1143|0),($1158|0))|0);
        $1169 = __THREW__; __THREW__ = 0;
        $1170 = $1169&1;
        if ($1170) {
         label = 398;
         break L556;
        }
        __THREW__ = 0;
        (invoke_ii(3269,($1143|0))|0);
        $1171 = __THREW__; __THREW__ = 0;
        $1172 = $1171&1;
        if ($1172) {
         label = 398;
         break L556;
        } else {
         $$1303$off0 = $$0302$off0964;$$1306 = $$0305963;$$1308 = $$0307962;$$2311 = $$0309961;$$2315 = $$0313960;
        }
       } else {
        $$1303$off0 = $$0302$off0964;$$1306 = $$0305963;$$1308 = $$0307962;$$2311 = $$0309961;$$2315 = $$0313960;
       }
      }
      }
      $1173 = ((($$sroa$0667$0958)) + 4|0);
      $1174 = HEAP32[$1173>>2]|0;
      $1175 = ($1174|0)==(0|0);
      if ($1175) {
       $1176 = ((($$sroa$0667$0958)) + 8|0);
       $1177 = HEAP32[$1176>>2]|0;
       $1178 = HEAP32[$1177>>2]|0;
       $1179 = ($1178|0)==($$sroa$0667$0958|0);
       if ($1179) {
        $$sroa$0667$0$be = $1177;
       } else {
        $1184 = $1176;
        while(1) {
         $1183 = HEAP32[$1184>>2]|0;
         $1185 = ((($1183)) + 8|0);
         $1186 = HEAP32[$1185>>2]|0;
         $1187 = HEAP32[$1186>>2]|0;
         $1188 = ($1187|0)==($1183|0);
         if ($1188) {
          $$sroa$0667$0$be = $1186;
          break;
         } else {
          $1184 = $1185;
         }
        }
       }
      } else {
       $$0$i$i$i$i559 = $1174;
       while(1) {
        $1181 = HEAP32[$$0$i$i$i$i559>>2]|0;
        $1182 = ($1181|0)==(0|0);
        if ($1182) {
         break;
        } else {
         $$0$i$i$i$i559 = $1181;
        }
       }
       $$sroa$0667$0$be = $$0$i$i$i$i559;
      }
      $1180 = ($$sroa$0667$0$be|0)==($83|0);
      if ($1180) {
       break;
      } else {
       $$0302$off0964 = $$1303$off0;$$0305963 = $$1306;$$0307962 = $$1308;$$0309961 = $$2311;$$0313960 = $$2315;$$sroa$0667$0958 = $$sroa$0667$0$be;
      }
     }
     if ($$1303$off0) {
      $$0305$lcssa1103 = $$1306;$$0307$lcssa1101 = $$1308;$$0309$lcssa1099 = $$2311;$$0313$lcssa1097 = $$2315;
     } else {
      $$0305$lcssa1102 = $$1306;$$0307$lcssa1100 = $$1308;$$0309$lcssa1098 = $$2311;$$0313$lcssa1096 = $$2315;
      label = 440;
     }
    }
    if ((label|0) == 440) {
     label = 0;
     $1189 = ((($1053)) + 92|0);
     HEAP32[$1189>>2] = 24;
     $$0305$lcssa1103 = $$0305$lcssa1102;$$0307$lcssa1101 = $$0307$lcssa1100;$$0309$lcssa1099 = $$0309$lcssa1098;$$0313$lcssa1097 = $$0313$lcssa1096;
    }
    $1192 = ((($1053)) + 76|0);
    HEAP32[$1192>>2] = 8;
    $1193 = ((($1053)) + 84|0);
    HEAP32[$1193>>2] = 8;
    $1194 = ((($1053)) + 80|0);
    HEAP32[$1194>>2] = 8;
    $1195 = ($$0309$lcssa1099|0)==(6408);
    $1196 = $1195 ? 8 : 0;
    $1197 = ((($1053)) + 88|0);
    HEAP32[$1197>>2] = $1196;
    $1198 = HEAP32[$1043>>2]|0;
    $1199 = ($1198|0)==(0|0);
    if (!($1199)) {
     __THREW__ = 0;
     $1200 = (invoke_ii(3325,($1198|0))|0);
     $1201 = __THREW__; __THREW__ = 0;
     $1202 = $1201&1;
     if ($1202) {
      $$sroa$0702$0 = 0;
      label = 441;
      break;
     }
     $1203 = ((($1053)) + 168|0);
     $1204 = HEAP32[$1203>>2]|0;
     $1205 = ($1204|0)==($1200|0);
     if ($1205) {
      $1215 = $1200;
     } else {
      HEAP32[$1203>>2] = $1200;
      $1206 = ($1200|0)==(0|0);
      if (!($1206)) {
       $1207 = ((($1200)) + 8|0);
       $1208 = HEAP32[$1207>>2]|0;HEAP32[$1207>>2] = (($1208+1)|0);
      }
      $1209 = ($1204|0)==(0|0);
      do {
       if (!($1209)) {
        $1210 = ((($1204)) + 8|0);
        $1211 = HEAP32[$1210>>2]|0;HEAP32[$1210>>2] = (($1211-1)|0);
        $1212 = ($1211|0)==(1);
        if (!($1212)) {
         break;
        }
        __THREW__ = 0;
        invoke_viii(3262,($1204|0),1,1);
        $1213 = __THREW__; __THREW__ = 0;
        $1214 = $1213&1;
        if ($1214) {
         $$sroa$0702$0 = 0;
         label = 441;
         break L556;
        }
       }
      } while(0);
      $$pr$i = HEAP32[$1203>>2]|0;
      $1215 = $$pr$i;
     }
     $1216 = ($1215|0)==(0|0);
     if ($1216) {
      $1221 = 0;
     } else {
      $1217 = ((($1215)) + 24|0);
      $1218 = HEAP32[$1217>>2]|0;
      $1219 = ($1218|0)!=(0|0);
      $$$i = $1219 ? $1198 : 0;
      $1221 = $$$i;
     }
     $1220 = ((($1053)) + 172|0);
     HEAP32[$1220>>2] = $1221;
     $1222 = ((($1221)) + 44|0);
     $1223 = HEAP32[$1222>>2]|0;
     $1224 = ($1223|0)==(0|0);
     if (!($1224)) {
      $1225 = ((($1223)) + 12|0);
      $1226 = ((($1053)) + 12|0);
      __THREW__ = 0;
      (invoke_iii(3477,($1226|0),($1225|0))|0);
      $1227 = __THREW__; __THREW__ = 0;
      $1228 = $1227&1;
      if ($1228) {
       label = 456;
       break;
      }
      $1229 = ((($1223)) + 24|0);
      $1230 = HEAP32[$1229>>2]|0;
      $1231 = ((($1053)) + 24|0);
      HEAP32[$1231>>2] = $1230;
      $1232 = ((($1223)) + 28|0);
      $1233 = HEAP32[$1232>>2]|0;
      $1234 = ((($1053)) + 28|0);
      HEAP32[$1234>>2] = $1233;
     }
    }
    __THREW__ = 0;
    $1237 = (invoke_ii(3471,($1053|0))|0);
    $1238 = __THREW__; __THREW__ = 0;
    $1239 = $1238&1;
    if ($1239) {
     $$sroa$0702$0 = 0;
     label = 441;
     break;
    }
    $1240 = ($1237|0)==(0|0);
    do {
     if ($1240) {
      $$sroa$0702$5806 = 0;
      label = 518;
     } else {
      $1241 = ((($1237)) + 8|0);
      $1242 = HEAP32[$1241>>2]|0;HEAP32[$1241>>2] = (($1242+1)|0);
      __THREW__ = 0;
      $1243 = (invoke_ii(3380,($1237|0))|0);
      $1244 = __THREW__; __THREW__ = 0;
      $1245 = $1244&1;
      if ($1245) {
       $$sroa$0702$0 = $1237;
       label = 441;
       break L556;
      }
      if ($1243) {
       __THREW__ = 0;
       $1246 = (invoke_ii(3265,4)|0);
       $1247 = __THREW__; __THREW__ = 0;
       $1248 = $1247&1;
       if ($1248) {
        $$sroa$0702$0 = $1237;
        label = 441;
        break L556;
       }
       if ($1246) {
        __THREW__ = 0;
        $1249 = (invoke_ii(3266,4)|0);
        $1250 = __THREW__; __THREW__ = 0;
        $1251 = $1250&1;
        if ($1251) {
         $$sroa$0702$0 = $1237;
         label = 441;
         break L556;
        }
        __THREW__ = 0;
        $1252 = (invoke_iiii(3267,($1249|0),(118299|0),62)|0);
        $1253 = __THREW__; __THREW__ = 0;
        $1254 = $1253&1;
        if ($1254) {
         $$sroa$0702$0 = $1237;
         label = 441;
         break L556;
        }
        $1255 = HEAP32[$1252>>2]|0;
        $1256 = ((($1255)) + -12|0);
        $1257 = HEAP32[$1256>>2]|0;
        $1258 = (($1252) + ($1257)|0);
        __THREW__ = 0;
        invoke_vii(3257,($5|0),($1258|0));
        $1259 = __THREW__; __THREW__ = 0;
        $1260 = $1259&1;
        if ($1260) {
         $$sroa$0702$0 = $1237;
         label = 441;
         break L556;
        }
        __THREW__ = 0;
        $1261 = (invoke_iii(3255,($5|0),(215188|0))|0);
        $1262 = __THREW__; __THREW__ = 0;
        $1263 = $1262&1;
        if ($1263) {
         label = 469;
         break L556;
        }
        $1264 = HEAP32[$1261>>2]|0;
        $1265 = ((($1264)) + 28|0);
        $1266 = HEAP32[$1265>>2]|0;
        __THREW__ = 0;
        $1267 = (invoke_iii($1266|0,($1261|0),10)|0);
        $1268 = __THREW__; __THREW__ = 0;
        $1269 = $1268&1;
        if ($1269) {
         label = 469;
         break L556;
        }
        __THREW__ = 0;
        invoke_vi(3263,($5|0));
        $1270 = __THREW__; __THREW__ = 0;
        $1271 = $1270&1;
        if ($1271) {
         $$sroa$0702$0 = $1237;
         label = 441;
         break L556;
        }
        __THREW__ = 0;
        (invoke_iii(3268,($1252|0),($1267|0))|0);
        $1278 = __THREW__; __THREW__ = 0;
        $1279 = $1278&1;
        if ($1279) {
         $$sroa$0702$0 = $1237;
         label = 441;
         break L556;
        }
        __THREW__ = 0;
        (invoke_ii(3269,($1252|0))|0);
        $1280 = __THREW__; __THREW__ = 0;
        $1281 = $1280&1;
        if ($1281) {
         $$sroa$0702$0 = $1237;
         label = 441;
         break L556;
        }
       }
       $1282 = HEAP32[$1040>>2]|0;
       $1283 = ($1282|0)==($1237|0);
       do {
        if (!($1283)) {
         HEAP32[$1040>>2] = $1237;
         $1284 = ((($1237)) + 8|0);
         $1285 = HEAP32[$1284>>2]|0;HEAP32[$1284>>2] = (($1285+1)|0);
         $1286 = ($1282|0)==(0|0);
         if ($1286) {
          break;
         }
         $1287 = ((($1282)) + 8|0);
         $1288 = HEAP32[$1287>>2]|0;HEAP32[$1287>>2] = (($1288-1)|0);
         $1289 = ($1288|0)==(1);
         if (!($1289)) {
          break;
         }
         __THREW__ = 0;
         invoke_viii(3262,($1282|0),1,1);
         $1290 = __THREW__; __THREW__ = 0;
         $1291 = $1290&1;
         if ($1291) {
          $$sroa$0702$0 = $1237;
          label = 441;
          break L556;
         }
        }
       } while(0);
       HEAP32[$1044>>2] = 1028;
       HEAP8[$1045>>0] = 1;
       HEAP32[$1046>>2] = 1028;
       HEAP8[$1047>>0] = 1;
       $1292 = ($$0313$lcssa1097|0)!=(0|0);
       $or$cond4 = $1051 & $1292;
       if ($or$cond4) {
        __THREW__ = 0;
        $1293 = (invoke_ii(3265,4)|0);
        $1294 = __THREW__; __THREW__ = 0;
        $1295 = $1294&1;
        if ($1295) {
         $$sroa$0702$0 = $1237;
         label = 441;
         break L556;
        }
        if ($1293) {
         __THREW__ = 0;
         $1296 = (invoke_ii(3266,4)|0);
         $1297 = __THREW__; __THREW__ = 0;
         $1298 = $1297&1;
         if ($1298) {
          $$sroa$0702$0 = $1237;
          label = 441;
          break L556;
         }
         __THREW__ = 0;
         $1299 = (invoke_iiii(3267,($1296|0),(118362|0),69)|0);
         $1300 = __THREW__; __THREW__ = 0;
         $1301 = $1300&1;
         if ($1301) {
          $$sroa$0702$0 = $1237;
          label = 441;
          break L556;
         }
         $1302 = HEAP32[$1299>>2]|0;
         $1303 = ((($1302)) + -12|0);
         $1304 = HEAP32[$1303>>2]|0;
         $1305 = (($1299) + ($1304)|0);
         __THREW__ = 0;
         invoke_vii(3257,($8|0),($1305|0));
         $1306 = __THREW__; __THREW__ = 0;
         $1307 = $1306&1;
         if ($1307) {
          $$sroa$0702$0 = $1237;
          label = 441;
          break L556;
         }
         __THREW__ = 0;
         $1308 = (invoke_iii(3255,($8|0),(215188|0))|0);
         $1309 = __THREW__; __THREW__ = 0;
         $1310 = $1309&1;
         if ($1310) {
          label = 487;
          break L556;
         }
         $1311 = HEAP32[$1308>>2]|0;
         $1312 = ((($1311)) + 28|0);
         $1313 = HEAP32[$1312>>2]|0;
         __THREW__ = 0;
         $1314 = (invoke_iii($1313|0,($1308|0),10)|0);
         $1315 = __THREW__; __THREW__ = 0;
         $1316 = $1315&1;
         if ($1316) {
          label = 487;
          break L556;
         }
         __THREW__ = 0;
         invoke_vi(3263,($8|0));
         $1317 = __THREW__; __THREW__ = 0;
         $1318 = $1317&1;
         if ($1318) {
          $$sroa$0702$0 = $1237;
          label = 441;
          break L556;
         }
         __THREW__ = 0;
         (invoke_iii(3268,($1299|0),($1314|0))|0);
         $1325 = __THREW__; __THREW__ = 0;
         $1326 = $1325&1;
         if ($1326) {
          $$sroa$0702$0 = $1237;
          label = 441;
          break L556;
         }
         __THREW__ = 0;
         (invoke_ii(3269,($1299|0))|0);
         $1327 = __THREW__; __THREW__ = 0;
         $1328 = $1327&1;
         if ($1328) {
          $$sroa$0702$0 = $1237;
          label = 441;
          break L556;
         }
        }
        $1329 = ((($$0313$lcssa1097)) + 236|0);
        $1330 = HEAP32[$1329>>2]|0;
        $1331 = ($1330|0)==($1237|0);
        if ($1331) {
         $$3 = 1;$$sroa$0702$5805 = $1237;
         break;
        }
        HEAP32[$1329>>2] = $1237;
        if (!($1240)) {
         $1332 = ((($1237)) + 8|0);
         $1333 = HEAP32[$1332>>2]|0;HEAP32[$1332>>2] = (($1333+1)|0);
        }
        $1334 = ($1330|0)==(0|0);
        if ($1334) {
         $$3 = 1;$$sroa$0702$5805 = $1237;
         break;
        }
        $1335 = ((($1330)) + 8|0);
        $1336 = HEAP32[$1335>>2]|0;HEAP32[$1335>>2] = (($1336-1)|0);
        $1337 = ($1336|0)==(1);
        if (!($1337)) {
         $$3 = 1;$$sroa$0702$5805 = $1237;
         break;
        }
        __THREW__ = 0;
        invoke_viii(3262,($1330|0),1,1);
        $1338 = __THREW__; __THREW__ = 0;
        $1339 = $1338&1;
        if ($1339) {
         $$sroa$0702$0 = $1237;
         label = 441;
         break L556;
        } else {
         $$3 = 1;$$sroa$0702$5805 = $1237;
         break;
        }
       }
       __THREW__ = 0;
       $1340 = (invoke_ii(3265,4)|0);
       $1341 = __THREW__; __THREW__ = 0;
       $1342 = $1341&1;
       if ($1342) {
        $$sroa$0702$0 = $1237;
        label = 441;
        break L556;
       }
       if ($1340) {
        __THREW__ = 0;
        $1343 = (invoke_ii(3266,4)|0);
        $1344 = __THREW__; __THREW__ = 0;
        $1345 = $1344&1;
        if ($1345) {
         $$sroa$0702$0 = $1237;
         label = 441;
         break L556;
        }
        __THREW__ = 0;
        $1346 = (invoke_iiii(3267,($1343|0),(118432|0),93)|0);
        $1347 = __THREW__; __THREW__ = 0;
        $1348 = $1347&1;
        if ($1348) {
         $$sroa$0702$0 = $1237;
         label = 441;
         break L556;
        }
        $1349 = HEAP32[$1346>>2]|0;
        $1350 = ((($1349)) + -12|0);
        $1351 = HEAP32[$1350>>2]|0;
        $1352 = (($1346) + ($1351)|0);
        __THREW__ = 0;
        invoke_vii(3257,($9|0),($1352|0));
        $1353 = __THREW__; __THREW__ = 0;
        $1354 = $1353&1;
        if ($1354) {
         $$sroa$0702$0 = $1237;
         label = 441;
         break L556;
        }
        __THREW__ = 0;
        $1355 = (invoke_iii(3255,($9|0),(215188|0))|0);
        $1356 = __THREW__; __THREW__ = 0;
        $1357 = $1356&1;
        if ($1357) {
         label = 506;
         break L556;
        }
        $1358 = HEAP32[$1355>>2]|0;
        $1359 = ((($1358)) + 28|0);
        $1360 = HEAP32[$1359>>2]|0;
        __THREW__ = 0;
        $1361 = (invoke_iii($1360|0,($1355|0),10)|0);
        $1362 = __THREW__; __THREW__ = 0;
        $1363 = $1362&1;
        if ($1363) {
         label = 506;
         break L556;
        }
        __THREW__ = 0;
        invoke_vi(3263,($9|0));
        $1364 = __THREW__; __THREW__ = 0;
        $1365 = $1364&1;
        if ($1365) {
         $$sroa$0702$0 = $1237;
         label = 441;
         break L556;
        }
        __THREW__ = 0;
        (invoke_iii(3268,($1346|0),($1361|0))|0);
        $1372 = __THREW__; __THREW__ = 0;
        $1373 = $1372&1;
        if ($1373) {
         $$sroa$0702$0 = $1237;
         label = 441;
         break L556;
        }
        __THREW__ = 0;
        (invoke_ii(3269,($1346|0))|0);
        $1374 = __THREW__; __THREW__ = 0;
        $1375 = $1374&1;
        if ($1375) {
         $$sroa$0702$0 = $1237;
         label = 441;
         break L556;
        }
       }
       $1376 = HEAP32[$1048>>2]|0;
       $1377 = ($1376|0)==($$0313$lcssa1097|0);
       do {
        if (!($1377)) {
         HEAP32[$1048>>2] = $$0313$lcssa1097;
         $1378 = ($$0313$lcssa1097|0)==(0|0);
         if (!($1378)) {
          $1379 = ((($$0313$lcssa1097)) + 8|0);
          $1380 = HEAP32[$1379>>2]|0;HEAP32[$1379>>2] = (($1380+1)|0);
         }
         $1381 = ($1376|0)==(0|0);
         if ($1381) {
          break;
         }
         $1382 = ((($1376)) + 8|0);
         $1383 = HEAP32[$1382>>2]|0;HEAP32[$1382>>2] = (($1383-1)|0);
         $1384 = ($1383|0)==(1);
         if (!($1384)) {
          break;
         }
         __THREW__ = 0;
         invoke_viii(3262,($1376|0),1,1);
         $1385 = __THREW__; __THREW__ = 0;
         $1386 = $1385&1;
         if ($1386) {
          $$sroa$0702$0 = $1237;
          label = 441;
          break L556;
         }
        }
       } while(0);
       HEAP32[$1049>>2] = $$0307$lcssa1101;
       HEAP32[$1050>>2] = $$0305$lcssa1103;
       $$3 = $$2970;$$sroa$0702$5805 = $1237;
      } else {
       $$sroa$0702$5806 = $1237;
       label = 518;
      }
     }
    } while(0);
    if ((label|0) == 518) {
     label = 0;
     __THREW__ = 0;
     $1387 = (invoke_ii(3265,4)|0);
     $1388 = __THREW__; __THREW__ = 0;
     $1389 = $1388&1;
     if ($1389) {
      $$sroa$0702$0 = $$sroa$0702$5806;
      label = 441;
      break;
     }
     if ($1387) {
      __THREW__ = 0;
      $1390 = (invoke_ii(3266,4)|0);
      $1391 = __THREW__; __THREW__ = 0;
      $1392 = $1391&1;
      if ($1392) {
       $$sroa$0702$0 = $$sroa$0702$5806;
       label = 441;
       break;
      }
      __THREW__ = 0;
      $1393 = (invoke_iiii(3267,($1390|0),(118526|0),34)|0);
      $1394 = __THREW__; __THREW__ = 0;
      $1395 = $1394&1;
      if ($1395) {
       $$sroa$0702$0 = $$sroa$0702$5806;
       label = 441;
       break;
      }
      $1396 = HEAP32[$1393>>2]|0;
      $1397 = ((($1396)) + -12|0);
      $1398 = HEAP32[$1397>>2]|0;
      $1399 = (($1393) + ($1398)|0);
      __THREW__ = 0;
      invoke_vii(3257,($10|0),($1399|0));
      $1400 = __THREW__; __THREW__ = 0;
      $1401 = $1400&1;
      if ($1401) {
       $$sroa$0702$0 = $$sroa$0702$5806;
       label = 441;
       break;
      }
      __THREW__ = 0;
      $1402 = (invoke_iii(3255,($10|0),(215188|0))|0);
      $1403 = __THREW__; __THREW__ = 0;
      $1404 = $1403&1;
      if ($1404) {
       label = 526;
       break;
      }
      $1405 = HEAP32[$1402>>2]|0;
      $1406 = ((($1405)) + 28|0);
      $1407 = HEAP32[$1406>>2]|0;
      __THREW__ = 0;
      $1408 = (invoke_iii($1407|0,($1402|0),10)|0);
      $1409 = __THREW__; __THREW__ = 0;
      $1410 = $1409&1;
      if ($1410) {
       label = 526;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3263,($10|0));
      $1411 = __THREW__; __THREW__ = 0;
      $1412 = $1411&1;
      if ($1412) {
       $$sroa$0702$0 = $$sroa$0702$5806;
       label = 441;
       break;
      }
      __THREW__ = 0;
      (invoke_iii(3268,($1393|0),($1408|0))|0);
      $1419 = __THREW__; __THREW__ = 0;
      $1420 = $1419&1;
      if ($1420) {
       $$sroa$0702$0 = $$sroa$0702$5806;
       label = 441;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(3269,($1393|0))|0);
      $1421 = __THREW__; __THREW__ = 0;
      $1422 = $1421&1;
      if ($1422) {
       $$sroa$0702$0 = $$sroa$0702$5806;
       label = 441;
       break;
      }
     }
     $1423 = ($$2970|0)<($62|0);
     $$403 = $1423 ? $62 : 2;
     $$403$ = $1051 ? $$403 : 3;
     $$3 = $$403$;$$sroa$0702$5805 = $$sroa$0702$5806;
    }
    $1424 = HEAP32[$1058>>2]|0;HEAP32[$1058>>2] = (($1424-1)|0);
    $1425 = ($1424|0)==(1);
    if ($1425) {
     __THREW__ = 0;
     invoke_viii(3262,($1053|0),1,1);
     $1426 = __THREW__; __THREW__ = 0;
     $1427 = $1426&1;
     if ($1427) {
      label = 536;
      break;
     }
    }
    $1434 = ($$sroa$0702$5805|0)==(0|0);
    if (!($1434)) {
     $1437 = ((($$sroa$0702$5805)) + 8|0);
     $1438 = HEAP32[$1437>>2]|0;HEAP32[$1437>>2] = (($1438-1)|0);
     $1439 = ($1438|0)==(1);
     if ($1439) {
      __ZNK3osg10Referenced24signalObserversAndDeleteEbb($$sroa$0702$5805,1,1);
     }
    }
    $1435 = HEAP32[$1040>>2]|0;
    $1436 = ($1435|0)==(0|0);
    if ($1436) {
     $$2970 = $$3;
    } else {
     $$2$lcssa = $$3;
     label = 544;
     break L554;
    }
   }
   switch (label|0) {
    case 394: {
     $1077 = ___cxa_find_matching_catch_2()|0;
     $1078 = tempRet0;
     $$26 = $1078;$$26368 = $1077;
     ___resumeException($$26368|0);
     // unreachable;
     break;
    }
    case 395: {
     $1079 = ___cxa_find_matching_catch_2()|0;
     $1080 = tempRet0;
     __ZdlPv($1053);
     $$26 = $1080;$$26368 = $1079;
     ___resumeException($$26368|0);
     // unreachable;
     break;
    }
    case 398: {
     $1083 = ___cxa_find_matching_catch_2()|0;
     $1084 = tempRet0;
     $$sroa$0702$6 = 0;$eh$lpad$body575$sink813$index22Z2D = $1084;$eh$lpad$body575$sink813$indexZ2D = $1083;
     label = 534;
     break;
    }
    case 429: {
     $1163 = ___cxa_find_matching_catch_2()|0;
     $1164 = tempRet0;
     __THREW__ = 0;
     invoke_vi(3263,($4|0));
     $1165 = __THREW__; __THREW__ = 0;
     $1166 = $1165&1;
     if ($1166) {
      $1167 = ___cxa_find_matching_catch_3(0|0)|0;
      $1168 = tempRet0;
      ___clang_call_terminate($1167);
      // unreachable;
     } else {
      $$sroa$0702$6 = 0;$eh$lpad$body575$sink813$index22Z2D = $1164;$eh$lpad$body575$sink813$indexZ2D = $1163;
      label = 534;
      break;
     }
     break;
    }
    case 441: {
     $1190 = ___cxa_find_matching_catch_2()|0;
     $1191 = tempRet0;
     $$sroa$0702$6 = $$sroa$0702$0;$eh$lpad$body575$sink813$index22Z2D = $1191;$eh$lpad$body575$sink813$indexZ2D = $1190;
     label = 534;
     break;
    }
    case 456: {
     $1235 = ___cxa_find_matching_catch_2()|0;
     $1236 = tempRet0;
     $$sroa$0702$6 = 0;$eh$lpad$body575$sink813$index22Z2D = $1236;$eh$lpad$body575$sink813$indexZ2D = $1235;
     label = 534;
     break;
    }
    case 469: {
     $1272 = ___cxa_find_matching_catch_2()|0;
     $1273 = tempRet0;
     __THREW__ = 0;
     invoke_vi(3263,($5|0));
     $1274 = __THREW__; __THREW__ = 0;
     $1275 = $1274&1;
     if ($1275) {
      $1276 = ___cxa_find_matching_catch_3(0|0)|0;
      $1277 = tempRet0;
      ___clang_call_terminate($1276);
      // unreachable;
     } else {
      $$sroa$0702$6 = $1237;$eh$lpad$body575$sink813$index22Z2D = $1273;$eh$lpad$body575$sink813$indexZ2D = $1272;
      label = 534;
      break;
     }
     break;
    }
    case 487: {
     $1319 = ___cxa_find_matching_catch_2()|0;
     $1320 = tempRet0;
     __THREW__ = 0;
     invoke_vi(3263,($8|0));
     $1321 = __THREW__; __THREW__ = 0;
     $1322 = $1321&1;
     if ($1322) {
      $1323 = ___cxa_find_matching_catch_3(0|0)|0;
      $1324 = tempRet0;
      ___clang_call_terminate($1323);
      // unreachable;
     } else {
      $$sroa$0702$6 = $1237;$eh$lpad$body575$sink813$index22Z2D = $1320;$eh$lpad$body575$sink813$indexZ2D = $1319;
      label = 534;
      break;
     }
     break;
    }
    case 506: {
     $1366 = ___cxa_find_matching_catch_2()|0;
     $1367 = tempRet0;
     __THREW__ = 0;
     invoke_vi(3263,($9|0));
     $1368 = __THREW__; __THREW__ = 0;
     $1369 = $1368&1;
     if ($1369) {
      $1370 = ___cxa_find_matching_catch_3(0|0)|0;
      $1371 = tempRet0;
      ___clang_call_terminate($1370);
      // unreachable;
     } else {
      $$sroa$0702$6 = $1237;$eh$lpad$body575$sink813$index22Z2D = $1367;$eh$lpad$body575$sink813$indexZ2D = $1366;
      label = 534;
      break;
     }
     break;
    }
    case 526: {
     $1413 = ___cxa_find_matching_catch_2()|0;
     $1414 = tempRet0;
     __THREW__ = 0;
     invoke_vi(3263,($10|0));
     $1415 = __THREW__; __THREW__ = 0;
     $1416 = $1415&1;
     if ($1416) {
      $1417 = ___cxa_find_matching_catch_3(0|0)|0;
      $1418 = tempRet0;
      ___clang_call_terminate($1417);
      // unreachable;
     } else {
      $$sroa$0702$6 = $$sroa$0702$5806;$eh$lpad$body575$sink813$index22Z2D = $1414;$eh$lpad$body575$sink813$indexZ2D = $1413;
      label = 534;
      break;
     }
     break;
    }
    case 536: {
     $1432 = ___cxa_find_matching_catch_2()|0;
     $1433 = tempRet0;
     $$25 = $1433;$$25367 = $1432;$$sroa$0702$9 = $$sroa$0702$5805;
     break;
    }
    case 566: {
     STACKTOP = sp;return;
     break;
    }
   }
   if ((label|0) == 534) {
    $1428 = HEAP32[$1058>>2]|0;HEAP32[$1058>>2] = (($1428-1)|0);
    $1429 = ($1428|0)==(1);
    if ($1429) {
     __THREW__ = 0;
     invoke_viii(3262,($1053|0),1,1);
     $1430 = __THREW__; __THREW__ = 0;
     $1431 = $1430&1;
     if ($1431) {
      $1505 = ___cxa_find_matching_catch_3(0|0)|0;
      $1506 = tempRet0;
      ___clang_call_terminate($1505);
      // unreachable;
     } else {
      $$25 = $eh$lpad$body575$sink813$index22Z2D;$$25367 = $eh$lpad$body575$sink813$indexZ2D;$$sroa$0702$9 = $$sroa$0702$6;
     }
    } else {
     $$25 = $eh$lpad$body575$sink813$index22Z2D;$$25367 = $eh$lpad$body575$sink813$indexZ2D;$$sroa$0702$9 = $$sroa$0702$6;
    }
   }
   $1440 = ($$sroa$0702$9|0)==(0|0);
   if ($1440) {
    $$26 = $$25;$$26368 = $$25367;
    ___resumeException($$26368|0);
    // unreachable;
   }
   $1441 = ((($$sroa$0702$9)) + 8|0);
   $1442 = HEAP32[$1441>>2]|0;HEAP32[$1441>>2] = (($1442-1)|0);
   $1443 = ($1442|0)==(1);
   if (!($1443)) {
    $$26 = $$25;$$26368 = $$25367;
    ___resumeException($$26368|0);
    // unreachable;
   }
   __THREW__ = 0;
   invoke_viii(3262,($$sroa$0702$9|0),1,1);
   $1444 = __THREW__; __THREW__ = 0;
   $1445 = $1444&1;
   if ($1445) {
    $1505 = ___cxa_find_matching_catch_3(0|0)|0;
    $1506 = tempRet0;
    ___clang_call_terminate($1505);
    // unreachable;
   } else {
    $$26 = $$25;$$26368 = $$25367;
    ___resumeException($$26368|0);
    // unreachable;
   }
  } else {
   $$2$lcssa = $$2$ph;
   label = 544;
  }
 } while(0);
 if ((label|0) == 544) {
  $1446 = ($$2$lcssa|0)==(3);
  if (!($1446)) {
   STACKTOP = sp;return;
  }
 }
 $1447 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
 do {
  if ($1447) {
   $1448 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
   $1449 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($1448,118561,36)|0);
   $1450 = HEAP32[$1449>>2]|0;
   $1451 = ((($1450)) + -12|0);
   $1452 = HEAP32[$1451>>2]|0;
   $1453 = (($1449) + ($1452)|0);
   __ZNKSt3__28ios_base6getlocEv($11,$1453);
   __THREW__ = 0;
   $1454 = (invoke_iii(3255,($11|0),(215188|0))|0);
   $1455 = __THREW__; __THREW__ = 0;
   $1456 = $1455&1;
   if (!($1456)) {
    $1457 = HEAP32[$1454>>2]|0;
    $1458 = ((($1457)) + 28|0);
    $1459 = HEAP32[$1458>>2]|0;
    __THREW__ = 0;
    $1460 = (invoke_iii($1459|0,($1454|0),10)|0);
    $1461 = __THREW__; __THREW__ = 0;
    $1462 = $1461&1;
    if (!($1462)) {
     __ZNSt3__26localeD2Ev($11);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($1449,$1460)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($1449)|0);
     break;
    }
   }
   $1463 = ___cxa_find_matching_catch_2()|0;
   $1464 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($11|0));
   $1465 = __THREW__; __THREW__ = 0;
   $1466 = $1465&1;
   if ($1466) {
    $1467 = ___cxa_find_matching_catch_3(0|0)|0;
    $1468 = tempRet0;
    ___clang_call_terminate($1467);
    // unreachable;
   } else {
    ___resumeException($1463|0);
    // unreachable;
   }
  }
 } while(0);
 $1469 = HEAP32[$81>>2]|0;
 $1470 = ($1469|0)==($83|0);
 if ($1470) {
  STACKTOP = sp;return;
 }
 $1471 = ((($0)) + 236|0);
 $1472 = ((($0)) + 240|0);
 $1473 = ((($0)) + 244|0);
 $$sroa$0657$0957 = $1469;
 while(1) {
  $1474 = ((($$sroa$0657$0957)) + 28|0);
  $1475 = HEAP32[$1474>>2]|0;
  $1476 = ($1475|0)==(0|0);
  if (!($1476)) {
   $1477 = ((($$sroa$0657$0957)) + 32|0);
   $1478 = HEAP32[$1477>>2]|0;
   $1479 = ((($$sroa$0657$0957)) + 36|0);
   $1480 = HEAP32[$1479>>2]|0;
   $1481 = HEAP32[$1471>>2]|0;
   $1482 = ($1481|0)==($1475|0);
   if (!($1482)) {
    HEAP32[$1471>>2] = $1475;
    $1483 = ((($1475)) + 8|0);
    $1484 = HEAP32[$1483>>2]|0;HEAP32[$1483>>2] = (($1484+1)|0);
    $1485 = ($1481|0)==(0|0);
    if (!($1485)) {
     $1486 = ((($1481)) + 8|0);
     $1487 = HEAP32[$1486>>2]|0;HEAP32[$1486>>2] = (($1487-1)|0);
     $1488 = ($1487|0)==(1);
     if ($1488) {
      __ZNK3osg10Referenced24signalObserversAndDeleteEbb($1481,1,1);
     }
    }
   }
   HEAP32[$1472>>2] = $1478;
   HEAP32[$1473>>2] = $1480;
  }
  $1489 = ((($$sroa$0657$0957)) + 4|0);
  $1490 = HEAP32[$1489>>2]|0;
  $1491 = ($1490|0)==(0|0);
  if ($1491) {
   $1492 = ((($$sroa$0657$0957)) + 8|0);
   $1493 = HEAP32[$1492>>2]|0;
   $1494 = HEAP32[$1493>>2]|0;
   $1495 = ($1494|0)==($$sroa$0657$0957|0);
   if ($1495) {
    $$sroa$0657$0$be = $1493;
   } else {
    $1500 = $1492;
    while(1) {
     $1499 = HEAP32[$1500>>2]|0;
     $1501 = ((($1499)) + 8|0);
     $1502 = HEAP32[$1501>>2]|0;
     $1503 = HEAP32[$1502>>2]|0;
     $1504 = ($1503|0)==($1499|0);
     if ($1504) {
      $$sroa$0657$0$be = $1502;
      break;
     } else {
      $1500 = $1501;
     }
    }
   }
  } else {
   $$0$i$i$i$i = $1490;
   while(1) {
    $1497 = HEAP32[$$0$i$i$i$i>>2]|0;
    $1498 = ($1497|0)==(0|0);
    if ($1498) {
     break;
    } else {
     $$0$i$i$i$i = $1497;
    }
   }
   $$sroa$0657$0$be = $$0$i$i$i$i;
  }
  $1496 = ($$sroa$0657$0$be|0)==($83|0);
  if ($1496) {
   break;
  } else {
   $$sroa$0657$0957 = $$sroa$0657$0$be;
  }
 }
 STACKTOP = sp;return;
}
function __ZN3osg10RenderInfoC2ERKS0_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$1 = 0, $$18 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i9 = 0, $scevgep5$i$i$i10 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $2;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = ((($2)) + 8|0);
  $5 = HEAP32[$4>>2]|0;HEAP32[$4>>2] = (($5+1)|0);
 }
 $6 = ((($0)) + 4|0);
 $7 = ((($1)) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 HEAP32[$6>>2] = $8;
 $9 = ((($0)) + 8|0);
 $10 = ((($1)) + 8|0);
 __THREW__ = 0;
 invoke_vii(3686,($9|0),($10|0));
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 do {
  if ($12) {
   $23 = ___cxa_find_matching_catch_2()|0;
   $24 = tempRet0;
   $$1 = $24;$$18 = $23;
  } else {
   $13 = ((($0)) + 20|0);
   $14 = ((($1)) + 20|0);
   __THREW__ = 0;
   invoke_vii(3687,($13|0),($14|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if ($16) {
    $25 = ___cxa_find_matching_catch_2()|0;
    $26 = tempRet0;
    $27 = HEAP32[$9>>2]|0;
    $28 = ($27|0)==(0|0);
    if ($28) {
     $$1 = $26;$$18 = $25;
     break;
    }
    $29 = ((($0)) + 12|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = ($30|0)==($27|0);
    if (!($31)) {
     $scevgep$i$i$i9 = ((($30)) + -4|0);
     $32 = $scevgep$i$i$i9;
     $33 = $27;
     $34 = (($32) - ($33))|0;
     $35 = $34 >>> 2;
     $36 = $35 ^ -1;
     $scevgep5$i$i$i10 = (($30) + ($36<<2)|0);
     HEAP32[$29>>2] = $scevgep5$i$i$i10;
    }
    __ZdlPv($27);
    $$1 = $26;$$18 = $25;
    break;
   } else {
    $17 = ((($0)) + 32|0);
    $18 = ((($1)) + 32|0);
    $19 = HEAP32[$18>>2]|0;
    HEAP32[$17>>2] = $19;
    $20 = ($19|0)==(0|0);
    if ($20) {
     return;
    }
    $21 = ((($19)) + 8|0);
    $22 = HEAP32[$21>>2]|0;HEAP32[$21>>2] = (($22+1)|0);
    return;
   }
  }
 } while(0);
 $37 = HEAP32[$0>>2]|0;
 $38 = ($37|0)==(0|0);
 if ($38) {
  HEAP32[$0>>2] = 0;
  ___resumeException($$18|0);
  // unreachable;
 }
 $39 = ((($37)) + 8|0);
 $40 = HEAP32[$39>>2]|0;HEAP32[$39>>2] = (($40-1)|0);
 $41 = ($40|0)==(1);
 if (!($41)) {
  HEAP32[$0>>2] = 0;
  ___resumeException($$18|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(3262,($37|0),1,1);
 $42 = __THREW__; __THREW__ = 0;
 $43 = $42&1;
 if ($43) {
  $44 = ___cxa_find_matching_catch_3(0|0)|0;
  $45 = tempRet0;
  ___clang_call_terminate($44);
  // unreachable;
 } else {
  HEAP32[$0>>2] = 0;
  ___resumeException($$18|0);
  // unreachable;
 }
}
function __ZN18DrawInnerOperationC1EPN7osgUtil11RenderStageERN3osg10RenderInfoE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$04 = 0, $$1 = 0, $$15 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = ((($0)) + 60|0);
 __ZN3osg10ReferencedC2Eb($4,1);
 ;HEAP32[$3>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;
 __THREW__ = 0;
 $5 = (invoke_ii(3276,16)|0);
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 do {
  if ($7) {
   $23 = ___cxa_find_matching_catch_2()|0;
   $24 = tempRet0;
   $$0 = $24;$$04 = $23;
   label = 10;
  } else {
   HEAP32[$3>>2] = $5;
   $8 = ((($3)) + 8|0);
   HEAP32[$8>>2] = -2147483632;
   $9 = ((($3)) + 4|0);
   HEAP32[$9>>2] = 14;
   dest=$5; src=117744; stop=dest+14|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
   $10 = ((($5)) + 14|0);
   HEAP8[$10>>0] = 0;
   HEAP32[$0>>2] = ((22940));
   HEAP32[$4>>2] = ((22972));
   $11 = ((($0)) + 4|0);
   __THREW__ = 0;
   invoke_vii(3457,($11|0),($3|0));
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if ($13) {
    $25 = ___cxa_find_matching_catch_2()|0;
    $26 = tempRet0;
    $27 = ((($3)) + 11|0);
    $28 = HEAP8[$27>>0]|0;
    $29 = ($28<<24>>24)<(0);
    if (!($29)) {
     $$0 = $26;$$04 = $25;
     label = 10;
     break;
    }
    $30 = HEAP32[$3>>2]|0;
    __ZdlPv($30);
    $$0 = $26;$$04 = $25;
    label = 10;
    break;
   }
   $14 = ((($0)) + 16|0);
   HEAP8[$14>>0] = 0;
   $15 = ((($3)) + 11|0);
   $16 = HEAP8[$15>>0]|0;
   $17 = ($16<<24>>24)<(0);
   if ($17) {
    $18 = HEAP32[$3>>2]|0;
    __ZdlPv($18);
   }
   HEAP32[$0>>2] = (54428);
   HEAP32[$4>>2] = (54460);
   $19 = ((($0)) + 20|0);
   HEAP32[$19>>2] = $1;
   $20 = ((($0)) + 24|0);
   __THREW__ = 0;
   invoke_vii(3688,($20|0),($2|0));
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if (!($22)) {
    STACKTOP = sp;return;
   }
   $31 = ___cxa_find_matching_catch_2()|0;
   $32 = tempRet0;
   HEAP32[$0>>2] = ((22940));
   HEAP32[$4>>2] = ((22972));
   $33 = ((($11)) + 11|0);
   $34 = HEAP8[$33>>0]|0;
   $35 = ($34<<24>>24)<(0);
   if ($35) {
    $36 = HEAP32[$11>>2]|0;
    __ZdlPv($36);
    $$1 = $32;$$15 = $31;
   } else {
    $$1 = $32;$$15 = $31;
   }
  }
 } while(0);
 if ((label|0) == 10) {
  $$1 = $$0;$$15 = $$04;
 }
 __THREW__ = 0;
 invoke_vi(712,($4|0));
 $37 = __THREW__; __THREW__ = 0;
 $38 = $37&1;
 if ($38) {
  $39 = ___cxa_find_matching_catch_3(0|0)|0;
  $40 = tempRet0;
  ___clang_call_terminate($39);
  // unreachable;
 } else {
  ___resumeException($$15|0);
  // unreachable;
 }
}
function __ZN18DrawInnerOperationclEPN3osg6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = sp + 4|0;
 $4 = ($1|0)==(0|0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (___dynamic_cast($1,26112,24816,0)|0);
 $6 = ($5|0)==(0|0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = ((($0)) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if ($9) {
  STACKTOP = sp;return;
 }
 HEAP32[$2>>2] = 0;
 HEAP8[$3>>0] = 0;
 $10 = ((($0)) + 24|0);
 $11 = ((($5)) + 48|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = HEAP32[$10>>2]|0;
 $14 = ($13|0)==($12|0);
 if (!($14)) {
  HEAP32[$10>>2] = $12;
  $15 = ($12|0)==(0|0);
  if (!($15)) {
   $16 = ((($12)) + 8|0);
   $17 = HEAP32[$16>>2]|0;HEAP32[$16>>2] = (($17+1)|0);
  }
  $18 = ($13|0)==(0|0);
  if (!($18)) {
   $19 = ((($13)) + 8|0);
   $20 = HEAP32[$19>>2]|0;HEAP32[$19>>2] = (($20-1)|0);
   $21 = ($20|0)==(1);
   if ($21) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($13,1,1);
   }
  }
 }
 $22 = HEAP32[$7>>2]|0;
 $23 = HEAP32[$22>>2]|0;
 $24 = ((($23)) + 196|0);
 $25 = HEAP32[$24>>2]|0;
 FUNCTION_TABLE_viiii[$25 & 8191]($22,$10,$2,$3);
 STACKTOP = sp;return;
}
function __ZN18DrawInnerOperationD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = ((54428));
 $1 = ((($0)) + 60|0);
 HEAP32[$1>>2] = ((54460));
 $2 = ((($0)) + 24|0);
 __THREW__ = 0;
 invoke_vi(3504,($2|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if (!($4)) {
  HEAP32[$0>>2] = ((22940));
  HEAP32[$1>>2] = ((22972));
  $5 = ((($0)) + 4|0);
  $6 = ((($5)) + 11|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = ($7<<24>>24)<(0);
  if (!($8)) {
   __ZN3osg10ReferencedD2Ev($1);
   return;
  }
  $9 = HEAP32[$5>>2]|0;
  __ZdlPv($9);
  __ZN3osg10ReferencedD2Ev($1);
  return;
 }
 $10 = ___cxa_find_matching_catch_2()|0;
 $11 = tempRet0;
 HEAP32[$0>>2] = ((22940));
 HEAP32[$1>>2] = ((22972));
 $12 = ((($0)) + 4|0);
 $13 = ((($12)) + 11|0);
 $14 = HEAP8[$13>>0]|0;
 $15 = ($14<<24>>24)<(0);
 if ($15) {
  $16 = HEAP32[$12>>2]|0;
  __ZdlPv($16);
 }
 __THREW__ = 0;
 invoke_vi(712,($1|0));
 $17 = __THREW__; __THREW__ = 0;
 $18 = $17&1;
 if ($18) {
  $19 = ___cxa_find_matching_catch_3(0|0)|0;
  $20 = tempRet0;
  ___clang_call_terminate($19);
  // unreachable;
 } else {
  ___resumeException($10|0);
  // unreachable;
 }
}
function __ZN18DrawInnerOperationD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = ((54428));
 $1 = ((($0)) + 60|0);
 HEAP32[$1>>2] = ((54460));
 $2 = ((($0)) + 24|0);
 __THREW__ = 0;
 invoke_vi(3504,($2|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $10 = ___cxa_find_matching_catch_2()|0;
  $11 = tempRet0;
  HEAP32[$0>>2] = ((22940));
  HEAP32[$1>>2] = ((22972));
  $12 = ((($0)) + 4|0);
  $13 = ((($12)) + 11|0);
  $14 = HEAP8[$13>>0]|0;
  $15 = ($14<<24>>24)<(0);
  if ($15) {
   $16 = HEAP32[$12>>2]|0;
   __ZdlPv($16);
  }
  __THREW__ = 0;
  invoke_vi(712,($1|0));
  $19 = __THREW__; __THREW__ = 0;
  $20 = $19&1;
  if ($20) {
   $21 = ___cxa_find_matching_catch_3(0|0)|0;
   $22 = tempRet0;
   ___clang_call_terminate($21);
   // unreachable;
  } else {
   $eh$lpad$body$index2Z2D = $11;$eh$lpad$body$indexZ2D = $10;
   __ZdlPv($0);
   ___resumeException($eh$lpad$body$indexZ2D|0);
   // unreachable;
  }
 }
 HEAP32[$0>>2] = ((22940));
 HEAP32[$1>>2] = ((22972));
 $5 = ((($0)) + 4|0);
 $6 = ((($5)) + 11|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = ($7<<24>>24)<(0);
 if ($8) {
  $9 = HEAP32[$5>>2]|0;
  __ZdlPv($9);
 }
 __THREW__ = 0;
 invoke_vi(712,($1|0));
 $17 = __THREW__; __THREW__ = 0;
 $18 = $17&1;
 if (!($18)) {
  __ZdlPv($0);
  return;
 }
 $23 = ___cxa_find_matching_catch_2()|0;
 $24 = tempRet0;
 $eh$lpad$body$index2Z2D = $24;$eh$lpad$body$indexZ2D = $23;
 __ZdlPv($0);
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
}
function __ZTv0_n16_N18DrawInnerOperationD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 HEAP32[$4>>2] = ((54428));
 $5 = ((($4)) + 60|0);
 HEAP32[$5>>2] = ((54460));
 $6 = ((($4)) + 24|0);
 __THREW__ = 0;
 invoke_vi(3504,($6|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if (!($8)) {
  HEAP32[$4>>2] = ((22940));
  HEAP32[$5>>2] = ((22972));
  $9 = ((($4)) + 4|0);
  $10 = ((($9)) + 11|0);
  $11 = HEAP8[$10>>0]|0;
  $12 = ($11<<24>>24)<(0);
  if (!($12)) {
   __ZN3osg10ReferencedD2Ev($5);
   return;
  }
  $13 = HEAP32[$9>>2]|0;
  __ZdlPv($13);
  __ZN3osg10ReferencedD2Ev($5);
  return;
 }
 $14 = ___cxa_find_matching_catch_2()|0;
 $15 = tempRet0;
 HEAP32[$4>>2] = ((22940));
 HEAP32[$5>>2] = ((22972));
 $16 = ((($4)) + 4|0);
 $17 = ((($16)) + 11|0);
 $18 = HEAP8[$17>>0]|0;
 $19 = ($18<<24>>24)<(0);
 if ($19) {
  $20 = HEAP32[$16>>2]|0;
  __ZdlPv($20);
 }
 __THREW__ = 0;
 invoke_vi(712,($5|0));
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if ($22) {
  $23 = ___cxa_find_matching_catch_3(0|0)|0;
  $24 = tempRet0;
  ___clang_call_terminate($23);
  // unreachable;
 } else {
  ___resumeException($14|0);
  // unreachable;
 }
}
function __ZTv0_n16_N18DrawInnerOperationD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __ZN18DrawInnerOperationD0Ev($4);
 return;
}
function __ZNSt3__26vectorIPN3osg6CameraENS_9allocatorIS3_EEEC2ERKS6_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i = 0, $scevgep5$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = 0;
 $2 = ((($0)) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = ((($0)) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$1>>2]|0;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 2;
 $9 = ($8|0)==(0);
 if ($9) {
  return;
 }
 $10 = ($8>>>0)>(1073741823);
 if ($10) {
  __THREW__ = 0;
  invoke_vi(3307,($0|0));
  $11 = __THREW__; __THREW__ = 0;
 } else {
  __THREW__ = 0;
  $12 = (invoke_ii(3276,($7|0))|0);
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if (!($14)) {
   HEAP32[$2>>2] = $12;
   HEAP32[$0>>2] = $12;
   $15 = (($12) + ($8<<2)|0);
   $16 = ((($0)) + 8|0);
   HEAP32[$16>>2] = $15;
   $17 = HEAP32[$1>>2]|0;
   $18 = HEAP32[$4>>2]|0;
   $19 = $17;
   $20 = (($18) - ($19))|0;
   $21 = ($20|0)>(0);
   if (!($21)) {
    return;
   }
   $22 = $20 >>> 2;
   _memcpy(($12|0),($17|0),($20|0))|0;
   $23 = (($12) + ($22<<2)|0);
   HEAP32[$2>>2] = $23;
   return;
  }
 }
 $24 = ___cxa_find_matching_catch_2()|0;
 $25 = tempRet0;
 $26 = HEAP32[$0>>2]|0;
 $27 = ($26|0)==(0|0);
 if ($27) {
  ___resumeException($24|0);
  // unreachable;
 }
 $28 = HEAP32[$2>>2]|0;
 $29 = ($28|0)==($26|0);
 if (!($29)) {
  $scevgep$i$i$i = ((($28)) + -4|0);
  $30 = $scevgep$i$i$i;
  $31 = $26;
  $32 = (($30) - ($31))|0;
  $33 = $32 >>> 2;
  $34 = $33 ^ -1;
  $scevgep5$i$i$i = (($28) + ($34<<2)|0);
  HEAP32[$2>>2] = $scevgep5$i$i$i;
 }
 __ZdlPv($26);
 ___resumeException($24|0);
 // unreachable;
}
function __ZNSt3__26vectorIPN7osgUtil9RenderBinENS_9allocatorIS3_EEEC2ERKS6_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i = 0, $scevgep5$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = 0;
 $2 = ((($0)) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = ((($0)) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$1>>2]|0;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 2;
 $9 = ($8|0)==(0);
 if ($9) {
  return;
 }
 $10 = ($8>>>0)>(1073741823);
 if ($10) {
  __THREW__ = 0;
  invoke_vi(3307,($0|0));
  $11 = __THREW__; __THREW__ = 0;
 } else {
  __THREW__ = 0;
  $12 = (invoke_ii(3276,($7|0))|0);
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if (!($14)) {
   HEAP32[$2>>2] = $12;
   HEAP32[$0>>2] = $12;
   $15 = (($12) + ($8<<2)|0);
   $16 = ((($0)) + 8|0);
   HEAP32[$16>>2] = $15;
   $17 = HEAP32[$1>>2]|0;
   $18 = HEAP32[$4>>2]|0;
   $19 = $17;
   $20 = (($18) - ($19))|0;
   $21 = ($20|0)>(0);
   if (!($21)) {
    return;
   }
   $22 = $20 >>> 2;
   _memcpy(($12|0),($17|0),($20|0))|0;
   $23 = (($12) + ($22<<2)|0);
   HEAP32[$2>>2] = $23;
   return;
  }
 }
 $24 = ___cxa_find_matching_catch_2()|0;
 $25 = tempRet0;
 $26 = HEAP32[$0>>2]|0;
 $27 = ($26|0)==(0|0);
 if ($27) {
  ___resumeException($24|0);
  // unreachable;
 }
 $28 = HEAP32[$2>>2]|0;
 $29 = ($28|0)==($26|0);
 if (!($29)) {
  $scevgep$i$i$i = ((($28)) + -4|0);
  $30 = $scevgep$i$i$i;
  $31 = $26;
  $32 = (($30) - ($31))|0;
  $33 = $32 >>> 2;
  $34 = $33 ^ -1;
  $scevgep5$i$i$i = (($28) + ($34<<2)|0);
  HEAP32[$2>>2] = $scevgep5$i$i$i;
 }
 __ZdlPv($26);
 ___resumeException($24|0);
 // unreachable;
}
function __ZNSt3__26__treeINS_12__value_typeIN3osg6Camera15BufferComponentEN7osgUtil11RenderStage10AttachmentEEENS_19__map_value_compareIS4_S8_NS_4lessIS4_EELb1EEENS_9allocatorIS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 }
 $3 = HEAP32[$1>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIN3osg6Camera15BufferComponentEN7osgUtil11RenderStage10AttachmentEEENS_19__map_value_compareIS4_S8_NS_4lessIS4_EELb1EEENS_9allocatorIS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($0,$3);
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIN3osg6Camera15BufferComponentEN7osgUtil11RenderStage10AttachmentEEENS_19__map_value_compareIS4_S8_NS_4lessIS4_EELb1EEENS_9allocatorIS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($0,$5);
 $6 = ((($1)) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = ((($7)) + 8|0);
  $10 = HEAP32[$9>>2]|0;HEAP32[$9>>2] = (($10-1)|0);
  $11 = ($10|0)==(1);
  if ($11) {
   __THREW__ = 0;
   invoke_viii(3262,($7|0),1,1);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if ($13) {
    $14 = ___cxa_find_matching_catch_2()|0;
    $15 = tempRet0;
    ___cxa_call_unexpected(($14|0));
    // unreachable;
   }
  }
 }
 __ZdlPv($1);
 return;
}
function __ZN3osg11ContextData3getINS_21GLRenderBufferManagerEEEPT_v($0) {
 $0 = $0|0;
 var $$0$i$i = 0, $$0$ph$i$i = 0, $$014$i = 0, $$024$i$i = 0, $$025$i$i = 0, $$025$i53$i = 0, $$037$i = 0, $$03752$i = 0, $$in$i$i = 0, $$pre$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 36|0);
 $2 = ((($0)) + 40|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 do {
  if ($4) {
   $$025$i$i = $2;$$037$i = $2;$15 = $3;
   label = 12;
  } else {
   $5 = ((($0)) + 40|0);
   $$0$i$i = $5;$$024$i$i = $3;$51 = $3;
   while(1) {
    $6 = ((($$024$i$i)) + 16|0);
    $7 = HEAP32[$6>>2]|0;
    $8 = ($7>>>0)>(24520>>>0);
    if ($8) {
     $9 = HEAP32[$$024$i$i>>2]|0;
     $10 = ($9|0)==(0|0);
     if ($10) {
      label = 6;
      break;
     } else {
      $$0$ph$i$i = $$024$i$i;$$in$i$i = $9;
     }
    } else {
     $11 = ($7>>>0)<(24520>>>0);
     if (!($11)) {
      label = 10;
      break;
     }
     $12 = ((($$024$i$i)) + 4|0);
     $13 = HEAP32[$12>>2]|0;
     $14 = ($13|0)==(0|0);
     if ($14) {
      label = 9;
      break;
     } else {
      $$0$ph$i$i = $12;$$in$i$i = $13;
     }
    }
    $$0$i$i = $$0$ph$i$i;$$024$i$i = $$in$i$i;$51 = $$in$i$i;
   }
   if ((label|0) == 6) {
    $$025$i53$i = $$024$i$i;$$03752$i = $$024$i$i;
    label = 13;
    break;
   }
   else if ((label|0) == 9) {
    $$025$i53$i = $12;$$03752$i = $$024$i$i;
    label = 13;
    break;
   }
   else if ((label|0) == 10) {
    $$025$i$i = $$0$i$i;$$037$i = $$024$i$i;$15 = $51;
    label = 12;
    break;
   }
  }
 } while(0);
 if ((label|0) == 12) {
  $16 = ($15|0)==(0|0);
  if ($16) {
   $$025$i53$i = $$025$i$i;$$03752$i = $$037$i;
   label = 13;
  } else {
   $$014$i = $15;
  }
 }
 if ((label|0) == 13) {
  $17 = (__Znwj(24)|0);
  $18 = ((($17)) + 16|0);
  HEAP32[$18>>2] = (24520);
  $19 = ((($17)) + 20|0);
  HEAP32[$19>>2] = 0;
  HEAP32[$17>>2] = 0;
  $20 = ((($17)) + 4|0);
  HEAP32[$20>>2] = 0;
  $21 = ((($17)) + 8|0);
  HEAP32[$21>>2] = $$03752$i;
  HEAP32[$$025$i53$i>>2] = $17;
  $22 = HEAP32[$1>>2]|0;
  $23 = HEAP32[$22>>2]|0;
  $24 = ($23|0)==(0|0);
  if ($24) {
   $28 = $17;
  } else {
   $25 = $23;
   HEAP32[$1>>2] = $25;
   $$pre$i$i = HEAP32[$$025$i53$i>>2]|0;
   $28 = $$pre$i$i;
  }
  $26 = ((($0)) + 40|0);
  $27 = HEAP32[$26>>2]|0;
  __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($27,$28);
  $29 = ((($0)) + 44|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (($30) + 1)|0;
  HEAP32[$29>>2] = $31;
  $$014$i = $17;
 }
 $32 = ((($$014$i)) + 20|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ($33|0)==(0|0);
 if (!($34)) {
  $50 = HEAP32[$32>>2]|0;
  return ($50|0);
 }
 $35 = (__Znwj(52)|0);
 $36 = ((($0)) + 24|0);
 $37 = HEAP32[$36>>2]|0;
 __THREW__ = 0;
 invoke_vii(3689,($35|0),($37|0));
 $38 = __THREW__; __THREW__ = 0;
 $39 = $38&1;
 if ($39) {
  $48 = ___cxa_find_matching_catch_2()|0;
  $49 = tempRet0;
  __ZdlPv($35);
  ___resumeException($48|0);
  // unreachable;
 }
 $40 = HEAP32[$32>>2]|0;
 $41 = ($40|0)==($35|0);
 if ($41) {
  $50 = HEAP32[$32>>2]|0;
  return ($50|0);
 }
 HEAP32[$32>>2] = $35;
 $42 = ((($35)) + 8|0);
 $43 = HEAP32[$42>>2]|0;HEAP32[$42>>2] = (($43+1)|0);
 $44 = ($40|0)==(0|0);
 if ($44) {
  $50 = HEAP32[$32>>2]|0;
  return ($50|0);
 }
 $45 = ((($40)) + 8|0);
 $46 = HEAP32[$45>>2]|0;HEAP32[$45>>2] = (($46-1)|0);
 $47 = ($46|0)==(1);
 if (!($47)) {
  $50 = HEAP32[$32>>2]|0;
  return ($50|0);
 }
 __ZNK3osg10Referenced24signalObserversAndDeleteEbb($40,1,1);
 $50 = HEAP32[$32>>2]|0;
 return ($50|0);
}
function __ZN3osg11ContextData3getINS_26GLFrameBufferObjectManagerEEEPT_v($0) {
 $0 = $0|0;
 var $$0$i$i = 0, $$0$ph$i$i = 0, $$014$i = 0, $$024$i$i = 0, $$025$i$i = 0, $$025$i53$i = 0, $$037$i = 0, $$03752$i = 0, $$in$i$i = 0, $$pre$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 36|0);
 $2 = ((($0)) + 40|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 do {
  if ($4) {
   $$025$i$i = $2;$$037$i = $2;$15 = $3;
   label = 12;
  } else {
   $5 = ((($0)) + 40|0);
   $$0$i$i = $5;$$024$i$i = $3;$51 = $3;
   while(1) {
    $6 = ((($$024$i$i)) + 16|0);
    $7 = HEAP32[$6>>2]|0;
    $8 = ($7>>>0)>(24536>>>0);
    if ($8) {
     $9 = HEAP32[$$024$i$i>>2]|0;
     $10 = ($9|0)==(0|0);
     if ($10) {
      label = 6;
      break;
     } else {
      $$0$ph$i$i = $$024$i$i;$$in$i$i = $9;
     }
    } else {
     $11 = ($7>>>0)<(24536>>>0);
     if (!($11)) {
      label = 10;
      break;
     }
     $12 = ((($$024$i$i)) + 4|0);
     $13 = HEAP32[$12>>2]|0;
     $14 = ($13|0)==(0|0);
     if ($14) {
      label = 9;
      break;
     } else {
      $$0$ph$i$i = $12;$$in$i$i = $13;
     }
    }
    $$0$i$i = $$0$ph$i$i;$$024$i$i = $$in$i$i;$51 = $$in$i$i;
   }
   if ((label|0) == 6) {
    $$025$i53$i = $$024$i$i;$$03752$i = $$024$i$i;
    label = 13;
    break;
   }
   else if ((label|0) == 9) {
    $$025$i53$i = $12;$$03752$i = $$024$i$i;
    label = 13;
    break;
   }
   else if ((label|0) == 10) {
    $$025$i$i = $$0$i$i;$$037$i = $$024$i$i;$15 = $51;
    label = 12;
    break;
   }
  }
 } while(0);
 if ((label|0) == 12) {
  $16 = ($15|0)==(0|0);
  if ($16) {
   $$025$i53$i = $$025$i$i;$$03752$i = $$037$i;
   label = 13;
  } else {
   $$014$i = $15;
  }
 }
 if ((label|0) == 13) {
  $17 = (__Znwj(24)|0);
  $18 = ((($17)) + 16|0);
  HEAP32[$18>>2] = (24536);
  $19 = ((($17)) + 20|0);
  HEAP32[$19>>2] = 0;
  HEAP32[$17>>2] = 0;
  $20 = ((($17)) + 4|0);
  HEAP32[$20>>2] = 0;
  $21 = ((($17)) + 8|0);
  HEAP32[$21>>2] = $$03752$i;
  HEAP32[$$025$i53$i>>2] = $17;
  $22 = HEAP32[$1>>2]|0;
  $23 = HEAP32[$22>>2]|0;
  $24 = ($23|0)==(0|0);
  if ($24) {
   $28 = $17;
  } else {
   $25 = $23;
   HEAP32[$1>>2] = $25;
   $$pre$i$i = HEAP32[$$025$i53$i>>2]|0;
   $28 = $$pre$i$i;
  }
  $26 = ((($0)) + 40|0);
  $27 = HEAP32[$26>>2]|0;
  __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($27,$28);
  $29 = ((($0)) + 44|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (($30) + 1)|0;
  HEAP32[$29>>2] = $31;
  $$014$i = $17;
 }
 $32 = ((($$014$i)) + 20|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ($33|0)==(0|0);
 if (!($34)) {
  $50 = HEAP32[$32>>2]|0;
  return ($50|0);
 }
 $35 = (__Znwj(52)|0);
 $36 = ((($0)) + 24|0);
 $37 = HEAP32[$36>>2]|0;
 __THREW__ = 0;
 invoke_vii(3690,($35|0),($37|0));
 $38 = __THREW__; __THREW__ = 0;
 $39 = $38&1;
 if ($39) {
  $48 = ___cxa_find_matching_catch_2()|0;
  $49 = tempRet0;
  __ZdlPv($35);
  ___resumeException($48|0);
  // unreachable;
 }
 $40 = HEAP32[$32>>2]|0;
 $41 = ($40|0)==($35|0);
 if ($41) {
  $50 = HEAP32[$32>>2]|0;
  return ($50|0);
 }
 HEAP32[$32>>2] = $35;
 $42 = ((($35)) + 8|0);
 $43 = HEAP32[$42>>2]|0;HEAP32[$42>>2] = (($43+1)|0);
 $44 = ($40|0)==(0|0);
 if ($44) {
  $50 = HEAP32[$32>>2]|0;
  return ($50|0);
 }
 $45 = ((($40)) + 8|0);
 $46 = HEAP32[$45>>2]|0;HEAP32[$45>>2] = (($46-1)|0);
 $47 = ($46|0)==(1);
 if (!($47)) {
  $50 = HEAP32[$32>>2]|0;
  return ($50|0);
 }
 __ZNK3osg10Referenced24signalObserversAndDeleteEbb($40,1,1);
 $50 = HEAP32[$32>>2]|0;
 return ($50|0);
}
function __ZN7osgUtil11RenderStageC2ERKS0_RKN3osg6CopyOpE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$023$i$i = 0, $$023$i$i34 = 0, $$6 = 0, $$632 = 0, $$7 = 0, $$733 = 0, $$pre$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0;
 var $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0;
 var $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0;
 var $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0.0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN7osgUtil9RenderBinC2ERKS0_RKN3osg6CopyOpE($0,$1,$2);
 HEAP32[$0>>2] = (54212);
 $3 = ((($0)) + 100|0);
 HEAP8[$3>>0] = 0;
 $4 = ((($0)) + 104|0);
 $5 = ((($1)) + 104|0);
 __THREW__ = 0;
 invoke_vii(3691,($4|0),($5|0));
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 L1: do {
  if ($7) {
   $103 = ___cxa_find_matching_catch_2()|0;
   $104 = tempRet0;
   $$7 = $104;$$733 = $103;
  } else {
   $8 = ((($0)) + 116|0);
   $9 = ((($1)) + 116|0);
   __THREW__ = 0;
   invoke_vii(3691,($8|0),($9|0));
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   L4: do {
    if ($11) {
     $105 = ___cxa_find_matching_catch_2()|0;
     $106 = tempRet0;
     $$6 = $106;$$632 = $105;
    } else {
     $12 = ((($0)) + 128|0);
     HEAP32[$12>>2] = 0;
     $13 = ((($0)) + 132|0);
     HEAP32[$13>>2] = 0;
     $14 = ((($0)) + 136|0);
     HEAP32[$14>>2] = 0;
     $15 = ((($0)) + 140|0);
     $16 = ((($1)) + 140|0);
     $17 = HEAP32[$16>>2]|0;
     HEAP32[$15>>2] = $17;
     $18 = ($17|0)==(0|0);
     if (!($18)) {
      $19 = ((($17)) + 8|0);
      $20 = HEAP32[$19>>2]|0;HEAP32[$19>>2] = (($20+1)|0);
     }
     $21 = ((($0)) + 144|0);
     HEAP32[$21>>2] = 0;
     $22 = ((($0)) + 148|0);
     $23 = ((($1)) + 148|0);
     $24 = HEAP32[$23>>2]|0;
     HEAP32[$22>>2] = $24;
     $25 = ((($0)) + 152|0);
     $26 = ((($1)) + 152|0);
     $27 = HEAP8[$26>>0]|0;
     HEAP8[$25>>0] = $27;
     $28 = ((($0)) + 156|0);
     $29 = ((($1)) + 156|0);
     $30 = HEAP32[$29>>2]|0;
     HEAP32[$28>>2] = $30;
     $31 = ((($0)) + 160|0);
     $32 = ((($1)) + 160|0);
     $33 = HEAP8[$32>>0]|0;
     HEAP8[$31>>0] = $33;
     $34 = ((($0)) + 164|0);
     $35 = ((($1)) + 164|0);
     $36 = HEAP32[$35>>2]|0;
     HEAP32[$34>>2] = $36;
     $37 = ((($0)) + 168|0);
     $38 = ((($1)) + 168|0);
     $39 = HEAP32[$38>>2]|0;
     HEAP32[$37>>2] = $39;
     $40 = ($39|0)==(0|0);
     if (!($40)) {
      $41 = ((($39)) + 8|0);
      $42 = HEAP32[$41>>2]|0;HEAP32[$41>>2] = (($42+1)|0);
     }
     $43 = ((($0)) + 172|0);
     $44 = ((($1)) + 172|0);
     ;HEAP32[$43>>2]=HEAP32[$44>>2]|0;HEAP32[$43+4>>2]=HEAP32[$44+4>>2]|0;HEAP32[$43+8>>2]=HEAP32[$44+8>>2]|0;HEAP32[$43+12>>2]=HEAP32[$44+12>>2]|0;
     $45 = ((($0)) + 188|0);
     $46 = ((($1)) + 188|0);
     ;HEAP32[$45>>2]=HEAP32[$46>>2]|0;HEAP32[$45+4>>2]=HEAP32[$46+4>>2]|0;HEAP32[$45+8>>2]=HEAP32[$46+8>>2]|0;HEAP32[$45+12>>2]=HEAP32[$46+12>>2]|0;
     $47 = ((($0)) + 208|0);
     $48 = ((($1)) + 208|0);
     $49 = +HEAPF64[$48>>3];
     HEAPF64[$47>>3] = $49;
     $50 = ((($0)) + 216|0);
     $51 = ((($1)) + 216|0);
     $52 = HEAP32[$51>>2]|0;
     HEAP32[$50>>2] = $52;
     $53 = ((($0)) + 220|0);
     $54 = ((($1)) + 220|0);
     $55 = HEAP8[$54>>0]|0;
     HEAP8[$53>>0] = $55;
     $56 = ((($0)) + 224|0);
     $57 = ((($1)) + 224|0);
     $58 = HEAP32[$57>>2]|0;
     HEAP32[$56>>2] = $58;
     $59 = ((($0)) + 228|0);
     $60 = ((($1)) + 228|0);
     $61 = HEAP32[$60>>2]|0;
     HEAP32[$59>>2] = $61;
     $62 = ($61|0)==(0|0);
     if (!($62)) {
      $63 = ((($61)) + 8|0);
      $64 = HEAP32[$63>>2]|0;HEAP32[$63>>2] = (($64+1)|0);
     }
     $65 = ((($0)) + 232|0);
     $66 = ((($1)) + 232|0);
     $67 = HEAP32[$66>>2]|0;
     HEAP32[$65>>2] = $67;
     $68 = ((($0)) + 236|0);
     HEAP32[$68>>2] = 0;
     $69 = ((($0)) + 240|0);
     $70 = ((($1)) + 240|0);
     $71 = HEAP32[$70>>2]|0;
     HEAP32[$69>>2] = $71;
     $72 = ((($0)) + 244|0);
     $73 = ((($1)) + 244|0);
     $74 = HEAP32[$73>>2]|0;
     HEAP32[$72>>2] = $74;
     $75 = ((($0)) + 248|0);
     HEAP32[$75>>2] = 0;
     $76 = ((($0)) + 252|0);
     $77 = ((($1)) + 252|0);
     $78 = HEAP32[$77>>2]|0;
     HEAP32[$76>>2] = $78;
     $79 = ((($0)) + 256|0);
     $80 = ((($1)) + 256|0);
     $81 = HEAP32[$80>>2]|0;
     HEAP32[$79>>2] = $81;
     $82 = ((($0)) + 260|0);
     $83 = ((($0)) + 264|0);
     HEAP32[$83>>2] = 0;
     $84 = ((($0)) + 268|0);
     HEAP32[$84>>2] = 0;
     $85 = ((($0)) + 264|0);
     HEAP32[$82>>2] = $85;
     $86 = ((($0)) + 272|0);
     HEAP32[$86>>2] = 0;
     $87 = ((($0)) + 276|0);
     HEAP32[$87>>2] = 0;
     $88 = ((($0)) + 280|0);
     HEAP32[$88>>2] = 0;
     $89 = ((($0)) + 284|0);
     $90 = ((($1)) + 284|0);
     $91 = HEAP8[$90>>0]|0;
     HEAP8[$89>>0] = $91;
     $92 = ((($0)) + 288|0);
     __THREW__ = 0;
     invoke_vi(3299,($92|0));
     $93 = __THREW__; __THREW__ = 0;
     $94 = $93&1;
     if (!($94)) {
      $95 = ((($0)) + 416|0);
      HEAP32[$95>>2] = 0;
      $96 = ((($0)) + 420|0);
      $97 = ((($1)) + 420|0);
      $98 = HEAP32[$97>>2]|0;
      HEAP32[$96>>2] = $98;
      $99 = ($98|0)==(0|0);
      if ($99) {
       $102 = ((($0)) + 40|0);
       HEAP32[$102>>2] = $0;
       return;
      }
      $100 = ((($98)) + 8|0);
      $101 = HEAP32[$100>>2]|0;HEAP32[$100>>2] = (($101+1)|0);
      $102 = ((($0)) + 40|0);
      HEAP32[$102>>2] = $0;
      return;
     }
     $107 = ___cxa_find_matching_catch_2()|0;
     $108 = tempRet0;
     $109 = HEAP32[$88>>2]|0;
     $110 = ($109|0)==(0|0);
     if (!($110)) {
      $111 = ((($109)) + 8|0);
      $112 = HEAP32[$111>>2]|0;HEAP32[$111>>2] = (($112-1)|0);
      $113 = ($112|0)==(1);
      if ($113) {
       __THREW__ = 0;
       invoke_viii(3262,($109|0),1,1);
       $114 = __THREW__; __THREW__ = 0;
       $115 = $114&1;
       if ($115) {
        $243 = ___cxa_find_matching_catch_3(0|0)|0;
        $244 = tempRet0;
        ___clang_call_terminate($243);
        // unreachable;
       }
      }
     }
     HEAP32[$88>>2] = 0;
     $116 = HEAP32[$87>>2]|0;
     $117 = ($116|0)==(0|0);
     if (!($117)) {
      $118 = ((($116)) + 8|0);
      $119 = HEAP32[$118>>2]|0;HEAP32[$118>>2] = (($119-1)|0);
      $120 = ($119|0)==(1);
      if ($120) {
       __THREW__ = 0;
       invoke_viii(3262,($116|0),1,1);
       $121 = __THREW__; __THREW__ = 0;
       $122 = $121&1;
       if ($122) {
        $243 = ___cxa_find_matching_catch_3(0|0)|0;
        $244 = tempRet0;
        ___clang_call_terminate($243);
        // unreachable;
       }
      }
     }
     HEAP32[$87>>2] = 0;
     $123 = HEAP32[$86>>2]|0;
     $124 = ($123|0)==(0|0);
     if (!($124)) {
      $125 = ((($123)) + 8|0);
      $126 = HEAP32[$125>>2]|0;HEAP32[$125>>2] = (($126-1)|0);
      $127 = ($126|0)==(1);
      if ($127) {
       __THREW__ = 0;
       invoke_viii(3262,($123|0),1,1);
       $128 = __THREW__; __THREW__ = 0;
       $129 = $128&1;
       if ($129) {
        $243 = ___cxa_find_matching_catch_3(0|0)|0;
        $244 = tempRet0;
        ___clang_call_terminate($243);
        // unreachable;
       }
      }
     }
     HEAP32[$86>>2] = 0;
     $130 = HEAP32[$85>>2]|0;
     __ZNSt3__26__treeINS_12__value_typeIN3osg6Camera15BufferComponentEN7osgUtil11RenderStage10AttachmentEEENS_19__map_value_compareIS4_S8_NS_4lessIS4_EELb1EEENS_9allocatorIS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($82,$130);
     $131 = HEAP32[$75>>2]|0;
     $132 = ($131|0)==(0|0);
     if (!($132)) {
      $133 = ((($131)) + 8|0);
      $134 = HEAP32[$133>>2]|0;HEAP32[$133>>2] = (($134-1)|0);
      $135 = ($134|0)==(1);
      if ($135) {
       __THREW__ = 0;
       invoke_viii(3262,($131|0),1,1);
       $136 = __THREW__; __THREW__ = 0;
       $137 = $136&1;
       if ($137) {
        $243 = ___cxa_find_matching_catch_3(0|0)|0;
        $244 = tempRet0;
        ___clang_call_terminate($243);
        // unreachable;
       }
      }
     }
     HEAP32[$75>>2] = 0;
     $138 = HEAP32[$68>>2]|0;
     $139 = ($138|0)==(0|0);
     if (!($139)) {
      $140 = ((($138)) + 8|0);
      $141 = HEAP32[$140>>2]|0;HEAP32[$140>>2] = (($141-1)|0);
      $142 = ($141|0)==(1);
      if ($142) {
       __THREW__ = 0;
       invoke_viii(3262,($138|0),1,1);
       $143 = __THREW__; __THREW__ = 0;
       $144 = $143&1;
       if ($144) {
        $243 = ___cxa_find_matching_catch_3(0|0)|0;
        $244 = tempRet0;
        ___clang_call_terminate($243);
        // unreachable;
       }
      }
     }
     HEAP32[$68>>2] = 0;
     $145 = HEAP32[$59>>2]|0;
     $146 = ($145|0)==(0|0);
     if (!($146)) {
      $147 = ((($145)) + 8|0);
      $148 = HEAP32[$147>>2]|0;HEAP32[$147>>2] = (($148-1)|0);
      $149 = ($148|0)==(1);
      if ($149) {
       __THREW__ = 0;
       invoke_viii(3262,($145|0),1,1);
       $150 = __THREW__; __THREW__ = 0;
       $151 = $150&1;
       if ($151) {
        $243 = ___cxa_find_matching_catch_3(0|0)|0;
        $244 = tempRet0;
        ___clang_call_terminate($243);
        // unreachable;
       }
      }
     }
     HEAP32[$59>>2] = 0;
     $152 = HEAP32[$37>>2]|0;
     $153 = ($152|0)==(0|0);
     if (!($153)) {
      $154 = ((($152)) + 8|0);
      $155 = HEAP32[$154>>2]|0;HEAP32[$154>>2] = (($155-1)|0);
      $156 = ($155|0)==(1);
      if ($156) {
       __THREW__ = 0;
       invoke_viii(3262,($152|0),1,1);
       $157 = __THREW__; __THREW__ = 0;
       $158 = $157&1;
       if ($158) {
        $243 = ___cxa_find_matching_catch_3(0|0)|0;
        $244 = tempRet0;
        ___clang_call_terminate($243);
        // unreachable;
       }
      }
     }
     HEAP32[$37>>2] = 0;
     $159 = HEAP32[$21>>2]|0;
     $160 = ($159|0)==(0|0);
     if (!($160)) {
      $161 = ((($159)) + 8|0);
      $162 = HEAP32[$161>>2]|0;HEAP32[$161>>2] = (($162-1)|0);
      $163 = ($162|0)==(1);
      if ($163) {
       __THREW__ = 0;
       invoke_viii(3262,($159|0),1,1);
       $164 = __THREW__; __THREW__ = 0;
       $165 = $164&1;
       if ($165) {
        $243 = ___cxa_find_matching_catch_3(0|0)|0;
        $244 = tempRet0;
        ___clang_call_terminate($243);
        // unreachable;
       }
      }
     }
     HEAP32[$21>>2] = 0;
     $166 = HEAP32[$15>>2]|0;
     $167 = ($166|0)==(0|0);
     if (!($167)) {
      $168 = ((($166)) + 8|0);
      $169 = HEAP32[$168>>2]|0;HEAP32[$168>>2] = (($169-1)|0);
      $170 = ($169|0)==(1);
      if ($170) {
       __THREW__ = 0;
       invoke_viii(3262,($166|0),1,1);
       $171 = __THREW__; __THREW__ = 0;
       $172 = $171&1;
       if ($172) {
        $243 = ___cxa_find_matching_catch_3(0|0)|0;
        $244 = tempRet0;
        ___clang_call_terminate($243);
        // unreachable;
       }
      }
     }
     HEAP32[$15>>2] = 0;
     $173 = HEAP32[$12>>2]|0;
     $174 = ($173|0)==(0|0);
     if (!($174)) {
      $175 = HEAP32[$13>>2]|0;
      $176 = ($175|0)==($173|0);
      do {
       if ($176) {
        $190 = $173;
       } else {
        $178 = $175;
        L71: while(1) {
         $177 = ((($178)) + -4|0);
         HEAP32[$13>>2] = $177;
         $179 = HEAP32[$177>>2]|0;
         $180 = ($179|0)==(0|0);
         do {
          if (!($180)) {
           $181 = ((($179)) + 8|0);
           $182 = HEAP32[$181>>2]|0;HEAP32[$181>>2] = (($182-1)|0);
           $183 = ($182|0)==(1);
           if (!($183)) {
            break;
           }
           __THREW__ = 0;
           invoke_viii(3262,($179|0),1,1);
           $184 = __THREW__; __THREW__ = 0;
           $185 = $184&1;
           if ($185) {
            label = 48;
            break L71;
           }
          }
         } while(0);
         HEAP32[$177>>2] = 0;
         $186 = HEAP32[$13>>2]|0;
         $187 = ($186|0)==($173|0);
         if ($187) {
          label = 49;
          break;
         } else {
          $178 = $186;
         }
        }
        if ((label|0) == 48) {
         $188 = ___cxa_find_matching_catch_2()|0;
         $189 = tempRet0;
         ___cxa_call_unexpected(($188|0));
         // unreachable;
        }
        else if ((label|0) == 49) {
         $$pre$i = HEAP32[$12>>2]|0;
         $190 = $$pre$i;
         break;
        }
       }
      } while(0);
      __ZdlPv($190);
     }
     $191 = ((($0)) + 124|0);
     $192 = HEAP32[$191>>2]|0;
     $193 = ($192|0)==(0);
     if ($193) {
      $$6 = $108;$$632 = $107;
     } else {
      $194 = ((($0)) + 120|0);
      $195 = HEAP32[$194>>2]|0;
      $196 = HEAP32[$8>>2]|0;
      $197 = ((($196)) + 4|0);
      $198 = HEAP32[$197>>2]|0;
      $199 = HEAP32[$195>>2]|0;
      $200 = ((($199)) + 4|0);
      HEAP32[$200>>2] = $198;
      $201 = HEAP32[$197>>2]|0;
      HEAP32[$201>>2] = $199;
      HEAP32[$191>>2] = 0;
      $202 = ($195|0)==($8|0);
      if ($202) {
       $$6 = $108;$$632 = $107;
      } else {
       $$023$i$i34 = $195;
       L83: while(1) {
        $203 = ((($$023$i$i34)) + 4|0);
        $204 = HEAP32[$203>>2]|0;
        $205 = ((($$023$i$i34)) + 12|0);
        $206 = HEAP32[$205>>2]|0;
        $207 = ($206|0)==(0|0);
        do {
         if (!($207)) {
          $208 = ((($206)) + 8|0);
          $209 = HEAP32[$208>>2]|0;HEAP32[$208>>2] = (($209-1)|0);
          $210 = ($209|0)==(1);
          if (!($210)) {
           break;
          }
          __THREW__ = 0;
          invoke_viii(3262,($206|0),1,1);
          $211 = __THREW__; __THREW__ = 0;
          $212 = $211&1;
          if ($212) {
           break L83;
          }
         }
        } while(0);
        __ZdlPv($$023$i$i34);
        $213 = ($204|0)==($8|0);
        if ($213) {
         $$6 = $108;$$632 = $107;
         break L4;
        } else {
         $$023$i$i34 = $204;
        }
       }
       $214 = ___cxa_find_matching_catch_2()|0;
       $215 = tempRet0;
       ___cxa_call_unexpected(($214|0));
       // unreachable;
      }
     }
    }
   } while(0);
   $216 = ((($0)) + 112|0);
   $217 = HEAP32[$216>>2]|0;
   $218 = ($217|0)==(0);
   if ($218) {
    $$7 = $$6;$$733 = $$632;
   } else {
    $219 = ((($0)) + 108|0);
    $220 = HEAP32[$219>>2]|0;
    $221 = HEAP32[$4>>2]|0;
    $222 = ((($221)) + 4|0);
    $223 = HEAP32[$222>>2]|0;
    $224 = HEAP32[$220>>2]|0;
    $225 = ((($224)) + 4|0);
    HEAP32[$225>>2] = $223;
    $226 = HEAP32[$222>>2]|0;
    HEAP32[$226>>2] = $224;
    HEAP32[$216>>2] = 0;
    $227 = ($220|0)==($4|0);
    if ($227) {
     $$7 = $$6;$$733 = $$632;
    } else {
     $$023$i$i = $220;
     while(1) {
      $228 = ((($$023$i$i)) + 4|0);
      $229 = HEAP32[$228>>2]|0;
      $230 = ((($$023$i$i)) + 12|0);
      $231 = HEAP32[$230>>2]|0;
      $232 = ($231|0)==(0|0);
      if (!($232)) {
       $233 = ((($231)) + 8|0);
       $234 = HEAP32[$233>>2]|0;HEAP32[$233>>2] = (($234-1)|0);
       $235 = ($234|0)==(1);
       if ($235) {
        __THREW__ = 0;
        invoke_viii(3262,($231|0),1,1);
        $236 = __THREW__; __THREW__ = 0;
        $237 = $236&1;
        if ($237) {
         break;
        }
       }
      }
      __ZdlPv($$023$i$i);
      $238 = ($229|0)==($4|0);
      if ($238) {
       $$7 = $$6;$$733 = $$632;
       break L1;
      } else {
       $$023$i$i = $229;
      }
     }
     $239 = ___cxa_find_matching_catch_2()|0;
     $240 = tempRet0;
     ___cxa_call_unexpected(($239|0));
     // unreachable;
    }
   }
  }
 } while(0);
 __THREW__ = 0;
 invoke_vi(1385,($0|0));
 $241 = __THREW__; __THREW__ = 0;
 $242 = $241&1;
 if ($242) {
  $243 = ___cxa_find_matching_catch_3(0|0)|0;
  $244 = tempRet0;
  ___clang_call_terminate($243);
  // unreachable;
 } else {
  ___resumeException($$733|0);
  // unreachable;
 }
}
function __ZNSt3__24listINS_4pairIiN3osg7ref_ptrIN7osgUtil11RenderStageEEEEENS_9allocatorIS7_EEEC2ERKSA_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$023$i$i = 0, $$pre = 0, $$pre17 = 0, $$sroa$07$0 = 0, $$sroa$07$015 = 0, $$sroa$07$016 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = $0;
 $2 = ((($0)) + 4|0);
 HEAP32[$2>>2] = $0;
 $3 = ((($0)) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = ((($1)) + 4|0);
 $$sroa$07$015 = HEAP32[$4>>2]|0;
 $5 = $$sroa$07$015;
 $6 = ($5|0)==($1|0);
 if ($6) {
  return;
 }
 $$sroa$07$016 = $$sroa$07$015;$13 = $0;$51 = $5;$9 = 0;
 while(1) {
  $32 = $$sroa$07$016;
  __THREW__ = 0;
  $33 = (invoke_ii(3276,16)|0);
  $34 = __THREW__; __THREW__ = 0;
  $35 = $34&1;
  if ($35) {
   break;
  }
  $36 = ((($33)) + 8|0);
  $37 = ((($32)) + 8|0);
  $38 = HEAP32[$37>>2]|0;
  HEAP32[$36>>2] = $38;
  $39 = ((($33)) + 12|0);
  $40 = ((($32)) + 12|0);
  $41 = HEAP32[$40>>2]|0;
  HEAP32[$39>>2] = $41;
  $42 = ($41|0)==(0|0);
  if ($42) {
   $46 = $13;$49 = $9;
  } else {
   $43 = ((($41)) + 8|0);
   $44 = HEAP32[$43>>2]|0;HEAP32[$43>>2] = (($44+1)|0);
   $$pre = HEAP32[$0>>2]|0;
   $$pre17 = HEAP32[$3>>2]|0;
   $46 = $$pre;$49 = $$pre17;
  }
  $45 = ((($33)) + 4|0);
  HEAP32[$45>>2] = $0;
  HEAP32[$33>>2] = $46;
  $47 = ((($46)) + 4|0);
  HEAP32[$47>>2] = $33;
  HEAP32[$0>>2] = $33;
  $48 = (($49) + 1)|0;
  HEAP32[$3>>2] = $48;
  $50 = ((($51)) + 4|0);
  $$sroa$07$0 = HEAP32[$50>>2]|0;
  $52 = $$sroa$07$0;
  $53 = ($52|0)==($1|0);
  if ($53) {
   label = 3;
   break;
  } else {
   $$sroa$07$016 = $$sroa$07$0;$13 = $33;$51 = $52;$9 = $48;
  }
 }
 if ((label|0) == 3) {
  return;
 }
 $7 = ___cxa_find_matching_catch_2()|0;
 $8 = tempRet0;
 $10 = ($9|0)==(0);
 if ($10) {
  ___resumeException($7|0);
  // unreachable;
 }
 $11 = HEAP32[$2>>2]|0;
 $12 = ((($13)) + 4|0);
 $14 = HEAP32[$12>>2]|0;
 $15 = HEAP32[$11>>2]|0;
 $16 = ((($15)) + 4|0);
 HEAP32[$16>>2] = $14;
 $17 = HEAP32[$12>>2]|0;
 HEAP32[$17>>2] = $15;
 HEAP32[$3>>2] = 0;
 $18 = ($11|0)==($0|0);
 if ($18) {
  ___resumeException($7|0);
  // unreachable;
 } else {
  $$023$i$i = $11;
 }
 while(1) {
  $19 = ((($$023$i$i)) + 4|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = ((($$023$i$i)) + 12|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = ($22|0)==(0|0);
  if (!($23)) {
   $24 = ((($22)) + 8|0);
   $25 = HEAP32[$24>>2]|0;HEAP32[$24>>2] = (($25-1)|0);
   $26 = ($25|0)==(1);
   if ($26) {
    __THREW__ = 0;
    invoke_viii(3262,($22|0),1,1);
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     label = 10;
     break;
    }
   }
  }
  __ZdlPv($$023$i$i);
  $29 = ($20|0)==($0|0);
  if ($29) {
   label = 11;
   break;
  } else {
   $$023$i$i = $20;
  }
 }
 if ((label|0) == 10) {
  $30 = ___cxa_find_matching_catch_2()|0;
  $31 = tempRet0;
  ___cxa_call_unexpected(($30|0));
  // unreachable;
 }
 else if ((label|0) == 11) {
  ___resumeException($7|0);
  // unreachable;
 }
}
function __ZN7osgUtil11RenderStageC2Ev($0) {
 $0 = $0|0;
 var $$0 = 0, $$02 = 0, $$023$i$i = 0, $$023$i$i8 = 0, $$pre$i = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0;
 var $202 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $1 = (__ZN7osgUtil9RenderBin27getDefaultRenderBinSortModeEv()|0);
 __ZN7osgUtil9RenderBinC2ENS0_8SortModeE($0,$1);
 HEAP32[$0>>2] = (54212);
 $2 = ((($0)) + 104|0);
 HEAP32[$2>>2] = $2;
 $3 = ((($0)) + 108|0);
 HEAP32[$3>>2] = $2;
 $4 = ((($0)) + 112|0);
 HEAP32[$4>>2] = 0;
 $5 = ((($0)) + 116|0);
 HEAP32[$5>>2] = $5;
 $6 = ((($0)) + 120|0);
 HEAP32[$6>>2] = $5;
 $7 = ((($0)) + 124|0);
 $8 = ((($0)) + 128|0);
 $9 = ((($0)) + 132|0);
 $10 = ((($0)) + 140|0);
 $11 = ((($0)) + 144|0);
 $12 = ((($0)) + 168|0);
 $13 = ((($0)) + 228|0);
 HEAP32[$13>>2] = 0;
 $14 = ((($0)) + 232|0);
 HEAP32[$14>>2] = 0;
 $15 = ((($0)) + 236|0);
 HEAP32[$15>>2] = 0;
 $16 = ((($0)) + 248|0);
 HEAP32[$16>>2] = 0;
 $17 = ((($0)) + 260|0);
 $18 = ((($0)) + 264|0);
 HEAP32[$18>>2] = 0;
 $19 = ((($0)) + 268|0);
 HEAP32[$19>>2] = 0;
 $20 = ((($0)) + 264|0);
 ;HEAP32[$7>>2]=0|0;HEAP32[$7+4>>2]=0|0;HEAP32[$7+8>>2]=0|0;HEAP32[$7+12>>2]=0|0;HEAP32[$7+16>>2]=0|0;HEAP32[$7+20>>2]=0|0;
 dest=$12; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAP32[$17>>2] = $20;
 $21 = ((($0)) + 272|0);
 HEAP32[$21>>2] = 0;
 $22 = ((($0)) + 276|0);
 HEAP32[$22>>2] = 0;
 $23 = ((($0)) + 280|0);
 HEAP32[$23>>2] = 0;
 $24 = ((($0)) + 284|0);
 HEAP8[$24>>0] = 1;
 $25 = ((($0)) + 288|0);
 __THREW__ = 0;
 invoke_vi(3299,($25|0));
 $26 = __THREW__; __THREW__ = 0;
 $27 = $26&1;
 if ($27) {
  $53 = ___cxa_find_matching_catch_2()|0;
  $54 = tempRet0;
  $$0 = $54;$$02 = $53;
 } else {
  $28 = ((($0)) + 416|0);
  HEAP32[$28>>2] = 0;
  $29 = ((($0)) + 420|0);
  HEAP32[$29>>2] = 0;
  $30 = ((($0)) + 40|0);
  HEAP32[$30>>2] = $0;
  $31 = ((($0)) + 100|0);
  HEAP8[$31>>0] = 0;
  $32 = ((($0)) + 148|0);
  HEAP32[$32>>2] = 0;
  $33 = ((($0)) + 152|0);
  HEAP8[$33>>0] = 0;
  $34 = ((($0)) + 156|0);
  HEAP32[$34>>2] = 0;
  $35 = ((($0)) + 160|0);
  HEAP8[$35>>0] = 0;
  $36 = ((($0)) + 164|0);
  HEAP32[$36>>2] = 16640;
  $37 = ((($0)) + 172|0);
  $38 = ((($0)) + 208|0);
  ;HEAP32[$37>>2]=0|0;HEAP32[$37+4>>2]=0|0;HEAP32[$37+8>>2]=0|0;HEAP32[$37+12>>2]=0|0;HEAP32[$37+16>>2]=0|0;HEAP32[$37+20>>2]=0|0;HEAP32[$37+24>>2]=0|0;HEAP32[$37+28>>2]=0|0;
  HEAPF64[$38>>3] = 1.0;
  $39 = ((($0)) + 216|0);
  HEAP32[$39>>2] = 0;
  $40 = ((($0)) + 220|0);
  HEAP8[$40>>0] = 0;
  $41 = ((($0)) + 224|0);
  HEAP32[$41>>2] = 0;
  $42 = HEAP32[$13>>2]|0;
  $43 = ($42|0)==(0|0);
  if ($43) {
   HEAP32[$14>>2] = 0;
   $49 = ((($0)) + 240|0);
   HEAP32[$49>>2] = 0;
   $50 = ((($0)) + 244|0);
   HEAP32[$50>>2] = 0;
   $51 = ((($0)) + 252|0);
   HEAP32[$51>>2] = 6408;
   $52 = ((($0)) + 256|0);
   HEAP32[$52>>2] = 5121;
   return;
  }
  HEAP32[$13>>2] = 0;
  $44 = ((($42)) + 8|0);
  $45 = HEAP32[$44>>2]|0;HEAP32[$44>>2] = (($45-1)|0);
  $46 = ($45|0)==(1);
  if (!($46)) {
   HEAP32[$14>>2] = 0;
   $49 = ((($0)) + 240|0);
   HEAP32[$49>>2] = 0;
   $50 = ((($0)) + 244|0);
   HEAP32[$50>>2] = 0;
   $51 = ((($0)) + 252|0);
   HEAP32[$51>>2] = 6408;
   $52 = ((($0)) + 256|0);
   HEAP32[$52>>2] = 5121;
   return;
  }
  __THREW__ = 0;
  invoke_viii(3262,($42|0),1,1);
  $47 = __THREW__; __THREW__ = 0;
  $48 = $47&1;
  if (!($48)) {
   HEAP32[$14>>2] = 0;
   $49 = ((($0)) + 240|0);
   HEAP32[$49>>2] = 0;
   $50 = ((($0)) + 244|0);
   HEAP32[$50>>2] = 0;
   $51 = ((($0)) + 252|0);
   HEAP32[$51>>2] = 6408;
   $52 = ((($0)) + 256|0);
   HEAP32[$52>>2] = 5121;
   return;
  }
  $55 = ___cxa_find_matching_catch_2()|0;
  $56 = tempRet0;
  $57 = HEAP32[$29>>2]|0;
  $58 = ($57|0)==(0|0);
  if (!($58)) {
   $59 = ((($57)) + 8|0);
   $60 = HEAP32[$59>>2]|0;HEAP32[$59>>2] = (($60-1)|0);
   $61 = ($60|0)==(1);
   if ($61) {
    __THREW__ = 0;
    invoke_viii(3262,($57|0),1,1);
    $62 = __THREW__; __THREW__ = 0;
    $63 = $62&1;
    if ($63) {
     $201 = ___cxa_find_matching_catch_3(0|0)|0;
     $202 = tempRet0;
     ___clang_call_terminate($201);
     // unreachable;
    }
   }
  }
  HEAP32[$29>>2] = 0;
  $64 = HEAP32[$28>>2]|0;
  $65 = ($64|0)==(0|0);
  if (!($65)) {
   $66 = ((($64)) + 8|0);
   $67 = HEAP32[$66>>2]|0;HEAP32[$66>>2] = (($67-1)|0);
   $68 = ($67|0)==(1);
   if ($68) {
    __THREW__ = 0;
    invoke_viii(3262,($64|0),1,1);
    $69 = __THREW__; __THREW__ = 0;
    $70 = $69&1;
    if ($70) {
     $201 = ___cxa_find_matching_catch_3(0|0)|0;
     $202 = tempRet0;
     ___clang_call_terminate($201);
     // unreachable;
    }
   }
  }
  HEAP32[$28>>2] = 0;
  $$0 = $56;$$02 = $55;
 }
 $71 = HEAP32[$23>>2]|0;
 $72 = ($71|0)==(0|0);
 if (!($72)) {
  $73 = ((($71)) + 8|0);
  $74 = HEAP32[$73>>2]|0;HEAP32[$73>>2] = (($74-1)|0);
  $75 = ($74|0)==(1);
  if ($75) {
   __THREW__ = 0;
   invoke_viii(3262,($71|0),1,1);
   $76 = __THREW__; __THREW__ = 0;
   $77 = $76&1;
   if ($77) {
    $201 = ___cxa_find_matching_catch_3(0|0)|0;
    $202 = tempRet0;
    ___clang_call_terminate($201);
    // unreachable;
   }
  }
 }
 HEAP32[$23>>2] = 0;
 $78 = HEAP32[$22>>2]|0;
 $79 = ($78|0)==(0|0);
 if (!($79)) {
  $80 = ((($78)) + 8|0);
  $81 = HEAP32[$80>>2]|0;HEAP32[$80>>2] = (($81-1)|0);
  $82 = ($81|0)==(1);
  if ($82) {
   __THREW__ = 0;
   invoke_viii(3262,($78|0),1,1);
   $83 = __THREW__; __THREW__ = 0;
   $84 = $83&1;
   if ($84) {
    $201 = ___cxa_find_matching_catch_3(0|0)|0;
    $202 = tempRet0;
    ___clang_call_terminate($201);
    // unreachable;
   }
  }
 }
 HEAP32[$22>>2] = 0;
 $85 = HEAP32[$21>>2]|0;
 $86 = ($85|0)==(0|0);
 if (!($86)) {
  $87 = ((($85)) + 8|0);
  $88 = HEAP32[$87>>2]|0;HEAP32[$87>>2] = (($88-1)|0);
  $89 = ($88|0)==(1);
  if ($89) {
   __THREW__ = 0;
   invoke_viii(3262,($85|0),1,1);
   $90 = __THREW__; __THREW__ = 0;
   $91 = $90&1;
   if ($91) {
    $201 = ___cxa_find_matching_catch_3(0|0)|0;
    $202 = tempRet0;
    ___clang_call_terminate($201);
    // unreachable;
   }
  }
 }
 HEAP32[$21>>2] = 0;
 $92 = HEAP32[$20>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIN3osg6Camera15BufferComponentEN7osgUtil11RenderStage10AttachmentEEENS_19__map_value_compareIS4_S8_NS_4lessIS4_EELb1EEENS_9allocatorIS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($17,$92);
 $93 = HEAP32[$16>>2]|0;
 $94 = ($93|0)==(0|0);
 if (!($94)) {
  $95 = ((($93)) + 8|0);
  $96 = HEAP32[$95>>2]|0;HEAP32[$95>>2] = (($96-1)|0);
  $97 = ($96|0)==(1);
  if ($97) {
   __THREW__ = 0;
   invoke_viii(3262,($93|0),1,1);
   $98 = __THREW__; __THREW__ = 0;
   $99 = $98&1;
   if ($99) {
    $201 = ___cxa_find_matching_catch_3(0|0)|0;
    $202 = tempRet0;
    ___clang_call_terminate($201);
    // unreachable;
   }
  }
 }
 HEAP32[$16>>2] = 0;
 $100 = HEAP32[$15>>2]|0;
 $101 = ($100|0)==(0|0);
 if (!($101)) {
  $102 = ((($100)) + 8|0);
  $103 = HEAP32[$102>>2]|0;HEAP32[$102>>2] = (($103-1)|0);
  $104 = ($103|0)==(1);
  if ($104) {
   __THREW__ = 0;
   invoke_viii(3262,($100|0),1,1);
   $105 = __THREW__; __THREW__ = 0;
   $106 = $105&1;
   if ($106) {
    $201 = ___cxa_find_matching_catch_3(0|0)|0;
    $202 = tempRet0;
    ___clang_call_terminate($201);
    // unreachable;
   }
  }
 }
 HEAP32[$15>>2] = 0;
 $107 = HEAP32[$13>>2]|0;
 $108 = ($107|0)==(0|0);
 if (!($108)) {
  $109 = ((($107)) + 8|0);
  $110 = HEAP32[$109>>2]|0;HEAP32[$109>>2] = (($110-1)|0);
  $111 = ($110|0)==(1);
  if ($111) {
   __THREW__ = 0;
   invoke_viii(3262,($107|0),1,1);
   $112 = __THREW__; __THREW__ = 0;
   $113 = $112&1;
   if ($113) {
    $201 = ___cxa_find_matching_catch_3(0|0)|0;
    $202 = tempRet0;
    ___clang_call_terminate($201);
    // unreachable;
   }
  }
 }
 HEAP32[$13>>2] = 0;
 $114 = HEAP32[$12>>2]|0;
 $115 = ($114|0)==(0|0);
 if (!($115)) {
  $116 = ((($114)) + 8|0);
  $117 = HEAP32[$116>>2]|0;HEAP32[$116>>2] = (($117-1)|0);
  $118 = ($117|0)==(1);
  if ($118) {
   __THREW__ = 0;
   invoke_viii(3262,($114|0),1,1);
   $119 = __THREW__; __THREW__ = 0;
   $120 = $119&1;
   if ($120) {
    $201 = ___cxa_find_matching_catch_3(0|0)|0;
    $202 = tempRet0;
    ___clang_call_terminate($201);
    // unreachable;
   }
  }
 }
 HEAP32[$12>>2] = 0;
 $121 = HEAP32[$11>>2]|0;
 $122 = ($121|0)==(0|0);
 if (!($122)) {
  $123 = ((($121)) + 8|0);
  $124 = HEAP32[$123>>2]|0;HEAP32[$123>>2] = (($124-1)|0);
  $125 = ($124|0)==(1);
  if ($125) {
   __THREW__ = 0;
   invoke_viii(3262,($121|0),1,1);
   $126 = __THREW__; __THREW__ = 0;
   $127 = $126&1;
   if ($127) {
    $201 = ___cxa_find_matching_catch_3(0|0)|0;
    $202 = tempRet0;
    ___clang_call_terminate($201);
    // unreachable;
   }
  }
 }
 HEAP32[$11>>2] = 0;
 $128 = HEAP32[$10>>2]|0;
 $129 = ($128|0)==(0|0);
 if (!($129)) {
  $130 = ((($128)) + 8|0);
  $131 = HEAP32[$130>>2]|0;HEAP32[$130>>2] = (($131-1)|0);
  $132 = ($131|0)==(1);
  if ($132) {
   __THREW__ = 0;
   invoke_viii(3262,($128|0),1,1);
   $133 = __THREW__; __THREW__ = 0;
   $134 = $133&1;
   if ($134) {
    $201 = ___cxa_find_matching_catch_3(0|0)|0;
    $202 = tempRet0;
    ___clang_call_terminate($201);
    // unreachable;
   }
  }
 }
 HEAP32[$10>>2] = 0;
 $135 = HEAP32[$8>>2]|0;
 $136 = ($135|0)==(0|0);
 if (!($136)) {
  $137 = HEAP32[$9>>2]|0;
  $138 = ($137|0)==($135|0);
  do {
   if ($138) {
    $152 = $135;
   } else {
    $140 = $137;
    while(1) {
     $139 = ((($140)) + -4|0);
     HEAP32[$9>>2] = $139;
     $141 = HEAP32[$139>>2]|0;
     $142 = ($141|0)==(0|0);
     if (!($142)) {
      $143 = ((($141)) + 8|0);
      $144 = HEAP32[$143>>2]|0;HEAP32[$143>>2] = (($144-1)|0);
      $145 = ($144|0)==(1);
      if ($145) {
       __THREW__ = 0;
       invoke_viii(3262,($141|0),1,1);
       $146 = __THREW__; __THREW__ = 0;
       $147 = $146&1;
       if ($147) {
        label = 47;
        break;
       }
      }
     }
     HEAP32[$139>>2] = 0;
     $148 = HEAP32[$9>>2]|0;
     $149 = ($148|0)==($135|0);
     if ($149) {
      label = 48;
      break;
     } else {
      $140 = $148;
     }
    }
    if ((label|0) == 47) {
     $150 = ___cxa_find_matching_catch_2()|0;
     $151 = tempRet0;
     ___cxa_call_unexpected(($150|0));
     // unreachable;
    }
    else if ((label|0) == 48) {
     $$pre$i = HEAP32[$8>>2]|0;
     $152 = $$pre$i;
     break;
    }
   }
  } while(0);
  __ZdlPv($152);
 }
 $153 = HEAP32[$7>>2]|0;
 $154 = ($153|0)==(0);
 L83: do {
  if (!($154)) {
   $155 = HEAP32[$6>>2]|0;
   $156 = HEAP32[$5>>2]|0;
   $157 = ((($156)) + 4|0);
   $158 = HEAP32[$157>>2]|0;
   $159 = HEAP32[$155>>2]|0;
   $160 = ((($159)) + 4|0);
   HEAP32[$160>>2] = $158;
   $161 = HEAP32[$157>>2]|0;
   HEAP32[$161>>2] = $159;
   HEAP32[$7>>2] = 0;
   $162 = ($155|0)==($5|0);
   if (!($162)) {
    $$023$i$i8 = $155;
    while(1) {
     $163 = ((($$023$i$i8)) + 4|0);
     $164 = HEAP32[$163>>2]|0;
     $165 = ((($$023$i$i8)) + 12|0);
     $166 = HEAP32[$165>>2]|0;
     $167 = ($166|0)==(0|0);
     if (!($167)) {
      $168 = ((($166)) + 8|0);
      $169 = HEAP32[$168>>2]|0;HEAP32[$168>>2] = (($169-1)|0);
      $170 = ($169|0)==(1);
      if ($170) {
       __THREW__ = 0;
       invoke_viii(3262,($166|0),1,1);
       $171 = __THREW__; __THREW__ = 0;
       $172 = $171&1;
       if ($172) {
        break;
       }
      }
     }
     __ZdlPv($$023$i$i8);
     $173 = ($164|0)==($5|0);
     if ($173) {
      break L83;
     } else {
      $$023$i$i8 = $164;
     }
    }
    $174 = ___cxa_find_matching_catch_2()|0;
    $175 = tempRet0;
    ___cxa_call_unexpected(($174|0));
    // unreachable;
   }
  }
 } while(0);
 $176 = HEAP32[$4>>2]|0;
 $177 = ($176|0)==(0);
 L93: do {
  if (!($177)) {
   $178 = HEAP32[$3>>2]|0;
   $179 = HEAP32[$2>>2]|0;
   $180 = ((($179)) + 4|0);
   $181 = HEAP32[$180>>2]|0;
   $182 = HEAP32[$178>>2]|0;
   $183 = ((($182)) + 4|0);
   HEAP32[$183>>2] = $181;
   $184 = HEAP32[$180>>2]|0;
   HEAP32[$184>>2] = $182;
   HEAP32[$4>>2] = 0;
   $185 = ($178|0)==($2|0);
   if (!($185)) {
    $$023$i$i = $178;
    while(1) {
     $186 = ((($$023$i$i)) + 4|0);
     $187 = HEAP32[$186>>2]|0;
     $188 = ((($$023$i$i)) + 12|0);
     $189 = HEAP32[$188>>2]|0;
     $190 = ($189|0)==(0|0);
     if (!($190)) {
      $191 = ((($189)) + 8|0);
      $192 = HEAP32[$191>>2]|0;HEAP32[$191>>2] = (($192-1)|0);
      $193 = ($192|0)==(1);
      if ($193) {
       __THREW__ = 0;
       invoke_viii(3262,($189|0),1,1);
       $194 = __THREW__; __THREW__ = 0;
       $195 = $194&1;
       if ($195) {
        break;
       }
      }
     }
     __ZdlPv($$023$i$i);
     $196 = ($187|0)==($2|0);
     if ($196) {
      break L93;
     } else {
      $$023$i$i = $187;
     }
    }
    $197 = ___cxa_find_matching_catch_2()|0;
    $198 = tempRet0;
    ___cxa_call_unexpected(($197|0));
    // unreachable;
   }
  }
 } while(0);
 __THREW__ = 0;
 invoke_vi(1385,($0|0));
 $199 = __THREW__; __THREW__ = 0;
 $200 = $199&1;
 if ($200) {
  $201 = ___cxa_find_matching_catch_3(0|0)|0;
  $202 = tempRet0;
  ___clang_call_terminate($201);
  // unreachable;
 } else {
  ___resumeException($$02|0);
  // unreachable;
 }
}
function __ZN7osgUtil11RenderStage17addPreRenderStageEPS0_i($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$07 = 0, $$1 = 0, $$18 = 0, $$2 = 0, $$29 = 0, $$sroa$054$0 = 0, $$sroa$054$066 = 0, $$sroa$054$067 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($1|0)==(0|0);
 if ($3) {
  return;
 }
 $4 = ((($0)) + 104|0);
 $5 = ((($0)) + 108|0);
 $$sroa$054$066 = HEAP32[$5>>2]|0;
 $6 = $$sroa$054$066;
 $7 = ($6|0)==($4|0);
 L4: do {
  if ($7) {
   label = 5;
  } else {
   $$sroa$054$067 = $$sroa$054$066;$13 = $6;
   while(1) {
    $8 = $$sroa$054$067;
    $9 = ((($8)) + 8|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = ($10|0)>($2|0);
    if ($11) {
     break;
    }
    $12 = ((($13)) + 4|0);
    $$sroa$054$0 = HEAP32[$12>>2]|0;
    $14 = $$sroa$054$0;
    $15 = ($14|0)==($4|0);
    if ($15) {
     label = 5;
     break L4;
    } else {
     $$sroa$054$067 = $$sroa$054$0;$13 = $14;
    }
   }
   $19 = ($13|0)==($4|0);
   $20 = ((($1)) + 8|0);
   $21 = HEAP32[$20>>2]|0;HEAP32[$20>>2] = (($21+1)|0);
   $22 = HEAP32[$20>>2]|0;HEAP32[$20>>2] = (($22+1)|0);
   if ($19) {
    $29 = $20;
   } else {
    __THREW__ = 0;
    $54 = (invoke_ii(3276,16)|0);
    $55 = __THREW__; __THREW__ = 0;
    $56 = $55&1;
    do {
     if ($56) {
      $75 = ___cxa_find_matching_catch_2()|0;
      $76 = tempRet0;
      $77 = HEAP32[$20>>2]|0;HEAP32[$20>>2] = (($77-1)|0);
      $78 = ($77|0)==(1);
      if ($78) {
       __THREW__ = 0;
       invoke_viii(3262,($1|0),1,1);
       $79 = __THREW__; __THREW__ = 0;
       $80 = $79&1;
       if ($80) {
        $85 = ___cxa_find_matching_catch_3(0|0)|0;
        $86 = tempRet0;
        ___clang_call_terminate($85);
        // unreachable;
       } else {
        $$1 = $75;$$18 = $76;
       }
      } else {
       $$1 = $75;$$18 = $76;
      }
     } else {
      HEAP32[$54>>2] = 0;
      $57 = ((($54)) + 8|0);
      HEAP32[$57>>2] = $2;
      $58 = ((($54)) + 12|0);
      HEAP32[$58>>2] = $1;
      $59 = HEAP32[$20>>2]|0;HEAP32[$20>>2] = (($59+1)|0);
      $60 = HEAP32[$13>>2]|0;
      $61 = ((($60)) + 4|0);
      HEAP32[$61>>2] = $54;
      HEAP32[$54>>2] = $60;
      $62 = $$sroa$054$067;
      HEAP32[$62>>2] = $54;
      $63 = ((($54)) + 4|0);
      HEAP32[$63>>2] = $13;
      $64 = ((($0)) + 112|0);
      $65 = HEAP32[$64>>2]|0;
      $66 = (($65) + 1)|0;
      HEAP32[$64>>2] = $66;
      $67 = HEAP32[$20>>2]|0;HEAP32[$20>>2] = (($67-1)|0);
      $68 = ($67|0)==(1);
      if ($68) {
       __THREW__ = 0;
       invoke_viii(3262,($1|0),1,1);
       $69 = __THREW__; __THREW__ = 0;
       $70 = $69&1;
       if ($70) {
        $73 = ___cxa_find_matching_catch_2()|0;
        $74 = tempRet0;
        $$1 = $73;$$18 = $74;
        break;
       }
      }
      $71 = HEAP32[$20>>2]|0;HEAP32[$20>>2] = (($71-1)|0);
      $72 = ($71|0)==(1);
      if (!($72)) {
       return;
      }
      __ZNK3osg10Referenced24signalObserversAndDeleteEbb($1,1,1);
      return;
     }
    } while(0);
    $81 = HEAP32[$20>>2]|0;HEAP32[$20>>2] = (($81-1)|0);
    $82 = ($81|0)==(1);
    if (!($82)) {
     $$2 = $$1;$$29 = $$18;
     ___resumeException($$2|0);
     // unreachable;
    }
    __THREW__ = 0;
    invoke_viii(3262,($1|0),1,1);
    $83 = __THREW__; __THREW__ = 0;
    $84 = $83&1;
    if ($84) {
     $85 = ___cxa_find_matching_catch_3(0|0)|0;
     $86 = tempRet0;
     ___clang_call_terminate($85);
     // unreachable;
    } else {
     $$2 = $$1;$$29 = $$18;
     ___resumeException($$2|0);
     // unreachable;
    }
   }
  }
 } while(0);
 if ((label|0) == 5) {
  $16 = ((($1)) + 8|0);
  $17 = HEAP32[$16>>2]|0;HEAP32[$16>>2] = (($17+1)|0);
  $18 = HEAP32[$16>>2]|0;HEAP32[$16>>2] = (($18+1)|0);
  $29 = $16;
 }
 __THREW__ = 0;
 $23 = (invoke_ii(3276,16)|0);
 $24 = __THREW__; __THREW__ = 0;
 $25 = $24&1;
 do {
  if ($25) {
   $44 = ___cxa_find_matching_catch_2()|0;
   $45 = tempRet0;
   $46 = HEAP32[$29>>2]|0;HEAP32[$29>>2] = (($46-1)|0);
   $47 = ($46|0)==(1);
   if ($47) {
    __THREW__ = 0;
    invoke_viii(3262,($1|0),1,1);
    $48 = __THREW__; __THREW__ = 0;
    $49 = $48&1;
    if ($49) {
     $85 = ___cxa_find_matching_catch_3(0|0)|0;
     $86 = tempRet0;
     ___clang_call_terminate($85);
     // unreachable;
    } else {
     $$0 = $44;$$07 = $45;
    }
   } else {
    $$0 = $44;$$07 = $45;
   }
  } else {
   $26 = ((($23)) + 8|0);
   HEAP32[$26>>2] = $2;
   $27 = ((($23)) + 12|0);
   HEAP32[$27>>2] = $1;
   $28 = HEAP32[$29>>2]|0;HEAP32[$29>>2] = (($28+1)|0);
   $30 = ((($23)) + 4|0);
   HEAP32[$30>>2] = $4;
   $31 = HEAP32[$4>>2]|0;
   HEAP32[$23>>2] = $31;
   $32 = ((($31)) + 4|0);
   HEAP32[$32>>2] = $23;
   HEAP32[$4>>2] = $23;
   $33 = ((($0)) + 112|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = (($34) + 1)|0;
   HEAP32[$33>>2] = $35;
   $36 = HEAP32[$29>>2]|0;HEAP32[$29>>2] = (($36-1)|0);
   $37 = ($36|0)==(1);
   if ($37) {
    __THREW__ = 0;
    invoke_viii(3262,($1|0),1,1);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     $42 = ___cxa_find_matching_catch_2()|0;
     $43 = tempRet0;
     $$0 = $42;$$07 = $43;
     break;
    }
   }
   $40 = HEAP32[$29>>2]|0;HEAP32[$29>>2] = (($40-1)|0);
   $41 = ($40|0)==(1);
   if (!($41)) {
    return;
   }
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($1,1,1);
   return;
  }
 } while(0);
 $50 = HEAP32[$29>>2]|0;HEAP32[$29>>2] = (($50-1)|0);
 $51 = ($50|0)==(1);
 if (!($51)) {
  $$2 = $$0;$$29 = $$07;
  ___resumeException($$2|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(3262,($1|0),1,1);
 $52 = __THREW__; __THREW__ = 0;
 $53 = $52&1;
 if ($53) {
  $85 = ___cxa_find_matching_catch_3(0|0)|0;
  $86 = tempRet0;
  ___clang_call_terminate($85);
  // unreachable;
 } else {
  $$2 = $$0;$$29 = $$07;
  ___resumeException($$2|0);
  // unreachable;
 }
}
function __ZN7osgUtil11RenderStage18addPostRenderStageEPS0_i($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$07 = 0, $$1 = 0, $$18 = 0, $$2 = 0, $$29 = 0, $$sroa$054$0 = 0, $$sroa$054$066 = 0, $$sroa$054$067 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($1|0)==(0|0);
 if ($3) {
  return;
 }
 $4 = ((($0)) + 116|0);
 $5 = ((($0)) + 120|0);
 $$sroa$054$066 = HEAP32[$5>>2]|0;
 $6 = $$sroa$054$066;
 $7 = ($6|0)==($4|0);
 L4: do {
  if ($7) {
   label = 5;
  } else {
   $$sroa$054$067 = $$sroa$054$066;$13 = $6;
   while(1) {
    $8 = $$sroa$054$067;
    $9 = ((($8)) + 8|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = ($10|0)>($2|0);
    if ($11) {
     break;
    }
    $12 = ((($13)) + 4|0);
    $$sroa$054$0 = HEAP32[$12>>2]|0;
    $14 = $$sroa$054$0;
    $15 = ($14|0)==($4|0);
    if ($15) {
     label = 5;
     break L4;
    } else {
     $$sroa$054$067 = $$sroa$054$0;$13 = $14;
    }
   }
   $19 = ($13|0)==($4|0);
   $20 = ((($1)) + 8|0);
   $21 = HEAP32[$20>>2]|0;HEAP32[$20>>2] = (($21+1)|0);
   $22 = HEAP32[$20>>2]|0;HEAP32[$20>>2] = (($22+1)|0);
   if ($19) {
    $29 = $20;
   } else {
    __THREW__ = 0;
    $54 = (invoke_ii(3276,16)|0);
    $55 = __THREW__; __THREW__ = 0;
    $56 = $55&1;
    do {
     if ($56) {
      $75 = ___cxa_find_matching_catch_2()|0;
      $76 = tempRet0;
      $77 = HEAP32[$20>>2]|0;HEAP32[$20>>2] = (($77-1)|0);
      $78 = ($77|0)==(1);
      if ($78) {
       __THREW__ = 0;
       invoke_viii(3262,($1|0),1,1);
       $79 = __THREW__; __THREW__ = 0;
       $80 = $79&1;
       if ($80) {
        $85 = ___cxa_find_matching_catch_3(0|0)|0;
        $86 = tempRet0;
        ___clang_call_terminate($85);
        // unreachable;
       } else {
        $$1 = $75;$$18 = $76;
       }
      } else {
       $$1 = $75;$$18 = $76;
      }
     } else {
      HEAP32[$54>>2] = 0;
      $57 = ((($54)) + 8|0);
      HEAP32[$57>>2] = $2;
      $58 = ((($54)) + 12|0);
      HEAP32[$58>>2] = $1;
      $59 = HEAP32[$20>>2]|0;HEAP32[$20>>2] = (($59+1)|0);
      $60 = HEAP32[$13>>2]|0;
      $61 = ((($60)) + 4|0);
      HEAP32[$61>>2] = $54;
      HEAP32[$54>>2] = $60;
      $62 = $$sroa$054$067;
      HEAP32[$62>>2] = $54;
      $63 = ((($54)) + 4|0);
      HEAP32[$63>>2] = $13;
      $64 = ((($0)) + 124|0);
      $65 = HEAP32[$64>>2]|0;
      $66 = (($65) + 1)|0;
      HEAP32[$64>>2] = $66;
      $67 = HEAP32[$20>>2]|0;HEAP32[$20>>2] = (($67-1)|0);
      $68 = ($67|0)==(1);
      if ($68) {
       __THREW__ = 0;
       invoke_viii(3262,($1|0),1,1);
       $69 = __THREW__; __THREW__ = 0;
       $70 = $69&1;
       if ($70) {
        $73 = ___cxa_find_matching_catch_2()|0;
        $74 = tempRet0;
        $$1 = $73;$$18 = $74;
        break;
       }
      }
      $71 = HEAP32[$20>>2]|0;HEAP32[$20>>2] = (($71-1)|0);
      $72 = ($71|0)==(1);
      if (!($72)) {
       return;
      }
      __ZNK3osg10Referenced24signalObserversAndDeleteEbb($1,1,1);
      return;
     }
    } while(0);
    $81 = HEAP32[$20>>2]|0;HEAP32[$20>>2] = (($81-1)|0);
    $82 = ($81|0)==(1);
    if (!($82)) {
     $$2 = $$1;$$29 = $$18;
     ___resumeException($$2|0);
     // unreachable;
    }
    __THREW__ = 0;
    invoke_viii(3262,($1|0),1,1);
    $83 = __THREW__; __THREW__ = 0;
    $84 = $83&1;
    if ($84) {
     $85 = ___cxa_find_matching_catch_3(0|0)|0;
     $86 = tempRet0;
     ___clang_call_terminate($85);
     // unreachable;
    } else {
     $$2 = $$1;$$29 = $$18;
     ___resumeException($$2|0);
     // unreachable;
    }
   }
  }
 } while(0);
 if ((label|0) == 5) {
  $16 = ((($1)) + 8|0);
  $17 = HEAP32[$16>>2]|0;HEAP32[$16>>2] = (($17+1)|0);
  $18 = HEAP32[$16>>2]|0;HEAP32[$16>>2] = (($18+1)|0);
  $29 = $16;
 }
 __THREW__ = 0;
 $23 = (invoke_ii(3276,16)|0);
 $24 = __THREW__; __THREW__ = 0;
 $25 = $24&1;
 do {
  if ($25) {
   $44 = ___cxa_find_matching_catch_2()|0;
   $45 = tempRet0;
   $46 = HEAP32[$29>>2]|0;HEAP32[$29>>2] = (($46-1)|0);
   $47 = ($46|0)==(1);
   if ($47) {
    __THREW__ = 0;
    invoke_viii(3262,($1|0),1,1);
    $48 = __THREW__; __THREW__ = 0;
    $49 = $48&1;
    if ($49) {
     $85 = ___cxa_find_matching_catch_3(0|0)|0;
     $86 = tempRet0;
     ___clang_call_terminate($85);
     // unreachable;
    } else {
     $$0 = $44;$$07 = $45;
    }
   } else {
    $$0 = $44;$$07 = $45;
   }
  } else {
   $26 = ((($23)) + 8|0);
   HEAP32[$26>>2] = $2;
   $27 = ((($23)) + 12|0);
   HEAP32[$27>>2] = $1;
   $28 = HEAP32[$29>>2]|0;HEAP32[$29>>2] = (($28+1)|0);
   $30 = ((($23)) + 4|0);
   HEAP32[$30>>2] = $4;
   $31 = HEAP32[$4>>2]|0;
   HEAP32[$23>>2] = $31;
   $32 = ((($31)) + 4|0);
   HEAP32[$32>>2] = $23;
   HEAP32[$4>>2] = $23;
   $33 = ((($0)) + 124|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = (($34) + 1)|0;
   HEAP32[$33>>2] = $35;
   $36 = HEAP32[$29>>2]|0;HEAP32[$29>>2] = (($36-1)|0);
   $37 = ($36|0)==(1);
   if ($37) {
    __THREW__ = 0;
    invoke_viii(3262,($1|0),1,1);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     $42 = ___cxa_find_matching_catch_2()|0;
     $43 = tempRet0;
     $$0 = $42;$$07 = $43;
     break;
    }
   }
   $40 = HEAP32[$29>>2]|0;HEAP32[$29>>2] = (($40-1)|0);
   $41 = ($40|0)==(1);
   if (!($41)) {
    return;
   }
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($1,1,1);
   return;
  }
 } while(0);
 $50 = HEAP32[$29>>2]|0;HEAP32[$29>>2] = (($50-1)|0);
 $51 = ($50|0)==(1);
 if (!($51)) {
  $$2 = $$0;$$29 = $$07;
  ___resumeException($$2|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(3262,($1|0),1,1);
 $52 = __THREW__; __THREW__ = 0;
 $53 = $52&1;
 if ($53) {
  $85 = ___cxa_find_matching_catch_3(0|0)|0;
  $86 = tempRet0;
  ___clang_call_terminate($85);
  // unreachable;
 } else {
  $$2 = $$0;$$29 = $$07;
  ___resumeException($$2|0);
  // unreachable;
 }
}
function __ZNK7osgUtil11RenderStage8getStatsERNS_10StatisticsE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$$0$off0 = 0, $$$2$off0 = 0, $$$2$off09 = 0, $$0$off0$lcssa = 0, $$0$off027 = 0, $$2$off0$lcssa = 0, $$2$off023 = 0, $$sroa$011$0 = 0, $$sroa$011$022 = 0, $$sroa$011$024 = 0, $$sroa$017$0 = 0, $$sroa$017$026 = 0, $$sroa$017$028 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 108|0);
 $$sroa$017$026 = HEAP32[$2>>2]|0;
 $3 = ((($0)) + 104|0);
 $4 = $$sroa$017$026;
 $5 = ($4|0)==($3|0);
 if ($5) {
  $$0$off0$lcssa = 0;
 } else {
  $$0$off027 = 0;$$sroa$017$028 = $$sroa$017$026;$15 = $4;
  while(1) {
   $10 = $$sroa$017$028;
   $11 = ((($10)) + 12|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = (__ZNK7osgUtil11RenderStage8getStatsERNS_10StatisticsE($12,$1)|0);
   $$$0$off0 = $$0$off027 | $13;
   $14 = ((($15)) + 4|0);
   $$sroa$017$0 = HEAP32[$14>>2]|0;
   $16 = $$sroa$017$0;
   $17 = ($16|0)==($3|0);
   if ($17) {
    $$0$off0$lcssa = $$$0$off0;
    break;
   } else {
    $$0$off027 = $$$0$off0;$$sroa$017$028 = $$sroa$017$0;$15 = $16;
   }
  }
 }
 $6 = ((($0)) + 120|0);
 $$sroa$011$022 = HEAP32[$6>>2]|0;
 $7 = ((($0)) + 116|0);
 $8 = $$sroa$011$022;
 $9 = ($8|0)==($7|0);
 if ($9) {
  $$2$off0$lcssa = $$0$off0$lcssa;
  $18 = (__ZNK7osgUtil9RenderBin8getStatsERNS_10StatisticsE($0,$1)|0);
  $$$2$off0 = $$2$off0$lcssa | $18;
  return ($$$2$off0|0);
 } else {
  $$2$off023 = $$0$off0$lcssa;$$sroa$011$024 = $$sroa$011$022;$24 = $8;
 }
 while(1) {
  $19 = $$sroa$011$024;
  $20 = ((($19)) + 12|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = (__ZNK7osgUtil11RenderStage8getStatsERNS_10StatisticsE($21,$1)|0);
  $$$2$off09 = $$2$off023 | $22;
  $23 = ((($24)) + 4|0);
  $$sroa$011$0 = HEAP32[$23>>2]|0;
  $25 = $$sroa$011$0;
  $26 = ($25|0)==($7|0);
  if ($26) {
   $$2$off0$lcssa = $$$2$off09;
   break;
  } else {
   $$2$off023 = $$$2$off09;$$sroa$011$024 = $$sroa$011$0;$24 = $25;
  }
 }
 $18 = (__ZNK7osgUtil9RenderBin8getStatsERNS_10StatisticsE($0,$1)|0);
 $$$2$off0 = $$2$off0$lcssa | $18;
 return ($$$2$off0|0);
}
function __ZN7osgUtil11RenderStage35collateReferencesToDependentCamerasEv($0) {
 $0 = $0|0;
 var $$0 = 0, $$011 = 0, $$pre$i = 0, $$pre$i18 = 0, $$sroa$024$0 = 0, $$sroa$024$042 = 0, $$sroa$024$043 = 0, $$sroa$032$0 = 0, $$sroa$032$045 = 0, $$sroa$032$046 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp + 4|0;
 $2 = sp;
 $3 = ((($0)) + 128|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 132|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==($4|0);
 L1: do {
  if (!($7)) {
   $9 = $6;
   while(1) {
    $8 = ((($9)) + -4|0);
    HEAP32[$5>>2] = $8;
    $10 = HEAP32[$8>>2]|0;
    $11 = ($10|0)==(0|0);
    if (!($11)) {
     $12 = ((($10)) + 8|0);
     $13 = HEAP32[$12>>2]|0;HEAP32[$12>>2] = (($13-1)|0);
     $14 = ($13|0)==(1);
     if ($14) {
      __THREW__ = 0;
      invoke_viii(3262,($10|0),1,1);
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if ($16) {
       break;
      }
     }
    }
    HEAP32[$8>>2] = 0;
    $17 = HEAP32[$5>>2]|0;
    $18 = ($17|0)==($4|0);
    if ($18) {
     break L1;
    } else {
     $9 = $17;
    }
   }
   $19 = ___cxa_find_matching_catch_2()|0;
   $20 = tempRet0;
   ___cxa_call_unexpected(($19|0));
   // unreachable;
  }
 } while(0);
 $21 = ((($0)) + 108|0);
 $$sroa$032$045 = HEAP32[$21>>2]|0;
 $22 = ((($0)) + 104|0);
 $23 = $$sroa$032$045;
 $24 = ($23|0)==($22|0);
 L10: do {
  if (!($24)) {
   $25 = ((($0)) + 136|0);
   $$sroa$032$046 = $$sroa$032$045;$72 = $23;
   while(1) {
    $31 = $$sroa$032$046;
    $32 = ((($31)) + 12|0);
    $33 = HEAP32[$32>>2]|0;
    __ZN7osgUtil11RenderStage35collateReferencesToDependentCamerasEv($33);
    $34 = HEAP32[$32>>2]|0;
    $35 = ((($34)) + 228|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = ($36|0)==(0|0);
    if (!($37)) {
     $38 = ((($36)) + 24|0);
     $39 = HEAP32[$38>>2]|0;
     $40 = ($39|0)==(0|0);
     if (!($40)) {
      $41 = ((($34)) + 232|0);
      $42 = HEAP32[$41>>2]|0;
      $43 = ($42|0)==(0|0);
      if (!($43)) {
       HEAP32[$1>>2] = $42;
       $44 = ((($42)) + 8|0);
       $45 = HEAP32[$44>>2]|0;HEAP32[$44>>2] = (($45+1)|0);
       $46 = HEAP32[$5>>2]|0;
       $47 = HEAP32[$25>>2]|0;
       $48 = ($46|0)==($47|0);
       if ($48) {
        __THREW__ = 0;
        invoke_vii(3692,($3|0),($1|0));
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         break;
        }
       } else {
        $49 = HEAP32[$1>>2]|0;
        HEAP32[$46>>2] = $49;
        $50 = ($49|0)==(0|0);
        if ($50) {
         $54 = $46;
        } else {
         $51 = ((($49)) + 8|0);
         $52 = HEAP32[$51>>2]|0;HEAP32[$51>>2] = (($52+1)|0);
         $$pre$i18 = HEAP32[$5>>2]|0;
         $54 = $$pre$i18;
        }
        $53 = ((($54)) + 4|0);
        HEAP32[$5>>2] = $53;
       }
       $57 = HEAP32[$1>>2]|0;
       $58 = ($57|0)==(0|0);
       if (!($58)) {
        $59 = ((($57)) + 8|0);
        $60 = HEAP32[$59>>2]|0;HEAP32[$59>>2] = (($60-1)|0);
        $61 = ($60|0)==(1);
        if ($61) {
         __ZNK3osg10Referenced24signalObserversAndDeleteEbb($57,1,1);
        }
       }
      }
     }
    }
    $71 = ((($72)) + 4|0);
    $$sroa$032$0 = HEAP32[$71>>2]|0;
    $73 = $$sroa$032$0;
    $74 = ($73|0)==($22|0);
    if ($74) {
     break L10;
    } else {
     $$sroa$032$046 = $$sroa$032$0;$72 = $73;
    }
   }
   $62 = ___cxa_find_matching_catch_2()|0;
   $63 = tempRet0;
   $64 = HEAP32[$1>>2]|0;
   $65 = ($64|0)==(0|0);
   if (!($65)) {
    $66 = ((($64)) + 8|0);
    $67 = HEAP32[$66>>2]|0;HEAP32[$66>>2] = (($67-1)|0);
    $68 = ($67|0)==(1);
    if ($68) {
     __THREW__ = 0;
     invoke_viii(3262,($64|0),1,1);
     $69 = __THREW__; __THREW__ = 0;
     $70 = $69&1;
     if ($70) {
      $119 = ___cxa_find_matching_catch_3(0|0)|0;
      $120 = tempRet0;
      ___clang_call_terminate($119);
      // unreachable;
     }
    }
   }
   $$0 = $62;$$011 = $63;
   ___resumeException($$0|0);
   // unreachable;
  }
 } while(0);
 $26 = ((($0)) + 120|0);
 $$sroa$024$042 = HEAP32[$26>>2]|0;
 $27 = ((($0)) + 116|0);
 $28 = $$sroa$024$042;
 $29 = ($28|0)==($27|0);
 if ($29) {
  STACKTOP = sp;return;
 }
 $30 = ((($0)) + 136|0);
 $$sroa$024$043 = $$sroa$024$042;$116 = $28;
 while(1) {
  $75 = $$sroa$024$043;
  $76 = ((($75)) + 12|0);
  $77 = HEAP32[$76>>2]|0;
  __ZN7osgUtil11RenderStage35collateReferencesToDependentCamerasEv($77);
  $78 = HEAP32[$76>>2]|0;
  $79 = ((($78)) + 228|0);
  $80 = HEAP32[$79>>2]|0;
  $81 = ($80|0)==(0|0);
  if (!($81)) {
   $82 = ((($80)) + 24|0);
   $83 = HEAP32[$82>>2]|0;
   $84 = ($83|0)==(0|0);
   if (!($84)) {
    $85 = ((($78)) + 232|0);
    $86 = HEAP32[$85>>2]|0;
    $87 = ($86|0)==(0|0);
    if (!($87)) {
     HEAP32[$2>>2] = $86;
     $88 = ((($86)) + 8|0);
     $89 = HEAP32[$88>>2]|0;HEAP32[$88>>2] = (($89+1)|0);
     $90 = HEAP32[$5>>2]|0;
     $91 = HEAP32[$30>>2]|0;
     $92 = ($90|0)==($91|0);
     if ($92) {
      __THREW__ = 0;
      invoke_vii(3692,($3|0),($2|0));
      $99 = __THREW__; __THREW__ = 0;
      $100 = $99&1;
      if ($100) {
       break;
      }
     } else {
      $93 = HEAP32[$2>>2]|0;
      HEAP32[$90>>2] = $93;
      $94 = ($93|0)==(0|0);
      if ($94) {
       $98 = $90;
      } else {
       $95 = ((($93)) + 8|0);
       $96 = HEAP32[$95>>2]|0;HEAP32[$95>>2] = (($96+1)|0);
       $$pre$i = HEAP32[$5>>2]|0;
       $98 = $$pre$i;
      }
      $97 = ((($98)) + 4|0);
      HEAP32[$5>>2] = $97;
     }
     $101 = HEAP32[$2>>2]|0;
     $102 = ($101|0)==(0|0);
     if (!($102)) {
      $103 = ((($101)) + 8|0);
      $104 = HEAP32[$103>>2]|0;HEAP32[$103>>2] = (($104-1)|0);
      $105 = ($104|0)==(1);
      if ($105) {
       __ZNK3osg10Referenced24signalObserversAndDeleteEbb($101,1,1);
      }
     }
    }
   }
  }
  $115 = ((($116)) + 4|0);
  $$sroa$024$0 = HEAP32[$115>>2]|0;
  $117 = $$sroa$024$0;
  $118 = ($117|0)==($27|0);
  if ($118) {
   label = 28;
   break;
  } else {
   $$sroa$024$043 = $$sroa$024$0;$116 = $117;
  }
 }
 if ((label|0) == 28) {
  STACKTOP = sp;return;
 }
 $106 = ___cxa_find_matching_catch_2()|0;
 $107 = tempRet0;
 $108 = HEAP32[$2>>2]|0;
 $109 = ($108|0)==(0|0);
 if (!($109)) {
  $110 = ((($108)) + 8|0);
  $111 = HEAP32[$110>>2]|0;HEAP32[$110>>2] = (($111-1)|0);
  $112 = ($111|0)==(1);
  if ($112) {
   __THREW__ = 0;
   invoke_viii(3262,($108|0),1,1);
   $113 = __THREW__; __THREW__ = 0;
   $114 = $113&1;
   if ($114) {
    $119 = ___cxa_find_matching_catch_3(0|0)|0;
    $120 = tempRet0;
    ___clang_call_terminate($119);
    // unreachable;
   }
  }
 }
 $$0 = $106;$$011 = $107;
 ___resumeException($$0|0);
 // unreachable;
}
function __ZNSt3__26vectorIN3osg7ref_ptrINS1_6CameraEEENS_9allocatorIS4_EEE21__push_back_slow_pathIKS4_EEvRT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$06$i$i = 0, $$pre = 0, $$pre$i = 0, $$pre38 = 0, $$pre39 = 0, $$sroa$7$0 = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(1073741823);
 $9 = $4;
 $10 = $3;
 if ($8) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $11 = ((($0)) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) - ($4))|0;
 $14 = $13 >> 2;
 $15 = ($14>>>0)<(536870911);
 $16 = $13 >> 1;
 $17 = ($16>>>0)<($7>>>0);
 $$sroa$speculated$i = $17 ? $7 : $16;
 $$sroa$speculated$$i = $15 ? $$sroa$speculated$i : 1073741823;
 $18 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($18) {
   $28 = 0;
  } else {
   $19 = ($$sroa$speculated$$i>>>0)>(1073741823);
   if (!($19)) {
    $25 = $$sroa$speculated$$i << 2;
    $26 = (__Znwj($25)|0);
    $28 = $26;
    break;
   }
   $20 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($20|0),(204840|0));
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if ($22) {
    $23 = ___cxa_find_matching_catch_2()|0;
    $24 = tempRet0;
    ___cxa_free_exception(($20|0));
    ___resumeException($23|0);
    // unreachable;
   } else {
    HEAP32[$20>>2] = (99824);
    ___cxa_throw(($20|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $27 = (($28) + ($6<<2)|0);
 $29 = $27;
 $30 = (($28) + ($$sroa$speculated$$i<<2)|0);
 $31 = $30;
 $32 = HEAP32[$1>>2]|0;
 HEAP32[$27>>2] = $32;
 $33 = ($32|0)==(0|0);
 if ($33) {
  $38 = $10;$40 = $9;
 } else {
  $34 = ((($32)) + 8|0);
  $35 = HEAP32[$34>>2]|0;HEAP32[$34>>2] = (($35+1)|0);
  $$pre = HEAP32[$0>>2]|0;
  $$pre38 = HEAP32[$2>>2]|0;
  $38 = $$pre38;$40 = $$pre;
 }
 $36 = ((($27)) + 4|0);
 $37 = $36;
 $39 = ($38|0)==($40|0);
 if ($39) {
  $41 = $38;
  $53 = $29;$54 = $41;$56 = $38;
 } else {
  $$06$i$i = $38;$$sroa$7$0 = $29;$44 = $27;
  while(1) {
   $42 = ((($$06$i$i)) + -4|0);
   $43 = ((($44)) + -4|0);
   $45 = HEAP32[$42>>2]|0;
   HEAP32[$43>>2] = $45;
   $46 = ($45|0)==(0|0);
   if (!($46)) {
    $47 = ((($45)) + 8|0);
    $48 = HEAP32[$47>>2]|0;HEAP32[$47>>2] = (($48+1)|0);
   }
   $49 = $$sroa$7$0;
   $50 = ((($49)) + -4|0);
   $51 = $50;
   $52 = ($42|0)==($40|0);
   if ($52) {
    break;
   } else {
    $$06$i$i = $42;$$sroa$7$0 = $51;$44 = $50;
   }
  }
  $$pre$i = HEAP32[$0>>2]|0;
  $$pre39 = HEAP32[$2>>2]|0;
  $53 = $51;$54 = $$pre$i;$56 = $$pre39;
 }
 HEAP32[$0>>2] = $53;
 HEAP32[$2>>2] = $37;
 HEAP32[$11>>2] = $31;
 $55 = $54;
 $57 = ($56|0)==($55|0);
 L25: do {
  if (!($57)) {
   $59 = $56;
   while(1) {
    $58 = ((($59)) + -4|0);
    $60 = HEAP32[$58>>2]|0;
    $61 = ($60|0)==(0|0);
    if (!($61)) {
     $62 = ((($60)) + 8|0);
     $63 = HEAP32[$62>>2]|0;HEAP32[$62>>2] = (($63-1)|0);
     $64 = ($63|0)==(1);
     if ($64) {
      __THREW__ = 0;
      invoke_viii(3262,($60|0),1,1);
      $65 = __THREW__; __THREW__ = 0;
      $66 = $65&1;
      if ($66) {
       break;
      }
     }
    }
    HEAP32[$58>>2] = 0;
    $67 = ($58|0)==($55|0);
    if ($67) {
     break L25;
    } else {
     $59 = $58;
    }
   }
   $68 = ___cxa_find_matching_catch_2()|0;
   $69 = tempRet0;
   ___cxa_call_unexpected(($68|0));
   // unreachable;
  }
 } while(0);
 $70 = ($54|0)==(0);
 if ($70) {
  return;
 }
 $71 = $54;
 __ZdlPv($71);
 return;
}
function __ZN7osgUtil11RenderStage33clearReferencesToDependentCamerasEv($0) {
 $0 = $0|0;
 var $$sroa$02$0 = 0, $$sroa$02$013 = 0, $$sroa$02$014 = 0, $$sroa$08$0 = 0, $$sroa$08$016 = 0, $$sroa$08$017 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 108|0);
 $$sroa$08$016 = HEAP32[$1>>2]|0;
 $2 = ((($0)) + 104|0);
 $3 = $$sroa$08$016;
 $4 = ($3|0)==($2|0);
 if (!($4)) {
  $$sroa$08$017 = $$sroa$08$016;$13 = $3;
  while(1) {
   $9 = $$sroa$08$017;
   $10 = ((($9)) + 12|0);
   $11 = HEAP32[$10>>2]|0;
   __ZN7osgUtil11RenderStage33clearReferencesToDependentCamerasEv($11);
   $12 = ((($13)) + 4|0);
   $$sroa$08$0 = HEAP32[$12>>2]|0;
   $14 = $$sroa$08$0;
   $15 = ($14|0)==($2|0);
   if ($15) {
    break;
   } else {
    $$sroa$08$017 = $$sroa$08$0;$13 = $14;
   }
  }
 }
 $5 = ((($0)) + 120|0);
 $$sroa$02$013 = HEAP32[$5>>2]|0;
 $6 = ((($0)) + 116|0);
 $7 = $$sroa$02$013;
 $8 = ($7|0)==($6|0);
 if (!($8)) {
  $$sroa$02$014 = $$sroa$02$013;$38 = $7;
  while(1) {
   $34 = $$sroa$02$014;
   $35 = ((($34)) + 12|0);
   $36 = HEAP32[$35>>2]|0;
   __ZN7osgUtil11RenderStage33clearReferencesToDependentCamerasEv($36);
   $37 = ((($38)) + 4|0);
   $$sroa$02$0 = HEAP32[$37>>2]|0;
   $39 = $$sroa$02$0;
   $40 = ($39|0)==($6|0);
   if ($40) {
    break;
   } else {
    $$sroa$02$014 = $$sroa$02$0;$38 = $39;
   }
  }
 }
 $16 = ((($0)) + 128|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ((($0)) + 132|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)==($17|0);
 if ($20) {
  return;
 } else {
  $22 = $19;
 }
 while(1) {
  $21 = ((($22)) + -4|0);
  HEAP32[$18>>2] = $21;
  $23 = HEAP32[$21>>2]|0;
  $24 = ($23|0)==(0|0);
  if (!($24)) {
   $25 = ((($23)) + 8|0);
   $26 = HEAP32[$25>>2]|0;HEAP32[$25>>2] = (($26-1)|0);
   $27 = ($26|0)==(1);
   if ($27) {
    __THREW__ = 0;
    invoke_viii(3262,($23|0),1,1);
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if ($29) {
     label = 9;
     break;
    }
   }
  }
  HEAP32[$21>>2] = 0;
  $30 = HEAP32[$18>>2]|0;
  $31 = ($30|0)==($17|0);
  if ($31) {
   label = 10;
   break;
  } else {
   $22 = $30;
  }
 }
 if ((label|0) == 9) {
  $32 = ___cxa_find_matching_catch_2()|0;
  $33 = tempRet0;
  ___cxa_call_unexpected(($32|0));
  // unreachable;
 }
 else if ((label|0) == 10) {
  return;
 }
}
function __GLOBAL__sub_I_ApplicationUsage_cpp() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN3osg16ApplicationUsage8instanceEv()|0);
 return;
}
function __ZN3osg16ApplicationUsage8instanceEv() {
 var $$0 = 0, $$01 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $0 = HEAP8[206016]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  $27 = HEAP32[52016]|0;
  return ($27|0);
 }
 $2 = (___cxa_guard_acquire(206016)|0);
 $3 = ($2|0)==(0);
 if ($3) {
  $27 = HEAP32[52016]|0;
  return ($27|0);
 }
 __THREW__ = 0;
 $4 = (invoke_ii(3276,108)|0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $28 = ___cxa_find_matching_catch_2()|0;
  $29 = tempRet0;
  $$0 = $29;$$01 = $28;
  ___resumeException($$01|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_vi(3282,($4|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $30 = ___cxa_find_matching_catch_2()|0;
  $31 = tempRet0;
  __ZdlPv($4);
  $$0 = $31;$$01 = $30;
  ___resumeException($$01|0);
  // unreachable;
 } else {
  HEAP32[$4>>2] = (54480);
  $9 = ((($4)) + 12|0);
  $10 = ((($4)) + 52|0);
  HEAP32[$10>>2] = 0;
  $11 = ((($4)) + 56|0);
  HEAP32[$11>>2] = 0;
  $12 = ((($4)) + 48|0);
  dest=$9; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
  HEAP32[$12>>2] = $10;
  $13 = ((($4)) + 64|0);
  HEAP32[$13>>2] = 0;
  $14 = ((($4)) + 68|0);
  HEAP32[$14>>2] = 0;
  $15 = ((($4)) + 60|0);
  HEAP32[$15>>2] = $13;
  $16 = ((($4)) + 76|0);
  HEAP32[$16>>2] = 0;
  $17 = ((($4)) + 80|0);
  HEAP32[$17>>2] = 0;
  $18 = ((($4)) + 72|0);
  HEAP32[$18>>2] = $16;
  $19 = ((($4)) + 88|0);
  HEAP32[$19>>2] = 0;
  $20 = ((($4)) + 92|0);
  HEAP32[$20>>2] = 0;
  $21 = ((($4)) + 84|0);
  HEAP32[$21>>2] = $19;
  $22 = ((($4)) + 100|0);
  HEAP32[$22>>2] = 0;
  $23 = ((($4)) + 104|0);
  HEAP32[$23>>2] = 0;
  $24 = ((($4)) + 96|0);
  HEAP32[$24>>2] = $22;
  HEAP32[52016] = $4;
  $25 = ((($4)) + 8|0);
  $26 = HEAP32[$25>>2]|0;HEAP32[$25>>2] = (($26+1)|0);
  (___cxa_atexit((3693|0),(208064|0),(___dso_handle|0))|0);
  $27 = HEAP32[52016]|0;
  return ($27|0);
 }
 return (0)|0;
}
function __ZN3osg7ref_ptrINS_16ApplicationUsageEED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = ((($1)) + 8|0);
  $4 = HEAP32[$3>>2]|0;HEAP32[$3>>2] = (($4-1)|0);
  $5 = ($4|0)==(1);
  if ($5) {
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($1,1,1);
  }
 }
 HEAP32[$0>>2] = 0;
 return;
}
function __ZN3osg16ApplicationUsageD2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (54480);
 $1 = ((($0)) + 96|0);
 $2 = ((($0)) + 100|0);
 $3 = HEAP32[$2>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES7_EENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($1,$3);
 $4 = ((($0)) + 84|0);
 $5 = ((($0)) + 88|0);
 $6 = HEAP32[$5>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES7_EENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($4,$6);
 $7 = ((($0)) + 72|0);
 $8 = ((($0)) + 76|0);
 $9 = HEAP32[$8>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES7_EENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($7,$9);
 $10 = ((($0)) + 60|0);
 $11 = ((($0)) + 64|0);
 $12 = HEAP32[$11>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES7_EENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($10,$12);
 $13 = ((($0)) + 48|0);
 $14 = ((($0)) + 52|0);
 $15 = HEAP32[$14>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES7_EENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($13,$15);
 $16 = ((($0)) + 36|0);
 $17 = ((($16)) + 11|0);
 $18 = HEAP8[$17>>0]|0;
 $19 = ($18<<24>>24)<(0);
 if ($19) {
  $20 = HEAP32[$16>>2]|0;
  __ZdlPv($20);
 }
 $21 = ((($0)) + 24|0);
 $22 = ((($21)) + 11|0);
 $23 = HEAP8[$22>>0]|0;
 $24 = ($23<<24>>24)<(0);
 if ($24) {
  $25 = HEAP32[$21>>2]|0;
  __ZdlPv($25);
 }
 $26 = ((($0)) + 12|0);
 $27 = ((($26)) + 11|0);
 $28 = HEAP8[$27>>0]|0;
 $29 = ($28<<24>>24)<(0);
 if (!($29)) {
  __ZN3osg10ReferencedD2Ev($0);
  return;
 }
 $30 = HEAP32[$26>>2]|0;
 __ZdlPv($30);
 __ZN3osg10ReferencedD2Ev($0);
 return;
}
function __ZN3osg16ApplicationUsageD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1431,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZN3osg16ApplicationUsage19addUsageExplanationENS0_4TypeERKNSt3__212basic_stringIcNS2_11char_traitsIcEENS2_9allocatorIcEEEESA_($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $$07 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $4 = sp + 12|0;
 $5 = sp;
 switch ($1|0) {
 case 1:  {
  $6 = ((($4)) + 11|0);
  $7 = ((($0)) + 48|0);
  ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;
  __THREW__ = 0;
  $8 = (invoke_iii(3694,($7|0),($2|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __THREW__ = 0;
   (invoke_iii(3477,($8|0),($3|0))|0);
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if (!($12)) {
    $13 = ((($0)) + 96|0);
    __THREW__ = 0;
    $14 = (invoke_iii(3694,($13|0),($2|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     __THREW__ = 0;
     (invoke_iii(3477,($14|0),($4|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if (!($18)) {
      $19 = HEAP8[$6>>0]|0;
      $20 = ($19<<24>>24)<(0);
      if ($20) {
       $21 = HEAP32[$4>>2]|0;
       __ZdlPv($21);
      }
      STACKTOP = sp;return;
     }
    }
   }
  }
  $22 = ___cxa_find_matching_catch_2()|0;
  $23 = tempRet0;
  $24 = HEAP8[$6>>0]|0;
  $25 = ($24<<24>>24)<(0);
  if ($25) {
   $26 = HEAP32[$4>>2]|0;
   __ZdlPv($26);
  }
  $$0 = $23;$$07 = $22;
  ___resumeException($$07|0);
  // unreachable;
  break;
 }
 case 2:  {
  $27 = ((($5)) + 11|0);
  $28 = ((($0)) + 60|0);
  ;HEAP32[$5>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;
  __THREW__ = 0;
  $29 = (invoke_iii(3694,($28|0),($2|0))|0);
  $30 = __THREW__; __THREW__ = 0;
  $31 = $30&1;
  if (!($31)) {
   __THREW__ = 0;
   (invoke_iii(3477,($29|0),($3|0))|0);
   $32 = __THREW__; __THREW__ = 0;
   $33 = $32&1;
   if (!($33)) {
    $34 = ((($0)) + 84|0);
    __THREW__ = 0;
    $35 = (invoke_iii(3694,($34|0),($2|0))|0);
    $36 = __THREW__; __THREW__ = 0;
    $37 = $36&1;
    if (!($37)) {
     __THREW__ = 0;
     (invoke_iii(3477,($35|0),($5|0))|0);
     $38 = __THREW__; __THREW__ = 0;
     $39 = $38&1;
     if (!($39)) {
      $40 = HEAP8[$27>>0]|0;
      $41 = ($40<<24>>24)<(0);
      if ($41) {
       $42 = HEAP32[$5>>2]|0;
       __ZdlPv($42);
      }
      STACKTOP = sp;return;
     }
    }
   }
  }
  $43 = ___cxa_find_matching_catch_2()|0;
  $44 = tempRet0;
  $45 = HEAP8[$27>>0]|0;
  $46 = ($45<<24>>24)<(0);
  if ($46) {
   $47 = HEAP32[$5>>2]|0;
   __ZdlPv($47);
  }
  $$0 = $44;$$07 = $43;
  ___resumeException($$07|0);
  // unreachable;
  break;
 }
 default: {
  STACKTOP = sp;return;
 }
 }
}
function __ZNSt3__23mapINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES6_NS_4lessIS6_EENS4_INS_4pairIKS6_S6_EEEEEixERSA_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$014 = 0, $$pre$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = (__ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES7_EENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE12__find_equalIS7_EERPNS_16__tree_node_baseIPvEERPNS_15__tree_end_nodeISJ_EERKT_($0,$2,$1)|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if (!($5)) {
  $$014 = $4;
  $26 = ((($$014)) + 28|0);
  STACKTOP = sp;return ($26|0);
 }
 $6 = (__Znwj(40)|0);
 $7 = ((($6)) + 16|0);
 __THREW__ = 0;
 invoke_vii(3457,($7|0),($1|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $10 = ___cxa_find_matching_catch_2()|0;
  $11 = tempRet0;
  __ZdlPv($6);
  ___resumeException($10|0);
  // unreachable;
 }
 $12 = ((($6)) + 28|0);
 ;HEAP32[$12>>2]=0|0;HEAP32[$12+4>>2]=0|0;HEAP32[$12+8>>2]=0|0;
 $13 = HEAP32[$2>>2]|0;
 HEAP32[$6>>2] = 0;
 $14 = ((($6)) + 4|0);
 HEAP32[$14>>2] = 0;
 $15 = ((($6)) + 8|0);
 HEAP32[$15>>2] = $13;
 HEAP32[$3>>2] = $6;
 $16 = HEAP32[$0>>2]|0;
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==(0|0);
 if ($18) {
  $22 = $6;
 } else {
  $19 = $17;
  HEAP32[$0>>2] = $19;
  $$pre$i = HEAP32[$3>>2]|0;
  $22 = $$pre$i;
 }
 $20 = ((($0)) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($21,$22);
 $23 = ((($0)) + 8|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (($24) + 1)|0;
 HEAP32[$23>>2] = $25;
 $$014 = $6;
 $26 = ((($$014)) + 28|0);
 STACKTOP = sp;return ($26|0);
}
function __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES7_EENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE12__find_equalIS7_EERPNS_16__tree_node_baseIPvEERPNS_15__tree_end_nodeISJ_EERKT_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$0$ph = 0, $$024 = 0, $$025 = 0, $$in = 0, $$sroa$speculated$i$i$i$i$i = 0, $$sroa$speculated$i$i$i$i$i26 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  HEAP32[$1>>2] = $3;
  $$025 = $3;
  return ($$025|0);
 }
 $6 = ((($0)) + 4|0);
 $7 = ((($2)) + 11|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = ($8<<24>>24)<(0);
 $10 = ((($2)) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $8&255;
 $13 = $9 ? $11 : $12;
 $14 = HEAP32[$2>>2]|0;
 $15 = $9 ? $14 : $2;
 $$0 = $6;$$024 = $4;
 while(1) {
  $16 = ((($$024)) + 16|0);
  $17 = ((($16)) + 11|0);
  $18 = HEAP8[$17>>0]|0;
  $19 = ($18<<24>>24)<(0);
  $20 = ((($$024)) + 20|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = $18&255;
  $23 = $19 ? $21 : $22;
  $24 = ($23>>>0)<($13>>>0);
  $$sroa$speculated$i$i$i$i$i26 = $24 ? $23 : $13;
  $25 = ($$sroa$speculated$i$i$i$i$i26|0)==(0);
  if ($25) {
   label = 6;
  } else {
   $26 = HEAP32[$16>>2]|0;
   $27 = $19 ? $26 : $16;
   $28 = (_memcmp($15,$27,$$sroa$speculated$i$i$i$i$i26)|0);
   $29 = ($28|0)==(0);
   if ($29) {
    label = 6;
   } else {
    $31 = ($28|0)<(0);
    if ($31) {
     label = 8;
    } else {
     label = 10;
    }
   }
  }
  if ((label|0) == 6) {
   label = 0;
   $30 = ($13>>>0)<($23>>>0);
   if ($30) {
    label = 8;
   } else {
    label = 10;
   }
  }
  if ((label|0) == 8) {
   label = 0;
   $32 = HEAP32[$$024>>2]|0;
   $33 = ($32|0)==(0|0);
   if ($33) {
    label = 9;
    break;
   } else {
    $$0$ph = $$024;$$in = $32;
   }
  }
  else if ((label|0) == 10) {
   label = 0;
   $34 = ($13>>>0)<($23>>>0);
   $$sroa$speculated$i$i$i$i$i = $34 ? $13 : $23;
   $35 = ($$sroa$speculated$i$i$i$i$i|0)==(0);
   if ($35) {
    label = 12;
   } else {
    $36 = HEAP32[$16>>2]|0;
    $37 = $19 ? $36 : $16;
    $38 = (_memcmp($37,$15,$$sroa$speculated$i$i$i$i$i)|0);
    $39 = ($38|0)==(0);
    if ($39) {
     label = 12;
    } else {
     $40 = ($38|0)<(0);
     if (!($40)) {
      label = 16;
      break;
     }
    }
   }
   if ((label|0) == 12) {
    label = 0;
    if (!($24)) {
     label = 16;
     break;
    }
   }
   $41 = ((($$024)) + 4|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = ($42|0)==(0|0);
   if ($43) {
    label = 15;
    break;
   } else {
    $$0$ph = $41;$$in = $42;
   }
  }
  $$0 = $$0$ph;$$024 = $$in;
 }
 if ((label|0) == 9) {
  HEAP32[$1>>2] = $$024;
  $$025 = $$024;
  return ($$025|0);
 }
 else if ((label|0) == 15) {
  HEAP32[$1>>2] = $$024;
  $$025 = $41;
  return ($$025|0);
 }
 else if ((label|0) == 16) {
  HEAP32[$1>>2] = $$024;
  $$025 = $$0;
  return ($$025|0);
 }
 return (0)|0;
}
function __ZN3osg16ApplicationUsage23addKeyboardMouseBindingERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEES9_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 72|0);
 $4 = (__ZNSt3__23mapINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES6_NS_4lessIS6_EENS4_INS_4pairIKS6_S6_EEEEEixERSA_($3,$1)|0);
 (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEaSERKS5_($4,$2)|0);
 return;
}
function __ZNSt3__2plIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_12basic_stringIT_T0_T1_EEPKS6_RKS9_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 ;HEAP32[$0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;
 $3 = (_strlen($1)|0);
 $4 = ((($2)) + 11|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)<(0);
 $7 = ((($2)) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $5&255;
 $10 = $6 ? $8 : $9;
 $11 = (($10) + ($3))|0;
 $12 = ($11>>>0)>(4294967279);
 do {
  if ($12) {
   __THREW__ = 0;
   invoke_vi(3367,($0|0));
   $13 = __THREW__; __THREW__ = 0;
  } else {
   $14 = ($11>>>0)<(11);
   if ($14) {
    $15 = $3&255;
    $16 = ((($0)) + 11|0);
    HEAP8[$16>>0] = $15;
    $$0$i = $0;
   } else {
    $17 = (($11) + 16)|0;
    $18 = $17 & -16;
    __THREW__ = 0;
    $19 = (invoke_ii(3276,($18|0))|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     break;
    }
    HEAP32[$0>>2] = $19;
    $22 = $18 | -2147483648;
    $23 = ((($0)) + 8|0);
    HEAP32[$23>>2] = $22;
    $24 = ((($0)) + 4|0);
    HEAP32[$24>>2] = $3;
    $$0$i = $19;
   }
   $25 = ($3|0)==(0);
   if (!($25)) {
    _memcpy(($$0$i|0),($1|0),($3|0))|0;
   }
   $26 = (($$0$i) + ($3)|0);
   HEAP8[$26>>0] = 0;
   $27 = HEAP32[$2>>2]|0;
   $28 = $6 ? $27 : $2;
   __THREW__ = 0;
   (invoke_iiii(3544,($0|0),($28|0),($10|0))|0);
   $29 = __THREW__; __THREW__ = 0;
   $30 = $29&1;
   if (!($30)) {
    return;
   }
  }
 } while(0);
 $31 = ___cxa_find_matching_catch_2()|0;
 $32 = tempRet0;
 $33 = ((($0)) + 11|0);
 $34 = HEAP8[$33>>0]|0;
 $35 = ($34<<24>>24)<(0);
 if (!($35)) {
  ___resumeException($31|0);
  // unreachable;
 }
 $36 = HEAP32[$0>>2]|0;
 __ZdlPv($36);
 ___resumeException($31|0);
 // unreachable;
}
function __ZNSt3__26__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EENS4_IS6_EEE12__find_equalIS6_EERPNS_16__tree_node_baseIPvEERPNS_15__tree_end_nodeISF_EERKT_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$0$ph = 0, $$024 = 0, $$025 = 0, $$in = 0, $$sroa$speculated$i$i$i$i = 0, $$sroa$speculated$i$i$i$i26 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  HEAP32[$1>>2] = $3;
  $$025 = $3;
  return ($$025|0);
 }
 $6 = ((($0)) + 4|0);
 $7 = ((($2)) + 11|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = ($8<<24>>24)<(0);
 $10 = ((($2)) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $8&255;
 $13 = $9 ? $11 : $12;
 $14 = HEAP32[$2>>2]|0;
 $15 = $9 ? $14 : $2;
 $$0 = $6;$$024 = $4;
 while(1) {
  $16 = ((($$024)) + 16|0);
  $17 = ((($16)) + 11|0);
  $18 = HEAP8[$17>>0]|0;
  $19 = ($18<<24>>24)<(0);
  $20 = ((($$024)) + 20|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = $18&255;
  $23 = $19 ? $21 : $22;
  $24 = ($23>>>0)<($13>>>0);
  $$sroa$speculated$i$i$i$i26 = $24 ? $23 : $13;
  $25 = ($$sroa$speculated$i$i$i$i26|0)==(0);
  if ($25) {
   label = 6;
  } else {
   $26 = HEAP32[$16>>2]|0;
   $27 = $19 ? $26 : $16;
   $28 = (_memcmp($15,$27,$$sroa$speculated$i$i$i$i26)|0);
   $29 = ($28|0)==(0);
   if ($29) {
    label = 6;
   } else {
    $31 = ($28|0)<(0);
    if ($31) {
     label = 8;
    } else {
     label = 10;
    }
   }
  }
  if ((label|0) == 6) {
   label = 0;
   $30 = ($13>>>0)<($23>>>0);
   if ($30) {
    label = 8;
   } else {
    label = 10;
   }
  }
  if ((label|0) == 8) {
   label = 0;
   $32 = HEAP32[$$024>>2]|0;
   $33 = ($32|0)==(0|0);
   if ($33) {
    label = 9;
    break;
   } else {
    $$0$ph = $$024;$$in = $32;
   }
  }
  else if ((label|0) == 10) {
   label = 0;
   $34 = ($13>>>0)<($23>>>0);
   $$sroa$speculated$i$i$i$i = $34 ? $13 : $23;
   $35 = ($$sroa$speculated$i$i$i$i|0)==(0);
   if ($35) {
    label = 12;
   } else {
    $36 = HEAP32[$16>>2]|0;
    $37 = $19 ? $36 : $16;
    $38 = (_memcmp($37,$15,$$sroa$speculated$i$i$i$i)|0);
    $39 = ($38|0)==(0);
    if ($39) {
     label = 12;
    } else {
     $40 = ($38|0)<(0);
     if (!($40)) {
      label = 16;
      break;
     }
    }
   }
   if ((label|0) == 12) {
    label = 0;
    if (!($24)) {
     label = 16;
     break;
    }
   }
   $41 = ((($$024)) + 4|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = ($42|0)==(0|0);
   if ($43) {
    label = 15;
    break;
   } else {
    $$0$ph = $41;$$in = $42;
   }
  }
  $$0 = $$0$ph;$$024 = $$in;
 }
 if ((label|0) == 9) {
  HEAP32[$1>>2] = $$024;
  $$025 = $$024;
  return ($$025|0);
 }
 else if ((label|0) == 15) {
  HEAP32[$1>>2] = $$024;
  $$025 = $41;
  return ($$025|0);
 }
 else if ((label|0) == 16) {
  HEAP32[$1>>2] = $$024;
  $$025 = $$0;
  return ($$025|0);
 }
 return (0)|0;
}
function __ZNSt3__26__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EENS4_IS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 }
 $3 = HEAP32[$1>>2]|0;
 __ZNSt3__26__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EENS4_IS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($0,$3);
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 __ZNSt3__26__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EENS4_IS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($0,$5);
 $6 = ((($1)) + 16|0);
 $7 = ((($6)) + 11|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = ($8<<24>>24)<(0);
 if ($9) {
  $10 = HEAP32[$6>>2]|0;
  __ZdlPv($10);
 }
 __ZdlPv($1);
 return;
}
function __ZNSt3__26__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EENS4_IS6_EEE4findIS6_EENS_15__tree_iteratorIS6_PNS_11__tree_nodeIS6_PvEEiEERKT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$ph$lcssa$i = 0, $$0$ph15$i = 0, $$07$ph14$i = 0, $$0711$i = 0, $$sroa$0$0 = 0, $$sroa$speculated$i$i$i$i = 0, $$sroa$speculated$i$i$i$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 do {
  if (!($4)) {
   $5 = ((($1)) + 11|0);
   $6 = HEAP8[$5>>0]|0;
   $7 = ($6<<24>>24)<(0);
   $8 = ((($1)) + 4|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = $6&255;
   $11 = $7 ? $9 : $10;
   $12 = HEAP32[$1>>2]|0;
   $13 = $7 ? $12 : $1;
   $$0$ph15$i = $2;$$07$ph14$i = $3;
   L3: while(1) {
    $$0711$i = $$07$ph14$i;
    while(1) {
     $14 = ((($$0711$i)) + 16|0);
     $15 = ((($14)) + 11|0);
     $16 = HEAP8[$15>>0]|0;
     $17 = ($16<<24>>24)<(0);
     $18 = ((($$0711$i)) + 20|0);
     $19 = HEAP32[$18>>2]|0;
     $20 = $16&255;
     $21 = $17 ? $19 : $20;
     $22 = ($11>>>0)<($21>>>0);
     $$sroa$speculated$i$i$i$i$i = $22 ? $11 : $21;
     $23 = ($$sroa$speculated$i$i$i$i$i|0)==(0);
     if ($23) {
      label = 6;
     } else {
      $24 = HEAP32[$14>>2]|0;
      $25 = $17 ? $24 : $14;
      $26 = (_memcmp($25,$13,$$sroa$speculated$i$i$i$i$i)|0);
      $27 = ($26|0)==(0);
      if ($27) {
       label = 6;
      } else {
       $29 = ($26|0)<(0);
       if (!($29)) {
        break;
       }
      }
     }
     if ((label|0) == 6) {
      label = 0;
      $28 = ($21>>>0)<($11>>>0);
      if (!($28)) {
       break;
      }
     }
     $32 = ((($$0711$i)) + 4|0);
     $33 = HEAP32[$32>>2]|0;
     $34 = ($33|0)==(0|0);
     if ($34) {
      $$0$ph$lcssa$i = $$0$ph15$i;
      break L3;
     } else {
      $$0711$i = $33;
     }
    }
    $30 = HEAP32[$$0711$i>>2]|0;
    $31 = ($30|0)==(0|0);
    if ($31) {
     $$0$ph$lcssa$i = $$0711$i;
     break;
    } else {
     $$0$ph15$i = $$0711$i;$$07$ph14$i = $30;
    }
   }
   $35 = ($$0$ph$lcssa$i|0)==($2|0);
   if (!($35)) {
    $36 = ((($$0$ph$lcssa$i)) + 16|0);
    $37 = ((($36)) + 11|0);
    $38 = HEAP8[$37>>0]|0;
    $39 = ($38<<24>>24)<(0);
    $40 = ((($$0$ph$lcssa$i)) + 20|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = $38&255;
    $43 = $39 ? $41 : $42;
    $44 = ($43>>>0)<($11>>>0);
    $$sroa$speculated$i$i$i$i = $44 ? $43 : $11;
    $45 = ($$sroa$speculated$i$i$i$i|0)==(0);
    if (!($45)) {
     $46 = HEAP32[$36>>2]|0;
     $47 = $39 ? $46 : $36;
     $48 = (_memcmp($13,$47,$$sroa$speculated$i$i$i$i)|0);
     $49 = ($48|0)==(0);
     if (!($49)) {
      $51 = ($48|0)<(0);
      if ($51) {
       break;
      } else {
       $$sroa$0$0 = $$0$ph$lcssa$i;
      }
      return ($$sroa$0$0|0);
     }
    }
    $50 = ($11>>>0)<($43>>>0);
    if (!($50)) {
     $$sroa$0$0 = $$0$ph$lcssa$i;
     return ($$sroa$0$0|0);
    }
   }
  }
 } while(0);
 $$sroa$0$0 = $2;
 return ($$sroa$0$0|0);
}
function __ZN3osg5ArrayD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1265,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK3osg5Array9classNameEv($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $2 = ((($0)) + 52|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3>>>0)<(38);
 if ($4) {
  $5 = (54716 + ($3<<2)|0);
  $6 = HEAP32[$5>>2]|0;
  $$0 = $6;
  STACKTOP = sp;return ($$0|0);
 }
 $7 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(5)|0);
 if (!($7)) {
  $$0 = 118699;
  STACKTOP = sp;return ($$0|0);
 }
 $8 = (__ZN3osg6notifyENS_14NotifySeverityE(5)|0);
 $9 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($8,118659,39)|0);
 $10 = HEAP32[$2>>2]|0;
 $11 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi($9,$10)|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ((($12)) + -12|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($11) + ($14)|0);
 __ZNKSt3__28ios_base6getlocEv($1,$15);
 __THREW__ = 0;
 $16 = (invoke_iii(3255,($1|0),(215188|0))|0);
 $17 = __THREW__; __THREW__ = 0;
 $18 = $17&1;
 if (!($18)) {
  $19 = HEAP32[$16>>2]|0;
  $20 = ((($19)) + 28|0);
  $21 = HEAP32[$20>>2]|0;
  __THREW__ = 0;
  $22 = (invoke_iii($21|0,($16|0),10)|0);
  $23 = __THREW__; __THREW__ = 0;
  $24 = $23&1;
  if (!($24)) {
   __ZNSt3__26localeD2Ev($1);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($11,$22)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($11)|0);
   $$0 = 118699;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $25 = ___cxa_find_matching_catch_2()|0;
 $26 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($1|0));
 $27 = __THREW__; __THREW__ = 0;
 $28 = $27&1;
 if ($28) {
  $29 = ___cxa_find_matching_catch_3(0|0)|0;
  $30 = tempRet0;
  ___clang_call_terminate($29);
  // unreachable;
 } else {
  ___resumeException($25|0);
  // unreachable;
 }
 return (0)|0;
}
function __ZN3osg4Node6asNodeEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ($0|0);
}
function __ZNK3osg4Node6asNodeEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ($0|0);
}
function __ZN3osg4Node10asDrawableEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZNK3osg4Node10asDrawableEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZN3osg4Node10asGeometryEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZNK3osg4Node10asGeometryEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZN3osg5Group7asGroupEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ($0|0);
}
function __ZNK3osg5Group7asGroupEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ($0|0);
}
function __ZN3osg4Node11asTransformEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZNK3osg4Node11asTransformEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZN3osg4Node8asSwitchEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZNK3osg4Node8asSwitchEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZN3osg5Geode7asGeodeEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ($0|0);
}
function __ZNK3osg5Geode7asGeodeEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ($0|0);
}
function __ZN3osg4Node9asTerrainEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZNK3osg4Node9asTerrainEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZN3osg5Group12childRemovedEjj($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN3osg5Group13childInsertedEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZNSt3__26vectorIPN3osg4NodeENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(1073741823);
 if ($8) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $9 = ((($0)) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) - ($4))|0;
 $12 = $11 >> 2;
 $13 = ($12>>>0)<(536870911);
 $14 = $11 >> 1;
 $15 = ($14>>>0)<($7>>>0);
 $$sroa$speculated$i = $15 ? $7 : $14;
 $$sroa$speculated$$i = $13 ? $$sroa$speculated$i : 1073741823;
 $16 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($16) {
   $26 = 0;
  } else {
   $17 = ($$sroa$speculated$$i>>>0)>(1073741823);
   if (!($17)) {
    $23 = $$sroa$speculated$$i << 2;
    $24 = (__Znwj($23)|0);
    $26 = $24;
    break;
   }
   $18 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($18|0),(204840|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if ($20) {
    $21 = ___cxa_find_matching_catch_2()|0;
    $22 = tempRet0;
    ___cxa_free_exception(($18|0));
    ___resumeException($21|0);
    // unreachable;
   } else {
    HEAP32[$18>>2] = (99824);
    ___cxa_throw(($18|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $25 = (($26) + ($6<<2)|0);
 $27 = (($26) + ($$sroa$speculated$$i<<2)|0);
 $28 = $27;
 $29 = HEAP32[$1>>2]|0;
 HEAP32[$25>>2] = $29;
 $30 = ((($25)) + 4|0);
 $31 = $30;
 $32 = (0 - ($6))|0;
 $33 = (($25) + ($32<<2)|0);
 $34 = $33;
 $35 = ($5|0)>(0);
 if ($35) {
  $36 = $4;
  _memcpy(($33|0),($36|0),($5|0))|0;
 }
 HEAP32[$0>>2] = $34;
 HEAP32[$2>>2] = $31;
 HEAP32[$9>>2] = $28;
 $37 = ($4|0)==(0);
 if ($37) {
  return;
 }
 $38 = $4;
 __ZdlPv($38);
 return;
}
function __ZNSt3__26vectorIPN3osg4NodeENS_9allocatorIS3_EEE6insertENS_11__wrap_iterIPKS3_EERS8_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$ = 0, $$0 = 0, $$017$i = 0, $$025 = 0, $$idx = 0, $$in$i32 = 0, $$pre = 0, $$sroa$22$0 = 0, $$sroa$22$1 = 0, $$sroa$22$1$in = 0, $$sroa$38$0 = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $$sroa$speculated$i33 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = HEAP32[$0>>2]|0;
 $4 = $3;
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) - ($4))|0;
 $7 = $6 >> 2;
 $8 = (($3) + ($7<<2)|0);
 $9 = ((($0)) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ((($0)) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($10>>>0)<($12>>>0);
 $14 = $10;
 $15 = $12;
 if ($13) {
  $16 = ($8|0)==($10|0);
  if ($16) {
   $17 = HEAP32[$2>>2]|0;
   HEAP32[$8>>2] = $17;
   $18 = HEAP32[$9>>2]|0;
   $19 = ((($18)) + 4|0);
   HEAP32[$9>>2] = $19;
   $$0 = $8;
   return ($$0|0);
  }
  $20 = ((($8)) + 4|0);
  $21 = $20;
  $22 = (($14) - ($21))|0;
  $23 = $22 >> 2;
  $24 = (($8) + ($23<<2)|0);
  $25 = ($24>>>0)<($10>>>0);
  if ($25) {
   $$017$i = $24;$$in$i32 = $10;
   while(1) {
    $29 = HEAP32[$$017$i>>2]|0;
    HEAP32[$$in$i32>>2] = $29;
    $30 = ((($$017$i)) + 4|0);
    $31 = HEAP32[$9>>2]|0;
    $32 = ((($31)) + 4|0);
    HEAP32[$9>>2] = $32;
    $33 = ($30>>>0)<($10>>>0);
    if ($33) {
     $$017$i = $30;$$in$i32 = $32;
    } else {
     break;
    }
   }
  }
  $26 = ($23|0)==(0);
  if (!($26)) {
   $27 = (0 - ($23))|0;
   $28 = (($10) + ($27<<2)|0);
   _memmove(($28|0),($8|0),($22|0))|0;
  }
  $34 = ($8>>>0)>($2>>>0);
  if ($34) {
   $$025 = $2;
  } else {
   $35 = HEAP32[$9>>2]|0;
   $36 = ($35>>>0)>($2>>>0);
   $37 = ((($2)) + 4|0);
   $$ = $36 ? $37 : $2;
   $$025 = $$;
  }
  $38 = HEAP32[$$025>>2]|0;
  HEAP32[$8>>2] = $38;
  $$0 = $8;
  return ($$0|0);
 }
 $39 = (($14) - ($4))|0;
 $40 = $39 >> 2;
 $41 = (($40) + 1)|0;
 $42 = ($41>>>0)>(1073741823);
 if ($42) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $43 = (($15) - ($4))|0;
 $44 = $43 >> 2;
 $45 = ($44>>>0)<(536870911);
 $46 = $43 >> 1;
 $47 = ($46>>>0)<($41>>>0);
 $$sroa$speculated$i33 = $47 ? $41 : $46;
 $$sroa$speculated$$i = $45 ? $$sroa$speculated$i33 : 1073741823;
 $48 = $8;
 $49 = $6 >> 2;
 $50 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($50) {
   $60 = 0;$89 = 0;
  } else {
   $51 = ($$sroa$speculated$$i>>>0)>(1073741823);
   if (!($51)) {
    $57 = $$sroa$speculated$$i << 2;
    $58 = (__Znwj($57)|0);
    $60 = $58;$89 = $58;
    break;
   }
   $52 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($52|0),(204840|0));
   $53 = __THREW__; __THREW__ = 0;
   $54 = $53&1;
   if ($54) {
    $55 = ___cxa_find_matching_catch_2()|0;
    $56 = tempRet0;
    ___cxa_free_exception(($52|0));
    ___resumeException($55|0);
    // unreachable;
   } else {
    HEAP32[$52>>2] = (99824);
    ___cxa_throw(($52|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $59 = (($60) + ($49<<2)|0);
 $61 = $59;
 $62 = (($60) + ($$sroa$speculated$$i<<2)|0);
 $63 = $62;
 $64 = ($49|0)==($$sroa$speculated$$i|0);
 L31: do {
  if ($64) {
   $65 = ($6|0)>(0);
   if ($65) {
    $66 = (($$sroa$speculated$$i) + 1)|0;
    $67 = (($66|0) / -2)&-1;
    $68 = (($59) + ($67<<2)|0);
    $69 = $68;
    $$sroa$22$0 = $69;$$sroa$38$0 = $63;$91 = $68;$95 = $3;
    break;
   }
   $$idx = $$sroa$speculated$$i << 2;
   $70 = $$idx >> 1;
   $71 = ($70|0)==(0);
   $$sroa$speculated$i = $71 ? 1 : $70;
   $72 = ($$sroa$speculated$i>>>0)>(1073741823);
   do {
    if ($72) {
     $73 = (___cxa_allocate_exception(8)|0);
     __THREW__ = 0;
     invoke_vii(3366,($73|0),(204840|0));
     $74 = __THREW__; __THREW__ = 0;
     $75 = $74&1;
     if ($75) {
      $77 = ___cxa_find_matching_catch_2()|0;
      $78 = tempRet0;
      ___cxa_free_exception(($73|0));
      $eh$lpad$body$index2Z2D = $78;$eh$lpad$body$indexZ2D = $77;
      break;
     } else {
      HEAP32[$73>>2] = (99824);
      __THREW__ = 0;
      invoke_viii(3695,($73|0),(34608|0),(3230|0));
      $76 = __THREW__; __THREW__ = 0;
      label = 35;
      break;
     }
    } else {
     $79 = $$sroa$speculated$i << 2;
     __THREW__ = 0;
     $80 = (invoke_ii(3276,($79|0))|0);
     $81 = __THREW__; __THREW__ = 0;
     $82 = $81&1;
     if ($82) {
      label = 35;
     } else {
      $83 = $$sroa$speculated$i >>> 2;
      $84 = (($80) + ($83<<2)|0);
      $85 = $84;
      $86 = (($80) + ($$sroa$speculated$i<<2)|0);
      $87 = $86;
      $88 = ($60|0)==(0|0);
      if ($88) {
       $$sroa$22$0 = $85;$$sroa$38$0 = $87;$91 = $84;$95 = $3;
       break L31;
      }
      __ZdlPv($89);
      $$pre = HEAP32[$0>>2]|0;
      $$sroa$22$0 = $85;$$sroa$38$0 = $87;$91 = $84;$95 = $$pre;
      break L31;
     }
    }
   } while(0);
   if ((label|0) == 35) {
    $110 = ___cxa_find_matching_catch_2()|0;
    $111 = tempRet0;
    $eh$lpad$body$index2Z2D = $111;$eh$lpad$body$indexZ2D = $110;
   }
   $112 = ($60|0)==(0|0);
   if ($112) {
    ___resumeException($eh$lpad$body$indexZ2D|0);
    // unreachable;
   }
   __ZdlPv($89);
   ___resumeException($eh$lpad$body$indexZ2D|0);
   // unreachable;
  } else {
   $$sroa$22$0 = $61;$$sroa$38$0 = $63;$91 = $59;$95 = $3;
  }
 } while(0);
 $90 = HEAP32[$2>>2]|0;
 HEAP32[$91>>2] = $90;
 $92 = $$sroa$22$0;
 $93 = ((($92)) + 4|0);
 $94 = $$sroa$22$0;
 $96 = $95;
 $97 = (($48) - ($96))|0;
 $98 = $97 >> 2;
 $99 = (0 - ($98))|0;
 $100 = (($94) + ($99<<2)|0);
 $101 = $100;
 $102 = ($97|0)>(0);
 if ($102) {
  _memcpy(($100|0),($95|0),($97|0))|0;
 }
 $103 = HEAP32[$9>>2]|0;
 $104 = (($103) - ($48))|0;
 $105 = ($104|0)>(0);
 if ($105) {
  $106 = $104 >>> 2;
  $107 = (($93) + ($106<<2)|0);
  _memcpy(($93|0),($8|0),($104|0))|0;
  $$sroa$22$1$in = $107;
 } else {
  $$sroa$22$1$in = $93;
 }
 $$sroa$22$1 = $$sroa$22$1$in;
 $108 = HEAP32[$0>>2]|0;
 HEAP32[$0>>2] = $101;
 HEAP32[$9>>2] = $$sroa$22$1;
 HEAP32[$11>>2] = $$sroa$38$0;
 $109 = ($108|0)==(0|0);
 if ($109) {
  $$0 = $94;
  return ($$0|0);
 }
 __ZdlPv($108);
 $$0 = $94;
 return ($$0|0);
}
function __ZNK3osg9Billboard13computeMatrixERNS_7MatrixdERKNS_5Vec3fES5_($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$sroa$0$0 = 0.0, $$sroa$0$1 = 0.0, $$sroa$0113$0 = 0.0, $$sroa$0113$1 = 0.0, $$sroa$0134$0 = 0.0, $$sroa$0147$0 = 0.0, $$sroa$10$0 = 0.0, $$sroa$10119$0 = 0.0, $$sroa$13$0 = 0.0, $$sroa$15$0 = 0.0, $$sroa$8$0 = 0.0, $$sroa$9$0 = 0.0, $10 = 0, $100 = 0.0, $101 = 0.0, $102 = 0.0, $103 = 0.0, $104 = 0, $105 = 0.0, $106 = 0.0;
 var $107 = 0.0, $108 = 0, $109 = 0.0, $11 = 0.0, $110 = 0.0, $111 = 0, $112 = 0.0, $113 = 0.0, $114 = 0.0, $115 = 0, $116 = 0.0, $117 = 0.0, $118 = 0.0, $119 = 0.0, $12 = 0.0, $120 = 0.0, $121 = 0.0, $122 = 0.0, $123 = 0.0, $124 = 0.0;
 var $125 = 0.0, $126 = 0.0, $127 = 0.0, $128 = 0.0, $129 = 0, $13 = 0, $130 = 0.0, $131 = 0.0, $132 = 0.0, $133 = 0.0, $134 = 0.0, $135 = 0.0, $136 = 0.0, $137 = 0.0, $138 = 0.0, $139 = 0.0, $14 = 0.0, $140 = 0.0, $141 = 0.0, $142 = 0.0;
 var $143 = 0.0, $144 = 0, $145 = 0, $146 = 0.0, $147 = 0.0, $148 = 0.0, $149 = 0.0, $15 = 0, $150 = 0.0, $151 = 0.0, $152 = 0, $153 = 0.0, $154 = 0.0, $155 = 0.0, $156 = 0, $157 = 0.0, $158 = 0.0, $159 = 0, $16 = 0.0, $160 = 0.0;
 var $161 = 0.0, $162 = 0, $163 = 0.0, $164 = 0.0, $165 = 0.0, $166 = 0.0, $167 = 0.0, $168 = 0.0, $169 = 0.0, $17 = 0.0, $170 = 0.0, $171 = 0.0, $172 = 0.0, $173 = 0.0, $174 = 0.0, $175 = 0.0, $176 = 0.0, $177 = 0.0, $178 = 0.0, $179 = 0.0;
 var $18 = 0, $180 = 0, $181 = 0.0, $182 = 0.0, $183 = 0.0, $184 = 0.0, $185 = 0.0, $186 = 0.0, $187 = 0.0, $188 = 0.0, $189 = 0.0, $19 = 0, $190 = 0.0, $191 = 0.0, $192 = 0.0, $193 = 0.0, $194 = 0.0, $195 = 0.0, $196 = 0.0, $197 = 0.0;
 var $198 = 0.0, $199 = 0.0, $20 = 0.0, $200 = 0, $201 = 0.0, $202 = 0.0, $203 = 0.0, $204 = 0.0, $205 = 0.0, $206 = 0.0, $207 = 0, $208 = 0.0, $209 = 0, $21 = 0.0, $210 = 0.0, $211 = 0, $212 = 0.0, $213 = 0, $214 = 0.0, $215 = 0;
 var $216 = 0.0, $217 = 0, $218 = 0.0, $219 = 0, $22 = 0.0, $220 = 0.0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0.0, $226 = 0.0, $227 = 0.0, $228 = 0.0, $229 = 0.0, $23 = 0.0, $230 = 0, $231 = 0.0, $232 = 0.0, $233 = 0.0;
 var $234 = 0, $235 = 0.0, $236 = 0.0, $237 = 0.0, $238 = 0.0, $239 = 0.0, $24 = 0.0, $240 = 0, $241 = 0.0, $242 = 0.0, $243 = 0.0, $244 = 0, $245 = 0.0, $246 = 0.0, $247 = 0, $248 = 0.0, $249 = 0.0, $25 = 0, $250 = 0.0, $251 = 0;
 var $252 = 0.0, $253 = 0.0, $254 = 0, $255 = 0.0, $256 = 0, $257 = 0.0, $258 = 0.0, $259 = 0, $26 = 0.0, $260 = 0.0, $261 = 0.0, $262 = 0.0, $263 = 0, $264 = 0.0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0.0;
 var $270 = 0, $271 = 0, $28 = 0.0, $29 = 0.0, $30 = 0.0, $31 = 0.0, $32 = 0.0, $33 = 0, $34 = 0.0, $35 = 0, $36 = 0, $37 = 0.0, $38 = 0.0, $39 = 0.0, $4 = 0, $40 = 0.0, $41 = 0.0, $42 = 0, $43 = 0.0, $44 = 0.0;
 var $45 = 0.0, $46 = 0.0, $47 = 0.0, $48 = 0.0, $49 = 0, $5 = 0.0, $50 = 0.0, $51 = 0, $52 = 0, $53 = 0.0, $54 = 0.0, $55 = 0.0, $56 = 0.0, $57 = 0.0, $58 = 0, $59 = 0.0, $6 = 0.0, $60 = 0.0, $61 = 0.0, $62 = 0.0;
 var $63 = 0.0, $64 = 0.0, $65 = 0, $66 = 0.0, $67 = 0, $68 = 0.0, $69 = 0, $7 = 0.0, $70 = 0, $71 = 0, $72 = 0.0, $73 = 0.0, $74 = 0, $75 = 0.0, $76 = 0.0, $77 = 0.0, $78 = 0, $79 = 0.0, $8 = 0, $80 = 0.0;
 var $81 = 0.0, $82 = 0, $83 = 0.0, $84 = 0.0, $85 = 0, $86 = 0.0, $87 = 0.0, $88 = 0.0, $89 = 0, $9 = 0.0, $90 = 0.0, $91 = 0.0, $92 = 0.0, $93 = 0.0, $94 = 0.0, $95 = 0, $96 = 0, $97 = 0, $98 = 0.0, $99 = 0.0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(128|0);
 $4 = sp;
 __ZN3osg7Matrixd12makeIdentityEv($4);
 $5 = +HEAPF32[$2>>2];
 $6 = +HEAPF32[$3>>2];
 $7 = $5 - $6;
 $8 = ((($2)) + 4|0);
 $9 = +HEAPF32[$8>>2];
 $10 = ((($3)) + 4|0);
 $11 = +HEAPF32[$10>>2];
 $12 = $9 - $11;
 $13 = ((($2)) + 8|0);
 $14 = +HEAPF32[$13>>2];
 $15 = ((($3)) + 8|0);
 $16 = +HEAPF32[$15>>2];
 $17 = $14 - $16;
 $18 = ((($0)) + 332|0);
 $19 = HEAP32[$18>>2]|0;
 switch ($19|0) {
 case 5:  {
  $20 = $7 * $7;
  $21 = $12 * $12;
  $22 = $20 + $21;
  $23 = $22 + 0.0;
  $24 = (+Math_sqrt((+$23)));
  $25 = $24 > 0.0;
  if ($25) {
   $26 = 1.0 / $24;
   $27 = $7 * $26;
   $28 = $12 * $26;
   $29 = -$28;
   $30 = $29;
   HEAPF64[$4>>3] = $30;
   $31 = -$27;
   $32 = $31;
   $33 = ((($4)) + 32|0);
   HEAPF64[$33>>3] = $32;
   $34 = $27;
   $35 = ((($4)) + 8|0);
   HEAPF64[$35>>3] = $34;
   $36 = ((($4)) + 40|0);
   HEAPF64[$36>>3] = $30;
  }
  break;
 }
 case 4:  {
  $37 = $7 * $7;
  $38 = $37 + 0.0;
  $39 = $17 * $17;
  $40 = $38 + $39;
  $41 = (+Math_sqrt((+$40)));
  $42 = $41 > 0.0;
  if ($42) {
   $43 = 1.0 / $41;
   $44 = $17 * $43;
   $45 = -$44;
   $46 = $7 * $43;
   $47 = $46;
   HEAPF64[$4>>3] = $47;
   $48 = $45;
   $49 = ((($4)) + 64|0);
   HEAPF64[$49>>3] = $48;
   $50 = $44;
   $51 = ((($4)) + 16|0);
   HEAPF64[$51>>3] = $50;
   $52 = ((($4)) + 80|0);
   HEAPF64[$52>>3] = $47;
  }
  break;
 }
 case 3:  {
  $53 = $12 * $12;
  $54 = $53 + 0.0;
  $55 = $17 * $17;
  $56 = $54 + $55;
  $57 = (+Math_sqrt((+$56)));
  $58 = $57 > 0.0;
  if ($58) {
   $59 = 1.0 / $57;
   $60 = $17 * $59;
   $61 = -$60;
   $62 = $12 * $59;
   $63 = -$62;
   $64 = $63;
   $65 = ((($4)) + 40|0);
   HEAPF64[$65>>3] = $64;
   $66 = $60;
   $67 = ((($4)) + 72|0);
   HEAPF64[$67>>3] = $66;
   $68 = $61;
   $69 = ((($4)) + 48|0);
   HEAPF64[$69>>3] = $68;
   $70 = ((($4)) + 80|0);
   HEAPF64[$70>>3] = $64;
  }
  break;
 }
 case 2:  {
  $71 = ((($0)) + 336|0);
  $72 = +HEAPF32[$71>>2];
  $73 = $7 * $72;
  $74 = ((($0)) + 340|0);
  $75 = +HEAPF32[$74>>2];
  $76 = $12 * $75;
  $77 = $73 + $76;
  $78 = ((($0)) + 344|0);
  $79 = +HEAPF32[$78>>2];
  $80 = $17 * $79;
  $81 = $77 + $80;
  $82 = ((($0)) + 176|0);
  $83 = +HEAPF32[$82>>2];
  $84 = $7 * $83;
  $85 = ((($0)) + 180|0);
  $86 = +HEAPF32[$85>>2];
  $87 = $12 * $86;
  $88 = $84 + $87;
  $89 = ((($0)) + 184|0);
  $90 = +HEAPF32[$89>>2];
  $91 = $17 * $90;
  $92 = $88 + $91;
  $93 = (+Math_atan2((+$81),(+$92)));
  $94 = $93;
  $95 = ((($0)) + 164|0);
  __THREW__ = 0;
  invoke_vidi(3696,($4|0),(+$94),($95|0));
  $96 = __THREW__; __THREW__ = 0;
  $97 = $96&1;
  if ($97) {
   $270 = ___cxa_find_matching_catch_2()|0;
   $271 = tempRet0;
   ___resumeException($270|0);
   // unreachable;
  }
  break;
 }
 case 1:  {
  $98 = $7 * $7;
  $99 = $12 * $12;
  $100 = $98 + $99;
  $101 = $17 * $17;
  $102 = $100 + $101;
  $103 = (+Math_sqrt((+$102)));
  $104 = $103 != 0.0;
  if ($104) {
   $105 = $7 / $103;
   $106 = $12 / $103;
   $107 = $17 / $103;
   $108 = ((($0)) + 184|0);
   $109 = +HEAPF32[$108>>2];
   $110 = $106 * $109;
   $111 = ((($0)) + 180|0);
   $112 = +HEAPF32[$111>>2];
   $113 = $107 * $112;
   $114 = $110 - $113;
   $115 = ((($0)) + 176|0);
   $116 = +HEAPF32[$115>>2];
   $117 = $107 * $116;
   $118 = $105 * $109;
   $119 = $117 - $118;
   $120 = $105 * $112;
   $121 = $106 * $116;
   $122 = $120 - $121;
   $123 = $114 * $114;
   $124 = $119 * $119;
   $125 = $123 + $124;
   $126 = $122 * $122;
   $127 = $126 + $125;
   $128 = (+Math_sqrt((+$127)));
   $129 = $128 != 0.0;
   if ($129) {
    $130 = $105 * $116;
    $131 = $106 * $112;
    $132 = $131 + $130;
    $133 = $107 * $109;
    $134 = $133 + $132;
    $135 = $114 / $128;
    $136 = $119 / $128;
    $137 = $122 / $128;
    $138 = (+Math_acos((+$134)));
    $139 = -$138;
    $140 = $139;
    $141 = $135;
    $142 = $136;
    $143 = $137;
    __THREW__ = 0;
    invoke_vidddd(3697,($4|0),(+$140),(+$141),(+$142),(+$143));
    $144 = __THREW__; __THREW__ = 0;
    $145 = $144&1;
    if ($145) {
     $270 = ___cxa_find_matching_catch_2()|0;
     $271 = tempRet0;
     ___resumeException($270|0);
     // unreachable;
    }
   }
  }
  break;
 }
 case 0:  {
  $146 = $7 * $7;
  $147 = $12 * $12;
  $148 = $146 + $147;
  $149 = $17 * $17;
  $150 = $148 + $149;
  $151 = (+Math_sqrt((+$150)));
  $152 = $151 != 0.0;
  if ($152) {
   $153 = $7 / $151;
   $154 = $12 / $151;
   $155 = $17 / $151;
   $156 = ((($1)) + 8|0);
   $157 = +HEAPF64[$156>>3];
   $158 = $157;
   $159 = ((($1)) + 40|0);
   $160 = +HEAPF64[$159>>3];
   $161 = $160;
   $162 = ((($1)) + 72|0);
   $163 = +HEAPF64[$162>>3];
   $164 = $163;
   $165 = $155 * $161;
   $166 = $154 * $164;
   $167 = $165 - $166;
   $168 = $153 * $164;
   $169 = $155 * $158;
   $170 = $168 - $169;
   $171 = $154 * $158;
   $172 = $153 * $161;
   $173 = $171 - $172;
   $174 = $167 * $167;
   $175 = $170 * $170;
   $176 = $174 + $175;
   $177 = $173 * $173;
   $178 = $177 + $176;
   $179 = (+Math_sqrt((+$178)));
   $180 = $179 > 0.0;
   $181 = 1.0 / $179;
   $182 = $181 * $167;
   $183 = $181 * $170;
   $184 = $181 * $173;
   $$sroa$13$0 = $180 ? $184 : $173;
   $$sroa$8$0 = $180 ? $183 : $170;
   $$sroa$0134$0 = $180 ? $182 : $167;
   $185 = $154 * $$sroa$13$0;
   $186 = $155 * $$sroa$8$0;
   $187 = $185 - $186;
   $188 = $155 * $$sroa$0134$0;
   $189 = $153 * $$sroa$13$0;
   $190 = $188 - $189;
   $191 = $153 * $$sroa$8$0;
   $192 = $154 * $$sroa$0134$0;
   $193 = $191 - $192;
   $194 = $187 * $187;
   $195 = $190 * $190;
   $196 = $194 + $195;
   $197 = $193 * $193;
   $198 = $197 + $196;
   $199 = (+Math_sqrt((+$198)));
   $200 = $199 > 0.0;
   $201 = 1.0 / $199;
   $202 = $201 * $187;
   $203 = $201 * $190;
   $204 = $201 * $193;
   $$sroa$15$0 = $200 ? $204 : $193;
   $$sroa$9$0 = $200 ? $203 : $190;
   $$sroa$0147$0 = $200 ? $202 : $187;
   $205 = $$sroa$0134$0;
   HEAPF64[$4>>3] = $205;
   $206 = $$sroa$8$0;
   $207 = ((($4)) + 8|0);
   HEAPF64[$207>>3] = $206;
   $208 = $$sroa$13$0;
   $209 = ((($4)) + 16|0);
   HEAPF64[$209>>3] = $208;
   $210 = $$sroa$0147$0;
   $211 = ((($4)) + 32|0);
   HEAPF64[$211>>3] = $210;
   $212 = $$sroa$9$0;
   $213 = ((($4)) + 40|0);
   HEAPF64[$213>>3] = $212;
   $214 = $$sroa$15$0;
   $215 = ((($4)) + 48|0);
   HEAPF64[$215>>3] = $214;
   $216 = $153;
   $217 = ((($4)) + 64|0);
   HEAPF64[$217>>3] = $216;
   $218 = $154;
   $219 = ((($4)) + 72|0);
   HEAPF64[$219>>3] = $218;
   $220 = $155;
   $221 = ((($4)) + 80|0);
   HEAPF64[$221>>3] = $220;
   $222 = ((($0)) + 192|0);
   __THREW__ = 0;
   invoke_vii(3546,($4|0),($222|0));
   $223 = __THREW__; __THREW__ = 0;
   $224 = $223&1;
   if ($224) {
    $270 = ___cxa_find_matching_catch_2()|0;
    $271 = tempRet0;
    ___resumeException($270|0);
    // unreachable;
   }
  }
  break;
 }
 case 6:  {
  $225 = -$12;
  $226 = $12 * $12;
  $227 = $7 * $7;
  $228 = $227 + $226;
  $229 = (+Math_sqrt((+$228)));
  $230 = $229 > 0.0;
  $231 = 1.0 / $229;
  $232 = $231 * $225;
  $233 = $7 * $231;
  $$sroa$10119$0 = $230 ? $233 : $7;
  $$sroa$0113$0 = $230 ? $232 : $225;
  $234 = $229 == 0.0;
  $$sroa$0113$1 = $234 ? 1.0 : $$sroa$0113$0;
  $235 = -$17;
  $236 = $229 * $229;
  $237 = $17 * $17;
  $238 = $237 + $236;
  $239 = (+Math_sqrt((+$238)));
  $240 = $239 > 0.0;
  $241 = 1.0 / $239;
  $242 = $229 * $241;
  $243 = $241 * $235;
  $$sroa$10$0 = $240 ? $243 : $235;
  $$sroa$0$0 = $240 ? $242 : $229;
  $244 = $239 == 0.0;
  $$sroa$0$1 = $244 ? 1.0 : $$sroa$0$0;
  $245 = $$sroa$0113$1;
  HEAPF64[$4>>3] = $245;
  $246 = $$sroa$10119$0;
  $247 = ((($4)) + 8|0);
  HEAPF64[$247>>3] = $246;
  $248 = $$sroa$10119$0 * $$sroa$0$1;
  $249 = -$248;
  $250 = $249;
  $251 = ((($4)) + 32|0);
  HEAPF64[$251>>3] = $250;
  $252 = $$sroa$0113$1 * $$sroa$0$1;
  $253 = $252;
  $254 = ((($4)) + 40|0);
  HEAPF64[$254>>3] = $253;
  $255 = $$sroa$10$0;
  $256 = ((($4)) + 48|0);
  HEAPF64[$256>>3] = $255;
  $257 = $$sroa$10119$0 * $$sroa$10$0;
  $258 = $257;
  $259 = ((($4)) + 64|0);
  HEAPF64[$259>>3] = $258;
  $260 = $$sroa$0113$1 * $$sroa$10$0;
  $261 = -$260;
  $262 = $261;
  $263 = ((($4)) + 72|0);
  HEAPF64[$263>>3] = $262;
  $264 = $$sroa$0$1;
  $265 = ((($4)) + 80|0);
  HEAPF64[$265>>3] = $264;
  break;
 }
 default: {
 }
 }
 __THREW__ = 0;
 invoke_vii(3698,($4|0),($3|0));
 $266 = __THREW__; __THREW__ = 0;
 $267 = $266&1;
 if ($267) {
  $270 = ___cxa_find_matching_catch_2()|0;
  $271 = tempRet0;
  ___resumeException($270|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_vii(3546,($1|0),($4|0));
 $268 = __THREW__; __THREW__ = 0;
 $269 = $268&1;
 if ($269) {
  $270 = ___cxa_find_matching_catch_2()|0;
  $271 = tempRet0;
  ___resumeException($270|0);
  // unreachable;
 } else {
  STACKTOP = sp;return 1;
 }
 return (0)|0;
}
function __ZN3osg14GLBufferObjectD2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i = 0, $scevgep5$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (54876);
 $1 = ((($0)) + 40|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  __ZN3osg14GraphicsObjectD2Ev($0);
  return;
 }
 $4 = ((($0)) + 44|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==($2|0);
 if (!($6)) {
  $scevgep$i$i$i = ((($5)) + -20|0);
  $7 = $scevgep$i$i$i;
  $8 = $2;
  $9 = (($7) - ($8))|0;
  $10 = (($9>>>0) / 20)&-1;
  $11 = $10 ^ -1;
  $scevgep5$i$i$i = (($5) + (($11*20)|0)|0);
  HEAP32[$4>>2] = $scevgep5$i$i$i;
 }
 __ZdlPv($2);
 __ZN3osg14GraphicsObjectD2Ev($0);
 return;
}
function __ZN3osg14GLBufferObjectD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i = 0, $scevgep5$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (54876);
 $1 = ((($0)) + 40|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = ((($0)) + 44|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==($2|0);
  if (!($6)) {
   $scevgep$i$i$i$i = ((($5)) + -20|0);
   $7 = $scevgep$i$i$i$i;
   $8 = $2;
   $9 = (($7) - ($8))|0;
   $10 = (($9>>>0) / 20)&-1;
   $11 = $10 ^ -1;
   $scevgep5$i$i$i$i = (($5) + (($11*20)|0)|0);
   HEAP32[$4>>2] = $scevgep5$i$i$i$i;
  }
  __ZdlPv($2);
 }
 __THREW__ = 0;
 invoke_vi(1859,($0|0));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $14 = ___cxa_find_matching_catch_2()|0;
  $15 = tempRet0;
  __ZdlPv($0);
  ___resumeException($14|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZN3osg17GLBufferObjectSetD2Ev($0) {
 $0 = $0|0;
 var $$023$i$i = 0, $$023$i$i4 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (54896);
 $1 = ((($0)) + 60|0);
 $2 = ((($0)) + 68|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 L1: do {
  if (!($4)) {
   $5 = ((($0)) + 64|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = HEAP32[$1>>2]|0;
   $8 = ((($7)) + 4|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = HEAP32[$6>>2]|0;
   $11 = ((($10)) + 4|0);
   HEAP32[$11>>2] = $9;
   $12 = HEAP32[$8>>2]|0;
   HEAP32[$12>>2] = $10;
   HEAP32[$2>>2] = 0;
   $13 = ($6|0)==($1|0);
   if (!($13)) {
    $$023$i$i = $6;
    while(1) {
     $14 = ((($$023$i$i)) + 4|0);
     $15 = HEAP32[$14>>2]|0;
     $16 = ((($$023$i$i)) + 8|0);
     $17 = HEAP32[$16>>2]|0;
     $18 = ($17|0)==(0|0);
     if (!($18)) {
      $19 = ((($17)) + 8|0);
      $20 = HEAP32[$19>>2]|0;HEAP32[$19>>2] = (($20-1)|0);
      $21 = ($20|0)==(1);
      if ($21) {
       __THREW__ = 0;
       invoke_viii(3262,($17|0),1,1);
       $22 = __THREW__; __THREW__ = 0;
       $23 = $22&1;
       if ($23) {
        break;
       }
      }
     }
     __ZdlPv($$023$i$i);
     $24 = ($15|0)==($1|0);
     if ($24) {
      break L1;
     } else {
      $$023$i$i = $15;
     }
    }
    $25 = ___cxa_find_matching_catch_2()|0;
    $26 = tempRet0;
    ___cxa_call_unexpected(($25|0));
    // unreachable;
   }
  }
 } while(0);
 $27 = ((($0)) + 48|0);
 $28 = ((($0)) + 56|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ($29|0)==(0);
 L11: do {
  if (!($30)) {
   $31 = ((($0)) + 52|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = HEAP32[$27>>2]|0;
   $34 = ((($33)) + 4|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = HEAP32[$32>>2]|0;
   $37 = ((($36)) + 4|0);
   HEAP32[$37>>2] = $35;
   $38 = HEAP32[$34>>2]|0;
   HEAP32[$38>>2] = $36;
   HEAP32[$28>>2] = 0;
   $39 = ($32|0)==($27|0);
   if (!($39)) {
    $$023$i$i4 = $32;
    while(1) {
     $40 = ((($$023$i$i4)) + 4|0);
     $41 = HEAP32[$40>>2]|0;
     $42 = ((($$023$i$i4)) + 8|0);
     $43 = HEAP32[$42>>2]|0;
     $44 = ($43|0)==(0|0);
     if (!($44)) {
      $45 = ((($43)) + 8|0);
      $46 = HEAP32[$45>>2]|0;HEAP32[$45>>2] = (($46-1)|0);
      $47 = ($46|0)==(1);
      if ($47) {
       __THREW__ = 0;
       invoke_viii(3262,($43|0),1,1);
       $48 = __THREW__; __THREW__ = 0;
       $49 = $48&1;
       if ($49) {
        break;
       }
      }
     }
     __ZdlPv($$023$i$i4);
     $50 = ($41|0)==($27|0);
     if ($50) {
      break L11;
     } else {
      $$023$i$i4 = $41;
     }
    }
    $51 = ___cxa_find_matching_catch_2()|0;
    $52 = tempRet0;
    ___cxa_call_unexpected(($51|0));
    // unreachable;
   }
  }
 } while(0);
 $53 = ((($0)) + 12|0);
 __THREW__ = 0;
 invoke_vi(707,($53|0));
 $54 = __THREW__; __THREW__ = 0;
 $55 = $54&1;
 if (!($55)) {
  __ZN3osg10ReferencedD2Ev($0);
  return;
 }
 $56 = ___cxa_find_matching_catch_2()|0;
 $57 = tempRet0;
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $58 = __THREW__; __THREW__ = 0;
 $59 = $58&1;
 if ($59) {
  $60 = ___cxa_find_matching_catch_3(0|0)|0;
  $61 = tempRet0;
  ___clang_call_terminate($60);
  // unreachable;
 } else {
  ___resumeException($56|0);
  // unreachable;
 }
}
function __ZN3osg17GLBufferObjectSetD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1436,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZN3osg21GLBufferObjectManagerD2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (54916);
 $1 = ((($0)) + 44|0);
 $2 = ((($0)) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIN3osg19BufferObjectProfileENS2_7ref_ptrINS2_17GLBufferObjectSetEEEEENS_19__map_value_compareIS3_S7_NS_4lessIS3_EELb1EEENS_9allocatorIS7_EEE7destroyEPNS_11__tree_nodeIS7_PvEE($1,$3);
 __ZN3osg21GraphicsObjectManagerD2Ev($0);
 return;
}
function __ZN3osg21GLBufferObjectManagerD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (54916);
 $1 = ((($0)) + 44|0);
 $2 = ((($0)) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIN3osg19BufferObjectProfileENS2_7ref_ptrINS2_17GLBufferObjectSetEEEEENS_19__map_value_compareIS3_S7_NS_4lessIS3_EELb1EEENS_9allocatorIS7_EEE7destroyEPNS_11__tree_nodeIS7_PvEE($1,$3);
 __THREW__ = 0;
 invoke_vi(1861,($0|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch_2()|0;
  $7 = tempRet0;
  __ZdlPv($0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZN3osg21GLBufferObjectManager8newFrameEPNS_10FrameStampE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $6 = ((($0)) + 56|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($7) + 1)|0;
  HEAP32[$6>>2] = $8;
 } else {
  $3 = ((($1)) + 12|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ((($0)) + 56|0);
  HEAP32[$5>>2] = $4;
 }
 $9 = ((($0)) + 60|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 1)|0;
 HEAP32[$9>>2] = $11;
 return;
}
function __ZN3osg21GLBufferObjectManager10resetStatsEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 60|0);
 HEAP32[$1>>2] = 0;
 $2 = ((($0)) + 64|0);
 HEAP32[$2>>2] = 0;
 $3 = ((($0)) + 72|0);
 HEAPF64[$3>>3] = 0.0;
 $4 = ((($0)) + 80|0);
 HEAP32[$4>>2] = 0;
 $5 = ((($0)) + 88|0);
 HEAPF64[$5>>3] = 0.0;
 $6 = ((($0)) + 96|0);
 HEAP32[$6>>2] = 0;
 $7 = ((($0)) + 104|0);
 HEAPF64[$7>>3] = 0.0;
 return;
}
function __ZN3osg21GLBufferObjectManager11reportStatsERNSt3__213basic_ostreamIcNS1_11char_traitsIcEEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$ = 0.0, $10 = 0, $100 = 0, $101 = 0, $102 = 0.0, $103 = 0, $104 = 0, $105 = 0.0, $106 = 0.0, $107 = 0.0, $108 = 0, $109 = 0, $11 = 0.0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0;
 var $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0;
 var $135 = 0.0, $136 = 0, $137 = 0, $138 = 0.0, $139 = 0.0, $14 = 0, $140 = 0.0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0;
 var $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0.0, $169 = 0, $17 = 0, $170 = 0.0;
 var $171 = 0.0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0;
 var $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0.0, $7 = 0, $70 = 0, $71 = 0, $72 = 0.0, $73 = 0.0, $74 = 0.0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $2 = sp + 20|0;
 $3 = sp + 16|0;
 $4 = sp + 12|0;
 $5 = sp + 8|0;
 $6 = sp + 4|0;
 $7 = sp;
 $8 = ((($0)) + 60|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0);
 $11 = (+($9>>>0));
 $$ = $10 ? 1.0 : $11;
 $12 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($1,119173,37)|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($13)) + -12|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($12) + ($15)|0);
 __ZNKSt3__28ios_base6getlocEv($7,$16);
 __THREW__ = 0;
 $17 = (invoke_iii(3255,($7|0),(215188|0))|0);
 $18 = __THREW__; __THREW__ = 0;
 $19 = $18&1;
 if (!($19)) {
  $20 = HEAP32[$17>>2]|0;
  $21 = ((($20)) + 28|0);
  $22 = HEAP32[$21>>2]|0;
  __THREW__ = 0;
  $23 = (invoke_iii($22|0,($17|0),10)|0);
  $24 = __THREW__; __THREW__ = 0;
  $25 = $24&1;
  if (!($25)) {
   __ZNSt3__26localeD2Ev($7);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($12,$23)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($12)|0);
   $32 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($1,119211,31)|0);
   $33 = ((($0)) + 28|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($32,$34)|0);
   $36 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($35,119243,30)|0);
   $37 = ((($0)) + 32|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($36,$38)|0);
   $40 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($39,119274,29)|0);
   $41 = ((($0)) + 36|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($40,$42)|0);
   $44 = HEAP32[$43>>2]|0;
   $45 = ((($44)) + -12|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = (($43) + ($46)|0);
   __ZNKSt3__28ios_base6getlocEv($6,$47);
   __THREW__ = 0;
   $48 = (invoke_iii(3255,($6|0),(215188|0))|0);
   $49 = __THREW__; __THREW__ = 0;
   $50 = $49&1;
   if (!($50)) {
    $51 = HEAP32[$48>>2]|0;
    $52 = ((($51)) + 28|0);
    $53 = HEAP32[$52>>2]|0;
    __THREW__ = 0;
    $54 = (invoke_iii($53|0,($48|0),10)|0);
    $55 = __THREW__; __THREW__ = 0;
    $56 = $55&1;
    if (!($56)) {
     __ZNSt3__26localeD2Ev($6);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($43,$54)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($43)|0);
     $63 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($1,154526,23)|0);
     $64 = ((($0)) + 80|0);
     $65 = HEAP32[$64>>2]|0;
     $66 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($63,$65)|0);
     $67 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($66,154550,16)|0);
     $68 = ((($0)) + 88|0);
     $69 = +HEAPF64[$68>>3];
     $70 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEd($67,$69)|0);
     $71 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($70,154567,18)|0);
     $72 = +HEAPF64[$68>>3];
     $73 = $72 / $$;
     $74 = $73 * 1000.0;
     $75 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEd($71,$74)|0);
     $76 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($75,163681,2)|0);
     $77 = HEAP32[$76>>2]|0;
     $78 = ((($77)) + -12|0);
     $79 = HEAP32[$78>>2]|0;
     $80 = (($76) + ($79)|0);
     __ZNKSt3__28ios_base6getlocEv($5,$80);
     __THREW__ = 0;
     $81 = (invoke_iii(3255,($5|0),(215188|0))|0);
     $82 = __THREW__; __THREW__ = 0;
     $83 = $82&1;
     if (!($83)) {
      $84 = HEAP32[$81>>2]|0;
      $85 = ((($84)) + 28|0);
      $86 = HEAP32[$85>>2]|0;
      __THREW__ = 0;
      $87 = (invoke_iii($86|0,($81|0),10)|0);
      $88 = __THREW__; __THREW__ = 0;
      $89 = $88&1;
      if (!($89)) {
       __ZNSt3__26localeD2Ev($5);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($76,$87)|0);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($76)|0);
       $96 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($1,154586,21)|0);
       $97 = ((($0)) + 64|0);
       $98 = HEAP32[$97>>2]|0;
       $99 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($96,$98)|0);
       $100 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($99,154608,14)|0);
       $101 = ((($0)) + 72|0);
       $102 = +HEAPF64[$101>>3];
       $103 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEd($100,$102)|0);
       $104 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($103,154567,18)|0);
       $105 = +HEAPF64[$101>>3];
       $106 = $105 / $$;
       $107 = $106 * 1000.0;
       $108 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEd($104,$107)|0);
       $109 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($108,163681,2)|0);
       $110 = HEAP32[$109>>2]|0;
       $111 = ((($110)) + -12|0);
       $112 = HEAP32[$111>>2]|0;
       $113 = (($109) + ($112)|0);
       __ZNKSt3__28ios_base6getlocEv($4,$113);
       __THREW__ = 0;
       $114 = (invoke_iii(3255,($4|0),(215188|0))|0);
       $115 = __THREW__; __THREW__ = 0;
       $116 = $115&1;
       if (!($116)) {
        $117 = HEAP32[$114>>2]|0;
        $118 = ((($117)) + 28|0);
        $119 = HEAP32[$118>>2]|0;
        __THREW__ = 0;
        $120 = (invoke_iii($119|0,($114|0),10)|0);
        $121 = __THREW__; __THREW__ = 0;
        $122 = $121&1;
        if (!($122)) {
         __ZNSt3__26localeD2Ev($4);
         (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($109,$120)|0);
         (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($109)|0);
         $129 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($1,119304,21)|0);
         $130 = ((($0)) + 96|0);
         $131 = HEAP32[$130>>2]|0;
         $132 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($129,$131)|0);
         $133 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($132,119326,13)|0);
         $134 = ((($0)) + 104|0);
         $135 = +HEAPF64[$134>>3];
         $136 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEd($133,$135)|0);
         $137 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($136,154567,18)|0);
         $138 = +HEAPF64[$134>>3];
         $139 = $138 / $$;
         $140 = $139 * 1000.0;
         $141 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEd($137,$140)|0);
         $142 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($141,163681,2)|0);
         $143 = HEAP32[$142>>2]|0;
         $144 = ((($143)) + -12|0);
         $145 = HEAP32[$144>>2]|0;
         $146 = (($142) + ($145)|0);
         __ZNKSt3__28ios_base6getlocEv($3,$146);
         __THREW__ = 0;
         $147 = (invoke_iii(3255,($3|0),(215188|0))|0);
         $148 = __THREW__; __THREW__ = 0;
         $149 = $148&1;
         if (!($149)) {
          $150 = HEAP32[$147>>2]|0;
          $151 = ((($150)) + 28|0);
          $152 = HEAP32[$151>>2]|0;
          __THREW__ = 0;
          $153 = (invoke_iii($152|0,($147|0),10)|0);
          $154 = __THREW__; __THREW__ = 0;
          $155 = $154&1;
          if (!($155)) {
           __ZNSt3__26localeD2Ev($3);
           (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($142,$153)|0);
           (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($142)|0);
           $162 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($1,119066,34)|0);
           $163 = ((($0)) + 40|0);
           $164 = HEAP32[$163>>2]|0;
           $165 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($162,$164)|0);
           $166 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($165,154193,20)|0);
           $167 = HEAP32[$41>>2]|0;
           $168 = (+($167>>>0));
           $169 = HEAP32[$163>>2]|0;
           $170 = (+($169>>>0));
           $171 = $168 / $170;
           $172 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEd($166,$171)|0);
           $173 = HEAP32[$172>>2]|0;
           $174 = ((($173)) + -12|0);
           $175 = HEAP32[$174>>2]|0;
           $176 = (($172) + ($175)|0);
           __ZNKSt3__28ios_base6getlocEv($2,$176);
           __THREW__ = 0;
           $177 = (invoke_iii(3255,($2|0),(215188|0))|0);
           $178 = __THREW__; __THREW__ = 0;
           $179 = $178&1;
           if (!($179)) {
            $180 = HEAP32[$177>>2]|0;
            $181 = ((($180)) + 28|0);
            $182 = HEAP32[$181>>2]|0;
            __THREW__ = 0;
            $183 = (invoke_iii($182|0,($177|0),10)|0);
            $184 = __THREW__; __THREW__ = 0;
            $185 = $184&1;
            if (!($185)) {
             __ZNSt3__26localeD2Ev($2);
             (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($172,$183)|0);
             (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($172)|0);
             $192 = HEAP32[$0>>2]|0;
             $193 = ((($192)) + 24|0);
             $194 = HEAP32[$193>>2]|0;
             FUNCTION_TABLE_vii[$194 & 8191]($0,$1);
             STACKTOP = sp;return;
            }
           }
           $186 = ___cxa_find_matching_catch_2()|0;
           $187 = tempRet0;
           __THREW__ = 0;
           invoke_vi(3263,($2|0));
           $188 = __THREW__; __THREW__ = 0;
           $189 = $188&1;
           if ($189) {
            $190 = ___cxa_find_matching_catch_3(0|0)|0;
            $191 = tempRet0;
            ___clang_call_terminate($190);
            // unreachable;
           } else {
            ___resumeException($186|0);
            // unreachable;
           }
          }
         }
         $156 = ___cxa_find_matching_catch_2()|0;
         $157 = tempRet0;
         __THREW__ = 0;
         invoke_vi(3263,($3|0));
         $158 = __THREW__; __THREW__ = 0;
         $159 = $158&1;
         if ($159) {
          $160 = ___cxa_find_matching_catch_3(0|0)|0;
          $161 = tempRet0;
          ___clang_call_terminate($160);
          // unreachable;
         } else {
          ___resumeException($156|0);
          // unreachable;
         }
        }
       }
       $123 = ___cxa_find_matching_catch_2()|0;
       $124 = tempRet0;
       __THREW__ = 0;
       invoke_vi(3263,($4|0));
       $125 = __THREW__; __THREW__ = 0;
       $126 = $125&1;
       if ($126) {
        $127 = ___cxa_find_matching_catch_3(0|0)|0;
        $128 = tempRet0;
        ___clang_call_terminate($127);
        // unreachable;
       } else {
        ___resumeException($123|0);
        // unreachable;
       }
      }
     }
     $90 = ___cxa_find_matching_catch_2()|0;
     $91 = tempRet0;
     __THREW__ = 0;
     invoke_vi(3263,($5|0));
     $92 = __THREW__; __THREW__ = 0;
     $93 = $92&1;
     if ($93) {
      $94 = ___cxa_find_matching_catch_3(0|0)|0;
      $95 = tempRet0;
      ___clang_call_terminate($94);
      // unreachable;
     } else {
      ___resumeException($90|0);
      // unreachable;
     }
    }
   }
   $57 = ___cxa_find_matching_catch_2()|0;
   $58 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($6|0));
   $59 = __THREW__; __THREW__ = 0;
   $60 = $59&1;
   if ($60) {
    $61 = ___cxa_find_matching_catch_3(0|0)|0;
    $62 = tempRet0;
    ___clang_call_terminate($61);
    // unreachable;
   } else {
    ___resumeException($57|0);
    // unreachable;
   }
  }
 }
 $26 = ___cxa_find_matching_catch_2()|0;
 $27 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($7|0));
 $28 = __THREW__; __THREW__ = 0;
 $29 = $28&1;
 if ($29) {
  $30 = ___cxa_find_matching_catch_3(0|0)|0;
  $31 = tempRet0;
  ___clang_call_terminate($30);
  // unreachable;
 } else {
  ___resumeException($26|0);
  // unreachable;
 }
}
function __ZNK3osg21GLBufferObjectManager14recomputeStatsERNSt3__213basic_ostreamIcNS1_11char_traitsIcEEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i = 0, $$0$i$i$i$i = 0, $$0$i46 = 0, $$0$i53 = 0, $$0$lcssa = 0, $$037$lcssa = 0, $$03774 = 0, $$039$lcssa = 0, $$03973 = 0, $$040$lcssa = 0, $$04072 = 0, $$06$lcssa$i = 0, $$06$lcssa$i48 = 0, $$06$lcssa$i55 = 0, $$068$i = 0, $$068$i45 = 0, $$068$i52 = 0, $$07$i = 0, $$07$i50 = 0, $$075 = 0;
 var $$09$i = 0, $$09$i44 = 0, $$09$i51 = 0, $$sroa$059$0$be = 0, $$sroa$059$071 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0.0, $63 = 0, $64 = 0.0, $65 = 0.0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp + 12|0;
 $3 = sp + 8|0;
 $4 = sp + 4|0;
 $5 = sp;
 $6 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($1,119025,40)|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($7)) + -12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($6) + ($9)|0);
 __ZNKSt3__28ios_base6getlocEv($5,$10);
 __THREW__ = 0;
 $11 = (invoke_iii(3255,($5|0),(215188|0))|0);
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if (!($13)) {
  $14 = HEAP32[$11>>2]|0;
  $15 = ((($14)) + 28|0);
  $16 = HEAP32[$15>>2]|0;
  __THREW__ = 0;
  $17 = (invoke_iii($16|0,($11|0),10)|0);
  $18 = __THREW__; __THREW__ = 0;
  $19 = $18&1;
  if (!($19)) {
   __ZNSt3__26localeD2Ev($5);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($6,$17)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($6)|0);
   $26 = ((($0)) + 44|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = ((($0)) + 48|0);
   $29 = ($27|0)==($28|0);
   L4: do {
    if ($29) {
     $$0$lcssa = 0;$$037$lcssa = 0;$$039$lcssa = 0;$$040$lcssa = 0;
    } else {
     $$03774 = 0;$$03973 = 0;$$04072 = 0;$$075 = 0;$$sroa$059$071 = $27;
     while(1) {
      $86 = ((($$sroa$059$071)) + 28|0);
      $87 = HEAP32[$86>>2]|0;
      $88 = ((($87)) + 72|0);
      $$07$i = HEAP32[$88>>2]|0;
      $89 = ($$07$i|0)==(0|0);
      if ($89) {
       $$06$lcssa$i = 0;
      } else {
       $$068$i = 0;$$09$i = $$07$i;
       while(1) {
        $90 = (($$068$i) + 1)|0;
        $91 = ((($$09$i)) + 64|0);
        $$0$i = HEAP32[$91>>2]|0;
        $92 = ($$0$i|0)==(0|0);
        if ($92) {
         $$06$lcssa$i = $90;
         break;
        } else {
         $$068$i = $90;$$09$i = $$0$i;
        }
       }
      }
      $93 = (($$06$lcssa$i) + ($$075))|0;
      $94 = ((($87)) + 44|0);
      $95 = HEAP32[$94>>2]|0;
      $96 = (($95) + ($$04072))|0;
      $97 = ((($87)) + 56|0);
      $98 = HEAP32[$97>>2]|0;
      $99 = (($98) + ($$03973))|0;
      $100 = ((($87)) + 68|0);
      $101 = ((($87)) + 40|0);
      $102 = HEAP32[$101>>2]|0;
      if ($89) {
       $$06$lcssa$i48 = 0;
      } else {
       $$068$i45 = 0;$$09$i44 = $$07$i;
       while(1) {
        $103 = (($$068$i45) + 1)|0;
        $104 = ((($$09$i44)) + 64|0);
        $$0$i46 = HEAP32[$104>>2]|0;
        $105 = ($$0$i46|0)==(0|0);
        if ($105) {
         $$06$lcssa$i48 = $103;
         break;
        } else {
         $$068$i45 = $103;$$09$i44 = $$0$i46;
        }
       }
      }
      $106 = (($98) + ($$06$lcssa$i48))|0;
      $107 = Math_imul($106, $102)|0;
      $108 = (($107) + ($$03774))|0;
      $109 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($1,154214,8)|0);
      $110 = HEAP32[$101>>2]|0;
      $111 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($109,$110)|0);
      $112 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($111,119101,39)|0);
      $$07$i50 = HEAP32[$88>>2]|0;
      $113 = ($$07$i50|0)==(0|0);
      if ($113) {
       $$06$lcssa$i55 = 0;
      } else {
       $$068$i52 = 0;$$09$i51 = $$07$i50;
       while(1) {
        $114 = (($$068$i52) + 1)|0;
        $115 = ((($$09$i51)) + 64|0);
        $$0$i53 = HEAP32[$115>>2]|0;
        $116 = ($$0$i53|0)==(0|0);
        if ($116) {
         $$06$lcssa$i55 = $114;
         break;
        } else {
         $$068$i52 = $114;$$09$i51 = $$0$i53;
        }
       }
      }
      $117 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($112,$$06$lcssa$i55)|0);
      $118 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($117,119141,31)|0);
      $119 = HEAP32[$94>>2]|0;
      $120 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($118,$119)|0);
      $121 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($120,154293,21)|0);
      $122 = HEAP32[$97>>2]|0;
      $123 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($121,$122)|0);
      $124 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($123,154315,28)|0);
      $125 = HEAP32[$100>>2]|0;
      $126 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($124,$125)|0);
      $127 = HEAP32[$126>>2]|0;
      $128 = ((($127)) + -12|0);
      $129 = HEAP32[$128>>2]|0;
      $130 = (($126) + ($129)|0);
      __ZNKSt3__28ios_base6getlocEv($2,$130);
      __THREW__ = 0;
      $131 = (invoke_iii(3255,($2|0),(215188|0))|0);
      $132 = __THREW__; __THREW__ = 0;
      $133 = $132&1;
      if ($133) {
       break;
      }
      $134 = HEAP32[$131>>2]|0;
      $135 = ((($134)) + 28|0);
      $136 = HEAP32[$135>>2]|0;
      __THREW__ = 0;
      $137 = (invoke_iii($136|0,($131|0),10)|0);
      $138 = __THREW__; __THREW__ = 0;
      $139 = $138&1;
      if ($139) {
       break;
      }
      __ZNSt3__26localeD2Ev($2);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($126,$137)|0);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($126)|0);
      $146 = ((($$sroa$059$071)) + 4|0);
      $147 = HEAP32[$146>>2]|0;
      $148 = ($147|0)==(0|0);
      if ($148) {
       $149 = ((($$sroa$059$071)) + 8|0);
       $150 = HEAP32[$149>>2]|0;
       $151 = HEAP32[$150>>2]|0;
       $152 = ($151|0)==($$sroa$059$071|0);
       if ($152) {
        $$sroa$059$0$be = $150;
       } else {
        $157 = $149;
        while(1) {
         $156 = HEAP32[$157>>2]|0;
         $158 = ((($156)) + 8|0);
         $159 = HEAP32[$158>>2]|0;
         $160 = HEAP32[$159>>2]|0;
         $161 = ($160|0)==($156|0);
         if ($161) {
          $$sroa$059$0$be = $159;
          break;
         } else {
          $157 = $158;
         }
        }
       }
      } else {
       $$0$i$i$i$i = $147;
       while(1) {
        $154 = HEAP32[$$0$i$i$i$i>>2]|0;
        $155 = ($154|0)==(0|0);
        if ($155) {
         break;
        } else {
         $$0$i$i$i$i = $154;
        }
       }
       $$sroa$059$0$be = $$0$i$i$i$i;
      }
      $153 = ($$sroa$059$0$be|0)==($28|0);
      if ($153) {
       $$0$lcssa = $93;$$037$lcssa = $108;$$039$lcssa = $99;$$040$lcssa = $96;
       break L4;
      } else {
       $$03774 = $108;$$03973 = $99;$$04072 = $96;$$075 = $93;$$sroa$059$071 = $$sroa$059$0$be;
      }
     }
     $140 = ___cxa_find_matching_catch_2()|0;
     $141 = tempRet0;
     __THREW__ = 0;
     invoke_vi(3263,($2|0));
     $142 = __THREW__; __THREW__ = 0;
     $143 = $142&1;
     if ($143) {
      $144 = ___cxa_find_matching_catch_3(0|0)|0;
      $145 = tempRet0;
      ___clang_call_terminate($144);
      // unreachable;
     } else {
      ___resumeException($140|0);
      // unreachable;
     }
    }
   } while(0);
   $30 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($1,154102,21)|0);
   $31 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($30,$$0$lcssa)|0);
   $32 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($31,154124,12)|0);
   $33 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($32,$$040$lcssa)|0);
   $34 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($33,154137,13)|0);
   $35 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($34,$$039$lcssa)|0);
   $36 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($35,154151,13)|0);
   $37 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($36,$$037$lcssa)|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = ((($38)) + -12|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = (($37) + ($40)|0);
   __ZNKSt3__28ios_base6getlocEv($4,$41);
   __THREW__ = 0;
   $42 = (invoke_iii(3255,($4|0),(215188|0))|0);
   $43 = __THREW__; __THREW__ = 0;
   $44 = $43&1;
   if (!($44)) {
    $45 = HEAP32[$42>>2]|0;
    $46 = ((($45)) + 28|0);
    $47 = HEAP32[$46>>2]|0;
    __THREW__ = 0;
    $48 = (invoke_iii($47|0,($42|0),10)|0);
    $49 = __THREW__; __THREW__ = 0;
    $50 = $49&1;
    if (!($50)) {
     __ZNSt3__26localeD2Ev($4);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($37,$48)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($37)|0);
     $57 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($1,119066,34)|0);
     $58 = ((($0)) + 40|0);
     $59 = HEAP32[$58>>2]|0;
     $60 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($57,$59)|0);
     $61 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($60,154193,20)|0);
     $62 = (+($$037$lcssa>>>0));
     $63 = HEAP32[$58>>2]|0;
     $64 = (+($63>>>0));
     $65 = $62 / $64;
     $66 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEd($61,$65)|0);
     $67 = HEAP32[$66>>2]|0;
     $68 = ((($67)) + -12|0);
     $69 = HEAP32[$68>>2]|0;
     $70 = (($66) + ($69)|0);
     __ZNKSt3__28ios_base6getlocEv($3,$70);
     __THREW__ = 0;
     $71 = (invoke_iii(3255,($3|0),(215188|0))|0);
     $72 = __THREW__; __THREW__ = 0;
     $73 = $72&1;
     if (!($73)) {
      $74 = HEAP32[$71>>2]|0;
      $75 = ((($74)) + 28|0);
      $76 = HEAP32[$75>>2]|0;
      __THREW__ = 0;
      $77 = (invoke_iii($76|0,($71|0),10)|0);
      $78 = __THREW__; __THREW__ = 0;
      $79 = $78&1;
      if (!($79)) {
       __ZNSt3__26localeD2Ev($3);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($66,$77)|0);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($66)|0);
       STACKTOP = sp;return;
      }
     }
     $80 = ___cxa_find_matching_catch_2()|0;
     $81 = tempRet0;
     __THREW__ = 0;
     invoke_vi(3263,($3|0));
     $82 = __THREW__; __THREW__ = 0;
     $83 = $82&1;
     if ($83) {
      $84 = ___cxa_find_matching_catch_3(0|0)|0;
      $85 = tempRet0;
      ___clang_call_terminate($84);
      // unreachable;
     } else {
      ___resumeException($80|0);
      // unreachable;
     }
    }
   }
   $51 = ___cxa_find_matching_catch_2()|0;
   $52 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($4|0));
   $53 = __THREW__; __THREW__ = 0;
   $54 = $53&1;
   if ($54) {
    $55 = ___cxa_find_matching_catch_3(0|0)|0;
    $56 = tempRet0;
    ___clang_call_terminate($55);
    // unreachable;
   } else {
    ___resumeException($51|0);
    // unreachable;
   }
  }
 }
 $20 = ___cxa_find_matching_catch_2()|0;
 $21 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($5|0));
 $22 = __THREW__; __THREW__ = 0;
 $23 = $22&1;
 if ($23) {
  $24 = ___cxa_find_matching_catch_3(0|0)|0;
  $25 = tempRet0;
  ___clang_call_terminate($24);
  // unreachable;
 } else {
  ___resumeException($20|0);
  // unreachable;
 }
}
function __ZN3osg21GLBufferObjectManager21flushDeletedGLObjectsEdRd($0,$1,$2) {
 $0 = $0|0;
 $1 = +$1;
 $2 = $2|0;
 var $$0$i$i$i$i = 0, $$sink$i$i$i = 0.0, $$sink$i$i$i8 = 0.0, $$sroa$015$0$be = 0, $$sroa$015$038 = 0, $10 = 0, $11 = 0.0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0.0, $23 = 0, $24 = 0;
 var $25 = 0.0, $26 = 0.0, $27 = 0, $28 = 0.0, $29 = 0.0, $3 = 0, $30 = 0.0, $31 = 0.0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0.0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0.0, $68 = 0, $69 = 0, $7 = 0, $70 = 0.0, $71 = 0.0, $72 = 0, $73 = 0.0, $74 = 0.0, $75 = 0.0, $76 = 0.0, $77 = 0, $78 = 0, $8 = 0;
 var $9 = 0, $or$cond = 0, $or$cond37 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 72|0);
 $4 = (__ZN3osg5Timer8instanceEv()|0);
 $5 = (__ZNK3osg5Timer4tickEv($4)|0);
 $6 = tempRet0;
 $7 = ((($0)) + 44|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($0)) + 48|0);
 $10 = ($8|0)!=($9|0);
 $11 = +HEAPF64[$2>>3];
 $12 = $11 > 0.0;
 $or$cond37 = $10 & $12;
 L1: do {
  if ($or$cond37) {
   $$sroa$015$038 = $8;
   while(1) {
    $32 = ((($$sroa$015$038)) + 28|0);
    $33 = HEAP32[$32>>2]|0;
    __THREW__ = 0;
    invoke_vidi(3699,($33|0),0.0,($2|0));
    $34 = __THREW__; __THREW__ = 0;
    $35 = $34&1;
    if ($35) {
     break;
    }
    $36 = ((($$sroa$015$038)) + 4|0);
    $37 = HEAP32[$36>>2]|0;
    $38 = ($37|0)==(0|0);
    if ($38) {
     $39 = ((($$sroa$015$038)) + 8|0);
     $40 = HEAP32[$39>>2]|0;
     $41 = HEAP32[$40>>2]|0;
     $42 = ($41|0)==($$sroa$015$038|0);
     if ($42) {
      $$sroa$015$0$be = $40;
     } else {
      $49 = $39;
      while(1) {
       $48 = HEAP32[$49>>2]|0;
       $50 = ((($48)) + 8|0);
       $51 = HEAP32[$50>>2]|0;
       $52 = HEAP32[$51>>2]|0;
       $53 = ($52|0)==($48|0);
       if ($53) {
        $$sroa$015$0$be = $51;
        break;
       } else {
        $49 = $50;
       }
      }
     }
    } else {
     $$0$i$i$i$i = $37;
     while(1) {
      $46 = HEAP32[$$0$i$i$i$i>>2]|0;
      $47 = ($46|0)==(0|0);
      if ($47) {
       break;
      } else {
       $$0$i$i$i$i = $46;
      }
     }
     $$sroa$015$0$be = $$0$i$i$i$i;
    }
    $43 = ($$sroa$015$0$be|0)!=($9|0);
    $44 = +HEAPF64[$2>>3];
    $45 = $44 > 0.0;
    $or$cond = $43 & $45;
    if ($or$cond) {
     $$sroa$015$038 = $$sroa$015$0$be;
    } else {
     break L1;
    }
   }
   $54 = ___cxa_find_matching_catch_2()|0;
   $55 = tempRet0;
   __THREW__ = 0;
   $56 = (invoke_ii(3385,($4|0))|0);
   $57 = tempRet0;
   $58 = __THREW__; __THREW__ = 0;
   $59 = $58&1;
   if ($59) {
    $77 = ___cxa_find_matching_catch_3(0|0)|0;
    $78 = tempRet0;
    ___clang_call_terminate($77);
    // unreachable;
   }
   $60 = ($57>>>0)>($6>>>0);
   $61 = ($56>>>0)>($5>>>0);
   $62 = ($57|0)==($6|0);
   $63 = $62 & $61;
   $64 = $60 | $63;
   if ($64) {
    $65 = (_i64Subtract(($56|0),($57|0),($5|0),($6|0))|0);
    $66 = tempRet0;
    $67 = (+($65>>>0)) + (4294967296.0*(+($66>>>0)));
    $$sink$i$i$i = $67;
    $72 = ((($4)) + 8|0);
    $73 = +HEAPF64[$72>>3];
    $74 = $$sink$i$i$i * $73;
    $75 = +HEAPF64[$3>>3];
    $76 = $74 + $75;
    HEAPF64[$3>>3] = $76;
    ___resumeException($54|0);
    // unreachable;
   } else {
    $68 = (_i64Subtract(($5|0),($6|0),($56|0),($57|0))|0);
    $69 = tempRet0;
    $70 = (+($68>>>0)) + (4294967296.0*(+($69>>>0)));
    $71 = -$70;
    $$sink$i$i$i = $71;
    $72 = ((($4)) + 8|0);
    $73 = +HEAPF64[$72>>3];
    $74 = $$sink$i$i$i * $73;
    $75 = +HEAPF64[$3>>3];
    $76 = $74 + $75;
    HEAPF64[$3>>3] = $76;
    ___resumeException($54|0);
    // unreachable;
   }
  }
 } while(0);
 $13 = (__ZNK3osg5Timer4tickEv($4)|0);
 $14 = tempRet0;
 $15 = ($14>>>0)>($6>>>0);
 $16 = ($13>>>0)>($5>>>0);
 $17 = ($14|0)==($6|0);
 $18 = $17 & $16;
 $19 = $15 | $18;
 if ($19) {
  $20 = (_i64Subtract(($13|0),($14|0),($5|0),($6|0))|0);
  $21 = tempRet0;
  $22 = (+($20>>>0)) + (4294967296.0*(+($21>>>0)));
  $$sink$i$i$i8 = $22;
  $27 = ((($4)) + 8|0);
  $28 = +HEAPF64[$27>>3];
  $29 = $$sink$i$i$i8 * $28;
  $30 = +HEAPF64[$3>>3];
  $31 = $29 + $30;
  HEAPF64[$3>>3] = $31;
  return;
 } else {
  $23 = (_i64Subtract(($5|0),($6|0),($13|0),($14|0))|0);
  $24 = tempRet0;
  $25 = (+($23>>>0)) + (4294967296.0*(+($24>>>0)));
  $26 = -$25;
  $$sink$i$i$i8 = $26;
  $27 = ((($4)) + 8|0);
  $28 = +HEAPF64[$27>>3];
  $29 = $$sink$i$i$i8 * $28;
  $30 = +HEAPF64[$3>>3];
  $31 = $29 + $30;
  HEAPF64[$3>>3] = $31;
  return;
 }
}
function __ZN3osg21GLBufferObjectManager24flushAllDeletedGLObjectsEv($0) {
 $0 = $0|0;
 var $$0$i$i$i$i = 0, $$sink$i$i$i = 0.0, $$sink$i$i$i5 = 0.0, $$sroa$011$0$be = 0, $$sroa$011$032 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0.0, $19 = 0, $2 = 0, $20 = 0, $21 = 0.0, $22 = 0.0;
 var $23 = 0, $24 = 0.0, $25 = 0.0, $26 = 0.0, $27 = 0.0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0.0, $62 = 0, $63 = 0, $64 = 0.0, $65 = 0.0, $66 = 0, $67 = 0.0, $68 = 0.0, $69 = 0.0, $7 = 0, $70 = 0.0, $71 = 0, $72 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 72|0);
 $2 = (__ZN3osg5Timer8instanceEv()|0);
 $3 = (__ZNK3osg5Timer4tickEv($2)|0);
 $4 = tempRet0;
 $5 = ((($0)) + 44|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($0)) + 48|0);
 $8 = ($6|0)==($7|0);
 L1: do {
  if (!($8)) {
   $$sroa$011$032 = $6;
   while(1) {
    $28 = ((($$sroa$011$032)) + 28|0);
    $29 = HEAP32[$28>>2]|0;
    __THREW__ = 0;
    invoke_vi(3700,($29|0));
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = ((($$sroa$011$032)) + 4|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = ($33|0)==(0|0);
    if ($34) {
     $35 = ((($$sroa$011$032)) + 8|0);
     $36 = HEAP32[$35>>2]|0;
     $37 = HEAP32[$36>>2]|0;
     $38 = ($37|0)==($$sroa$011$032|0);
     if ($38) {
      $$sroa$011$0$be = $36;
     } else {
      $43 = $35;
      while(1) {
       $42 = HEAP32[$43>>2]|0;
       $44 = ((($42)) + 8|0);
       $45 = HEAP32[$44>>2]|0;
       $46 = HEAP32[$45>>2]|0;
       $47 = ($46|0)==($42|0);
       if ($47) {
        $$sroa$011$0$be = $45;
        break;
       } else {
        $43 = $44;
       }
      }
     }
    } else {
     $$0$i$i$i$i = $33;
     while(1) {
      $40 = HEAP32[$$0$i$i$i$i>>2]|0;
      $41 = ($40|0)==(0|0);
      if ($41) {
       break;
      } else {
       $$0$i$i$i$i = $40;
      }
     }
     $$sroa$011$0$be = $$0$i$i$i$i;
    }
    $39 = ($$sroa$011$0$be|0)==($7|0);
    if ($39) {
     break L1;
    } else {
     $$sroa$011$032 = $$sroa$011$0$be;
    }
   }
   $48 = ___cxa_find_matching_catch_2()|0;
   $49 = tempRet0;
   __THREW__ = 0;
   $50 = (invoke_ii(3385,($2|0))|0);
   $51 = tempRet0;
   $52 = __THREW__; __THREW__ = 0;
   $53 = $52&1;
   if ($53) {
    $71 = ___cxa_find_matching_catch_3(0|0)|0;
    $72 = tempRet0;
    ___clang_call_terminate($71);
    // unreachable;
   }
   $54 = ($51>>>0)>($4>>>0);
   $55 = ($50>>>0)>($3>>>0);
   $56 = ($51|0)==($4|0);
   $57 = $56 & $55;
   $58 = $54 | $57;
   if ($58) {
    $59 = (_i64Subtract(($50|0),($51|0),($3|0),($4|0))|0);
    $60 = tempRet0;
    $61 = (+($59>>>0)) + (4294967296.0*(+($60>>>0)));
    $$sink$i$i$i = $61;
    $66 = ((($2)) + 8|0);
    $67 = +HEAPF64[$66>>3];
    $68 = $$sink$i$i$i * $67;
    $69 = +HEAPF64[$1>>3];
    $70 = $68 + $69;
    HEAPF64[$1>>3] = $70;
    ___resumeException($48|0);
    // unreachable;
   } else {
    $62 = (_i64Subtract(($3|0),($4|0),($50|0),($51|0))|0);
    $63 = tempRet0;
    $64 = (+($62>>>0)) + (4294967296.0*(+($63>>>0)));
    $65 = -$64;
    $$sink$i$i$i = $65;
    $66 = ((($2)) + 8|0);
    $67 = +HEAPF64[$66>>3];
    $68 = $$sink$i$i$i * $67;
    $69 = +HEAPF64[$1>>3];
    $70 = $68 + $69;
    HEAPF64[$1>>3] = $70;
    ___resumeException($48|0);
    // unreachable;
   }
  }
 } while(0);
 $9 = (__ZNK3osg5Timer4tickEv($2)|0);
 $10 = tempRet0;
 $11 = ($10>>>0)>($4>>>0);
 $12 = ($9>>>0)>($3>>>0);
 $13 = ($10|0)==($4|0);
 $14 = $13 & $12;
 $15 = $11 | $14;
 if ($15) {
  $16 = (_i64Subtract(($9|0),($10|0),($3|0),($4|0))|0);
  $17 = tempRet0;
  $18 = (+($16>>>0)) + (4294967296.0*(+($17>>>0)));
  $$sink$i$i$i5 = $18;
  $23 = ((($2)) + 8|0);
  $24 = +HEAPF64[$23>>3];
  $25 = $$sink$i$i$i5 * $24;
  $26 = +HEAPF64[$1>>3];
  $27 = $25 + $26;
  HEAPF64[$1>>3] = $27;
  return;
 } else {
  $19 = (_i64Subtract(($3|0),($4|0),($9|0),($10|0))|0);
  $20 = tempRet0;
  $21 = (+($19>>>0)) + (4294967296.0*(+($20>>>0)));
  $22 = -$21;
  $$sink$i$i$i5 = $22;
  $23 = ((($2)) + 8|0);
  $24 = +HEAPF64[$23>>3];
  $25 = $$sink$i$i$i5 * $24;
  $26 = +HEAPF64[$1>>3];
  $27 = $25 + $26;
  HEAPF64[$1>>3] = $27;
  return;
 }
}
function __ZN3osg21GLBufferObjectManager18deleteAllGLObjectsEv($0) {
 $0 = $0|0;
 var $$0$i$i$i$i = 0, $$sink$i$i$i = 0.0, $$sink$i$i$i5 = 0.0, $$sroa$011$0$be = 0, $$sroa$011$032 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0.0, $19 = 0, $2 = 0, $20 = 0, $21 = 0.0, $22 = 0.0;
 var $23 = 0, $24 = 0.0, $25 = 0.0, $26 = 0.0, $27 = 0.0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0.0, $62 = 0, $63 = 0, $64 = 0.0, $65 = 0.0, $66 = 0, $67 = 0.0, $68 = 0.0, $69 = 0.0, $7 = 0, $70 = 0.0, $71 = 0, $72 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 72|0);
 $2 = (__ZN3osg5Timer8instanceEv()|0);
 $3 = (__ZNK3osg5Timer4tickEv($2)|0);
 $4 = tempRet0;
 $5 = ((($0)) + 44|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($0)) + 48|0);
 $8 = ($6|0)==($7|0);
 L1: do {
  if (!($8)) {
   $$sroa$011$032 = $6;
   while(1) {
    $28 = ((($$sroa$011$032)) + 28|0);
    $29 = HEAP32[$28>>2]|0;
    __THREW__ = 0;
    invoke_vi(3701,($29|0));
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = ((($$sroa$011$032)) + 4|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = ($33|0)==(0|0);
    if ($34) {
     $35 = ((($$sroa$011$032)) + 8|0);
     $36 = HEAP32[$35>>2]|0;
     $37 = HEAP32[$36>>2]|0;
     $38 = ($37|0)==($$sroa$011$032|0);
     if ($38) {
      $$sroa$011$0$be = $36;
     } else {
      $43 = $35;
      while(1) {
       $42 = HEAP32[$43>>2]|0;
       $44 = ((($42)) + 8|0);
       $45 = HEAP32[$44>>2]|0;
       $46 = HEAP32[$45>>2]|0;
       $47 = ($46|0)==($42|0);
       if ($47) {
        $$sroa$011$0$be = $45;
        break;
       } else {
        $43 = $44;
       }
      }
     }
    } else {
     $$0$i$i$i$i = $33;
     while(1) {
      $40 = HEAP32[$$0$i$i$i$i>>2]|0;
      $41 = ($40|0)==(0|0);
      if ($41) {
       break;
      } else {
       $$0$i$i$i$i = $40;
      }
     }
     $$sroa$011$0$be = $$0$i$i$i$i;
    }
    $39 = ($$sroa$011$0$be|0)==($7|0);
    if ($39) {
     break L1;
    } else {
     $$sroa$011$032 = $$sroa$011$0$be;
    }
   }
   $48 = ___cxa_find_matching_catch_2()|0;
   $49 = tempRet0;
   __THREW__ = 0;
   $50 = (invoke_ii(3385,($2|0))|0);
   $51 = tempRet0;
   $52 = __THREW__; __THREW__ = 0;
   $53 = $52&1;
   if ($53) {
    $71 = ___cxa_find_matching_catch_3(0|0)|0;
    $72 = tempRet0;
    ___clang_call_terminate($71);
    // unreachable;
   }
   $54 = ($51>>>0)>($4>>>0);
   $55 = ($50>>>0)>($3>>>0);
   $56 = ($51|0)==($4|0);
   $57 = $56 & $55;
   $58 = $54 | $57;
   if ($58) {
    $59 = (_i64Subtract(($50|0),($51|0),($3|0),($4|0))|0);
    $60 = tempRet0;
    $61 = (+($59>>>0)) + (4294967296.0*(+($60>>>0)));
    $$sink$i$i$i = $61;
    $66 = ((($2)) + 8|0);
    $67 = +HEAPF64[$66>>3];
    $68 = $$sink$i$i$i * $67;
    $69 = +HEAPF64[$1>>3];
    $70 = $68 + $69;
    HEAPF64[$1>>3] = $70;
    ___resumeException($48|0);
    // unreachable;
   } else {
    $62 = (_i64Subtract(($3|0),($4|0),($50|0),($51|0))|0);
    $63 = tempRet0;
    $64 = (+($62>>>0)) + (4294967296.0*(+($63>>>0)));
    $65 = -$64;
    $$sink$i$i$i = $65;
    $66 = ((($2)) + 8|0);
    $67 = +HEAPF64[$66>>3];
    $68 = $$sink$i$i$i * $67;
    $69 = +HEAPF64[$1>>3];
    $70 = $68 + $69;
    HEAPF64[$1>>3] = $70;
    ___resumeException($48|0);
    // unreachable;
   }
  }
 } while(0);
 $9 = (__ZNK3osg5Timer4tickEv($2)|0);
 $10 = tempRet0;
 $11 = ($10>>>0)>($4>>>0);
 $12 = ($9>>>0)>($3>>>0);
 $13 = ($10|0)==($4|0);
 $14 = $13 & $12;
 $15 = $11 | $14;
 if ($15) {
  $16 = (_i64Subtract(($9|0),($10|0),($3|0),($4|0))|0);
  $17 = tempRet0;
  $18 = (+($16>>>0)) + (4294967296.0*(+($17>>>0)));
  $$sink$i$i$i5 = $18;
  $23 = ((($2)) + 8|0);
  $24 = +HEAPF64[$23>>3];
  $25 = $$sink$i$i$i5 * $24;
  $26 = +HEAPF64[$1>>3];
  $27 = $25 + $26;
  HEAPF64[$1>>3] = $27;
  return;
 } else {
  $19 = (_i64Subtract(($3|0),($4|0),($9|0),($10|0))|0);
  $20 = tempRet0;
  $21 = (+($19>>>0)) + (4294967296.0*(+($20>>>0)));
  $22 = -$21;
  $$sink$i$i$i5 = $22;
  $23 = ((($2)) + 8|0);
  $24 = +HEAPF64[$23>>3];
  $25 = $$sink$i$i$i5 * $24;
  $26 = +HEAPF64[$1>>3];
  $27 = $25 + $26;
  HEAPF64[$1>>3] = $27;
  return;
 }
}
function __ZN3osg21GLBufferObjectManager19discardAllGLObjectsEv($0) {
 $0 = $0|0;
 var $$0$i$i$i$i = 0, $$sroa$02$0$be = 0, $$sroa$02$06 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 44|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 48|0);
 $4 = ($2|0)==($3|0);
 if ($4) {
  return;
 } else {
  $$sroa$02$06 = $2;
 }
 while(1) {
  $5 = ((($$sroa$02$06)) + 28|0);
  $6 = HEAP32[$5>>2]|0;
  __ZN3osg17GLBufferObjectSet25discardAllGLBufferObjectsEv($6);
  $7 = ((($$sroa$02$06)) + 4|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)==(0|0);
  if ($9) {
   $10 = ((($$sroa$02$06)) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = HEAP32[$11>>2]|0;
   $13 = ($12|0)==($$sroa$02$06|0);
   if ($13) {
    $$sroa$02$0$be = $11;
   } else {
    $18 = $10;
    while(1) {
     $17 = HEAP32[$18>>2]|0;
     $19 = ((($17)) + 8|0);
     $20 = HEAP32[$19>>2]|0;
     $21 = HEAP32[$20>>2]|0;
     $22 = ($21|0)==($17|0);
     if ($22) {
      $$sroa$02$0$be = $20;
      break;
     } else {
      $18 = $19;
     }
    }
   }
  } else {
   $$0$i$i$i$i = $8;
   while(1) {
    $15 = HEAP32[$$0$i$i$i$i>>2]|0;
    $16 = ($15|0)==(0|0);
    if ($16) {
     break;
    } else {
     $$0$i$i$i$i = $15;
    }
   }
   $$sroa$02$0$be = $$0$i$i$i$i;
  }
  $14 = ($$sroa$02$0$be|0)==($3|0);
  if ($14) {
   break;
  } else {
   $$sroa$02$06 = $$sroa$02$0$be;
  }
 }
 return;
}
function __ZN3osg17GLBufferObjectSet25discardAllGLBufferObjectsEv($0) {
 $0 = $0|0;
 var $$012 = 0, $$013 = 0, $$023$i$i = 0, $$023$i$i15 = 0, $$036 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 72|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 L1: do {
  if (!($3)) {
   $4 = ((($0)) + 28|0);
   $$036 = $2;
   while(1) {
    $5 = ((($$036)) + 8|0);
    $6 = HEAP32[$5>>2]|0;HEAP32[$5>>2] = (($6+1)|0);
    $7 = ((($$036)) + 64|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = ((($$036)) + 52|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = ($10|0)==(0|0);
    if (!($11)) {
     $12 = ((($10)) + 8|0);
     $13 = HEAP32[$12>>2]|0;HEAP32[$12>>2] = (($13+1)|0);
     $14 = HEAP32[$4>>2]|0;
     __THREW__ = 0;
     invoke_viii(3702,($10|0),($14|0),(0|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      label = 5;
      break;
     }
     $23 = HEAP32[$12>>2]|0;HEAP32[$12>>2] = (($23-1)|0);
     $24 = ($23|0)==(1);
     if ($24) {
      __THREW__ = 0;
      invoke_viii(3262,($10|0),1,1);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if ($26) {
       label = 12;
       break;
      }
     }
    }
    $27 = HEAP32[$5>>2]|0;HEAP32[$5>>2] = (($27-1)|0);
    $28 = ($27|0)==(1);
    if ($28) {
     __ZNK3osg10Referenced24signalObserversAndDeleteEbb($$036,1,1);
    }
    $29 = ($8|0)==(0|0);
    if ($29) {
     break L1;
    } else {
     $$036 = $8;
    }
   }
   if ((label|0) == 5) {
    $17 = ___cxa_find_matching_catch_2()|0;
    $18 = tempRet0;
    $19 = HEAP32[$12>>2]|0;HEAP32[$12>>2] = (($19-1)|0);
    $20 = ($19|0)==(1);
    if ($20) {
     __THREW__ = 0;
     invoke_viii(3262,($10|0),1,1);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      $105 = ___cxa_find_matching_catch_3(0|0)|0;
      $106 = tempRet0;
      ___clang_call_terminate($105);
      // unreachable;
     } else {
      $$012 = $18;$$013 = $17;
     }
    } else {
     $$012 = $18;$$013 = $17;
    }
   }
   else if ((label|0) == 12) {
    $30 = ___cxa_find_matching_catch_2()|0;
    $31 = tempRet0;
    $$012 = $31;$$013 = $30;
   }
   $32 = HEAP32[$5>>2]|0;HEAP32[$5>>2] = (($32-1)|0);
   $33 = ($32|0)==(1);
   if (!($33)) {
    ___resumeException($$013|0);
    // unreachable;
   }
   __THREW__ = 0;
   invoke_viii(3262,($$036|0),1,1);
   $34 = __THREW__; __THREW__ = 0;
   $35 = $34&1;
   if ($35) {
    $105 = ___cxa_find_matching_catch_3(0|0)|0;
    $106 = tempRet0;
    ___clang_call_terminate($105);
    // unreachable;
   } else {
    ___resumeException($$013|0);
    // unreachable;
   }
  }
 } while(0);
 HEAP32[$1>>2] = 0;
 $36 = ((($0)) + 76|0);
 HEAP32[$36>>2] = 0;
 $37 = ((($0)) + 60|0);
 $38 = ((($0)) + 68|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = ($39|0)==(0);
 L26: do {
  if (!($40)) {
   $41 = ((($0)) + 64|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = HEAP32[$37>>2]|0;
   $44 = ((($43)) + 4|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = HEAP32[$42>>2]|0;
   $47 = ((($46)) + 4|0);
   HEAP32[$47>>2] = $45;
   $48 = HEAP32[$44>>2]|0;
   HEAP32[$48>>2] = $46;
   HEAP32[$38>>2] = 0;
   $49 = ($42|0)==($37|0);
   if (!($49)) {
    $$023$i$i15 = $42;
    while(1) {
     $50 = ((($$023$i$i15)) + 4|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = ((($$023$i$i15)) + 8|0);
     $53 = HEAP32[$52>>2]|0;
     $54 = ($53|0)==(0|0);
     if (!($54)) {
      $55 = ((($53)) + 8|0);
      $56 = HEAP32[$55>>2]|0;HEAP32[$55>>2] = (($56-1)|0);
      $57 = ($56|0)==(1);
      if ($57) {
       __THREW__ = 0;
       invoke_viii(3262,($53|0),1,1);
       $58 = __THREW__; __THREW__ = 0;
       $59 = $58&1;
       if ($59) {
        break;
       }
      }
     }
     __ZdlPv($$023$i$i15);
     $60 = ($51|0)==($37|0);
     if ($60) {
      break L26;
     } else {
      $$023$i$i15 = $51;
     }
    }
    $61 = ___cxa_find_matching_catch_2()|0;
    $62 = tempRet0;
    ___cxa_call_unexpected(($61|0));
    // unreachable;
   }
  }
 } while(0);
 $63 = ((($0)) + 48|0);
 $64 = ((($0)) + 56|0);
 $65 = HEAP32[$64>>2]|0;
 $66 = ($65|0)==(0);
 L36: do {
  if (!($66)) {
   $67 = ((($0)) + 52|0);
   $68 = HEAP32[$67>>2]|0;
   $69 = HEAP32[$63>>2]|0;
   $70 = ((($69)) + 4|0);
   $71 = HEAP32[$70>>2]|0;
   $72 = HEAP32[$68>>2]|0;
   $73 = ((($72)) + 4|0);
   HEAP32[$73>>2] = $71;
   $74 = HEAP32[$70>>2]|0;
   HEAP32[$74>>2] = $72;
   HEAP32[$64>>2] = 0;
   $75 = ($68|0)==($63|0);
   if (!($75)) {
    $$023$i$i = $68;
    while(1) {
     $76 = ((($$023$i$i)) + 4|0);
     $77 = HEAP32[$76>>2]|0;
     $78 = ((($$023$i$i)) + 8|0);
     $79 = HEAP32[$78>>2]|0;
     $80 = ($79|0)==(0|0);
     if (!($80)) {
      $81 = ((($79)) + 8|0);
      $82 = HEAP32[$81>>2]|0;HEAP32[$81>>2] = (($82-1)|0);
      $83 = ($82|0)==(1);
      if ($83) {
       __THREW__ = 0;
       invoke_viii(3262,($79|0),1,1);
       $84 = __THREW__; __THREW__ = 0;
       $85 = $84&1;
       if ($85) {
        break;
       }
      }
     }
     __ZdlPv($$023$i$i);
     $86 = ($77|0)==($63|0);
     if ($86) {
      break L36;
     } else {
      $$023$i$i = $77;
     }
    }
    $87 = ___cxa_find_matching_catch_2()|0;
    $88 = tempRet0;
    ___cxa_call_unexpected(($87|0));
    // unreachable;
   }
  }
 } while(0);
 $89 = ((($0)) + 44|0);
 $90 = HEAP32[$89>>2]|0;
 HEAP32[$89>>2] = 0;
 $91 = ((($0)) + 40|0);
 $92 = HEAP32[$91>>2]|0;
 $93 = Math_imul($92, $90)|0;
 $94 = ((($0)) + 24|0);
 $95 = HEAP32[$94>>2]|0;
 $96 = ((($95)) + 36|0);
 $97 = HEAP32[$96>>2]|0;
 $98 = (($97) - ($93))|0;
 HEAP32[$96>>2] = $98;
 $99 = ((($95)) + 32|0);
 $100 = HEAP32[$99>>2]|0;
 $101 = (($100) - ($90))|0;
 HEAP32[$99>>2] = $101;
 $102 = ((($95)) + 64|0);
 $103 = HEAP32[$102>>2]|0;
 $104 = (($103) + ($90))|0;
 HEAP32[$102>>2] = $104;
 return;
}
function __ZN3osg12BufferObject17setGLBufferObjectEjPNS_14GLBufferObjectE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 60|0);
 $4 = ((($0)) + 64|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$3>>2]|0;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 2;
 $9 = ($8>>>0)>($1>>>0);
 L1: do {
  if (!($9)) {
   $10 = (($1) + 1)|0;
   $11 = ($10>>>0)>($8>>>0);
   $12 = $6;
   $13 = $5;
   if ($11) {
    $14 = (($10) - ($8))|0;
    __ZNSt3__26vectorIN3osg7ref_ptrINS1_14GLBufferObjectEEENS_9allocatorIS4_EEE8__appendEj($3,$14);
    break;
   }
   $15 = ($10>>>0)<($8>>>0);
   if ($15) {
    $16 = (($12) + ($10<<2)|0);
    $17 = ($13|0)==($16|0);
    if (!($17)) {
     $19 = $13;
     while(1) {
      $18 = ((($19)) + -4|0);
      HEAP32[$4>>2] = $18;
      $20 = HEAP32[$18>>2]|0;
      $21 = ($20|0)==(0|0);
      if (!($21)) {
       $22 = ((($20)) + 8|0);
       $23 = HEAP32[$22>>2]|0;HEAP32[$22>>2] = (($23-1)|0);
       $24 = ($23|0)==(1);
       if ($24) {
        __THREW__ = 0;
        invoke_viii(3262,($20|0),1,1);
        $25 = __THREW__; __THREW__ = 0;
        $26 = $25&1;
        if ($26) {
         break;
        }
       }
      }
      HEAP32[$18>>2] = 0;
      $27 = HEAP32[$4>>2]|0;
      $28 = ($27|0)==($16|0);
      if ($28) {
       break L1;
      } else {
       $19 = $27;
      }
     }
     $29 = ___cxa_find_matching_catch_2()|0;
     $30 = tempRet0;
     ___cxa_call_unexpected(($29|0));
     // unreachable;
    }
   }
  }
 } while(0);
 $31 = HEAP32[$3>>2]|0;
 $32 = (($31) + ($1<<2)|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ($33|0)==($2|0);
 if ($34) {
  return;
 }
 HEAP32[$32>>2] = $2;
 $35 = ($2|0)==(0|0);
 if (!($35)) {
  $36 = ((($2)) + 8|0);
  $37 = HEAP32[$36>>2]|0;HEAP32[$36>>2] = (($37+1)|0);
 }
 $38 = ($33|0)==(0|0);
 if ($38) {
  return;
 }
 $39 = ((($33)) + 8|0);
 $40 = HEAP32[$39>>2]|0;HEAP32[$39>>2] = (($40-1)|0);
 $41 = ($40|0)==(1);
 if (!($41)) {
  return;
 }
 __ZNK3osg10Referenced24signalObserversAndDeleteEbb($33,1,1);
 return;
}
function __ZNSt3__26vectorIN3osg7ref_ptrINS1_14GLBufferObjectEEENS_9allocatorIS4_EEE8__appendEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$06$i$i = 0, $$pre = 0, $$pre$i = 0, $$promoted4$i = 0, $$sroa$7$0 = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i = 0, $scevgep$i15 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) - ($5))|0;
 $7 = $6 >> 2;
 $8 = ($7>>>0)<($1>>>0);
 $9 = $5;
 if (!($8)) {
  $$promoted4$i = $5;
  $10 = $1 << 2;
  _memset(($$promoted4$i|0),0,($10|0))|0;
  $scevgep$i = (($9) + ($1<<2)|0);
  HEAP32[$4>>2] = $scevgep$i;
  return;
 }
 $11 = HEAP32[$0>>2]|0;
 $12 = (($5) - ($11))|0;
 $13 = $12 >> 2;
 $14 = (($13) + ($1))|0;
 $15 = ($14>>>0)>(1073741823);
 $16 = $11;
 if ($15) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $17 = (($3) - ($11))|0;
 $18 = $17 >> 2;
 $19 = ($18>>>0)<(536870911);
 $20 = $17 >> 1;
 $21 = ($20>>>0)<($14>>>0);
 $$sroa$speculated$i = $21 ? $14 : $20;
 $$sroa$speculated$$i = $19 ? $$sroa$speculated$i : 1073741823;
 $22 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($22) {
   $32 = 0;
  } else {
   $23 = ($$sroa$speculated$$i>>>0)>(1073741823);
   if (!($23)) {
    $29 = $$sroa$speculated$$i << 2;
    $30 = (__Znwj($29)|0);
    $32 = $30;
    break;
   }
   $24 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($24|0),(204840|0));
   $25 = __THREW__; __THREW__ = 0;
   $26 = $25&1;
   if ($26) {
    $27 = ___cxa_find_matching_catch_2()|0;
    $28 = tempRet0;
    ___cxa_free_exception(($24|0));
    ___resumeException($27|0);
    // unreachable;
   } else {
    HEAP32[$24>>2] = (99824);
    ___cxa_throw(($24|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $31 = (($32) + ($13<<2)|0);
 $33 = $31;
 $34 = (($32) + ($$sroa$speculated$$i<<2)|0);
 $35 = $34;
 $36 = $1 << 2;
 _memset(($31|0),0,($36|0))|0;
 $scevgep$i15 = (($31) + ($1<<2)|0);
 $37 = $scevgep$i15;
 $38 = ($9|0)==($16|0);
 if ($38) {
  $50 = $33;$51 = $5;$53 = $9;
 } else {
  $$06$i$i = $9;$$sroa$7$0 = $33;$41 = $31;
  while(1) {
   $39 = ((($$06$i$i)) + -4|0);
   $40 = ((($41)) + -4|0);
   $42 = HEAP32[$39>>2]|0;
   HEAP32[$40>>2] = $42;
   $43 = ($42|0)==(0|0);
   if (!($43)) {
    $44 = ((($42)) + 8|0);
    $45 = HEAP32[$44>>2]|0;HEAP32[$44>>2] = (($45+1)|0);
   }
   $46 = $$sroa$7$0;
   $47 = ((($46)) + -4|0);
   $48 = $47;
   $49 = ($39|0)==($16|0);
   if ($49) {
    break;
   } else {
    $$06$i$i = $39;$$sroa$7$0 = $48;$41 = $47;
   }
  }
  $$pre$i = HEAP32[$0>>2]|0;
  $$pre = HEAP32[$4>>2]|0;
  $50 = $48;$51 = $$pre$i;$53 = $$pre;
 }
 HEAP32[$0>>2] = $50;
 HEAP32[$4>>2] = $37;
 HEAP32[$2>>2] = $35;
 $52 = $51;
 $54 = ($53|0)==($52|0);
 L25: do {
  if (!($54)) {
   $56 = $53;
   while(1) {
    $55 = ((($56)) + -4|0);
    $57 = HEAP32[$55>>2]|0;
    $58 = ($57|0)==(0|0);
    if (!($58)) {
     $59 = ((($57)) + 8|0);
     $60 = HEAP32[$59>>2]|0;HEAP32[$59>>2] = (($60-1)|0);
     $61 = ($60|0)==(1);
     if ($61) {
      __THREW__ = 0;
      invoke_viii(3262,($57|0),1,1);
      $62 = __THREW__; __THREW__ = 0;
      $63 = $62&1;
      if ($63) {
       break;
      }
     }
    }
    HEAP32[$55>>2] = 0;
    $64 = ($55|0)==($52|0);
    if ($64) {
     break L25;
    } else {
     $56 = $55;
    }
   }
   $65 = ___cxa_find_matching_catch_2()|0;
   $66 = tempRet0;
   ___cxa_call_unexpected(($65|0));
   // unreachable;
  }
 } while(0);
 $67 = ($51|0)==(0);
 if ($67) {
  return;
 }
 $68 = $51;
 __ZdlPv($68);
 return;
}
function __ZN3osg17GLBufferObjectSet24deleteAllGLBufferObjectsEv($0) {
 $0 = $0|0;
 var $$013$lcssa = 0, $$01360 = 0, $$061 = 0, $$2 = 0, $$217 = 0, $$3 = 0, $$318 = 0, $$sink$i = 0, $$sink1$i = 0, $1 = 0, $10 = 0, $100 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 (FUNCTION_TABLE_ii[$4 & 8191]($1)|0);
 $5 = ((($0)) + 68|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if (!($7)) {
  __THREW__ = 0;
  invoke_vi(3703,($0|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if ($9) {
   $10 = ___cxa_find_matching_catch_2()|0;
   $11 = tempRet0;
   $12 = HEAP32[$1>>2]|0;
   $13 = ((($12)) + 12|0);
   $14 = HEAP32[$13>>2]|0;
   __THREW__ = 0;
   (invoke_ii($14|0,($1|0))|0);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if ($16) {
    $99 = ___cxa_find_matching_catch_3(0|0)|0;
    $100 = tempRet0;
    ___clang_call_terminate($99);
    // unreachable;
   }
   $$3 = $11;$$318 = $10;
   ___resumeException($$318|0);
   // unreachable;
  }
 }
 $17 = HEAP32[$1>>2]|0;
 $18 = ((($17)) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 (FUNCTION_TABLE_ii[$19 & 8191]($1)|0);
 $20 = ((($0)) + 72|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0|0);
 if ($22) {
  $$013$lcssa = 0;
  $91 = ((($0)) + 24|0);
  $92 = HEAP32[$91>>2]|0;
  $93 = ((($92)) + 32|0);
  $94 = HEAP32[$93>>2]|0;
  $95 = (($94) + ($$013$lcssa))|0;
  HEAP32[$93>>2] = $95;
  $96 = ((($92)) + 28|0);
  $97 = HEAP32[$96>>2]|0;
  $98 = (($97) - ($$013$lcssa))|0;
  HEAP32[$96>>2] = $98;
  __ZN3osg17GLBufferObjectSet30flushAllDeletedGLBufferObjectsEv($0);
  return;
 }
 $23 = ((($0)) + 48|0);
 $24 = ((($0)) + 56|0);
 $25 = ((($0)) + 76|0);
 $26 = ((($0)) + 28|0);
 $$01360 = 0;$$061 = $21;
 while(1) {
  $27 = ((($$061)) + 8|0);
  $28 = HEAP32[$27>>2]|0;HEAP32[$27>>2] = (($28+1)|0);
  $29 = ((($$061)) + 64|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = HEAP32[$27>>2]|0;HEAP32[$27>>2] = (($31+1)|0);
  __THREW__ = 0;
  $32 = (invoke_ii(3276,12)|0);
  $33 = __THREW__; __THREW__ = 0;
  $34 = $33&1;
  if ($34) {
   label = 13;
   break;
  }
  $35 = ((($32)) + 8|0);
  HEAP32[$35>>2] = $$061;
  $36 = HEAP32[$27>>2]|0;HEAP32[$27>>2] = (($36+1)|0);
  $37 = ((($32)) + 4|0);
  HEAP32[$37>>2] = $23;
  $38 = HEAP32[$23>>2]|0;
  HEAP32[$32>>2] = $38;
  $39 = ((($38)) + 4|0);
  HEAP32[$39>>2] = $32;
  HEAP32[$23>>2] = $32;
  $40 = HEAP32[$24>>2]|0;
  $41 = (($40) + 1)|0;
  HEAP32[$24>>2] = $41;
  $42 = HEAP32[$27>>2]|0;HEAP32[$27>>2] = (($42-1)|0);
  $43 = ($42|0)==(1);
  if ($43) {
   __THREW__ = 0;
   invoke_viii(3262,($$061|0),1,1);
   $44 = __THREW__; __THREW__ = 0;
   $45 = $44&1;
   if ($45) {
    label = 12;
    break;
   }
  }
  $46 = ((($$061)) + 60|0);
  $47 = HEAP32[$46>>2]|0;
  $48 = ($47|0)==(0|0);
  $49 = HEAP32[$29>>2]|0;
  $50 = ((($47)) + 64|0);
  $$sink$i = $48 ? $20 : $50;
  HEAP32[$$sink$i>>2] = $49;
  $51 = HEAP32[$29>>2]|0;
  $52 = ($51|0)==(0|0);
  $53 = HEAP32[$46>>2]|0;
  $54 = ((($51)) + 60|0);
  $$sink1$i = $52 ? $25 : $54;
  HEAP32[$$sink1$i>>2] = $53;
  HEAP32[$29>>2] = 0;
  HEAP32[$46>>2] = 0;
  $55 = (($$01360) + 1)|0;
  $56 = ((($$061)) + 52|0);
  $57 = HEAP32[$56>>2]|0;
  $58 = ($57|0)==(0|0);
  if (!($58)) {
   $59 = ((($57)) + 8|0);
   $60 = HEAP32[$59>>2]|0;HEAP32[$59>>2] = (($60+1)|0);
   $61 = HEAP32[$26>>2]|0;
   __THREW__ = 0;
   invoke_viii(3702,($57|0),($61|0),(0|0));
   $62 = __THREW__; __THREW__ = 0;
   $63 = $62&1;
   if ($63) {
    label = 15;
    break;
   }
   $78 = HEAP32[$59>>2]|0;HEAP32[$59>>2] = (($78-1)|0);
   $79 = ($78|0)==(1);
   if ($79) {
    __THREW__ = 0;
    invoke_viii(3262,($57|0),1,1);
    $80 = __THREW__; __THREW__ = 0;
    $81 = $80&1;
    if ($81) {
     label = 22;
     break;
    }
   }
  }
  $82 = HEAP32[$27>>2]|0;HEAP32[$27>>2] = (($82-1)|0);
  $83 = ($82|0)==(1);
  if ($83) {
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($$061,1,1);
  }
  $84 = ($30|0)==(0|0);
  if ($84) {
   $$013$lcssa = $55;
   label = 25;
   break;
  } else {
   $$01360 = $55;$$061 = $30;
  }
 }
 if ((label|0) == 12) {
  $64 = ___cxa_find_matching_catch_2()|0;
  $65 = tempRet0;
  $$2 = $65;$$217 = $64;
 }
 else if ((label|0) == 13) {
  $66 = ___cxa_find_matching_catch_2()|0;
  $67 = tempRet0;
  $68 = HEAP32[$27>>2]|0;HEAP32[$27>>2] = (($68-1)|0);
  $69 = ($68|0)==(1);
  if ($69) {
   __THREW__ = 0;
   invoke_viii(3262,($$061|0),1,1);
   $70 = __THREW__; __THREW__ = 0;
   $71 = $70&1;
   if ($71) {
    $99 = ___cxa_find_matching_catch_3(0|0)|0;
    $100 = tempRet0;
    ___clang_call_terminate($99);
    // unreachable;
   } else {
    $$2 = $67;$$217 = $66;
   }
  } else {
   $$2 = $67;$$217 = $66;
  }
 }
 else if ((label|0) == 15) {
  $72 = ___cxa_find_matching_catch_2()|0;
  $73 = tempRet0;
  $74 = HEAP32[$59>>2]|0;HEAP32[$59>>2] = (($74-1)|0);
  $75 = ($74|0)==(1);
  if ($75) {
   __THREW__ = 0;
   invoke_viii(3262,($57|0),1,1);
   $76 = __THREW__; __THREW__ = 0;
   $77 = $76&1;
   if ($77) {
    $99 = ___cxa_find_matching_catch_3(0|0)|0;
    $100 = tempRet0;
    ___clang_call_terminate($99);
    // unreachable;
   } else {
    $$2 = $73;$$217 = $72;
   }
  } else {
   $$2 = $73;$$217 = $72;
  }
 }
 else if ((label|0) == 22) {
  $85 = ___cxa_find_matching_catch_2()|0;
  $86 = tempRet0;
  $$2 = $86;$$217 = $85;
 }
 else if ((label|0) == 25) {
  $91 = ((($0)) + 24|0);
  $92 = HEAP32[$91>>2]|0;
  $93 = ((($92)) + 32|0);
  $94 = HEAP32[$93>>2]|0;
  $95 = (($94) + ($$013$lcssa))|0;
  HEAP32[$93>>2] = $95;
  $96 = ((($92)) + 28|0);
  $97 = HEAP32[$96>>2]|0;
  $98 = (($97) - ($$013$lcssa))|0;
  HEAP32[$96>>2] = $98;
  __ZN3osg17GLBufferObjectSet30flushAllDeletedGLBufferObjectsEv($0);
  return;
 }
 $87 = HEAP32[$27>>2]|0;HEAP32[$27>>2] = (($87-1)|0);
 $88 = ($87|0)==(1);
 if (!($88)) {
  $$3 = $$2;$$318 = $$217;
  ___resumeException($$318|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(3262,($$061|0),1,1);
 $89 = __THREW__; __THREW__ = 0;
 $90 = $89&1;
 if ($90) {
  $99 = ___cxa_find_matching_catch_3(0|0)|0;
  $100 = tempRet0;
  ___clang_call_terminate($99);
  // unreachable;
 } else {
  $$3 = $$2;$$318 = $$217;
  ___resumeException($$318|0);
  // unreachable;
 }
}
function __ZN3osg17GLBufferObjectSet37handlePendingOrphandedGLBufferObjectsEv($0) {
 $0 = $0|0;
 var $$023$i$i = 0, $$sink$i = 0, $$sink1$i = 0, $$sroa$019$0 = 0, $$sroa$019$028 = 0, $$sroa$019$029 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 60|0);
 $2 = ((($0)) + 68|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  return;
 }
 $5 = ((($0)) + 64|0);
 $$sroa$019$028 = HEAP32[$5>>2]|0;
 $6 = $$sroa$019$028;
 $7 = ($6|0)==($1|0);
 L4: do {
  if (!($7)) {
   $8 = ((($0)) + 48|0);
   $9 = ((($0)) + 56|0);
   $10 = ((($0)) + 72|0);
   $11 = ((($0)) + 76|0);
   $$sroa$019$029 = $$sroa$019$028;$74 = $6;
   while(1) {
    $43 = $$sroa$019$029;
    $44 = ((($43)) + 8|0);
    $45 = HEAP32[$44>>2]|0;
    $46 = ($45|0)==(0|0);
    if (!($46)) {
     $47 = ((($45)) + 8|0);
     $48 = HEAP32[$47>>2]|0;HEAP32[$47>>2] = (($48+1)|0);
    }
    __THREW__ = 0;
    $49 = (invoke_ii(3276,12)|0);
    $50 = __THREW__; __THREW__ = 0;
    $51 = $50&1;
    if ($51) {
     break;
    }
    $52 = ((($49)) + 8|0);
    HEAP32[$52>>2] = $45;
    if (!($46)) {
     $53 = ((($45)) + 8|0);
     $54 = HEAP32[$53>>2]|0;HEAP32[$53>>2] = (($54+1)|0);
    }
    $55 = ((($49)) + 4|0);
    HEAP32[$55>>2] = $8;
    $56 = HEAP32[$8>>2]|0;
    HEAP32[$49>>2] = $56;
    $57 = ((($56)) + 4|0);
    HEAP32[$57>>2] = $49;
    HEAP32[$8>>2] = $49;
    $58 = HEAP32[$9>>2]|0;
    $59 = (($58) + 1)|0;
    HEAP32[$9>>2] = $59;
    if (!($46)) {
     $60 = ((($45)) + 8|0);
     $61 = HEAP32[$60>>2]|0;HEAP32[$60>>2] = (($61-1)|0);
     $62 = ($61|0)==(1);
     if ($62) {
      __ZNK3osg10Referenced24signalObserversAndDeleteEbb($45,1,1);
     }
    }
    $63 = ((($45)) + 60|0);
    $64 = HEAP32[$63>>2]|0;
    $65 = ($64|0)==(0|0);
    $66 = ((($45)) + 64|0);
    $67 = HEAP32[$66>>2]|0;
    $68 = ((($64)) + 64|0);
    $$sink$i = $65 ? $10 : $68;
    HEAP32[$$sink$i>>2] = $67;
    $69 = HEAP32[$66>>2]|0;
    $70 = ($69|0)==(0|0);
    $71 = HEAP32[$63>>2]|0;
    $72 = ((($69)) + 60|0);
    $$sink1$i = $70 ? $11 : $72;
    HEAP32[$$sink1$i>>2] = $71;
    HEAP32[$66>>2] = 0;
    HEAP32[$63>>2] = 0;
    $73 = ((($74)) + 4|0);
    $$sroa$019$0 = HEAP32[$73>>2]|0;
    $75 = $$sroa$019$0;
    $76 = ($75|0)==($1|0);
    if ($76) {
     break L4;
    } else {
     $$sroa$019$029 = $$sroa$019$0;$74 = $75;
    }
   }
   $77 = ___cxa_find_matching_catch_2()|0;
   $78 = tempRet0;
   if ($46) {
    ___resumeException($77|0);
    // unreachable;
   }
   $79 = ((($45)) + 8|0);
   $80 = HEAP32[$79>>2]|0;HEAP32[$79>>2] = (($80-1)|0);
   $81 = ($80|0)==(1);
   if (!($81)) {
    ___resumeException($77|0);
    // unreachable;
   }
   __THREW__ = 0;
   invoke_viii(3262,($45|0),1,1);
   $82 = __THREW__; __THREW__ = 0;
   $83 = $82&1;
   if ($83) {
    $84 = ___cxa_find_matching_catch_3(0|0)|0;
    $85 = tempRet0;
    ___clang_call_terminate($84);
    // unreachable;
   } else {
    ___resumeException($77|0);
    // unreachable;
   }
  }
 } while(0);
 $12 = ((($0)) + 24|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($13)) + 32|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($15) + ($3))|0;
 HEAP32[$14>>2] = $16;
 $17 = ((($13)) + 28|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($18) - ($3))|0;
 HEAP32[$17>>2] = $19;
 $20 = HEAP32[$2>>2]|0;
 $21 = ($20|0)==(0);
 if ($21) {
  return;
 }
 $22 = HEAP32[$5>>2]|0;
 $23 = HEAP32[$1>>2]|0;
 $24 = ((($23)) + 4|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = HEAP32[$22>>2]|0;
 $27 = ((($26)) + 4|0);
 HEAP32[$27>>2] = $25;
 $28 = HEAP32[$24>>2]|0;
 HEAP32[$28>>2] = $26;
 HEAP32[$2>>2] = 0;
 $29 = ($22|0)==($1|0);
 if ($29) {
  return;
 } else {
  $$023$i$i = $22;
 }
 while(1) {
  $30 = ((($$023$i$i)) + 4|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = ((($$023$i$i)) + 8|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = ($33|0)==(0|0);
  if (!($34)) {
   $35 = ((($33)) + 8|0);
   $36 = HEAP32[$35>>2]|0;HEAP32[$35>>2] = (($36-1)|0);
   $37 = ($36|0)==(1);
   if ($37) {
    __THREW__ = 0;
    invoke_viii(3262,($33|0),1,1);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     label = 10;
     break;
    }
   }
  }
  __ZdlPv($$023$i$i);
  $40 = ($31|0)==($1|0);
  if ($40) {
   label = 24;
   break;
  } else {
   $$023$i$i = $31;
  }
 }
 if ((label|0) == 10) {
  $41 = ___cxa_find_matching_catch_2()|0;
  $42 = tempRet0;
  ___cxa_call_unexpected(($41|0));
  // unreachable;
 }
 else if ((label|0) == 24) {
  return;
 }
}
function __ZN3osg17GLBufferObjectSet30flushAllDeletedGLBufferObjectsEv($0) {
 $0 = $0|0;
 var $$023$i$i = 0, $$sroa$08$0 = 0, $$sroa$08$017 = 0, $$sroa$08$018 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 (FUNCTION_TABLE_ii[$4 & 8191]($1)|0);
 $5 = ((($0)) + 68|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if (!($7)) {
  __THREW__ = 0;
  invoke_vi(3703,($0|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if ($9) {
   $10 = ___cxa_find_matching_catch_2()|0;
   $11 = tempRet0;
   $12 = HEAP32[$1>>2]|0;
   $13 = ((($12)) + 12|0);
   $14 = HEAP32[$13>>2]|0;
   __THREW__ = 0;
   (invoke_ii($14|0,($1|0))|0);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if ($16) {
    $73 = ___cxa_find_matching_catch_3(0|0)|0;
    $74 = tempRet0;
    ___clang_call_terminate($73);
    // unreachable;
   } else {
    ___resumeException($10|0);
    // unreachable;
   }
  }
 }
 $17 = HEAP32[$1>>2]|0;
 $18 = ((($17)) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 (FUNCTION_TABLE_ii[$19 & 8191]($1)|0);
 $20 = ((($0)) + 48|0);
 $21 = ((($0)) + 52|0);
 $$sroa$08$017 = HEAP32[$21>>2]|0;
 $22 = $$sroa$08$017;
 $23 = ($22|0)==($20|0);
 if (!($23)) {
  $$sroa$08$018 = $$sroa$08$017;$70 = $22;
  while(1) {
   $66 = $$sroa$08$018;
   $67 = ((($66)) + 8|0);
   $68 = HEAP32[$67>>2]|0;
   __ZN3osg14GLBufferObject14deleteGLObjectEv($68);
   $69 = ((($70)) + 4|0);
   $$sroa$08$0 = HEAP32[$69>>2]|0;
   $71 = $$sroa$08$0;
   $72 = ($71|0)==($20|0);
   if ($72) {
    break;
   } else {
    $$sroa$08$018 = $$sroa$08$0;$70 = $71;
   }
  }
 }
 $24 = ((($0)) + 56|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ((($0)) + 44|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (($27) - ($25))|0;
 HEAP32[$26>>2] = $28;
 $29 = ((($0)) + 40|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = Math_imul($30, $25)|0;
 $32 = ((($0)) + 24|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ((($33)) + 36|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (($35) - ($31))|0;
 HEAP32[$34>>2] = $36;
 $37 = ((($33)) + 32|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (($38) - ($25))|0;
 HEAP32[$37>>2] = $39;
 $40 = ((($33)) + 64|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = (($41) + ($25))|0;
 HEAP32[$40>>2] = $42;
 $43 = HEAP32[$24>>2]|0;
 $44 = ($43|0)==(0);
 if ($44) {
  return;
 }
 $45 = HEAP32[$21>>2]|0;
 $46 = HEAP32[$20>>2]|0;
 $47 = ((($46)) + 4|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = HEAP32[$45>>2]|0;
 $50 = ((($49)) + 4|0);
 HEAP32[$50>>2] = $48;
 $51 = HEAP32[$47>>2]|0;
 HEAP32[$51>>2] = $49;
 HEAP32[$24>>2] = 0;
 $52 = ($45|0)==($20|0);
 if ($52) {
  return;
 } else {
  $$023$i$i = $45;
 }
 while(1) {
  $53 = ((($$023$i$i)) + 4|0);
  $54 = HEAP32[$53>>2]|0;
  $55 = ((($$023$i$i)) + 8|0);
  $56 = HEAP32[$55>>2]|0;
  $57 = ($56|0)==(0|0);
  if (!($57)) {
   $58 = ((($56)) + 8|0);
   $59 = HEAP32[$58>>2]|0;HEAP32[$58>>2] = (($59-1)|0);
   $60 = ($59|0)==(1);
   if ($60) {
    __THREW__ = 0;
    invoke_viii(3262,($56|0),1,1);
    $61 = __THREW__; __THREW__ = 0;
    $62 = $61&1;
    if ($62) {
     label = 11;
     break;
    }
   }
  }
  __ZdlPv($$023$i$i);
  $63 = ($54|0)==($20|0);
  if ($63) {
   label = 12;
   break;
  } else {
   $$023$i$i = $54;
  }
 }
 if ((label|0) == 11) {
  $64 = ___cxa_find_matching_catch_2()|0;
  $65 = tempRet0;
  ___cxa_call_unexpected(($64|0));
  // unreachable;
 }
 else if ((label|0) == 12) {
  return;
 }
}
function __ZN3osg14GLBufferObject14deleteGLObjectEv($0) {
 $0 = $0|0;
 var $$pre = 0, $$pre$phiZ2D = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i = 0, $scevgep5$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $2 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(5)|0);
 do {
  if ($2) {
   $3 = (__ZN3osg6notifyENS_14NotifySeverityE(5)|0);
   $4 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($3,118868,33)|0);
   $5 = ((($0)) + 16|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($4,$6)|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ((($8)) + -12|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (($7) + ($10)|0);
   __ZNKSt3__28ios_base6getlocEv($1,$11);
   __THREW__ = 0;
   $12 = (invoke_iii(3255,($1|0),(215188|0))|0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if (!($14)) {
    $15 = HEAP32[$12>>2]|0;
    $16 = ((($15)) + 28|0);
    $17 = HEAP32[$16>>2]|0;
    __THREW__ = 0;
    $18 = (invoke_iii($17|0,($12|0),10)|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __ZNSt3__26localeD2Ev($1);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($7,$18)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($7)|0);
     $$pre$phiZ2D = $5;
     break;
    }
   }
   $21 = ___cxa_find_matching_catch_2()|0;
   $22 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($1|0));
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if ($24) {
    $25 = ___cxa_find_matching_catch_3(0|0)|0;
    $26 = tempRet0;
    ___clang_call_terminate($25);
    // unreachable;
   } else {
    ___resumeException($21|0);
    // unreachable;
   }
  } else {
   $$pre = ((($0)) + 16|0);
   $$pre$phiZ2D = $$pre;
  }
 } while(0);
 $27 = HEAP32[$$pre$phiZ2D>>2]|0;
 $28 = ($27|0)==(0);
 if ($28) {
  STACKTOP = sp;return;
 }
 $29 = ((($0)) + 72|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ((($30)) + 736|0);
 $32 = HEAP32[$31>>2]|0;
 FUNCTION_TABLE_vii[$32 & 8191](1,$$pre$phiZ2D);
 HEAP32[$$pre$phiZ2D>>2] = 0;
 $33 = ((($0)) + 32|0);
 HEAP32[$33>>2] = 0;
 $34 = ((($0)) + 40|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = ((($0)) + 44|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = ($37|0)==($35|0);
 if ($38) {
  STACKTOP = sp;return;
 }
 $scevgep$i$i$i = ((($37)) + -20|0);
 $39 = $scevgep$i$i$i;
 $40 = $35;
 $41 = (($39) - ($40))|0;
 $42 = (($41>>>0) / 20)&-1;
 $43 = $42 ^ -1;
 $scevgep5$i$i$i = (($37) + (($43*20)|0)|0);
 HEAP32[$36>>2] = $scevgep5$i$i$i;
 STACKTOP = sp;return;
}
function __ZN3osg17GLBufferObjectSet27flushDeletedGLBufferObjectsEdRd($0,$1,$2) {
 $0 = $0|0;
 $1 = +$1;
 $2 = $2|0;
 var $$026$lcssa$ph = 0, $$026$lcssa101 = 0, $$02695 = 0, $$1 = 0, $$125 = 0, $$lcssa$ph = 0, $$not = 0, $$pre = 0, $$sink$i$i = 0.0, $$sink$i$i38 = 0.0, $$sroa$050$0 = 0, $$sroa$050$094 = 0, $$sroa$050$096 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = 0.0, $146 = 0, $147 = 0, $148 = 0.0, $149 = 0.0, $15 = 0, $150 = 0.0, $151 = 0.0, $152 = 0.0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0;
 var $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0;
 var $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0;
 var $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0.0, $213 = 0, $214 = 0;
 var $215 = 0.0, $216 = 0.0, $217 = 0, $218 = 0.0, $219 = 0.0, $22 = 0, $220 = 0.0, $221 = 0.0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0.0, $57 = 0, $58 = 0, $59 = 0.0, $6 = 0, $60 = 0, $61 = 0, $62 = 0.0;
 var $63 = 0.0, $64 = 0.0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $or$cond = 0, $or$cond87 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp + 8|0;
 $4 = sp + 4|0;
 $5 = sp;
 $6 = ((($0)) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($7)) + 8|0);
 $9 = HEAP32[$8>>2]|0;
 (FUNCTION_TABLE_ii[$9 & 8191]($6)|0);
 $10 = ((($0)) + 68|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0);
 if (!($12)) {
  __THREW__ = 0;
  invoke_vi(3703,($0|0));
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if ($14) {
   $15 = ___cxa_find_matching_catch_2()|0;
   $16 = tempRet0;
   $17 = HEAP32[$6>>2]|0;
   $18 = ((($17)) + 12|0);
   $19 = HEAP32[$18>>2]|0;
   __THREW__ = 0;
   (invoke_ii($19|0,($6|0))|0);
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if ($21) {
    $228 = ___cxa_find_matching_catch_3(0|0)|0;
    $229 = tempRet0;
    ___clang_call_terminate($228);
    // unreachable;
   }
   $$1 = $15;$$125 = $16;
   ___resumeException($$1|0);
   // unreachable;
  }
 }
 $22 = HEAP32[$6>>2]|0;
 $23 = ((($22)) + 12|0);
 $24 = HEAP32[$23>>2]|0;
 (FUNCTION_TABLE_ii[$24 & 8191]($6)|0);
 $25 = ((($0)) + 24|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ((($26)) + 36|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = ((($26)) + 40|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ($28>>>0)>($30>>>0);
 if (!($31)) {
  $32 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
  if (!($32)) {
   STACKTOP = sp;return;
  }
  $33 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
  $34 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($33,118902,38)|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = ((($35)) + -12|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = (($34) + ($37)|0);
  __ZNKSt3__28ios_base6getlocEv($5,$38);
  __THREW__ = 0;
  $39 = (invoke_iii(3255,($5|0),(215188|0))|0);
  $40 = __THREW__; __THREW__ = 0;
  $41 = $40&1;
  if (!($41)) {
   $42 = HEAP32[$39>>2]|0;
   $43 = ((($42)) + 28|0);
   $44 = HEAP32[$43>>2]|0;
   __THREW__ = 0;
   $45 = (invoke_iii($44|0,($39|0),10)|0);
   $46 = __THREW__; __THREW__ = 0;
   $47 = $46&1;
   if (!($47)) {
    __ZNSt3__26localeD2Ev($5);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($34,$45)|0);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($34)|0);
    STACKTOP = sp;return;
   }
  }
  $48 = ___cxa_find_matching_catch_2()|0;
  $49 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3263,($5|0));
  $50 = __THREW__; __THREW__ = 0;
  $51 = $50&1;
  if ($51) {
   $52 = ___cxa_find_matching_catch_3(0|0)|0;
   $53 = tempRet0;
   ___clang_call_terminate($52);
   // unreachable;
  } else {
   ___resumeException($48|0);
   // unreachable;
  }
 }
 $54 = ((($0)) + 56|0);
 $55 = HEAP32[$54>>2]|0;
 $$not = ($55|0)!=(0);
 $56 = +HEAPF64[$2>>3];
 $57 = !($56 <= 0.0);
 $or$cond = $$not & $57;
 if (!($or$cond)) {
  STACKTOP = sp;return;
 }
 $58 = (($28) - ($30))|0;
 $59 = (+($58>>>0));
 $60 = ((($0)) + 40|0);
 $61 = HEAP32[$60>>2]|0;
 $62 = (+($61>>>0));
 $63 = $59 / $62;
 $64 = (+Math_ceil((+$63)));
 $65 = (~~(($64))>>>0);
 $66 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
 do {
  if ($66) {
   $67 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
   $68 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($67,118941,41)|0);
   $69 = HEAP32[$25>>2]|0;
   $70 = ((($69)) + 36|0);
   $71 = HEAP32[$70>>2]|0;
   $72 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($68,$71)|0);
   $73 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($72,118983,41)|0);
   $74 = HEAP32[$25>>2]|0;
   $75 = ((($74)) + 40|0);
   $76 = HEAP32[$75>>2]|0;
   $77 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($73,$76)|0);
   $78 = HEAP32[$77>>2]|0;
   $79 = ((($78)) + -12|0);
   $80 = HEAP32[$79>>2]|0;
   $81 = (($77) + ($80)|0);
   __ZNKSt3__28ios_base6getlocEv($4,$81);
   __THREW__ = 0;
   $82 = (invoke_iii(3255,($4|0),(215188|0))|0);
   $83 = __THREW__; __THREW__ = 0;
   $84 = $83&1;
   if (!($84)) {
    $85 = HEAP32[$82>>2]|0;
    $86 = ((($85)) + 28|0);
    $87 = HEAP32[$86>>2]|0;
    __THREW__ = 0;
    $88 = (invoke_iii($87|0,($82|0),10)|0);
    $89 = __THREW__; __THREW__ = 0;
    $90 = $89&1;
    if (!($90)) {
     __ZNSt3__26localeD2Ev($4);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($77,$88)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($77)|0);
     break;
    }
   }
   $91 = ___cxa_find_matching_catch_2()|0;
   $92 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($4|0));
   $93 = __THREW__; __THREW__ = 0;
   $94 = $93&1;
   if ($94) {
    $95 = ___cxa_find_matching_catch_3(0|0)|0;
    $96 = tempRet0;
    ___clang_call_terminate($95);
    // unreachable;
   } else {
    ___resumeException($91|0);
    // unreachable;
   }
  }
 } while(0);
 $97 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
 do {
  if ($97) {
   $98 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
   $99 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($98,154000,19)|0);
   $100 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($99,$58)|0);
   $101 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($100,154020,26)|0);
   $102 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($101,$65)|0);
   $103 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($102,154047,6)|0);
   $104 = HEAP32[$54>>2]|0;
   $105 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($103,$104)|0);
   $106 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($105,154054,8)|0);
   $107 = HEAP32[$106>>2]|0;
   $108 = ((($107)) + -12|0);
   $109 = HEAP32[$108>>2]|0;
   $110 = (($106) + ($109)|0);
   __ZNKSt3__28ios_base6getlocEv($3,$110);
   __THREW__ = 0;
   $111 = (invoke_iii(3255,($3|0),(215188|0))|0);
   $112 = __THREW__; __THREW__ = 0;
   $113 = $112&1;
   if (!($113)) {
    $114 = HEAP32[$111>>2]|0;
    $115 = ((($114)) + 28|0);
    $116 = HEAP32[$115>>2]|0;
    __THREW__ = 0;
    $117 = (invoke_iii($116|0,($111|0),10)|0);
    $118 = __THREW__; __THREW__ = 0;
    $119 = $118&1;
    if (!($119)) {
     __ZNSt3__26localeD2Ev($3);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($106,$117)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($106)|0);
     break;
    }
   }
   $120 = ___cxa_find_matching_catch_2()|0;
   $121 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($3|0));
   $122 = __THREW__; __THREW__ = 0;
   $123 = $122&1;
   if ($123) {
    $124 = ___cxa_find_matching_catch_3(0|0)|0;
    $125 = tempRet0;
    ___clang_call_terminate($124);
    // unreachable;
   } else {
    ___resumeException($120|0);
    // unreachable;
   }
  }
 } while(0);
 $126 = (__ZN3osg5Timer8instanceEv()|0);
 $127 = (__ZNK3osg5Timer4tickEv($126)|0);
 $128 = tempRet0;
 $129 = ((($0)) + 52|0);
 $$sroa$050$094 = HEAP32[$129>>2]|0;
 $130 = ((($0)) + 48|0);
 $131 = $$sroa$050$094;
 $132 = ($131|0)==($130|0);
 L46: do {
  if ($132) {
   $$026$lcssa101 = 0;
   label = 43;
  } else {
   $133 = ((($126)) + 8|0);
   $$02695 = 0;$$sroa$050$096 = $$sroa$050$094;$162 = $131;
   while(1) {
    __THREW__ = 0;
    $134 = (invoke_ii(3385,($126|0))|0);
    $135 = tempRet0;
    $136 = __THREW__; __THREW__ = 0;
    $137 = $136&1;
    if ($137) {
     break L46;
    }
    $138 = ($135>>>0)>($128>>>0);
    $139 = ($134>>>0)>($127>>>0);
    $140 = ($135|0)==($128|0);
    $141 = $140 & $139;
    $142 = $138 | $141;
    if ($142) {
     $143 = (_i64Subtract(($134|0),($135|0),($127|0),($128|0))|0);
     $144 = tempRet0;
     $145 = (+($143>>>0)) + (4294967296.0*(+($144>>>0)));
     $$sink$i$i = $145;
    } else {
     $146 = (_i64Subtract(($127|0),($128|0),($134|0),($135|0))|0);
     $147 = tempRet0;
     $148 = (+($146>>>0)) + (4294967296.0*(+($147>>>0)));
     $149 = -$148;
     $$sink$i$i = $149;
    }
    $150 = +HEAPF64[$133>>3];
    $151 = $$sink$i$i * $150;
    $152 = +HEAPF64[$2>>3];
    $153 = $151 < $152;
    $154 = ($$02695>>>0)<($65>>>0);
    $or$cond87 = $154 & $153;
    if (!($or$cond87)) {
     $$026$lcssa$ph = $$02695;$$lcssa$ph = $162;
     break;
    }
    $155 = $$sroa$050$096;
    $156 = ((($155)) + 8|0);
    $157 = HEAP32[$156>>2]|0;
    __THREW__ = 0;
    invoke_vi(3704,($157|0));
    $158 = __THREW__; __THREW__ = 0;
    $159 = $158&1;
    if ($159) {
     break L46;
    }
    $160 = (($$02695) + 1)|0;
    $161 = ((($162)) + 4|0);
    $$sroa$050$0 = HEAP32[$161>>2]|0;
    $163 = $$sroa$050$0;
    $164 = ($163|0)==($130|0);
    if ($164) {
     $$026$lcssa$ph = $160;$$lcssa$ph = $130;
     break;
    } else {
     $$02695 = $160;$$sroa$050$096 = $$sroa$050$0;$162 = $163;
    }
   }
   $$pre = HEAP32[$129>>2]|0;
   $165 = ($$pre|0)==($$lcssa$ph|0);
   if ($165) {
    $$026$lcssa101 = $$026$lcssa$ph;
    label = 43;
   } else {
    $166 = HEAP32[$$lcssa$ph>>2]|0;
    $167 = ((($166)) + 4|0);
    $168 = HEAP32[$167>>2]|0;
    $169 = HEAP32[$$pre>>2]|0;
    $170 = ((($169)) + 4|0);
    HEAP32[$170>>2] = $168;
    $171 = HEAP32[$167>>2]|0;
    HEAP32[$171>>2] = $169;
    $173 = $$pre;
    while(1) {
     $172 = ((($173)) + 4|0);
     $174 = HEAP32[$172>>2]|0;
     $175 = HEAP32[$54>>2]|0;
     $176 = (($175) + -1)|0;
     HEAP32[$54>>2] = $176;
     $177 = ((($173)) + 8|0);
     $178 = HEAP32[$177>>2]|0;
     $179 = ($178|0)==(0|0);
     if (!($179)) {
      $180 = ((($178)) + 8|0);
      $181 = HEAP32[$180>>2]|0;HEAP32[$180>>2] = (($181-1)|0);
      $182 = ($181|0)==(1);
      if ($182) {
       __THREW__ = 0;
       invoke_viii(3262,($178|0),1,1);
       $183 = __THREW__; __THREW__ = 0;
       $184 = $183&1;
       if ($184) {
        break L46;
       }
      }
     }
     __ZdlPv($173);
     $185 = ($174|0)==($$lcssa$ph|0);
     if ($185) {
      $$026$lcssa101 = $$026$lcssa$ph;
      label = 43;
      break;
     } else {
      $173 = $174;
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 43) {
  $186 = ((($0)) + 44|0);
  $187 = HEAP32[$186>>2]|0;
  $188 = (($187) - ($$026$lcssa101))|0;
  HEAP32[$186>>2] = $188;
  $189 = HEAP32[$25>>2]|0;
  $190 = ((($189)) + 36|0);
  $191 = HEAP32[$190>>2]|0;
  $192 = HEAP32[$60>>2]|0;
  $193 = Math_imul($192, $$026$lcssa101)|0;
  $194 = (($191) - ($193))|0;
  HEAP32[$190>>2] = $194;
  $195 = ((($189)) + 32|0);
  $196 = HEAP32[$195>>2]|0;
  $197 = (($196) - ($$026$lcssa101))|0;
  HEAP32[$195>>2] = $197;
  $198 = ((($189)) + 64|0);
  $199 = HEAP32[$198>>2]|0;
  $200 = (($199) + ($$026$lcssa101))|0;
  HEAP32[$198>>2] = $200;
  __THREW__ = 0;
  $201 = (invoke_ii(3385,($126|0))|0);
  $202 = tempRet0;
  $203 = __THREW__; __THREW__ = 0;
  $204 = $203&1;
  if (!($204)) {
   $205 = ($202>>>0)>($128>>>0);
   $206 = ($201>>>0)>($127>>>0);
   $207 = ($202|0)==($128|0);
   $208 = $207 & $206;
   $209 = $205 | $208;
   if ($209) {
    $210 = (_i64Subtract(($201|0),($202|0),($127|0),($128|0))|0);
    $211 = tempRet0;
    $212 = (+($210>>>0)) + (4294967296.0*(+($211>>>0)));
    $$sink$i$i38 = $212;
   } else {
    $213 = (_i64Subtract(($127|0),($128|0),($201|0),($202|0))|0);
    $214 = tempRet0;
    $215 = (+($213>>>0)) + (4294967296.0*(+($214>>>0)));
    $216 = -$215;
    $$sink$i$i38 = $216;
   }
   $217 = ((($126)) + 8|0);
   $218 = +HEAPF64[$217>>3];
   $219 = $$sink$i$i38 * $218;
   $220 = +HEAPF64[$2>>3];
   $221 = $220 - $219;
   HEAPF64[$2>>3] = $221;
   (__ZNK3osg5Timer4tickEv($126)|0);
   $222 = tempRet0;
   STACKTOP = sp;return;
  }
 }
 $223 = ___cxa_find_matching_catch_2()|0;
 $224 = tempRet0;
 __THREW__ = 0;
 (invoke_ii(3385,($126|0))|0);
 $225 = tempRet0;
 $226 = __THREW__; __THREW__ = 0;
 $227 = $226&1;
 if ($227) {
  $228 = ___cxa_find_matching_catch_3(0|0)|0;
  $229 = tempRet0;
  ___clang_call_terminate($228);
  // unreachable;
 } else {
  $$1 = $223;$$125 = $224;
  ___resumeException($$1|0);
  // unreachable;
 }
}
function __ZNSt3__26__treeINS_12__value_typeIN3osg19BufferObjectProfileENS2_7ref_ptrINS2_17GLBufferObjectSetEEEEENS_19__map_value_compareIS3_S7_NS_4lessIS3_EELb1EEENS_9allocatorIS7_EEE7destroyEPNS_11__tree_nodeIS7_PvEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 }
 $3 = HEAP32[$1>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIN3osg19BufferObjectProfileENS2_7ref_ptrINS2_17GLBufferObjectSetEEEEENS_19__map_value_compareIS3_S7_NS_4lessIS3_EELb1EEENS_9allocatorIS7_EEE7destroyEPNS_11__tree_nodeIS7_PvEE($0,$3);
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIN3osg19BufferObjectProfileENS2_7ref_ptrINS2_17GLBufferObjectSetEEEEENS_19__map_value_compareIS3_S7_NS_4lessIS3_EELb1EEENS_9allocatorIS7_EEE7destroyEPNS_11__tree_nodeIS7_PvEE($0,$5);
 $6 = ((($1)) + 28|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = ((($7)) + 8|0);
  $10 = HEAP32[$9>>2]|0;HEAP32[$9>>2] = (($10-1)|0);
  $11 = ($10|0)==(1);
  if ($11) {
   __THREW__ = 0;
   invoke_viii(3262,($7|0),1,1);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if ($13) {
    $14 = ___cxa_find_matching_catch_2()|0;
    $15 = tempRet0;
    ___cxa_call_unexpected(($14|0));
    // unreachable;
   }
  }
 }
 __ZdlPv($1);
 return;
}
function __ZN3osg12BufferObjectD2Ev($0) {
 $0 = $0|0;
 var $$pre$i$i = 0, $$pre$i$i7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i11 = 0, $scevgep5$i$i$i = 0, $scevgep5$i$i$i12 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (54968);
 __THREW__ = 0;
 invoke_vii(1454,($0|0),(0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  $3 = ((($0)) + 60|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==(0|0);
  if (!($5)) {
   $6 = ((($0)) + 64|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($7|0)==($4|0);
   do {
    if ($8) {
     $22 = $4;
    } else {
     $10 = $7;
     while(1) {
      $9 = ((($10)) + -4|0);
      HEAP32[$6>>2] = $9;
      $11 = HEAP32[$9>>2]|0;
      $12 = ($11|0)==(0|0);
      if (!($12)) {
       $13 = ((($11)) + 8|0);
       $14 = HEAP32[$13>>2]|0;HEAP32[$13>>2] = (($14-1)|0);
       $15 = ($14|0)==(1);
       if ($15) {
        __THREW__ = 0;
        invoke_viii(3262,($11|0),1,1);
        $16 = __THREW__; __THREW__ = 0;
        $17 = $16&1;
        if ($17) {
         label = 8;
         break;
        }
       }
      }
      HEAP32[$9>>2] = 0;
      $18 = HEAP32[$6>>2]|0;
      $19 = ($18|0)==($4|0);
      if ($19) {
       label = 9;
       break;
      } else {
       $10 = $18;
      }
     }
     if ((label|0) == 8) {
      $20 = ___cxa_find_matching_catch_2()|0;
      $21 = tempRet0;
      ___cxa_call_unexpected(($20|0));
      // unreachable;
     }
     else if ((label|0) == 9) {
      $$pre$i$i = HEAP32[$3>>2]|0;
      $22 = $$pre$i$i;
      break;
     }
    }
   } while(0);
   __ZdlPv($22);
  }
  $23 = ((($0)) + 48|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = ($24|0)==(0|0);
  if ($25) {
   __ZN3osg6ObjectD2Ev($0);
   return;
  }
  $26 = ((($0)) + 52|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = ($27|0)==($24|0);
  if (!($28)) {
   $scevgep$i$i$i = ((($27)) + -4|0);
   $29 = $scevgep$i$i$i;
   $30 = $24;
   $31 = (($29) - ($30))|0;
   $32 = $31 >>> 2;
   $33 = $32 ^ -1;
   $scevgep5$i$i$i = (($27) + ($33<<2)|0);
   HEAP32[$26>>2] = $scevgep5$i$i$i;
  }
  __ZdlPv($24);
  __ZN3osg6ObjectD2Ev($0);
  return;
 }
 $34 = ___cxa_find_matching_catch_2()|0;
 $35 = tempRet0;
 $36 = ((($0)) + 60|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = ($37|0)==(0|0);
 if (!($38)) {
  $39 = ((($0)) + 64|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = ($40|0)==($37|0);
  do {
   if ($41) {
    $55 = $37;
   } else {
    $43 = $40;
    while(1) {
     $42 = ((($43)) + -4|0);
     HEAP32[$39>>2] = $42;
     $44 = HEAP32[$42>>2]|0;
     $45 = ($44|0)==(0|0);
     if (!($45)) {
      $46 = ((($44)) + 8|0);
      $47 = HEAP32[$46>>2]|0;HEAP32[$46>>2] = (($47-1)|0);
      $48 = ($47|0)==(1);
      if ($48) {
       __THREW__ = 0;
       invoke_viii(3262,($44|0),1,1);
       $49 = __THREW__; __THREW__ = 0;
       $50 = $49&1;
       if ($50) {
        label = 22;
        break;
       }
      }
     }
     HEAP32[$42>>2] = 0;
     $51 = HEAP32[$39>>2]|0;
     $52 = ($51|0)==($37|0);
     if ($52) {
      label = 23;
      break;
     } else {
      $43 = $51;
     }
    }
    if ((label|0) == 22) {
     $53 = ___cxa_find_matching_catch_2()|0;
     $54 = tempRet0;
     ___cxa_call_unexpected(($53|0));
     // unreachable;
    }
    else if ((label|0) == 23) {
     $$pre$i$i7 = HEAP32[$36>>2]|0;
     $55 = $$pre$i$i7;
     break;
    }
   }
  } while(0);
  __ZdlPv($55);
 }
 $56 = ((($0)) + 48|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = ($57|0)==(0|0);
 if (!($58)) {
  $59 = ((($0)) + 52|0);
  $60 = HEAP32[$59>>2]|0;
  $61 = ($60|0)==($57|0);
  if (!($61)) {
   $scevgep$i$i$i11 = ((($60)) + -4|0);
   $62 = $scevgep$i$i$i11;
   $63 = $57;
   $64 = (($62) - ($63))|0;
   $65 = $64 >>> 2;
   $66 = $65 ^ -1;
   $scevgep5$i$i$i12 = (($60) + ($66<<2)|0);
   HEAP32[$59>>2] = $scevgep5$i$i$i12;
  }
  __ZdlPv($57);
 }
 __THREW__ = 0;
 invoke_vi(388,($0|0));
 $67 = __THREW__; __THREW__ = 0;
 $68 = $67&1;
 if ($68) {
  $69 = ___cxa_find_matching_catch_3(0|0)|0;
  $70 = tempRet0;
  ___clang_call_terminate($69);
  // unreachable;
 } else {
  ___resumeException($34|0);
  // unreachable;
 }
}
function __ZN3osg12BufferObjectD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1448,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK3osg12BufferObject12isSameKindAsEPKNS_6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,23080,0)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK3osg12BufferObject11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175113|0);
}
function __ZNK3osg12BufferObject9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (119402|0);
}
function __ZN3osg12BufferObject21resizeGLObjectBuffersEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 60|0);
 $3 = ((($0)) + 64|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$2>>2]|0;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 2;
 $8 = ($7>>>0)<($1>>>0);
 $9 = $5;
 $10 = $4;
 if ($8) {
  $11 = (($1) - ($7))|0;
  __ZNSt3__26vectorIN3osg7ref_ptrINS1_14GLBufferObjectEEENS_9allocatorIS4_EEE8__appendEj($2,$11);
  return;
 }
 $12 = ($7>>>0)>($1>>>0);
 if (!($12)) {
  return;
 }
 $13 = (($9) + ($1<<2)|0);
 $14 = ($10|0)==($13|0);
 if ($14) {
  return;
 } else {
  $16 = $10;
 }
 while(1) {
  $15 = ((($16)) + -4|0);
  HEAP32[$3>>2] = $15;
  $17 = HEAP32[$15>>2]|0;
  $18 = ($17|0)==(0|0);
  if (!($18)) {
   $19 = ((($17)) + 8|0);
   $20 = HEAP32[$19>>2]|0;HEAP32[$19>>2] = (($20-1)|0);
   $21 = ($20|0)==(1);
   if ($21) {
    __THREW__ = 0;
    invoke_viii(3262,($17|0),1,1);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     label = 9;
     break;
    }
   }
  }
  HEAP32[$15>>2] = 0;
  $24 = HEAP32[$3>>2]|0;
  $25 = ($24|0)==($13|0);
  if ($25) {
   label = 10;
   break;
  } else {
   $16 = $24;
  }
 }
 if ((label|0) == 9) {
  $26 = ___cxa_find_matching_catch_2()|0;
  $27 = tempRet0;
  ___cxa_call_unexpected(($26|0));
  // unreachable;
 }
 else if ((label|0) == 10) {
  return;
 }
}
function __ZNK3osg12BufferObject16releaseGLObjectsEPNS_5StateE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$031 = 0, $$pre = 0, $$pre33 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0;
 var $205 = 0, $206 = 0, $207 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(5)|0);
 do {
  if ($3) {
   $4 = (__ZN3osg6notifyENS_14NotifySeverityE(5)|0);
   $5 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($4,119370,31)|0);
   $6 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEPKv($5,$1)|0);
   $7 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($6,174996,1)|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ((($8)) + -12|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (($7) + ($10)|0);
   __ZNKSt3__28ios_base6getlocEv($2,$11);
   __THREW__ = 0;
   $12 = (invoke_iii(3255,($2|0),(215188|0))|0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if (!($14)) {
    $15 = HEAP32[$12>>2]|0;
    $16 = ((($15)) + 28|0);
    $17 = HEAP32[$16>>2]|0;
    __THREW__ = 0;
    $18 = (invoke_iii($17|0,($12|0),10)|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __ZNSt3__26localeD2Ev($2);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($7,$18)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($7)|0);
     break;
    }
   }
   $21 = ___cxa_find_matching_catch_2()|0;
   $22 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($2|0));
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if ($24) {
    $25 = ___cxa_find_matching_catch_3(0|0)|0;
    $26 = tempRet0;
    ___clang_call_terminate($25);
    // unreachable;
   } else {
    ___resumeException($21|0);
    // unreachable;
   }
  }
 } while(0);
 $27 = ($1|0)==(0|0);
 if ($27) {
  $28 = ((($0)) + 60|0);
  $29 = ((($0)) + 64|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = HEAP32[$28>>2]|0;
  $32 = ($30|0)==($31|0);
  if ($32) {
   STACKTOP = sp;return;
  }
  $$031 = 0;$132 = $31;$138 = $30;
  L16: while(1) {
   $133 = $132;
   $134 = (($133) + ($$031<<2)|0);
   $135 = HEAP32[$134>>2]|0;
   $136 = ($135|0)==(0|0);
   if (!($136)) {
    $137 = (($138) - ($132))|0;
    $139 = $137 >> 2;
    $140 = ($139>>>0)>($$031>>>0);
    do {
     if (!($140)) {
      $141 = (($$031) + 1)|0;
      $142 = ($141>>>0)>($139>>>0);
      $143 = $132;
      $144 = $138;
      if ($142) {
       $145 = (($141) - ($139))|0;
       __ZNSt3__26vectorIN3osg7ref_ptrINS1_14GLBufferObjectEEENS_9allocatorIS4_EEE8__appendEj($28,$145);
       break;
      }
      $146 = ($141>>>0)<($139>>>0);
      if ($146) {
       $147 = (($143) + ($141<<2)|0);
       $148 = ($144|0)==($147|0);
       if (!($148)) {
        $150 = $144;
        while(1) {
         $149 = ((($150)) + -4|0);
         HEAP32[$29>>2] = $149;
         $151 = HEAP32[$149>>2]|0;
         $152 = ($151|0)==(0|0);
         if (!($152)) {
          $153 = ((($151)) + 8|0);
          $154 = HEAP32[$153>>2]|0;HEAP32[$153>>2] = (($154-1)|0);
          $155 = ($154|0)==(1);
          if ($155) {
           __THREW__ = 0;
           invoke_viii(3262,($151|0),1,1);
           $156 = __THREW__; __THREW__ = 0;
           $157 = $156&1;
           if ($157) {
            label = 57;
            break L16;
           }
          }
         }
         HEAP32[$149>>2] = 0;
         $158 = HEAP32[$29>>2]|0;
         $159 = ($158|0)==($147|0);
         if ($159) {
          break;
         } else {
          $150 = $158;
         }
        }
       }
      }
     }
    } while(0);
    $162 = HEAP32[$28>>2]|0;
    $163 = (($162) + ($$031<<2)|0);
    $164 = HEAP32[$163>>2]|0;
    $165 = ((($164)) + 56|0);
    $166 = HEAP32[$165>>2]|0;
    $167 = ($166|0)==(0|0);
    $168 = $162;
    if ($167) {
     $171 = $168;
    } else {
     __ZN3osg17GLBufferObjectSet6orphanEPNS_14GLBufferObjectE($166,$164);
     $$pre33 = HEAP32[$28>>2]|0;
     $171 = $$pre33;
    }
    $169 = HEAP32[$29>>2]|0;
    $170 = (($169) - ($171))|0;
    $172 = $170 >> 2;
    $173 = ($172>>>0)>($$031>>>0);
    do {
     if (!($173)) {
      $174 = (($$031) + 1)|0;
      $175 = ($174>>>0)>($172>>>0);
      $176 = $171;
      $177 = $169;
      if ($175) {
       $178 = (($174) - ($172))|0;
       __ZNSt3__26vectorIN3osg7ref_ptrINS1_14GLBufferObjectEEENS_9allocatorIS4_EEE8__appendEj($28,$178);
       break;
      }
      $179 = ($174>>>0)<($172>>>0);
      if ($179) {
       $180 = (($176) + ($174<<2)|0);
       $181 = ($177|0)==($180|0);
       if (!($181)) {
        $183 = $177;
        while(1) {
         $182 = ((($183)) + -4|0);
         HEAP32[$29>>2] = $182;
         $184 = HEAP32[$182>>2]|0;
         $185 = ($184|0)==(0|0);
         if (!($185)) {
          $186 = ((($184)) + 8|0);
          $187 = HEAP32[$186>>2]|0;HEAP32[$186>>2] = (($187-1)|0);
          $188 = ($187|0)==(1);
          if ($188) {
           __THREW__ = 0;
           invoke_viii(3262,($184|0),1,1);
           $189 = __THREW__; __THREW__ = 0;
           $190 = $189&1;
           if ($190) {
            label = 69;
            break L16;
           }
          }
         }
         HEAP32[$182>>2] = 0;
         $191 = HEAP32[$29>>2]|0;
         $192 = ($191|0)==($180|0);
         if ($192) {
          break;
         } else {
          $183 = $191;
         }
        }
       }
      }
     }
    } while(0);
    $195 = HEAP32[$28>>2]|0;
    $196 = (($195) + ($$031<<2)|0);
    $197 = HEAP32[$196>>2]|0;
    $198 = ($197|0)==(0|0);
    if (!($198)) {
     HEAP32[$196>>2] = 0;
     $199 = ((($197)) + 8|0);
     $200 = HEAP32[$199>>2]|0;HEAP32[$199>>2] = (($200-1)|0);
     $201 = ($200|0)==(1);
     if ($201) {
      __ZNK3osg10Referenced24signalObserversAndDeleteEbb($197,1,1);
     }
    }
   }
   $202 = (($$031) + 1)|0;
   $203 = HEAP32[$29>>2]|0;
   $204 = HEAP32[$28>>2]|0;
   $205 = (($203) - ($204))|0;
   $206 = $205 >> 2;
   $207 = ($202>>>0)<($206>>>0);
   if ($207) {
    $$031 = $202;$132 = $204;$138 = $203;
   } else {
    label = 74;
    break;
   }
  }
  if ((label|0) == 57) {
   $160 = ___cxa_find_matching_catch_2()|0;
   $161 = tempRet0;
   ___cxa_call_unexpected(($160|0));
   // unreachable;
  }
  else if ((label|0) == 69) {
   $193 = ___cxa_find_matching_catch_2()|0;
   $194 = tempRet0;
   ___cxa_call_unexpected(($193|0));
   // unreachable;
  }
  else if ((label|0) == 74) {
   STACKTOP = sp;return;
  }
 }
 $33 = ((($1)) + 124|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ((($0)) + 60|0);
 $36 = ((($0)) + 64|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = HEAP32[$35>>2]|0;
 $39 = (($37) - ($38))|0;
 $40 = $39 >> 2;
 $41 = ($40>>>0)>($34>>>0);
 L57: do {
  if (!($41)) {
   $42 = (($34) + 1)|0;
   $43 = ($42>>>0)>($40>>>0);
   $44 = $38;
   $45 = $37;
   if ($43) {
    $46 = (($42) - ($40))|0;
    __ZNSt3__26vectorIN3osg7ref_ptrINS1_14GLBufferObjectEEENS_9allocatorIS4_EEE8__appendEj($35,$46);
    break;
   }
   $47 = ($42>>>0)<($40>>>0);
   if ($47) {
    $48 = (($44) + ($42<<2)|0);
    $49 = ($45|0)==($48|0);
    if (!($49)) {
     $51 = $45;
     while(1) {
      $50 = ((($51)) + -4|0);
      HEAP32[$36>>2] = $50;
      $52 = HEAP32[$50>>2]|0;
      $53 = ($52|0)==(0|0);
      if (!($53)) {
       $54 = ((($52)) + 8|0);
       $55 = HEAP32[$54>>2]|0;HEAP32[$54>>2] = (($55-1)|0);
       $56 = ($55|0)==(1);
       if ($56) {
        __THREW__ = 0;
        invoke_viii(3262,($52|0),1,1);
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         break;
        }
       }
      }
      HEAP32[$50>>2] = 0;
      $59 = HEAP32[$36>>2]|0;
      $60 = ($59|0)==($48|0);
      if ($60) {
       break L57;
      } else {
       $51 = $59;
      }
     }
     $61 = ___cxa_find_matching_catch_2()|0;
     $62 = tempRet0;
     ___cxa_call_unexpected(($61|0));
     // unreachable;
    }
   }
  }
 } while(0);
 $63 = HEAP32[$35>>2]|0;
 $64 = (($63) + ($34<<2)|0);
 $65 = HEAP32[$64>>2]|0;
 $66 = ($65|0)==(0|0);
 if ($66) {
  STACKTOP = sp;return;
 }
 $67 = $63;
 $68 = HEAP32[$36>>2]|0;
 $69 = (($68) - ($67))|0;
 $70 = $69 >> 2;
 $71 = ($70>>>0)>($34>>>0);
 L74: do {
  if (!($71)) {
   $72 = (($34) + 1)|0;
   $73 = ($72>>>0)>($70>>>0);
   $74 = $68;
   if ($73) {
    $75 = (($72) - ($70))|0;
    __ZNSt3__26vectorIN3osg7ref_ptrINS1_14GLBufferObjectEEENS_9allocatorIS4_EEE8__appendEj($35,$75);
    break;
   }
   $76 = ($72>>>0)<($70>>>0);
   if ($76) {
    $77 = (($63) + ($72<<2)|0);
    $78 = ($74|0)==($77|0);
    if (!($78)) {
     $80 = $74;
     while(1) {
      $79 = ((($80)) + -4|0);
      HEAP32[$36>>2] = $79;
      $81 = HEAP32[$79>>2]|0;
      $82 = ($81|0)==(0|0);
      if (!($82)) {
       $83 = ((($81)) + 8|0);
       $84 = HEAP32[$83>>2]|0;HEAP32[$83>>2] = (($84-1)|0);
       $85 = ($84|0)==(1);
       if ($85) {
        __THREW__ = 0;
        invoke_viii(3262,($81|0),1,1);
        $86 = __THREW__; __THREW__ = 0;
        $87 = $86&1;
        if ($87) {
         break;
        }
       }
      }
      HEAP32[$79>>2] = 0;
      $88 = HEAP32[$36>>2]|0;
      $89 = ($88|0)==($77|0);
      if ($89) {
       break L74;
      } else {
       $80 = $88;
      }
     }
     $90 = ___cxa_find_matching_catch_2()|0;
     $91 = tempRet0;
     ___cxa_call_unexpected(($90|0));
     // unreachable;
    }
   }
  }
 } while(0);
 $92 = HEAP32[$35>>2]|0;
 $93 = (($92) + ($34<<2)|0);
 $94 = HEAP32[$93>>2]|0;
 $95 = ((($94)) + 56|0);
 $96 = HEAP32[$95>>2]|0;
 $97 = ($96|0)==(0|0);
 $98 = $92;
 if ($97) {
  $101 = $98;
 } else {
  __ZN3osg17GLBufferObjectSet6orphanEPNS_14GLBufferObjectE($96,$94);
  $$pre = HEAP32[$35>>2]|0;
  $101 = $$pre;
 }
 $99 = HEAP32[$36>>2]|0;
 $100 = (($99) - ($101))|0;
 $102 = $100 >> 2;
 $103 = ($102>>>0)>($34>>>0);
 L91: do {
  if (!($103)) {
   $104 = (($34) + 1)|0;
   $105 = ($104>>>0)>($102>>>0);
   $106 = $101;
   $107 = $99;
   if ($105) {
    $108 = (($104) - ($102))|0;
    __ZNSt3__26vectorIN3osg7ref_ptrINS1_14GLBufferObjectEEENS_9allocatorIS4_EEE8__appendEj($35,$108);
    break;
   }
   $109 = ($104>>>0)<($102>>>0);
   if ($109) {
    $110 = (($106) + ($104<<2)|0);
    $111 = ($107|0)==($110|0);
    if (!($111)) {
     $113 = $107;
     while(1) {
      $112 = ((($113)) + -4|0);
      HEAP32[$36>>2] = $112;
      $114 = HEAP32[$112>>2]|0;
      $115 = ($114|0)==(0|0);
      if (!($115)) {
       $116 = ((($114)) + 8|0);
       $117 = HEAP32[$116>>2]|0;HEAP32[$116>>2] = (($117-1)|0);
       $118 = ($117|0)==(1);
       if ($118) {
        __THREW__ = 0;
        invoke_viii(3262,($114|0),1,1);
        $119 = __THREW__; __THREW__ = 0;
        $120 = $119&1;
        if ($120) {
         break;
        }
       }
      }
      HEAP32[$112>>2] = 0;
      $121 = HEAP32[$36>>2]|0;
      $122 = ($121|0)==($110|0);
      if ($122) {
       break L91;
      } else {
       $113 = $121;
      }
     }
     $123 = ___cxa_find_matching_catch_2()|0;
     $124 = tempRet0;
     ___cxa_call_unexpected(($123|0));
     // unreachable;
    }
   }
  }
 } while(0);
 $125 = HEAP32[$35>>2]|0;
 $126 = (($125) + ($34<<2)|0);
 $127 = HEAP32[$126>>2]|0;
 $128 = ($127|0)==(0|0);
 if ($128) {
  STACKTOP = sp;return;
 }
 HEAP32[$126>>2] = 0;
 $129 = ((($127)) + 8|0);
 $130 = HEAP32[$129>>2]|0;HEAP32[$129>>2] = (($130-1)|0);
 $131 = ($130|0)==(1);
 if (!($131)) {
  STACKTOP = sp;return;
 }
 __ZNK3osg10Referenced24signalObserversAndDeleteEbb($127,1,1);
 STACKTOP = sp;return;
}
function __ZN3osg17GLBufferObjectSet6orphanEPNS_14GLBufferObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$04 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 (FUNCTION_TABLE_ii[$5 & 8191]($2)|0);
 $6 = ((($1)) + 52|0);
 HEAP32[$6>>2] = 0;
 $7 = ((($1)) + 20|0);
 HEAP32[$7>>2] = 0;
 $8 = ((($1)) + 24|0);
 HEAP32[$8>>2] = 0;
 $9 = ((($1)) + 28|0);
 HEAP32[$9>>2] = 0;
 $10 = ((($1)) + 40|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($1)) + 44|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==($11|0);
 if (!($14)) {
  $scevgep$i$i$i$i$i = ((($13)) + -20|0);
  $15 = $scevgep$i$i$i$i$i;
  $16 = $11;
  $17 = (($15) - ($16))|0;
  $18 = (($17>>>0) / 20)&-1;
  $19 = $18 ^ -1;
  $scevgep5$i$i$i$i$i = (($13) + (($19*20)|0)|0);
  HEAP32[$12>>2] = $scevgep5$i$i$i$i$i;
 }
 $20 = ((($1)) + 8|0);
 $21 = HEAP32[$20>>2]|0;HEAP32[$20>>2] = (($21+1)|0);
 $22 = ((($0)) + 60|0);
 __THREW__ = 0;
 $23 = (invoke_ii(3276,12)|0);
 $24 = __THREW__; __THREW__ = 0;
 $25 = $24&1;
 do {
  if ($25) {
   $43 = ___cxa_find_matching_catch_2()|0;
   $44 = tempRet0;
   $45 = HEAP32[$20>>2]|0;HEAP32[$20>>2] = (($45-1)|0);
   $46 = ($45|0)==(1);
   if ($46) {
    __THREW__ = 0;
    invoke_viii(3262,($1|0),1,1);
    $47 = __THREW__; __THREW__ = 0;
    $48 = $47&1;
    if ($48) {
     $54 = ___cxa_find_matching_catch_3(0|0)|0;
     $55 = tempRet0;
     ___clang_call_terminate($54);
     // unreachable;
    } else {
     $$0 = $44;$$04 = $43;
    }
   } else {
    $$0 = $44;$$04 = $43;
   }
  } else {
   $26 = ((($23)) + 8|0);
   HEAP32[$26>>2] = $1;
   $27 = HEAP32[$20>>2]|0;HEAP32[$20>>2] = (($27+1)|0);
   $28 = ((($23)) + 4|0);
   HEAP32[$28>>2] = $22;
   $29 = HEAP32[$22>>2]|0;
   HEAP32[$23>>2] = $29;
   $30 = ((($29)) + 4|0);
   HEAP32[$30>>2] = $23;
   HEAP32[$22>>2] = $23;
   $31 = ((($0)) + 68|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = (($32) + 1)|0;
   HEAP32[$31>>2] = $33;
   $34 = HEAP32[$20>>2]|0;HEAP32[$20>>2] = (($34-1)|0);
   $35 = ($34|0)==(1);
   if (!($35)) {
    $38 = HEAP32[$2>>2]|0;
    $39 = ((($38)) + 12|0);
    $40 = HEAP32[$39>>2]|0;
    (FUNCTION_TABLE_ii[$40 & 8191]($2)|0);
    return;
   }
   __THREW__ = 0;
   invoke_viii(3262,($1|0),1,1);
   $36 = __THREW__; __THREW__ = 0;
   $37 = $36&1;
   if ($37) {
    $41 = ___cxa_find_matching_catch_2()|0;
    $42 = tempRet0;
    $$0 = $42;$$04 = $41;
    break;
   } else {
    $38 = HEAP32[$2>>2]|0;
    $39 = ((($38)) + 12|0);
    $40 = HEAP32[$39>>2]|0;
    (FUNCTION_TABLE_ii[$40 & 8191]($2)|0);
    return;
   }
  }
 } while(0);
 $49 = HEAP32[$2>>2]|0;
 $50 = ((($49)) + 12|0);
 $51 = HEAP32[$50>>2]|0;
 __THREW__ = 0;
 (invoke_ii($51|0,($2|0))|0);
 $52 = __THREW__; __THREW__ = 0;
 $53 = $52&1;
 if ($53) {
  $54 = ___cxa_find_matching_catch_3(0|0)|0;
  $55 = tempRet0;
  ___clang_call_terminate($54);
  // unreachable;
 } else {
  ___resumeException($$04|0);
  // unreachable;
 }
}
function __ZN3osg10BufferDataD2Ev($0) {
 $0 = $0|0;
 var $$0 = 0, $$02 = 0, $$1 = 0, $$13 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (55116);
 __THREW__ = 0;
 invoke_vii(3554,($0|0),(0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if ($2) {
   $23 = ___cxa_find_matching_catch_2()|0;
   $24 = tempRet0;
   $25 = ((($0)) + 44|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = ($26|0)==(0|0);
   if (!($27)) {
    $28 = HEAP32[$26>>2]|0;
    $29 = ((($28)) + -12|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = (($26) + ($30)|0);
    $32 = ((($31)) + 8|0);
    $33 = HEAP32[$32>>2]|0;HEAP32[$32>>2] = (($33-1)|0);
    $34 = ($33|0)==(1);
    if ($34) {
     __THREW__ = 0;
     invoke_viii(3262,($31|0),1,1);
     $35 = __THREW__; __THREW__ = 0;
     $36 = $35&1;
     if ($36) {
      $51 = ___cxa_find_matching_catch_3(0|0)|0;
      $52 = tempRet0;
      ___clang_call_terminate($51);
      // unreachable;
     }
    }
   }
   HEAP32[$25>>2] = 0;
   $$0 = $24;$$02 = $23;
   label = 15;
  } else {
   $3 = ((($0)) + 44|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = ($4|0)==(0|0);
   if (!($5)) {
    $6 = HEAP32[$4>>2]|0;
    $7 = ((($6)) + -12|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = (($4) + ($8)|0);
    $10 = ((($9)) + 8|0);
    $11 = HEAP32[$10>>2]|0;HEAP32[$10>>2] = (($11-1)|0);
    $12 = ($11|0)==(1);
    if ($12) {
     __THREW__ = 0;
     invoke_viii(3262,($9|0),1,1);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      $37 = ___cxa_find_matching_catch_2()|0;
      $38 = tempRet0;
      $$0 = $38;$$02 = $37;
      label = 15;
      break;
     }
    }
   }
   HEAP32[$3>>2] = 0;
   $15 = ((($0)) + 40|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ($16|0)==(0|0);
   if ($17) {
    HEAP32[$15>>2] = 0;
    __ZN3osg6ObjectD2Ev($0);
    return;
   }
   $18 = ((($16)) + 8|0);
   $19 = HEAP32[$18>>2]|0;HEAP32[$18>>2] = (($19-1)|0);
   $20 = ($19|0)==(1);
   if (!($20)) {
    HEAP32[$15>>2] = 0;
    __ZN3osg6ObjectD2Ev($0);
    return;
   }
   __THREW__ = 0;
   invoke_viii(3262,($16|0),1,1);
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if ($22) {
    $39 = ___cxa_find_matching_catch_2()|0;
    $40 = tempRet0;
    $$1 = $40;$$13 = $39;
    break;
   } else {
    HEAP32[$15>>2] = 0;
    __ZN3osg6ObjectD2Ev($0);
    return;
   }
  }
 } while(0);
 if ((label|0) == 15) {
  $41 = ((($0)) + 40|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = ($42|0)==(0|0);
  if (!($43)) {
   $44 = ((($42)) + 8|0);
   $45 = HEAP32[$44>>2]|0;HEAP32[$44>>2] = (($45-1)|0);
   $46 = ($45|0)==(1);
   if ($46) {
    __THREW__ = 0;
    invoke_viii(3262,($42|0),1,1);
    $47 = __THREW__; __THREW__ = 0;
    $48 = $47&1;
    if ($48) {
     $51 = ___cxa_find_matching_catch_3(0|0)|0;
     $52 = tempRet0;
     ___clang_call_terminate($51);
     // unreachable;
    }
   }
  }
  HEAP32[$41>>2] = 0;
  $$1 = $$0;$$13 = $$02;
 }
 __THREW__ = 0;
 invoke_vi(388,($0|0));
 $49 = __THREW__; __THREW__ = 0;
 $50 = $49&1;
 if ($50) {
  $51 = ___cxa_find_matching_catch_3(0|0)|0;
  $52 = tempRet0;
  ___clang_call_terminate($51);
  // unreachable;
 } else {
  ___resumeException($$13|0);
  // unreachable;
 }
}
function __ZN3osg10BufferDataD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1265,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK3osg10BufferData12isSameKindAsEPKNS_6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,23096,0)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK3osg10BufferData11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175113|0);
}
function __ZNK3osg10BufferData9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (119466|0);
}
function __ZN3osg10BufferData21resizeGLObjectBuffersEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 40|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  return;
 }
 $5 = HEAP32[$3>>2]|0;
 $6 = ((($5)) + 132|0);
 $7 = HEAP32[$6>>2]|0;
 FUNCTION_TABLE_vii[$7 & 8191]($3,$1);
 return;
}
function __ZNK3osg10BufferData16releaseGLObjectsEPNS_5StateE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(5)|0);
 do {
  if ($3) {
   $4 = (__ZN3osg6notifyENS_14NotifySeverityE(5)|0);
   $5 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($4,119436,29)|0);
   $6 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEPKv($5,$1)|0);
   $7 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($6,174996,1)|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ((($8)) + -12|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (($7) + ($10)|0);
   __ZNKSt3__28ios_base6getlocEv($2,$11);
   __THREW__ = 0;
   $12 = (invoke_iii(3255,($2|0),(215188|0))|0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if (!($14)) {
    $15 = HEAP32[$12>>2]|0;
    $16 = ((($15)) + 28|0);
    $17 = HEAP32[$16>>2]|0;
    __THREW__ = 0;
    $18 = (invoke_iii($17|0,($12|0),10)|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __ZNSt3__26localeD2Ev($2);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($7,$18)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($7)|0);
     break;
    }
   }
   $21 = ___cxa_find_matching_catch_2()|0;
   $22 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($2|0));
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if ($24) {
    $25 = ___cxa_find_matching_catch_3(0|0)|0;
    $26 = tempRet0;
    ___clang_call_terminate($25);
    // unreachable;
   } else {
    ___resumeException($21|0);
    // unreachable;
   }
  }
 } while(0);
 $27 = ((($0)) + 40|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = ($28|0)==(0|0);
 if ($29) {
  STACKTOP = sp;return;
 }
 $30 = HEAP32[$28>>2]|0;
 $31 = ((($30)) + 136|0);
 $32 = HEAP32[$31>>2]|0;
 FUNCTION_TABLE_vii[$32 & 8191]($28,$1);
 STACKTOP = sp;return;
}
function __ZN3osg10BufferData15setBufferObjectEPNS_12BufferObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$1$i = 0, $$pr = 0, $$pre = 0, $$sroa$04$010$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = ((($0)) + 40|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==($1|0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $6 = ($4|0)==(0|0);
 if ($6) {
  $9 = 0;
 } else {
  $7 = ((($0)) + 36|0);
  $8 = HEAP32[$7>>2]|0;
  __ZN3osg12BufferObject16removeBufferDataEj($4,$8);
  $$pre = HEAP32[$3>>2]|0;
  $9 = $$pre;
 }
 $10 = ($9|0)==($1|0);
 if ($10) {
  $18 = $1;
 } else {
  HEAP32[$3>>2] = $1;
  $11 = ($1|0)==(0|0);
  if (!($11)) {
   $12 = ((($1)) + 8|0);
   $13 = HEAP32[$12>>2]|0;HEAP32[$12>>2] = (($13+1)|0);
  }
  $14 = ($9|0)==(0|0);
  if (!($14)) {
   $15 = ((($9)) + 8|0);
   $16 = HEAP32[$15>>2]|0;HEAP32[$15>>2] = (($16-1)|0);
   $17 = ($16|0)==(1);
   if ($17) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($9,1,1);
   }
  }
  $$pr = HEAP32[$3>>2]|0;
  $18 = $$pr;
 }
 $19 = ($18|0)==(0|0);
 if ($19) {
  $43 = 0;
 } else {
  HEAP32[$2>>2] = $0;
  $20 = $0;
  $21 = ((($18)) + 48|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = ((($18)) + 52|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = ($22|0)==($24|0);
  L19: do {
   if ($25) {
    label = 16;
   } else {
    $$sroa$04$010$i = $22;
    while(1) {
     $28 = HEAP32[$$sroa$04$010$i>>2]|0;
     $29 = ($28|0)==($0|0);
     $26 = ((($$sroa$04$010$i)) + 4|0);
     if ($29) {
      break;
     }
     $27 = ($26|0)==($24|0);
     if ($27) {
      label = 16;
      break L19;
     } else {
      $$sroa$04$010$i = $26;
     }
    }
    $30 = ((($0)) + 36|0);
    $31 = HEAP32[$30>>2]|0;
    $$1$i = $31;
   }
  } while(0);
  if ((label|0) == 16) {
   $32 = ((($18)) + 56|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = ($24|0)==($33|0);
   if ($34) {
    __ZNSt3__26vectorIPN3osg10BufferDataENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_($21,$2);
   } else {
    HEAP32[$24>>2] = $20;
    $35 = HEAP32[$23>>2]|0;
    $36 = ((($35)) + 4|0);
    HEAP32[$23>>2] = $36;
   }
   __ZN3osg12BufferObject5dirtyEv($18);
   $37 = HEAP32[$23>>2]|0;
   $38 = HEAP32[$21>>2]|0;
   $39 = (($37) - ($38))|0;
   $40 = $39 >> 2;
   $41 = (($40) + -1)|0;
   $$1$i = $41;
  }
  $43 = $$1$i;
 }
 $42 = ((($0)) + 36|0);
 HEAP32[$42>>2] = $43;
 STACKTOP = sp;return;
}
function __ZN3osg12BufferObject16removeBufferDataEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$015 = 0, $$015$in28 = 0, $$015$in28$phi = 0, $$01526 = 0, $$01529 = 0, $$024 = 0, $$cast27 = 0, $$pre = 0, $$pre$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep5$i$i$i = 0, $scevgep5$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = ((($0)) + 48|0);
 $4 = ((($0)) + 52|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$3>>2]|0;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 2;
 $9 = ($8>>>0)>($1>>>0);
 if (!($9)) {
  $11 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
  if (!($11)) {
   STACKTOP = sp;return;
  }
  $12 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
  $13 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($12,119477,6)|0);
  $14 = HEAP32[$0>>2]|0;
  $15 = ((($14)) + 28|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (FUNCTION_TABLE_ii[$16 & 8191]($0)|0);
  $18 = (_strlen($17)|0);
  $19 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($13,$17,$18)|0);
  $20 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($19,119484,19)|0);
  $21 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($20,$1)|0);
  $22 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($21,119504,15)|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = ((($23)) + -12|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (($22) + ($25)|0);
  __ZNKSt3__28ios_base6getlocEv($2,$26);
  __THREW__ = 0;
  $27 = (invoke_iii(3255,($2|0),(215188|0))|0);
  $28 = __THREW__; __THREW__ = 0;
  $29 = $28&1;
  if (!($29)) {
   $30 = HEAP32[$27>>2]|0;
   $31 = ((($30)) + 28|0);
   $32 = HEAP32[$31>>2]|0;
   __THREW__ = 0;
   $33 = (invoke_iii($32|0,($27|0),10)|0);
   $34 = __THREW__; __THREW__ = 0;
   $35 = $34&1;
   if (!($35)) {
    __ZNSt3__26localeD2Ev($2);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($22,$33)|0);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($22)|0);
    STACKTOP = sp;return;
   }
  }
  $36 = ___cxa_find_matching_catch_2()|0;
  $37 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3263,($2|0));
  $38 = __THREW__; __THREW__ = 0;
  $39 = $38&1;
  if ($39) {
   $40 = ___cxa_find_matching_catch_3(0|0)|0;
   $41 = tempRet0;
   ___clang_call_terminate($40);
   // unreachable;
  } else {
   ___resumeException($36|0);
   // unreachable;
  }
 }
 $$01526 = (($1) + 1)|0;
 $10 = ($$01526>>>0)<($8>>>0);
 $$cast27 = $6;
 if ($10) {
  $$015$in28 = $1;$$01529 = $$01526;
  while(1) {
   $62 = (($$cast27) + ($$01529<<2)|0);
   $63 = HEAP32[$62>>2]|0;
   $64 = ((($63)) + 36|0);
   HEAP32[$64>>2] = $$015$in28;
   $$015 = (($$01529) + 1)|0;
   $65 = ($$015>>>0)<($8>>>0);
   if ($65) {
    $$015$in28$phi = $$01529;$$01529 = $$015;$$015$in28 = $$015$in28$phi;
   } else {
    break;
   }
  }
 }
 $42 = (($$cast27) + ($1<<2)|0);
 $43 = ((($42)) + 4|0);
 $44 = $43;
 $45 = (($5) - ($44))|0;
 $46 = $45 >> 2;
 $47 = ($46|0)==(0);
 $48 = $5;
 if ($47) {
  $50 = $48;
 } else {
  _memmove(($42|0),($43|0),($45|0))|0;
  $$pre$i = HEAP32[$4>>2]|0;
  $50 = $$pre$i;
 }
 $49 = (($42) + ($46<<2)|0);
 $51 = ($50|0)==($49|0);
 if (!($51)) {
  $scevgep$i$i$i = ((($50)) + -4|0);
  $52 = $scevgep$i$i$i;
  $53 = $49;
  $54 = (($52) - ($53))|0;
  $55 = $54 >>> 2;
  $56 = $55 ^ -1;
  $scevgep5$i$i$i = (($50) + ($56<<2)|0);
  HEAP32[$4>>2] = $scevgep5$i$i$i;
 }
 $57 = ((($0)) + 60|0);
 $58 = ((($0)) + 64|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = HEAP32[$57>>2]|0;
 $61 = ($59|0)==($60|0);
 if ($61) {
  STACKTOP = sp;return;
 }
 $$024 = 0;$66 = $60;$72 = $59;
 L28: while(1) {
  $67 = $66;
  $68 = (($67) + ($$024<<2)|0);
  $69 = HEAP32[$68>>2]|0;
  $70 = ($69|0)==(0|0);
  if ($70) {
   $113 = $66;$114 = $72;
  } else {
   $71 = (($72) - ($66))|0;
   $73 = $71 >> 2;
   $74 = ($73>>>0)>($$024>>>0);
   do {
    if (!($74)) {
     $75 = (($$024) + 1)|0;
     $76 = ($75>>>0)>($73>>>0);
     $77 = $66;
     $78 = $72;
     if ($76) {
      $79 = (($75) - ($73))|0;
      __ZNSt3__26vectorIN3osg7ref_ptrINS1_14GLBufferObjectEEENS_9allocatorIS4_EEE8__appendEj($57,$79);
      break;
     }
     $80 = ($75>>>0)<($73>>>0);
     if ($80) {
      $81 = (($77) + ($75<<2)|0);
      $82 = ($78|0)==($81|0);
      if (!($82)) {
       $84 = $78;
       while(1) {
        $83 = ((($84)) + -4|0);
        HEAP32[$58>>2] = $83;
        $85 = HEAP32[$83>>2]|0;
        $86 = ($85|0)==(0|0);
        if (!($86)) {
         $87 = ((($85)) + 8|0);
         $88 = HEAP32[$87>>2]|0;HEAP32[$87>>2] = (($88-1)|0);
         $89 = ($88|0)==(1);
         if ($89) {
          __THREW__ = 0;
          invoke_viii(3262,($85|0),1,1);
          $90 = __THREW__; __THREW__ = 0;
          $91 = $90&1;
          if ($91) {
           label = 27;
           break L28;
          }
         }
        }
        HEAP32[$83>>2] = 0;
        $92 = HEAP32[$58>>2]|0;
        $93 = ($92|0)==($81|0);
        if ($93) {
         break;
        } else {
         $84 = $92;
        }
       }
      }
     }
    }
   } while(0);
   $96 = HEAP32[$57>>2]|0;
   $97 = (($96) + ($$024<<2)|0);
   $98 = HEAP32[$97>>2]|0;
   $99 = ((($98)) + 40|0);
   $100 = HEAP32[$99>>2]|0;
   $101 = ((($98)) + 44|0);
   $102 = HEAP32[$101>>2]|0;
   $103 = ($102|0)==($100|0);
   $104 = $96;
   if (!($103)) {
    $scevgep$i$i$i$i = ((($102)) + -20|0);
    $105 = $scevgep$i$i$i$i;
    $106 = $100;
    $107 = (($105) - ($106))|0;
    $108 = (($107>>>0) / 20)&-1;
    $109 = $108 ^ -1;
    $scevgep5$i$i$i$i = (($102) + (($109*20)|0)|0);
    HEAP32[$101>>2] = $scevgep5$i$i$i$i;
   }
   $110 = ((($98)) + 36|0);
   HEAP8[$110>>0] = 1;
   $$pre = HEAP32[$58>>2]|0;
   $113 = $104;$114 = $$pre;
  }
  $111 = (($$024) + 1)|0;
  $112 = (($114) - ($113))|0;
  $115 = $112 >> 2;
  $116 = ($111>>>0)<($115>>>0);
  if ($116) {
   $$024 = $111;$66 = $113;$72 = $114;
  } else {
   label = 32;
   break;
  }
 }
 if ((label|0) == 27) {
  $94 = ___cxa_find_matching_catch_2()|0;
  $95 = tempRet0;
  ___cxa_call_unexpected(($94|0));
  // unreachable;
 }
 else if ((label|0) == 32) {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__26vectorIPN3osg10BufferDataENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(1073741823);
 if ($8) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $9 = ((($0)) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) - ($4))|0;
 $12 = $11 >> 2;
 $13 = ($12>>>0)<(536870911);
 $14 = $11 >> 1;
 $15 = ($14>>>0)<($7>>>0);
 $$sroa$speculated$i = $15 ? $7 : $14;
 $$sroa$speculated$$i = $13 ? $$sroa$speculated$i : 1073741823;
 $16 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($16) {
   $26 = 0;
  } else {
   $17 = ($$sroa$speculated$$i>>>0)>(1073741823);
   if (!($17)) {
    $23 = $$sroa$speculated$$i << 2;
    $24 = (__Znwj($23)|0);
    $26 = $24;
    break;
   }
   $18 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($18|0),(204840|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if ($20) {
    $21 = ___cxa_find_matching_catch_2()|0;
    $22 = tempRet0;
    ___cxa_free_exception(($18|0));
    ___resumeException($21|0);
    // unreachable;
   } else {
    HEAP32[$18>>2] = (99824);
    ___cxa_throw(($18|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $25 = (($26) + ($6<<2)|0);
 $27 = (($26) + ($$sroa$speculated$$i<<2)|0);
 $28 = $27;
 $29 = HEAP32[$1>>2]|0;
 HEAP32[$25>>2] = $29;
 $30 = ((($25)) + 4|0);
 $31 = $30;
 $32 = (0 - ($6))|0;
 $33 = (($25) + ($32<<2)|0);
 $34 = $33;
 $35 = ($5|0)>(0);
 if ($35) {
  $36 = $4;
  _memcpy(($33|0),($36|0),($5|0))|0;
 }
 HEAP32[$0>>2] = $34;
 HEAP32[$2>>2] = $31;
 HEAP32[$9>>2] = $28;
 $37 = ($4|0)==(0);
 if ($37) {
  return;
 }
 $38 = $4;
 __ZdlPv($38);
 return;
}
function __ZN3osg12BufferObject5dirtyEv($0) {
 $0 = $0|0;
 var $$08 = 0, $$pre = 0, $$pre$pre = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 60|0);
 $2 = ((($0)) + 64|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$1>>2]|0;
 $5 = ($3|0)==($4|0);
 if ($5) {
  return;
 }
 $$08 = 0;$12 = $3;$6 = $4;
 L4: while(1) {
  $7 = $6;
  $8 = (($7) + ($$08<<2)|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($9|0)==(0|0);
  if ($10) {
   $44 = $6;$45 = $12;
  } else {
   $11 = (($12) - ($6))|0;
   $13 = $11 >> 2;
   $14 = ($13>>>0)>($$08>>>0);
   do {
    if ($14) {
     $$pre = $12;
    } else {
     $15 = (($$08) + 1)|0;
     $16 = ($15>>>0)>($13>>>0);
     $17 = $6;
     $18 = $12;
     if ($16) {
      $19 = (($15) - ($13))|0;
      __ZNSt3__26vectorIN3osg7ref_ptrINS1_14GLBufferObjectEEENS_9allocatorIS4_EEE8__appendEj($1,$19);
      $$pre$pre = HEAP32[$2>>2]|0;
      $$pre = $$pre$pre;
      break;
     }
     $20 = ($15>>>0)<($13>>>0);
     if ($20) {
      $21 = (($17) + ($15<<2)|0);
      $22 = ($18|0)==($21|0);
      if ($22) {
       $$pre = $12;
      } else {
       $24 = $18;
       while(1) {
        $23 = ((($24)) + -4|0);
        HEAP32[$2>>2] = $23;
        $25 = HEAP32[$23>>2]|0;
        $26 = ($25|0)==(0|0);
        if (!($26)) {
         $27 = ((($25)) + 8|0);
         $28 = HEAP32[$27>>2]|0;HEAP32[$27>>2] = (($28-1)|0);
         $29 = ($28|0)==(1);
         if ($29) {
          __THREW__ = 0;
          invoke_viii(3262,($25|0),1,1);
          $30 = __THREW__; __THREW__ = 0;
          $31 = $30&1;
          if ($31) {
           label = 14;
           break L4;
          }
         }
        }
        HEAP32[$23>>2] = 0;
        $32 = HEAP32[$2>>2]|0;
        $33 = ($32|0)==($21|0);
        if ($33) {
         break;
        } else {
         $24 = $32;
        }
       }
       $36 = $32;
       $$pre = $36;
      }
     } else {
      $$pre = $12;
     }
    }
   } while(0);
   $37 = HEAP32[$1>>2]|0;
   $38 = (($37) + ($$08<<2)|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = ((($39)) + 36|0);
   HEAP8[$40>>0] = 1;
   $41 = $37;
   $44 = $41;$45 = $$pre;
  }
  $42 = (($$08) + 1)|0;
  $43 = (($45) - ($44))|0;
  $46 = $43 >> 2;
  $47 = ($42>>>0)<($46>>>0);
  if ($47) {
   $$08 = $42;$12 = $45;$6 = $44;
  } else {
   label = 3;
   break;
  }
 }
 if ((label|0) == 3) {
  return;
 }
 else if ((label|0) == 14) {
  $34 = ___cxa_find_matching_catch_2()|0;
  $35 = tempRet0;
  ___cxa_call_unexpected(($34|0));
  // unreachable;
 }
}
function __ZN3osg18VertexBufferObjectD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1448,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK3osg18VertexBufferObject9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(72)|0);
 __THREW__ = 0;
 invoke_vi(3705,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $6 = ___cxa_find_matching_catch_2()|0;
  $7 = tempRet0;
  __ZdlPv($1);
  ___resumeException($6|0);
  // unreachable;
 } else {
  HEAP32[$1>>2] = (55296);
  $4 = ((($1)) + 32|0);
  HEAP32[$4>>2] = 34962;
  $5 = ((($1)) + 36|0);
  HEAP32[$5>>2] = 35044;
  return ($1|0);
 }
 return (0)|0;
}
function __ZNK3osg18VertexBufferObject5cloneERKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(72)|0);
 __THREW__ = 0;
 invoke_viii(3706,($2|0),($0|0),($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch_2()|0;
  $6 = tempRet0;
  __ZdlPv($2);
  ___resumeException($5|0);
  // unreachable;
 } else {
  HEAP32[$2>>2] = (55296);
  return ($2|0);
 }
 return (0)|0;
}
function __ZNK3osg18VertexBufferObject12isSameKindAsEPKNS_6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,23112,0)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK3osg18VertexBufferObject11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175113|0);
}
function __ZNK3osg18VertexBufferObject9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (119539|0);
}
function __ZN3osg12BufferObjectC2ERKS0_RKNS_6CopyOpE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i = 0, $scevgep5$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg6ObjectC2ERKS0_RKNS_6CopyOpE($0,$1,$2);
 HEAP32[$0>>2] = (54968);
 $3 = ((($0)) + 32|0);
 HEAP32[$3>>2] = 0;
 $4 = ((($0)) + 36|0);
 HEAP32[$4>>2] = 0;
 $5 = ((($0)) + 40|0);
 HEAP32[$5>>2] = 0;
 $6 = ((($0)) + 44|0);
 $7 = ((($1)) + 44|0);
 $8 = HEAP8[$7>>0]|0;
 HEAP8[$6>>0] = $8;
 $9 = ((($0)) + 48|0);
 HEAP32[$9>>2] = 0;
 $10 = ((($0)) + 52|0);
 HEAP32[$10>>2] = 0;
 $11 = ((($0)) + 56|0);
 HEAP32[$11>>2] = 0;
 $12 = ((($0)) + 60|0);
 __THREW__ = 0;
 $13 = (invoke_i(3285)|0);
 $14 = __THREW__; __THREW__ = 0;
 $15 = $14&1;
 if (!($15)) {
  $16 = HEAP32[$13>>2]|0;
  __THREW__ = 0;
  $17 = (invoke_ii(3286,($16|0))|0);
  $18 = __THREW__; __THREW__ = 0;
  $19 = $18&1;
  if (!($19)) {
   __THREW__ = 0;
   invoke_vii(3707,($12|0),($17|0));
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if (!($21)) {
    return;
   }
  }
 }
 $22 = ___cxa_find_matching_catch_2()|0;
 $23 = tempRet0;
 $24 = HEAP32[$9>>2]|0;
 $25 = ($24|0)==(0|0);
 if (!($25)) {
  $26 = HEAP32[$10>>2]|0;
  $27 = ($26|0)==($24|0);
  if (!($27)) {
   $scevgep$i$i$i = ((($26)) + -4|0);
   $28 = $scevgep$i$i$i;
   $29 = $24;
   $30 = (($28) - ($29))|0;
   $31 = $30 >>> 2;
   $32 = $31 ^ -1;
   $scevgep5$i$i$i = (($26) + ($32<<2)|0);
   HEAP32[$10>>2] = $scevgep5$i$i$i;
  }
  __ZdlPv($24);
 }
 __THREW__ = 0;
 invoke_vi(388,($0|0));
 $33 = __THREW__; __THREW__ = 0;
 $34 = $33&1;
 if ($34) {
  $35 = ___cxa_find_matching_catch_3(0|0)|0;
  $36 = tempRet0;
  ___clang_call_terminate($35);
  // unreachable;
 } else {
  ___resumeException($22|0);
  // unreachable;
 }
}
function __ZNSt3__26vectorIN3osg7ref_ptrINS1_14GLBufferObjectEEENS_9allocatorIS4_EEEC2Ej($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$pre$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = 0;
 $2 = ((($0)) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = ((($0)) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = ($1|0)==(0);
 if ($4) {
  return;
 }
 $5 = ($1>>>0)>(1073741823);
 if ($5) {
  __THREW__ = 0;
  invoke_vi(3307,($0|0));
  $6 = __THREW__; __THREW__ = 0;
 } else {
  $7 = $1 << 2;
  __THREW__ = 0;
  $8 = (invoke_ii(3276,($7|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   HEAP32[$0>>2] = $8;
   $11 = (($8) + ($1<<2)|0);
   $12 = ((($0)) + 8|0);
   HEAP32[$12>>2] = $11;
   _memset(($8|0),0,($7|0))|0;
   HEAP32[$2>>2] = $11;
   return;
  }
 }
 $13 = ___cxa_find_matching_catch_2()|0;
 $14 = tempRet0;
 $15 = HEAP32[$0>>2]|0;
 $16 = ($15|0)==(0|0);
 if ($16) {
  ___resumeException($13|0);
  // unreachable;
 }
 $17 = HEAP32[$2>>2]|0;
 $18 = ($17|0)==($15|0);
 do {
  if ($18) {
   $32 = $15;
  } else {
   $20 = $17;
   while(1) {
    $19 = ((($20)) + -4|0);
    HEAP32[$2>>2] = $19;
    $21 = HEAP32[$19>>2]|0;
    $22 = ($21|0)==(0|0);
    if (!($22)) {
     $23 = ((($21)) + 8|0);
     $24 = HEAP32[$23>>2]|0;HEAP32[$23>>2] = (($24-1)|0);
     $25 = ($24|0)==(1);
     if ($25) {
      __THREW__ = 0;
      invoke_viii(3262,($21|0),1,1);
      $26 = __THREW__; __THREW__ = 0;
      $27 = $26&1;
      if ($27) {
       label = 12;
       break;
      }
     }
    }
    HEAP32[$19>>2] = 0;
    $28 = HEAP32[$2>>2]|0;
    $29 = ($28|0)==($15|0);
    if ($29) {
     label = 13;
     break;
    } else {
     $20 = $28;
    }
   }
   if ((label|0) == 12) {
    $30 = ___cxa_find_matching_catch_2()|0;
    $31 = tempRet0;
    ___cxa_call_unexpected(($30|0));
    // unreachable;
   }
   else if ((label|0) == 13) {
    $$pre$i = HEAP32[$0>>2]|0;
    $32 = $$pre$i;
    break;
   }
  }
 } while(0);
 __ZdlPv($32);
 ___resumeException($13|0);
 // unreachable;
}
function __ZN3osg12BufferObjectC2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i = 0, $scevgep5$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg10ReferencedC2Ev($0);
 $1 = ((($0)) + 12|0);
 ;HEAP32[$1>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;
 $2 = ((($0)) + 24|0);
 HEAP32[$2>>2] = 2;
 $3 = ((($0)) + 28|0);
 HEAP32[$3>>2] = 0;
 HEAP32[$0>>2] = (54968);
 $4 = ((($0)) + 32|0);
 $5 = ((($0)) + 48|0);
 HEAP32[$5>>2] = 0;
 $6 = ((($0)) + 52|0);
 HEAP32[$6>>2] = 0;
 $7 = ((($0)) + 56|0);
 HEAP32[$7>>2] = 0;
 $8 = ((($0)) + 60|0);
 ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;HEAP8[$4+12>>0]=0|0;
 __THREW__ = 0;
 $9 = (invoke_i(3285)|0);
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if (!($11)) {
  $12 = HEAP32[$9>>2]|0;
  __THREW__ = 0;
  $13 = (invoke_ii(3286,($12|0))|0);
  $14 = __THREW__; __THREW__ = 0;
  $15 = $14&1;
  if (!($15)) {
   __THREW__ = 0;
   invoke_vii(3707,($8|0),($13|0));
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    return;
   }
  }
 }
 $18 = ___cxa_find_matching_catch_2()|0;
 $19 = tempRet0;
 $20 = HEAP32[$5>>2]|0;
 $21 = ($20|0)==(0|0);
 if (!($21)) {
  $22 = HEAP32[$6>>2]|0;
  $23 = ($22|0)==($20|0);
  if (!($23)) {
   $scevgep$i$i$i = ((($22)) + -4|0);
   $24 = $scevgep$i$i$i;
   $25 = $20;
   $26 = (($24) - ($25))|0;
   $27 = $26 >>> 2;
   $28 = $27 ^ -1;
   $scevgep5$i$i$i = (($22) + ($28<<2)|0);
   HEAP32[$6>>2] = $scevgep5$i$i$i;
  }
  __ZdlPv($20);
 }
 __THREW__ = 0;
 invoke_vi(388,($0|0));
 $29 = __THREW__; __THREW__ = 0;
 $30 = $29&1;
 if ($30) {
  $31 = ___cxa_find_matching_catch_3(0|0)|0;
  $32 = tempRet0;
  ___clang_call_terminate($31);
  // unreachable;
 } else {
  ___resumeException($18|0);
  // unreachable;
 }
}
function __ZN3osg19ElementBufferObjectD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1448,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK3osg19ElementBufferObject9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(72)|0);
 __THREW__ = 0;
 invoke_vi(3705,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $6 = ___cxa_find_matching_catch_2()|0;
  $7 = tempRet0;
  __ZdlPv($1);
  ___resumeException($6|0);
  // unreachable;
 } else {
  HEAP32[$1>>2] = (55444);
  $4 = ((($1)) + 32|0);
  HEAP32[$4>>2] = 34963;
  $5 = ((($1)) + 36|0);
  HEAP32[$5>>2] = 35044;
  return ($1|0);
 }
 return (0)|0;
}
function __ZNK3osg19ElementBufferObject5cloneERKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(72)|0);
 __THREW__ = 0;
 invoke_viii(3706,($2|0),($0|0),($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch_2()|0;
  $6 = tempRet0;
  __ZdlPv($2);
  ___resumeException($5|0);
  // unreachable;
 } else {
  HEAP32[$2>>2] = (55444);
  return ($2|0);
 }
 return (0)|0;
}
function __ZNK3osg19ElementBufferObject12isSameKindAsEPKNS_6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,23128,0)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK3osg19ElementBufferObject11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175113|0);
}
function __ZNK3osg19ElementBufferObject9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (119585|0);
}
function __ZN3osg17PixelBufferObjectD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1448,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK3osg17PixelBufferObject9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(72)|0);
 __THREW__ = 0;
 invoke_vii(3553,($1|0),(0|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch_2()|0;
  $5 = tempRet0;
  __ZdlPv($1);
  ___resumeException($4|0);
  // unreachable;
 } else {
  return ($1|0);
 }
 return (0)|0;
}
function __ZNK3osg17PixelBufferObject5cloneERKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(72)|0);
 __THREW__ = 0;
 invoke_viii(3706,($2|0),($0|0),($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch_2()|0;
  $6 = tempRet0;
  __ZdlPv($2);
  ___resumeException($5|0);
  // unreachable;
 } else {
  HEAP32[$2>>2] = (55592);
  return ($2|0);
 }
 return (0)|0;
}
function __ZNK3osg17PixelBufferObject12isSameKindAsEPKNS_6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,23144,0)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK3osg17PixelBufferObject11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175113|0);
}
function __ZNK3osg17PixelBufferObject9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (119633|0);
}
function __ZN3osg17PixelBufferObjectC2EPNS_5ImageE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$pre$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0;
 var $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 __ZN3osg12BufferObjectC2Ev($0);
 HEAP32[$0>>2] = (55592);
 $3 = ((($0)) + 32|0);
 HEAP32[$3>>2] = 35052;
 $4 = ((($0)) + 36|0);
 HEAP32[$4>>2] = 35040;
 __THREW__ = 0;
 $5 = (invoke_ii(3265,5)|0);
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 L1: do {
  if ($7) {
   label = 15;
  } else {
   do {
    if ($5) {
     __THREW__ = 0;
     $8 = (invoke_ii(3266,5)|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      label = 15;
      break L1;
     }
     __THREW__ = 0;
     $11 = (invoke_iiii(3267,($8|0),(119651|0),41)|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      label = 15;
      break L1;
     }
     __THREW__ = 0;
     $14 = (invoke_iii(3275,($11|0),($1|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      label = 15;
      break L1;
     }
     $17 = HEAP32[$14>>2]|0;
     $18 = ((($17)) + -12|0);
     $19 = HEAP32[$18>>2]|0;
     $20 = (($14) + ($19)|0);
     __THREW__ = 0;
     invoke_vii(3257,($2|0),($20|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      label = 15;
      break L1;
     }
     __THREW__ = 0;
     $23 = (invoke_iii(3255,($2|0),(215188|0))|0);
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if (!($25)) {
      $26 = HEAP32[$23>>2]|0;
      $27 = ((($26)) + 28|0);
      $28 = HEAP32[$27>>2]|0;
      __THREW__ = 0;
      $29 = (invoke_iii($28|0,($23|0),10)|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if (!($31)) {
       __THREW__ = 0;
       invoke_vi(3263,($2|0));
       $38 = __THREW__; __THREW__ = 0;
       $39 = $38&1;
       if ($39) {
        label = 15;
        break L1;
       }
       __THREW__ = 0;
       (invoke_iii(3268,($14|0),($29|0))|0);
       $40 = __THREW__; __THREW__ = 0;
       $41 = $40&1;
       if ($41) {
        label = 15;
        break L1;
       }
       __THREW__ = 0;
       (invoke_ii(3269,($14|0))|0);
       $42 = __THREW__; __THREW__ = 0;
       $43 = $42&1;
       if ($43) {
        label = 15;
        break L1;
       } else {
        break;
       }
      }
     }
     $32 = ___cxa_find_matching_catch_2()|0;
     $33 = tempRet0;
     __THREW__ = 0;
     invoke_vi(3263,($2|0));
     $34 = __THREW__; __THREW__ = 0;
     $35 = $34&1;
     if ($35) {
      $36 = ___cxa_find_matching_catch_3(0|0)|0;
      $37 = tempRet0;
      ___clang_call_terminate($36);
      // unreachable;
     } else {
      $eh$lpad$body$index2Z2D = $33;$eh$lpad$body$indexZ2D = $32;
      break L1;
     }
    }
   } while(0);
   $48 = ($1|0)==(0|0);
   if ($48) {
    STACKTOP = sp;return;
   }
   $49 = ((($0)) + 48|0);
   $50 = ((($0)) + 52|0);
   $51 = HEAP32[$50>>2]|0;
   $52 = HEAP32[$49>>2]|0;
   $53 = ($51|0)==($52|0);
   $54 = $52;
   if ($53) {
    __THREW__ = 0;
    invoke_vii(3708,($49|0),1);
    $55 = __THREW__; __THREW__ = 0;
    $56 = $55&1;
    if ($56) {
     label = 15;
     break;
    }
    $$pre$i = HEAP32[$49>>2]|0;
    $57 = $$pre$i;
   } else {
    $57 = $54;
   }
   HEAP32[$57>>2] = $1;
   STACKTOP = sp;return;
  }
 } while(0);
 if ((label|0) == 15) {
  $44 = ___cxa_find_matching_catch_2()|0;
  $45 = tempRet0;
  $eh$lpad$body$index2Z2D = $45;$eh$lpad$body$indexZ2D = $44;
 }
 __THREW__ = 0;
 invoke_vi(1448,($0|0));
 $46 = __THREW__; __THREW__ = 0;
 $47 = $46&1;
 if ($47) {
  $58 = ___cxa_find_matching_catch_3(0|0)|0;
  $59 = tempRet0;
  ___clang_call_terminate($58);
  // unreachable;
 } else {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
}
function __ZNSt3__26vectorIPN3osg10BufferDataENS_9allocatorIS3_EEE8__appendEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i = 0, $$0$i16 = 0, $$sroa$15$0 = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) - ($5))|0;
 $7 = $6 >> 2;
 $8 = ($7>>>0)<($1>>>0);
 if (!($8)) {
  $9 = $5;
  $$0$i = $1;$10 = $9;
  while(1) {
   HEAP32[$10>>2] = 0;
   $11 = HEAP32[$4>>2]|0;
   $12 = ((($11)) + 4|0);
   HEAP32[$4>>2] = $12;
   $13 = (($$0$i) + -1)|0;
   $14 = ($13|0)==(0);
   if ($14) {
    break;
   } else {
    $$0$i = $13;$10 = $12;
   }
  }
  return;
 }
 $15 = HEAP32[$0>>2]|0;
 $16 = (($5) - ($15))|0;
 $17 = $16 >> 2;
 $18 = (($17) + ($1))|0;
 $19 = ($18>>>0)>(1073741823);
 if ($19) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $20 = (($3) - ($15))|0;
 $21 = $20 >> 2;
 $22 = ($21>>>0)<(536870911);
 $23 = $20 >> 1;
 $24 = ($23>>>0)<($18>>>0);
 $$sroa$speculated$i = $24 ? $18 : $23;
 $$sroa$speculated$$i = $22 ? $$sroa$speculated$i : 1073741823;
 $25 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($25) {
   $35 = 0;
  } else {
   $26 = ($$sroa$speculated$$i>>>0)>(1073741823);
   if (!($26)) {
    $32 = $$sroa$speculated$$i << 2;
    $33 = (__Znwj($32)|0);
    $35 = $33;
    break;
   }
   $27 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($27|0),(204840|0));
   $28 = __THREW__; __THREW__ = 0;
   $29 = $28&1;
   if ($29) {
    $30 = ___cxa_find_matching_catch_2()|0;
    $31 = tempRet0;
    ___cxa_free_exception(($27|0));
    ___resumeException($30|0);
    // unreachable;
   } else {
    HEAP32[$27>>2] = (99824);
    ___cxa_throw(($27|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $34 = (($35) + ($17<<2)|0);
 $36 = $34;
 $37 = (($35) + ($$sroa$speculated$$i<<2)|0);
 $$0$i16 = $1;$$sroa$15$0 = $36;$38 = $34;
 while(1) {
  HEAP32[$38>>2] = 0;
  $39 = $$sroa$15$0;
  $40 = ((($39)) + 4|0);
  $41 = $40;
  $42 = (($$0$i16) + -1)|0;
  $43 = ($42|0)==(0);
  if ($43) {
   break;
  } else {
   $$0$i16 = $42;$$sroa$15$0 = $41;$38 = $40;
  }
 }
 $44 = $37;
 $45 = HEAP32[$0>>2]|0;
 $46 = HEAP32[$4>>2]|0;
 $47 = $45;
 $48 = (($46) - ($47))|0;
 $49 = $48 >> 2;
 $50 = (0 - ($49))|0;
 $51 = (($34) + ($50<<2)|0);
 $52 = $51;
 $53 = ($48|0)>(0);
 if ($53) {
  _memcpy(($51|0),($45|0),($48|0))|0;
 }
 HEAP32[$0>>2] = $52;
 HEAP32[$4>>2] = $41;
 HEAP32[$2>>2] = $44;
 $54 = ($45|0)==(0|0);
 if ($54) {
  return;
 }
 __ZdlPv($45);
 return;
}
function __ZNK3osg12BufferObject25getOrCreateGLBufferObjectEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$pr = 0, $$pre = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = ((($0)) + 60|0);
 $4 = ((($0)) + 64|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$3>>2]|0;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 2;
 $9 = ($8>>>0)>($1>>>0);
 L1: do {
  if (!($9)) {
   $10 = (($1) + 1)|0;
   $11 = ($10>>>0)>($8>>>0);
   $12 = $6;
   $13 = $5;
   if ($11) {
    $14 = (($10) - ($8))|0;
    __ZNSt3__26vectorIN3osg7ref_ptrINS1_14GLBufferObjectEEENS_9allocatorIS4_EEE8__appendEj($3,$14);
    break;
   }
   $15 = ($10>>>0)<($8>>>0);
   if ($15) {
    $16 = (($12) + ($10<<2)|0);
    $17 = ($13|0)==($16|0);
    if (!($17)) {
     $19 = $13;
     while(1) {
      $18 = ((($19)) + -4|0);
      HEAP32[$4>>2] = $18;
      $20 = HEAP32[$18>>2]|0;
      $21 = ($20|0)==(0|0);
      if (!($21)) {
       $22 = ((($20)) + 8|0);
       $23 = HEAP32[$22>>2]|0;HEAP32[$22>>2] = (($23-1)|0);
       $24 = ($23|0)==(1);
       if ($24) {
        __THREW__ = 0;
        invoke_viii(3262,($20|0),1,1);
        $25 = __THREW__; __THREW__ = 0;
        $26 = $25&1;
        if ($26) {
         break;
        }
       }
      }
      HEAP32[$18>>2] = 0;
      $27 = HEAP32[$4>>2]|0;
      $28 = ($27|0)==($16|0);
      if ($28) {
       break L1;
      } else {
       $19 = $27;
      }
     }
     $29 = ___cxa_find_matching_catch_2()|0;
     $30 = tempRet0;
     ___cxa_call_unexpected(($29|0));
     // unreachable;
    }
   }
  }
 } while(0);
 $31 = HEAP32[$3>>2]|0;
 $32 = (($31) + ($1<<2)|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ($33|0)==(0|0);
 $35 = $31;
 L15: do {
  if ($34) {
   $36 = (__ZN3osg22getOrCreateContextDataEj($1)|0);
   $37 = (__ZN3osg11ContextData3getINS_21GLBufferObjectManagerEEEPT_v($36)|0);
   __ZN3osg21GLBufferObjectManager22generateGLBufferObjectEPKNS_12BufferObjectE($2,$37,$0);
   $38 = HEAP32[$4>>2]|0;
   $39 = HEAP32[$3>>2]|0;
   $40 = (($38) - ($39))|0;
   $41 = $40 >> 2;
   $42 = ($41>>>0)>($1>>>0);
   L17: do {
    if ($42) {
     label = 22;
    } else {
     $43 = (($1) + 1)|0;
     $44 = ($43>>>0)>($41>>>0);
     $45 = $39;
     $46 = $38;
     if ($44) {
      $47 = (($43) - ($41))|0;
      __THREW__ = 0;
      invoke_vii(3709,($3|0),($47|0));
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       break;
      } else {
       label = 22;
       break;
      }
     }
     $50 = ($43>>>0)<($41>>>0);
     if ($50) {
      $51 = (($45) + ($43<<2)|0);
      $52 = ($46|0)==($51|0);
      if ($52) {
       label = 22;
      } else {
       $54 = $46;
       while(1) {
        $53 = ((($54)) + -4|0);
        HEAP32[$4>>2] = $53;
        $55 = HEAP32[$53>>2]|0;
        $56 = ($55|0)==(0|0);
        if (!($56)) {
         $57 = ((($55)) + 8|0);
         $58 = HEAP32[$57>>2]|0;HEAP32[$57>>2] = (($58-1)|0);
         $59 = ($58|0)==(1);
         if ($59) {
          __THREW__ = 0;
          invoke_viii(3262,($55|0),1,1);
          $60 = __THREW__; __THREW__ = 0;
          $61 = $60&1;
          if ($61) {
           break;
          }
         }
        }
        HEAP32[$53>>2] = 0;
        $62 = HEAP32[$4>>2]|0;
        $63 = ($62|0)==($51|0);
        if ($63) {
         label = 22;
         break L17;
        } else {
         $54 = $62;
        }
       }
       $64 = ___cxa_find_matching_catch_2()|0;
       $65 = tempRet0;
       ___cxa_call_unexpected(($64|0));
       // unreachable;
      }
     } else {
      label = 22;
     }
    }
   } while(0);
   do {
    if ((label|0) == 22) {
     $66 = HEAP32[$3>>2]|0;
     $67 = (($66) + ($1<<2)|0);
     $68 = HEAP32[$67>>2]|0;
     $69 = HEAP32[$2>>2]|0;
     $70 = ($68|0)==($69|0);
     if ($70) {
      $80 = $68;
     } else {
      HEAP32[$67>>2] = $69;
      $71 = ($69|0)==(0|0);
      if (!($71)) {
       $72 = ((($69)) + 8|0);
       $73 = HEAP32[$72>>2]|0;HEAP32[$72>>2] = (($73+1)|0);
      }
      $74 = ($68|0)==(0|0);
      if (!($74)) {
       $75 = ((($68)) + 8|0);
       $76 = HEAP32[$75>>2]|0;HEAP32[$75>>2] = (($76-1)|0);
       $77 = ($76|0)==(1);
       if ($77) {
        __THREW__ = 0;
        invoke_viii(3262,($68|0),1,1);
        $78 = __THREW__; __THREW__ = 0;
        $79 = $78&1;
        if ($79) {
         break;
        }
       }
      }
      $$pr = HEAP32[$2>>2]|0;
      $80 = $$pr;
     }
     $81 = ($80|0)==(0|0);
     if (!($81)) {
      $82 = ((($80)) + 8|0);
      $83 = HEAP32[$82>>2]|0;HEAP32[$82>>2] = (($83-1)|0);
      $84 = ($83|0)==(1);
      if ($84) {
       __ZNK3osg10Referenced24signalObserversAndDeleteEbb($80,1,1);
      }
     }
     $$pre = HEAP32[$3>>2]|0;
     $96 = $$pre;
     break L15;
    }
   } while(0);
   $85 = ___cxa_find_matching_catch_2()|0;
   $86 = tempRet0;
   $87 = HEAP32[$2>>2]|0;
   $88 = ($87|0)==(0|0);
   if ($88) {
    ___resumeException($85|0);
    // unreachable;
   }
   $89 = ((($87)) + 8|0);
   $90 = HEAP32[$89>>2]|0;HEAP32[$89>>2] = (($90-1)|0);
   $91 = ($90|0)==(1);
   if (!($91)) {
    ___resumeException($85|0);
    // unreachable;
   }
   __THREW__ = 0;
   invoke_viii(3262,($87|0),1,1);
   $92 = __THREW__; __THREW__ = 0;
   $93 = $92&1;
   if ($93) {
    $123 = ___cxa_find_matching_catch_3(0|0)|0;
    $124 = tempRet0;
    ___clang_call_terminate($123);
    // unreachable;
   } else {
    ___resumeException($85|0);
    // unreachable;
   }
  } else {
   $96 = $35;
  }
 } while(0);
 $94 = HEAP32[$4>>2]|0;
 $95 = (($94) - ($96))|0;
 $97 = $95 >> 2;
 $98 = ($97>>>0)>($1>>>0);
 if ($98) {
  $120 = HEAP32[$3>>2]|0;
  $121 = (($120) + ($1<<2)|0);
  $122 = HEAP32[$121>>2]|0;
  STACKTOP = sp;return ($122|0);
 }
 $99 = (($1) + 1)|0;
 $100 = ($99>>>0)>($97>>>0);
 $101 = $96;
 $102 = $94;
 if ($100) {
  $103 = (($99) - ($97))|0;
  __ZNSt3__26vectorIN3osg7ref_ptrINS1_14GLBufferObjectEEENS_9allocatorIS4_EEE8__appendEj($3,$103);
  $120 = HEAP32[$3>>2]|0;
  $121 = (($120) + ($1<<2)|0);
  $122 = HEAP32[$121>>2]|0;
  STACKTOP = sp;return ($122|0);
 }
 $104 = ($99>>>0)<($97>>>0);
 if (!($104)) {
  $120 = HEAP32[$3>>2]|0;
  $121 = (($120) + ($1<<2)|0);
  $122 = HEAP32[$121>>2]|0;
  STACKTOP = sp;return ($122|0);
 }
 $105 = (($101) + ($99<<2)|0);
 $106 = ($102|0)==($105|0);
 if ($106) {
  $120 = HEAP32[$3>>2]|0;
  $121 = (($120) + ($1<<2)|0);
  $122 = HEAP32[$121>>2]|0;
  STACKTOP = sp;return ($122|0);
 } else {
  $108 = $102;
 }
 while(1) {
  $107 = ((($108)) + -4|0);
  HEAP32[$4>>2] = $107;
  $109 = HEAP32[$107>>2]|0;
  $110 = ($109|0)==(0|0);
  if (!($110)) {
   $111 = ((($109)) + 8|0);
   $112 = HEAP32[$111>>2]|0;HEAP32[$111>>2] = (($112-1)|0);
   $113 = ($112|0)==(1);
   if ($113) {
    __THREW__ = 0;
    invoke_viii(3262,($109|0),1,1);
    $114 = __THREW__; __THREW__ = 0;
    $115 = $114&1;
    if ($115) {
     label = 46;
     break;
    }
   }
  }
  HEAP32[$107>>2] = 0;
  $116 = HEAP32[$4>>2]|0;
  $117 = ($116|0)==($105|0);
  if ($117) {
   label = 47;
   break;
  } else {
   $108 = $116;
  }
 }
 if ((label|0) == 46) {
  $118 = ___cxa_find_matching_catch_2()|0;
  $119 = tempRet0;
  ___cxa_call_unexpected(($118|0));
  // unreachable;
 }
 else if ((label|0) == 47) {
  $120 = HEAP32[$3>>2]|0;
  $121 = (($120) + ($1<<2)|0);
  $122 = HEAP32[$121>>2]|0;
  STACKTOP = sp;return ($122|0);
 }
 return (0)|0;
}
function __ZN3osg11ContextData3getINS_21GLBufferObjectManagerEEEPT_v($0) {
 $0 = $0|0;
 var $$0$i$i = 0, $$0$ph$i$i = 0, $$014$i = 0, $$024$i$i = 0, $$025$i$i = 0, $$025$i53$i = 0, $$037$i = 0, $$03752$i = 0, $$in$i$i = 0, $$pre$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 36|0);
 $2 = ((($0)) + 40|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 do {
  if ($4) {
   $$025$i$i = $2;$$037$i = $2;$15 = $3;
   label = 12;
  } else {
   $5 = ((($0)) + 40|0);
   $$0$i$i = $5;$$024$i$i = $3;$51 = $3;
   while(1) {
    $6 = ((($$024$i$i)) + 16|0);
    $7 = HEAP32[$6>>2]|0;
    $8 = ($7>>>0)>(23064>>>0);
    if ($8) {
     $9 = HEAP32[$$024$i$i>>2]|0;
     $10 = ($9|0)==(0|0);
     if ($10) {
      label = 6;
      break;
     } else {
      $$0$ph$i$i = $$024$i$i;$$in$i$i = $9;
     }
    } else {
     $11 = ($7>>>0)<(23064>>>0);
     if (!($11)) {
      label = 10;
      break;
     }
     $12 = ((($$024$i$i)) + 4|0);
     $13 = HEAP32[$12>>2]|0;
     $14 = ($13|0)==(0|0);
     if ($14) {
      label = 9;
      break;
     } else {
      $$0$ph$i$i = $12;$$in$i$i = $13;
     }
    }
    $$0$i$i = $$0$ph$i$i;$$024$i$i = $$in$i$i;$51 = $$in$i$i;
   }
   if ((label|0) == 6) {
    $$025$i53$i = $$024$i$i;$$03752$i = $$024$i$i;
    label = 13;
    break;
   }
   else if ((label|0) == 9) {
    $$025$i53$i = $12;$$03752$i = $$024$i$i;
    label = 13;
    break;
   }
   else if ((label|0) == 10) {
    $$025$i$i = $$0$i$i;$$037$i = $$024$i$i;$15 = $51;
    label = 12;
    break;
   }
  }
 } while(0);
 if ((label|0) == 12) {
  $16 = ($15|0)==(0|0);
  if ($16) {
   $$025$i53$i = $$025$i$i;$$03752$i = $$037$i;
   label = 13;
  } else {
   $$014$i = $15;
  }
 }
 if ((label|0) == 13) {
  $17 = (__Znwj(24)|0);
  $18 = ((($17)) + 16|0);
  HEAP32[$18>>2] = (23064);
  $19 = ((($17)) + 20|0);
  HEAP32[$19>>2] = 0;
  HEAP32[$17>>2] = 0;
  $20 = ((($17)) + 4|0);
  HEAP32[$20>>2] = 0;
  $21 = ((($17)) + 8|0);
  HEAP32[$21>>2] = $$03752$i;
  HEAP32[$$025$i53$i>>2] = $17;
  $22 = HEAP32[$1>>2]|0;
  $23 = HEAP32[$22>>2]|0;
  $24 = ($23|0)==(0|0);
  if ($24) {
   $28 = $17;
  } else {
   $25 = $23;
   HEAP32[$1>>2] = $25;
   $$pre$i$i = HEAP32[$$025$i53$i>>2]|0;
   $28 = $$pre$i$i;
  }
  $26 = ((($0)) + 40|0);
  $27 = HEAP32[$26>>2]|0;
  __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($27,$28);
  $29 = ((($0)) + 44|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (($30) + 1)|0;
  HEAP32[$29>>2] = $31;
  $$014$i = $17;
 }
 $32 = ((($$014$i)) + 20|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ($33|0)==(0|0);
 if (!($34)) {
  $50 = HEAP32[$32>>2]|0;
  return ($50|0);
 }
 $35 = (__Znwj(112)|0);
 $36 = ((($0)) + 24|0);
 $37 = HEAP32[$36>>2]|0;
 __THREW__ = 0;
 invoke_vii(3710,($35|0),($37|0));
 $38 = __THREW__; __THREW__ = 0;
 $39 = $38&1;
 if ($39) {
  $48 = ___cxa_find_matching_catch_2()|0;
  $49 = tempRet0;
  __ZdlPv($35);
  ___resumeException($48|0);
  // unreachable;
 }
 $40 = HEAP32[$32>>2]|0;
 $41 = ($40|0)==($35|0);
 if ($41) {
  $50 = HEAP32[$32>>2]|0;
  return ($50|0);
 }
 HEAP32[$32>>2] = $35;
 $42 = ((($35)) + 8|0);
 $43 = HEAP32[$42>>2]|0;HEAP32[$42>>2] = (($43+1)|0);
 $44 = ($40|0)==(0|0);
 if ($44) {
  $50 = HEAP32[$32>>2]|0;
  return ($50|0);
 }
 $45 = ((($40)) + 8|0);
 $46 = HEAP32[$45>>2]|0;HEAP32[$45>>2] = (($46-1)|0);
 $47 = ($46|0)==(1);
 if (!($47)) {
  $50 = HEAP32[$32>>2]|0;
  return ($50|0);
 }
 __ZNK3osg10Referenced24signalObserversAndDeleteEbb($40,1,1);
 $50 = HEAP32[$32>>2]|0;
 return ($50|0);
}
function __ZN3osg21GLBufferObjectManager22generateGLBufferObjectEPKNS_12BufferObjectE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$1 = 0, $$115 = 0, $$sink$i$i$i = 0.0, $$sink$i$i$i19 = 0.0, $$sink16$index = 0, $$sink16$index3 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0.0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0.0, $63 = 0.0, $64 = 0, $65 = 0.0, $66 = 0.0, $67 = 0.0, $68 = 0.0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0.0, $87 = 0, $88 = 0, $89 = 0.0, $9 = 0, $90 = 0.0, $91 = 0, $92 = 0.0, $93 = 0.0, $94 = 0.0, $95 = 0.0, $96 = 0;
 var $97 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = ((($1)) + 88|0);
 $5 = (__ZN3osg5Timer8instanceEv()|0);
 $6 = (__ZNK3osg5Timer4tickEv($5)|0);
 $7 = tempRet0;
 $8 = ((($1)) + 80|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 1)|0;
 HEAP32[$8>>2] = $10;
 __THREW__ = 0;
 $11 = (invoke_ii(3711,($2|0))|0);
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $69 = ___cxa_find_matching_catch_2()|0;
  $70 = tempRet0;
  $$1 = $69;$$115 = $70;
 } else {
  $14 = ((($2)) + 40|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = ($11>>>0)>($15>>>0);
  $17 = $16 ? $11 : $15;
  $18 = ((($2)) + 32|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = ((($2)) + 36|0);
  $21 = HEAP32[$20>>2]|0;
  HEAP32[$3>>2] = $19;
  $22 = ((($3)) + 4|0);
  HEAP32[$22>>2] = $21;
  $23 = ((($3)) + 8|0);
  HEAP32[$23>>2] = $17;
  $24 = ((($1)) + 44|0);
  __THREW__ = 0;
  $25 = (invoke_iii(3712,($24|0),($3|0))|0);
  $26 = __THREW__; __THREW__ = 0;
  $27 = $26&1;
  do {
   if ($27) {
    label = 17;
   } else {
    $28 = HEAP32[$25>>2]|0;
    $29 = ($28|0)==(0|0);
    if ($29) {
     __THREW__ = 0;
     $30 = (invoke_ii(3276,80)|0);
     $31 = __THREW__; __THREW__ = 0;
     $32 = $31&1;
     if ($32) {
      label = 17;
      break;
     }
     __THREW__ = 0;
     invoke_viii(3713,($30|0),($1|0),($3|0));
     $33 = __THREW__; __THREW__ = 0;
     $34 = $33&1;
     if ($34) {
      $45 = ___cxa_find_matching_catch_2()|0;
      $46 = tempRet0;
      __ZdlPv($30);
      $$sink16$index = $45;$$sink16$index3 = $46;
      break;
     }
     $35 = HEAP32[$25>>2]|0;
     $36 = ($35|0)==($30|0);
     if (!($36)) {
      HEAP32[$25>>2] = $30;
      $37 = ((($30)) + 8|0);
      $38 = HEAP32[$37>>2]|0;HEAP32[$37>>2] = (($38+1)|0);
      $39 = ($35|0)==(0|0);
      if (!($39)) {
       $40 = ((($35)) + 8|0);
       $41 = HEAP32[$40>>2]|0;HEAP32[$40>>2] = (($41-1)|0);
       $42 = ($41|0)==(1);
       if ($42) {
        __THREW__ = 0;
        invoke_viii(3262,($35|0),1,1);
        $43 = __THREW__; __THREW__ = 0;
        $44 = $43&1;
        if ($44) {
         label = 17;
         break;
        }
       }
      }
     }
    }
    $47 = HEAP32[$25>>2]|0;
    __THREW__ = 0;
    invoke_viii(3714,($0|0),($47|0),($2|0));
    $48 = __THREW__; __THREW__ = 0;
    $49 = $48&1;
    if ($49) {
     $73 = ___cxa_find_matching_catch_2()|0;
     $74 = tempRet0;
     $$sink16$index = $73;$$sink16$index3 = $74;
     break;
    }
    $50 = (__ZNK3osg5Timer4tickEv($5)|0);
    $51 = tempRet0;
    $52 = ($51>>>0)>($7>>>0);
    $53 = ($50>>>0)>($6>>>0);
    $54 = ($51|0)==($7|0);
    $55 = $54 & $53;
    $56 = $52 | $55;
    if ($56) {
     $57 = (_i64Subtract(($50|0),($51|0),($6|0),($7|0))|0);
     $58 = tempRet0;
     $59 = (+($57>>>0)) + (4294967296.0*(+($58>>>0)));
     $$sink$i$i$i19 = $59;
     $64 = ((($5)) + 8|0);
     $65 = +HEAPF64[$64>>3];
     $66 = $$sink$i$i$i19 * $65;
     $67 = +HEAPF64[$4>>3];
     $68 = $66 + $67;
     HEAPF64[$4>>3] = $68;
     STACKTOP = sp;return;
    } else {
     $60 = (_i64Subtract(($6|0),($7|0),($50|0),($51|0))|0);
     $61 = tempRet0;
     $62 = (+($60>>>0)) + (4294967296.0*(+($61>>>0)));
     $63 = -$62;
     $$sink$i$i$i19 = $63;
     $64 = ((($5)) + 8|0);
     $65 = +HEAPF64[$64>>3];
     $66 = $$sink$i$i$i19 * $65;
     $67 = +HEAPF64[$4>>3];
     $68 = $66 + $67;
     HEAPF64[$4>>3] = $68;
     STACKTOP = sp;return;
    }
   }
  } while(0);
  if ((label|0) == 17) {
   $71 = ___cxa_find_matching_catch_2()|0;
   $72 = tempRet0;
   $$sink16$index = $71;$$sink16$index3 = $72;
  }
  $$1 = $$sink16$index;$$115 = $$sink16$index3;
 }
 __THREW__ = 0;
 $75 = (invoke_ii(3385,($5|0))|0);
 $76 = tempRet0;
 $77 = __THREW__; __THREW__ = 0;
 $78 = $77&1;
 if ($78) {
  $96 = ___cxa_find_matching_catch_3(0|0)|0;
  $97 = tempRet0;
  ___clang_call_terminate($96);
  // unreachable;
 }
 $79 = ($76>>>0)>($7>>>0);
 $80 = ($75>>>0)>($6>>>0);
 $81 = ($76|0)==($7|0);
 $82 = $81 & $80;
 $83 = $79 | $82;
 if ($83) {
  $84 = (_i64Subtract(($75|0),($76|0),($6|0),($7|0))|0);
  $85 = tempRet0;
  $86 = (+($84>>>0)) + (4294967296.0*(+($85>>>0)));
  $$sink$i$i$i = $86;
  $91 = ((($5)) + 8|0);
  $92 = +HEAPF64[$91>>3];
  $93 = $$sink$i$i$i * $92;
  $94 = +HEAPF64[$4>>3];
  $95 = $93 + $94;
  HEAPF64[$4>>3] = $95;
  ___resumeException($$1|0);
  // unreachable;
 } else {
  $87 = (_i64Subtract(($6|0),($7|0),($75|0),($76|0))|0);
  $88 = tempRet0;
  $89 = (+($87>>>0)) + (4294967296.0*(+($88>>>0)));
  $90 = -$89;
  $$sink$i$i$i = $90;
  $91 = ((($5)) + 8|0);
  $92 = +HEAPF64[$91>>3];
  $93 = $$sink$i$i$i * $92;
  $94 = +HEAPF64[$4>>3];
  $95 = $93 + $94;
  HEAPF64[$4>>3] = $95;
  ___resumeException($$1|0);
  // unreachable;
 }
}
function __ZNK3osg12BufferObject25computeRequiredBufferSizeEv($0) {
 $0 = $0|0;
 var $$0$lcssa = 0, $$014 = 0, $$1 = 0, $$sroa$08$013 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $2 = ((($0)) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 52|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if ($6) {
  $$0$lcssa = 0;
  STACKTOP = sp;return ($$0$lcssa|0);
 }
 $$014 = 0;$$sroa$08$013 = $3;
 while(1) {
  $7 = HEAP32[$$sroa$08$013>>2]|0;
  $8 = ($7|0)==(0|0);
  if ($8) {
   $14 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
   if ($14) {
    $15 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
    $16 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($15,119902,14)|0);
    $17 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEPKv($16,$0)|0);
    $18 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($17,119917,1)|0);
    $19 = HEAP32[$0>>2]|0;
    $20 = ((($19)) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (FUNCTION_TABLE_ii[$21 & 8191]($0)|0);
    $23 = (_strlen($22)|0);
    $24 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($18,$22,$23)|0);
    $25 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($24,119919,68)|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = ((($26)) + -12|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = (($25) + ($28)|0);
    __ZNKSt3__28ios_base6getlocEv($1,$29);
    __THREW__ = 0;
    $30 = (invoke_iii(3255,($1|0),(215188|0))|0);
    $31 = __THREW__; __THREW__ = 0;
    $32 = $31&1;
    if ($32) {
     break;
    }
    $33 = HEAP32[$30>>2]|0;
    $34 = ((($33)) + 28|0);
    $35 = HEAP32[$34>>2]|0;
    __THREW__ = 0;
    $36 = (invoke_iii($35|0,($30|0),10)|0);
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     break;
    }
    __ZNSt3__26localeD2Ev($1);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($25,$36)|0);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($25)|0);
    $$1 = $$014;
   } else {
    $$1 = $$014;
   }
  } else {
   $9 = HEAP32[$7>>2]|0;
   $10 = ((($9)) + 144|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (FUNCTION_TABLE_ii[$11 & 8191]($7)|0);
   $13 = (($12) + ($$014))|0;
   $$1 = $13;
  }
  $45 = ((($$sroa$08$013)) + 4|0);
  $46 = HEAP32[$4>>2]|0;
  $47 = ($45|0)==($46|0);
  if ($47) {
   $$0$lcssa = $$1;
   label = 3;
   break;
  } else {
   $$014 = $$1;$$sroa$08$013 = $45;
  }
 }
 if ((label|0) == 3) {
  STACKTOP = sp;return ($$0$lcssa|0);
 }
 $39 = ___cxa_find_matching_catch_2()|0;
 $40 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($1|0));
 $41 = __THREW__; __THREW__ = 0;
 $42 = $41&1;
 if ($42) {
  $43 = ___cxa_find_matching_catch_3(0|0)|0;
  $44 = tempRet0;
  ___clang_call_terminate($43);
  // unreachable;
 } else {
  ___resumeException($39|0);
  // unreachable;
 }
 return (0)|0;
}
function __ZNSt3__23mapIN3osg19BufferObjectProfileENS1_7ref_ptrINS1_17GLBufferObjectSetEEENS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S5_EEEEEixERSA_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i = 0, $$0$ph$i = 0, $$014 = 0, $$024$i = 0, $$025$i = 0, $$025$i54 = 0, $$037 = 0, $$03753 = 0, $$in$i = 0, $$pre$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 do {
  if ($4) {
   $$025$i = $2;$$037 = $2;$30 = $3;
   label = 16;
  } else {
   $5 = ((($0)) + 4|0);
   $6 = HEAP32[$1>>2]|0;
   $7 = ((($1)) + 4|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ((($1)) + 8|0);
   $10 = HEAP32[$9>>2]|0;
   $$0$i = $5;$$024$i = $3;$55 = $3;
   L4: while(1) {
    $11 = ((($$024$i)) + 16|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ($6>>>0)<($12>>>0);
    do {
     if ($13) {
      label = 9;
     } else {
      $14 = ($6>>>0)>($12>>>0);
      if (!($14)) {
       $15 = ((($$024$i)) + 20|0);
       $16 = HEAP32[$15>>2]|0;
       $17 = ($8>>>0)<($16>>>0);
       if ($17) {
        label = 9;
        break;
       }
       $18 = ($8>>>0)>($16>>>0);
       if (!($18)) {
        $19 = ((($$024$i)) + 24|0);
        $20 = HEAP32[$19>>2]|0;
        $21 = ($10>>>0)<($20>>>0);
        if ($21) {
         label = 9;
         break;
        }
        $24 = ((($$024$i)) + 24|0);
        $25 = HEAP32[$24>>2]|0;
        $26 = ($25>>>0)<($10>>>0);
        if (!($26)) {
         label = 14;
         break L4;
        }
       }
      }
      $27 = ((($$024$i)) + 4|0);
      $28 = HEAP32[$27>>2]|0;
      $29 = ($28|0)==(0|0);
      if ($29) {
       label = 13;
       break L4;
      } else {
       $$0$ph$i = $27;$$in$i = $28;
      }
     }
    } while(0);
    if ((label|0) == 9) {
     label = 0;
     $22 = HEAP32[$$024$i>>2]|0;
     $23 = ($22|0)==(0|0);
     if ($23) {
      label = 10;
      break;
     } else {
      $$0$ph$i = $$024$i;$$in$i = $22;
     }
    }
    $$0$i = $$0$ph$i;$$024$i = $$in$i;$55 = $$in$i;
   }
   if ((label|0) == 10) {
    $$025$i54 = $$024$i;$$03753 = $$024$i;
    break;
   }
   else if ((label|0) == 13) {
    $$025$i54 = $27;$$03753 = $$024$i;
    break;
   }
   else if ((label|0) == 14) {
    $$025$i = $$0$i;$$037 = $$024$i;$30 = $55;
    label = 16;
    break;
   }
  }
 } while(0);
 if ((label|0) == 16) {
  $31 = ($30|0)==(0|0);
  if ($31) {
   $$025$i54 = $$025$i;$$03753 = $$037;
  } else {
   $$014 = $30;
   $54 = ((($$014)) + 28|0);
   return ($54|0);
  }
 }
 $32 = (__Znwj(32)|0);
 $33 = ((($32)) + 16|0);
 $34 = HEAP32[$1>>2]|0;
 HEAP32[$33>>2] = $34;
 $35 = ((($32)) + 20|0);
 $36 = ((($1)) + 4|0);
 $37 = HEAP32[$36>>2]|0;
 HEAP32[$35>>2] = $37;
 $38 = ((($32)) + 24|0);
 $39 = ((($1)) + 8|0);
 $40 = HEAP32[$39>>2]|0;
 HEAP32[$38>>2] = $40;
 $41 = ((($32)) + 28|0);
 HEAP32[$41>>2] = 0;
 HEAP32[$32>>2] = 0;
 $42 = ((($32)) + 4|0);
 HEAP32[$42>>2] = 0;
 $43 = ((($32)) + 8|0);
 HEAP32[$43>>2] = $$03753;
 HEAP32[$$025$i54>>2] = $32;
 $44 = HEAP32[$0>>2]|0;
 $45 = HEAP32[$44>>2]|0;
 $46 = ($45|0)==(0|0);
 if ($46) {
  $50 = $32;
 } else {
  $47 = $45;
  HEAP32[$0>>2] = $47;
  $$pre$i = HEAP32[$$025$i54>>2]|0;
  $50 = $$pre$i;
 }
 $48 = ((($0)) + 4|0);
 $49 = HEAP32[$48>>2]|0;
 __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($49,$50);
 $51 = ((($0)) + 8|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = (($52) + 1)|0;
 HEAP32[$51>>2] = $53;
 $$014 = $32;
 $54 = ((($$014)) + 28|0);
 return ($54|0);
}
function __ZN3osg17GLBufferObjectSetC2EPNS_21GLBufferObjectManagerERKNS_19BufferObjectProfileE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$023$i$i = 0, $$023$i$i10 = 0, $$2 = 0, $$27 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 __ZN3osg10ReferencedC2Ev($0);
 HEAP32[$0>>2] = (54896);
 $4 = ((($0)) + 12|0);
 __THREW__ = 0;
 invoke_vii(3507,($4|0),0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $68 = ___cxa_find_matching_catch_2()|0;
  $69 = tempRet0;
  $$2 = $69;$$27 = $68;
 } else {
  $7 = ((($0)) + 24|0);
  HEAP32[$7>>2] = $1;
  $8 = ((($0)) + 28|0);
  $9 = ((($1)) + 24|0);
  $10 = HEAP32[$9>>2]|0;
  HEAP32[$8>>2] = $10;
  $11 = ((($0)) + 32|0);
  $12 = HEAP32[$2>>2]|0;
  HEAP32[$11>>2] = $12;
  $13 = ((($0)) + 36|0);
  $14 = ((($2)) + 4|0);
  $15 = HEAP32[$14>>2]|0;
  HEAP32[$13>>2] = $15;
  $16 = ((($0)) + 40|0);
  $17 = ((($2)) + 8|0);
  $18 = HEAP32[$17>>2]|0;
  HEAP32[$16>>2] = $18;
  $19 = ((($0)) + 44|0);
  HEAP32[$19>>2] = 0;
  $20 = ((($0)) + 48|0);
  HEAP32[$20>>2] = $20;
  $21 = ((($0)) + 52|0);
  HEAP32[$21>>2] = $20;
  $22 = ((($0)) + 56|0);
  HEAP32[$22>>2] = 0;
  $23 = ((($0)) + 60|0);
  HEAP32[$23>>2] = $23;
  $24 = ((($0)) + 64|0);
  HEAP32[$24>>2] = $23;
  $25 = ((($0)) + 68|0);
  HEAP32[$25>>2] = 0;
  $26 = ((($0)) + 72|0);
  HEAP32[$26>>2] = 0;
  $27 = ((($0)) + 76|0);
  HEAP32[$27>>2] = 0;
  __THREW__ = 0;
  $28 = (invoke_ii(3265,4)|0);
  $29 = __THREW__; __THREW__ = 0;
  $30 = $29&1;
  do {
   if ($30) {
    label = 17;
   } else {
    if (!($28)) {
     STACKTOP = sp;return;
    }
    __THREW__ = 0;
    $31 = (invoke_ii(3266,4)|0);
    $32 = __THREW__; __THREW__ = 0;
    $33 = $32&1;
    if ($33) {
     label = 17;
    } else {
     __THREW__ = 0;
     $34 = (invoke_iiii(3267,($31|0),(119849|0),52)|0);
     $35 = __THREW__; __THREW__ = 0;
     $36 = $35&1;
     if ($36) {
      label = 17;
     } else {
      $37 = HEAP32[$16>>2]|0;
      __THREW__ = 0;
      $38 = (invoke_iii(3417,($34|0),($37|0))|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if ($40) {
       label = 17;
      } else {
       $41 = HEAP32[$38>>2]|0;
       $42 = ((($41)) + -12|0);
       $43 = HEAP32[$42>>2]|0;
       $44 = (($38) + ($43)|0);
       __THREW__ = 0;
       invoke_vii(3257,($3|0),($44|0));
       $45 = __THREW__; __THREW__ = 0;
       $46 = $45&1;
       if ($46) {
        label = 17;
       } else {
        __THREW__ = 0;
        $47 = (invoke_iii(3255,($3|0),(215188|0))|0);
        $48 = __THREW__; __THREW__ = 0;
        $49 = $48&1;
        if (!($49)) {
         $50 = HEAP32[$47>>2]|0;
         $51 = ((($50)) + 28|0);
         $52 = HEAP32[$51>>2]|0;
         __THREW__ = 0;
         $53 = (invoke_iii($52|0,($47|0),10)|0);
         $54 = __THREW__; __THREW__ = 0;
         $55 = $54&1;
         if (!($55)) {
          __THREW__ = 0;
          invoke_vi(3263,($3|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           label = 17;
           break;
          }
          __THREW__ = 0;
          (invoke_iii(3268,($38|0),($53|0))|0);
          $64 = __THREW__; __THREW__ = 0;
          $65 = $64&1;
          if ($65) {
           label = 17;
           break;
          }
          __THREW__ = 0;
          (invoke_ii(3269,($38|0))|0);
          $66 = __THREW__; __THREW__ = 0;
          $67 = $66&1;
          if ($67) {
           label = 17;
           break;
          }
          STACKTOP = sp;return;
         }
        }
        $58 = ___cxa_find_matching_catch_2()|0;
        $59 = tempRet0;
        __THREW__ = 0;
        invoke_vi(3263,($3|0));
        $60 = __THREW__; __THREW__ = 0;
        $61 = $60&1;
        if ($61) {
         $62 = ___cxa_find_matching_catch_3(0|0)|0;
         $63 = tempRet0;
         ___clang_call_terminate($62);
         // unreachable;
        } else {
         $eh$lpad$body$index2Z2D = $59;$eh$lpad$body$indexZ2D = $58;
         break;
        }
       }
      }
     }
    }
   }
  } while(0);
  if ((label|0) == 17) {
   $70 = ___cxa_find_matching_catch_2()|0;
   $71 = tempRet0;
   $eh$lpad$body$index2Z2D = $71;$eh$lpad$body$indexZ2D = $70;
  }
  $72 = HEAP32[$25>>2]|0;
  $73 = ($72|0)==(0);
  L26: do {
   if (!($73)) {
    $74 = HEAP32[$24>>2]|0;
    $75 = HEAP32[$23>>2]|0;
    $76 = ((($75)) + 4|0);
    $77 = HEAP32[$76>>2]|0;
    $78 = HEAP32[$74>>2]|0;
    $79 = ((($78)) + 4|0);
    HEAP32[$79>>2] = $77;
    $80 = HEAP32[$76>>2]|0;
    HEAP32[$80>>2] = $78;
    HEAP32[$25>>2] = 0;
    $81 = ($74|0)==($23|0);
    if (!($81)) {
     $$023$i$i10 = $74;
     while(1) {
      $82 = ((($$023$i$i10)) + 4|0);
      $83 = HEAP32[$82>>2]|0;
      $84 = ((($$023$i$i10)) + 8|0);
      $85 = HEAP32[$84>>2]|0;
      $86 = ($85|0)==(0|0);
      if (!($86)) {
       $87 = ((($85)) + 8|0);
       $88 = HEAP32[$87>>2]|0;HEAP32[$87>>2] = (($88-1)|0);
       $89 = ($88|0)==(1);
       if ($89) {
        __THREW__ = 0;
        invoke_viii(3262,($85|0),1,1);
        $90 = __THREW__; __THREW__ = 0;
        $91 = $90&1;
        if ($91) {
         break;
        }
       }
      }
      __ZdlPv($$023$i$i10);
      $92 = ($83|0)==($23|0);
      if ($92) {
       break L26;
      } else {
       $$023$i$i10 = $83;
      }
     }
     $93 = ___cxa_find_matching_catch_2()|0;
     $94 = tempRet0;
     ___cxa_call_unexpected(($93|0));
     // unreachable;
    }
   }
  } while(0);
  $95 = HEAP32[$22>>2]|0;
  $96 = ($95|0)==(0);
  L36: do {
   if (!($96)) {
    $97 = HEAP32[$21>>2]|0;
    $98 = HEAP32[$20>>2]|0;
    $99 = ((($98)) + 4|0);
    $100 = HEAP32[$99>>2]|0;
    $101 = HEAP32[$97>>2]|0;
    $102 = ((($101)) + 4|0);
    HEAP32[$102>>2] = $100;
    $103 = HEAP32[$99>>2]|0;
    HEAP32[$103>>2] = $101;
    HEAP32[$22>>2] = 0;
    $104 = ($97|0)==($20|0);
    if (!($104)) {
     $$023$i$i = $97;
     while(1) {
      $105 = ((($$023$i$i)) + 4|0);
      $106 = HEAP32[$105>>2]|0;
      $107 = ((($$023$i$i)) + 8|0);
      $108 = HEAP32[$107>>2]|0;
      $109 = ($108|0)==(0|0);
      if (!($109)) {
       $110 = ((($108)) + 8|0);
       $111 = HEAP32[$110>>2]|0;HEAP32[$110>>2] = (($111-1)|0);
       $112 = ($111|0)==(1);
       if ($112) {
        __THREW__ = 0;
        invoke_viii(3262,($108|0),1,1);
        $113 = __THREW__; __THREW__ = 0;
        $114 = $113&1;
        if ($114) {
         break;
        }
       }
      }
      __ZdlPv($$023$i$i);
      $115 = ($106|0)==($20|0);
      if ($115) {
       break L36;
      } else {
       $$023$i$i = $106;
      }
     }
     $116 = ___cxa_find_matching_catch_2()|0;
     $117 = tempRet0;
     ___cxa_call_unexpected(($116|0));
     // unreachable;
    }
   }
  } while(0);
  __THREW__ = 0;
  invoke_vi(707,($4|0));
  $118 = __THREW__; __THREW__ = 0;
  $119 = $118&1;
  if ($119) {
   $122 = ___cxa_find_matching_catch_3(0|0)|0;
   $123 = tempRet0;
   ___clang_call_terminate($122);
   // unreachable;
  } else {
   $$2 = $eh$lpad$body$index2Z2D;$$27 = $eh$lpad$body$indexZ2D;
  }
 }
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $120 = __THREW__; __THREW__ = 0;
 $121 = $120&1;
 if ($121) {
  $122 = ___cxa_find_matching_catch_3(0|0)|0;
  $123 = tempRet0;
  ___clang_call_terminate($122);
  // unreachable;
 } else {
  ___resumeException($$27|0);
  // unreachable;
 }
}
function __ZN3osg17GLBufferObjectSet14takeOrGenerateEPNS_12BufferObjectE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$017 = 0, $$4 = 0, $$421 = 0, $$pre = 0, $$pre66 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0;
 var $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0;
 var $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0;
 var $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0;
 var $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0;
 var $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index3Z2D = 0, $eh$lpad$body$indexZ2D = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i3$i$i = 0, $scevgep5$i$i$i$i$i = 0, $scevgep5$i$i$i4$i$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp + 4|0;
 $4 = sp;
 $5 = ((($1)) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($6)) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 (FUNCTION_TABLE_ii[$8 & 8191]($5)|0);
 $9 = ((($1)) + 68|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0);
 if (!($11)) {
  __THREW__ = 0;
  invoke_vi(3703,($1|0));
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if (!($13)) {
   __THREW__ = 0;
   invoke_viii(3715,($0|0),($1|0),($2|0));
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if (!($15)) {
    $286 = HEAP32[$5>>2]|0;
    $287 = ((($286)) + 12|0);
    $288 = HEAP32[$287>>2]|0;
    (FUNCTION_TABLE_ii[$288 & 8191]($5)|0);
    STACKTOP = sp;return;
   }
  }
  $16 = ___cxa_find_matching_catch_2()|0;
  $17 = tempRet0;
  $18 = HEAP32[$5>>2]|0;
  $19 = ((($18)) + 12|0);
  $20 = HEAP32[$19>>2]|0;
  __THREW__ = 0;
  (invoke_ii($20|0,($5|0))|0);
  $21 = __THREW__; __THREW__ = 0;
  $22 = $21&1;
  if ($22) {
   $289 = ___cxa_find_matching_catch_3(0|0)|0;
   $290 = tempRet0;
   ___clang_call_terminate($289);
   // unreachable;
  }
  $$4 = $16;$$421 = $17;
  ___resumeException($$4|0);
  // unreachable;
 }
 $23 = HEAP32[$5>>2]|0;
 $24 = ((($23)) + 12|0);
 $25 = HEAP32[$24>>2]|0;
 (FUNCTION_TABLE_ii[$25 & 8191]($5)|0);
 $26 = ((($1)) + 56|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ($27|0)==(0);
 if (!($28)) {
  __ZN3osg17GLBufferObjectSet15takeFromOrphansEPNS_12BufferObjectE($0,$1,$2);
  STACKTOP = sp;return;
 }
 $29 = ((($1)) + 24|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ((($30)) + 56|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = ((($30)) + 40|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)==(0);
 if (!($35)) {
  $36 = ((($1)) + 40|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = ((($30)) + 36|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = (($39) + ($37))|0;
  $41 = ($40>>>0)>($34>>>0);
  if ($41) {
   $42 = ((($1)) + 44|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = ($43>>>0)>(1);
   if ($44) {
    $45 = ((($1)) + 72|0);
    $46 = HEAP32[$45>>2]|0;
    $47 = ($46|0)==(0|0);
    if (!($47)) {
     $48 = ((($46)) + 68|0);
     $49 = HEAP32[$48>>2]|0;
     $50 = ($49>>>0)<($32>>>0);
     if ($50) {
      $51 = HEAP32[$5>>2]|0;
      $52 = ((($51)) + 8|0);
      $53 = HEAP32[$52>>2]|0;
      (FUNCTION_TABLE_ii[$53 & 8191]($5)|0);
      $54 = HEAP32[$45>>2]|0;
      HEAP32[$0>>2] = $54;
      $55 = ((($54)) + 8|0);
      $56 = HEAP32[$55>>2]|0;HEAP32[$55>>2] = (($56+1)|0);
      $$pre = HEAP32[$0>>2]|0;
      $57 = ((($$pre)) + 52|0);
      $58 = HEAP32[$57>>2]|0;
      $59 = ($58|0)==(0|0);
      L23: do {
       if ($59) {
        __THREW__ = 0;
        $133 = (invoke_ii(3265,4)|0);
        $134 = __THREW__; __THREW__ = 0;
        $135 = $134&1;
        if ($135) {
         label = 36;
        } else {
         if ($133) {
          __THREW__ = 0;
          $136 = (invoke_ii(3266,4)|0);
          $137 = __THREW__; __THREW__ = 0;
          $138 = $137&1;
          if ($138) {
           label = 36;
          } else {
           __THREW__ = 0;
           $139 = (invoke_iiii(3267,($136|0),(119798|0),50)|0);
           $140 = __THREW__; __THREW__ = 0;
           $141 = $140&1;
           if ($141) {
            label = 36;
           } else {
            __THREW__ = 0;
            $142 = (invoke_iii(3275,($139|0),($$pre|0))|0);
            $143 = __THREW__; __THREW__ = 0;
            $144 = $143&1;
            if ($144) {
             label = 36;
            } else {
             $145 = HEAP32[$142>>2]|0;
             $146 = ((($145)) + -12|0);
             $147 = HEAP32[$146>>2]|0;
             $148 = (($142) + ($147)|0);
             __THREW__ = 0;
             invoke_vii(3257,($4|0),($148|0));
             $149 = __THREW__; __THREW__ = 0;
             $150 = $149&1;
             if ($150) {
              label = 36;
             } else {
              __THREW__ = 0;
              $151 = (invoke_iii(3255,($4|0),(215188|0))|0);
              $152 = __THREW__; __THREW__ = 0;
              $153 = $152&1;
              if (!($153)) {
               $154 = HEAP32[$151>>2]|0;
               $155 = ((($154)) + 28|0);
               $156 = HEAP32[$155>>2]|0;
               __THREW__ = 0;
               $157 = (invoke_iii($156|0,($151|0),10)|0);
               $158 = __THREW__; __THREW__ = 0;
               $159 = $158&1;
               if (!($159)) {
                __THREW__ = 0;
                invoke_vi(3263,($4|0));
                $166 = __THREW__; __THREW__ = 0;
                $167 = $166&1;
                if ($167) {
                 label = 36;
                 break;
                }
                __THREW__ = 0;
                (invoke_iii(3268,($142|0),($157|0))|0);
                $168 = __THREW__; __THREW__ = 0;
                $169 = $168&1;
                if ($169) {
                 label = 36;
                 break;
                }
                __THREW__ = 0;
                (invoke_ii(3269,($142|0))|0);
                $170 = __THREW__; __THREW__ = 0;
                $171 = $170&1;
                if ($171) {
                 label = 36;
                 break;
                } else {
                 $172 = $$pre;
                 label = 54;
                 break;
                }
               }
              }
              $160 = ___cxa_find_matching_catch_2()|0;
              $161 = tempRet0;
              __THREW__ = 0;
              invoke_vi(3263,($4|0));
              $162 = __THREW__; __THREW__ = 0;
              $163 = $162&1;
              if ($163) {
               $164 = ___cxa_find_matching_catch_3(0|0)|0;
               $165 = tempRet0;
               ___clang_call_terminate($164);
               // unreachable;
              } else {
               $eh$lpad$body$index3Z2D = $161;$eh$lpad$body$indexZ2D = $160;
               label = 37;
               break;
              }
             }
            }
           }
          }
         } else {
          $172 = $$pre;
          label = 54;
         }
        }
       } else {
        $60 = ((($58)) + 8|0);
        $61 = HEAP32[$60>>2]|0;HEAP32[$60>>2] = (($61+1)|0);
        $62 = ((($1)) + 28|0);
        $63 = HEAP32[$62>>2]|0;
        __THREW__ = 0;
        invoke_viii(3702,($58|0),($63|0),(0|0));
        $64 = __THREW__; __THREW__ = 0;
        $65 = $64&1;
        if ($65) {
         label = 36;
        } else {
         __THREW__ = 0;
         $66 = (invoke_ii(3265,4)|0);
         $67 = __THREW__; __THREW__ = 0;
         $68 = $67&1;
         if ($68) {
          label = 36;
         } else {
          if (!($66)) {
           $$pre66 = HEAP32[$0>>2]|0;
           $172 = $$pre66;
           label = 54;
           break;
          }
          __THREW__ = 0;
          $69 = (invoke_ii(3266,4)|0);
          $70 = __THREW__; __THREW__ = 0;
          $71 = $70&1;
          if ($71) {
           label = 36;
          } else {
           __THREW__ = 0;
           $72 = (invoke_iiii(3267,($69|0),(119719|0),18)|0);
           $73 = __THREW__; __THREW__ = 0;
           $74 = $73&1;
           if ($74) {
            label = 36;
           } else {
            __THREW__ = 0;
            $75 = (invoke_iii(3275,($72|0),($1|0))|0);
            $76 = __THREW__; __THREW__ = 0;
            $77 = $76&1;
            if ($77) {
             label = 36;
            } else {
             __THREW__ = 0;
             $78 = (invoke_iiii(3267,($75|0),(119738|0),35)|0);
             $79 = __THREW__; __THREW__ = 0;
             $80 = $79&1;
             if ($80) {
              label = 36;
             } else {
              $81 = HEAP32[$0>>2]|0;
              __THREW__ = 0;
              $82 = (invoke_iii(3275,($78|0),($81|0))|0);
              $83 = __THREW__; __THREW__ = 0;
              $84 = $83&1;
              if ($84) {
               label = 36;
              } else {
               __THREW__ = 0;
               $85 = (invoke_iiii(3267,($82|0),(119774|0),23)|0);
               $86 = __THREW__; __THREW__ = 0;
               $87 = $86&1;
               if ($87) {
                label = 36;
               } else {
                $88 = HEAP32[$42>>2]|0;
                __THREW__ = 0;
                $89 = (invoke_iii(3417,($85|0),($88|0))|0);
                $90 = __THREW__; __THREW__ = 0;
                $91 = $90&1;
                if ($91) {
                 label = 36;
                } else {
                 __THREW__ = 0;
                 $92 = (invoke_iiii(3267,($89|0),(146703|0),6)|0);
                 $93 = __THREW__; __THREW__ = 0;
                 $94 = $93&1;
                 if ($94) {
                  label = 36;
                  break;
                 }
                 $95 = HEAP32[$36>>2]|0;
                 __THREW__ = 0;
                 $96 = (invoke_iii(3417,($92|0),($95|0))|0);
                 $97 = __THREW__; __THREW__ = 0;
                 $98 = $97&1;
                 if ($98) {
                  label = 36;
                  break;
                 }
                 $99 = HEAP32[$96>>2]|0;
                 $100 = ((($99)) + -12|0);
                 $101 = HEAP32[$100>>2]|0;
                 $102 = (($96) + ($101)|0);
                 __THREW__ = 0;
                 invoke_vii(3257,($3|0),($102|0));
                 $103 = __THREW__; __THREW__ = 0;
                 $104 = $103&1;
                 if ($104) {
                  label = 36;
                  break;
                 }
                 __THREW__ = 0;
                 $105 = (invoke_iii(3255,($3|0),(215188|0))|0);
                 $106 = __THREW__; __THREW__ = 0;
                 $107 = $106&1;
                 do {
                  if (!($107)) {
                   $108 = HEAP32[$105>>2]|0;
                   $109 = ((($108)) + 28|0);
                   $110 = HEAP32[$109>>2]|0;
                   __THREW__ = 0;
                   $111 = (invoke_iii($110|0,($105|0),10)|0);
                   $112 = __THREW__; __THREW__ = 0;
                   $113 = $112&1;
                   if ($113) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3263,($3|0));
                   $120 = __THREW__; __THREW__ = 0;
                   $121 = $120&1;
                   if ($121) {
                    label = 36;
                    break L23;
                   }
                   __THREW__ = 0;
                   (invoke_iii(3268,($96|0),($111|0))|0);
                   $122 = __THREW__; __THREW__ = 0;
                   $123 = $122&1;
                   if ($123) {
                    label = 36;
                    break L23;
                   }
                   __THREW__ = 0;
                   (invoke_ii(3269,($96|0))|0);
                   $124 = __THREW__; __THREW__ = 0;
                   $125 = $124&1;
                   if ($125) {
                    label = 36;
                    break L23;
                   } else {
                    $172 = $81;
                    label = 54;
                    break L23;
                   }
                  }
                 } while(0);
                 $114 = ___cxa_find_matching_catch_2()|0;
                 $115 = tempRet0;
                 __THREW__ = 0;
                 invoke_vi(3263,($3|0));
                 $116 = __THREW__; __THREW__ = 0;
                 $117 = $116&1;
                 if ($117) {
                  $118 = ___cxa_find_matching_catch_3(0|0)|0;
                  $119 = tempRet0;
                  ___clang_call_terminate($118);
                  // unreachable;
                 } else {
                  $eh$lpad$body$index3Z2D = $115;$eh$lpad$body$indexZ2D = $114;
                  label = 37;
                  break;
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      } while(0);
      do {
       if ((label|0) == 54) {
        __THREW__ = 0;
        invoke_vii(3716,($1|0),($172|0));
        $173 = __THREW__; __THREW__ = 0;
        $174 = $173&1;
        if ($174) {
         label = 36;
        } else {
         $175 = ((($172)) + 52|0);
         HEAP32[$175>>2] = $2;
         $176 = ($2|0)==(0|0);
         if ($176) {
          $197 = ((($172)) + 20|0);
          HEAP32[$197>>2] = 0;
          $198 = ((($172)) + 24|0);
          HEAP32[$198>>2] = 0;
          $199 = ((($172)) + 28|0);
          HEAP32[$199>>2] = 0;
          $200 = ((($172)) + 40|0);
          $201 = HEAP32[$200>>2]|0;
          $202 = ((($172)) + 44|0);
          $203 = HEAP32[$202>>2]|0;
          $204 = ($203|0)==($201|0);
          if (!($204)) {
           $scevgep$i$i$i$i$i = ((($203)) + -20|0);
           $205 = $scevgep$i$i$i$i$i;
           $206 = $201;
           $207 = (($205) - ($206))|0;
           $208 = (($207>>>0) / 20)&-1;
           $209 = $208 ^ -1;
           $scevgep5$i$i$i$i$i = (($203) + (($209*20)|0)|0);
           HEAP32[$202>>2] = $scevgep5$i$i$i$i$i;
          }
         } else {
          $177 = ((($2)) + 32|0);
          $178 = HEAP32[$177>>2]|0;
          $179 = ((($172)) + 20|0);
          HEAP32[$179>>2] = $178;
          $180 = ((($2)) + 36|0);
          $181 = HEAP32[$180>>2]|0;
          $182 = ((($172)) + 24|0);
          HEAP32[$182>>2] = $181;
          $183 = ((($2)) + 40|0);
          $184 = HEAP32[$183>>2]|0;
          $185 = ((($172)) + 28|0);
          HEAP32[$185>>2] = $184;
          $186 = ((($172)) + 36|0);
          HEAP8[$186>>0] = 1;
          $187 = ((($172)) + 40|0);
          $188 = HEAP32[$187>>2]|0;
          $189 = ((($172)) + 44|0);
          $190 = HEAP32[$189>>2]|0;
          $191 = ($190|0)==($188|0);
          if (!($191)) {
           $scevgep$i$i$i3$i$i = ((($190)) + -20|0);
           $192 = $scevgep$i$i$i3$i$i;
           $193 = $188;
           $194 = (($192) - ($193))|0;
           $195 = (($194>>>0) / 20)&-1;
           $196 = $195 ^ -1;
           $scevgep5$i$i$i4$i$i = (($190) + (($196*20)|0)|0);
           HEAP32[$189>>2] = $scevgep5$i$i$i4$i$i;
          }
         }
         $210 = ((($1)) + 32|0);
         $211 = HEAP32[$210>>2]|0;
         $212 = ((($172)) + 20|0);
         HEAP32[$212>>2] = $211;
         $213 = ((($1)) + 36|0);
         $214 = HEAP32[$213>>2]|0;
         $215 = ((($172)) + 24|0);
         HEAP32[$215>>2] = $214;
         $216 = HEAP32[$36>>2]|0;
         $217 = ((($172)) + 28|0);
         HEAP32[$217>>2] = $216;
         if (!($59)) {
          $218 = ((($58)) + 8|0);
          $219 = HEAP32[$218>>2]|0;HEAP32[$218>>2] = (($219-1)|0);
          $220 = ($219|0)==(1);
          if ($220) {
           __THREW__ = 0;
           invoke_viii(3262,($58|0),1,1);
           $221 = __THREW__; __THREW__ = 0;
           $222 = $221&1;
           if ($222) {
            $226 = ___cxa_find_matching_catch_2()|0;
            $227 = tempRet0;
            $$0 = $226;$$017 = $227;
            break;
           }
          }
         }
         $223 = HEAP32[$5>>2]|0;
         $224 = ((($223)) + 12|0);
         $225 = HEAP32[$224>>2]|0;
         (FUNCTION_TABLE_ii[$225 & 8191]($5)|0);
         STACKTOP = sp;return;
        }
       }
      } while(0);
      if ((label|0) == 36) {
       $126 = ___cxa_find_matching_catch_2()|0;
       $127 = tempRet0;
       $eh$lpad$body$index3Z2D = $127;$eh$lpad$body$indexZ2D = $126;
       label = 37;
      }
      if ((label|0) == 37) {
       if ($59) {
        $$0 = $eh$lpad$body$indexZ2D;$$017 = $eh$lpad$body$index3Z2D;
       } else {
        $128 = ((($58)) + 8|0);
        $129 = HEAP32[$128>>2]|0;HEAP32[$128>>2] = (($129-1)|0);
        $130 = ($129|0)==(1);
        if ($130) {
         __THREW__ = 0;
         invoke_viii(3262,($58|0),1,1);
         $131 = __THREW__; __THREW__ = 0;
         $132 = $131&1;
         if ($132) {
          $289 = ___cxa_find_matching_catch_3(0|0)|0;
          $290 = tempRet0;
          ___clang_call_terminate($289);
          // unreachable;
         } else {
          $$0 = $eh$lpad$body$indexZ2D;$$017 = $eh$lpad$body$index3Z2D;
         }
        } else {
         $$0 = $eh$lpad$body$indexZ2D;$$017 = $eh$lpad$body$index3Z2D;
        }
       }
      }
      $228 = HEAP32[$0>>2]|0;
      $229 = ($228|0)==(0|0);
      if (!($229)) {
       $230 = ((($228)) + 8|0);
       $231 = HEAP32[$230>>2]|0;HEAP32[$230>>2] = (($231-1)|0);
       $232 = ($231|0)==(1);
       if ($232) {
        __THREW__ = 0;
        invoke_viii(3262,($228|0),1,1);
        $233 = __THREW__; __THREW__ = 0;
        $234 = $233&1;
        if ($234) {
         $289 = ___cxa_find_matching_catch_3(0|0)|0;
         $290 = tempRet0;
         ___clang_call_terminate($289);
         // unreachable;
        }
       }
      }
      HEAP32[$0>>2] = 0;
      $235 = HEAP32[$5>>2]|0;
      $236 = ((($235)) + 12|0);
      $237 = HEAP32[$236>>2]|0;
      __THREW__ = 0;
      (invoke_ii($237|0,($5|0))|0);
      $238 = __THREW__; __THREW__ = 0;
      $239 = $238&1;
      if ($239) {
       $289 = ___cxa_find_matching_catch_3(0|0)|0;
       $290 = tempRet0;
       ___clang_call_terminate($289);
       // unreachable;
      } else {
       $$4 = $$0;$$421 = $$017;
       ___resumeException($$4|0);
       // unreachable;
      }
     }
    }
   }
  }
 }
 $240 = (__Znwj(76)|0);
 $241 = ((($1)) + 28|0);
 $242 = HEAP32[$241>>2]|0;
 __THREW__ = 0;
 invoke_viiii(3717,($240|0),($242|0),($2|0),0);
 $243 = __THREW__; __THREW__ = 0;
 $244 = $243&1;
 if ($244) {
  $284 = ___cxa_find_matching_catch_2()|0;
  $285 = tempRet0;
  __ZdlPv($240);
  $$4 = $284;$$421 = $285;
  ___resumeException($$4|0);
  // unreachable;
 }
 $245 = ((($1)) + 32|0);
 $246 = HEAP32[$245>>2]|0;
 $247 = ((($240)) + 20|0);
 HEAP32[$247>>2] = $246;
 $248 = ((($1)) + 36|0);
 $249 = HEAP32[$248>>2]|0;
 $250 = ((($240)) + 24|0);
 HEAP32[$250>>2] = $249;
 $251 = ((($1)) + 40|0);
 $252 = HEAP32[$251>>2]|0;
 $253 = ((($240)) + 28|0);
 HEAP32[$253>>2] = $252;
 $254 = ((($240)) + 56|0);
 HEAP32[$254>>2] = $1;
 $255 = ((($1)) + 44|0);
 $256 = HEAP32[$255>>2]|0;
 $257 = (($256) + 1)|0;
 HEAP32[$255>>2] = $257;
 $258 = HEAP32[$29>>2]|0;
 $259 = ((($258)) + 36|0);
 $260 = HEAP32[$259>>2]|0;
 $261 = (($260) + ($252))|0;
 HEAP32[$259>>2] = $261;
 $262 = ((($258)) + 28|0);
 $263 = HEAP32[$262>>2]|0;
 $264 = (($263) + 1)|0;
 HEAP32[$262>>2] = $264;
 $265 = ((($240)) + 60|0);
 $266 = HEAP32[$265>>2]|0;
 $267 = ($266|0)==(0|0);
 if ($267) {
  $268 = ((($240)) + 64|0);
  $269 = HEAP32[$268>>2]|0;
  $270 = ($269|0)==(0|0);
  if ($270) {
   $271 = ((($258)) + 56|0);
   $272 = HEAP32[$271>>2]|0;
   $273 = ((($240)) + 68|0);
   HEAP32[$273>>2] = $272;
   $274 = ((($1)) + 76|0);
   $275 = HEAP32[$274>>2]|0;
   $276 = ($275|0)==(0|0);
   $277 = $275;
   if (!($276)) {
    $278 = ((($275)) + 64|0);
    HEAP32[$278>>2] = $240;
   }
   HEAP32[$265>>2] = $277;
   $279 = ((($1)) + 72|0);
   $280 = HEAP32[$279>>2]|0;
   $281 = ($280|0)==(0|0);
   if ($281) {
    HEAP32[$279>>2] = $240;
   }
   HEAP32[$274>>2] = $240;
  } else {
   label = 72;
  }
 } else {
  label = 72;
 }
 if ((label|0) == 72) {
  __ZN3osg17GLBufferObjectSet10moveToBackEPNS_14GLBufferObjectE($1,$240);
 }
 HEAP32[$0>>2] = $240;
 $282 = ((($240)) + 8|0);
 $283 = HEAP32[$282>>2]|0;HEAP32[$282>>2] = (($283+1)|0);
 STACKTOP = sp;return;
}
function __ZN3osg17GLBufferObjectSet15takeFromOrphansEPNS_12BufferObjectE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$pre = 0, $$pre$phi6Z2D = 0, $$pre$phi7Z2D = 0, $$pre$phiZ2D = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i$i3$i = 0, $scevgep5$i$i$i$i = 0, $scevgep5$i$i$i4$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($1)) + 52|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($4)) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 HEAP32[$0>>2] = $6;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $11 = $4;
 } else {
  $8 = ((($6)) + 8|0);
  $9 = HEAP32[$8>>2]|0;HEAP32[$8>>2] = (($9+1)|0);
  $$pre = HEAP32[$3>>2]|0;
  $11 = $$pre;
 }
 $10 = ((($11)) + 4|0);
 $12 = HEAP32[$10>>2]|0;
 $13 = HEAP32[$11>>2]|0;
 $14 = ((($13)) + 4|0);
 HEAP32[$14>>2] = $12;
 $15 = HEAP32[$10>>2]|0;
 HEAP32[$15>>2] = $13;
 $16 = ((($1)) + 56|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($17) + -1)|0;
 HEAP32[$16>>2] = $18;
 $19 = ((($11)) + 8|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)==(0|0);
 if ($21) {
  label = 6;
 } else {
  $22 = ((($20)) + 8|0);
  $23 = HEAP32[$22>>2]|0;HEAP32[$22>>2] = (($23-1)|0);
  $24 = ($23|0)==(1);
  if ($24) {
   __THREW__ = 0;
   invoke_viii(3262,($20|0),1,1);
   $25 = __THREW__; __THREW__ = 0;
   $26 = $25&1;
   if (!($26)) {
    label = 6;
   }
  } else {
   label = 6;
  }
 }
 if ((label|0) == 6) {
  __ZdlPv($11);
  $27 = HEAP32[$0>>2]|0;
  $28 = ((($27)) + 52|0);
  HEAP32[$28>>2] = $2;
  $29 = ($2|0)==(0|0);
  if ($29) {
   $50 = ((($27)) + 20|0);
   HEAP32[$50>>2] = 0;
   $51 = ((($27)) + 24|0);
   HEAP32[$51>>2] = 0;
   $52 = ((($27)) + 28|0);
   HEAP32[$52>>2] = 0;
   $53 = ((($27)) + 40|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = ((($27)) + 44|0);
   $56 = HEAP32[$55>>2]|0;
   $57 = ($56|0)==($54|0);
   if ($57) {
    $$pre$phi6Z2D = $51;$$pre$phi7Z2D = $52;$$pre$phiZ2D = $50;
   } else {
    $scevgep$i$i$i$i = ((($56)) + -20|0);
    $58 = $scevgep$i$i$i$i;
    $59 = $54;
    $60 = (($58) - ($59))|0;
    $61 = (($60>>>0) / 20)&-1;
    $62 = $61 ^ -1;
    $scevgep5$i$i$i$i = (($56) + (($62*20)|0)|0);
    HEAP32[$55>>2] = $scevgep5$i$i$i$i;
    $$pre$phi6Z2D = $51;$$pre$phi7Z2D = $52;$$pre$phiZ2D = $50;
   }
  } else {
   $30 = ((($2)) + 32|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = ((($27)) + 20|0);
   HEAP32[$32>>2] = $31;
   $33 = ((($2)) + 36|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = ((($27)) + 24|0);
   HEAP32[$35>>2] = $34;
   $36 = ((($2)) + 40|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = ((($27)) + 28|0);
   HEAP32[$38>>2] = $37;
   $39 = ((($27)) + 36|0);
   HEAP8[$39>>0] = 1;
   $40 = ((($27)) + 40|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = ((($27)) + 44|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = ($43|0)==($41|0);
   if ($44) {
    $$pre$phi6Z2D = $35;$$pre$phi7Z2D = $38;$$pre$phiZ2D = $32;
   } else {
    $scevgep$i$i$i3$i = ((($43)) + -20|0);
    $45 = $scevgep$i$i$i3$i;
    $46 = $41;
    $47 = (($45) - ($46))|0;
    $48 = (($47>>>0) / 20)&-1;
    $49 = $48 ^ -1;
    $scevgep5$i$i$i4$i = (($43) + (($49*20)|0)|0);
    HEAP32[$42>>2] = $scevgep5$i$i$i4$i;
    $$pre$phi6Z2D = $35;$$pre$phi7Z2D = $38;$$pre$phiZ2D = $32;
   }
  }
  $63 = ((($1)) + 32|0);
  $64 = HEAP32[$63>>2]|0;
  HEAP32[$$pre$phiZ2D>>2] = $64;
  $65 = ((($1)) + 36|0);
  $66 = HEAP32[$65>>2]|0;
  HEAP32[$$pre$phi6Z2D>>2] = $66;
  $67 = ((($1)) + 40|0);
  $68 = HEAP32[$67>>2]|0;
  HEAP32[$$pre$phi7Z2D>>2] = $68;
  $69 = ((($1)) + 24|0);
  $70 = HEAP32[$69>>2]|0;
  $71 = ((($70)) + 32|0);
  $72 = HEAP32[$71>>2]|0;
  $73 = (($72) + -1)|0;
  HEAP32[$71>>2] = $73;
  $74 = ((($70)) + 28|0);
  $75 = HEAP32[$74>>2]|0;
  $76 = (($75) + 1)|0;
  HEAP32[$74>>2] = $76;
  $77 = ((($27)) + 60|0);
  $78 = HEAP32[$77>>2]|0;
  $79 = ($78|0)==(0|0);
  if ($79) {
   $80 = ((($27)) + 64|0);
   $81 = HEAP32[$80>>2]|0;
   $82 = ($81|0)==(0|0);
   if ($82) {
    $85 = ((($70)) + 56|0);
    $86 = HEAP32[$85>>2]|0;
    $87 = ((($27)) + 68|0);
    HEAP32[$87>>2] = $86;
    $88 = ((($1)) + 76|0);
    $89 = HEAP32[$88>>2]|0;
    $90 = ($89|0)==(0|0);
    $91 = $89;
    if (!($90)) {
     $92 = ((($89)) + 64|0);
     HEAP32[$92>>2] = $27;
    }
    HEAP32[$77>>2] = $91;
    $93 = ((($1)) + 72|0);
    $94 = HEAP32[$93>>2]|0;
    $95 = ($94|0)==(0|0);
    if ($95) {
     HEAP32[$93>>2] = $27;
    }
    HEAP32[$88>>2] = $27;
    return;
   }
  }
  __THREW__ = 0;
  invoke_vii(3716,($1|0),($27|0));
  $83 = __THREW__; __THREW__ = 0;
  $84 = $83&1;
  if (!($84)) {
   return;
  }
 }
 $96 = ___cxa_find_matching_catch_2()|0;
 $97 = tempRet0;
 $98 = HEAP32[$0>>2]|0;
 $99 = ($98|0)==(0|0);
 if ($99) {
  HEAP32[$0>>2] = 0;
  ___resumeException($96|0);
  // unreachable;
 }
 $100 = ((($98)) + 8|0);
 $101 = HEAP32[$100>>2]|0;HEAP32[$100>>2] = (($101-1)|0);
 $102 = ($101|0)==(1);
 if (!($102)) {
  HEAP32[$0>>2] = 0;
  ___resumeException($96|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(3262,($98|0),1,1);
 $103 = __THREW__; __THREW__ = 0;
 $104 = $103&1;
 if ($104) {
  $105 = ___cxa_find_matching_catch_3(0|0)|0;
  $106 = tempRet0;
  ___clang_call_terminate($105);
  // unreachable;
 } else {
  HEAP32[$0>>2] = 0;
  ___resumeException($96|0);
  // unreachable;
 }
}
function __ZN3osg17GLBufferObjectSet10moveToBackEPNS_14GLBufferObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$sink = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp + 4|0;
 $3 = sp;
 $4 = ((($0)) + 24|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($5)) + 56|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($1)) + 68|0);
 HEAP32[$8>>2] = $7;
 $9 = ((($0)) + 76|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==($1|0);
 if ($11) {
  STACKTOP = sp;return;
 }
 $12 = ($10|0)==(0|0);
 if ($12) {
  $13 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
  do {
   if ($13) {
    $14 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
    $15 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($14,154898,53)|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = ((($16)) + -12|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = (($15) + ($18)|0);
    __ZNKSt3__28ios_base6getlocEv($2,$19);
    __THREW__ = 0;
    $20 = (invoke_iii(3255,($2|0),(215188|0))|0);
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if (!($22)) {
     $23 = HEAP32[$20>>2]|0;
     $24 = ((($23)) + 28|0);
     $25 = HEAP32[$24>>2]|0;
     __THREW__ = 0;
     $26 = (invoke_iii($25|0,($20|0),10)|0);
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     if (!($28)) {
      __ZNSt3__26localeD2Ev($2);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($15,$26)|0);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($15)|0);
      break;
     }
    }
    $29 = ___cxa_find_matching_catch_2()|0;
    $30 = tempRet0;
    __THREW__ = 0;
    invoke_vi(3263,($2|0));
    $31 = __THREW__; __THREW__ = 0;
    $32 = $31&1;
    if ($32) {
     $33 = ___cxa_find_matching_catch_3(0|0)|0;
     $34 = tempRet0;
     ___clang_call_terminate($33);
     // unreachable;
    } else {
     ___resumeException($29|0);
     // unreachable;
    }
   }
  } while(0);
  $35 = ((($0)) + 72|0);
  HEAP32[$35>>2] = $1;
  HEAP32[$9>>2] = $1;
  STACKTOP = sp;return;
 }
 $36 = ((($1)) + 64|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = ($37|0)==(0|0);
 if (!($38)) {
  $61 = ((($1)) + 60|0);
  $62 = HEAP32[$61>>2]|0;
  $63 = ($62|0)==(0|0);
  $64 = ((($0)) + 72|0);
  $65 = ((($62)) + 64|0);
  $$sink = $63 ? $64 : $65;
  HEAP32[$$sink>>2] = $37;
  $66 = HEAP32[$36>>2]|0;
  $67 = ((($66)) + 60|0);
  HEAP32[$67>>2] = $62;
  $68 = HEAP32[$9>>2]|0;
  $69 = ((($68)) + 64|0);
  HEAP32[$69>>2] = $1;
  HEAP32[$61>>2] = $68;
  HEAP32[$36>>2] = 0;
  HEAP32[$9>>2] = $1;
  STACKTOP = sp;return;
 }
 $39 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
 if (!($39)) {
  STACKTOP = sp;return;
 }
 $40 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
 $41 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($40,154952,60)|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ((($42)) + -12|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = (($41) + ($44)|0);
 __ZNKSt3__28ios_base6getlocEv($3,$45);
 __THREW__ = 0;
 $46 = (invoke_iii(3255,($3|0),(215188|0))|0);
 $47 = __THREW__; __THREW__ = 0;
 $48 = $47&1;
 if (!($48)) {
  $49 = HEAP32[$46>>2]|0;
  $50 = ((($49)) + 28|0);
  $51 = HEAP32[$50>>2]|0;
  __THREW__ = 0;
  $52 = (invoke_iii($51|0,($46|0),10)|0);
  $53 = __THREW__; __THREW__ = 0;
  $54 = $53&1;
  if (!($54)) {
   __ZNSt3__26localeD2Ev($3);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($41,$52)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($41)|0);
   STACKTOP = sp;return;
  }
 }
 $55 = ___cxa_find_matching_catch_2()|0;
 $56 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($3|0));
 $57 = __THREW__; __THREW__ = 0;
 $58 = $57&1;
 if ($58) {
  $59 = ___cxa_find_matching_catch_3(0|0)|0;
  $60 = tempRet0;
  ___clang_call_terminate($59);
  // unreachable;
 } else {
  ___resumeException($55|0);
  // unreachable;
 }
}
function __ZN3osg14GLBufferObjectC2EjPNS_12BufferObjectEj($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $scevgep$i$i$i = 0, $scevgep5$i$i$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 __ZN3osg14GraphicsObjectC2Ev($0);
 HEAP32[$0>>2] = (54876);
 $4 = ((($0)) + 12|0);
 HEAP32[$4>>2] = $1;
 $5 = ((($0)) + 16|0);
 HEAP32[$5>>2] = $3;
 $6 = ((($0)) + 20|0);
 $7 = ((($0)) + 24|0);
 $8 = ((($0)) + 28|0);
 $9 = ((($0)) + 36|0);
 ;HEAP32[$6>>2]=0|0;HEAP32[$6+4>>2]=0|0;HEAP32[$6+8>>2]=0|0;HEAP32[$6+12>>2]=0|0;
 HEAP8[$9>>0] = 1;
 $10 = ((($0)) + 40|0);
 $11 = ((($0)) + 44|0);
 $12 = ((($0)) + 52|0);
 $13 = ((($0)) + 72|0);
 dest=$10; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAP32[$12>>2] = $2;
 $14 = ($2|0)==(0|0);
 if ($14) {
  HEAP32[$6>>2] = 0;
  HEAP32[$7>>2] = 0;
  HEAP32[$8>>2] = 0;
 } else {
  $15 = ((($2)) + 32|0);
  $16 = HEAP32[$15>>2]|0;
  HEAP32[$6>>2] = $16;
  $17 = ((($2)) + 36|0);
  $18 = HEAP32[$17>>2]|0;
  HEAP32[$7>>2] = $18;
  $19 = ((($2)) + 40|0);
  $20 = HEAP32[$19>>2]|0;
  HEAP32[$8>>2] = $20;
  HEAP8[$9>>0] = 1;
 }
 __THREW__ = 0;
 $21 = (invoke_iii(3718,($1|0),1)|0);
 $22 = __THREW__; __THREW__ = 0;
 $23 = $22&1;
 if (!($23)) {
  HEAP32[$13>>2] = $21;
  $24 = ($3|0)==(0);
  if (!($24)) {
   return;
  }
  $25 = ((($21)) + 720|0);
  $26 = HEAP32[$25>>2]|0;
  __THREW__ = 0;
  invoke_vii($26|0,1,($5|0));
  $27 = __THREW__; __THREW__ = 0;
  $28 = $27&1;
  if (!($28)) {
   return;
  }
 }
 $29 = ___cxa_find_matching_catch_2()|0;
 $30 = tempRet0;
 $31 = HEAP32[$10>>2]|0;
 $32 = ($31|0)==(0|0);
 if (!($32)) {
  $33 = HEAP32[$11>>2]|0;
  $34 = ($33|0)==($31|0);
  if (!($34)) {
   $scevgep$i$i$i = ((($33)) + -20|0);
   $35 = $scevgep$i$i$i;
   $36 = $31;
   $37 = (($35) - ($36))|0;
   $38 = (($37>>>0) / 20)&-1;
   $39 = $38 ^ -1;
   $scevgep5$i$i$i = (($33) + (($39*20)|0)|0);
   HEAP32[$11>>2] = $scevgep5$i$i$i;
  }
  __ZdlPv($31);
 }
 __THREW__ = 0;
 invoke_vi(1859,($0|0));
 $40 = __THREW__; __THREW__ = 0;
 $41 = $40&1;
 if ($41) {
  $42 = ___cxa_find_matching_catch_3(0|0)|0;
  $43 = tempRet0;
  ___clang_call_terminate($42);
  // unreachable;
 } else {
  ___resumeException($29|0);
  // unreachable;
 }
}
function __ZN3osg21GLBufferObjectManagerC2Ej($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = (__Znwj(32)|0);
 HEAP32[$2>>2] = $3;
 $4 = ((($2)) + 8|0);
 HEAP32[$4>>2] = -2147483616;
 $5 = ((($2)) + 4|0);
 HEAP32[$5>>2] = 21;
 dest=$3; src=119988; stop=dest+21|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $6 = ((($3)) + 21|0);
 HEAP8[$6>>0] = 0;
 __THREW__ = 0;
 invoke_viii(3719,($0|0),($2|0),($1|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if (!($8)) {
  $9 = ((($2)) + 11|0);
  $10 = HEAP8[$9>>0]|0;
  $11 = ($10<<24>>24)<(0);
  if ($11) {
   $12 = HEAP32[$2>>2]|0;
   __ZdlPv($12);
  }
  HEAP32[$0>>2] = (54916);
  $13 = ((($0)) + 28|0);
  $14 = ((($0)) + 48|0);
  HEAP32[$14>>2] = 0;
  $15 = ((($0)) + 52|0);
  HEAP32[$15>>2] = 0;
  $16 = ((($0)) + 48|0);
  $17 = ((($0)) + 44|0);
  ;HEAP32[$13>>2]=0|0;HEAP32[$13+4>>2]=0|0;HEAP32[$13+8>>2]=0|0;HEAP32[$13+12>>2]=0|0;
  HEAP32[$17>>2] = $16;
  $18 = ((($0)) + 56|0);
  HEAP32[$18>>2] = 0;
  $19 = ((($0)) + 60|0);
  HEAP32[$19>>2] = 0;
  $20 = ((($0)) + 64|0);
  HEAP32[$20>>2] = 0;
  $21 = ((($0)) + 72|0);
  HEAPF64[$21>>3] = 0.0;
  $22 = ((($0)) + 80|0);
  HEAP32[$22>>2] = 0;
  $23 = ((($0)) + 88|0);
  HEAPF64[$23>>3] = 0.0;
  $24 = ((($0)) + 96|0);
  HEAP32[$24>>2] = 0;
  $25 = ((($0)) + 104|0);
  HEAPF64[$25>>3] = 0.0;
  STACKTOP = sp;return;
 }
 $26 = ___cxa_find_matching_catch_2()|0;
 $27 = tempRet0;
 $28 = ((($2)) + 11|0);
 $29 = HEAP8[$28>>0]|0;
 $30 = ($29<<24>>24)<(0);
 if (!($30)) {
  ___resumeException($26|0);
  // unreachable;
 }
 $31 = HEAP32[$2>>2]|0;
 __ZdlPv($31);
 ___resumeException($26|0);
 // unreachable;
}
function __ZN3osg14GLBufferObject13compileBufferEv($0) {
 $0 = $0|0;
 var $$0$i = 0, $$0$i98 = 0, $$0$off0 = 0, $$085$off0$ = 0, $$085$off0122 = 0, $$086 = 0, $$086$us = 0, $$087$lcssa = 0, $$087121 = 0, $$090$lcssa = 0, $$090119 = 0, $$289 = 0, $$3$off0 = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre128 = 0, $$pre129 = 0, $$pre130 = 0, $$pre131 = 0, $$pre136 = 0;
 var $$sink$i$i = 0, $$sink1$i$i = 0, $$sroa$0102$0118 = 0, $$sroa$0102$0118$us = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0;
 var $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0;
 var $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0;
 var $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0;
 var $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0;
 var $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0;
 var $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0;
 var $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0;
 var $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0;
 var $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0;
 var $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0;
 var $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $not$ = 0, $or$cond$i = 0, $scevgep$i$i$i = 0, $scevgep5$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(64|0);
 $1 = sp + 48|0;
 $2 = sp + 44|0;
 $3 = sp + 24|0;
 $4 = sp;
 $5 = ((($0)) + 36|0);
 HEAP8[$5>>0] = 0;
 $6 = ((($0)) + 40|0);
 $7 = ((($0)) + 52|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($8)) + 48|0);
 $10 = ((($8)) + 52|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = HEAP32[$9>>2]|0;
 $13 = (($11) - ($12))|0;
 $14 = $13 >> 2;
 __ZNSt3__26vectorIN3osg14GLBufferObject11BufferEntryENS_9allocatorIS3_EEE7reserveEj($6,$14);
 $15 = HEAP32[$7>>2]|0;
 $16 = ((($15)) + 48|0);
 $17 = ((($15)) + 52|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = HEAP32[$16>>2]|0;
 $20 = ($18|0)==($19|0);
 $$pre131 = ((($0)) + 44|0);
 if ($20) {
  $$087$lcssa = 0;$$090$lcssa = 0;
 } else {
  $21 = ((($3)) + 12|0);
  $22 = ((($3)) + 4|0);
  $23 = ((($3)) + 8|0);
  $24 = ((($3)) + 16|0);
  $25 = ((($0)) + 48|0);
  $$085$off0122 = 0;$$087121 = 0;$$090119 = 0;$27 = $15;
  while(1) {
   $26 = ((($27)) + 48|0);
   $28 = HEAP32[$26>>2]|0;
   $29 = (($28) + ($$090119<<2)|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = HEAP32[$$pre131>>2]|0;
   $32 = HEAP32[$6>>2]|0;
   $33 = (($31) - ($32))|0;
   $34 = (($33|0) / 20)&-1;
   $35 = ($$090119>>>0)<($34>>>0);
   $36 = $32;
   do {
    if ($35) {
     $$pre136 = (((($36) + (($$090119*20)|0)|0)) + 16|0);
     if (!($$085$off0122)) {
      $37 = HEAP32[$$pre136>>2]|0;
      $38 = ($37|0)==($30|0);
      if ($38) {
       $39 = (((($36) + (($$090119*20)|0)|0)) + 8|0);
       $40 = HEAP32[$39>>2]|0;
       $41 = HEAP32[$30>>2]|0;
       $42 = ((($41)) + 144|0);
       $43 = HEAP32[$42>>2]|0;
       $44 = (FUNCTION_TABLE_ii[$43 & 8191]($30)|0);
       $45 = ($40|0)==($44|0);
       if ($45) {
        $62 = HEAP32[$39>>2]|0;
        $63 = (($62) + ($$087121))|0;
        $64 = $63 & 3;
        $65 = ($64|0)==(0);
        if ($65) {
         $$289 = $63;$$3$off0 = 0;
         break;
        }
        $66 = (($63) + 4)|0;
        $67 = $66 & -4;
        $$289 = $67;$$3$off0 = 0;
        break;
       }
      }
     }
     $46 = (((($36) + (($$090119*20)|0)|0)) + 12|0);
     $47 = HEAP32[$46>>2]|0;
     $48 = (((($36) + (($$090119*20)|0)|0)) + 8|0);
     $49 = HEAP32[$48>>2]|0;
     $50 = (($49) + ($47))|0;
     $51 = $50 & 3;
     $52 = ($51|0)==(0);
     $53 = (($50) + 4)|0;
     $54 = $53 & -4;
     $$0$i = $52 ? $50 : $54;
     $55 = (($36) + (($$090119*20)|0)|0);
     HEAP32[$55>>2] = 0;
     $56 = (((($36) + (($$090119*20)|0)|0)) + 4|0);
     HEAP32[$56>>2] = 16777215;
     HEAP32[$46>>2] = $$087121;
     $57 = HEAP32[$30>>2]|0;
     $58 = ((($57)) + 144|0);
     $59 = HEAP32[$58>>2]|0;
     $60 = (FUNCTION_TABLE_ii[$59 & 8191]($30)|0);
     HEAP32[$48>>2] = $60;
     HEAP32[$$pre136>>2] = $30;
     $61 = (($60) + ($$087121))|0;
     $not$ = ($$0$i|0)!=($61|0);
     $$085$off0$ = $$085$off0122 | $not$;
     $$289 = $61;$$3$off0 = $$085$off0$;
    } else {
     $68 = $31;
     ;HEAP32[$3>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;HEAP32[$3+12>>2]=0|0;HEAP32[$3+16>>2]=0|0;
     HEAP32[$21>>2] = $$087121;
     HEAP32[$22>>2] = 16777215;
     $69 = ($30|0)==(0|0);
     if ($69) {
      $74 = 0;$81 = $68;
     } else {
      $70 = HEAP32[$30>>2]|0;
      $71 = ((($70)) + 144|0);
      $72 = HEAP32[$71>>2]|0;
      $73 = (FUNCTION_TABLE_ii[$72 & 8191]($30)|0);
      $$pre = HEAP32[$$pre131>>2]|0;
      $74 = $73;$81 = $$pre;
     }
     HEAP32[$23>>2] = $74;
     HEAP32[$24>>2] = $30;
     $75 = (($74) + ($$087121))|0;
     $76 = $75 & 3;
     $77 = ($76|0)==(0);
     $78 = (($75) + 4)|0;
     $79 = $78 & -4;
     $$0$i98 = $77 ? $75 : $79;
     $80 = HEAP32[$25>>2]|0;
     $82 = ($81|0)==($80|0);
     if ($82) {
      __ZNSt3__26vectorIN3osg14GLBufferObject11BufferEntryENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_($6,$3);
     } else {
      $83 = $30;
      $84 = HEAP32[$3>>2]|0;
      HEAP32[$81>>2] = $84;
      $85 = ((($81)) + 4|0);
      $86 = HEAP32[$22>>2]|0;
      HEAP32[$85>>2] = $86;
      $87 = ((($81)) + 8|0);
      HEAP32[$87>>2] = $74;
      $88 = ((($81)) + 12|0);
      $89 = HEAP32[$21>>2]|0;
      HEAP32[$88>>2] = $89;
      $90 = ((($81)) + 16|0);
      HEAP32[$90>>2] = $83;
      $91 = ((($81)) + 20|0);
      HEAP32[$$pre131>>2] = $91;
     }
     $$289 = $$0$i98;$$3$off0 = $$085$off0122;
    }
   } while(0);
   $92 = (($$090119) + 1)|0;
   $93 = HEAP32[$7>>2]|0;
   $94 = ((($93)) + 48|0);
   $95 = ((($93)) + 52|0);
   $96 = HEAP32[$95>>2]|0;
   $97 = HEAP32[$94>>2]|0;
   $98 = (($96) - ($97))|0;
   $99 = $98 >> 2;
   $100 = ($92>>>0)<($99>>>0);
   if ($100) {
    $$085$off0122 = $$3$off0;$$087121 = $$289;$$090119 = $92;$27 = $93;
   } else {
    $$087$lcssa = $$289;$$090$lcssa = $92;
    break;
   }
  }
 }
 $101 = HEAP32[$$pre131>>2]|0;
 $102 = HEAP32[$6>>2]|0;
 $103 = (($101) - ($102))|0;
 $104 = (($103|0) / 20)&-1;
 $105 = ($$090$lcssa>>>0)<($104>>>0);
 $106 = $101;
 if ($105) {
  $107 = $102;
  $108 = (($107) + (($$090$lcssa*20)|0)|0);
  $109 = ($108|0)==($106|0);
  if (!($109)) {
   $scevgep$i$i$i = ((($106)) + -20|0);
   $110 = $scevgep$i$i$i;
   $111 = $108;
   $112 = (($110) - ($111))|0;
   $113 = (($112>>>0) / 20)&-1;
   $114 = $113 ^ -1;
   $scevgep5$i$i$i = (($106) + (($114*20)|0)|0);
   HEAP32[$$pre131>>2] = $scevgep5$i$i$i;
  }
 }
 $115 = ((($0)) + 72|0);
 $116 = HEAP32[$115>>2]|0;
 $117 = ((($116)) + 724|0);
 $118 = HEAP32[$117>>2]|0;
 $119 = ((($0)) + 20|0);
 $120 = HEAP32[$119>>2]|0;
 $121 = ((($0)) + 16|0);
 $122 = HEAP32[$121>>2]|0;
 FUNCTION_TABLE_vii[$118 & 8191]($120,$122);
 $123 = HEAP32[$115>>2]|0;
 $124 = HEAP32[$121>>2]|0;
 $125 = HEAP32[$7>>2]|0;
 $126 = ((($125)) + 12|0);
 $127 = ((($123)) + 1688|0);
 $128 = HEAP32[$127>>2]|0;
 $129 = ($128|0)==(0|0);
 if (!($129)) {
  $130 = ((($126)) + 11|0);
  $131 = HEAP8[$130>>0]|0;
  $132 = ($131<<24>>24)<(0);
  $133 = ((($125)) + 16|0);
  $134 = HEAP32[$133>>2]|0;
  $135 = $131&255;
  $136 = $132 ? $134 : $135;
  $137 = ($136|0)==(0);
  if (!($137)) {
   $138 = HEAP32[$126>>2]|0;
   $139 = $132 ? $138 : $126;
   FUNCTION_TABLE_viiii[$128 & 8191](33504,$124,$136,$139);
  }
 }
 $140 = ((($0)) + 28|0);
 $141 = HEAP32[$140>>2]|0;
 $142 = ($$087$lcssa>>>0)>($141>>>0);
 if ($142) {
  $143 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
  do {
   if ($143) {
    $144 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
    $145 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($144,120010,13)|0);
    $146 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($145,$$087$lcssa)|0);
    $147 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($146,120024,17)|0);
    $148 = HEAP32[$140>>2]|0;
    $149 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($147,$148)|0);
    $150 = HEAP32[$149>>2]|0;
    $151 = ((($150)) + -12|0);
    $152 = HEAP32[$151>>2]|0;
    $153 = (($149) + ($152)|0);
    __ZNKSt3__28ios_base6getlocEv($1,$153);
    __THREW__ = 0;
    $154 = (invoke_iii(3255,($1|0),(215188|0))|0);
    $155 = __THREW__; __THREW__ = 0;
    $156 = $155&1;
    if (!($156)) {
     $157 = HEAP32[$154>>2]|0;
     $158 = ((($157)) + 28|0);
     $159 = HEAP32[$158>>2]|0;
     __THREW__ = 0;
     $160 = (invoke_iii($159|0,($154|0),10)|0);
     $161 = __THREW__; __THREW__ = 0;
     $162 = $161&1;
     if (!($162)) {
      __ZNSt3__26localeD2Ev($1);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($149,$160)|0);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($149)|0);
      break;
     }
    }
    $163 = ___cxa_find_matching_catch_2()|0;
    $164 = tempRet0;
    __THREW__ = 0;
    invoke_vi(3263,($1|0));
    $165 = __THREW__; __THREW__ = 0;
    $166 = $165&1;
    if ($166) {
     $167 = ___cxa_find_matching_catch_3(0|0)|0;
     $168 = tempRet0;
     ___clang_call_terminate($167);
     // unreachable;
    } else {
     ___resumeException($163|0);
     // unreachable;
    }
   }
  } while(0);
  $169 = HEAP32[$140>>2]|0;
  HEAP32[$140>>2] = $$087$lcssa;
  $170 = ((($0)) + 56|0);
  $171 = HEAP32[$170>>2]|0;
  $172 = ($171|0)==(0|0);
  if ($172) {
   $234 = $$087$lcssa;
  } else {
   $173 = (($$087$lcssa) - ($169))|0;
   $174 = ((($171)) + 24|0);
   $175 = HEAP32[$174>>2]|0;
   $176 = ((($175)) + 44|0);
   $177 = (__ZNSt3__23mapIN3osg19BufferObjectProfileENS1_7ref_ptrINS1_17GLBufferObjectSetEEENS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S5_EEEEEixERSA_($176,$119)|0);
   $178 = HEAP32[$177>>2]|0;
   $179 = ($178|0)==(0|0);
   if ($179) {
    $180 = (__Znwj(80)|0);
    __THREW__ = 0;
    invoke_viii(3713,($180|0),($175|0),($119|0));
    $181 = __THREW__; __THREW__ = 0;
    $182 = $181&1;
    if ($182) {
     $191 = ___cxa_find_matching_catch_2()|0;
     $192 = tempRet0;
     __ZdlPv($180);
     ___resumeException($191|0);
     // unreachable;
    }
    $183 = HEAP32[$177>>2]|0;
    $184 = ($183|0)==($180|0);
    if (!($184)) {
     HEAP32[$177>>2] = $180;
     $185 = ((($180)) + 8|0);
     $186 = HEAP32[$185>>2]|0;HEAP32[$185>>2] = (($186+1)|0);
     $187 = ($183|0)==(0|0);
     if (!($187)) {
      $188 = ((($183)) + 8|0);
      $189 = HEAP32[$188>>2]|0;HEAP32[$188>>2] = (($189-1)|0);
      $190 = ($189|0)==(1);
      if ($190) {
       __ZNK3osg10Referenced24signalObserversAndDeleteEbb($183,1,1);
      }
     }
    }
   }
   $193 = HEAP32[$177>>2]|0;
   $194 = ($193|0)!=($171|0);
   $195 = ($193|0)!=(0|0);
   $or$cond$i = $194 & $195;
   if ($or$cond$i) {
    $196 = ((($171)) + 44|0);
    $197 = HEAP32[$196>>2]|0;
    $198 = (($197) + -1)|0;
    HEAP32[$196>>2] = $198;
    $199 = ((($0)) + 60|0);
    $200 = HEAP32[$199>>2]|0;
    $201 = ($200|0)==(0|0);
    $202 = ((($0)) + 64|0);
    $203 = HEAP32[$202>>2]|0;
    $204 = ((($171)) + 72|0);
    $205 = ((($200)) + 64|0);
    $$sink$i$i = $201 ? $204 : $205;
    HEAP32[$$sink$i$i>>2] = $203;
    $206 = HEAP32[$202>>2]|0;
    $207 = ($206|0)==(0|0);
    $208 = HEAP32[$199>>2]|0;
    $209 = ((($171)) + 76|0);
    $210 = ((($206)) + 60|0);
    $$sink1$i$i = $207 ? $209 : $210;
    HEAP32[$$sink1$i$i>>2] = $208;
    HEAP32[$202>>2] = 0;
    HEAP32[$199>>2] = 0;
    HEAP32[$170>>2] = $193;
    $211 = ((($193)) + 44|0);
    $212 = HEAP32[$211>>2]|0;
    $213 = (($212) + 1)|0;
    HEAP32[$211>>2] = $213;
    $214 = ((($193)) + 24|0);
    $215 = HEAP32[$214>>2]|0;
    $216 = ((($215)) + 56|0);
    $217 = HEAP32[$216>>2]|0;
    $218 = ((($0)) + 68|0);
    HEAP32[$218>>2] = $217;
    $219 = ((($193)) + 76|0);
    $220 = HEAP32[$219>>2]|0;
    $221 = ($220|0)==(0|0);
    $222 = $220;
    if (!($221)) {
     $223 = ((($220)) + 64|0);
     HEAP32[$223>>2] = $0;
    }
    HEAP32[$199>>2] = $222;
    $224 = ((($193)) + 72|0);
    $225 = HEAP32[$224>>2]|0;
    $226 = ($225|0)==(0|0);
    if ($226) {
     HEAP32[$224>>2] = $0;
    }
    HEAP32[$219>>2] = $0;
    $228 = $215;
   } else {
    $$pre128 = HEAP32[$170>>2]|0;
    $$phi$trans$insert = ((($$pre128)) + 24|0);
    $$pre129 = HEAP32[$$phi$trans$insert>>2]|0;
    $228 = $$pre129;
   }
   $227 = ((($228)) + 36|0);
   $229 = HEAP32[$227>>2]|0;
   $230 = (($173) + ($229))|0;
   HEAP32[$227>>2] = $230;
   $$pre130 = HEAP32[$140>>2]|0;
   $234 = $$pre130;
  }
 } else {
  $234 = $141;
 }
 $231 = ((($0)) + 32|0);
 $232 = HEAP32[$231>>2]|0;
 $233 = ($232|0)==($234|0);
 if ($233) {
  $$0$off0 = 0;
 } else {
  HEAP32[$231>>2] = $234;
  $235 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
  do {
   if ($235) {
    $236 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
    $237 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($236,120042,50)|0);
    $238 = HEAP32[$231>>2]|0;
    $239 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($237,$238)|0);
    $240 = HEAP32[$239>>2]|0;
    $241 = ((($240)) + -12|0);
    $242 = HEAP32[$241>>2]|0;
    $243 = (($239) + ($242)|0);
    __ZNKSt3__28ios_base6getlocEv($2,$243);
    __THREW__ = 0;
    $244 = (invoke_iii(3255,($2|0),(215188|0))|0);
    $245 = __THREW__; __THREW__ = 0;
    $246 = $245&1;
    if (!($246)) {
     $247 = HEAP32[$244>>2]|0;
     $248 = ((($247)) + 28|0);
     $249 = HEAP32[$248>>2]|0;
     __THREW__ = 0;
     $250 = (invoke_iii($249|0,($244|0),10)|0);
     $251 = __THREW__; __THREW__ = 0;
     $252 = $251&1;
     if (!($252)) {
      __ZNSt3__26localeD2Ev($2);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($239,$250)|0);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($239)|0);
      break;
     }
    }
    $253 = ___cxa_find_matching_catch_2()|0;
    $254 = tempRet0;
    __THREW__ = 0;
    invoke_vi(3263,($2|0));
    $255 = __THREW__; __THREW__ = 0;
    $256 = $255&1;
    if ($256) {
     $257 = ___cxa_find_matching_catch_3(0|0)|0;
     $258 = tempRet0;
     ___clang_call_terminate($257);
     // unreachable;
    } else {
     ___resumeException($253|0);
     // unreachable;
    }
   }
  } while(0);
  $259 = HEAP32[$115>>2]|0;
  $260 = ((($259)) + 728|0);
  $261 = HEAP32[$260>>2]|0;
  $262 = HEAP32[$119>>2]|0;
  $263 = HEAP32[$140>>2]|0;
  $264 = ((($0)) + 24|0);
  $265 = HEAP32[$264>>2]|0;
  FUNCTION_TABLE_viiii[$261 & 8191]($262,$263,0,$265);
  $$0$off0 = 1;
 }
 $266 = HEAP32[$6>>2]|0;
 $267 = HEAP32[$$pre131>>2]|0;
 $268 = ($266|0)==($267|0);
 if ($268) {
  STACKTOP = sp;return;
 }
 $269 = ((($4)) + 16|0);
 $270 = ((($4)) + 20|0);
 if ($$0$off0) {
  $$sroa$0102$0118$us = $266;
  L81: while(1) {
   $271 = ((($$sroa$0102$0118$us)) + 16|0);
   $272 = HEAP32[$271>>2]|0;
   $273 = ($272|0)==(0|0);
   do {
    if (!($273)) {
     HEAP32[$$sroa$0102$0118$us>>2] = 0;
     $274 = ((($272)) + 32|0);
     $275 = HEAP32[$274>>2]|0;
     $276 = ((($$sroa$0102$0118$us)) + 4|0);
     HEAP32[$276>>2] = $275;
     $277 = HEAP32[$272>>2]|0;
     $278 = ((($277)) + 164|0);
     $279 = HEAP32[$278>>2]|0;
     $280 = (FUNCTION_TABLE_ii[$279 & 8191]($272)|0);
     $281 = ($280|0)==(0|0);
     if (!($281)) {
      $282 = ((($280)) + 84|0);
      $283 = HEAP32[$282>>2]|0;
      $284 = ($283|0)==(0);
      if (!($284)) {
       $285 = ((($280)) + 72|0);
       $286 = HEAP32[$285>>2]|0;
       $287 = ($283|0)==($286|0);
       if (!($287)) {
        $288 = ((($$sroa$0102$0118$us)) + 12|0);
        $289 = HEAP32[$288>>2]|0;
        __ZN3osg5Image12DataIteratorC2EPKS0_($4,$280);
        $$086$us = $289;
        while(1) {
         $290 = HEAP32[$269>>2]|0;
         $291 = ($290|0)==(0|0);
         if ($291) {
          break;
         }
         $292 = HEAP32[$115>>2]|0;
         $293 = ((($292)) + 732|0);
         $294 = HEAP32[$293>>2]|0;
         $295 = HEAP32[$119>>2]|0;
         $296 = HEAP32[$270>>2]|0;
         __THREW__ = 0;
         invoke_viiii($294|0,($295|0),($$086$us|0),($296|0),($290|0));
         $297 = __THREW__; __THREW__ = 0;
         $298 = $297&1;
         if ($298) {
          label = 78;
          break L81;
         }
         $299 = HEAP32[$270>>2]|0;
         $300 = (($299) + ($$086$us))|0;
         __THREW__ = 0;
         invoke_vi(3720,($4|0));
         $301 = __THREW__; __THREW__ = 0;
         $302 = $301&1;
         if ($302) {
          label = 78;
          break L81;
         } else {
          $$086$us = $300;
         }
        }
        break;
       }
      }
     }
     $303 = HEAP32[$115>>2]|0;
     $304 = ((($303)) + 732|0);
     $305 = HEAP32[$304>>2]|0;
     $306 = HEAP32[$119>>2]|0;
     $307 = ((($$sroa$0102$0118$us)) + 12|0);
     $308 = HEAP32[$307>>2]|0;
     $309 = ((($$sroa$0102$0118$us)) + 8|0);
     $310 = HEAP32[$309>>2]|0;
     $311 = HEAP32[$271>>2]|0;
     $312 = HEAP32[$311>>2]|0;
     $313 = ((($312)) + 140|0);
     $314 = HEAP32[$313>>2]|0;
     $315 = (FUNCTION_TABLE_ii[$314 & 8191]($311)|0);
     FUNCTION_TABLE_viiii[$305 & 8191]($306,$308,$310,$315);
    }
   } while(0);
   $316 = ((($$sroa$0102$0118$us)) + 20|0);
   $317 = HEAP32[$$pre131>>2]|0;
   $318 = ($316|0)==($317|0);
   if ($318) {
    label = 69;
    break;
   } else {
    $$sroa$0102$0118$us = $316;
   }
  }
  if ((label|0) == 69) {
   STACKTOP = sp;return;
  }
  else if ((label|0) == 78) {
   $342 = ___cxa_find_matching_catch_2()|0;
   $343 = tempRet0;
   ___resumeException($342|0);
   // unreachable;
  }
 } else {
  $$sroa$0102$0118 = $266;
 }
 L100: while(1) {
  $319 = ((($$sroa$0102$0118)) + 16|0);
  $320 = HEAP32[$319>>2]|0;
  $321 = ($320|0)==(0|0);
  do {
   if (!($321)) {
    $322 = ((($$sroa$0102$0118)) + 4|0);
    $323 = HEAP32[$322>>2]|0;
    $324 = ((($320)) + 32|0);
    $325 = HEAP32[$324>>2]|0;
    $326 = ($323|0)==($325|0);
    if (!($326)) {
     HEAP32[$$sroa$0102$0118>>2] = 0;
     HEAP32[$322>>2] = $325;
     $327 = HEAP32[$320>>2]|0;
     $328 = ((($327)) + 164|0);
     $329 = HEAP32[$328>>2]|0;
     $330 = (FUNCTION_TABLE_ii[$329 & 8191]($320)|0);
     $331 = ($330|0)==(0|0);
     if (!($331)) {
      $332 = ((($330)) + 84|0);
      $333 = HEAP32[$332>>2]|0;
      $334 = ($333|0)==(0);
      if (!($334)) {
       $335 = ((($330)) + 72|0);
       $336 = HEAP32[$335>>2]|0;
       $337 = ($333|0)==($336|0);
       if (!($337)) {
        $338 = ((($$sroa$0102$0118)) + 12|0);
        $339 = HEAP32[$338>>2]|0;
        __ZN3osg5Image12DataIteratorC2EPKS0_($4,$330);
        $$086 = $339;
        while(1) {
         $340 = HEAP32[$269>>2]|0;
         $341 = ($340|0)==(0|0);
         if ($341) {
          break;
         }
         $344 = HEAP32[$115>>2]|0;
         $345 = ((($344)) + 732|0);
         $346 = HEAP32[$345>>2]|0;
         $347 = HEAP32[$119>>2]|0;
         $348 = HEAP32[$270>>2]|0;
         __THREW__ = 0;
         invoke_viiii($346|0,($347|0),($$086|0),($348|0),($340|0));
         $349 = __THREW__; __THREW__ = 0;
         $350 = $349&1;
         if ($350) {
          label = 78;
          break L100;
         }
         $351 = HEAP32[$270>>2]|0;
         $352 = (($351) + ($$086))|0;
         __THREW__ = 0;
         invoke_vi(3720,($4|0));
         $353 = __THREW__; __THREW__ = 0;
         $354 = $353&1;
         if ($354) {
          label = 78;
          break L100;
         } else {
          $$086 = $352;
         }
        }
        break;
       }
      }
     }
     $355 = HEAP32[$115>>2]|0;
     $356 = ((($355)) + 732|0);
     $357 = HEAP32[$356>>2]|0;
     $358 = HEAP32[$119>>2]|0;
     $359 = ((($$sroa$0102$0118)) + 12|0);
     $360 = HEAP32[$359>>2]|0;
     $361 = ((($$sroa$0102$0118)) + 8|0);
     $362 = HEAP32[$361>>2]|0;
     $363 = HEAP32[$319>>2]|0;
     $364 = HEAP32[$363>>2]|0;
     $365 = ((($364)) + 140|0);
     $366 = HEAP32[$365>>2]|0;
     $367 = (FUNCTION_TABLE_ii[$366 & 8191]($363)|0);
     FUNCTION_TABLE_viiii[$357 & 8191]($358,$360,$362,$367);
    }
   }
  } while(0);
  $368 = ((($$sroa$0102$0118)) + 20|0);
  $369 = HEAP32[$$pre131>>2]|0;
  $370 = ($368|0)==($369|0);
  if ($370) {
   label = 69;
   break;
  } else {
   $$sroa$0102$0118 = $368;
  }
 }
 if ((label|0) == 69) {
  STACKTOP = sp;return;
 }
 else if ((label|0) == 78) {
  $342 = ___cxa_find_matching_catch_2()|0;
  $343 = tempRet0;
  ___resumeException($342|0);
  // unreachable;
 }
}
function __ZNSt3__26vectorIN3osg14GLBufferObject11BufferEntryENS_9allocatorIS3_EEE7reserveEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$06$i$i = 0, $$pre$i = 0, $$sroa$7$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = (($5|0) / 20)&-1;
 $7 = ($6>>>0)<($1>>>0);
 $8 = $4;
 if (!($7)) {
  return;
 }
 $9 = ((($0)) + 4|0);
 $10 = ($1>>>0)>(214748364);
 if ($10) {
  $11 = (___cxa_allocate_exception(8)|0);
  __THREW__ = 0;
  invoke_vii(3366,($11|0),(204840|0));
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if ($13) {
   $14 = ___cxa_find_matching_catch_2()|0;
   $15 = tempRet0;
   ___cxa_free_exception(($11|0));
   ___resumeException($14|0);
   // unreachable;
  } else {
   HEAP32[$11>>2] = (99824);
   ___cxa_throw(($11|0),(34608|0),(3230|0));
   // unreachable;
  }
 }
 $16 = HEAP32[$9>>2]|0;
 $17 = (($16) - ($4))|0;
 $18 = (($17|0) / 20)&-1;
 $19 = ($1*20)|0;
 $20 = (__Znwj($19)|0);
 $21 = (($20) + (($18*20)|0)|0);
 $22 = $21;
 $23 = (($20) + (($1*20)|0)|0);
 $24 = $23;
 $25 = $16;
 $26 = ($25|0)==($8|0);
 if ($26) {
  $47 = $22;$48 = $16;
 } else {
  $$06$i$i = $25;$$sroa$7$0 = $22;$29 = $21;
  while(1) {
   $27 = ((($$06$i$i)) + -20|0);
   $28 = ((($29)) + -20|0);
   $30 = HEAP32[$27>>2]|0;
   HEAP32[$28>>2] = $30;
   $31 = ((($29)) + -16|0);
   $32 = ((($$06$i$i)) + -16|0);
   $33 = HEAP32[$32>>2]|0;
   HEAP32[$31>>2] = $33;
   $34 = ((($29)) + -12|0);
   $35 = ((($$06$i$i)) + -12|0);
   $36 = HEAP32[$35>>2]|0;
   HEAP32[$34>>2] = $36;
   $37 = ((($29)) + -8|0);
   $38 = ((($$06$i$i)) + -8|0);
   $39 = HEAP32[$38>>2]|0;
   HEAP32[$37>>2] = $39;
   $40 = ((($29)) + -4|0);
   $41 = ((($$06$i$i)) + -4|0);
   $42 = HEAP32[$41>>2]|0;
   HEAP32[$40>>2] = $42;
   $43 = $$sroa$7$0;
   $44 = ((($43)) + -20|0);
   $45 = $44;
   $46 = ($27|0)==($8|0);
   if ($46) {
    break;
   } else {
    $$06$i$i = $27;$$sroa$7$0 = $45;$29 = $44;
   }
  }
  $$pre$i = HEAP32[$0>>2]|0;
  $47 = $45;$48 = $$pre$i;
 }
 HEAP32[$0>>2] = $47;
 HEAP32[$9>>2] = $22;
 HEAP32[$2>>2] = $24;
 $49 = ($48|0)==(0);
 if ($49) {
  return;
 }
 $50 = $48;
 __ZdlPv($50);
 return;
}
function __ZNSt3__26vectorIN3osg14GLBufferObject11BufferEntryENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$06$i$i = 0, $$pre$i = 0, $$sroa$7$0 = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = (($5|0) / 20)&-1;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(214748364);
 $9 = $4;
 $10 = $3;
 if ($8) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $11 = ((($0)) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) - ($4))|0;
 $14 = (($13|0) / 20)&-1;
 $15 = ($14>>>0)<(107374182);
 $16 = $14 << 1;
 $17 = ($16>>>0)<($7>>>0);
 $$sroa$speculated$i = $17 ? $7 : $16;
 $$sroa$speculated$$i = $15 ? $$sroa$speculated$i : 214748364;
 $18 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($18) {
   $28 = 0;
  } else {
   $19 = ($$sroa$speculated$$i>>>0)>(214748364);
   if (!($19)) {
    $25 = ($$sroa$speculated$$i*20)|0;
    $26 = (__Znwj($25)|0);
    $28 = $26;
    break;
   }
   $20 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($20|0),(204840|0));
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if ($22) {
    $23 = ___cxa_find_matching_catch_2()|0;
    $24 = tempRet0;
    ___cxa_free_exception(($20|0));
    ___resumeException($23|0);
    // unreachable;
   } else {
    HEAP32[$20>>2] = (99824);
    ___cxa_throw(($20|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $27 = (($28) + (($6*20)|0)|0);
 $29 = $27;
 $30 = (($28) + (($$sroa$speculated$$i*20)|0)|0);
 $31 = $30;
 $32 = HEAP32[$1>>2]|0;
 HEAP32[$27>>2] = $32;
 $33 = (((($28) + (($6*20)|0)|0)) + 4|0);
 $34 = ((($1)) + 4|0);
 $35 = HEAP32[$34>>2]|0;
 HEAP32[$33>>2] = $35;
 $36 = (((($28) + (($6*20)|0)|0)) + 8|0);
 $37 = ((($1)) + 8|0);
 $38 = HEAP32[$37>>2]|0;
 HEAP32[$36>>2] = $38;
 $39 = (((($28) + (($6*20)|0)|0)) + 12|0);
 $40 = ((($1)) + 12|0);
 $41 = HEAP32[$40>>2]|0;
 HEAP32[$39>>2] = $41;
 $42 = (((($28) + (($6*20)|0)|0)) + 16|0);
 $43 = ((($1)) + 16|0);
 $44 = HEAP32[$43>>2]|0;
 HEAP32[$42>>2] = $44;
 $45 = ((($27)) + 20|0);
 $46 = $45;
 $47 = ($10|0)==($9|0);
 if ($47) {
  $68 = $29;$69 = $3;
 } else {
  $$06$i$i = $10;$$sroa$7$0 = $29;$50 = $27;
  while(1) {
   $48 = ((($$06$i$i)) + -20|0);
   $49 = ((($50)) + -20|0);
   $51 = HEAP32[$48>>2]|0;
   HEAP32[$49>>2] = $51;
   $52 = ((($50)) + -16|0);
   $53 = ((($$06$i$i)) + -16|0);
   $54 = HEAP32[$53>>2]|0;
   HEAP32[$52>>2] = $54;
   $55 = ((($50)) + -12|0);
   $56 = ((($$06$i$i)) + -12|0);
   $57 = HEAP32[$56>>2]|0;
   HEAP32[$55>>2] = $57;
   $58 = ((($50)) + -8|0);
   $59 = ((($$06$i$i)) + -8|0);
   $60 = HEAP32[$59>>2]|0;
   HEAP32[$58>>2] = $60;
   $61 = ((($50)) + -4|0);
   $62 = ((($$06$i$i)) + -4|0);
   $63 = HEAP32[$62>>2]|0;
   HEAP32[$61>>2] = $63;
   $64 = $$sroa$7$0;
   $65 = ((($64)) + -20|0);
   $66 = $65;
   $67 = ($48|0)==($9|0);
   if ($67) {
    break;
   } else {
    $$06$i$i = $48;$$sroa$7$0 = $66;$50 = $65;
   }
  }
  $$pre$i = HEAP32[$0>>2]|0;
  $68 = $66;$69 = $$pre$i;
 }
 HEAP32[$0>>2] = $68;
 HEAP32[$2>>2] = $46;
 HEAP32[$11>>2] = $31;
 $70 = ($69|0)==(0);
 if ($70) {
  return;
 }
 $71 = $69;
 __ZdlPv($71);
 return;
}
function __ZNK3osg14GLBufferObject24hasAllBufferDataBeenReadEv($0) {
 $0 = $0|0;
 var $$sroa$04$09 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 40|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 44|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2|0)==($4|0);
 if ($5) {
  $14 = 1;
  return ($14|0);
 } else {
  $$sroa$04$09 = $2;
 }
 while(1) {
  $8 = HEAP32[$$sroa$04$09>>2]|0;
  $9 = ((($$sroa$04$09)) + 16|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ((($10)) + 48|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($8>>>0)<($12>>>0);
  $6 = ((($$sroa$04$09)) + 20|0);
  if ($13) {
   $14 = 0;
   label = 4;
   break;
  }
  $7 = ($6|0)==($4|0);
  if ($7) {
   $14 = 1;
   label = 4;
   break;
  } else {
   $$sroa$04$09 = $6;
  }
 }
 if ((label|0) == 4) {
  return ($14|0);
 }
 return (0)|0;
}
function __ZN3osg14GLBufferObject24setBufferDataHasBeenReadEPKNS_10BufferDataE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 36|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 40|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + (($3*20)|0)|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 1)|0;
 HEAP32[$6>>2] = $8;
 return;
}
function __ZN3osg21GLBufferObjectManager28setMaxGLBufferObjectPoolSizeEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = ((($0)) + 40|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==($1|0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $6 = ((($0)) + 36|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7>>>0)>($1>>>0);
 do {
  if ($8) {
   $9 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
   if ($9) {
    $10 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
    $11 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($10,120093,39)|0);
    $12 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($11,$1)|0);
    $13 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($12,120133,48)|0);
    $14 = HEAP32[$6>>2]|0;
    $15 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($13,$14)|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = ((($16)) + -12|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = (($15) + ($18)|0);
    __ZNKSt3__28ios_base6getlocEv($2,$19);
    __THREW__ = 0;
    $20 = (invoke_iii(3255,($2|0),(215188|0))|0);
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if (!($22)) {
     $23 = HEAP32[$20>>2]|0;
     $24 = ((($23)) + 28|0);
     $25 = HEAP32[$24>>2]|0;
     __THREW__ = 0;
     $26 = (invoke_iii($25|0,($20|0),10)|0);
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     if (!($28)) {
      __ZNSt3__26localeD2Ev($2);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($15,$26)|0);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($15)|0);
      break;
     }
    }
    $29 = ___cxa_find_matching_catch_2()|0;
    $30 = tempRet0;
    __THREW__ = 0;
    invoke_vi(3263,($2|0));
    $31 = __THREW__; __THREW__ = 0;
    $32 = $31&1;
    if ($32) {
     $33 = ___cxa_find_matching_catch_3(0|0)|0;
     $34 = tempRet0;
     ___clang_call_terminate($33);
     // unreachable;
    } else {
     ___resumeException($29|0);
     // unreachable;
    }
   }
  }
 } while(0);
 HEAP32[$3>>2] = $1;
 STACKTOP = sp;return;
}
function __ZN3osg18VertexBufferObjectC2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg12BufferObjectC2Ev($0);
 HEAP32[$0>>2] = (55296);
 $1 = ((($0)) + 32|0);
 HEAP32[$1>>2] = 34962;
 $2 = ((($0)) + 36|0);
 HEAP32[$2>>2] = 35044;
 return;
}
function __ZN3osg19ElementBufferObjectC2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg12BufferObjectC2Ev($0);
 HEAP32[$0>>2] = (55444);
 $1 = ((($0)) + 32|0);
 HEAP32[$1>>2] = 34963;
 $2 = ((($0)) + 36|0);
 HEAP32[$2>>2] = 35044;
 return;
}
function __ZN3osg12NodeCallback3runEPNS_6ObjectES2_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($1|0)==(0|0);
 if ($3) {
  $13 = 0;
 } else {
  $4 = HEAP32[$1>>2]|0;
  $5 = ((($4)) + 32|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (FUNCTION_TABLE_ii[$6 & 8191]($1)|0);
  $13 = $7;
 }
 $8 = ($2|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$2>>2]|0;
  $10 = ((($9)) + 40|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (FUNCTION_TABLE_ii[$11 & 8191]($2)|0);
  $14 = ($13|0)!=(0|0);
  $15 = ($12|0)!=(0|0);
  $or$cond = $14 & $15;
  if ($or$cond) {
   $16 = HEAP32[$0>>2]|0;
   $17 = ((($16)) + 32|0);
   $18 = HEAP32[$17>>2]|0;
   FUNCTION_TABLE_viii[$18 & 8191]($0,$13,$12);
   $$0 = 1;
   return ($$0|0);
  }
 }
 $19 = HEAP32[$0>>2]|0;
 $20 = ((($19)) + -12|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($0) + ($21)|0);
 $23 = ((($22)) + 4|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)==(0|0);
 if (!($25)) {
  $26 = HEAP32[$24>>2]|0;
  $27 = ((($26)) + 92|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (FUNCTION_TABLE_iiii[$28 & 8191]($24,$1,$2)|0);
  $$0 = $29;
  return ($$0|0);
 }
 if ($3) {
  $38 = 0;
 } else {
  $30 = HEAP32[$1>>2]|0;
  $31 = ((($30)) + 32|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = (FUNCTION_TABLE_ii[$32 & 8191]($1)|0);
  $38 = $33;
 }
 if ($8) {
  $$0 = 0;
  return ($$0|0);
 }
 $34 = HEAP32[$2>>2]|0;
 $35 = ((($34)) + 40|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = (FUNCTION_TABLE_ii[$36 & 8191]($2)|0);
 $39 = ($38|0)!=(0|0);
 $40 = ($37|0)!=(0|0);
 $or$cond$i = $39 & $40;
 if (!($or$cond$i)) {
  $$0 = 0;
  return ($$0|0);
 }
 $41 = ((($37)) + 16|0);
 $42 = HEAP32[$41>>2]|0;
 switch ($42|0) {
 case 1:  {
  $43 = HEAP32[$38>>2]|0;
  $44 = ((($43)) + 192|0);
  $45 = HEAP32[$44>>2]|0;
  FUNCTION_TABLE_vii[$45 & 8191]($38,$37);
  $$0 = 1;
  return ($$0|0);
  break;
 }
 case 0:  {
  $$0 = 1;
  return ($$0|0);
  break;
 }
 default: {
  $46 = HEAP32[$38>>2]|0;
  $47 = ((($46)) + 196|0);
  $48 = HEAP32[$47>>2]|0;
  FUNCTION_TABLE_vii[$48 & 8191]($38,$37);
  $$0 = 1;
  return ($$0|0);
 }
 }
 return (0)|0;
}
function __ZN3osg12NodeCallbackclEPNS_4NodeEPNS_11NodeVisitorE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = HEAP32[$0>>2]|0;
 $4 = ((($3)) + -12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($0) + ($5)|0);
 $7 = ($2|0)==(0|0);
 if ($7) {
  $18 = 0;
 } else {
  $8 = HEAP32[$2>>2]|0;
  $9 = ((($8)) + -12|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($2) + ($10)|0);
  $18 = $11;
 }
 $12 = ((($6)) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0|0);
 if (!($14)) {
  $15 = HEAP32[$13>>2]|0;
  $16 = ((($15)) + 92|0);
  $17 = HEAP32[$16>>2]|0;
  (FUNCTION_TABLE_iiii[$17 & 8191]($13,$1,$18)|0);
  return;
 }
 $19 = ($1|0)==(0|0);
 if ($19) {
  $29 = 0;
 } else {
  $20 = HEAP32[$1>>2]|0;
  $21 = ((($20)) + 32|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = (FUNCTION_TABLE_ii[$22 & 8191]($1)|0);
  $29 = $23;
 }
 $24 = ($18|0)==(0|0);
 if ($24) {
  return;
 }
 $25 = HEAP32[$18>>2]|0;
 $26 = ((($25)) + 40|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (FUNCTION_TABLE_ii[$27 & 8191]($18)|0);
 $30 = ($29|0)!=(0|0);
 $31 = ($28|0)!=(0|0);
 $or$cond$i = $30 & $31;
 if (!($or$cond$i)) {
  return;
 }
 $32 = ((($28)) + 16|0);
 $33 = HEAP32[$32>>2]|0;
 switch ($33|0) {
 case 1:  {
  $34 = HEAP32[$29>>2]|0;
  $35 = ((($34)) + 192|0);
  $36 = HEAP32[$35>>2]|0;
  FUNCTION_TABLE_vii[$36 & 8191]($29,$28);
  return;
  break;
 }
 case 0:  {
  return;
  break;
 }
 default: {
  $37 = HEAP32[$29>>2]|0;
  $38 = ((($37)) + 196|0);
  $39 = HEAP32[$38>>2]|0;
  FUNCTION_TABLE_vii[$39 & 8191]($29,$28);
  return;
 }
 }
}
function __ZTv0_n108_N3osg12NodeCallback3runEPNS_6ObjectES2_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = HEAP32[$0>>2]|0;
 $4 = ((($3)) + -108|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($0) + ($5)|0);
 $7 = (__ZN3osg12NodeCallback3runEPNS_6ObjectES2_($6,$1,$2)|0);
 return ($7|0);
}
function __ZNK3osg22StateAttributeCallback9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(44)|0);
 $2 = ((($1)) + 12|0);
 __THREW__ = 0;
 invoke_vi(3282,($2|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $10 = ___cxa_find_matching_catch_2()|0;
  $11 = tempRet0;
  __ZdlPv($1);
  ___resumeException($10|0);
  // unreachable;
 } else {
  $5 = ((($1)) + 24|0);
  ;HEAP32[$5>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;
  $6 = ((($1)) + 36|0);
  HEAP32[$6>>2] = 2;
  $7 = ((($1)) + 40|0);
  HEAP32[$7>>2] = 0;
  $8 = ((($1)) + 8|0);
  HEAP32[$8>>2] = 0;
  HEAP32[$1>>2] = (2768);
  $9 = ((($1)) + 4|0);
  HEAP32[$9>>2] = (2924);
  HEAP32[$2>>2] = (3172);
  return ($2|0);
 }
 return (0)|0;
}
function __ZNK3osg22StateAttributeCallback5cloneERKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(44)|0);
 $3 = ((($2)) + 12|0);
 $4 = HEAP32[$0>>2]|0;
 $5 = ((($4)) + -16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($0) + ($6)|0);
 __THREW__ = 0;
 invoke_viii(3468,($3|0),($7|0),($1|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $25 = ___cxa_find_matching_catch_2()|0;
  $26 = tempRet0;
  __ZdlPv($2);
  ___resumeException($25|0);
  // unreachable;
 }
 $10 = ((($2)) + 4|0);
 $11 = HEAP32[$0>>2]|0;
 $12 = ((($11)) + -12|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($0) + ($13)|0);
 HEAP32[$10>>2] = ((29984));
 HEAP32[$3>>2] = ((30232));
 $15 = ((($2)) + 8|0);
 $16 = ((($14)) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 HEAP32[$15>>2] = $17;
 $18 = ($17|0)==(0|0);
 if ($18) {
  HEAP32[$2>>2] = (2768);
  HEAP32[$10>>2] = (2924);
  HEAP32[$3>>2] = (3172);
  return ($3|0);
 }
 $19 = HEAP32[$17>>2]|0;
 $20 = ((($19)) + -12|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($17) + ($21)|0);
 $23 = ((($22)) + 8|0);
 $24 = HEAP32[$23>>2]|0;HEAP32[$23>>2] = (($24+1)|0);
 HEAP32[$2>>2] = (2768);
 HEAP32[$10>>2] = (2924);
 HEAP32[$3>>2] = (3172);
 return ($3|0);
}
function __ZNK3osg22StateAttributeCallback12isSameKindAsEPKNS_6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,23184,-1)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK3osg22StateAttributeCallback11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175113|0);
}
function __ZNK3osg22StateAttributeCallback9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (120203|0);
}
function __ZN3osg22StateAttributeCallback24asStateAttributeCallbackEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ($0|0);
}
function __ZNK3osg22StateAttributeCallback24asStateAttributeCallbackEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ($0|0);
}
function __ZN3osg22StateAttributeCallback3runEPNS_6ObjectES2_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($1|0)==(0|0);
 if ($3) {
  $13 = 0;
 } else {
  $4 = HEAP32[$1>>2]|0;
  $5 = ((($4)) + 56|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (FUNCTION_TABLE_ii[$6 & 8191]($1)|0);
  $13 = $7;
 }
 $8 = ($2|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$2>>2]|0;
  $10 = ((($9)) + 40|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (FUNCTION_TABLE_ii[$11 & 8191]($2)|0);
  $14 = ($13|0)!=(0|0);
  $15 = ($12|0)!=(0|0);
  $or$cond = $14 & $15;
  if ($or$cond) {
   $16 = HEAP32[$0>>2]|0;
   $17 = ((($16)) + 32|0);
   $18 = HEAP32[$17>>2]|0;
   FUNCTION_TABLE_viii[$18 & 8191]($0,$13,$12);
   $$0 = 1;
   return ($$0|0);
  }
 }
 $19 = HEAP32[$0>>2]|0;
 $20 = ((($19)) + -12|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($0) + ($21)|0);
 $23 = ((($22)) + 4|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)==(0|0);
 if (!($25)) {
  $26 = HEAP32[$24>>2]|0;
  $27 = ((($26)) + 92|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (FUNCTION_TABLE_iiii[$28 & 8191]($24,$1,$2)|0);
  $$0 = $29;
  return ($$0|0);
 }
 if ($3) {
  $38 = 0;
 } else {
  $30 = HEAP32[$1>>2]|0;
  $31 = ((($30)) + 32|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = (FUNCTION_TABLE_ii[$32 & 8191]($1)|0);
  $38 = $33;
 }
 if ($8) {
  $$0 = 0;
  return ($$0|0);
 }
 $34 = HEAP32[$2>>2]|0;
 $35 = ((($34)) + 40|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = (FUNCTION_TABLE_ii[$36 & 8191]($2)|0);
 $39 = ($38|0)!=(0|0);
 $40 = ($37|0)!=(0|0);
 $or$cond$i = $39 & $40;
 if (!($or$cond$i)) {
  $$0 = 0;
  return ($$0|0);
 }
 $41 = ((($37)) + 16|0);
 $42 = HEAP32[$41>>2]|0;
 switch ($42|0) {
 case 1:  {
  $43 = HEAP32[$38>>2]|0;
  $44 = ((($43)) + 192|0);
  $45 = HEAP32[$44>>2]|0;
  FUNCTION_TABLE_vii[$45 & 8191]($38,$37);
  $$0 = 1;
  return ($$0|0);
  break;
 }
 case 0:  {
  $$0 = 1;
  return ($$0|0);
  break;
 }
 default: {
  $46 = HEAP32[$38>>2]|0;
  $47 = ((($46)) + 196|0);
  $48 = HEAP32[$47>>2]|0;
  FUNCTION_TABLE_vii[$48 & 8191]($38,$37);
  $$0 = 1;
  return ($$0|0);
 }
 }
 return (0)|0;
}
function __ZN3osg22StateAttributeCallbackclEPNS_14StateAttributeEPNS_11NodeVisitorE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN3osg22StateAttributeCallbackD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 4|0);
 HEAP32[$1>>2] = ((29984));
 $2 = ((($1)) + 8|0);
 HEAP32[$2>>2] = ((30232));
 $3 = ((($0)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  HEAP32[$3>>2] = 0;
  $15 = ((($0)) + 12|0);
  __ZN3osg6ObjectD2Ev($15);
  return;
 }
 $6 = HEAP32[$4>>2]|0;
 $7 = ((($6)) + -12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($4) + ($8)|0);
 $10 = ((($9)) + 8|0);
 $11 = HEAP32[$10>>2]|0;HEAP32[$10>>2] = (($11-1)|0);
 $12 = ($11|0)==(1);
 if (!($12)) {
  HEAP32[$3>>2] = 0;
  $15 = ((($0)) + 12|0);
  __ZN3osg6ObjectD2Ev($15);
  return;
 }
 __THREW__ = 0;
 invoke_viii(3262,($9|0),1,1);
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 if (!($14)) {
  HEAP32[$3>>2] = 0;
  $15 = ((($0)) + 12|0);
  __ZN3osg6ObjectD2Ev($15);
  return;
 }
 $16 = ___cxa_find_matching_catch_2()|0;
 $17 = tempRet0;
 $18 = ((($0)) + 12|0);
 __THREW__ = 0;
 invoke_vi(388,($18|0));
 $19 = __THREW__; __THREW__ = 0;
 $20 = $19&1;
 if ($20) {
  $21 = ___cxa_find_matching_catch_3(0|0)|0;
  $22 = tempRet0;
  ___clang_call_terminate($21);
  // unreachable;
 } else {
  ___resumeException($16|0);
  // unreachable;
 }
}
function __ZN3osg22StateAttributeCallbackD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 4|0);
 HEAP32[$1>>2] = ((29984));
 $2 = ((($1)) + 8|0);
 HEAP32[$2>>2] = ((30232));
 $3 = ((($0)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if (!($5)) {
  $6 = HEAP32[$4>>2]|0;
  $7 = ((($6)) + -12|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($4) + ($8)|0);
  $10 = ((($9)) + 8|0);
  $11 = HEAP32[$10>>2]|0;HEAP32[$10>>2] = (($11-1)|0);
  $12 = ($11|0)==(1);
  if ($12) {
   __THREW__ = 0;
   invoke_viii(3262,($9|0),1,1);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if ($14) {
    $18 = ___cxa_find_matching_catch_2()|0;
    $19 = tempRet0;
    $20 = ((($0)) + 12|0);
    __THREW__ = 0;
    invoke_vi(388,($20|0));
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if ($22) {
     $23 = ___cxa_find_matching_catch_3(0|0)|0;
     $24 = tempRet0;
     ___clang_call_terminate($23);
     // unreachable;
    } else {
     $eh$lpad$body$index2Z2D = $19;$eh$lpad$body$indexZ2D = $18;
     __ZdlPv($0);
     ___resumeException($eh$lpad$body$indexZ2D|0);
     // unreachable;
    }
   }
  }
 }
 HEAP32[$3>>2] = 0;
 $15 = ((($0)) + 12|0);
 __THREW__ = 0;
 invoke_vi(388,($15|0));
 $16 = __THREW__; __THREW__ = 0;
 $17 = $16&1;
 if (!($17)) {
  __ZdlPv($0);
  return;
 }
 $25 = ___cxa_find_matching_catch_2()|0;
 $26 = tempRet0;
 $eh$lpad$body$index2Z2D = $26;$eh$lpad$body$indexZ2D = $25;
 __ZdlPv($0);
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
}
function __ZTv0_n16_NK3osg22StateAttributeCallback9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(44)|0);
 $2 = ((($1)) + 12|0);
 __THREW__ = 0;
 invoke_vi(3282,($2|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch_2()|0;
  $6 = tempRet0;
  __ZdlPv($1);
  ___resumeException($5|0);
  // unreachable;
 } else {
  $7 = ((($1)) + 24|0);
  ;HEAP32[$7>>2]=0|0;HEAP32[$7+4>>2]=0|0;HEAP32[$7+8>>2]=0|0;
  $8 = ((($1)) + 36|0);
  HEAP32[$8>>2] = 2;
  $9 = ((($1)) + 40|0);
  HEAP32[$9>>2] = 0;
  $10 = ((($1)) + 8|0);
  HEAP32[$10>>2] = 0;
  HEAP32[$1>>2] = (2768);
  $11 = ((($1)) + 4|0);
  HEAP32[$11>>2] = (2924);
  HEAP32[$2>>2] = (3172);
  return ($2|0);
 }
 return (0)|0;
}
function __ZTv0_n20_NK3osg22StateAttributeCallback5cloneERKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $3 = ((($2)) + -20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($0) + ($4)|0);
 $6 = (__Znwj(44)|0);
 $7 = ((($6)) + 12|0);
 $8 = HEAP32[$5>>2]|0;
 $9 = ((($8)) + -16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($5) + ($10)|0);
 __THREW__ = 0;
 invoke_viii(3468,($7|0),($11|0),($1|0));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $29 = ___cxa_find_matching_catch_2()|0;
  $30 = tempRet0;
  __ZdlPv($6);
  ___resumeException($29|0);
  // unreachable;
 }
 $14 = ((($6)) + 4|0);
 $15 = HEAP32[$5>>2]|0;
 $16 = ((($15)) + -12|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($5) + ($17)|0);
 HEAP32[$14>>2] = ((29984));
 HEAP32[$7>>2] = ((30232));
 $19 = ((($6)) + 8|0);
 $20 = ((($18)) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 HEAP32[$19>>2] = $21;
 $22 = ($21|0)==(0|0);
 if ($22) {
  HEAP32[$6>>2] = (2768);
  HEAP32[$14>>2] = (2924);
  HEAP32[$7>>2] = (3172);
  return ($7|0);
 }
 $23 = HEAP32[$21>>2]|0;
 $24 = ((($23)) + -12|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($21) + ($25)|0);
 $27 = ((($26)) + 8|0);
 $28 = HEAP32[$27>>2]|0;HEAP32[$27>>2] = (($28+1)|0);
 HEAP32[$6>>2] = (2768);
 HEAP32[$14>>2] = (2924);
 HEAP32[$7>>2] = (3172);
 return ($7|0);
}
function __ZTv0_n24_NK3osg22StateAttributeCallback12isSameKindAsEPKNS_6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,23184,-1)|0);
 $phitmp$i = ($3|0)!=(0|0);
 $4 = $phitmp$i;
 return ($4|0);
}
function __ZTv0_n28_NK3osg22StateAttributeCallback11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175113|0);
}
function __ZTv0_n32_NK3osg22StateAttributeCallback9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (120203|0);
}
function __ZTv0_n60_N3osg22StateAttributeCallback24asStateAttributeCallbackEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -60|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 return ($4|0);
}
function __ZTv0_n64_NK3osg22StateAttributeCallback24asStateAttributeCallbackEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -64|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 return ($4|0);
}
function __ZTv0_n108_N3osg22StateAttributeCallback3runEPNS_6ObjectES2_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = HEAP32[$0>>2]|0;
 $4 = ((($3)) + -108|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($0) + ($5)|0);
 $7 = (__ZN3osg22StateAttributeCallback3runEPNS_6ObjectES2_($6,$1,$2)|0);
 return ($7|0);
}
function __ZTv0_n112_N3osg22StateAttributeCallbackD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -112|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 $5 = ((($4)) + 4|0);
 HEAP32[$5>>2] = ((29984));
 $6 = ((($5)) + 8|0);
 HEAP32[$6>>2] = ((30232));
 $7 = ((($4)) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if ($9) {
  HEAP32[$7>>2] = 0;
  $26 = ((($4)) + 12|0);
  __ZN3osg6ObjectD2Ev($26);
  return;
 }
 $10 = HEAP32[$8>>2]|0;
 $11 = ((($10)) + -12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($8) + ($12)|0);
 $14 = ((($13)) + 8|0);
 $15 = HEAP32[$14>>2]|0;HEAP32[$14>>2] = (($15-1)|0);
 $16 = ($15|0)==(1);
 if (!($16)) {
  HEAP32[$7>>2] = 0;
  $26 = ((($4)) + 12|0);
  __ZN3osg6ObjectD2Ev($26);
  return;
 }
 __THREW__ = 0;
 invoke_viii(3262,($13|0),1,1);
 $17 = __THREW__; __THREW__ = 0;
 $18 = $17&1;
 if (!($18)) {
  HEAP32[$7>>2] = 0;
  $26 = ((($4)) + 12|0);
  __ZN3osg6ObjectD2Ev($26);
  return;
 }
 $19 = ___cxa_find_matching_catch_2()|0;
 $20 = tempRet0;
 $21 = ((($4)) + 12|0);
 __THREW__ = 0;
 invoke_vi(388,($21|0));
 $22 = __THREW__; __THREW__ = 0;
 $23 = $22&1;
 if ($23) {
  $24 = ___cxa_find_matching_catch_3(0|0)|0;
  $25 = tempRet0;
  ___clang_call_terminate($24);
  // unreachable;
 } else {
  ___resumeException($19|0);
  // unreachable;
 }
}
function __ZTv0_n112_N3osg22StateAttributeCallbackD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$i$index2Z2D = 0, $eh$lpad$body$i$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -112|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 $5 = ((($4)) + 4|0);
 HEAP32[$5>>2] = ((29984));
 $6 = ((($5)) + 8|0);
 HEAP32[$6>>2] = ((30232));
 $7 = ((($4)) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if (!($9)) {
  $10 = HEAP32[$8>>2]|0;
  $11 = ((($10)) + -12|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($8) + ($12)|0);
  $14 = ((($13)) + 8|0);
  $15 = HEAP32[$14>>2]|0;HEAP32[$14>>2] = (($15-1)|0);
  $16 = ($15|0)==(1);
  if ($16) {
   __THREW__ = 0;
   invoke_viii(3262,($13|0),1,1);
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if ($18) {
    $22 = ___cxa_find_matching_catch_2()|0;
    $23 = tempRet0;
    $24 = ((($4)) + 12|0);
    __THREW__ = 0;
    invoke_vi(388,($24|0));
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if ($26) {
     $27 = ___cxa_find_matching_catch_3(0|0)|0;
     $28 = tempRet0;
     ___clang_call_terminate($27);
     // unreachable;
    } else {
     $eh$lpad$body$i$index2Z2D = $23;$eh$lpad$body$i$indexZ2D = $22;
     __ZdlPv($4);
     ___resumeException($eh$lpad$body$i$indexZ2D|0);
     // unreachable;
    }
   }
  }
 }
 HEAP32[$7>>2] = 0;
 $19 = ((($4)) + 12|0);
 __THREW__ = 0;
 invoke_vi(388,($19|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if (!($21)) {
  __ZdlPv($4);
  return;
 }
 $29 = ___cxa_find_matching_catch_2()|0;
 $30 = tempRet0;
 $eh$lpad$body$i$index2Z2D = $30;$eh$lpad$body$i$indexZ2D = $29;
 __ZdlPv($4);
 ___resumeException($eh$lpad$body$i$indexZ2D|0);
 // unreachable;
}
function __ZTv0_n16_N3osg22StateAttributeCallbackD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 $5 = ((($4)) + 4|0);
 HEAP32[$5>>2] = ((29984));
 $6 = ((($5)) + 8|0);
 HEAP32[$6>>2] = ((30232));
 $7 = ((($4)) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if ($9) {
  HEAP32[$7>>2] = 0;
  $26 = ((($4)) + 12|0);
  __ZN3osg6ObjectD2Ev($26);
  return;
 }
 $10 = HEAP32[$8>>2]|0;
 $11 = ((($10)) + -12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($8) + ($12)|0);
 $14 = ((($13)) + 8|0);
 $15 = HEAP32[$14>>2]|0;HEAP32[$14>>2] = (($15-1)|0);
 $16 = ($15|0)==(1);
 if (!($16)) {
  HEAP32[$7>>2] = 0;
  $26 = ((($4)) + 12|0);
  __ZN3osg6ObjectD2Ev($26);
  return;
 }
 __THREW__ = 0;
 invoke_viii(3262,($13|0),1,1);
 $17 = __THREW__; __THREW__ = 0;
 $18 = $17&1;
 if (!($18)) {
  HEAP32[$7>>2] = 0;
  $26 = ((($4)) + 12|0);
  __ZN3osg6ObjectD2Ev($26);
  return;
 }
 $19 = ___cxa_find_matching_catch_2()|0;
 $20 = tempRet0;
 $21 = ((($4)) + 12|0);
 __THREW__ = 0;
 invoke_vi(388,($21|0));
 $22 = __THREW__; __THREW__ = 0;
 $23 = $22&1;
 if ($23) {
  $24 = ___cxa_find_matching_catch_3(0|0)|0;
  $25 = tempRet0;
  ___clang_call_terminate($24);
  // unreachable;
 } else {
  ___resumeException($19|0);
  // unreachable;
 }
}
function __ZTv0_n16_N3osg22StateAttributeCallbackD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$i$index2Z2D = 0, $eh$lpad$body$i$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 $5 = ((($4)) + 4|0);
 HEAP32[$5>>2] = ((29984));
 $6 = ((($5)) + 8|0);
 HEAP32[$6>>2] = ((30232));
 $7 = ((($4)) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if (!($9)) {
  $10 = HEAP32[$8>>2]|0;
  $11 = ((($10)) + -12|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($8) + ($12)|0);
  $14 = ((($13)) + 8|0);
  $15 = HEAP32[$14>>2]|0;HEAP32[$14>>2] = (($15-1)|0);
  $16 = ($15|0)==(1);
  if ($16) {
   __THREW__ = 0;
   invoke_viii(3262,($13|0),1,1);
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if ($18) {
    $22 = ___cxa_find_matching_catch_2()|0;
    $23 = tempRet0;
    $24 = ((($4)) + 12|0);
    __THREW__ = 0;
    invoke_vi(388,($24|0));
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if ($26) {
     $27 = ___cxa_find_matching_catch_3(0|0)|0;
     $28 = tempRet0;
     ___clang_call_terminate($27);
     // unreachable;
    } else {
     $eh$lpad$body$i$index2Z2D = $23;$eh$lpad$body$i$indexZ2D = $22;
     __ZdlPv($4);
     ___resumeException($eh$lpad$body$i$indexZ2D|0);
     // unreachable;
    }
   }
  }
 }
 HEAP32[$7>>2] = 0;
 $19 = ((($4)) + 12|0);
 __THREW__ = 0;
 invoke_vi(388,($19|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if (!($21)) {
  __ZdlPv($4);
  return;
 }
 $29 = ___cxa_find_matching_catch_2()|0;
 $30 = tempRet0;
 $eh$lpad$body$i$index2Z2D = $30;$eh$lpad$body$i$indexZ2D = $29;
 __ZdlPv($4);
 ___resumeException($eh$lpad$body$i$indexZ2D|0);
 // unreachable;
}
function __ZTv0_n20_NK3osg22StateAttributeCallback9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(44)|0);
 $2 = ((($1)) + 12|0);
 __THREW__ = 0;
 invoke_vi(3282,($2|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch_2()|0;
  $6 = tempRet0;
  __ZdlPv($1);
  ___resumeException($5|0);
  // unreachable;
 } else {
  $7 = ((($1)) + 24|0);
  ;HEAP32[$7>>2]=0|0;HEAP32[$7+4>>2]=0|0;HEAP32[$7+8>>2]=0|0;
  $8 = ((($1)) + 36|0);
  HEAP32[$8>>2] = 2;
  $9 = ((($1)) + 40|0);
  HEAP32[$9>>2] = 0;
  $10 = ((($1)) + 8|0);
  HEAP32[$10>>2] = 0;
  HEAP32[$1>>2] = (2768);
  $11 = ((($1)) + 4|0);
  HEAP32[$11>>2] = (2924);
  HEAP32[$2>>2] = (3172);
  return ($2|0);
 }
 return (0)|0;
}
function __ZTv0_n24_NK3osg22StateAttributeCallback5cloneERKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $3 = ((($2)) + -24|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($0) + ($4)|0);
 $6 = (__Znwj(44)|0);
 $7 = ((($6)) + 12|0);
 $8 = HEAP32[$5>>2]|0;
 $9 = ((($8)) + -16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($5) + ($10)|0);
 __THREW__ = 0;
 invoke_viii(3468,($7|0),($11|0),($1|0));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $29 = ___cxa_find_matching_catch_2()|0;
  $30 = tempRet0;
  __ZdlPv($6);
  ___resumeException($29|0);
  // unreachable;
 }
 $14 = ((($6)) + 4|0);
 $15 = HEAP32[$5>>2]|0;
 $16 = ((($15)) + -12|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($5) + ($17)|0);
 HEAP32[$14>>2] = ((29984));
 HEAP32[$7>>2] = ((30232));
 $19 = ((($6)) + 8|0);
 $20 = ((($18)) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 HEAP32[$19>>2] = $21;
 $22 = ($21|0)==(0|0);
 if ($22) {
  HEAP32[$6>>2] = (2768);
  HEAP32[$14>>2] = (2924);
  HEAP32[$7>>2] = (3172);
  return ($7|0);
 }
 $23 = HEAP32[$21>>2]|0;
 $24 = ((($23)) + -12|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($21) + ($25)|0);
 $27 = ((($26)) + 8|0);
 $28 = HEAP32[$27>>2]|0;HEAP32[$27>>2] = (($28+1)|0);
 HEAP32[$6>>2] = (2768);
 HEAP32[$14>>2] = (2924);
 HEAP32[$7>>2] = (3172);
 return ($7|0);
}
function __ZTv0_n28_NK3osg22StateAttributeCallback12isSameKindAsEPKNS_6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,23184,-1)|0);
 $phitmp$i = ($3|0)!=(0|0);
 $4 = $phitmp$i;
 return ($4|0);
}
function __ZTv0_n32_NK3osg22StateAttributeCallback11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175113|0);
}
function __ZTv0_n36_NK3osg22StateAttributeCallback9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (120203|0);
}
function __ZN3osg22DrawableUpdateCallback3runEPNS_6ObjectES2_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = HEAP32[$1>>2]|0;
 $4 = ((($3)) + 80|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_ii[$5 & 8191]($1)|0);
 $7 = HEAP32[$2>>2]|0;
 $8 = ((($7)) + 40|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (FUNCTION_TABLE_ii[$9 & 8191]($2)|0);
 $11 = ($6|0)!=(0|0);
 $12 = ($10|0)!=(0|0);
 $or$cond = $11 & $12;
 if ($or$cond) {
  $13 = HEAP32[$0>>2]|0;
  $14 = ((($13)) + 32|0);
  $15 = HEAP32[$14>>2]|0;
  FUNCTION_TABLE_viii[$15 & 8191]($0,$10,$6);
  $$0 = 1;
  return ($$0|0);
 }
 $16 = HEAP32[$0>>2]|0;
 $17 = ((($16)) + -12|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($0) + ($18)|0);
 $20 = ((($19)) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0|0);
 if (!($22)) {
  $23 = HEAP32[$21>>2]|0;
  $24 = ((($23)) + 92|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (FUNCTION_TABLE_iiii[$25 & 8191]($21,$1,$2)|0);
  $$0 = $26;
  return ($$0|0);
 }
 $27 = HEAP32[$1>>2]|0;
 $28 = ((($27)) + 32|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (FUNCTION_TABLE_ii[$29 & 8191]($1)|0);
 $31 = HEAP32[$2>>2]|0;
 $32 = ((($31)) + 40|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = (FUNCTION_TABLE_ii[$33 & 8191]($2)|0);
 $35 = ($30|0)!=(0|0);
 $36 = ($34|0)!=(0|0);
 $or$cond$i = $35 & $36;
 if (!($or$cond$i)) {
  $$0 = 0;
  return ($$0|0);
 }
 $37 = ((($34)) + 16|0);
 $38 = HEAP32[$37>>2]|0;
 switch ($38|0) {
 case 1:  {
  $39 = HEAP32[$30>>2]|0;
  $40 = ((($39)) + 192|0);
  $41 = HEAP32[$40>>2]|0;
  FUNCTION_TABLE_vii[$41 & 8191]($30,$34);
  $$0 = 1;
  return ($$0|0);
  break;
 }
 case 0:  {
  $$0 = 1;
  return ($$0|0);
  break;
 }
 default: {
  $42 = HEAP32[$30>>2]|0;
  $43 = ((($42)) + 196|0);
  $44 = HEAP32[$43>>2]|0;
  FUNCTION_TABLE_vii[$44 & 8191]($30,$34);
  $$0 = 1;
  return ($$0|0);
 }
 }
 return (0)|0;
}
function __ZTv0_n108_N3osg22DrawableUpdateCallback3runEPNS_6ObjectES2_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i = 0, $or$cond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = HEAP32[$0>>2]|0;
 $4 = ((($3)) + -108|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($0) + ($5)|0);
 $7 = HEAP32[$1>>2]|0;
 $8 = ((($7)) + 80|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (FUNCTION_TABLE_ii[$9 & 8191]($1)|0);
 $11 = HEAP32[$2>>2]|0;
 $12 = ((($11)) + 40|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (FUNCTION_TABLE_ii[$13 & 8191]($2)|0);
 $15 = ($10|0)!=(0|0);
 $16 = ($14|0)!=(0|0);
 $or$cond$i = $15 & $16;
 if ($or$cond$i) {
  $17 = HEAP32[$6>>2]|0;
  $18 = ((($17)) + 32|0);
  $19 = HEAP32[$18>>2]|0;
  FUNCTION_TABLE_viii[$19 & 8191]($6,$14,$10);
  $$0$i = 1;
  return ($$0$i|0);
 }
 $20 = HEAP32[$6>>2]|0;
 $21 = ((($20)) + -12|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($6) + ($22)|0);
 $24 = ((($23)) + 4|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)==(0|0);
 if (!($26)) {
  $27 = HEAP32[$25>>2]|0;
  $28 = ((($27)) + 92|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = (FUNCTION_TABLE_iiii[$29 & 8191]($25,$1,$2)|0);
  $$0$i = $30;
  return ($$0$i|0);
 }
 $31 = HEAP32[$1>>2]|0;
 $32 = ((($31)) + 32|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = (FUNCTION_TABLE_ii[$33 & 8191]($1)|0);
 $35 = HEAP32[$2>>2]|0;
 $36 = ((($35)) + 40|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (FUNCTION_TABLE_ii[$37 & 8191]($2)|0);
 $39 = ($34|0)!=(0|0);
 $40 = ($38|0)!=(0|0);
 $or$cond$i$i = $39 & $40;
 if (!($or$cond$i$i)) {
  $$0$i = 0;
  return ($$0$i|0);
 }
 $41 = ((($38)) + 16|0);
 $42 = HEAP32[$41>>2]|0;
 switch ($42|0) {
 case 1:  {
  $43 = HEAP32[$34>>2]|0;
  $44 = ((($43)) + 192|0);
  $45 = HEAP32[$44>>2]|0;
  FUNCTION_TABLE_vii[$45 & 8191]($34,$38);
  $$0$i = 1;
  return ($$0$i|0);
  break;
 }
 case 0:  {
  $$0$i = 1;
  return ($$0$i|0);
  break;
 }
 default: {
  $46 = HEAP32[$34>>2]|0;
  $47 = ((($46)) + 196|0);
  $48 = HEAP32[$47>>2]|0;
  FUNCTION_TABLE_vii[$48 & 8191]($34,$38);
  $$0$i = 1;
  return ($$0$i|0);
 }
 }
 return (0)|0;
}
function __ZN3osg21DrawableEventCallback3runEPNS_6ObjectES2_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = HEAP32[$1>>2]|0;
 $4 = ((($3)) + 80|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_ii[$5 & 8191]($1)|0);
 $7 = HEAP32[$2>>2]|0;
 $8 = ((($7)) + 40|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (FUNCTION_TABLE_ii[$9 & 8191]($2)|0);
 $11 = ($6|0)!=(0|0);
 $12 = ($10|0)!=(0|0);
 $or$cond = $11 & $12;
 if ($or$cond) {
  $13 = HEAP32[$0>>2]|0;
  $14 = ((($13)) + 32|0);
  $15 = HEAP32[$14>>2]|0;
  FUNCTION_TABLE_viii[$15 & 8191]($0,$10,$6);
  $$0 = 1;
  return ($$0|0);
 }
 $16 = HEAP32[$0>>2]|0;
 $17 = ((($16)) + -12|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($0) + ($18)|0);
 $20 = ((($19)) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0|0);
 if (!($22)) {
  $23 = HEAP32[$21>>2]|0;
  $24 = ((($23)) + 92|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (FUNCTION_TABLE_iiii[$25 & 8191]($21,$1,$2)|0);
  $$0 = $26;
  return ($$0|0);
 }
 $27 = HEAP32[$1>>2]|0;
 $28 = ((($27)) + 32|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (FUNCTION_TABLE_ii[$29 & 8191]($1)|0);
 $31 = HEAP32[$2>>2]|0;
 $32 = ((($31)) + 40|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = (FUNCTION_TABLE_ii[$33 & 8191]($2)|0);
 $35 = ($30|0)!=(0|0);
 $36 = ($34|0)!=(0|0);
 $or$cond$i = $35 & $36;
 if (!($or$cond$i)) {
  $$0 = 0;
  return ($$0|0);
 }
 $37 = ((($34)) + 16|0);
 $38 = HEAP32[$37>>2]|0;
 switch ($38|0) {
 case 1:  {
  $39 = HEAP32[$30>>2]|0;
  $40 = ((($39)) + 192|0);
  $41 = HEAP32[$40>>2]|0;
  FUNCTION_TABLE_vii[$41 & 8191]($30,$34);
  $$0 = 1;
  return ($$0|0);
  break;
 }
 case 0:  {
  $$0 = 1;
  return ($$0|0);
  break;
 }
 default: {
  $42 = HEAP32[$30>>2]|0;
  $43 = ((($42)) + 196|0);
  $44 = HEAP32[$43>>2]|0;
  FUNCTION_TABLE_vii[$44 & 8191]($30,$34);
  $$0 = 1;
  return ($$0|0);
 }
 }
 return (0)|0;
}
function __ZTv0_n108_N3osg21DrawableEventCallback3runEPNS_6ObjectES2_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i = 0, $or$cond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = HEAP32[$0>>2]|0;
 $4 = ((($3)) + -108|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($0) + ($5)|0);
 $7 = HEAP32[$1>>2]|0;
 $8 = ((($7)) + 80|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (FUNCTION_TABLE_ii[$9 & 8191]($1)|0);
 $11 = HEAP32[$2>>2]|0;
 $12 = ((($11)) + 40|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (FUNCTION_TABLE_ii[$13 & 8191]($2)|0);
 $15 = ($10|0)!=(0|0);
 $16 = ($14|0)!=(0|0);
 $or$cond$i = $15 & $16;
 if ($or$cond$i) {
  $17 = HEAP32[$6>>2]|0;
  $18 = ((($17)) + 32|0);
  $19 = HEAP32[$18>>2]|0;
  FUNCTION_TABLE_viii[$19 & 8191]($6,$14,$10);
  $$0$i = 1;
  return ($$0$i|0);
 }
 $20 = HEAP32[$6>>2]|0;
 $21 = ((($20)) + -12|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($6) + ($22)|0);
 $24 = ((($23)) + 4|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)==(0|0);
 if (!($26)) {
  $27 = HEAP32[$25>>2]|0;
  $28 = ((($27)) + 92|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = (FUNCTION_TABLE_iiii[$29 & 8191]($25,$1,$2)|0);
  $$0$i = $30;
  return ($$0$i|0);
 }
 $31 = HEAP32[$1>>2]|0;
 $32 = ((($31)) + 32|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = (FUNCTION_TABLE_ii[$33 & 8191]($1)|0);
 $35 = HEAP32[$2>>2]|0;
 $36 = ((($35)) + 40|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (FUNCTION_TABLE_ii[$37 & 8191]($2)|0);
 $39 = ($34|0)!=(0|0);
 $40 = ($38|0)!=(0|0);
 $or$cond$i$i = $39 & $40;
 if (!($or$cond$i$i)) {
  $$0$i = 0;
  return ($$0$i|0);
 }
 $41 = ((($38)) + 16|0);
 $42 = HEAP32[$41>>2]|0;
 switch ($42|0) {
 case 1:  {
  $43 = HEAP32[$34>>2]|0;
  $44 = ((($43)) + 192|0);
  $45 = HEAP32[$44>>2]|0;
  FUNCTION_TABLE_vii[$45 & 8191]($34,$38);
  $$0$i = 1;
  return ($$0$i|0);
  break;
 }
 case 0:  {
  $$0$i = 1;
  return ($$0$i|0);
  break;
 }
 default: {
  $46 = HEAP32[$34>>2]|0;
  $47 = ((($46)) + 196|0);
  $48 = HEAP32[$47>>2]|0;
  FUNCTION_TABLE_vii[$48 & 8191]($34,$38);
  $$0$i = 1;
  return ($$0$i|0);
 }
 }
 return (0)|0;
}
function __ZN3osg8Callback8traverseEPNS_6ObjectES2_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if (!($5)) {
  $6 = HEAP32[$4>>2]|0;
  $7 = ((($6)) + 92|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (FUNCTION_TABLE_iiii[$8 & 8191]($4,$1,$2)|0);
  $$1 = $9;
  return ($$1|0);
 }
 $10 = ($1|0)==(0|0);
 if ($10) {
  $20 = 0;
 } else {
  $11 = HEAP32[$1>>2]|0;
  $12 = ((($11)) + 32|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (FUNCTION_TABLE_ii[$13 & 8191]($1)|0);
  $20 = $14;
 }
 $15 = ($2|0)==(0|0);
 if ($15) {
  $$1 = 0;
  return ($$1|0);
 }
 $16 = HEAP32[$2>>2]|0;
 $17 = ((($16)) + 40|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (FUNCTION_TABLE_ii[$18 & 8191]($2)|0);
 $21 = ($20|0)!=(0|0);
 $22 = ($19|0)!=(0|0);
 $or$cond = $21 & $22;
 if (!($or$cond)) {
  $$1 = 0;
  return ($$1|0);
 }
 $23 = ((($19)) + 16|0);
 $24 = HEAP32[$23>>2]|0;
 switch ($24|0) {
 case 1:  {
  $25 = HEAP32[$20>>2]|0;
  $26 = ((($25)) + 192|0);
  $27 = HEAP32[$26>>2]|0;
  FUNCTION_TABLE_vii[$27 & 8191]($20,$19);
  $$1 = 1;
  return ($$1|0);
  break;
 }
 case 0:  {
  $$1 = 1;
  return ($$1|0);
  break;
 }
 default: {
  $28 = HEAP32[$20>>2]|0;
  $29 = ((($28)) + 196|0);
  $30 = HEAP32[$29>>2]|0;
  FUNCTION_TABLE_vii[$30 & 8191]($20,$19);
  $$1 = 1;
  return ($$1|0);
 }
 }
 return (0)|0;
}
function __ZN3osg6CameraD2Ev($0) {
 $0 = $0|0;
 var $$0 = 0, $$02 = 0, $$1 = 0, $$10 = 0, $$1015 = 0, $$11 = 0, $$1116 = 0, $$12 = 0, $$1217 = 0, $$13 = 0, $$1318 = 0, $$14 = 0, $$1419 = 0, $$15 = 0, $$1520 = 0, $$16 = 0, $$2 = 0, $$27 = 0, $$3 = 0, $$38 = 0;
 var $$4 = 0, $$49 = 0, $$5 = 0, $$510 = 0, $$6 = 0, $$611 = 0, $$7 = 0, $$712 = 0, $$pre = 0, $$pre$phiZ2D = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0;
 var $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0;
 var $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0;
 var $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0;
 var $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0;
 var $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0;
 var $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0;
 var $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0;
 var $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0;
 var $306 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (56344);
 $1 = ((($0)) + 144|0);
 HEAP32[$1>>2] = (56628);
 __THREW__ = 0;
 invoke_vii(3444,($0|0),(0|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if ($3) {
   label = 4;
  } else {
   $4 = ((($0)) + 624|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = ($5|0)==(0|0);
   if (!($6)) {
    __THREW__ = 0;
    invoke_vii(3721,($5|0),($0|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     label = 4;
     break;
    }
   }
   $23 = ((($0)) + 648|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = ($24|0)==(0|0);
   if (!($25)) {
    $26 = HEAP32[$24>>2]|0;
    $27 = ((($26)) + -12|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = (($24) + ($28)|0);
    $30 = ((($29)) + 8|0);
    $31 = HEAP32[$30>>2]|0;HEAP32[$30>>2] = (($31-1)|0);
    $32 = ($31|0)==(1);
    if ($32) {
     __THREW__ = 0;
     invoke_viii(3262,($29|0),1,1);
     $33 = __THREW__; __THREW__ = 0;
     $34 = $33&1;
     if ($34) {
      $155 = ___cxa_find_matching_catch_2()|0;
      $156 = tempRet0;
      $$0 = $156;$$02 = $155;
      label = 51;
      break;
     }
    }
   }
   HEAP32[$23>>2] = 0;
   $35 = ((($0)) + 644|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = ($36|0)==(0|0);
   if (!($37)) {
    $38 = HEAP32[$36>>2]|0;
    $39 = ((($38)) + -12|0);
    $40 = HEAP32[$39>>2]|0;
    $41 = (($36) + ($40)|0);
    $42 = ((($41)) + 8|0);
    $43 = HEAP32[$42>>2]|0;HEAP32[$42>>2] = (($43-1)|0);
    $44 = ($43|0)==(1);
    if ($44) {
     __THREW__ = 0;
     invoke_viii(3262,($41|0),1,1);
     $45 = __THREW__; __THREW__ = 0;
     $46 = $45&1;
     if ($46) {
      $157 = ___cxa_find_matching_catch_2()|0;
      $158 = tempRet0;
      $$1 = $158;$$16 = $157;
      label = 56;
      break;
     }
    }
   }
   HEAP32[$35>>2] = 0;
   $47 = ((($0)) + 640|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = ($48|0)==(0|0);
   if (!($49)) {
    $50 = HEAP32[$48>>2]|0;
    $51 = ((($50)) + -12|0);
    $52 = HEAP32[$51>>2]|0;
    $53 = (($48) + ($52)|0);
    $54 = ((($53)) + 8|0);
    $55 = HEAP32[$54>>2]|0;HEAP32[$54>>2] = (($55-1)|0);
    $56 = ($55|0)==(1);
    if ($56) {
     __THREW__ = 0;
     invoke_viii(3262,($53|0),1,1);
     $57 = __THREW__; __THREW__ = 0;
     $58 = $57&1;
     if ($58) {
      $171 = ___cxa_find_matching_catch_2()|0;
      $172 = tempRet0;
      $$2 = $172;$$27 = $171;
      label = 61;
      break;
     }
    }
   }
   HEAP32[$47>>2] = 0;
   $59 = ((($0)) + 636|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = ($60|0)==(0|0);
   if (!($61)) {
    $62 = HEAP32[$60>>2]|0;
    $63 = ((($62)) + -12|0);
    $64 = HEAP32[$63>>2]|0;
    $65 = (($60) + ($64)|0);
    $66 = ((($65)) + 8|0);
    $67 = HEAP32[$66>>2]|0;HEAP32[$66>>2] = (($67-1)|0);
    $68 = ($67|0)==(1);
    if ($68) {
     __THREW__ = 0;
     invoke_viii(3262,($65|0),1,1);
     $69 = __THREW__; __THREW__ = 0;
     $70 = $69&1;
     if ($70) {
      $185 = ___cxa_find_matching_catch_2()|0;
      $186 = tempRet0;
      $$3 = $186;$$38 = $185;
      label = 66;
      break;
     }
    }
   }
   HEAP32[$59>>2] = 0;
   $71 = ((($0)) + 632|0);
   $72 = HEAP32[$71>>2]|0;
   $73 = ($72|0)==(0|0);
   if (!($73)) {
    $74 = ((($72)) + 8|0);
    $75 = HEAP32[$74>>2]|0;HEAP32[$74>>2] = (($75-1)|0);
    $76 = ($75|0)==(1);
    if ($76) {
     __THREW__ = 0;
     invoke_viii(3262,($72|0),1,1);
     $77 = __THREW__; __THREW__ = 0;
     $78 = $77&1;
     if ($78) {
      $199 = ___cxa_find_matching_catch_2()|0;
      $200 = tempRet0;
      $$4 = $200;$$49 = $199;
      label = 71;
      break;
     }
    }
   }
   HEAP32[$71>>2] = 0;
   $79 = ((($0)) + 628|0);
   $80 = HEAP32[$79>>2]|0;
   $81 = ($80|0)==(0|0);
   if (!($81)) {
    $82 = HEAP32[$80>>2]|0;
    $83 = ((($82)) + -12|0);
    $84 = HEAP32[$83>>2]|0;
    $85 = (($80) + ($84)|0);
    $86 = ((($85)) + 8|0);
    $87 = HEAP32[$86>>2]|0;HEAP32[$86>>2] = (($87-1)|0);
    $88 = ($87|0)==(1);
    if ($88) {
     __THREW__ = 0;
     invoke_viii(3262,($85|0),1,1);
     $89 = __THREW__; __THREW__ = 0;
     $90 = $89&1;
     if ($90) {
      $209 = ___cxa_find_matching_catch_2()|0;
      $210 = tempRet0;
      $$5 = $210;$$510 = $209;$$pre$phiZ2D = $4;
      label = 76;
      break;
     }
    }
   }
   HEAP32[$79>>2] = 0;
   $91 = HEAP32[$4>>2]|0;
   $92 = ($91|0)==(0|0);
   if (!($92)) {
    $93 = ((($91)) + 8|0);
    $94 = HEAP32[$93>>2]|0;HEAP32[$93>>2] = (($94-1)|0);
    $95 = ($94|0)==(1);
    if ($95) {
     __THREW__ = 0;
     invoke_viii(3262,($91|0),1,1);
     $96 = __THREW__; __THREW__ = 0;
     $97 = $96&1;
     if ($97) {
      $223 = ___cxa_find_matching_catch_2()|0;
      $224 = tempRet0;
      $$6 = $224;$$611 = $223;
      label = 81;
      break;
     }
    }
   }
   HEAP32[$4>>2] = 0;
   $98 = ((($0)) + 620|0);
   $99 = HEAP32[$98>>2]|0;
   $100 = ($99|0)==(0|0);
   if (!($100)) {
    $101 = ((($99)) + 8|0);
    $102 = HEAP32[$101>>2]|0;HEAP32[$101>>2] = (($102-1)|0);
    $103 = ($102|0)==(1);
    if ($103) {
     __THREW__ = 0;
     invoke_viii(3262,($99|0),1,1);
     $104 = __THREW__; __THREW__ = 0;
     $105 = $104&1;
     if ($105) {
      $232 = ___cxa_find_matching_catch_2()|0;
      $233 = tempRet0;
      $$7 = $233;$$712 = $232;
      label = 85;
      break;
     }
    }
   }
   HEAP32[$98>>2] = 0;
   $106 = ((($0)) + 608|0);
   $107 = ((($0)) + 612|0);
   $108 = HEAP32[$107>>2]|0;
   __ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEE7destroyEPNS_11__tree_nodeIjPvEE($106,$108);
   $109 = ((($0)) + 584|0);
   $110 = ((($0)) + 588|0);
   $111 = HEAP32[$110>>2]|0;
   __ZNSt3__26__treeINS_12__value_typeIN3osg6Camera15BufferComponentENS3_10AttachmentEEENS_19__map_value_compareIS4_S6_NS_4lessIS4_EELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($109,$111);
   $112 = ((($0)) + 288|0);
   $113 = HEAP32[$112>>2]|0;
   $114 = ($113|0)==(0|0);
   if (!($114)) {
    $115 = ((($113)) + 8|0);
    $116 = HEAP32[$115>>2]|0;HEAP32[$115>>2] = (($116-1)|0);
    $117 = ($116|0)==(1);
    if ($117) {
     __THREW__ = 0;
     invoke_viii(3262,($113|0),1,1);
     $118 = __THREW__; __THREW__ = 0;
     $119 = $118&1;
     if ($119) {
      $256 = ___cxa_find_matching_catch_2()|0;
      $257 = tempRet0;
      $$10 = $257;$$1015 = $256;
      label = 91;
      break;
     }
    }
   }
   HEAP32[$112>>2] = 0;
   $120 = ((($0)) + 284|0);
   $121 = HEAP32[$120>>2]|0;
   $122 = ($121|0)==(0|0);
   if (!($122)) {
    $123 = ((($121)) + 8|0);
    $124 = HEAP32[$123>>2]|0;HEAP32[$123>>2] = (($124-1)|0);
    $125 = ($124|0)==(1);
    if ($125) {
     __THREW__ = 0;
     invoke_viii(3262,($121|0),1,1);
     $126 = __THREW__; __THREW__ = 0;
     $127 = $126&1;
     if ($127) {
      $258 = ___cxa_find_matching_catch_2()|0;
      $259 = tempRet0;
      $$11 = $259;$$1116 = $258;
      label = 96;
      break;
     }
    }
   }
   HEAP32[$120>>2] = 0;
   $128 = ((($0)) + 232|0);
   $129 = HEAP32[$128>>2]|0;
   $130 = ($129|0)==(0|0);
   if (!($130)) {
    $131 = ((($129)) + 8|0);
    $132 = HEAP32[$131>>2]|0;HEAP32[$131>>2] = (($132-1)|0);
    $133 = ($132|0)==(1);
    if ($133) {
     __THREW__ = 0;
     invoke_viii(3262,($129|0),1,1);
     $134 = __THREW__; __THREW__ = 0;
     $135 = $134&1;
     if ($135) {
      $268 = ___cxa_find_matching_catch_2()|0;
      $269 = tempRet0;
      $$12 = $269;$$1217 = $268;
      label = 101;
      break;
     }
    }
   }
   HEAP32[$128>>2] = 0;
   $136 = ((($0)) + 224|0);
   $137 = HEAP32[$136>>2]|0;
   $138 = ($137|0)==(0|0);
   if (!($138)) {
    $139 = ((($137)) + 8|0);
    $140 = HEAP32[$139>>2]|0;HEAP32[$139>>2] = (($140-1)|0);
    $141 = ($140|0)==(1);
    if ($141) {
     __THREW__ = 0;
     invoke_viii(3262,($137|0),1,1);
     $142 = __THREW__; __THREW__ = 0;
     $143 = $142&1;
     if ($143) {
      $278 = ___cxa_find_matching_catch_2()|0;
      $279 = tempRet0;
      $$13 = $279;$$1318 = $278;
      label = 106;
      break;
     }
    }
   }
   HEAP32[$136>>2] = 0;
   $144 = ((($0)) + 208|0);
   __THREW__ = 0;
   invoke_vi(707,($144|0));
   $145 = __THREW__; __THREW__ = 0;
   $146 = $145&1;
   if ($146) {
    $288 = ___cxa_find_matching_catch_2()|0;
    $289 = tempRet0;
    $$14 = $289;$$1419 = $288;
    label = 108;
    break;
   }
   HEAP32[$1>>2] = (58232);
   $147 = ((($0)) + 172|0);
   $148 = HEAP32[$147>>2]|0;
   $149 = ($148|0)==(0|0);
   if ($149) {
    HEAP32[$147>>2] = 0;
    __ZN3osg9TransformD2Ev($0);
    return;
   }
   $150 = ((($148)) + 8|0);
   $151 = HEAP32[$150>>2]|0;HEAP32[$150>>2] = (($151-1)|0);
   $152 = ($151|0)==(1);
   if (!($152)) {
    HEAP32[$147>>2] = 0;
    __ZN3osg9TransformD2Ev($0);
    return;
   }
   __THREW__ = 0;
   invoke_viii(3262,($148|0),1,1);
   $153 = __THREW__; __THREW__ = 0;
   $154 = $153&1;
   if ($154) {
    $293 = ___cxa_find_matching_catch_2()|0;
    $294 = tempRet0;
    $$15 = $294;$$1520 = $293;
    break;
   } else {
    HEAP32[$147>>2] = 0;
    __ZN3osg9TransformD2Ev($0);
    return;
   }
  }
 } while(0);
 if ((label|0) == 4) {
  $9 = ___cxa_find_matching_catch_2()|0;
  $10 = tempRet0;
  $11 = ((($0)) + 648|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($12|0)==(0|0);
  if (!($13)) {
   $14 = HEAP32[$12>>2]|0;
   $15 = ((($14)) + -12|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (($12) + ($16)|0);
   $18 = ((($17)) + 8|0);
   $19 = HEAP32[$18>>2]|0;HEAP32[$18>>2] = (($19-1)|0);
   $20 = ($19|0)==(1);
   if ($20) {
    __THREW__ = 0;
    invoke_viii(3262,($17|0),1,1);
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if ($22) {
     $305 = ___cxa_find_matching_catch_3(0|0)|0;
     $306 = tempRet0;
     ___clang_call_terminate($305);
     // unreachable;
    }
   }
  }
  HEAP32[$11>>2] = 0;
  $$0 = $10;$$02 = $9;
  label = 51;
 }
 if ((label|0) == 51) {
  $159 = ((($0)) + 644|0);
  $160 = HEAP32[$159>>2]|0;
  $161 = ($160|0)==(0|0);
  if (!($161)) {
   $162 = HEAP32[$160>>2]|0;
   $163 = ((($162)) + -12|0);
   $164 = HEAP32[$163>>2]|0;
   $165 = (($160) + ($164)|0);
   $166 = ((($165)) + 8|0);
   $167 = HEAP32[$166>>2]|0;HEAP32[$166>>2] = (($167-1)|0);
   $168 = ($167|0)==(1);
   if ($168) {
    __THREW__ = 0;
    invoke_viii(3262,($165|0),1,1);
    $169 = __THREW__; __THREW__ = 0;
    $170 = $169&1;
    if ($170) {
     $305 = ___cxa_find_matching_catch_3(0|0)|0;
     $306 = tempRet0;
     ___clang_call_terminate($305);
     // unreachable;
    }
   }
  }
  HEAP32[$159>>2] = 0;
  $$1 = $$0;$$16 = $$02;
  label = 56;
 }
 if ((label|0) == 56) {
  $173 = ((($0)) + 640|0);
  $174 = HEAP32[$173>>2]|0;
  $175 = ($174|0)==(0|0);
  if (!($175)) {
   $176 = HEAP32[$174>>2]|0;
   $177 = ((($176)) + -12|0);
   $178 = HEAP32[$177>>2]|0;
   $179 = (($174) + ($178)|0);
   $180 = ((($179)) + 8|0);
   $181 = HEAP32[$180>>2]|0;HEAP32[$180>>2] = (($181-1)|0);
   $182 = ($181|0)==(1);
   if ($182) {
    __THREW__ = 0;
    invoke_viii(3262,($179|0),1,1);
    $183 = __THREW__; __THREW__ = 0;
    $184 = $183&1;
    if ($184) {
     $305 = ___cxa_find_matching_catch_3(0|0)|0;
     $306 = tempRet0;
     ___clang_call_terminate($305);
     // unreachable;
    }
   }
  }
  HEAP32[$173>>2] = 0;
  $$2 = $$1;$$27 = $$16;
  label = 61;
 }
 if ((label|0) == 61) {
  $187 = ((($0)) + 636|0);
  $188 = HEAP32[$187>>2]|0;
  $189 = ($188|0)==(0|0);
  if (!($189)) {
   $190 = HEAP32[$188>>2]|0;
   $191 = ((($190)) + -12|0);
   $192 = HEAP32[$191>>2]|0;
   $193 = (($188) + ($192)|0);
   $194 = ((($193)) + 8|0);
   $195 = HEAP32[$194>>2]|0;HEAP32[$194>>2] = (($195-1)|0);
   $196 = ($195|0)==(1);
   if ($196) {
    __THREW__ = 0;
    invoke_viii(3262,($193|0),1,1);
    $197 = __THREW__; __THREW__ = 0;
    $198 = $197&1;
    if ($198) {
     $305 = ___cxa_find_matching_catch_3(0|0)|0;
     $306 = tempRet0;
     ___clang_call_terminate($305);
     // unreachable;
    }
   }
  }
  HEAP32[$187>>2] = 0;
  $$3 = $$2;$$38 = $$27;
  label = 66;
 }
 if ((label|0) == 66) {
  $201 = ((($0)) + 632|0);
  $202 = HEAP32[$201>>2]|0;
  $203 = ($202|0)==(0|0);
  if (!($203)) {
   $204 = ((($202)) + 8|0);
   $205 = HEAP32[$204>>2]|0;HEAP32[$204>>2] = (($205-1)|0);
   $206 = ($205|0)==(1);
   if ($206) {
    __THREW__ = 0;
    invoke_viii(3262,($202|0),1,1);
    $207 = __THREW__; __THREW__ = 0;
    $208 = $207&1;
    if ($208) {
     $305 = ___cxa_find_matching_catch_3(0|0)|0;
     $306 = tempRet0;
     ___clang_call_terminate($305);
     // unreachable;
    }
   }
  }
  HEAP32[$201>>2] = 0;
  $$4 = $$3;$$49 = $$38;
  label = 71;
 }
 if ((label|0) == 71) {
  $211 = ((($0)) + 628|0);
  $212 = HEAP32[$211>>2]|0;
  $213 = ($212|0)==(0|0);
  if (!($213)) {
   $214 = HEAP32[$212>>2]|0;
   $215 = ((($214)) + -12|0);
   $216 = HEAP32[$215>>2]|0;
   $217 = (($212) + ($216)|0);
   $218 = ((($217)) + 8|0);
   $219 = HEAP32[$218>>2]|0;HEAP32[$218>>2] = (($219-1)|0);
   $220 = ($219|0)==(1);
   if ($220) {
    __THREW__ = 0;
    invoke_viii(3262,($217|0),1,1);
    $221 = __THREW__; __THREW__ = 0;
    $222 = $221&1;
    if ($222) {
     $305 = ___cxa_find_matching_catch_3(0|0)|0;
     $306 = tempRet0;
     ___clang_call_terminate($305);
     // unreachable;
    }
   }
  }
  HEAP32[$211>>2] = 0;
  $$pre = ((($0)) + 624|0);
  $$5 = $$4;$$510 = $$49;$$pre$phiZ2D = $$pre;
  label = 76;
 }
 if ((label|0) == 76) {
  $225 = HEAP32[$$pre$phiZ2D>>2]|0;
  $226 = ($225|0)==(0|0);
  if (!($226)) {
   $227 = ((($225)) + 8|0);
   $228 = HEAP32[$227>>2]|0;HEAP32[$227>>2] = (($228-1)|0);
   $229 = ($228|0)==(1);
   if ($229) {
    __THREW__ = 0;
    invoke_viii(3262,($225|0),1,1);
    $230 = __THREW__; __THREW__ = 0;
    $231 = $230&1;
    if ($231) {
     $305 = ___cxa_find_matching_catch_3(0|0)|0;
     $306 = tempRet0;
     ___clang_call_terminate($305);
     // unreachable;
    }
   }
  }
  HEAP32[$$pre$phiZ2D>>2] = 0;
  $$6 = $$5;$$611 = $$510;
  label = 81;
 }
 if ((label|0) == 81) {
  $234 = ((($0)) + 620|0);
  $235 = HEAP32[$234>>2]|0;
  $236 = ($235|0)==(0|0);
  if (!($236)) {
   $237 = ((($235)) + 8|0);
   $238 = HEAP32[$237>>2]|0;HEAP32[$237>>2] = (($238-1)|0);
   $239 = ($238|0)==(1);
   if ($239) {
    __THREW__ = 0;
    invoke_viii(3262,($235|0),1,1);
    $240 = __THREW__; __THREW__ = 0;
    $241 = $240&1;
    if ($241) {
     $305 = ___cxa_find_matching_catch_3(0|0)|0;
     $306 = tempRet0;
     ___clang_call_terminate($305);
     // unreachable;
    }
   }
  }
  HEAP32[$234>>2] = 0;
  $$7 = $$6;$$712 = $$611;
  label = 85;
 }
 if ((label|0) == 85) {
  $242 = ((($0)) + 608|0);
  $243 = ((($0)) + 612|0);
  $244 = HEAP32[$243>>2]|0;
  __ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEE7destroyEPNS_11__tree_nodeIjPvEE($242,$244);
  $245 = ((($0)) + 584|0);
  $246 = ((($0)) + 588|0);
  $247 = HEAP32[$246>>2]|0;
  __ZNSt3__26__treeINS_12__value_typeIN3osg6Camera15BufferComponentENS3_10AttachmentEEENS_19__map_value_compareIS4_S6_NS_4lessIS4_EELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($245,$247);
  $248 = ((($0)) + 288|0);
  $249 = HEAP32[$248>>2]|0;
  $250 = ($249|0)==(0|0);
  if (!($250)) {
   $251 = ((($249)) + 8|0);
   $252 = HEAP32[$251>>2]|0;HEAP32[$251>>2] = (($252-1)|0);
   $253 = ($252|0)==(1);
   if ($253) {
    __THREW__ = 0;
    invoke_viii(3262,($249|0),1,1);
    $254 = __THREW__; __THREW__ = 0;
    $255 = $254&1;
    if ($255) {
     $305 = ___cxa_find_matching_catch_3(0|0)|0;
     $306 = tempRet0;
     ___clang_call_terminate($305);
     // unreachable;
    }
   }
  }
  HEAP32[$248>>2] = 0;
  $$10 = $$7;$$1015 = $$712;
  label = 91;
 }
 if ((label|0) == 91) {
  $260 = ((($0)) + 284|0);
  $261 = HEAP32[$260>>2]|0;
  $262 = ($261|0)==(0|0);
  if (!($262)) {
   $263 = ((($261)) + 8|0);
   $264 = HEAP32[$263>>2]|0;HEAP32[$263>>2] = (($264-1)|0);
   $265 = ($264|0)==(1);
   if ($265) {
    __THREW__ = 0;
    invoke_viii(3262,($261|0),1,1);
    $266 = __THREW__; __THREW__ = 0;
    $267 = $266&1;
    if ($267) {
     $305 = ___cxa_find_matching_catch_3(0|0)|0;
     $306 = tempRet0;
     ___clang_call_terminate($305);
     // unreachable;
    }
   }
  }
  HEAP32[$260>>2] = 0;
  $$11 = $$10;$$1116 = $$1015;
  label = 96;
 }
 if ((label|0) == 96) {
  $270 = ((($0)) + 232|0);
  $271 = HEAP32[$270>>2]|0;
  $272 = ($271|0)==(0|0);
  if (!($272)) {
   $273 = ((($271)) + 8|0);
   $274 = HEAP32[$273>>2]|0;HEAP32[$273>>2] = (($274-1)|0);
   $275 = ($274|0)==(1);
   if ($275) {
    __THREW__ = 0;
    invoke_viii(3262,($271|0),1,1);
    $276 = __THREW__; __THREW__ = 0;
    $277 = $276&1;
    if ($277) {
     $305 = ___cxa_find_matching_catch_3(0|0)|0;
     $306 = tempRet0;
     ___clang_call_terminate($305);
     // unreachable;
    }
   }
  }
  HEAP32[$270>>2] = 0;
  $$12 = $$11;$$1217 = $$1116;
  label = 101;
 }
 if ((label|0) == 101) {
  $280 = ((($0)) + 224|0);
  $281 = HEAP32[$280>>2]|0;
  $282 = ($281|0)==(0|0);
  if (!($282)) {
   $283 = ((($281)) + 8|0);
   $284 = HEAP32[$283>>2]|0;HEAP32[$283>>2] = (($284-1)|0);
   $285 = ($284|0)==(1);
   if ($285) {
    __THREW__ = 0;
    invoke_viii(3262,($281|0),1,1);
    $286 = __THREW__; __THREW__ = 0;
    $287 = $286&1;
    if ($287) {
     $305 = ___cxa_find_matching_catch_3(0|0)|0;
     $306 = tempRet0;
     ___clang_call_terminate($305);
     // unreachable;
    }
   }
  }
  HEAP32[$280>>2] = 0;
  $$13 = $$12;$$1318 = $$1217;
  label = 106;
 }
 if ((label|0) == 106) {
  $290 = ((($0)) + 208|0);
  __THREW__ = 0;
  invoke_vi(707,($290|0));
  $291 = __THREW__; __THREW__ = 0;
  $292 = $291&1;
  if ($292) {
   $305 = ___cxa_find_matching_catch_3(0|0)|0;
   $306 = tempRet0;
   ___clang_call_terminate($305);
   // unreachable;
  } else {
   $$14 = $$13;$$1419 = $$1318;
   label = 108;
  }
 }
 if ((label|0) == 108) {
  HEAP32[$1>>2] = (58232);
  $295 = ((($0)) + 172|0);
  $296 = HEAP32[$295>>2]|0;
  $297 = ($296|0)==(0|0);
  if (!($297)) {
   $298 = ((($296)) + 8|0);
   $299 = HEAP32[$298>>2]|0;HEAP32[$298>>2] = (($299-1)|0);
   $300 = ($299|0)==(1);
   if ($300) {
    __THREW__ = 0;
    invoke_viii(3262,($296|0),1,1);
    $301 = __THREW__; __THREW__ = 0;
    $302 = $301&1;
    if ($302) {
     $305 = ___cxa_find_matching_catch_3(0|0)|0;
     $306 = tempRet0;
     ___clang_call_terminate($305);
     // unreachable;
    }
   }
  }
  HEAP32[$295>>2] = 0;
  $$15 = $$14;$$1520 = $$1419;
 }
 __THREW__ = 0;
 invoke_vi(2366,($0|0));
 $303 = __THREW__; __THREW__ = 0;
 $304 = $303&1;
 if ($304) {
  $305 = ___cxa_find_matching_catch_3(0|0)|0;
  $306 = tempRet0;
  ___clang_call_terminate($305);
  // unreachable;
 } else {
  ___resumeException($$1520|0);
  // unreachable;
 }
}
function __ZN3osg6CameraD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1478,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK3osg6Camera9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(656)|0);
 __THREW__ = 0;
 invoke_vi(3336,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch_2()|0;
  $5 = tempRet0;
  __ZdlPv($1);
  ___resumeException($4|0);
  // unreachable;
 } else {
  return ($1|0);
 }
 return (0)|0;
}
function __ZNK3osg6Camera5cloneERKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(656)|0);
 __THREW__ = 0;
 invoke_viii(3722,($2|0),($0|0),($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch_2()|0;
  $6 = tempRet0;
  __ZdlPv($2);
  ___resumeException($5|0);
  // unreachable;
 } else {
  return ($2|0);
 }
 return (0)|0;
}
function __ZNK3osg6Camera12isSameKindAsEPKNS_6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,23304,0)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK3osg6Camera11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175113|0);
}
function __ZNK3osg6Camera9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (120371|0);
}
function __ZN3osg6Camera8asCameraEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ($0|0);
}
function __ZNK3osg6Camera8asCameraEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ($0|0);
}
function __ZN3osg6Camera21resizeGLObjectBuffersEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 632|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = HEAP32[$3>>2]|0;
  $6 = ((($5)) + 132|0);
  $7 = HEAP32[$6>>2]|0;
  FUNCTION_TABLE_vii[$7 & 8191]($3,$1);
 }
 __ZN3osg5Group21resizeGLObjectBuffersEj($0,$1);
 return;
}
function __ZNK3osg6Camera16releaseGLObjectsEPNS_5StateE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 632|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = HEAP32[$3>>2]|0;
  $6 = ((($5)) + 136|0);
  $7 = HEAP32[$6>>2]|0;
  FUNCTION_TABLE_vii[$7 & 8191]($3,$1);
 }
 __ZNK3osg5Group16releaseGLObjectsEPNS_5StateE($0,$1);
 return;
}
function __ZN3osg9Transform11asTransformEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ($0|0);
}
function __ZNK3osg9Transform11asTransformEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ($0|0);
}
function __ZN3osg4Node7asGeodeEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZNK3osg4Node7asGeodeEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZN3osg6Camera6acceptERNS_11NodeVisitorE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$byval_copy = 0, $$pre$i$i = 0, $$sink$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i = 0, $scevgep5$i$i$i$i = 0, $scevgep5$i$i$i$sink$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy = sp + 8|0;
 $2 = sp + 4|0;
 $3 = sp;
 $4 = ((($1)) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($1)) + 24|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($0)) + 116|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $9 | $7;
 $11 = $10 & $5;
 $12 = ($11|0)==(0);
 if ($12) {
  STACKTOP = sp;return;
 }
 HEAP32[$2>>2] = $0;
 $13 = ((($1)) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(1);
 $16 = ((($1)) + 28|0);
 $17 = $0;
 do {
  if ($15) {
   $25 = HEAP32[$16>>2]|0;
   HEAP32[$3>>2] = $25;
   ;HEAP32[$$byval_copy>>2]=HEAP32[$3>>2]|0;
   (__ZNSt3__26vectorIPN3osg4NodeENS_9allocatorIS3_EEE6insertENS_11__wrap_iterIPKS3_EERS8_($16,$$byval_copy,$2)|0);
  } else {
   $18 = ((($1)) + 32|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ((($1)) + 36|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = ($19|0)==($21|0);
   if ($22) {
    __ZNSt3__26vectorIPN3osg4NodeENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_($16,$2);
    break;
   } else {
    HEAP32[$19>>2] = $17;
    $23 = HEAP32[$18>>2]|0;
    $24 = ((($23)) + 4|0);
    HEAP32[$18>>2] = $24;
    break;
   }
  }
 } while(0);
 $26 = HEAP32[$1>>2]|0;
 $27 = ((($26)) + 152|0);
 $28 = HEAP32[$27>>2]|0;
 FUNCTION_TABLE_vii[$28 & 8191]($1,$0);
 $29 = HEAP32[$13>>2]|0;
 $30 = ($29|0)==(1);
 do {
  if ($30) {
   $34 = ((($1)) + 28|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ((($35)) + 4|0);
   $37 = ((($1)) + 32|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = $36;
   $40 = (($38) - ($39))|0;
   $41 = $40 >> 2;
   $42 = ($41|0)==(0);
   $43 = $38;
   if ($42) {
    $45 = $43;
   } else {
    _memmove(($35|0),($36|0),($40|0))|0;
    $$pre$i$i = HEAP32[$37>>2]|0;
    $45 = $$pre$i$i;
   }
   $44 = (($35) + ($41<<2)|0);
   $46 = ($45|0)==($44|0);
   if ($46) {
    STACKTOP = sp;return;
   } else {
    $scevgep$i$i$i$i = ((($45)) + -4|0);
    $47 = $scevgep$i$i$i$i;
    $48 = $44;
    $49 = (($47) - ($48))|0;
    $50 = $49 >>> 2;
    $51 = $50 ^ -1;
    $scevgep5$i$i$i$i = (($45) + ($51<<2)|0);
    $$sink$i = $37;$scevgep5$i$i$i$sink$i = $scevgep5$i$i$i$i;
    break;
   }
  } else {
   $31 = ((($1)) + 32|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ((($32)) + -4|0);
   $$sink$i = $31;$scevgep5$i$i$i$sink$i = $33;
  }
 } while(0);
 HEAP32[$$sink$i>>2] = $scevgep5$i$i$i$sink$i;
 STACKTOP = sp;return;
}
function __ZN3osg9Transform17asMatrixTransformEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZNK3osg9Transform17asMatrixTransformEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZN3osg9Transform27asPositionAttitudeTransformEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZNK3osg9Transform27asPositionAttitudeTransformEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZN3osg9Transform15asAutoTransformEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZNK3osg9Transform15asAutoTransformEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZNK3osg6Camera25computeLocalToWorldMatrixERNS_7MatrixdEPNS_11NodeVisitorE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0.0, $13 = 0, $14 = 0.0, $15 = 0, $16 = 0, $17 = 0.0, $18 = 0, $19 = 0, $20 = 0.0, $21 = 0, $22 = 0, $23 = 0.0, $24 = 0, $25 = 0, $26 = 0.0, $27 = 0, $28 = 0, $29 = 0.0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0.0, $33 = 0, $34 = 0, $35 = 0.0, $36 = 0, $37 = 0, $38 = 0.0, $39 = 0, $4 = 0, $40 = 0, $41 = 0.0, $42 = 0, $43 = 0, $44 = 0.0, $45 = 0, $46 = 0, $47 = 0.0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0.0, $51 = 0, $52 = 0, $53 = 0.0, $54 = 0, $55 = 0, $56 = 0.0, $57 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 136|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 if (!($5)) {
  $10 = ((($0)) + 432|0);
  $11 = ($10|0)==($1|0);
  if ($11) {
   return 1;
  }
  $12 = +HEAPF64[$10>>3];
  HEAPF64[$1>>3] = $12;
  $13 = ((($0)) + 440|0);
  $14 = +HEAPF64[$13>>3];
  $15 = ((($1)) + 8|0);
  HEAPF64[$15>>3] = $14;
  $16 = ((($0)) + 448|0);
  $17 = +HEAPF64[$16>>3];
  $18 = ((($1)) + 16|0);
  HEAPF64[$18>>3] = $17;
  $19 = ((($0)) + 456|0);
  $20 = +HEAPF64[$19>>3];
  $21 = ((($1)) + 24|0);
  HEAPF64[$21>>3] = $20;
  $22 = ((($0)) + 464|0);
  $23 = +HEAPF64[$22>>3];
  $24 = ((($1)) + 32|0);
  HEAPF64[$24>>3] = $23;
  $25 = ((($0)) + 472|0);
  $26 = +HEAPF64[$25>>3];
  $27 = ((($1)) + 40|0);
  HEAPF64[$27>>3] = $26;
  $28 = ((($0)) + 480|0);
  $29 = +HEAPF64[$28>>3];
  $30 = ((($1)) + 48|0);
  HEAPF64[$30>>3] = $29;
  $31 = ((($0)) + 488|0);
  $32 = +HEAPF64[$31>>3];
  $33 = ((($1)) + 56|0);
  HEAPF64[$33>>3] = $32;
  $34 = ((($0)) + 496|0);
  $35 = +HEAPF64[$34>>3];
  $36 = ((($1)) + 64|0);
  HEAPF64[$36>>3] = $35;
  $37 = ((($0)) + 504|0);
  $38 = +HEAPF64[$37>>3];
  $39 = ((($1)) + 72|0);
  HEAPF64[$39>>3] = $38;
  $40 = ((($0)) + 512|0);
  $41 = +HEAPF64[$40>>3];
  $42 = ((($1)) + 80|0);
  HEAPF64[$42>>3] = $41;
  $43 = ((($0)) + 520|0);
  $44 = +HEAPF64[$43>>3];
  $45 = ((($1)) + 88|0);
  HEAPF64[$45>>3] = $44;
  $46 = ((($0)) + 528|0);
  $47 = +HEAPF64[$46>>3];
  $48 = ((($1)) + 96|0);
  HEAPF64[$48>>3] = $47;
  $49 = ((($0)) + 536|0);
  $50 = +HEAPF64[$49>>3];
  $51 = ((($1)) + 104|0);
  HEAPF64[$51>>3] = $50;
  $52 = ((($0)) + 544|0);
  $53 = +HEAPF64[$52>>3];
  $54 = ((($1)) + 112|0);
  HEAPF64[$54>>3] = $53;
  $55 = ((($0)) + 552|0);
  $56 = +HEAPF64[$55>>3];
  $57 = ((($1)) + 120|0);
  HEAPF64[$57>>3] = $56;
  return 1;
 }
 $6 = ((($0)) + 292|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0);
 $9 = ((($0)) + 432|0);
 if ($8) {
  __ZN3osg7Matrixd7preMultERKS0_($1,$9);
  return 1;
 } else {
  __ZN3osg7Matrixd8postMultERKS0_($1,$9);
  return 1;
 }
 return (0)|0;
}
function __ZNK3osg6Camera25computeWorldToLocalMatrixERNS_7MatrixdEPNS_11NodeVisitorE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0.0, $13 = 0, $14 = 0, $15 = 0.0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0.0, $31 = 0, $32 = 0.0, $33 = 0, $34 = 0, $35 = 0.0, $36 = 0, $37 = 0, $38 = 0.0, $39 = 0, $4 = 0, $40 = 0, $41 = 0.0, $42 = 0, $43 = 0, $44 = 0.0, $45 = 0, $46 = 0, $47 = 0.0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0.0, $51 = 0, $52 = 0, $53 = 0.0, $54 = 0, $55 = 0, $56 = 0.0, $57 = 0, $58 = 0, $59 = 0.0, $6 = 0.0, $60 = 0, $61 = 0, $62 = 0.0, $63 = 0, $64 = 0, $65 = 0.0;
 var $66 = 0, $67 = 0, $68 = 0.0, $69 = 0, $7 = 0, $70 = 0, $71 = 0.0, $72 = 0, $73 = 0, $74 = 0.0, $75 = 0, $8 = 0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(128|0);
 $3 = sp;
 __ZN3osg7Matrixd12makeIdentityEv($3);
 $4 = ((($0)) + 432|0);
 $5 = ((($0)) + 456|0);
 $6 = +HEAPF64[$5>>3];
 $7 = $6 == 0.0;
 if ($7) {
  $8 = ((($0)) + 488|0);
  $9 = +HEAPF64[$8>>3];
  $10 = $9 == 0.0;
  if ($10) {
   $11 = ((($0)) + 520|0);
   $12 = +HEAPF64[$11>>3];
   $13 = $12 == 0.0;
   if ($13) {
    $14 = ((($0)) + 552|0);
    $15 = +HEAPF64[$14>>3];
    $16 = $15 == 1.0;
    if ($16) {
     (__ZN3osg7Matrixd10invert_4x3ERKS0_($3,$4)|0);
    } else {
     label = 6;
    }
   } else {
    label = 6;
   }
  } else {
   label = 6;
  }
 } else {
  label = 6;
 }
 if ((label|0) == 6) {
  (__ZN3osg7Matrixd10invert_4x4ERKS0_($3,$4)|0);
 }
 $17 = ((($0)) + 136|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ($18|0)==(0);
 if (!($19)) {
  $29 = ($3|0)==($1|0);
  if ($29) {
   STACKTOP = sp;return 1;
  }
  $30 = +HEAPF64[$3>>3];
  HEAPF64[$1>>3] = $30;
  $31 = ((($3)) + 8|0);
  $32 = +HEAPF64[$31>>3];
  $33 = ((($1)) + 8|0);
  HEAPF64[$33>>3] = $32;
  $34 = ((($3)) + 16|0);
  $35 = +HEAPF64[$34>>3];
  $36 = ((($1)) + 16|0);
  HEAPF64[$36>>3] = $35;
  $37 = ((($3)) + 24|0);
  $38 = +HEAPF64[$37>>3];
  $39 = ((($1)) + 24|0);
  HEAPF64[$39>>3] = $38;
  $40 = ((($3)) + 32|0);
  $41 = +HEAPF64[$40>>3];
  $42 = ((($1)) + 32|0);
  HEAPF64[$42>>3] = $41;
  $43 = ((($3)) + 40|0);
  $44 = +HEAPF64[$43>>3];
  $45 = ((($1)) + 40|0);
  HEAPF64[$45>>3] = $44;
  $46 = ((($3)) + 48|0);
  $47 = +HEAPF64[$46>>3];
  $48 = ((($1)) + 48|0);
  HEAPF64[$48>>3] = $47;
  $49 = ((($3)) + 56|0);
  $50 = +HEAPF64[$49>>3];
  $51 = ((($1)) + 56|0);
  HEAPF64[$51>>3] = $50;
  $52 = ((($3)) + 64|0);
  $53 = +HEAPF64[$52>>3];
  $54 = ((($1)) + 64|0);
  HEAPF64[$54>>3] = $53;
  $55 = ((($3)) + 72|0);
  $56 = +HEAPF64[$55>>3];
  $57 = ((($1)) + 72|0);
  HEAPF64[$57>>3] = $56;
  $58 = ((($3)) + 80|0);
  $59 = +HEAPF64[$58>>3];
  $60 = ((($1)) + 80|0);
  HEAPF64[$60>>3] = $59;
  $61 = ((($3)) + 88|0);
  $62 = +HEAPF64[$61>>3];
  $63 = ((($1)) + 88|0);
  HEAPF64[$63>>3] = $62;
  $64 = ((($3)) + 96|0);
  $65 = +HEAPF64[$64>>3];
  $66 = ((($1)) + 96|0);
  HEAPF64[$66>>3] = $65;
  $67 = ((($3)) + 104|0);
  $68 = +HEAPF64[$67>>3];
  $69 = ((($1)) + 104|0);
  HEAPF64[$69>>3] = $68;
  $70 = ((($3)) + 112|0);
  $71 = +HEAPF64[$70>>3];
  $72 = ((($1)) + 112|0);
  HEAPF64[$72>>3] = $71;
  $73 = ((($3)) + 120|0);
  $74 = +HEAPF64[$73>>3];
  $75 = ((($1)) + 120|0);
  HEAPF64[$75>>3] = $74;
  STACKTOP = sp;return 1;
 }
 $20 = ((($0)) + 292|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0);
 if ($22) {
  __THREW__ = 0;
  invoke_vii(3302,($1|0),($3|0));
  $23 = __THREW__; __THREW__ = 0;
  $24 = $23&1;
  if ($24) {
   $25 = ___cxa_find_matching_catch_2()|0;
   $26 = tempRet0;
   ___resumeException($25|0);
   // unreachable;
  } else {
   STACKTOP = sp;return 1;
  }
 } else {
  __THREW__ = 0;
  invoke_vii(3546,($1|0),($3|0));
  $27 = __THREW__; __THREW__ = 0;
  $28 = $27&1;
  if ($28) {
   $25 = ___cxa_find_matching_catch_2()|0;
   $26 = tempRet0;
   ___resumeException($25|0);
   // unreachable;
  } else {
   STACKTOP = sp;return 1;
  }
 }
 return (0)|0;
}
function __ZN3osg6Camera19inheritCullSettingsERKNS_12CullSettingsEj($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 144|0);
 __ZN3osg12CullSettings19inheritCullSettingsERKS0_j($3,$1,$2);
 $4 = (___dynamic_cast($1,24432,23304,144)|0);
 $5 = ($4|0)==(0|0);
 if ($5) {
  return;
 }
 $6 = $2 & 8192;
 $7 = ($6|0)==(0);
 if (!($7)) {
  $8 = ((($4)) + 240|0);
  $9 = ((($0)) + 240|0);
  ;HEAP32[$9>>2]=HEAP32[$8>>2]|0;HEAP32[$9+4>>2]=HEAP32[$8+4>>2]|0;HEAP32[$9+8>>2]=HEAP32[$8+8>>2]|0;HEAP32[$9+12>>2]=HEAP32[$8+12>>2]|0;
 }
 $10 = $2 & 16384;
 $11 = ($10|0)==(0);
 if (!($11)) {
  $12 = ((($4)) + 236|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ((($0)) + 236|0);
  HEAP32[$14>>2] = $13;
 }
 $15 = $2 & 131072;
 $16 = ($15|0)==(0);
 if (!($16)) {
  $17 = ((($4)) + 568|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = ((($0)) + 568|0);
  HEAP32[$19>>2] = $18;
 }
 $20 = $2 & 262144;
 $21 = ($20|0)==(0);
 if ($21) {
  return;
 }
 $22 = ((($4)) + 572|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ((($0)) + 572|0);
 HEAP32[$24>>2] = $23;
 return;
}
function __ZThn144_N3osg6CameraD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -144|0);
 __ZN3osg6CameraD2Ev($1);
 return;
}
function __ZThn144_N3osg6CameraD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -144|0);
 __THREW__ = 0;
 invoke_vi(1478,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch_2()|0;
  $5 = tempRet0;
  __ZdlPv($1);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZdlPv($1);
  return;
 }
}
function __ZThn144_N3osg6Camera19inheritCullSettingsERKNS_12CullSettingsEj($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + -144|0);
 $4 = ($0);
 __ZN3osg12CullSettings19inheritCullSettingsERKS0_j($4,$1,$2);
 $5 = (___dynamic_cast($1,24432,23304,144)|0);
 $6 = ($5|0)==(0|0);
 if ($6) {
  return;
 }
 $7 = $2 & 8192;
 $8 = ($7|0)==(0);
 if (!($8)) {
  $9 = ((($5)) + 240|0);
  $10 = ((($0)) + 96|0);
  ;HEAP32[$10>>2]=HEAP32[$9>>2]|0;HEAP32[$10+4>>2]=HEAP32[$9+4>>2]|0;HEAP32[$10+8>>2]=HEAP32[$9+8>>2]|0;HEAP32[$10+12>>2]=HEAP32[$9+12>>2]|0;
 }
 $11 = $2 & 16384;
 $12 = ($11|0)==(0);
 if (!($12)) {
  $13 = ((($5)) + 236|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = ((($3)) + 236|0);
  HEAP32[$15>>2] = $14;
 }
 $16 = $2 & 131072;
 $17 = ($16|0)==(0);
 if (!($17)) {
  $18 = ((($5)) + 568|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = ((($0)) + 424|0);
  HEAP32[$20>>2] = $19;
 }
 $21 = $2 & 262144;
 $22 = ($21|0)==(0);
 if ($22) {
  return;
 }
 $23 = ((($5)) + 572|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ((($3)) + 572|0);
 HEAP32[$25>>2] = $24;
 return;
}
function __ZN3osg6CameraC2ERKS0_RKNS_6CopyOpE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i$i = 0, $$10 = 0, $$1044 = 0, $$11 = 0, $$1145 = 0, $$4 = 0, $$438 = 0, $$byval_copy = 0, $$pre$i$i$i$i$i$i = 0, $$sroa$07$0$i = 0, $10 = 0, $100 = 0.0, $101 = 0, $102 = 0, $103 = 0.0, $104 = 0, $105 = 0, $106 = 0.0, $107 = 0;
 var $108 = 0, $109 = 0.0, $11 = 0, $110 = 0, $111 = 0, $112 = 0.0, $113 = 0, $114 = 0, $115 = 0.0, $116 = 0, $117 = 0, $118 = 0.0, $119 = 0, $12 = 0, $120 = 0, $121 = 0.0, $122 = 0, $123 = 0, $124 = 0.0, $125 = 0;
 var $126 = 0, $127 = 0.0, $128 = 0, $129 = 0, $13 = 0, $130 = 0.0, $131 = 0, $132 = 0, $133 = 0.0, $134 = 0, $135 = 0, $136 = 0.0, $137 = 0, $138 = 0, $139 = 0.0, $14 = 0, $140 = 0, $141 = 0, $142 = 0.0, $143 = 0;
 var $144 = 0, $145 = 0.0, $146 = 0, $147 = 0, $148 = 0.0, $149 = 0, $15 = 0, $150 = 0, $151 = 0.0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0;
 var $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0;
 var $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0;
 var $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0;
 var $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0;
 var $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0;
 var $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0;
 var $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0;
 var $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0;
 var $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0;
 var $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $35 = 0.0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0.0, $59 = 0, $6 = 0, $60 = 0, $61 = 0.0, $62 = 0, $63 = 0, $64 = 0.0, $65 = 0, $66 = 0, $67 = 0.0, $68 = 0, $69 = 0, $7 = 0, $70 = 0.0, $71 = 0, $72 = 0;
 var $73 = 0.0, $74 = 0, $75 = 0, $76 = 0.0, $77 = 0, $78 = 0, $79 = 0.0, $8 = 0, $80 = 0, $81 = 0, $82 = 0.0, $83 = 0, $84 = 0, $85 = 0.0, $86 = 0, $87 = 0, $88 = 0.0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0.0, $92 = 0, $93 = 0, $94 = 0.0, $95 = 0, $96 = 0, $97 = 0.0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy = sp + 12|0;
 $3 = sp + 8|0;
 $4 = sp + 4|0;
 $5 = sp;
 __ZN3osg9TransformC2ERKS0_RKNS_6CopyOpE($0,$1,$2);
 $6 = ((($0)) + 144|0);
 $7 = ((($1)) + 144|0);
 __THREW__ = 0;
 invoke_vii(3609,($6|0),($7|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $289 = ___cxa_find_matching_catch_2()|0;
  $290 = tempRet0;
  $$11 = $290;$$1145 = $289;
 } else {
  HEAP32[$0>>2] = (56344);
  HEAP32[$6>>2] = (56628);
  $10 = ((($0)) + 208|0);
  __THREW__ = 0;
  invoke_vii(3507,($10|0),0);
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if ($12) {
   $291 = ___cxa_find_matching_catch_2()|0;
   $292 = tempRet0;
   $$10 = $292;$$1044 = $291;
  } else {
   $13 = ((($0)) + 220|0);
   $14 = ((($1)) + 220|0);
   $15 = HEAP32[$14>>2]|0;
   HEAP32[$13>>2] = $15;
   $16 = ((($0)) + 224|0);
   HEAP32[$16>>2] = 0;
   $17 = ((($0)) + 228|0);
   $18 = ((($1)) + 228|0);
   $19 = HEAP8[$18>>0]|0;
   HEAP8[$17>>0] = $19;
   $20 = ((($0)) + 232|0);
   $21 = ((($1)) + 232|0);
   $22 = HEAP32[$21>>2]|0;
   HEAP32[$20>>2] = $22;
   $23 = ($22|0)==(0|0);
   if (!($23)) {
    $24 = ((($22)) + 8|0);
    $25 = HEAP32[$24>>2]|0;HEAP32[$24>>2] = (($25+1)|0);
   }
   $26 = ((($0)) + 236|0);
   $27 = ((($1)) + 236|0);
   $28 = HEAP32[$27>>2]|0;
   HEAP32[$26>>2] = $28;
   $29 = ((($0)) + 240|0);
   $30 = ((($1)) + 240|0);
   ;HEAP32[$29>>2]=HEAP32[$30>>2]|0;HEAP32[$29+4>>2]=HEAP32[$30+4>>2]|0;HEAP32[$29+8>>2]=HEAP32[$30+8>>2]|0;HEAP32[$29+12>>2]=HEAP32[$30+12>>2]|0;
   $31 = ((($0)) + 256|0);
   $32 = ((($1)) + 256|0);
   ;HEAP32[$31>>2]=HEAP32[$32>>2]|0;HEAP32[$31+4>>2]=HEAP32[$32+4>>2]|0;HEAP32[$31+8>>2]=HEAP32[$32+8>>2]|0;HEAP32[$31+12>>2]=HEAP32[$32+12>>2]|0;
   $33 = ((($0)) + 272|0);
   $34 = ((($1)) + 272|0);
   $35 = +HEAPF64[$34>>3];
   HEAPF64[$33>>3] = $35;
   $36 = ((($0)) + 280|0);
   $37 = ((($1)) + 280|0);
   $38 = HEAP32[$37>>2]|0;
   HEAP32[$36>>2] = $38;
   $39 = ((($0)) + 284|0);
   $40 = ((($1)) + 284|0);
   $41 = HEAP32[$40>>2]|0;
   HEAP32[$39>>2] = $41;
   $42 = ($41|0)==(0|0);
   if (!($42)) {
    $43 = ((($41)) + 8|0);
    $44 = HEAP32[$43>>2]|0;HEAP32[$43>>2] = (($44+1)|0);
   }
   $45 = ((($0)) + 288|0);
   $46 = ((($1)) + 288|0);
   $47 = HEAP32[$46>>2]|0;
   HEAP32[$45>>2] = $47;
   $48 = ($47|0)==(0|0);
   if (!($48)) {
    $49 = ((($47)) + 8|0);
    $50 = HEAP32[$49>>2]|0;HEAP32[$49>>2] = (($50+1)|0);
   }
   $51 = ((($0)) + 292|0);
   $52 = ((($1)) + 292|0);
   $53 = HEAP32[$52>>2]|0;
   HEAP32[$51>>2] = $53;
   $54 = ((($0)) + 296|0);
   $55 = ((($1)) + 296|0);
   $56 = HEAP32[$55>>2]|0;
   HEAP32[$54>>2] = $56;
   $57 = ((($1)) + 304|0);
   $58 = +HEAPF64[$57>>3];
   $59 = ((($0)) + 304|0);
   HEAPF64[$59>>3] = $58;
   $60 = ((($1)) + 312|0);
   $61 = +HEAPF64[$60>>3];
   $62 = ((($0)) + 312|0);
   HEAPF64[$62>>3] = $61;
   $63 = ((($1)) + 320|0);
   $64 = +HEAPF64[$63>>3];
   $65 = ((($0)) + 320|0);
   HEAPF64[$65>>3] = $64;
   $66 = ((($1)) + 328|0);
   $67 = +HEAPF64[$66>>3];
   $68 = ((($0)) + 328|0);
   HEAPF64[$68>>3] = $67;
   $69 = ((($1)) + 336|0);
   $70 = +HEAPF64[$69>>3];
   $71 = ((($0)) + 336|0);
   HEAPF64[$71>>3] = $70;
   $72 = ((($1)) + 344|0);
   $73 = +HEAPF64[$72>>3];
   $74 = ((($0)) + 344|0);
   HEAPF64[$74>>3] = $73;
   $75 = ((($1)) + 352|0);
   $76 = +HEAPF64[$75>>3];
   $77 = ((($0)) + 352|0);
   HEAPF64[$77>>3] = $76;
   $78 = ((($1)) + 360|0);
   $79 = +HEAPF64[$78>>3];
   $80 = ((($0)) + 360|0);
   HEAPF64[$80>>3] = $79;
   $81 = ((($1)) + 368|0);
   $82 = +HEAPF64[$81>>3];
   $83 = ((($0)) + 368|0);
   HEAPF64[$83>>3] = $82;
   $84 = ((($1)) + 376|0);
   $85 = +HEAPF64[$84>>3];
   $86 = ((($0)) + 376|0);
   HEAPF64[$86>>3] = $85;
   $87 = ((($1)) + 384|0);
   $88 = +HEAPF64[$87>>3];
   $89 = ((($0)) + 384|0);
   HEAPF64[$89>>3] = $88;
   $90 = ((($1)) + 392|0);
   $91 = +HEAPF64[$90>>3];
   $92 = ((($0)) + 392|0);
   HEAPF64[$92>>3] = $91;
   $93 = ((($1)) + 400|0);
   $94 = +HEAPF64[$93>>3];
   $95 = ((($0)) + 400|0);
   HEAPF64[$95>>3] = $94;
   $96 = ((($1)) + 408|0);
   $97 = +HEAPF64[$96>>3];
   $98 = ((($0)) + 408|0);
   HEAPF64[$98>>3] = $97;
   $99 = ((($1)) + 416|0);
   $100 = +HEAPF64[$99>>3];
   $101 = ((($0)) + 416|0);
   HEAPF64[$101>>3] = $100;
   $102 = ((($1)) + 424|0);
   $103 = +HEAPF64[$102>>3];
   $104 = ((($0)) + 424|0);
   HEAPF64[$104>>3] = $103;
   $105 = ((($1)) + 432|0);
   $106 = +HEAPF64[$105>>3];
   $107 = ((($0)) + 432|0);
   HEAPF64[$107>>3] = $106;
   $108 = ((($1)) + 440|0);
   $109 = +HEAPF64[$108>>3];
   $110 = ((($0)) + 440|0);
   HEAPF64[$110>>3] = $109;
   $111 = ((($1)) + 448|0);
   $112 = +HEAPF64[$111>>3];
   $113 = ((($0)) + 448|0);
   HEAPF64[$113>>3] = $112;
   $114 = ((($1)) + 456|0);
   $115 = +HEAPF64[$114>>3];
   $116 = ((($0)) + 456|0);
   HEAPF64[$116>>3] = $115;
   $117 = ((($1)) + 464|0);
   $118 = +HEAPF64[$117>>3];
   $119 = ((($0)) + 464|0);
   HEAPF64[$119>>3] = $118;
   $120 = ((($1)) + 472|0);
   $121 = +HEAPF64[$120>>3];
   $122 = ((($0)) + 472|0);
   HEAPF64[$122>>3] = $121;
   $123 = ((($1)) + 480|0);
   $124 = +HEAPF64[$123>>3];
   $125 = ((($0)) + 480|0);
   HEAPF64[$125>>3] = $124;
   $126 = ((($1)) + 488|0);
   $127 = +HEAPF64[$126>>3];
   $128 = ((($0)) + 488|0);
   HEAPF64[$128>>3] = $127;
   $129 = ((($1)) + 496|0);
   $130 = +HEAPF64[$129>>3];
   $131 = ((($0)) + 496|0);
   HEAPF64[$131>>3] = $130;
   $132 = ((($1)) + 504|0);
   $133 = +HEAPF64[$132>>3];
   $134 = ((($0)) + 504|0);
   HEAPF64[$134>>3] = $133;
   $135 = ((($1)) + 512|0);
   $136 = +HEAPF64[$135>>3];
   $137 = ((($0)) + 512|0);
   HEAPF64[$137>>3] = $136;
   $138 = ((($1)) + 520|0);
   $139 = +HEAPF64[$138>>3];
   $140 = ((($0)) + 520|0);
   HEAPF64[$140>>3] = $139;
   $141 = ((($1)) + 528|0);
   $142 = +HEAPF64[$141>>3];
   $143 = ((($0)) + 528|0);
   HEAPF64[$143>>3] = $142;
   $144 = ((($1)) + 536|0);
   $145 = +HEAPF64[$144>>3];
   $146 = ((($0)) + 536|0);
   HEAPF64[$146>>3] = $145;
   $147 = ((($1)) + 544|0);
   $148 = +HEAPF64[$147>>3];
   $149 = ((($0)) + 544|0);
   HEAPF64[$149>>3] = $148;
   $150 = ((($1)) + 552|0);
   $151 = +HEAPF64[$150>>3];
   $152 = ((($0)) + 552|0);
   HEAPF64[$152>>3] = $151;
   $153 = ((($0)) + 560|0);
   $154 = ((($1)) + 560|0);
   $155 = HEAP32[$154>>2]|0;
   HEAP32[$153>>2] = $155;
   $156 = ((($0)) + 564|0);
   $157 = ((($1)) + 564|0);
   $158 = HEAP32[$157>>2]|0;
   HEAP32[$156>>2] = $158;
   $159 = ((($0)) + 568|0);
   $160 = ((($1)) + 568|0);
   $161 = HEAP32[$160>>2]|0;
   HEAP32[$159>>2] = $161;
   $162 = ((($0)) + 572|0);
   $163 = ((($1)) + 572|0);
   $164 = HEAP32[$163>>2]|0;
   HEAP32[$162>>2] = $164;
   $165 = ((($0)) + 576|0);
   $166 = ((($1)) + 576|0);
   $167 = HEAP32[$166>>2]|0;
   HEAP32[$165>>2] = $167;
   $168 = ((($0)) + 580|0);
   $169 = ((($1)) + 580|0);
   $170 = HEAP32[$169>>2]|0;
   HEAP32[$168>>2] = $170;
   $171 = ((($0)) + 584|0);
   $172 = ((($0)) + 588|0);
   HEAP32[$172>>2] = 0;
   $173 = ((($0)) + 592|0);
   HEAP32[$173>>2] = 0;
   $174 = ((($0)) + 588|0);
   HEAP32[$171>>2] = $174;
   $175 = ((($1)) + 584|0);
   $176 = HEAP32[$175>>2]|0;
   $177 = ((($1)) + 588|0);
   $178 = ($176|0)==($177|0);
   L16: do {
    if ($178) {
     label = 27;
    } else {
     $179 = $174;
     $$sroa$07$0$i = $176;
     while(1) {
      $180 = ((($$sroa$07$0$i)) + 16|0);
      HEAP32[$5>>2] = $179;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy>>2]=HEAP32[$5>>2]|0;
      $181 = (invoke_iiiiii(3723,($171|0),($$byval_copy|0),($3|0),($4|0),($180|0))|0);
      $182 = __THREW__; __THREW__ = 0;
      $183 = $182&1;
      if ($183) {
       break;
      }
      $184 = HEAP32[$181>>2]|0;
      $185 = ($184|0)==(0|0);
      if ($185) {
       __THREW__ = 0;
       $186 = (invoke_ii(3276,52)|0);
       $187 = __THREW__; __THREW__ = 0;
       $188 = $187&1;
       if ($188) {
        break;
       }
       $189 = ((($186)) + 16|0);
       $190 = HEAP32[$180>>2]|0;
       HEAP32[$189>>2] = $190;
       $191 = ((($186)) + 20|0);
       $192 = ((($$sroa$07$0$i)) + 20|0);
       $193 = HEAP32[$192>>2]|0;
       HEAP32[$191>>2] = $193;
       $194 = ((($186)) + 24|0);
       $195 = ((($$sroa$07$0$i)) + 24|0);
       $196 = HEAP32[$195>>2]|0;
       HEAP32[$194>>2] = $196;
       $197 = ($196|0)==(0|0);
       if (!($197)) {
        $198 = ((($196)) + 8|0);
        $199 = HEAP32[$198>>2]|0;HEAP32[$198>>2] = (($199+1)|0);
       }
       $200 = ((($186)) + 28|0);
       $201 = ((($$sroa$07$0$i)) + 28|0);
       $202 = HEAP32[$201>>2]|0;
       HEAP32[$200>>2] = $202;
       $203 = ($202|0)==(0|0);
       if (!($203)) {
        $204 = ((($202)) + 8|0);
        $205 = HEAP32[$204>>2]|0;HEAP32[$204>>2] = (($205+1)|0);
       }
       $206 = ((($186)) + 32|0);
       $207 = ((($$sroa$07$0$i)) + 32|0);
       ;HEAP32[$206>>2]=HEAP32[$207>>2]|0;HEAP32[$206+4>>2]=HEAP32[$207+4>>2]|0;HEAP32[$206+8>>2]=HEAP32[$207+8>>2]|0;HEAP32[$206+12>>2]=HEAP32[$207+12>>2]|0;HEAP32[$206+16>>2]=HEAP32[$207+16>>2]|0;
       $208 = HEAP32[$3>>2]|0;
       HEAP32[$186>>2] = 0;
       $209 = ((($186)) + 4|0);
       HEAP32[$209>>2] = 0;
       $210 = ((($186)) + 8|0);
       HEAP32[$210>>2] = $208;
       HEAP32[$181>>2] = $186;
       $211 = HEAP32[$171>>2]|0;
       $212 = HEAP32[$211>>2]|0;
       $213 = ($212|0)==(0|0);
       if ($213) {
        $216 = $186;
       } else {
        $214 = $212;
        HEAP32[$171>>2] = $214;
        $$pre$i$i$i$i$i$i = HEAP32[$181>>2]|0;
        $216 = $$pre$i$i$i$i$i$i;
       }
       $215 = HEAP32[$172>>2]|0;
       __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($215,$216);
       $217 = HEAP32[$173>>2]|0;
       $218 = (($217) + 1)|0;
       HEAP32[$173>>2] = $218;
      }
      $219 = ((($$sroa$07$0$i)) + 4|0);
      $220 = HEAP32[$219>>2]|0;
      $221 = ($220|0)==(0|0);
      if ($221) {
       $222 = ((($$sroa$07$0$i)) + 8|0);
       $223 = HEAP32[$222>>2]|0;
       $224 = HEAP32[$223>>2]|0;
       $225 = ($224|0)==($$sroa$07$0$i|0);
       if ($225) {
        $$0$i$i$i$i$i = $223;
       } else {
        $229 = $222;
        while(1) {
         $228 = HEAP32[$229>>2]|0;
         $230 = ((($228)) + 8|0);
         $231 = HEAP32[$230>>2]|0;
         $232 = HEAP32[$231>>2]|0;
         $233 = ($232|0)==($228|0);
         if ($233) {
          $$0$i$i$i$i$i = $231;
          break;
         } else {
          $229 = $230;
         }
        }
       }
      } else {
       $$0$i$i$i$i$i$i = $220;
       while(1) {
        $226 = HEAP32[$$0$i$i$i$i$i$i>>2]|0;
        $227 = ($226|0)==(0|0);
        if ($227) {
         break;
        } else {
         $$0$i$i$i$i$i$i = $226;
        }
       }
       $$0$i$i$i$i$i = $$0$i$i$i$i$i$i;
      }
      $234 = ($$0$i$i$i$i$i|0)==($177|0);
      if ($234) {
       label = 27;
       break L16;
      } else {
       $$sroa$07$0$i = $$0$i$i$i$i$i;
      }
     }
     $293 = ___cxa_find_matching_catch_2()|0;
     $294 = tempRet0;
     $295 = HEAP32[$174>>2]|0;
     __ZNSt3__26__treeINS_12__value_typeIN3osg6Camera15BufferComponentENS3_10AttachmentEEENS_19__map_value_compareIS4_S6_NS_4lessIS4_EELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($171,$295);
     $$4 = $294;$$438 = $293;
    }
   } while(0);
   do {
    if ((label|0) == 27) {
     $235 = ((($0)) + 596|0);
     $236 = ((($1)) + 596|0);
     $237 = HEAP32[$236>>2]|0;
     HEAP32[$235>>2] = $237;
     $238 = ((($0)) + 600|0);
     $239 = ((($1)) + 600|0);
     $240 = HEAP32[$239>>2]|0;
     HEAP32[$238>>2] = $240;
     $241 = ((($0)) + 604|0);
     $242 = ((($1)) + 604|0);
     $243 = HEAP32[$242>>2]|0;
     HEAP32[$241>>2] = $243;
     $244 = ((($0)) + 608|0);
     $245 = ((($1)) + 608|0);
     __THREW__ = 0;
     invoke_vii(3724,($244|0),($245|0));
     $246 = __THREW__; __THREW__ = 0;
     $247 = $246&1;
     if ($247) {
      $296 = ___cxa_find_matching_catch_2()|0;
      $297 = tempRet0;
      $298 = HEAP32[$174>>2]|0;
      __ZNSt3__26__treeINS_12__value_typeIN3osg6Camera15BufferComponentENS3_10AttachmentEEENS_19__map_value_compareIS4_S6_NS_4lessIS4_EELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($171,$298);
      $$4 = $297;$$438 = $296;
      break;
     }
     $248 = ((($0)) + 620|0);
     $249 = ((($0)) + 636|0);
     $250 = ((($1)) + 636|0);
     ;HEAP32[$248>>2]=0|0;HEAP32[$248+4>>2]=0|0;HEAP32[$248+8>>2]=0|0;HEAP32[$248+12>>2]=0|0;
     $251 = HEAP32[$250>>2]|0;
     HEAP32[$249>>2] = $251;
     $252 = ($251|0)==(0|0);
     if (!($252)) {
      $253 = HEAP32[$251>>2]|0;
      $254 = ((($253)) + -12|0);
      $255 = HEAP32[$254>>2]|0;
      $256 = (($251) + ($255)|0);
      $257 = ((($256)) + 8|0);
      $258 = HEAP32[$257>>2]|0;HEAP32[$257>>2] = (($258+1)|0);
     }
     $259 = ((($0)) + 640|0);
     $260 = ((($1)) + 640|0);
     $261 = HEAP32[$260>>2]|0;
     HEAP32[$259>>2] = $261;
     $262 = ($261|0)==(0|0);
     if (!($262)) {
      $263 = HEAP32[$261>>2]|0;
      $264 = ((($263)) + -12|0);
      $265 = HEAP32[$264>>2]|0;
      $266 = (($261) + ($265)|0);
      $267 = ((($266)) + 8|0);
      $268 = HEAP32[$267>>2]|0;HEAP32[$267>>2] = (($268+1)|0);
     }
     $269 = ((($0)) + 644|0);
     $270 = ((($1)) + 644|0);
     $271 = HEAP32[$270>>2]|0;
     HEAP32[$269>>2] = $271;
     $272 = ($271|0)==(0|0);
     if (!($272)) {
      $273 = HEAP32[$271>>2]|0;
      $274 = ((($273)) + -12|0);
      $275 = HEAP32[$274>>2]|0;
      $276 = (($271) + ($275)|0);
      $277 = ((($276)) + 8|0);
      $278 = HEAP32[$277>>2]|0;HEAP32[$277>>2] = (($278+1)|0);
     }
     $279 = ((($0)) + 648|0);
     $280 = ((($1)) + 648|0);
     $281 = HEAP32[$280>>2]|0;
     HEAP32[$279>>2] = $281;
     $282 = ($281|0)==(0|0);
     if ($282) {
      STACKTOP = sp;return;
     }
     $283 = HEAP32[$281>>2]|0;
     $284 = ((($283)) + -12|0);
     $285 = HEAP32[$284>>2]|0;
     $286 = (($281) + ($285)|0);
     $287 = ((($286)) + 8|0);
     $288 = HEAP32[$287>>2]|0;HEAP32[$287>>2] = (($288+1)|0);
     STACKTOP = sp;return;
    }
   } while(0);
   $299 = HEAP32[$45>>2]|0;
   $300 = ($299|0)==(0|0);
   if (!($300)) {
    $301 = ((($299)) + 8|0);
    $302 = HEAP32[$301>>2]|0;HEAP32[$301>>2] = (($302-1)|0);
    $303 = ($302|0)==(1);
    if ($303) {
     __THREW__ = 0;
     invoke_viii(3262,($299|0),1,1);
     $304 = __THREW__; __THREW__ = 0;
     $305 = $304&1;
     if ($305) {
      $339 = ___cxa_find_matching_catch_3(0|0)|0;
      $340 = tempRet0;
      ___clang_call_terminate($339);
      // unreachable;
     }
    }
   }
   HEAP32[$45>>2] = 0;
   $306 = HEAP32[$39>>2]|0;
   $307 = ($306|0)==(0|0);
   if (!($307)) {
    $308 = ((($306)) + 8|0);
    $309 = HEAP32[$308>>2]|0;HEAP32[$308>>2] = (($309-1)|0);
    $310 = ($309|0)==(1);
    if ($310) {
     __THREW__ = 0;
     invoke_viii(3262,($306|0),1,1);
     $311 = __THREW__; __THREW__ = 0;
     $312 = $311&1;
     if ($312) {
      $339 = ___cxa_find_matching_catch_3(0|0)|0;
      $340 = tempRet0;
      ___clang_call_terminate($339);
      // unreachable;
     }
    }
   }
   HEAP32[$39>>2] = 0;
   $313 = HEAP32[$20>>2]|0;
   $314 = ($313|0)==(0|0);
   if (!($314)) {
    $315 = ((($313)) + 8|0);
    $316 = HEAP32[$315>>2]|0;HEAP32[$315>>2] = (($316-1)|0);
    $317 = ($316|0)==(1);
    if ($317) {
     __THREW__ = 0;
     invoke_viii(3262,($313|0),1,1);
     $318 = __THREW__; __THREW__ = 0;
     $319 = $318&1;
     if ($319) {
      $339 = ___cxa_find_matching_catch_3(0|0)|0;
      $340 = tempRet0;
      ___clang_call_terminate($339);
      // unreachable;
     }
    }
   }
   HEAP32[$20>>2] = 0;
   $320 = HEAP32[$16>>2]|0;
   $321 = ($320|0)==(0|0);
   if (!($321)) {
    $322 = ((($320)) + 8|0);
    $323 = HEAP32[$322>>2]|0;HEAP32[$322>>2] = (($323-1)|0);
    $324 = ($323|0)==(1);
    if ($324) {
     __THREW__ = 0;
     invoke_viii(3262,($320|0),1,1);
     $325 = __THREW__; __THREW__ = 0;
     $326 = $325&1;
     if ($326) {
      $339 = ___cxa_find_matching_catch_3(0|0)|0;
      $340 = tempRet0;
      ___clang_call_terminate($339);
      // unreachable;
     }
    }
   }
   HEAP32[$16>>2] = 0;
   __THREW__ = 0;
   invoke_vi(707,($10|0));
   $327 = __THREW__; __THREW__ = 0;
   $328 = $327&1;
   if ($328) {
    $339 = ___cxa_find_matching_catch_3(0|0)|0;
    $340 = tempRet0;
    ___clang_call_terminate($339);
    // unreachable;
   } else {
    $$10 = $$4;$$1044 = $$438;
   }
  }
  HEAP32[$6>>2] = (58232);
  $329 = ((($0)) + 172|0);
  $330 = HEAP32[$329>>2]|0;
  $331 = ($330|0)==(0|0);
  if (!($331)) {
   $332 = ((($330)) + 8|0);
   $333 = HEAP32[$332>>2]|0;HEAP32[$332>>2] = (($333-1)|0);
   $334 = ($333|0)==(1);
   if ($334) {
    __THREW__ = 0;
    invoke_viii(3262,($330|0),1,1);
    $335 = __THREW__; __THREW__ = 0;
    $336 = $335&1;
    if ($336) {
     $339 = ___cxa_find_matching_catch_3(0|0)|0;
     $340 = tempRet0;
     ___clang_call_terminate($339);
     // unreachable;
    }
   }
  }
  HEAP32[$329>>2] = 0;
  $$11 = $$10;$$1145 = $$1044;
 }
 __THREW__ = 0;
 invoke_vi(2366,($0|0));
 $337 = __THREW__; __THREW__ = 0;
 $338 = $337&1;
 if ($338) {
  $339 = ___cxa_find_matching_catch_3(0|0)|0;
  $340 = tempRet0;
  ___clang_call_terminate($339);
  // unreachable;
 } else {
  ___resumeException($$1145|0);
  // unreachable;
 }
}
function __ZNSt3__26__treeINS_12__value_typeIN3osg6Camera15BufferComponentENS3_10AttachmentEEENS_19__map_value_compareIS4_S6_NS_4lessIS4_EELb1EEENS_9allocatorIS6_EEE12__find_equalIS4_EERPNS_16__tree_node_baseIPvEENS_21__tree_const_iteratorIS6_PNS_11__tree_nodeIS6_SG_EEiEERPNS_15__tree_end_nodeISI_EESJ_RKT_($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0$i = 0, $$0$i$i = 0, $$0$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i$i = 0, $$0$i26 = 0, $$0$ph$i = 0, $$0$ph$i23 = 0, $$024$i = 0, $$024$i25 = 0, $$08$i$i = 0, $$2 = 0, $$in$i = 0, $$in$i22 = 0, $$pre = 0, $$sroa$043$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = ((($0)) + 4|0);
 $6 = HEAP32[$1>>2]|0;
 $7 = ($6|0)==($5|0);
 $8 = $6;
 if (!($7)) {
  $9 = ((($6)) + 16|0);
  $10 = HEAP32[$4>>2]|0;
  $11 = HEAP32[$9>>2]|0;
  $12 = ($10|0)<($11|0);
  if (!($12)) {
   $43 = ($11|0)<($10|0);
   if (!($43)) {
    HEAP32[$2>>2] = $8;
    HEAP32[$3>>2] = $8;
    $$2 = $3;
    return ($$2|0);
   }
   $44 = ((($6)) + 4|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = ($45|0)==(0|0);
   if ($46) {
    $47 = ((($6)) + 8|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = HEAP32[$48>>2]|0;
    $50 = ($49|0)==($6|0);
    if ($50) {
     $$0$i$i$i$i$i = $48;
    } else {
     $54 = $47;
     while(1) {
      $53 = HEAP32[$54>>2]|0;
      $55 = ((($53)) + 8|0);
      $56 = HEAP32[$55>>2]|0;
      $57 = HEAP32[$56>>2]|0;
      $58 = ($57|0)==($53|0);
      if ($58) {
       $$0$i$i$i$i$i = $56;
       break;
      } else {
       $54 = $55;
      }
     }
    }
   } else {
    $$0$i$i$i$i$i$i = $45;
    while(1) {
     $51 = HEAP32[$$0$i$i$i$i$i$i>>2]|0;
     $52 = ($51|0)==(0|0);
     if ($52) {
      break;
     } else {
      $$0$i$i$i$i$i$i = $51;
     }
    }
    $$0$i$i$i$i$i = $$0$i$i$i$i$i$i;
   }
   $59 = ($$0$i$i$i$i$i|0)==($5|0);
   if (!($59)) {
    $60 = ((($$0$i$i$i$i$i)) + 16|0);
    $61 = HEAP32[$60>>2]|0;
    $62 = ($10|0)<($61|0);
    if (!($62)) {
     $66 = HEAP32[$5>>2]|0;
     $67 = ($66|0)==(0|0);
     if ($67) {
      HEAP32[$2>>2] = $5;
      $$2 = $5;
      return ($$2|0);
     }
     $68 = ((($0)) + 4|0);
     $$0$i = $68;$$024$i = $66;
     while(1) {
      $69 = ((($$024$i)) + 16|0);
      $70 = HEAP32[$69>>2]|0;
      $71 = ($10|0)<($70|0);
      if ($71) {
       $72 = HEAP32[$$024$i>>2]|0;
       $73 = ($72|0)==(0|0);
       if ($73) {
        label = 39;
        break;
       } else {
        $$0$ph$i = $$024$i;$$in$i = $72;
       }
      } else {
       $74 = ($70|0)<($10|0);
       if (!($74)) {
        label = 43;
        break;
       }
       $75 = ((($$024$i)) + 4|0);
       $76 = HEAP32[$75>>2]|0;
       $77 = ($76|0)==(0|0);
       if ($77) {
        label = 42;
        break;
       } else {
        $$0$ph$i = $75;$$in$i = $76;
       }
      }
      $$0$i = $$0$ph$i;$$024$i = $$in$i;
     }
     if ((label|0) == 39) {
      HEAP32[$2>>2] = $$024$i;
      $$2 = $$024$i;
      return ($$2|0);
     }
     else if ((label|0) == 42) {
      HEAP32[$2>>2] = $$024$i;
      $$2 = $75;
      return ($$2|0);
     }
     else if ((label|0) == 43) {
      HEAP32[$2>>2] = $$024$i;
      $$2 = $$0$i;
      return ($$2|0);
     }
    }
   }
   $63 = ((($6)) + 4|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = ($64|0)==(0|0);
   if ($65) {
    HEAP32[$2>>2] = $8;
    $$2 = $44;
    return ($$2|0);
   } else {
    HEAP32[$2>>2] = $$0$i$i$i$i$i;
    $$2 = $$0$i$i$i$i$i;
    return ($$2|0);
   }
  }
 }
 $13 = HEAP32[$0>>2]|0;
 $14 = ($6|0)==($13|0);
 $$pre = HEAP32[$6>>2]|0;
 if ($14) {
  $$sroa$043$0 = $8;
 } else {
  $15 = ($$pre|0)==(0|0);
  if ($15) {
   $$0$i$i = $6;
   while(1) {
    $19 = ((($$0$i$i)) + 8|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = HEAP32[$20>>2]|0;
    $22 = ($21|0)==($$0$i$i|0);
    if ($22) {
     $$0$i$i = $20;
    } else {
     $$08$i$i = $20;
     break;
    }
   }
  } else {
   $$0$i$i$i = $$pre;
   while(1) {
    $16 = ((($$0$i$i$i)) + 4|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = ($17|0)==(0|0);
    if ($18) {
     $$08$i$i = $$0$i$i$i;
     break;
    } else {
     $$0$i$i$i = $17;
    }
   }
  }
  $23 = $$08$i$i;
  $24 = ((($$08$i$i)) + 16|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = HEAP32[$4>>2]|0;
  $27 = ($25|0)<($26|0);
  if ($27) {
   $$sroa$043$0 = $23;
  } else {
   $31 = HEAP32[$5>>2]|0;
   $32 = ($31|0)==(0|0);
   if ($32) {
    HEAP32[$2>>2] = $5;
    $$2 = $5;
    return ($$2|0);
   }
   $33 = ((($0)) + 4|0);
   $$0$i26 = $33;$$024$i25 = $31;
   while(1) {
    $34 = ((($$024$i25)) + 16|0);
    $35 = HEAP32[$34>>2]|0;
    $36 = ($26|0)<($35|0);
    if ($36) {
     $37 = HEAP32[$$024$i25>>2]|0;
     $38 = ($37|0)==(0|0);
     if ($38) {
      label = 17;
      break;
     } else {
      $$0$ph$i23 = $$024$i25;$$in$i22 = $37;
     }
    } else {
     $39 = ($35|0)<($26|0);
     if (!($39)) {
      label = 21;
      break;
     }
     $40 = ((($$024$i25)) + 4|0);
     $41 = HEAP32[$40>>2]|0;
     $42 = ($41|0)==(0|0);
     if ($42) {
      label = 20;
      break;
     } else {
      $$0$ph$i23 = $40;$$in$i22 = $41;
     }
    }
    $$0$i26 = $$0$ph$i23;$$024$i25 = $$in$i22;
   }
   if ((label|0) == 17) {
    HEAP32[$2>>2] = $$024$i25;
    $$2 = $$024$i25;
    return ($$2|0);
   }
   else if ((label|0) == 20) {
    HEAP32[$2>>2] = $$024$i25;
    $$2 = $40;
    return ($$2|0);
   }
   else if ((label|0) == 21) {
    HEAP32[$2>>2] = $$024$i25;
    $$2 = $$0$i26;
    return ($$2|0);
   }
  }
 }
 $28 = ($$pre|0)==(0|0);
 if ($28) {
  HEAP32[$2>>2] = $6;
  $$2 = $6;
  return ($$2|0);
 } else {
  $29 = $$sroa$043$0;
  HEAP32[$2>>2] = $29;
  $30 = ((($29)) + 4|0);
  $$2 = $30;
  return ($$2|0);
 }
 return (0)|0;
}
function __ZN11OpenThreads8AffinityC2ERKS0_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i$i$i = 0, $$0$i$i$i$i$i = 0, $$byval_copy = 0, $$in5$i$i = 0, $$pre$i$i$i$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy = sp + 12|0;
 $2 = sp + 8|0;
 $3 = sp + 4|0;
 $4 = sp;
 $5 = ((($0)) + 4|0);
 HEAP32[$5>>2] = 0;
 $6 = ((($0)) + 8|0);
 HEAP32[$6>>2] = 0;
 $7 = ((($0)) + 4|0);
 HEAP32[$0>>2] = $7;
 $8 = HEAP32[$1>>2]|0;
 $9 = ((($1)) + 4|0);
 $10 = ($8|0)==($9|0);
 if ($10) {
  STACKTOP = sp;return;
 }
 $11 = $7;
 $$in5$i$i = $8;
 while(1) {
  $12 = ((($$in5$i$i)) + 16|0);
  HEAP32[$4>>2] = $11;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy>>2]=HEAP32[$4>>2]|0;
  $13 = (invoke_iiiiii(3725,($0|0),($$byval_copy|0),($2|0),($3|0),($12|0))|0);
  $14 = __THREW__; __THREW__ = 0;
  $15 = $14&1;
  if ($15) {
   label = 15;
   break;
  }
  $16 = HEAP32[$13>>2]|0;
  $17 = ($16|0)==(0|0);
  if ($17) {
   __THREW__ = 0;
   $18 = (invoke_ii(3276,20)|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if ($20) {
    label = 15;
    break;
   }
   $21 = ((($18)) + 16|0);
   $22 = HEAP32[$12>>2]|0;
   HEAP32[$21>>2] = $22;
   $23 = HEAP32[$2>>2]|0;
   HEAP32[$18>>2] = 0;
   $24 = ((($18)) + 4|0);
   HEAP32[$24>>2] = 0;
   $25 = ((($18)) + 8|0);
   HEAP32[$25>>2] = $23;
   HEAP32[$13>>2] = $18;
   $26 = HEAP32[$0>>2]|0;
   $27 = HEAP32[$26>>2]|0;
   $28 = ($27|0)==(0|0);
   if ($28) {
    $31 = $18;
   } else {
    $29 = $27;
    HEAP32[$0>>2] = $29;
    $$pre$i$i$i$i$i = HEAP32[$13>>2]|0;
    $31 = $$pre$i$i$i$i$i;
   }
   $30 = HEAP32[$5>>2]|0;
   __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($30,$31);
   $32 = HEAP32[$6>>2]|0;
   $33 = (($32) + 1)|0;
   HEAP32[$6>>2] = $33;
  }
  $34 = ((($$in5$i$i)) + 4|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = ($35|0)==(0|0);
  if ($36) {
   $37 = ((($$in5$i$i)) + 8|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = HEAP32[$38>>2]|0;
   $40 = ($39|0)==($$in5$i$i|0);
   if ($40) {
    $$0$i$i$i$i = $38;
   } else {
    $44 = $37;
    while(1) {
     $43 = HEAP32[$44>>2]|0;
     $45 = ((($43)) + 8|0);
     $46 = HEAP32[$45>>2]|0;
     $47 = HEAP32[$46>>2]|0;
     $48 = ($47|0)==($43|0);
     if ($48) {
      $$0$i$i$i$i = $46;
      break;
     } else {
      $44 = $45;
     }
    }
   }
  } else {
   $$0$i$i$i$i$i = $35;
   while(1) {
    $41 = HEAP32[$$0$i$i$i$i$i>>2]|0;
    $42 = ($41|0)==(0|0);
    if ($42) {
     break;
    } else {
     $$0$i$i$i$i$i = $41;
    }
   }
   $$0$i$i$i$i = $$0$i$i$i$i$i;
  }
  $49 = ($$0$i$i$i$i|0)==($9|0);
  if ($49) {
   label = 16;
   break;
  } else {
   $$in5$i$i = $$0$i$i$i$i;
  }
 }
 if ((label|0) == 15) {
  $50 = ___cxa_find_matching_catch_2()|0;
  $51 = tempRet0;
  $52 = HEAP32[$7>>2]|0;
  __ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEE7destroyEPNS_11__tree_nodeIjPvEE($0,$52);
  ___resumeException($50|0);
  // unreachable;
 }
 else if ((label|0) == 16) {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__26__treeINS_12__value_typeIN3osg6Camera15BufferComponentENS3_10AttachmentEEENS_19__map_value_compareIS4_S6_NS_4lessIS4_EELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 }
 $3 = HEAP32[$1>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIN3osg6Camera15BufferComponentENS3_10AttachmentEEENS_19__map_value_compareIS4_S6_NS_4lessIS4_EELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($0,$3);
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIN3osg6Camera15BufferComponentENS3_10AttachmentEEENS_19__map_value_compareIS4_S6_NS_4lessIS4_EELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($0,$5);
 $6 = ((($1)) + 28|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = ((($7)) + 8|0);
  $10 = HEAP32[$9>>2]|0;HEAP32[$9>>2] = (($10-1)|0);
  $11 = ($10|0)==(1);
  if ($11) {
   __THREW__ = 0;
   invoke_viii(3262,($7|0),1,1);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if ($13) {
    $22 = ___cxa_find_matching_catch_2()|0;
    $23 = tempRet0;
    $24 = ((($1)) + 24|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = ($25|0)==(0|0);
    if (!($26)) {
     $27 = ((($25)) + 8|0);
     $28 = HEAP32[$27>>2]|0;HEAP32[$27>>2] = (($28-1)|0);
     $29 = ($28|0)==(1);
     if ($29) {
      __THREW__ = 0;
      invoke_viii(3262,($25|0),1,1);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       $32 = ___cxa_find_matching_catch_3(0|0)|0;
       $33 = tempRet0;
       ___clang_call_terminate($32);
       // unreachable;
      }
     }
    }
    HEAP32[$24>>2] = 0;
    $eh$lpad$body$indexZ2D = $22;
    ___cxa_call_unexpected(($eh$lpad$body$indexZ2D|0));
    // unreachable;
   }
  }
 }
 HEAP32[$6>>2] = 0;
 $14 = ((($1)) + 24|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0|0);
 if (!($16)) {
  $17 = ((($15)) + 8|0);
  $18 = HEAP32[$17>>2]|0;HEAP32[$17>>2] = (($18-1)|0);
  $19 = ($18|0)==(1);
  if ($19) {
   __THREW__ = 0;
   invoke_viii(3262,($15|0),1,1);
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if ($21) {
    $34 = ___cxa_find_matching_catch_2()|0;
    $35 = tempRet0;
    $eh$lpad$body$indexZ2D = $34;
    ___cxa_call_unexpected(($eh$lpad$body$indexZ2D|0));
    // unreachable;
   }
  }
 }
 __ZdlPv($1);
 return;
}
function __ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEE12__find_equalIjEERPNS_16__tree_node_baseIPvEENS_21__tree_const_iteratorIjPNS_11__tree_nodeIjS8_EEiEERPNS_15__tree_end_nodeISA_EESB_RKT_($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0$i = 0, $$0$i$i = 0, $$0$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i$i = 0, $$0$i26 = 0, $$0$ph$i = 0, $$0$ph$i23 = 0, $$024$i = 0, $$024$i25 = 0, $$08$i$i = 0, $$2 = 0, $$in$i = 0, $$in$i22 = 0, $$pre = 0, $$sroa$043$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = ((($0)) + 4|0);
 $6 = HEAP32[$1>>2]|0;
 $7 = ($6|0)==($5|0);
 $8 = $6;
 if (!($7)) {
  $9 = ((($6)) + 16|0);
  $10 = HEAP32[$4>>2]|0;
  $11 = HEAP32[$9>>2]|0;
  $12 = ($10>>>0)<($11>>>0);
  if (!($12)) {
   $43 = ($11>>>0)<($10>>>0);
   if (!($43)) {
    HEAP32[$2>>2] = $8;
    HEAP32[$3>>2] = $8;
    $$2 = $3;
    return ($$2|0);
   }
   $44 = ((($6)) + 4|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = ($45|0)==(0|0);
   if ($46) {
    $47 = ((($6)) + 8|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = HEAP32[$48>>2]|0;
    $50 = ($49|0)==($6|0);
    if ($50) {
     $$0$i$i$i$i$i = $48;
    } else {
     $54 = $47;
     while(1) {
      $53 = HEAP32[$54>>2]|0;
      $55 = ((($53)) + 8|0);
      $56 = HEAP32[$55>>2]|0;
      $57 = HEAP32[$56>>2]|0;
      $58 = ($57|0)==($53|0);
      if ($58) {
       $$0$i$i$i$i$i = $56;
       break;
      } else {
       $54 = $55;
      }
     }
    }
   } else {
    $$0$i$i$i$i$i$i = $45;
    while(1) {
     $51 = HEAP32[$$0$i$i$i$i$i$i>>2]|0;
     $52 = ($51|0)==(0|0);
     if ($52) {
      break;
     } else {
      $$0$i$i$i$i$i$i = $51;
     }
    }
    $$0$i$i$i$i$i = $$0$i$i$i$i$i$i;
   }
   $59 = ($$0$i$i$i$i$i|0)==($5|0);
   if (!($59)) {
    $60 = ((($$0$i$i$i$i$i)) + 16|0);
    $61 = HEAP32[$60>>2]|0;
    $62 = ($10>>>0)<($61>>>0);
    if (!($62)) {
     $66 = HEAP32[$5>>2]|0;
     $67 = ($66|0)==(0|0);
     if ($67) {
      HEAP32[$2>>2] = $5;
      $$2 = $5;
      return ($$2|0);
     }
     $68 = ((($0)) + 4|0);
     $$0$i = $68;$$024$i = $66;
     while(1) {
      $69 = ((($$024$i)) + 16|0);
      $70 = HEAP32[$69>>2]|0;
      $71 = ($10>>>0)<($70>>>0);
      if ($71) {
       $72 = HEAP32[$$024$i>>2]|0;
       $73 = ($72|0)==(0|0);
       if ($73) {
        label = 39;
        break;
       } else {
        $$0$ph$i = $$024$i;$$in$i = $72;
       }
      } else {
       $74 = ($70>>>0)<($10>>>0);
       if (!($74)) {
        label = 43;
        break;
       }
       $75 = ((($$024$i)) + 4|0);
       $76 = HEAP32[$75>>2]|0;
       $77 = ($76|0)==(0|0);
       if ($77) {
        label = 42;
        break;
       } else {
        $$0$ph$i = $75;$$in$i = $76;
       }
      }
      $$0$i = $$0$ph$i;$$024$i = $$in$i;
     }
     if ((label|0) == 39) {
      HEAP32[$2>>2] = $$024$i;
      $$2 = $$024$i;
      return ($$2|0);
     }
     else if ((label|0) == 42) {
      HEAP32[$2>>2] = $$024$i;
      $$2 = $75;
      return ($$2|0);
     }
     else if ((label|0) == 43) {
      HEAP32[$2>>2] = $$024$i;
      $$2 = $$0$i;
      return ($$2|0);
     }
    }
   }
   $63 = ((($6)) + 4|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = ($64|0)==(0|0);
   if ($65) {
    HEAP32[$2>>2] = $8;
    $$2 = $44;
    return ($$2|0);
   } else {
    HEAP32[$2>>2] = $$0$i$i$i$i$i;
    $$2 = $$0$i$i$i$i$i;
    return ($$2|0);
   }
  }
 }
 $13 = HEAP32[$0>>2]|0;
 $14 = ($6|0)==($13|0);
 $$pre = HEAP32[$6>>2]|0;
 if ($14) {
  $$sroa$043$0 = $8;
 } else {
  $15 = ($$pre|0)==(0|0);
  if ($15) {
   $$0$i$i = $6;
   while(1) {
    $19 = ((($$0$i$i)) + 8|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = HEAP32[$20>>2]|0;
    $22 = ($21|0)==($$0$i$i|0);
    if ($22) {
     $$0$i$i = $20;
    } else {
     $$08$i$i = $20;
     break;
    }
   }
  } else {
   $$0$i$i$i = $$pre;
   while(1) {
    $16 = ((($$0$i$i$i)) + 4|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = ($17|0)==(0|0);
    if ($18) {
     $$08$i$i = $$0$i$i$i;
     break;
    } else {
     $$0$i$i$i = $17;
    }
   }
  }
  $23 = $$08$i$i;
  $24 = ((($$08$i$i)) + 16|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = HEAP32[$4>>2]|0;
  $27 = ($25>>>0)<($26>>>0);
  if ($27) {
   $$sroa$043$0 = $23;
  } else {
   $31 = HEAP32[$5>>2]|0;
   $32 = ($31|0)==(0|0);
   if ($32) {
    HEAP32[$2>>2] = $5;
    $$2 = $5;
    return ($$2|0);
   }
   $33 = ((($0)) + 4|0);
   $$0$i26 = $33;$$024$i25 = $31;
   while(1) {
    $34 = ((($$024$i25)) + 16|0);
    $35 = HEAP32[$34>>2]|0;
    $36 = ($26>>>0)<($35>>>0);
    if ($36) {
     $37 = HEAP32[$$024$i25>>2]|0;
     $38 = ($37|0)==(0|0);
     if ($38) {
      label = 17;
      break;
     } else {
      $$0$ph$i23 = $$024$i25;$$in$i22 = $37;
     }
    } else {
     $39 = ($35>>>0)<($26>>>0);
     if (!($39)) {
      label = 21;
      break;
     }
     $40 = ((($$024$i25)) + 4|0);
     $41 = HEAP32[$40>>2]|0;
     $42 = ($41|0)==(0|0);
     if ($42) {
      label = 20;
      break;
     } else {
      $$0$ph$i23 = $40;$$in$i22 = $41;
     }
    }
    $$0$i26 = $$0$ph$i23;$$024$i25 = $$in$i22;
   }
   if ((label|0) == 17) {
    HEAP32[$2>>2] = $$024$i25;
    $$2 = $$024$i25;
    return ($$2|0);
   }
   else if ((label|0) == 20) {
    HEAP32[$2>>2] = $$024$i25;
    $$2 = $40;
    return ($$2|0);
   }
   else if ((label|0) == 21) {
    HEAP32[$2>>2] = $$024$i25;
    $$2 = $$0$i26;
    return ($$2|0);
   }
  }
 }
 $28 = ($$pre|0)==(0|0);
 if ($28) {
  HEAP32[$2>>2] = $6;
  $$2 = $6;
  return ($$2|0);
 } else {
  $29 = $$sroa$043$0;
  HEAP32[$2>>2] = $29;
  $30 = ((($29)) + 4|0);
  $$2 = $30;
  return ($$2|0);
 }
 return (0)|0;
}
function __ZN3osg6CameraC2Ev($0) {
 $0 = $0|0;
 var $$0 = 0, $$02 = 0, $$4 = 0, $$46 = 0, $$5 = 0, $$57 = 0, $$6 = 0, $$68 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0;
 var $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0;
 var $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0;
 var $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg9TransformC2Ev($0);
 $1 = ((($0)) + 144|0);
 HEAP32[$1>>2] = (58232);
 $2 = ((($0)) + 172|0);
 HEAP32[$2>>2] = 0;
 $3 = HEAP32[(58240)>>2]|0;
 __THREW__ = 0;
 invoke_vi($3|0,($1|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  label = 3;
 } else {
  __THREW__ = 0;
  invoke_vi(3610,($1|0));
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if ($7) {
   label = 3;
  } else {
   HEAP32[$0>>2] = (56344);
   HEAP32[$1>>2] = (56628);
   $19 = ((($0)) + 208|0);
   __THREW__ = 0;
   invoke_vii(3507,($19|0),0);
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if ($21) {
    $78 = ___cxa_find_matching_catch_2()|0;
    $79 = tempRet0;
    $$5 = $79;$$57 = $78;
   } else {
    $22 = ((($0)) + 220|0);
    HEAP32[$22>>2] = 0;
    $23 = ((($0)) + 224|0);
    HEAP32[$23>>2] = 0;
    $24 = ((($0)) + 228|0);
    HEAP8[$24>>0] = 1;
    $25 = ((($0)) + 232|0);
    HEAP32[$25>>2] = 0;
    $26 = ((($0)) + 236|0);
    HEAP32[$26>>2] = 16640;
    $27 = ((($0)) + 240|0);
    HEAPF32[$27>>2] = 0.0;
    $28 = ((($0)) + 244|0);
    HEAPF32[$28>>2] = 0.0;
    $29 = ((($0)) + 248|0);
    HEAPF32[$29>>2] = 0.0;
    $30 = ((($0)) + 252|0);
    HEAPF32[$30>>2] = 1.0;
    $31 = ((($0)) + 256|0);
    HEAPF32[$31>>2] = 0.0;
    $32 = ((($0)) + 260|0);
    HEAPF32[$32>>2] = 0.0;
    $33 = ((($0)) + 264|0);
    HEAPF32[$33>>2] = 0.0;
    $34 = ((($0)) + 268|0);
    HEAPF32[$34>>2] = 1.0;
    $35 = ((($0)) + 272|0);
    HEAPF64[$35>>3] = 1.0;
    $36 = ((($0)) + 280|0);
    $37 = ((($0)) + 284|0);
    $38 = ((($0)) + 288|0);
    $39 = ((($0)) + 296|0);
    ;HEAP32[$36>>2]=0|0;HEAP32[$36+4>>2]=0|0;HEAP32[$36+8>>2]=0|0;HEAP32[$36+12>>2]=0|0;
    HEAP32[$39>>2] = 1;
    $40 = ((($0)) + 304|0);
    __THREW__ = 0;
    invoke_vi(3299,($40|0));
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    do {
     if ($42) {
      $80 = ___cxa_find_matching_catch_2()|0;
      $81 = tempRet0;
      $$4 = $81;$$46 = $80;
     } else {
      $43 = ((($0)) + 432|0);
      __THREW__ = 0;
      invoke_vi(3299,($43|0));
      $44 = __THREW__; __THREW__ = 0;
      $45 = $44&1;
      if ($45) {
       $82 = ___cxa_find_matching_catch_2()|0;
       $83 = tempRet0;
       $$4 = $83;$$46 = $82;
       break;
      }
      $46 = ((($0)) + 560|0);
      HEAP32[$46>>2] = 2;
      $47 = ((($0)) + 564|0);
      HEAP32[$47>>2] = 0;
      $48 = ((($0)) + 568|0);
      HEAP32[$48>>2] = 0;
      $49 = ((($0)) + 572|0);
      HEAP32[$49>>2] = 0;
      $50 = ((($0)) + 576|0);
      HEAP32[$50>>2] = 3;
      $51 = ((($0)) + 580|0);
      HEAP32[$51>>2] = 3;
      $52 = ((($0)) + 584|0);
      $53 = ((($0)) + 588|0);
      HEAP32[$53>>2] = 0;
      $54 = ((($0)) + 592|0);
      HEAP32[$54>>2] = 0;
      $55 = ((($0)) + 588|0);
      HEAP32[$52>>2] = $55;
      $56 = ((($0)) + 596|0);
      HEAP32[$56>>2] = -1;
      $57 = ((($0)) + 600|0);
      HEAP32[$57>>2] = -1;
      $58 = ((($0)) + 604|0);
      HEAP32[$58>>2] = 0;
      $59 = ((($0)) + 608|0);
      $60 = ((($0)) + 612|0);
      HEAP32[$60>>2] = 0;
      $61 = ((($0)) + 616|0);
      HEAP32[$61>>2] = 0;
      $62 = ((($0)) + 612|0);
      HEAP32[$59>>2] = $62;
      $63 = ((($0)) + 620|0);
      $64 = ((($0)) + 624|0);
      $65 = ((($0)) + 628|0);
      $66 = ((($0)) + 632|0);
      $67 = ((($0)) + 636|0);
      $68 = ((($0)) + 640|0);
      $69 = ((($0)) + 644|0);
      $70 = ((($0)) + 648|0);
      ;HEAP32[$63>>2]=0|0;HEAP32[$63+4>>2]=0|0;HEAP32[$63+8>>2]=0|0;HEAP32[$63+12>>2]=0|0;HEAP32[$63+16>>2]=0|0;HEAP32[$63+20>>2]=0|0;HEAP32[$63+24>>2]=0|0;HEAP32[$63+28>>2]=0|0;
      __THREW__ = 0;
      $71 = (invoke_ii(3276,160)|0);
      $72 = __THREW__; __THREW__ = 0;
      $73 = $72&1;
      do {
       if ($73) {
        label = 18;
       } else {
        __THREW__ = 0;
        invoke_vi(3572,($71|0));
        $74 = __THREW__; __THREW__ = 0;
        $75 = $74&1;
        if ($75) {
         $86 = ___cxa_find_matching_catch_2()|0;
         $87 = tempRet0;
         __ZdlPv($71);
         $$0 = $87;$$02 = $86;
         break;
        }
        __THREW__ = 0;
        invoke_vii(3726,($0|0),($71|0));
        $76 = __THREW__; __THREW__ = 0;
        $77 = $76&1;
        if ($77) {
         label = 18;
        } else {
         return;
        }
       }
      } while(0);
      if ((label|0) == 18) {
       $84 = ___cxa_find_matching_catch_2()|0;
       $85 = tempRet0;
       $$0 = $85;$$02 = $84;
      }
      $88 = HEAP32[$70>>2]|0;
      $89 = ($88|0)==(0|0);
      if (!($89)) {
       $90 = HEAP32[$88>>2]|0;
       $91 = ((($90)) + -12|0);
       $92 = HEAP32[$91>>2]|0;
       $93 = (($88) + ($92)|0);
       $94 = ((($93)) + 8|0);
       $95 = HEAP32[$94>>2]|0;HEAP32[$94>>2] = (($95-1)|0);
       $96 = ($95|0)==(1);
       if ($96) {
        __THREW__ = 0;
        invoke_viii(3262,($93|0),1,1);
        $97 = __THREW__; __THREW__ = 0;
        $98 = $97&1;
        if ($98) {
         $205 = ___cxa_find_matching_catch_3(0|0)|0;
         $206 = tempRet0;
         ___clang_call_terminate($205);
         // unreachable;
        }
       }
      }
      HEAP32[$70>>2] = 0;
      $99 = HEAP32[$69>>2]|0;
      $100 = ($99|0)==(0|0);
      if (!($100)) {
       $101 = HEAP32[$99>>2]|0;
       $102 = ((($101)) + -12|0);
       $103 = HEAP32[$102>>2]|0;
       $104 = (($99) + ($103)|0);
       $105 = ((($104)) + 8|0);
       $106 = HEAP32[$105>>2]|0;HEAP32[$105>>2] = (($106-1)|0);
       $107 = ($106|0)==(1);
       if ($107) {
        __THREW__ = 0;
        invoke_viii(3262,($104|0),1,1);
        $108 = __THREW__; __THREW__ = 0;
        $109 = $108&1;
        if ($109) {
         $205 = ___cxa_find_matching_catch_3(0|0)|0;
         $206 = tempRet0;
         ___clang_call_terminate($205);
         // unreachable;
        }
       }
      }
      HEAP32[$69>>2] = 0;
      $110 = HEAP32[$68>>2]|0;
      $111 = ($110|0)==(0|0);
      if (!($111)) {
       $112 = HEAP32[$110>>2]|0;
       $113 = ((($112)) + -12|0);
       $114 = HEAP32[$113>>2]|0;
       $115 = (($110) + ($114)|0);
       $116 = ((($115)) + 8|0);
       $117 = HEAP32[$116>>2]|0;HEAP32[$116>>2] = (($117-1)|0);
       $118 = ($117|0)==(1);
       if ($118) {
        __THREW__ = 0;
        invoke_viii(3262,($115|0),1,1);
        $119 = __THREW__; __THREW__ = 0;
        $120 = $119&1;
        if ($120) {
         $205 = ___cxa_find_matching_catch_3(0|0)|0;
         $206 = tempRet0;
         ___clang_call_terminate($205);
         // unreachable;
        }
       }
      }
      HEAP32[$68>>2] = 0;
      $121 = HEAP32[$67>>2]|0;
      $122 = ($121|0)==(0|0);
      if (!($122)) {
       $123 = HEAP32[$121>>2]|0;
       $124 = ((($123)) + -12|0);
       $125 = HEAP32[$124>>2]|0;
       $126 = (($121) + ($125)|0);
       $127 = ((($126)) + 8|0);
       $128 = HEAP32[$127>>2]|0;HEAP32[$127>>2] = (($128-1)|0);
       $129 = ($128|0)==(1);
       if ($129) {
        __THREW__ = 0;
        invoke_viii(3262,($126|0),1,1);
        $130 = __THREW__; __THREW__ = 0;
        $131 = $130&1;
        if ($131) {
         $205 = ___cxa_find_matching_catch_3(0|0)|0;
         $206 = tempRet0;
         ___clang_call_terminate($205);
         // unreachable;
        }
       }
      }
      HEAP32[$67>>2] = 0;
      $132 = HEAP32[$66>>2]|0;
      $133 = ($132|0)==(0|0);
      if (!($133)) {
       $134 = ((($132)) + 8|0);
       $135 = HEAP32[$134>>2]|0;HEAP32[$134>>2] = (($135-1)|0);
       $136 = ($135|0)==(1);
       if ($136) {
        __THREW__ = 0;
        invoke_viii(3262,($132|0),1,1);
        $137 = __THREW__; __THREW__ = 0;
        $138 = $137&1;
        if ($138) {
         $205 = ___cxa_find_matching_catch_3(0|0)|0;
         $206 = tempRet0;
         ___clang_call_terminate($205);
         // unreachable;
        }
       }
      }
      HEAP32[$66>>2] = 0;
      $139 = HEAP32[$65>>2]|0;
      $140 = ($139|0)==(0|0);
      if (!($140)) {
       $141 = HEAP32[$139>>2]|0;
       $142 = ((($141)) + -12|0);
       $143 = HEAP32[$142>>2]|0;
       $144 = (($139) + ($143)|0);
       $145 = ((($144)) + 8|0);
       $146 = HEAP32[$145>>2]|0;HEAP32[$145>>2] = (($146-1)|0);
       $147 = ($146|0)==(1);
       if ($147) {
        __THREW__ = 0;
        invoke_viii(3262,($144|0),1,1);
        $148 = __THREW__; __THREW__ = 0;
        $149 = $148&1;
        if ($149) {
         $205 = ___cxa_find_matching_catch_3(0|0)|0;
         $206 = tempRet0;
         ___clang_call_terminate($205);
         // unreachable;
        }
       }
      }
      HEAP32[$65>>2] = 0;
      $150 = HEAP32[$64>>2]|0;
      $151 = ($150|0)==(0|0);
      if (!($151)) {
       $152 = ((($150)) + 8|0);
       $153 = HEAP32[$152>>2]|0;HEAP32[$152>>2] = (($153-1)|0);
       $154 = ($153|0)==(1);
       if ($154) {
        __THREW__ = 0;
        invoke_viii(3262,($150|0),1,1);
        $155 = __THREW__; __THREW__ = 0;
        $156 = $155&1;
        if ($156) {
         $205 = ___cxa_find_matching_catch_3(0|0)|0;
         $206 = tempRet0;
         ___clang_call_terminate($205);
         // unreachable;
        }
       }
      }
      HEAP32[$64>>2] = 0;
      $157 = HEAP32[$63>>2]|0;
      $158 = ($157|0)==(0|0);
      if (!($158)) {
       $159 = ((($157)) + 8|0);
       $160 = HEAP32[$159>>2]|0;HEAP32[$159>>2] = (($160-1)|0);
       $161 = ($160|0)==(1);
       if ($161) {
        __THREW__ = 0;
        invoke_viii(3262,($157|0),1,1);
        $162 = __THREW__; __THREW__ = 0;
        $163 = $162&1;
        if ($163) {
         $205 = ___cxa_find_matching_catch_3(0|0)|0;
         $206 = tempRet0;
         ___clang_call_terminate($205);
         // unreachable;
        }
       }
      }
      HEAP32[$63>>2] = 0;
      $164 = HEAP32[$62>>2]|0;
      __ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEE7destroyEPNS_11__tree_nodeIjPvEE($59,$164);
      $165 = HEAP32[$55>>2]|0;
      __ZNSt3__26__treeINS_12__value_typeIN3osg6Camera15BufferComponentENS3_10AttachmentEEENS_19__map_value_compareIS4_S6_NS_4lessIS4_EELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($52,$165);
      $$4 = $$0;$$46 = $$02;
     }
    } while(0);
    $166 = HEAP32[$38>>2]|0;
    $167 = ($166|0)==(0|0);
    if (!($167)) {
     $168 = ((($166)) + 8|0);
     $169 = HEAP32[$168>>2]|0;HEAP32[$168>>2] = (($169-1)|0);
     $170 = ($169|0)==(1);
     if ($170) {
      __THREW__ = 0;
      invoke_viii(3262,($166|0),1,1);
      $171 = __THREW__; __THREW__ = 0;
      $172 = $171&1;
      if ($172) {
       $205 = ___cxa_find_matching_catch_3(0|0)|0;
       $206 = tempRet0;
       ___clang_call_terminate($205);
       // unreachable;
      }
     }
    }
    HEAP32[$38>>2] = 0;
    $173 = HEAP32[$37>>2]|0;
    $174 = ($173|0)==(0|0);
    if (!($174)) {
     $175 = ((($173)) + 8|0);
     $176 = HEAP32[$175>>2]|0;HEAP32[$175>>2] = (($176-1)|0);
     $177 = ($176|0)==(1);
     if ($177) {
      __THREW__ = 0;
      invoke_viii(3262,($173|0),1,1);
      $178 = __THREW__; __THREW__ = 0;
      $179 = $178&1;
      if ($179) {
       $205 = ___cxa_find_matching_catch_3(0|0)|0;
       $206 = tempRet0;
       ___clang_call_terminate($205);
       // unreachable;
      }
     }
    }
    HEAP32[$37>>2] = 0;
    $180 = HEAP32[$25>>2]|0;
    $181 = ($180|0)==(0|0);
    if (!($181)) {
     $182 = ((($180)) + 8|0);
     $183 = HEAP32[$182>>2]|0;HEAP32[$182>>2] = (($183-1)|0);
     $184 = ($183|0)==(1);
     if ($184) {
      __THREW__ = 0;
      invoke_viii(3262,($180|0),1,1);
      $185 = __THREW__; __THREW__ = 0;
      $186 = $185&1;
      if ($186) {
       $205 = ___cxa_find_matching_catch_3(0|0)|0;
       $206 = tempRet0;
       ___clang_call_terminate($205);
       // unreachable;
      }
     }
    }
    HEAP32[$25>>2] = 0;
    $187 = HEAP32[$23>>2]|0;
    $188 = ($187|0)==(0|0);
    if (!($188)) {
     $189 = ((($187)) + 8|0);
     $190 = HEAP32[$189>>2]|0;HEAP32[$189>>2] = (($190-1)|0);
     $191 = ($190|0)==(1);
     if ($191) {
      __THREW__ = 0;
      invoke_viii(3262,($187|0),1,1);
      $192 = __THREW__; __THREW__ = 0;
      $193 = $192&1;
      if ($193) {
       $205 = ___cxa_find_matching_catch_3(0|0)|0;
       $206 = tempRet0;
       ___clang_call_terminate($205);
       // unreachable;
      }
     }
    }
    HEAP32[$23>>2] = 0;
    __THREW__ = 0;
    invoke_vi(707,($19|0));
    $194 = __THREW__; __THREW__ = 0;
    $195 = $194&1;
    if ($195) {
     $205 = ___cxa_find_matching_catch_3(0|0)|0;
     $206 = tempRet0;
     ___clang_call_terminate($205);
     // unreachable;
    } else {
     $$5 = $$4;$$57 = $$46;
    }
   }
   HEAP32[$1>>2] = (58232);
   $196 = HEAP32[$2>>2]|0;
   $197 = ($196|0)==(0|0);
   if (!($197)) {
    $198 = ((($196)) + 8|0);
    $199 = HEAP32[$198>>2]|0;HEAP32[$198>>2] = (($199-1)|0);
    $200 = ($199|0)==(1);
    if ($200) {
     __THREW__ = 0;
     invoke_viii(3262,($196|0),1,1);
     $201 = __THREW__; __THREW__ = 0;
     $202 = $201&1;
     if ($202) {
      $205 = ___cxa_find_matching_catch_3(0|0)|0;
      $206 = tempRet0;
      ___clang_call_terminate($205);
      // unreachable;
     }
    }
   }
   HEAP32[$2>>2] = 0;
   $$6 = $$5;$$68 = $$57;
  }
 }
 if ((label|0) == 3) {
  $8 = ___cxa_find_matching_catch_2()|0;
  $9 = tempRet0;
  $10 = HEAP32[$2>>2]|0;
  $11 = ($10|0)==(0|0);
  if (!($11)) {
   $12 = ((($10)) + 8|0);
   $13 = HEAP32[$12>>2]|0;HEAP32[$12>>2] = (($13-1)|0);
   $14 = ($13|0)==(1);
   if ($14) {
    __THREW__ = 0;
    invoke_viii(3262,($10|0),1,1);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     $17 = ___cxa_find_matching_catch_3(0|0)|0;
     $18 = tempRet0;
     ___clang_call_terminate($17);
     // unreachable;
    }
   }
  }
  HEAP32[$2>>2] = 0;
  $$6 = $9;$$68 = $8;
 }
 __THREW__ = 0;
 invoke_vi(2366,($0|0));
 $203 = __THREW__; __THREW__ = 0;
 $204 = $203&1;
 if ($204) {
  $205 = ___cxa_find_matching_catch_3(0|0)|0;
  $206 = tempRet0;
  ___clang_call_terminate($205);
  // unreachable;
 } else {
  ___resumeException($$68|0);
  // unreachable;
 }
}
function __ZN3osg6Camera15setCameraThreadEPNS_15OperationThreadE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$$i$i = 0, $$pr = 0, $$pr$i$i = 0, $$pre = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 620|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==($1|0);
 if ($4) {
  return;
 }
 $5 = ($3|0)==(0|0);
 if ($5) {
  $17 = 0;
 } else {
  $6 = HEAP32[$3>>2]|0;
  $7 = ((($6)) + 16|0);
  $8 = HEAP32[$7>>2]|0;
  (FUNCTION_TABLE_ii[$8 & 8191]($3)|0);
  $9 = HEAP32[$2>>2]|0;
  $10 = ((($9)) + 20|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($11|0)==(0|0);
  if (!($12)) {
   HEAP32[$10>>2] = 0;
   $13 = ((($11)) + 8|0);
   $14 = HEAP32[$13>>2]|0;HEAP32[$13>>2] = (($14-1)|0);
   $15 = ($14|0)==(1);
   if ($15) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($11,1,1);
   }
  }
  $16 = ((($9)) + 24|0);
  HEAP32[$16>>2] = 0;
  $$pre = HEAP32[$2>>2]|0;
  $17 = $$pre;
 }
 $18 = ($17|0)==($1|0);
 if ($18) {
  $26 = $1;
 } else {
  HEAP32[$2>>2] = $1;
  $19 = ($1|0)==(0|0);
  if (!($19)) {
   $20 = ((($1)) + 8|0);
   $21 = HEAP32[$20>>2]|0;HEAP32[$20>>2] = (($21+1)|0);
  }
  $22 = ($17|0)==(0|0);
  if (!($22)) {
   $23 = ((($17)) + 8|0);
   $24 = HEAP32[$23>>2]|0;HEAP32[$23>>2] = (($24-1)|0);
   $25 = ($24|0)==(1);
   if ($25) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($17,1,1);
   }
  }
  $$pr = HEAP32[$2>>2]|0;
  $26 = $$pr;
 }
 $27 = ($26|0)==(0|0);
 if ($27) {
  return;
 }
 $28 = ((($26)) + 12|0);
 $29 = ((($0)) + 608|0);
 (__ZN11OpenThreads6Thread20setProcessorAffinityERKNS_8AffinityE($28,$29)|0);
 $30 = HEAP32[$2>>2]|0;
 $31 = (__ZNK3osg10Referenced22getOrCreateObserverSetEv($0)|0);
 $32 = ((($30)) + 20|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ($33|0)==($31|0);
 if ($34) {
  $42 = $31;
 } else {
  HEAP32[$32>>2] = $31;
  $35 = ($31|0)==(0|0);
  if (!($35)) {
   $36 = ((($31)) + 8|0);
   $37 = HEAP32[$36>>2]|0;HEAP32[$36>>2] = (($37+1)|0);
  }
  $38 = ($33|0)==(0|0);
  if (!($38)) {
   $39 = ((($33)) + 8|0);
   $40 = HEAP32[$39>>2]|0;HEAP32[$39>>2] = (($40-1)|0);
   $41 = ($40|0)==(1);
   if ($41) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($33,1,1);
   }
  }
  $$pr$i$i = HEAP32[$32>>2]|0;
  $42 = $$pr$i$i;
 }
 $43 = ($42|0)==(0|0);
 if ($43) {
  $48 = 0;
 } else {
  $44 = ((($42)) + 24|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = ($45|0)!=(0|0);
  $$$i$i = $46 ? $0 : 0;
  $48 = $$$i$i;
 }
 $47 = ((($30)) + 24|0);
 HEAP32[$47>>2] = $48;
 return;
}
function __ZN3osg6Camera18setGraphicsContextEPNS_15GraphicsContextE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$pr = 0, $$pre = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 624|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==($1|0);
 if ($4) {
  return;
 }
 $5 = ($3|0)==(0|0);
 if ($5) {
  $6 = 0;
 } else {
  __ZN3osg15GraphicsContext12removeCameraEPNS_6CameraE($3,$0);
  $$pre = HEAP32[$2>>2]|0;
  $6 = $$pre;
 }
 $7 = ($6|0)==($1|0);
 if ($7) {
  $15 = $1;
 } else {
  HEAP32[$2>>2] = $1;
  $8 = ($1|0)==(0|0);
  if (!($8)) {
   $9 = ((($1)) + 8|0);
   $10 = HEAP32[$9>>2]|0;HEAP32[$9>>2] = (($10+1)|0);
  }
  $11 = ($6|0)==(0|0);
  if (!($11)) {
   $12 = ((($6)) + 8|0);
   $13 = HEAP32[$12>>2]|0;HEAP32[$12>>2] = (($13-1)|0);
   $14 = ($13|0)==(1);
   if ($14) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($6,1,1);
   }
  }
  $$pr = HEAP32[$2>>2]|0;
  $15 = $$pr;
 }
 $16 = ($15|0)==(0|0);
 if ($16) {
  return;
 }
 __ZN3osg15GraphicsContext9addCameraEPNS_6CameraE($15,$0);
 return;
}
function __ZN3osg6Camera29setRenderTargetImplementationENS0_26RenderTargetImplementationE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$sink = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 576|0);
 HEAP32[$2>>2] = $1;
 $3 = ($1|0)<(3);
 $4 = $3&1;
 $$sink = (($4) + ($1))|0;
 $5 = ((($0)) + 580|0);
 HEAP32[$5>>2] = $$sink;
 return;
}
function __ZN3osg6Camera11setViewportEPNS_8ViewportE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$pr = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0;
 var $or$cond3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 288|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==($1|0);
 if ($4) {
  return;
 }
 $5 = (__ZN3osg4Node19getOrCreateStateSetEv($0)|0);
 $6 = HEAP32[$2>>2]|0;
 $7 = ($6|0)!=(0|0);
 $8 = ($5|0)!=(0|0);
 $or$cond = $8 & $7;
 if ($or$cond) {
  __ZN3osg8StateSet15removeAttributeEPNS_14StateAttributeE($5,$6);
  $$pr = HEAP32[$2>>2]|0;
  $9 = $$pr;
 } else {
  $9 = $6;
 }
 $10 = ($9|0)==($1|0);
 if (!($10)) {
  HEAP32[$2>>2] = $1;
  $11 = ($1|0)==(0|0);
  if (!($11)) {
   $12 = ((($1)) + 8|0);
   $13 = HEAP32[$12>>2]|0;HEAP32[$12>>2] = (($13+1)|0);
  }
  $14 = ($9|0)==(0|0);
  if (!($14)) {
   $15 = ((($9)) + 8|0);
   $16 = HEAP32[$15>>2]|0;HEAP32[$15>>2] = (($16-1)|0);
   $17 = ($16|0)==(1);
   if ($17) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($9,1,1);
   }
  }
 }
 $18 = HEAP32[$2>>2]|0;
 $19 = ($18|0)!=(0|0);
 $or$cond3 = $8 & $19;
 if (!($or$cond3)) {
  return;
 }
 __ZN3osg8StateSet12setAttributeEPNS_14StateAttributeEj($5,$18,0);
 return;
}
function __ZN3osg6Camera11setViewportEiiii($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$pr$i = 0, $$pr$pre = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0.0, $37 = 0.0, $38 = 0.0, $39 = 0.0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i = 0, $or$cond3$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $5 = ((($0)) + 288|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $8 = (__Znwj(88)|0);
  __THREW__ = 0;
  invoke_vi(3599,($8|0));
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if ($10) {
   $27 = ___cxa_find_matching_catch_2()|0;
   $28 = tempRet0;
   __ZdlPv($8);
   ___resumeException($27|0);
   // unreachable;
  }
  $11 = HEAP32[$5>>2]|0;
  $12 = ($11|0)==($8|0);
  if ($12) {
   $32 = $8;
  } else {
   $13 = (__ZN3osg4Node19getOrCreateStateSetEv($0)|0);
   $14 = HEAP32[$5>>2]|0;
   $15 = ($14|0)!=(0|0);
   $16 = ($13|0)!=(0|0);
   $or$cond$i = $16 & $15;
   if ($or$cond$i) {
    __ZN3osg8StateSet15removeAttributeEPNS_14StateAttributeE($13,$14);
    $$pr$i = HEAP32[$5>>2]|0;
    $17 = $$pr$i;
   } else {
    $17 = $14;
   }
   $18 = ($17|0)==($8|0);
   if (!($18)) {
    HEAP32[$5>>2] = $8;
    $19 = ((($8)) + 8|0);
    $20 = HEAP32[$19>>2]|0;HEAP32[$19>>2] = (($20+1)|0);
    $21 = ($17|0)==(0|0);
    if (!($21)) {
     $22 = ((($17)) + 8|0);
     $23 = HEAP32[$22>>2]|0;HEAP32[$22>>2] = (($23-1)|0);
     $24 = ($23|0)==(1);
     if ($24) {
      __ZNK3osg10Referenced24signalObserversAndDeleteEbb($17,1,1);
     }
    }
   }
   $25 = HEAP32[$5>>2]|0;
   $26 = ($25|0)!=(0|0);
   $or$cond3$i = $16 & $26;
   if ($or$cond3$i) {
    __ZN3osg8StateSet12setAttributeEPNS_14StateAttributeEj($13,$25,0);
    $$pr$pre = HEAP32[$5>>2]|0;
    $29 = $$pr$pre;
   } else {
    $29 = $25;
   }
   $30 = ($29|0)==(0|0);
   if ($30) {
    return;
   } else {
    $32 = $29;
   }
  }
 } else {
  $32 = $6;
 }
 $31 = ((($32)) + 80|0);
 $33 = ((($32)) + 72|0);
 $34 = ((($32)) + 64|0);
 $35 = ((($32)) + 56|0);
 $36 = (+($4|0));
 $37 = (+($3|0));
 $38 = (+($2|0));
 $39 = (+($1|0));
 HEAPF64[$35>>3] = $39;
 HEAPF64[$34>>3] = $38;
 HEAPF64[$33>>3] = $37;
 HEAPF64[$31>>3] = $36;
 return;
}
function __ZN3osg6Camera32setProjectionMatrixAsPerspectiveEdddd($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = +$1;
 $2 = +$2;
 $3 = +$3;
 $4 = +$4;
 var $10 = 0, $11 = 0, $12 = 0.0, $13 = 0, $14 = 0, $15 = 0.0, $16 = 0, $17 = 0, $18 = 0.0, $19 = 0, $20 = 0, $21 = 0.0, $22 = 0, $23 = 0, $24 = 0.0, $25 = 0, $26 = 0, $27 = 0.0, $28 = 0, $29 = 0;
 var $30 = 0.0, $31 = 0, $32 = 0, $33 = 0.0, $34 = 0, $35 = 0, $36 = 0.0, $37 = 0, $38 = 0, $39 = 0.0, $40 = 0, $41 = 0, $42 = 0.0, $43 = 0, $44 = 0, $45 = 0.0, $46 = 0, $47 = 0, $48 = 0.0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0.0, $52 = 0, $6 = 0.0, $7 = 0, $8 = 0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(128|0);
 $5 = sp;
 __ZN3osg7Matrixd12makeIdentityEv($5);
 __ZN3osg7Matrixd15makePerspectiveEdddd($5,$1,$2,$3,$4);
 $6 = +HEAPF64[$5>>3];
 $7 = ((($0)) + 304|0);
 HEAPF64[$7>>3] = $6;
 $8 = ((($5)) + 8|0);
 $9 = +HEAPF64[$8>>3];
 $10 = ((($0)) + 312|0);
 HEAPF64[$10>>3] = $9;
 $11 = ((($5)) + 16|0);
 $12 = +HEAPF64[$11>>3];
 $13 = ((($0)) + 320|0);
 HEAPF64[$13>>3] = $12;
 $14 = ((($5)) + 24|0);
 $15 = +HEAPF64[$14>>3];
 $16 = ((($0)) + 328|0);
 HEAPF64[$16>>3] = $15;
 $17 = ((($5)) + 32|0);
 $18 = +HEAPF64[$17>>3];
 $19 = ((($0)) + 336|0);
 HEAPF64[$19>>3] = $18;
 $20 = ((($5)) + 40|0);
 $21 = +HEAPF64[$20>>3];
 $22 = ((($0)) + 344|0);
 HEAPF64[$22>>3] = $21;
 $23 = ((($5)) + 48|0);
 $24 = +HEAPF64[$23>>3];
 $25 = ((($0)) + 352|0);
 HEAPF64[$25>>3] = $24;
 $26 = ((($5)) + 56|0);
 $27 = +HEAPF64[$26>>3];
 $28 = ((($0)) + 360|0);
 HEAPF64[$28>>3] = $27;
 $29 = ((($5)) + 64|0);
 $30 = +HEAPF64[$29>>3];
 $31 = ((($0)) + 368|0);
 HEAPF64[$31>>3] = $30;
 $32 = ((($5)) + 72|0);
 $33 = +HEAPF64[$32>>3];
 $34 = ((($0)) + 376|0);
 HEAPF64[$34>>3] = $33;
 $35 = ((($5)) + 80|0);
 $36 = +HEAPF64[$35>>3];
 $37 = ((($0)) + 384|0);
 HEAPF64[$37>>3] = $36;
 $38 = ((($5)) + 88|0);
 $39 = +HEAPF64[$38>>3];
 $40 = ((($0)) + 392|0);
 HEAPF64[$40>>3] = $39;
 $41 = ((($5)) + 96|0);
 $42 = +HEAPF64[$41>>3];
 $43 = ((($0)) + 400|0);
 HEAPF64[$43>>3] = $42;
 $44 = ((($5)) + 104|0);
 $45 = +HEAPF64[$44>>3];
 $46 = ((($0)) + 408|0);
 HEAPF64[$46>>3] = $45;
 $47 = ((($5)) + 112|0);
 $48 = +HEAPF64[$47>>3];
 $49 = ((($0)) + 416|0);
 HEAPF64[$49>>3] = $48;
 $50 = ((($5)) + 120|0);
 $51 = +HEAPF64[$50>>3];
 $52 = ((($0)) + 424|0);
 HEAPF64[$52>>3] = $51;
 STACKTOP = sp;return;
}
function __ZNK3osg6Camera26getProjectionMatrixAsOrthoERdS1_S1_S1_S1_S1_($0,$1,$2,$3,$4,$5,$6) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 var $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $7 = ((($0)) + 304|0);
 $8 = (__ZNK3osg7Matrixd8getOrthoERdS1_S1_S1_S1_S1_($7,$1,$2,$3,$4,$5,$6)|0);
 return ($8|0);
}
function __ZNK3osg6Camera28getProjectionMatrixAsFrustumERdS1_S1_S1_S1_S1_($0,$1,$2,$3,$4,$5,$6) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 var $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $7 = ((($0)) + 304|0);
 $8 = (__ZNK3osg7Matrixd10getFrustumERdS1_S1_S1_S1_S1_($7,$1,$2,$3,$4,$5,$6)|0);
 return ($8|0);
}
function __ZNK3osg6Camera32getProjectionMatrixAsPerspectiveERdS1_S1_S1_($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = ((($0)) + 304|0);
 $6 = (__ZNK3osg7Matrixd14getPerspectiveERdS1_S1_S1_($5,$1,$2,$3,$4)|0);
 return ($6|0);
}
function __ZN3osg6Camera6attachENS0_15BufferComponentEPNS_7TextureEjjbjj($0,$1,$2,$3,$4,$5,$6,$7) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 var $$0$i$i = 0, $$0$i$i11 = 0, $$0$i$i27 = 0, $$0$i$i43 = 0, $$0$i$i59 = 0, $$0$i$i75 = 0, $$0$ph$i$i = 0, $$0$ph$i$i24 = 0, $$0$ph$i$i40 = 0, $$0$ph$i$i56 = 0, $$0$ph$i$i72 = 0, $$0$ph$i$i8 = 0, $$014$i = 0, $$014$i20 = 0, $$014$i36 = 0, $$014$i52 = 0, $$014$i68 = 0, $$014$i84 = 0, $$024$i$i = 0, $$024$i$i10 = 0;
 var $$024$i$i26 = 0, $$024$i$i42 = 0, $$024$i$i58 = 0, $$024$i$i74 = 0, $$025$i$i = 0, $$025$i$i13 = 0, $$025$i$i29 = 0, $$025$i$i45 = 0, $$025$i$i61 = 0, $$025$i$i77 = 0, $$025$i59$i = 0, $$025$i59$i15 = 0, $$025$i59$i31 = 0, $$025$i59$i47 = 0, $$025$i59$i63 = 0, $$025$i59$i79 = 0, $$043$i = 0, $$043$i12 = 0, $$043$i28 = 0, $$043$i44 = 0;
 var $$043$i60 = 0, $$043$i76 = 0, $$04358$i = 0, $$04358$i16 = 0, $$04358$i32 = 0, $$04358$i48 = 0, $$04358$i64 = 0, $$04358$i80 = 0, $$in$i$i = 0, $$in$i$i23 = 0, $$in$i$i39 = 0, $$in$i$i55 = 0, $$in$i$i7 = 0, $$in$i$i71 = 0, $$pre = 0, $$pre$i$i = 0, $$pre$i$i18 = 0, $$pre$i$i34 = 0, $$pre$i$i50 = 0, $$pre$i$i66 = 0;
 var $$pre$i$i82 = 0, $$pre203 = 0, $$pre204 = 0, $$pre205 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0;
 var $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $8 = $5&1;
 $9 = ((($0)) + 584|0);
 $10 = ((($0)) + 588|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0|0);
 do {
  if ($12) {
   $$025$i$i = $10;$$043$i = $10;$23 = $11;
   label = 12;
  } else {
   $13 = ((($0)) + 588|0);
   $$0$i$i = $13;$$024$i$i = $11;$212 = $11;
   while(1) {
    $14 = ((($$024$i$i)) + 16|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = ($15|0)>($1|0);
    if ($16) {
     $17 = HEAP32[$$024$i$i>>2]|0;
     $18 = ($17|0)==(0|0);
     if ($18) {
      label = 6;
      break;
     } else {
      $$0$ph$i$i = $$024$i$i;$$in$i$i = $17;
     }
    } else {
     $19 = ($15|0)<($1|0);
     if (!($19)) {
      label = 10;
      break;
     }
     $20 = ((($$024$i$i)) + 4|0);
     $21 = HEAP32[$20>>2]|0;
     $22 = ($21|0)==(0|0);
     if ($22) {
      label = 9;
      break;
     } else {
      $$0$ph$i$i = $20;$$in$i$i = $21;
     }
    }
    $$0$i$i = $$0$ph$i$i;$$024$i$i = $$in$i$i;$212 = $$in$i$i;
   }
   if ((label|0) == 6) {
    $$025$i59$i = $$024$i$i;$$04358$i = $$024$i$i;
    label = 13;
    break;
   }
   else if ((label|0) == 9) {
    $$025$i59$i = $20;$$04358$i = $$024$i$i;
    label = 13;
    break;
   }
   else if ((label|0) == 10) {
    $$025$i$i = $$0$i$i;$$043$i = $$024$i$i;$23 = $212;
    label = 12;
    break;
   }
  }
 } while(0);
 if ((label|0) == 12) {
  $24 = ($23|0)==(0|0);
  if ($24) {
   $$025$i59$i = $$025$i$i;$$04358$i = $$043$i;
   label = 13;
  } else {
   $$014$i = $23;
  }
 }
 if ((label|0) == 13) {
  $25 = (__Znwj(52)|0);
  $26 = ((($25)) + 16|0);
  HEAP32[$26>>2] = $1;
  $27 = ((($25)) + 20|0);
  $28 = ((($25)) + 44|0);
  HEAP32[$28>>2] = 0;
  $29 = ((($25)) + 48|0);
  HEAP32[$29>>2] = 0;
  ;HEAP32[$27>>2]=0|0;HEAP32[$27+4>>2]=0|0;HEAP32[$27+8>>2]=0|0;HEAP32[$27+12>>2]=0|0;HEAP32[$27+16>>2]=0|0;HEAP8[$27+20>>0]=0|0;
  HEAP32[$25>>2] = 0;
  $30 = ((($25)) + 4|0);
  HEAP32[$30>>2] = 0;
  $31 = ((($25)) + 8|0);
  HEAP32[$31>>2] = $$04358$i;
  HEAP32[$$025$i59$i>>2] = $25;
  $32 = HEAP32[$9>>2]|0;
  $33 = HEAP32[$32>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $38 = $25;
  } else {
   $35 = $33;
   HEAP32[$9>>2] = $35;
   $$pre$i$i = HEAP32[$$025$i59$i>>2]|0;
   $38 = $$pre$i$i;
  }
  $36 = ((($0)) + 588|0);
  $37 = HEAP32[$36>>2]|0;
  __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($37,$38);
  $39 = ((($0)) + 592|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = (($40) + 1)|0;
  HEAP32[$39>>2] = $41;
  $$014$i = $25;
 }
 $42 = ((($$014$i)) + 28|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = ($43|0)==($2|0);
 if (!($44)) {
  HEAP32[$42>>2] = $2;
  $45 = ($2|0)==(0|0);
  if (!($45)) {
   $46 = ((($2)) + 8|0);
   $47 = HEAP32[$46>>2]|0;HEAP32[$46>>2] = (($47+1)|0);
  }
  $48 = ($43|0)==(0|0);
  if (!($48)) {
   $49 = ((($43)) + 8|0);
   $50 = HEAP32[$49>>2]|0;HEAP32[$49>>2] = (($50-1)|0);
   $51 = ($50|0)==(1);
   if ($51) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($43,1,1);
   }
  }
 }
 $52 = HEAP32[$10>>2]|0;
 $53 = ($52|0)==(0|0);
 do {
  if ($53) {
   $$025$i$i13 = $10;$$043$i12 = $10;$64 = $52;
   label = 33;
  } else {
   $54 = ((($0)) + 588|0);
   $$0$i$i11 = $54;$$024$i$i10 = $52;$213 = $52;
   while(1) {
    $55 = ((($$024$i$i10)) + 16|0);
    $56 = HEAP32[$55>>2]|0;
    $57 = ($56|0)>($1|0);
    if ($57) {
     $58 = HEAP32[$$024$i$i10>>2]|0;
     $59 = ($58|0)==(0|0);
     if ($59) {
      label = 27;
      break;
     } else {
      $$0$ph$i$i8 = $$024$i$i10;$$in$i$i7 = $58;
     }
    } else {
     $60 = ($56|0)<($1|0);
     if (!($60)) {
      label = 31;
      break;
     }
     $61 = ((($$024$i$i10)) + 4|0);
     $62 = HEAP32[$61>>2]|0;
     $63 = ($62|0)==(0|0);
     if ($63) {
      label = 30;
      break;
     } else {
      $$0$ph$i$i8 = $61;$$in$i$i7 = $62;
     }
    }
    $$0$i$i11 = $$0$ph$i$i8;$$024$i$i10 = $$in$i$i7;$213 = $$in$i$i7;
   }
   if ((label|0) == 27) {
    $$025$i59$i15 = $$024$i$i10;$$04358$i16 = $$024$i$i10;
    label = 34;
    break;
   }
   else if ((label|0) == 30) {
    $$025$i59$i15 = $61;$$04358$i16 = $$024$i$i10;
    label = 34;
    break;
   }
   else if ((label|0) == 31) {
    $$025$i$i13 = $$0$i$i11;$$043$i12 = $$024$i$i10;$64 = $213;
    label = 33;
    break;
   }
  }
 } while(0);
 if ((label|0) == 33) {
  $65 = ($64|0)==(0|0);
  if ($65) {
   $$025$i59$i15 = $$025$i$i13;$$04358$i16 = $$043$i12;
   label = 34;
  } else {
   $$014$i20 = $64;$84 = $52;
  }
 }
 if ((label|0) == 34) {
  $66 = (__Znwj(52)|0);
  $67 = ((($66)) + 16|0);
  HEAP32[$67>>2] = $1;
  $68 = ((($66)) + 20|0);
  $69 = ((($66)) + 44|0);
  HEAP32[$69>>2] = 0;
  $70 = ((($66)) + 48|0);
  HEAP32[$70>>2] = 0;
  ;HEAP32[$68>>2]=0|0;HEAP32[$68+4>>2]=0|0;HEAP32[$68+8>>2]=0|0;HEAP32[$68+12>>2]=0|0;HEAP32[$68+16>>2]=0|0;HEAP8[$68+20>>0]=0|0;
  HEAP32[$66>>2] = 0;
  $71 = ((($66)) + 4|0);
  HEAP32[$71>>2] = 0;
  $72 = ((($66)) + 8|0);
  HEAP32[$72>>2] = $$04358$i16;
  HEAP32[$$025$i59$i15>>2] = $66;
  $73 = HEAP32[$9>>2]|0;
  $74 = HEAP32[$73>>2]|0;
  $75 = ($74|0)==(0|0);
  if ($75) {
   $79 = $66;
  } else {
   $76 = $74;
   HEAP32[$9>>2] = $76;
   $$pre$i$i18 = HEAP32[$$025$i59$i15>>2]|0;
   $79 = $$pre$i$i18;
  }
  $77 = ((($0)) + 588|0);
  $78 = HEAP32[$77>>2]|0;
  __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($78,$79);
  $80 = ((($0)) + 592|0);
  $81 = HEAP32[$80>>2]|0;
  $82 = (($81) + 1)|0;
  HEAP32[$80>>2] = $82;
  $$pre = HEAP32[$10>>2]|0;
  $$014$i20 = $66;$84 = $$pre;
 }
 $83 = ((($$014$i20)) + 32|0);
 HEAP32[$83>>2] = $3;
 $85 = ($84|0)==(0|0);
 do {
  if ($85) {
   $$025$i$i29 = $10;$$043$i28 = $10;$96 = $84;
   label = 48;
  } else {
   $86 = ((($0)) + 588|0);
   $$0$i$i27 = $86;$$024$i$i26 = $84;$214 = $84;
   while(1) {
    $87 = ((($$024$i$i26)) + 16|0);
    $88 = HEAP32[$87>>2]|0;
    $89 = ($88|0)>($1|0);
    if ($89) {
     $90 = HEAP32[$$024$i$i26>>2]|0;
     $91 = ($90|0)==(0|0);
     if ($91) {
      label = 42;
      break;
     } else {
      $$0$ph$i$i24 = $$024$i$i26;$$in$i$i23 = $90;
     }
    } else {
     $92 = ($88|0)<($1|0);
     if (!($92)) {
      label = 46;
      break;
     }
     $93 = ((($$024$i$i26)) + 4|0);
     $94 = HEAP32[$93>>2]|0;
     $95 = ($94|0)==(0|0);
     if ($95) {
      label = 45;
      break;
     } else {
      $$0$ph$i$i24 = $93;$$in$i$i23 = $94;
     }
    }
    $$0$i$i27 = $$0$ph$i$i24;$$024$i$i26 = $$in$i$i23;$214 = $$in$i$i23;
   }
   if ((label|0) == 42) {
    $$025$i59$i31 = $$024$i$i26;$$04358$i32 = $$024$i$i26;
    label = 49;
    break;
   }
   else if ((label|0) == 45) {
    $$025$i59$i31 = $93;$$04358$i32 = $$024$i$i26;
    label = 49;
    break;
   }
   else if ((label|0) == 46) {
    $$025$i$i29 = $$0$i$i27;$$043$i28 = $$024$i$i26;$96 = $214;
    label = 48;
    break;
   }
  }
 } while(0);
 if ((label|0) == 48) {
  $97 = ($96|0)==(0|0);
  if ($97) {
   $$025$i59$i31 = $$025$i$i29;$$04358$i32 = $$043$i28;
   label = 49;
  } else {
   $$014$i36 = $96;$116 = $84;
  }
 }
 if ((label|0) == 49) {
  $98 = (__Znwj(52)|0);
  $99 = ((($98)) + 16|0);
  HEAP32[$99>>2] = $1;
  $100 = ((($98)) + 20|0);
  $101 = ((($98)) + 44|0);
  HEAP32[$101>>2] = 0;
  $102 = ((($98)) + 48|0);
  HEAP32[$102>>2] = 0;
  ;HEAP32[$100>>2]=0|0;HEAP32[$100+4>>2]=0|0;HEAP32[$100+8>>2]=0|0;HEAP32[$100+12>>2]=0|0;HEAP32[$100+16>>2]=0|0;HEAP8[$100+20>>0]=0|0;
  HEAP32[$98>>2] = 0;
  $103 = ((($98)) + 4|0);
  HEAP32[$103>>2] = 0;
  $104 = ((($98)) + 8|0);
  HEAP32[$104>>2] = $$04358$i32;
  HEAP32[$$025$i59$i31>>2] = $98;
  $105 = HEAP32[$9>>2]|0;
  $106 = HEAP32[$105>>2]|0;
  $107 = ($106|0)==(0|0);
  if ($107) {
   $111 = $98;
  } else {
   $108 = $106;
   HEAP32[$9>>2] = $108;
   $$pre$i$i34 = HEAP32[$$025$i59$i31>>2]|0;
   $111 = $$pre$i$i34;
  }
  $109 = ((($0)) + 588|0);
  $110 = HEAP32[$109>>2]|0;
  __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($110,$111);
  $112 = ((($0)) + 592|0);
  $113 = HEAP32[$112>>2]|0;
  $114 = (($113) + 1)|0;
  HEAP32[$112>>2] = $114;
  $$pre203 = HEAP32[$10>>2]|0;
  $$014$i36 = $98;$116 = $$pre203;
 }
 $115 = ((($$014$i36)) + 36|0);
 HEAP32[$115>>2] = $4;
 $117 = ($116|0)==(0|0);
 do {
  if ($117) {
   $$025$i$i45 = $10;$$043$i44 = $10;$128 = $116;
   label = 63;
  } else {
   $118 = ((($0)) + 588|0);
   $$0$i$i43 = $118;$$024$i$i42 = $116;$215 = $116;
   while(1) {
    $119 = ((($$024$i$i42)) + 16|0);
    $120 = HEAP32[$119>>2]|0;
    $121 = ($120|0)>($1|0);
    if ($121) {
     $122 = HEAP32[$$024$i$i42>>2]|0;
     $123 = ($122|0)==(0|0);
     if ($123) {
      label = 57;
      break;
     } else {
      $$0$ph$i$i40 = $$024$i$i42;$$in$i$i39 = $122;
     }
    } else {
     $124 = ($120|0)<($1|0);
     if (!($124)) {
      label = 61;
      break;
     }
     $125 = ((($$024$i$i42)) + 4|0);
     $126 = HEAP32[$125>>2]|0;
     $127 = ($126|0)==(0|0);
     if ($127) {
      label = 60;
      break;
     } else {
      $$0$ph$i$i40 = $125;$$in$i$i39 = $126;
     }
    }
    $$0$i$i43 = $$0$ph$i$i40;$$024$i$i42 = $$in$i$i39;$215 = $$in$i$i39;
   }
   if ((label|0) == 57) {
    $$025$i59$i47 = $$024$i$i42;$$04358$i48 = $$024$i$i42;
    label = 64;
    break;
   }
   else if ((label|0) == 60) {
    $$025$i59$i47 = $125;$$04358$i48 = $$024$i$i42;
    label = 64;
    break;
   }
   else if ((label|0) == 61) {
    $$025$i$i45 = $$0$i$i43;$$043$i44 = $$024$i$i42;$128 = $215;
    label = 63;
    break;
   }
  }
 } while(0);
 if ((label|0) == 63) {
  $129 = ($128|0)==(0|0);
  if ($129) {
   $$025$i59$i47 = $$025$i$i45;$$04358$i48 = $$043$i44;
   label = 64;
  } else {
   $$014$i52 = $128;$148 = $116;
  }
 }
 if ((label|0) == 64) {
  $130 = (__Znwj(52)|0);
  $131 = ((($130)) + 16|0);
  HEAP32[$131>>2] = $1;
  $132 = ((($130)) + 20|0);
  $133 = ((($130)) + 44|0);
  HEAP32[$133>>2] = 0;
  $134 = ((($130)) + 48|0);
  HEAP32[$134>>2] = 0;
  ;HEAP32[$132>>2]=0|0;HEAP32[$132+4>>2]=0|0;HEAP32[$132+8>>2]=0|0;HEAP32[$132+12>>2]=0|0;HEAP32[$132+16>>2]=0|0;HEAP8[$132+20>>0]=0|0;
  HEAP32[$130>>2] = 0;
  $135 = ((($130)) + 4|0);
  HEAP32[$135>>2] = 0;
  $136 = ((($130)) + 8|0);
  HEAP32[$136>>2] = $$04358$i48;
  HEAP32[$$025$i59$i47>>2] = $130;
  $137 = HEAP32[$9>>2]|0;
  $138 = HEAP32[$137>>2]|0;
  $139 = ($138|0)==(0|0);
  if ($139) {
   $143 = $130;
  } else {
   $140 = $138;
   HEAP32[$9>>2] = $140;
   $$pre$i$i50 = HEAP32[$$025$i59$i47>>2]|0;
   $143 = $$pre$i$i50;
  }
  $141 = ((($0)) + 588|0);
  $142 = HEAP32[$141>>2]|0;
  __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($142,$143);
  $144 = ((($0)) + 592|0);
  $145 = HEAP32[$144>>2]|0;
  $146 = (($145) + 1)|0;
  HEAP32[$144>>2] = $146;
  $$pre204 = HEAP32[$10>>2]|0;
  $$014$i52 = $130;$148 = $$pre204;
 }
 $147 = ((($$014$i52)) + 40|0);
 HEAP8[$147>>0] = $8;
 $149 = ($148|0)==(0|0);
 do {
  if ($149) {
   $$025$i$i61 = $10;$$043$i60 = $10;$160 = $148;
   label = 78;
  } else {
   $150 = ((($0)) + 588|0);
   $$0$i$i59 = $150;$$024$i$i58 = $148;$216 = $148;
   while(1) {
    $151 = ((($$024$i$i58)) + 16|0);
    $152 = HEAP32[$151>>2]|0;
    $153 = ($152|0)>($1|0);
    if ($153) {
     $154 = HEAP32[$$024$i$i58>>2]|0;
     $155 = ($154|0)==(0|0);
     if ($155) {
      label = 72;
      break;
     } else {
      $$0$ph$i$i56 = $$024$i$i58;$$in$i$i55 = $154;
     }
    } else {
     $156 = ($152|0)<($1|0);
     if (!($156)) {
      label = 76;
      break;
     }
     $157 = ((($$024$i$i58)) + 4|0);
     $158 = HEAP32[$157>>2]|0;
     $159 = ($158|0)==(0|0);
     if ($159) {
      label = 75;
      break;
     } else {
      $$0$ph$i$i56 = $157;$$in$i$i55 = $158;
     }
    }
    $$0$i$i59 = $$0$ph$i$i56;$$024$i$i58 = $$in$i$i55;$216 = $$in$i$i55;
   }
   if ((label|0) == 72) {
    $$025$i59$i63 = $$024$i$i58;$$04358$i64 = $$024$i$i58;
    label = 79;
    break;
   }
   else if ((label|0) == 75) {
    $$025$i59$i63 = $157;$$04358$i64 = $$024$i$i58;
    label = 79;
    break;
   }
   else if ((label|0) == 76) {
    $$025$i$i61 = $$0$i$i59;$$043$i60 = $$024$i$i58;$160 = $216;
    label = 78;
    break;
   }
  }
 } while(0);
 if ((label|0) == 78) {
  $161 = ($160|0)==(0|0);
  if ($161) {
   $$025$i59$i63 = $$025$i$i61;$$04358$i64 = $$043$i60;
   label = 79;
  } else {
   $$014$i68 = $160;$180 = $148;
  }
 }
 if ((label|0) == 79) {
  $162 = (__Znwj(52)|0);
  $163 = ((($162)) + 16|0);
  HEAP32[$163>>2] = $1;
  $164 = ((($162)) + 20|0);
  $165 = ((($162)) + 44|0);
  HEAP32[$165>>2] = 0;
  $166 = ((($162)) + 48|0);
  HEAP32[$166>>2] = 0;
  ;HEAP32[$164>>2]=0|0;HEAP32[$164+4>>2]=0|0;HEAP32[$164+8>>2]=0|0;HEAP32[$164+12>>2]=0|0;HEAP32[$164+16>>2]=0|0;HEAP8[$164+20>>0]=0|0;
  HEAP32[$162>>2] = 0;
  $167 = ((($162)) + 4|0);
  HEAP32[$167>>2] = 0;
  $168 = ((($162)) + 8|0);
  HEAP32[$168>>2] = $$04358$i64;
  HEAP32[$$025$i59$i63>>2] = $162;
  $169 = HEAP32[$9>>2]|0;
  $170 = HEAP32[$169>>2]|0;
  $171 = ($170|0)==(0|0);
  if ($171) {
   $175 = $162;
  } else {
   $172 = $170;
   HEAP32[$9>>2] = $172;
   $$pre$i$i66 = HEAP32[$$025$i59$i63>>2]|0;
   $175 = $$pre$i$i66;
  }
  $173 = ((($0)) + 588|0);
  $174 = HEAP32[$173>>2]|0;
  __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($174,$175);
  $176 = ((($0)) + 592|0);
  $177 = HEAP32[$176>>2]|0;
  $178 = (($177) + 1)|0;
  HEAP32[$176>>2] = $178;
  $$pre205 = HEAP32[$10>>2]|0;
  $$014$i68 = $162;$180 = $$pre205;
 }
 $179 = ((($$014$i68)) + 44|0);
 HEAP32[$179>>2] = $6;
 $181 = ($180|0)==(0|0);
 do {
  if ($181) {
   $$025$i$i77 = $10;$$043$i76 = $10;$192 = $180;
   label = 93;
  } else {
   $182 = ((($0)) + 588|0);
   $$0$i$i75 = $182;$$024$i$i74 = $180;$217 = $180;
   while(1) {
    $183 = ((($$024$i$i74)) + 16|0);
    $184 = HEAP32[$183>>2]|0;
    $185 = ($184|0)>($1|0);
    if ($185) {
     $186 = HEAP32[$$024$i$i74>>2]|0;
     $187 = ($186|0)==(0|0);
     if ($187) {
      label = 87;
      break;
     } else {
      $$0$ph$i$i72 = $$024$i$i74;$$in$i$i71 = $186;
     }
    } else {
     $188 = ($184|0)<($1|0);
     if (!($188)) {
      label = 91;
      break;
     }
     $189 = ((($$024$i$i74)) + 4|0);
     $190 = HEAP32[$189>>2]|0;
     $191 = ($190|0)==(0|0);
     if ($191) {
      label = 90;
      break;
     } else {
      $$0$ph$i$i72 = $189;$$in$i$i71 = $190;
     }
    }
    $$0$i$i75 = $$0$ph$i$i72;$$024$i$i74 = $$in$i$i71;$217 = $$in$i$i71;
   }
   if ((label|0) == 87) {
    $$025$i59$i79 = $$024$i$i74;$$04358$i80 = $$024$i$i74;
    break;
   }
   else if ((label|0) == 90) {
    $$025$i59$i79 = $189;$$04358$i80 = $$024$i$i74;
    break;
   }
   else if ((label|0) == 91) {
    $$025$i$i77 = $$0$i$i75;$$043$i76 = $$024$i$i74;$192 = $217;
    label = 93;
    break;
   }
  }
 } while(0);
 if ((label|0) == 93) {
  $193 = ($192|0)==(0|0);
  if ($193) {
   $$025$i59$i79 = $$025$i$i77;$$04358$i80 = $$043$i76;
  } else {
   $$014$i84 = $192;
   $211 = ((($$014$i84)) + 48|0);
   HEAP32[$211>>2] = $7;
   return;
  }
 }
 $194 = (__Znwj(52)|0);
 $195 = ((($194)) + 16|0);
 HEAP32[$195>>2] = $1;
 $196 = ((($194)) + 20|0);
 $197 = ((($194)) + 44|0);
 HEAP32[$197>>2] = 0;
 $198 = ((($194)) + 48|0);
 HEAP32[$198>>2] = 0;
 ;HEAP32[$196>>2]=0|0;HEAP32[$196+4>>2]=0|0;HEAP32[$196+8>>2]=0|0;HEAP32[$196+12>>2]=0|0;HEAP32[$196+16>>2]=0|0;HEAP8[$196+20>>0]=0|0;
 HEAP32[$194>>2] = 0;
 $199 = ((($194)) + 4|0);
 HEAP32[$199>>2] = 0;
 $200 = ((($194)) + 8|0);
 HEAP32[$200>>2] = $$04358$i80;
 HEAP32[$$025$i59$i79>>2] = $194;
 $201 = HEAP32[$9>>2]|0;
 $202 = HEAP32[$201>>2]|0;
 $203 = ($202|0)==(0|0);
 if ($203) {
  $207 = $194;
 } else {
  $204 = $202;
  HEAP32[$9>>2] = $204;
  $$pre$i$i82 = HEAP32[$$025$i59$i79>>2]|0;
  $207 = $$pre$i$i82;
 }
 $205 = ((($0)) + 588|0);
 $206 = HEAP32[$205>>2]|0;
 __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($206,$207);
 $208 = ((($0)) + 592|0);
 $209 = HEAP32[$208>>2]|0;
 $210 = (($209) + 1)|0;
 HEAP32[$208>>2] = $210;
 $$014$i84 = $194;
 $211 = ((($$014$i84)) + 48|0);
 HEAP32[$211>>2] = $7;
 return;
}
function __ZN3osg6Camera20setProcessorAffinityERKN11OpenThreads8AffinityE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy1 = sp + 12|0;
 $$byval_copy = sp + 8|0;
 $2 = sp + 4|0;
 $3 = sp;
 $4 = ((($0)) + 608|0);
 $5 = ($4|0)==($1|0);
 if (!($5)) {
  $6 = HEAP32[$1>>2]|0;
  HEAP32[$2>>2] = $6;
  $7 = ((($1)) + 4|0);
  HEAP32[$3>>2] = $7;
  ;HEAP32[$$byval_copy>>2]=HEAP32[$2>>2]|0;
  ;HEAP32[$$byval_copy1>>2]=HEAP32[$3>>2]|0;
  __ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEE14__assign_multiINS_21__tree_const_iteratorIjPNS_11__tree_nodeIjPvEEiEEEEvT_SD_($4,$$byval_copy,$$byval_copy1);
 }
 $8 = ((($0)) + 620|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if ($10) {
  STACKTOP = sp;return;
 }
 $11 = ((($9)) + 12|0);
 (__ZN11OpenThreads6Thread20setProcessorAffinityERKNS_8AffinityE($11,$1)|0);
 STACKTOP = sp;return;
}
function __ZN3osg6Camera18createCameraThreadEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 620|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  return;
 }
 $4 = (__Znwj(52)|0);
 __THREW__ = 0;
 invoke_vi(3727,($4|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $7 = ___cxa_find_matching_catch_2()|0;
  $8 = tempRet0;
  __ZdlPv($4);
  ___resumeException($7|0);
  // unreachable;
 }
 __ZN3osg6Camera15setCameraThreadEPNS_15OperationThreadE($0,$4);
 return;
}
function __ZN3osg23CollectOccludersVisitorD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = ((56660));
 $1 = ((($0)) + 396|0);
 HEAP32[$1>>2] = ((57032));
 $2 = ((($0)) + 56|0);
 HEAP32[$2>>2] = (56868);
 $3 = ((($0)) + 384|0);
 $4 = ((($0)) + 388|0);
 $5 = HEAP32[$4>>2]|0;
 __ZNSt3__26__treeIN3osg20ShadowVolumeOccluderENS_4lessIS2_EENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($3,$5);
 __THREW__ = 0;
 invoke_vi(1621,($2|0));
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 do {
  if ($7) {
   $10 = ___cxa_find_matching_catch_2()|0;
   $11 = tempRet0;
   __THREW__ = 0;
   invoke_vii(3284,($0|0),((57176)|0));
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if ($13) {
    $14 = ___cxa_find_matching_catch_3(0|0)|0;
    $15 = tempRet0;
    ___clang_call_terminate($14);
    // unreachable;
   } else {
    $eh$lpad$body$index2Z2D = $11;$eh$lpad$body$indexZ2D = $10;
   }
  } else {
   __THREW__ = 0;
   invoke_vii(3284,($0|0),((57176)|0));
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if ($9) {
    $16 = ___cxa_find_matching_catch_2()|0;
    $17 = tempRet0;
    $eh$lpad$body$index2Z2D = $17;$eh$lpad$body$indexZ2D = $16;
    break;
   } else {
    __ZN3osg6ObjectD2Ev($1);
    return;
   }
  }
 } while(0);
 __THREW__ = 0;
 invoke_vi(388,($1|0));
 $18 = __THREW__; __THREW__ = 0;
 $19 = $18&1;
 if ($19) {
  $20 = ___cxa_find_matching_catch_3(0|0)|0;
  $21 = tempRet0;
  ___clang_call_terminate($20);
  // unreachable;
 } else {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
}
function __ZN3osg23CollectOccludersVisitorD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1530,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK3osg23CollectOccludersVisitor9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(432)|0);
 __THREW__ = 0;
 invoke_vi(3578,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $8 = ___cxa_find_matching_catch_2()|0;
  $9 = tempRet0;
  __ZdlPv($1);
  ___resumeException($8|0);
  // unreachable;
 } else {
  $4 = HEAP32[$1>>2]|0;
  $5 = ((($4)) + -12|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($1) + ($6)|0);
  return ($7|0);
 }
 return (0)|0;
}
function __ZNK3osg23CollectOccludersVisitor11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175113|0);
}
function __ZNK3osg23CollectOccludersVisitor9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (120392|0);
}
function __ZN3osg23CollectOccludersVisitor5resetEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 56|0);
 __ZN3osg9CullStack5resetEv($1);
 $2 = ((($0)) + 384|0);
 $3 = ((($0)) + 388|0);
 $4 = HEAP32[$3>>2]|0;
 __ZNSt3__26__treeIN3osg20ShadowVolumeOccluderENS_4lessIS2_EENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($2,$4);
 $5 = ((($0)) + 392|0);
 HEAP32[$5>>2] = 0;
 HEAP32[$2>>2] = $3;
 HEAP32[$3>>2] = 0;
 return;
}
function __ZNK3osg23CollectOccludersVisitor21getDistanceToEyePointERKNS_5Vec3fEb($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0.0, $10 = 0.0, $11 = 0.0, $12 = 0, $13 = 0.0, $14 = 0, $15 = 0.0, $16 = 0.0, $17 = 0.0, $18 = 0.0, $19 = 0.0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0, $24 = 0.0, $25 = 0.0, $3 = 0.0, $4 = 0, $5 = 0.0;
 var $6 = 0.0, $7 = 0, $8 = 0.0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = +HEAPF32[$1>>2];
 $4 = ((($0)) + 240|0);
 $5 = +HEAPF32[$4>>2];
 $6 = $3 - $5;
 $7 = ((($1)) + 4|0);
 $8 = +HEAPF32[$7>>2];
 $9 = ((($0)) + 244|0);
 $10 = +HEAPF32[$9>>2];
 $11 = $8 - $10;
 $12 = ((($1)) + 8|0);
 $13 = +HEAPF32[$12>>2];
 $14 = ((($0)) + 248|0);
 $15 = +HEAPF32[$14>>2];
 $16 = $13 - $15;
 $17 = $6 * $6;
 $18 = $11 * $11;
 $19 = $17 + $18;
 $20 = $16 * $16;
 $21 = $19 + $20;
 $22 = (+Math_sqrt((+$21)));
 if (!($2)) {
  $$0 = $22;
  return (+$$0);
 }
 $23 = ((($0)) + 76|0);
 $24 = +HEAPF32[$23>>2];
 $25 = $22 * $24;
 $$0 = $25;
 return (+$$0);
}
function __ZNK3osg23CollectOccludersVisitor23getDistanceFromEyePointERKNS_5Vec3fEb($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0.0, $12 = 0.0, $13 = 0, $14 = 0.0, $15 = 0.0, $16 = 0.0, $17 = 0, $18 = 0.0, $19 = 0.0, $20 = 0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0, $25 = 0.0, $26 = 0.0, $27 = 0.0, $28 = 0.0, $29 = 0;
 var $3 = 0, $30 = 0.0, $31 = 0.0, $32 = 0.0, $4 = 0, $5 = 0.0, $6 = 0.0, $7 = 0, $8 = 0.0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 152|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = +HEAPF32[$1>>2];
 $6 = $5;
 $7 = ((($4)) + 48|0);
 $8 = +HEAPF64[$7>>3];
 $9 = $6 * $8;
 $10 = ((($1)) + 4|0);
 $11 = +HEAPF32[$10>>2];
 $12 = $11;
 $13 = ((($4)) + 80|0);
 $14 = +HEAPF64[$13>>3];
 $15 = $12 * $14;
 $16 = $9 + $15;
 $17 = ((($1)) + 8|0);
 $18 = +HEAPF32[$17>>2];
 $19 = $18;
 $20 = ((($4)) + 112|0);
 $21 = +HEAPF64[$20>>3];
 $22 = $19 * $21;
 $23 = $16 + $22;
 $24 = ((($4)) + 144|0);
 $25 = +HEAPF64[$24>>3];
 $26 = $25 + $23;
 $27 = $26;
 $28 = -$27;
 if (!($2)) {
  $32 = $28;
  return (+$32);
 }
 $29 = ((($0)) + 76|0);
 $30 = +HEAPF32[$29>>2];
 $31 = $30 * $28;
 $32 = $31;
 return (+$32);
}
function __ZNK3osg23CollectOccludersVisitor22getDistanceToViewPointERKNS_5Vec3fEb($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0.0, $10 = 0.0, $11 = 0.0, $12 = 0, $13 = 0.0, $14 = 0, $15 = 0.0, $16 = 0.0, $17 = 0.0, $18 = 0.0, $19 = 0.0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0, $24 = 0.0, $25 = 0.0, $3 = 0.0, $4 = 0, $5 = 0.0;
 var $6 = 0.0, $7 = 0, $8 = 0.0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = +HEAPF32[$1>>2];
 $4 = ((($0)) + 268|0);
 $5 = +HEAPF32[$4>>2];
 $6 = $3 - $5;
 $7 = ((($1)) + 4|0);
 $8 = +HEAPF32[$7>>2];
 $9 = ((($0)) + 272|0);
 $10 = +HEAPF32[$9>>2];
 $11 = $8 - $10;
 $12 = ((($1)) + 8|0);
 $13 = +HEAPF32[$12>>2];
 $14 = ((($0)) + 276|0);
 $15 = +HEAPF32[$14>>2];
 $16 = $13 - $15;
 $17 = $6 * $6;
 $18 = $11 * $11;
 $19 = $17 + $18;
 $20 = $16 * $16;
 $21 = $19 + $20;
 $22 = (+Math_sqrt((+$21)));
 if (!($2)) {
  $$0 = $22;
  return (+$$0);
 }
 $23 = ((($0)) + 76|0);
 $24 = +HEAPF32[$23>>2];
 $25 = $22 * $24;
 $$0 = $25;
 return (+$$0);
}
function __ZN3osg23CollectOccludersVisitor5applyERNS_4NodeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$pre = 0, $$pre$phiZ2D = 0, $$pre3$pre$phiZZ2D = 0, $$sroa$03$015$i$i = 0, $$sroa$03$07$i$i$i = 0, $$sroa$09$016$i$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $11 = 0, $12 = 0.0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 108|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 do {
  if ($4) {
   $5 = ((($1)) + 104|0);
   $6 = HEAP8[$5>>0]|0;
   $7 = ($6<<24>>24)==(0);
   if ($7) {
    label = 3;
   } else {
    $10 = (__ZNK3osg4Node8getBoundEv($1)|0);
    $11 = ((($10)) + 12|0);
    $12 = +HEAPF32[$11>>2];
    $13 = !($12 >= 0.0);
    $14 = ((($0)) + 336|0);
    $15 = HEAP32[$14>>2]|0;
    if ($13) {
     $$pre3$pre$phiZZ2D = $14;$17 = $15;
     label = 5;
    } else {
     $20 = (__ZNK3osg4Node8getBoundEv($1)|0);
     $21 = (__ZN3osg10CullingSet8isCulledERKNS_18BoundingSphereImplINS_5Vec3fEEE($15,$20)|0);
     if ($21) {
      return;
     } else {
      $$pre = HEAP32[$14>>2]|0;
      $$pre$phiZ2D = $14;$22 = $$pre;
      break;
     }
    }
   }
  } else {
   label = 3;
  }
 } while(0);
 if ((label|0) == 3) {
  $8 = ((($0)) + 336|0);
  $9 = HEAP32[$8>>2]|0;
  $$pre3$pre$phiZZ2D = $8;$17 = $9;
  label = 5;
 }
 if ((label|0) == 5) {
  $16 = ((($17)) + 16|0);
  $18 = HEAP32[$16>>2]|0;
  $19 = ((($17)) + 36|0);
  HEAP32[$19>>2] = $18;
  $$pre$phiZ2D = $$pre3$pre$phiZZ2D;$22 = $17;
 }
 __ZN3osg10CullingSet15pushCurrentMaskEv($22);
 $23 = ((($1)) + 112|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)==(0);
 L13: do {
  if (!($25)) {
   $26 = ((($0)) + 16|0);
   $27 = HEAP32[$26>>2]|0;
   switch ($27|0) {
   case 0:  {
    break L13;
    break;
   }
   case 1:  {
    $28 = HEAP32[$1>>2]|0;
    $29 = ((($28)) + 192|0);
    $30 = HEAP32[$29>>2]|0;
    FUNCTION_TABLE_vii[$30 & 8191]($1,$0);
    break L13;
    break;
   }
   default: {
    $31 = HEAP32[$1>>2]|0;
    $32 = ((($31)) + 196|0);
    $33 = HEAP32[$32>>2]|0;
    FUNCTION_TABLE_vii[$33 & 8191]($1,$0);
    break L13;
   }
   }
  }
 } while(0);
 $34 = HEAP32[$$pre$phiZ2D>>2]|0;
 $35 = ((($34)) + 32|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = ($36|0)==(0);
 if (!($37)) {
  $38 = ((($34)) + 20|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = ((($34)) + 24|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = ($39|0)==($41|0);
  if (!($42)) {
   $43 = ((($41)) + -4|0);
   $44 = HEAP32[$43>>2]|0;
   $45 = ((($34)) + 16|0);
   HEAP32[$45>>2] = $44;
   HEAP32[$40>>2] = $43;
  }
  $46 = (($36) + -1)|0;
  HEAP32[$35>>2] = $46;
 }
 $47 = ((($34)) + 64|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = ((($34)) + 68|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = ($48|0)==($50|0);
 if (!($51)) {
  $$sroa$09$016$i$i = $48;
  while(1) {
   $52 = ((($$sroa$09$016$i$i)) + 20|0);
   $53 = HEAP32[$52>>2]|0;
   $54 = ($53|0)==(0);
   if (!($54)) {
    $55 = ((($$sroa$09$016$i$i)) + 8|0);
    $56 = HEAP32[$55>>2]|0;
    $57 = ((($$sroa$09$016$i$i)) + 12|0);
    $58 = HEAP32[$57>>2]|0;
    $59 = ($56|0)==($58|0);
    if (!($59)) {
     $60 = ((($58)) + -4|0);
     $61 = HEAP32[$60>>2]|0;
     $62 = ((($$sroa$09$016$i$i)) + 4|0);
     HEAP32[$62>>2] = $61;
     HEAP32[$57>>2] = $60;
    }
    $63 = (($53) + -1)|0;
    HEAP32[$52>>2] = $63;
   }
   $64 = ((($$sroa$09$016$i$i)) + 52|0);
   $65 = ($64|0)==($50|0);
   if ($65) {
    break;
   } else {
    $$sroa$09$016$i$i = $64;
   }
  }
 }
 $66 = ((($34)) + 76|0);
 $67 = HEAP32[$66>>2]|0;
 $68 = ((($34)) + 80|0);
 $69 = HEAP32[$68>>2]|0;
 $70 = ($67|0)==($69|0);
 if ($70) {
  return;
 } else {
  $$sroa$03$015$i$i = $67;
 }
 while(1) {
  $71 = ((($$sroa$03$015$i$i)) + 36|0);
  $72 = HEAP32[$71>>2]|0;
  $73 = ($72|0)==(0);
  if (!($73)) {
   $74 = ((($$sroa$03$015$i$i)) + 24|0);
   $75 = HEAP32[$74>>2]|0;
   $76 = ((($$sroa$03$015$i$i)) + 28|0);
   $77 = HEAP32[$76>>2]|0;
   $78 = ($75|0)==($77|0);
   if (!($78)) {
    $79 = ((($77)) + -4|0);
    $80 = HEAP32[$79>>2]|0;
    $81 = ((($$sroa$03$015$i$i)) + 20|0);
    HEAP32[$81>>2] = $80;
    HEAP32[$76>>2] = $79;
   }
   $82 = (($72) + -1)|0;
   HEAP32[$71>>2] = $82;
  }
  $83 = ((($$sroa$03$015$i$i)) + 68|0);
  $84 = HEAP32[$83>>2]|0;
  $85 = ((($$sroa$03$015$i$i)) + 72|0);
  $86 = HEAP32[$85>>2]|0;
  $87 = ($84|0)==($86|0);
  if (!($87)) {
   $$sroa$03$07$i$i$i = $84;
   while(1) {
    $88 = ((($$sroa$03$07$i$i$i)) + 16|0);
    $89 = HEAP32[$88>>2]|0;
    $90 = ($89|0)==(0);
    if (!($90)) {
     $91 = ((($$sroa$03$07$i$i$i)) + 4|0);
     $92 = HEAP32[$91>>2]|0;
     $93 = ((($$sroa$03$07$i$i$i)) + 8|0);
     $94 = HEAP32[$93>>2]|0;
     $95 = ($92|0)==($94|0);
     if (!($95)) {
      $96 = ((($94)) + -4|0);
      $97 = HEAP32[$96>>2]|0;
      HEAP32[$$sroa$03$07$i$i$i>>2] = $97;
      HEAP32[$93>>2] = $96;
     }
     $98 = (($89) + -1)|0;
     HEAP32[$88>>2] = $98;
    }
    $99 = ((($$sroa$03$07$i$i$i)) + 48|0);
    $100 = ($99|0)==($86|0);
    if ($100) {
     break;
    } else {
     $$sroa$03$07$i$i$i = $99;
    }
   }
  }
  $101 = ((($$sroa$03$015$i$i)) + 80|0);
  $102 = ($101|0)==($69|0);
  if ($102) {
   break;
  } else {
   $$sroa$03$015$i$i = $101;
  }
 }
 return;
}
function __ZN3osg23CollectOccludersVisitor5applyERNS_10ProjectionE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$pre = 0, $$pre$phiZ2D = 0, $$pre12$pre$phiZZ2D = 0, $$sroa$03$015$i$i = 0, $$sroa$03$07$i$i$i = 0, $$sroa$09$016$i$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $13 = 0.0, $14 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 56|0);
 $3 = ((($1)) + 108|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 do {
  if ($5) {
   $6 = ((($1)) + 104|0);
   $7 = HEAP8[$6>>0]|0;
   $8 = ($7<<24>>24)==(0);
   if ($8) {
    label = 3;
   } else {
    $11 = (__ZNK3osg4Node8getBoundEv($1)|0);
    $12 = ((($11)) + 12|0);
    $13 = +HEAPF32[$12>>2];
    $14 = !($13 >= 0.0);
    $15 = ((($0)) + 336|0);
    $16 = HEAP32[$15>>2]|0;
    if ($14) {
     $$pre12$pre$phiZZ2D = $15;$18 = $16;
     label = 5;
    } else {
     $21 = (__ZNK3osg4Node8getBoundEv($1)|0);
     $22 = (__ZN3osg10CullingSet8isCulledERKNS_18BoundingSphereImplINS_5Vec3fEEE($16,$21)|0);
     if ($22) {
      return;
     } else {
      $$pre = HEAP32[$15>>2]|0;
      $$pre$phiZ2D = $15;$23 = $$pre;
      break;
     }
    }
   }
  } else {
   label = 3;
  }
 } while(0);
 if ((label|0) == 3) {
  $9 = ((($0)) + 336|0);
  $10 = HEAP32[$9>>2]|0;
  $$pre12$pre$phiZZ2D = $9;$18 = $10;
  label = 5;
 }
 if ((label|0) == 5) {
  $17 = ((($18)) + 16|0);
  $19 = HEAP32[$17>>2]|0;
  $20 = ((($18)) + 36|0);
  HEAP32[$20>>2] = $19;
  $$pre$phiZ2D = $$pre12$pre$phiZZ2D;$23 = $18;
 }
 __ZN3osg10CullingSet15pushCurrentMaskEv($23);
 $24 = ((($1)) + 136|0);
 $25 = (__ZN3osg9CullStack19createOrReuseMatrixERKNS_7MatrixdE($2,$24)|0);
 $26 = ($25|0)==(0|0);
 if (!($26)) {
  $27 = ((($25)) + 8|0);
  $28 = HEAP32[$27>>2]|0;HEAP32[$27>>2] = (($28+1)|0);
 }
 __THREW__ = 0;
 invoke_vii(3580,($2|0),($25|0));
 $29 = __THREW__; __THREW__ = 0;
 $30 = $29&1;
 L16: do {
  if (!($30)) {
   $31 = ((($1)) + 112|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ($32|0)==(0);
   L18: do {
    if (!($33)) {
     $34 = ((($0)) + 16|0);
     $35 = HEAP32[$34>>2]|0;
     switch ($35|0) {
     case 0:  {
      break L18;
      break;
     }
     case 1:  {
      $36 = HEAP32[$1>>2]|0;
      $37 = ((($36)) + 192|0);
      $38 = HEAP32[$37>>2]|0;
      __THREW__ = 0;
      invoke_vii($38|0,($1|0),($0|0));
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if ($40) {
       break L16;
      } else {
       break L18;
      }
      break;
     }
     default: {
      $41 = HEAP32[$1>>2]|0;
      $42 = ((($41)) + 196|0);
      $43 = HEAP32[$42>>2]|0;
      __THREW__ = 0;
      invoke_vii($43|0,($1|0),($0|0));
      $44 = __THREW__; __THREW__ = 0;
      $45 = $44&1;
      if ($45) {
       break L16;
      } else {
       break L18;
      }
     }
     }
    }
   } while(0);
   __THREW__ = 0;
   invoke_vi(3583,($2|0));
   $46 = __THREW__; __THREW__ = 0;
   $47 = $46&1;
   if (!($47)) {
    $48 = HEAP32[$$pre$phiZ2D>>2]|0;
    $49 = ((($48)) + 32|0);
    $50 = HEAP32[$49>>2]|0;
    $51 = ($50|0)==(0);
    if (!($51)) {
     $52 = ((($48)) + 20|0);
     $53 = HEAP32[$52>>2]|0;
     $54 = ((($48)) + 24|0);
     $55 = HEAP32[$54>>2]|0;
     $56 = ($53|0)==($55|0);
     if (!($56)) {
      $57 = ((($55)) + -4|0);
      $58 = HEAP32[$57>>2]|0;
      $59 = ((($48)) + 16|0);
      HEAP32[$59>>2] = $58;
      HEAP32[$54>>2] = $57;
     }
     $60 = (($50) + -1)|0;
     HEAP32[$49>>2] = $60;
    }
    $61 = ((($48)) + 64|0);
    $62 = HEAP32[$61>>2]|0;
    $63 = ((($48)) + 68|0);
    $64 = HEAP32[$63>>2]|0;
    $65 = ($62|0)==($64|0);
    if (!($65)) {
     $$sroa$09$016$i$i = $62;
     while(1) {
      $66 = ((($$sroa$09$016$i$i)) + 20|0);
      $67 = HEAP32[$66>>2]|0;
      $68 = ($67|0)==(0);
      if (!($68)) {
       $69 = ((($$sroa$09$016$i$i)) + 8|0);
       $70 = HEAP32[$69>>2]|0;
       $71 = ((($$sroa$09$016$i$i)) + 12|0);
       $72 = HEAP32[$71>>2]|0;
       $73 = ($70|0)==($72|0);
       if (!($73)) {
        $74 = ((($72)) + -4|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = ((($$sroa$09$016$i$i)) + 4|0);
        HEAP32[$76>>2] = $75;
        HEAP32[$71>>2] = $74;
       }
       $77 = (($67) + -1)|0;
       HEAP32[$66>>2] = $77;
      }
      $78 = ((($$sroa$09$016$i$i)) + 52|0);
      $79 = ($78|0)==($64|0);
      if ($79) {
       break;
      } else {
       $$sroa$09$016$i$i = $78;
      }
     }
    }
    $80 = ((($48)) + 76|0);
    $81 = HEAP32[$80>>2]|0;
    $82 = ((($48)) + 80|0);
    $83 = HEAP32[$82>>2]|0;
    $84 = ($81|0)==($83|0);
    if (!($84)) {
     $$sroa$03$015$i$i = $81;
     while(1) {
      $85 = ((($$sroa$03$015$i$i)) + 36|0);
      $86 = HEAP32[$85>>2]|0;
      $87 = ($86|0)==(0);
      if (!($87)) {
       $88 = ((($$sroa$03$015$i$i)) + 24|0);
       $89 = HEAP32[$88>>2]|0;
       $90 = ((($$sroa$03$015$i$i)) + 28|0);
       $91 = HEAP32[$90>>2]|0;
       $92 = ($89|0)==($91|0);
       if (!($92)) {
        $93 = ((($91)) + -4|0);
        $94 = HEAP32[$93>>2]|0;
        $95 = ((($$sroa$03$015$i$i)) + 20|0);
        HEAP32[$95>>2] = $94;
        HEAP32[$90>>2] = $93;
       }
       $96 = (($86) + -1)|0;
       HEAP32[$85>>2] = $96;
      }
      $97 = ((($$sroa$03$015$i$i)) + 68|0);
      $98 = HEAP32[$97>>2]|0;
      $99 = ((($$sroa$03$015$i$i)) + 72|0);
      $100 = HEAP32[$99>>2]|0;
      $101 = ($98|0)==($100|0);
      if (!($101)) {
       $$sroa$03$07$i$i$i = $98;
       while(1) {
        $102 = ((($$sroa$03$07$i$i$i)) + 16|0);
        $103 = HEAP32[$102>>2]|0;
        $104 = ($103|0)==(0);
        if (!($104)) {
         $105 = ((($$sroa$03$07$i$i$i)) + 4|0);
         $106 = HEAP32[$105>>2]|0;
         $107 = ((($$sroa$03$07$i$i$i)) + 8|0);
         $108 = HEAP32[$107>>2]|0;
         $109 = ($106|0)==($108|0);
         if (!($109)) {
          $110 = ((($108)) + -4|0);
          $111 = HEAP32[$110>>2]|0;
          HEAP32[$$sroa$03$07$i$i$i>>2] = $111;
          HEAP32[$107>>2] = $110;
         }
         $112 = (($103) + -1)|0;
         HEAP32[$102>>2] = $112;
        }
        $113 = ((($$sroa$03$07$i$i$i)) + 48|0);
        $114 = ($113|0)==($100|0);
        if ($114) {
         break;
        } else {
         $$sroa$03$07$i$i$i = $113;
        }
       }
      }
      $115 = ((($$sroa$03$015$i$i)) + 80|0);
      $116 = ($115|0)==($83|0);
      if ($116) {
       break;
      } else {
       $$sroa$03$015$i$i = $115;
      }
     }
    }
    if ($26) {
     return;
    }
    $117 = ((($25)) + 8|0);
    $118 = HEAP32[$117>>2]|0;HEAP32[$117>>2] = (($118-1)|0);
    $119 = ($118|0)==(1);
    if (!($119)) {
     return;
    }
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($25,1,1);
    return;
   }
  }
 } while(0);
 $120 = ___cxa_find_matching_catch_2()|0;
 $121 = tempRet0;
 if ($26) {
  ___resumeException($120|0);
  // unreachable;
 }
 $122 = ((($25)) + 8|0);
 $123 = HEAP32[$122>>2]|0;HEAP32[$122>>2] = (($123-1)|0);
 $124 = ($123|0)==(1);
 if (!($124)) {
  ___resumeException($120|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(3262,($25|0),1,1);
 $125 = __THREW__; __THREW__ = 0;
 $126 = $125&1;
 if ($126) {
  $127 = ___cxa_find_matching_catch_3(0|0)|0;
  $128 = tempRet0;
  ___clang_call_terminate($127);
  // unreachable;
 } else {
  ___resumeException($120|0);
  // unreachable;
 }
}
function __ZN3osg23CollectOccludersVisitor5applyERNS_9TransformE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$pre = 0, $$pre$phiZ2D = 0, $$pre14$pre$phiZZ2D = 0, $$sink$i = 0, $$sroa$03$015$i$i = 0, $$sroa$03$07$i$i$i = 0, $$sroa$09$016$i$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0.0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 56|0);
 $3 = ((($1)) + 108|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 do {
  if ($5) {
   $6 = ((($1)) + 104|0);
   $7 = HEAP8[$6>>0]|0;
   $8 = ($7<<24>>24)==(0);
   if ($8) {
    label = 3;
   } else {
    $11 = (__ZNK3osg4Node8getBoundEv($1)|0);
    $12 = ((($11)) + 12|0);
    $13 = +HEAPF32[$12>>2];
    $14 = !($13 >= 0.0);
    $15 = ((($0)) + 336|0);
    $16 = HEAP32[$15>>2]|0;
    if ($14) {
     $$pre14$pre$phiZZ2D = $15;$18 = $16;
     label = 5;
    } else {
     $21 = (__ZNK3osg4Node8getBoundEv($1)|0);
     $22 = (__ZN3osg10CullingSet8isCulledERKNS_18BoundingSphereImplINS_5Vec3fEEE($16,$21)|0);
     if ($22) {
      return;
     } else {
      $$pre = HEAP32[$15>>2]|0;
      $$pre$phiZ2D = $15;$23 = $$pre;
      break;
     }
    }
   }
  } else {
   label = 3;
  }
 } while(0);
 if ((label|0) == 3) {
  $9 = ((($0)) + 336|0);
  $10 = HEAP32[$9>>2]|0;
  $$pre14$pre$phiZZ2D = $9;$18 = $10;
  label = 5;
 }
 if ((label|0) == 5) {
  $17 = ((($18)) + 16|0);
  $19 = HEAP32[$17>>2]|0;
  $20 = ((($18)) + 36|0);
  HEAP32[$20>>2] = $19;
  $$pre$phiZ2D = $$pre14$pre$phiZZ2D;$23 = $18;
 }
 __ZN3osg10CullingSet15pushCurrentMaskEv($23);
 $24 = ((($0)) + 168|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)==(0);
 $27 = ((($0)) + 152|0);
 $28 = ((($0)) + 352|0);
 $$sink$i = $26 ? $28 : $27;
 $29 = HEAP32[$$sink$i>>2]|0;
 $30 = ((($29)) + 32|0);
 $31 = (__ZN3osg9CullStack19createOrReuseMatrixERKNS_7MatrixdE($2,$30)|0);
 $32 = ($31|0)==(0|0);
 if (!($32)) {
  $33 = ((($31)) + 8|0);
  $34 = HEAP32[$33>>2]|0;HEAP32[$33>>2] = (($34+1)|0);
 }
 $35 = HEAP32[$1>>2]|0;
 $36 = ((($35)) + 264|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = ((($31)) + 32|0);
 __THREW__ = 0;
 (invoke_iiii($37|0,($1|0),($38|0),($0|0))|0);
 $39 = __THREW__; __THREW__ = 0;
 $40 = $39&1;
 L16: do {
  if (!($40)) {
   $41 = ((($1)) + 136|0);
   $42 = HEAP32[$41>>2]|0;
   __THREW__ = 0;
   invoke_viii(3581,($2|0),($31|0),($42|0));
   $43 = __THREW__; __THREW__ = 0;
   $44 = $43&1;
   if (!($44)) {
    $45 = ((($1)) + 112|0);
    $46 = HEAP32[$45>>2]|0;
    $47 = ($46|0)==(0);
    L19: do {
     if (!($47)) {
      $48 = ((($0)) + 16|0);
      $49 = HEAP32[$48>>2]|0;
      switch ($49|0) {
      case 0:  {
       break L19;
       break;
      }
      case 1:  {
       $50 = HEAP32[$1>>2]|0;
       $51 = ((($50)) + 192|0);
       $52 = HEAP32[$51>>2]|0;
       __THREW__ = 0;
       invoke_vii($52|0,($1|0),($0|0));
       $53 = __THREW__; __THREW__ = 0;
       $54 = $53&1;
       if ($54) {
        break L16;
       } else {
        break L19;
       }
       break;
      }
      default: {
       $55 = HEAP32[$1>>2]|0;
       $56 = ((($55)) + 196|0);
       $57 = HEAP32[$56>>2]|0;
       __THREW__ = 0;
       invoke_vii($57|0,($1|0),($0|0));
       $58 = __THREW__; __THREW__ = 0;
       $59 = $58&1;
       if ($59) {
        break L16;
       } else {
        break L19;
       }
      }
      }
     }
    } while(0);
    __THREW__ = 0;
    invoke_vi(3582,($2|0));
    $60 = __THREW__; __THREW__ = 0;
    $61 = $60&1;
    if (!($61)) {
     $62 = HEAP32[$$pre$phiZ2D>>2]|0;
     $63 = ((($62)) + 32|0);
     $64 = HEAP32[$63>>2]|0;
     $65 = ($64|0)==(0);
     if (!($65)) {
      $66 = ((($62)) + 20|0);
      $67 = HEAP32[$66>>2]|0;
      $68 = ((($62)) + 24|0);
      $69 = HEAP32[$68>>2]|0;
      $70 = ($67|0)==($69|0);
      if (!($70)) {
       $71 = ((($69)) + -4|0);
       $72 = HEAP32[$71>>2]|0;
       $73 = ((($62)) + 16|0);
       HEAP32[$73>>2] = $72;
       HEAP32[$68>>2] = $71;
      }
      $74 = (($64) + -1)|0;
      HEAP32[$63>>2] = $74;
     }
     $75 = ((($62)) + 64|0);
     $76 = HEAP32[$75>>2]|0;
     $77 = ((($62)) + 68|0);
     $78 = HEAP32[$77>>2]|0;
     $79 = ($76|0)==($78|0);
     if (!($79)) {
      $$sroa$09$016$i$i = $76;
      while(1) {
       $80 = ((($$sroa$09$016$i$i)) + 20|0);
       $81 = HEAP32[$80>>2]|0;
       $82 = ($81|0)==(0);
       if (!($82)) {
        $83 = ((($$sroa$09$016$i$i)) + 8|0);
        $84 = HEAP32[$83>>2]|0;
        $85 = ((($$sroa$09$016$i$i)) + 12|0);
        $86 = HEAP32[$85>>2]|0;
        $87 = ($84|0)==($86|0);
        if (!($87)) {
         $88 = ((($86)) + -4|0);
         $89 = HEAP32[$88>>2]|0;
         $90 = ((($$sroa$09$016$i$i)) + 4|0);
         HEAP32[$90>>2] = $89;
         HEAP32[$85>>2] = $88;
        }
        $91 = (($81) + -1)|0;
        HEAP32[$80>>2] = $91;
       }
       $92 = ((($$sroa$09$016$i$i)) + 52|0);
       $93 = ($92|0)==($78|0);
       if ($93) {
        break;
       } else {
        $$sroa$09$016$i$i = $92;
       }
      }
     }
     $94 = ((($62)) + 76|0);
     $95 = HEAP32[$94>>2]|0;
     $96 = ((($62)) + 80|0);
     $97 = HEAP32[$96>>2]|0;
     $98 = ($95|0)==($97|0);
     if (!($98)) {
      $$sroa$03$015$i$i = $95;
      while(1) {
       $99 = ((($$sroa$03$015$i$i)) + 36|0);
       $100 = HEAP32[$99>>2]|0;
       $101 = ($100|0)==(0);
       if (!($101)) {
        $102 = ((($$sroa$03$015$i$i)) + 24|0);
        $103 = HEAP32[$102>>2]|0;
        $104 = ((($$sroa$03$015$i$i)) + 28|0);
        $105 = HEAP32[$104>>2]|0;
        $106 = ($103|0)==($105|0);
        if (!($106)) {
         $107 = ((($105)) + -4|0);
         $108 = HEAP32[$107>>2]|0;
         $109 = ((($$sroa$03$015$i$i)) + 20|0);
         HEAP32[$109>>2] = $108;
         HEAP32[$104>>2] = $107;
        }
        $110 = (($100) + -1)|0;
        HEAP32[$99>>2] = $110;
       }
       $111 = ((($$sroa$03$015$i$i)) + 68|0);
       $112 = HEAP32[$111>>2]|0;
       $113 = ((($$sroa$03$015$i$i)) + 72|0);
       $114 = HEAP32[$113>>2]|0;
       $115 = ($112|0)==($114|0);
       if (!($115)) {
        $$sroa$03$07$i$i$i = $112;
        while(1) {
         $116 = ((($$sroa$03$07$i$i$i)) + 16|0);
         $117 = HEAP32[$116>>2]|0;
         $118 = ($117|0)==(0);
         if (!($118)) {
          $119 = ((($$sroa$03$07$i$i$i)) + 4|0);
          $120 = HEAP32[$119>>2]|0;
          $121 = ((($$sroa$03$07$i$i$i)) + 8|0);
          $122 = HEAP32[$121>>2]|0;
          $123 = ($120|0)==($122|0);
          if (!($123)) {
           $124 = ((($122)) + -4|0);
           $125 = HEAP32[$124>>2]|0;
           HEAP32[$$sroa$03$07$i$i$i>>2] = $125;
           HEAP32[$121>>2] = $124;
          }
          $126 = (($117) + -1)|0;
          HEAP32[$116>>2] = $126;
         }
         $127 = ((($$sroa$03$07$i$i$i)) + 48|0);
         $128 = ($127|0)==($114|0);
         if ($128) {
          break;
         } else {
          $$sroa$03$07$i$i$i = $127;
         }
        }
       }
       $129 = ((($$sroa$03$015$i$i)) + 80|0);
       $130 = ($129|0)==($97|0);
       if ($130) {
        break;
       } else {
        $$sroa$03$015$i$i = $129;
       }
      }
     }
     if ($32) {
      return;
     }
     $131 = ((($31)) + 8|0);
     $132 = HEAP32[$131>>2]|0;HEAP32[$131>>2] = (($132-1)|0);
     $133 = ($132|0)==(1);
     if (!($133)) {
      return;
     }
     __ZNK3osg10Referenced24signalObserversAndDeleteEbb($31,1,1);
     return;
    }
   }
  }
 } while(0);
 $134 = ___cxa_find_matching_catch_2()|0;
 $135 = tempRet0;
 if ($32) {
  ___resumeException($134|0);
  // unreachable;
 }
 $136 = ((($31)) + 8|0);
 $137 = HEAP32[$136>>2]|0;HEAP32[$136>>2] = (($137-1)|0);
 $138 = ($137|0)==(1);
 if (!($138)) {
  ___resumeException($134|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(3262,($31|0),1,1);
 $139 = __THREW__; __THREW__ = 0;
 $140 = $139&1;
 if ($140) {
  $141 = ___cxa_find_matching_catch_3(0|0)|0;
  $142 = tempRet0;
  ___clang_call_terminate($141);
  // unreachable;
 } else {
  ___resumeException($134|0);
  // unreachable;
 }
}
function __ZN3osg23CollectOccludersVisitor5applyERNS_6SwitchE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $3 = ((($2)) + 108|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 8191]($0,$1);
 return;
}
function __ZN3osg23CollectOccludersVisitor5applyERNS_3LODE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$pre = 0, $$pre$phiZ2D = 0, $$pre3$pre$phiZZ2D = 0, $$sroa$03$015$i$i = 0, $$sroa$03$07$i$i$i = 0, $$sroa$09$016$i$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $11 = 0, $12 = 0.0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 108|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 do {
  if ($4) {
   $5 = ((($1)) + 104|0);
   $6 = HEAP8[$5>>0]|0;
   $7 = ($6<<24>>24)==(0);
   if ($7) {
    label = 3;
   } else {
    $10 = (__ZNK3osg4Node8getBoundEv($1)|0);
    $11 = ((($10)) + 12|0);
    $12 = +HEAPF32[$11>>2];
    $13 = !($12 >= 0.0);
    $14 = ((($0)) + 336|0);
    $15 = HEAP32[$14>>2]|0;
    if ($13) {
     $$pre3$pre$phiZZ2D = $14;$17 = $15;
     label = 5;
    } else {
     $20 = (__ZNK3osg4Node8getBoundEv($1)|0);
     $21 = (__ZN3osg10CullingSet8isCulledERKNS_18BoundingSphereImplINS_5Vec3fEEE($15,$20)|0);
     if ($21) {
      return;
     } else {
      $$pre = HEAP32[$14>>2]|0;
      $$pre$phiZ2D = $14;$22 = $$pre;
      break;
     }
    }
   }
  } else {
   label = 3;
  }
 } while(0);
 if ((label|0) == 3) {
  $8 = ((($0)) + 336|0);
  $9 = HEAP32[$8>>2]|0;
  $$pre3$pre$phiZZ2D = $8;$17 = $9;
  label = 5;
 }
 if ((label|0) == 5) {
  $16 = ((($17)) + 16|0);
  $18 = HEAP32[$16>>2]|0;
  $19 = ((($17)) + 36|0);
  HEAP32[$19>>2] = $18;
  $$pre$phiZ2D = $$pre3$pre$phiZZ2D;$22 = $17;
 }
 __ZN3osg10CullingSet15pushCurrentMaskEv($22);
 $23 = ((($1)) + 112|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)==(0);
 L13: do {
  if (!($25)) {
   $26 = ((($0)) + 16|0);
   $27 = HEAP32[$26>>2]|0;
   switch ($27|0) {
   case 0:  {
    break L13;
    break;
   }
   case 1:  {
    $28 = HEAP32[$1>>2]|0;
    $29 = ((($28)) + 192|0);
    $30 = HEAP32[$29>>2]|0;
    FUNCTION_TABLE_vii[$30 & 8191]($1,$0);
    break L13;
    break;
   }
   default: {
    $31 = HEAP32[$1>>2]|0;
    $32 = ((($31)) + 196|0);
    $33 = HEAP32[$32>>2]|0;
    FUNCTION_TABLE_vii[$33 & 8191]($1,$0);
    break L13;
   }
   }
  }
 } while(0);
 $34 = HEAP32[$$pre$phiZ2D>>2]|0;
 $35 = ((($34)) + 32|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = ($36|0)==(0);
 if (!($37)) {
  $38 = ((($34)) + 20|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = ((($34)) + 24|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = ($39|0)==($41|0);
  if (!($42)) {
   $43 = ((($41)) + -4|0);
   $44 = HEAP32[$43>>2]|0;
   $45 = ((($34)) + 16|0);
   HEAP32[$45>>2] = $44;
   HEAP32[$40>>2] = $43;
  }
  $46 = (($36) + -1)|0;
  HEAP32[$35>>2] = $46;
 }
 $47 = ((($34)) + 64|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = ((($34)) + 68|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = ($48|0)==($50|0);
 if (!($51)) {
  $$sroa$09$016$i$i = $48;
  while(1) {
   $52 = ((($$sroa$09$016$i$i)) + 20|0);
   $53 = HEAP32[$52>>2]|0;
   $54 = ($53|0)==(0);
   if (!($54)) {
    $55 = ((($$sroa$09$016$i$i)) + 8|0);
    $56 = HEAP32[$55>>2]|0;
    $57 = ((($$sroa$09$016$i$i)) + 12|0);
    $58 = HEAP32[$57>>2]|0;
    $59 = ($56|0)==($58|0);
    if (!($59)) {
     $60 = ((($58)) + -4|0);
     $61 = HEAP32[$60>>2]|0;
     $62 = ((($$sroa$09$016$i$i)) + 4|0);
     HEAP32[$62>>2] = $61;
     HEAP32[$57>>2] = $60;
    }
    $63 = (($53) + -1)|0;
    HEAP32[$52>>2] = $63;
   }
   $64 = ((($$sroa$09$016$i$i)) + 52|0);
   $65 = ($64|0)==($50|0);
   if ($65) {
    break;
   } else {
    $$sroa$09$016$i$i = $64;
   }
  }
 }
 $66 = ((($34)) + 76|0);
 $67 = HEAP32[$66>>2]|0;
 $68 = ((($34)) + 80|0);
 $69 = HEAP32[$68>>2]|0;
 $70 = ($67|0)==($69|0);
 if ($70) {
  return;
 } else {
  $$sroa$03$015$i$i = $67;
 }
 while(1) {
  $71 = ((($$sroa$03$015$i$i)) + 36|0);
  $72 = HEAP32[$71>>2]|0;
  $73 = ($72|0)==(0);
  if (!($73)) {
   $74 = ((($$sroa$03$015$i$i)) + 24|0);
   $75 = HEAP32[$74>>2]|0;
   $76 = ((($$sroa$03$015$i$i)) + 28|0);
   $77 = HEAP32[$76>>2]|0;
   $78 = ($75|0)==($77|0);
   if (!($78)) {
    $79 = ((($77)) + -4|0);
    $80 = HEAP32[$79>>2]|0;
    $81 = ((($$sroa$03$015$i$i)) + 20|0);
    HEAP32[$81>>2] = $80;
    HEAP32[$76>>2] = $79;
   }
   $82 = (($72) + -1)|0;
   HEAP32[$71>>2] = $82;
  }
  $83 = ((($$sroa$03$015$i$i)) + 68|0);
  $84 = HEAP32[$83>>2]|0;
  $85 = ((($$sroa$03$015$i$i)) + 72|0);
  $86 = HEAP32[$85>>2]|0;
  $87 = ($84|0)==($86|0);
  if (!($87)) {
   $$sroa$03$07$i$i$i = $84;
   while(1) {
    $88 = ((($$sroa$03$07$i$i$i)) + 16|0);
    $89 = HEAP32[$88>>2]|0;
    $90 = ($89|0)==(0);
    if (!($90)) {
     $91 = ((($$sroa$03$07$i$i$i)) + 4|0);
     $92 = HEAP32[$91>>2]|0;
     $93 = ((($$sroa$03$07$i$i$i)) + 8|0);
     $94 = HEAP32[$93>>2]|0;
     $95 = ($92|0)==($94|0);
     if (!($95)) {
      $96 = ((($94)) + -4|0);
      $97 = HEAP32[$96>>2]|0;
      HEAP32[$$sroa$03$07$i$i$i>>2] = $97;
      HEAP32[$93>>2] = $96;
     }
     $98 = (($89) + -1)|0;
     HEAP32[$88>>2] = $98;
    }
    $99 = ((($$sroa$03$07$i$i$i)) + 48|0);
    $100 = ($99|0)==($86|0);
    if ($100) {
     break;
    } else {
     $$sroa$03$07$i$i$i = $99;
    }
   }
  }
  $101 = ((($$sroa$03$015$i$i)) + 80|0);
  $102 = ($101|0)==($69|0);
  if ($102) {
   break;
  } else {
   $$sroa$03$015$i$i = $101;
  }
 }
 return;
}
function __ZN3osg23CollectOccludersVisitor5applyERNS_12OccluderNodeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i$i$i = 0, $$0$ph$i$i$i$i = 0, $$024$i$i$i$i = 0, $$025$i$i$i$i = 0, $$039$i$i$i = 0, $$in$i$i$i$i = 0, $$pre$i$i$i$i = 0, $$sroa$03$015$i$i = 0, $$sroa$03$07$i$i$i = 0, $$sroa$09$016$i$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0.0, $160 = 0, $161 = 0, $162 = 0;
 var $163 = 0, $164 = 0, $165 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0.0, $41 = 0, $42 = 0.0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0.0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(80|0);
 $2 = sp;
 $3 = ((($0)) + 56|0);
 $4 = ((($0)) + 28|0);
 $5 = ((($0)) + 336|0);
 $6 = HEAP32[$5>>2]|0;
 __ZN3osg10CullingSet34disableAndPushOccludersCurrentMaskERNSt3__26vectorIPNS_4NodeENS1_9allocatorIS4_EEEE($6,$4);
 $7 = ((($1)) + 108|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0);
 if ($9) {
  $10 = ((($1)) + 104|0);
  $11 = HEAP8[$10>>0]|0;
  $12 = ($11<<24>>24)==(0);
  if ($12) {
   label = 3;
  } else {
   $14 = (__ZNK3osg4Node8getBoundEv($1)|0);
   $15 = ((($14)) + 12|0);
   $16 = +HEAPF32[$15>>2];
   $17 = !($16 >= 0.0);
   $18 = HEAP32[$5>>2]|0;
   if ($17) {
    $20 = $18;
    label = 5;
   } else {
    $23 = (__ZNK3osg4Node8getBoundEv($1)|0);
    $24 = (__ZN3osg10CullingSet8isCulledERKNS_18BoundingSphereImplINS_5Vec3fEEE($18,$23)|0);
    $25 = HEAP32[$5>>2]|0;
    if ($24) {
     __ZN3osg10CullingSet23popOccludersCurrentMaskERNSt3__26vectorIPNS_4NodeENS1_9allocatorIS4_EEEE($25,$4);
     STACKTOP = sp;return;
    } else {
     $26 = $25;
    }
   }
  }
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $13 = HEAP32[$5>>2]|0;
  $20 = $13;
  label = 5;
 }
 if ((label|0) == 5) {
  $19 = ((($20)) + 16|0);
  $21 = HEAP32[$19>>2]|0;
  $22 = ((($20)) + 36|0);
  HEAP32[$22>>2] = $21;
  $26 = $20;
 }
 __ZN3osg10CullingSet15pushCurrentMaskEv($26);
 $27 = ((($1)) + 136|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = ($28|0)==(0|0);
 L12: do {
  if (!($29)) {
   $30 = ((($2)) + 36|0);
   dest=$2; stop=dest+68|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
   HEAP32[$30>>2] = 1;
   $31 = ((($2)) + 68|0);
   HEAP32[$31>>2] = 0;
   $32 = ((($2)) + 72|0);
   HEAP32[$32>>2] = 0;
   $33 = ((($2)) + 76|0);
   HEAP32[$33>>2] = 0;
   $34 = ((($0)) + 380|0);
   $35 = HEAP8[$34>>0]|0;
   $36 = ($35<<24>>24)!=(0);
   __THREW__ = 0;
   $37 = (invoke_iiiiii(3728,($2|0),($4|0),($28|0),($3|0),($36|0))|0);
   $38 = __THREW__; __THREW__ = 0;
   $39 = $38&1;
   do {
    if ($39) {
     label = 30;
    } else {
     if ($37) {
      $40 = +HEAPF32[$2>>2];
      $41 = ((($0)) + 372|0);
      $42 = +HEAPF32[$41>>2];
      $43 = $40 > $42;
      if ($43) {
       $44 = ((($0)) + 384|0);
       $45 = ((($0)) + 388|0);
       $46 = HEAP32[$45>>2]|0;
       $47 = ($46|0)==(0|0);
       do {
        if ($47) {
         $$025$i$i$i$i = $45;$$039$i$i$i = $45;
        } else {
         $48 = ((($0)) + 388|0);
         $$0$i$i$i$i = $48;$$024$i$i$i$i = $46;
         while(1) {
          $49 = ((($$024$i$i$i$i)) + 16|0);
          $50 = +HEAPF32[$49>>2];
          $51 = $40 > $50;
          if ($51) {
           $52 = HEAP32[$$024$i$i$i$i>>2]|0;
           $53 = ($52|0)==(0|0);
           if ($53) {
            label = 17;
            break;
           } else {
            $$0$ph$i$i$i$i = $$024$i$i$i$i;$$in$i$i$i$i = $52;
           }
          } else {
           $54 = $50 > $40;
           if (!($54)) {
            label = 21;
            break;
           }
           $55 = ((($$024$i$i$i$i)) + 4|0);
           $56 = HEAP32[$55>>2]|0;
           $57 = ($56|0)==(0|0);
           if ($57) {
            label = 20;
            break;
           } else {
            $$0$ph$i$i$i$i = $55;$$in$i$i$i$i = $56;
           }
          }
          $$0$i$i$i$i = $$0$ph$i$i$i$i;$$024$i$i$i$i = $$in$i$i$i$i;
         }
         if ((label|0) == 17) {
          $$025$i$i$i$i = $$024$i$i$i$i;$$039$i$i$i = $$024$i$i$i$i;
          break;
         }
         else if ((label|0) == 20) {
          $$025$i$i$i$i = $55;$$039$i$i$i = $$024$i$i$i$i;
          break;
         }
         else if ((label|0) == 21) {
          $$025$i$i$i$i = $$0$i$i$i$i;$$039$i$i$i = $$024$i$i$i$i;
          break;
         }
        }
       } while(0);
       $58 = HEAP32[$$025$i$i$i$i>>2]|0;
       $59 = ($58|0)==(0|0);
       if ($59) {
        __THREW__ = 0;
        $60 = (invoke_ii(3276,96)|0);
        $61 = __THREW__; __THREW__ = 0;
        $62 = $61&1;
        if ($62) {
         label = 30;
         break;
        }
        $63 = ((($60)) + 16|0);
        __THREW__ = 0;
        invoke_vii(3587,($63|0),($2|0));
        $64 = __THREW__; __THREW__ = 0;
        $65 = $64&1;
        if ($65) {
         $66 = ___cxa_find_matching_catch_2()|0;
         $67 = tempRet0;
         __ZdlPv($60);
         $eh$lpad$body$index2Z2D = $67;$eh$lpad$body$indexZ2D = $66;
         break;
        }
        HEAP32[$60>>2] = 0;
        $68 = ((($60)) + 4|0);
        HEAP32[$68>>2] = 0;
        $69 = ((($60)) + 8|0);
        HEAP32[$69>>2] = $$039$i$i$i;
        HEAP32[$$025$i$i$i$i>>2] = $60;
        $70 = HEAP32[$44>>2]|0;
        $71 = HEAP32[$70>>2]|0;
        $72 = ($71|0)==(0|0);
        if ($72) {
         $76 = $60;
        } else {
         $73 = $71;
         HEAP32[$44>>2] = $73;
         $$pre$i$i$i$i = HEAP32[$$025$i$i$i$i>>2]|0;
         $76 = $$pre$i$i$i$i;
        }
        $74 = ((($0)) + 388|0);
        $75 = HEAP32[$74>>2]|0;
        __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($75,$76);
        $77 = ((($0)) + 392|0);
        $78 = HEAP32[$77>>2]|0;
        $79 = (($78) + 1)|0;
        HEAP32[$77>>2] = $79;
       }
      }
     }
     __ZN3osg20ShadowVolumeOccluderD2Ev($2);
     break L12;
    }
   } while(0);
   if ((label|0) == 30) {
    $80 = ___cxa_find_matching_catch_2()|0;
    $81 = tempRet0;
    $eh$lpad$body$index2Z2D = $81;$eh$lpad$body$indexZ2D = $80;
   }
   __THREW__ = 0;
   invoke_vi(3586,($2|0));
   $82 = __THREW__; __THREW__ = 0;
   $83 = $82&1;
   if ($83) {
    $164 = ___cxa_find_matching_catch_3(0|0)|0;
    $165 = tempRet0;
    ___clang_call_terminate($164);
    // unreachable;
   } else {
    ___resumeException($eh$lpad$body$indexZ2D|0);
    // unreachable;
   }
  }
 } while(0);
 $84 = ((($1)) + 112|0);
 $85 = HEAP32[$84>>2]|0;
 $86 = ($85|0)==(0);
 L50: do {
  if (!($86)) {
   $87 = ((($0)) + 16|0);
   $88 = HEAP32[$87>>2]|0;
   switch ($88|0) {
   case 0:  {
    break L50;
    break;
   }
   case 1:  {
    $89 = HEAP32[$1>>2]|0;
    $90 = ((($89)) + 192|0);
    $91 = HEAP32[$90>>2]|0;
    FUNCTION_TABLE_vii[$91 & 8191]($1,$0);
    break L50;
    break;
   }
   default: {
    $92 = HEAP32[$1>>2]|0;
    $93 = ((($92)) + 196|0);
    $94 = HEAP32[$93>>2]|0;
    FUNCTION_TABLE_vii[$94 & 8191]($1,$0);
    break L50;
   }
   }
  }
 } while(0);
 $95 = HEAP32[$5>>2]|0;
 $96 = ((($95)) + 32|0);
 $97 = HEAP32[$96>>2]|0;
 $98 = ($97|0)==(0);
 if (!($98)) {
  $99 = ((($95)) + 20|0);
  $100 = HEAP32[$99>>2]|0;
  $101 = ((($95)) + 24|0);
  $102 = HEAP32[$101>>2]|0;
  $103 = ($100|0)==($102|0);
  if (!($103)) {
   $104 = ((($102)) + -4|0);
   $105 = HEAP32[$104>>2]|0;
   $106 = ((($95)) + 16|0);
   HEAP32[$106>>2] = $105;
   HEAP32[$101>>2] = $104;
  }
  $107 = (($97) + -1)|0;
  HEAP32[$96>>2] = $107;
 }
 $108 = ((($95)) + 64|0);
 $109 = HEAP32[$108>>2]|0;
 $110 = ((($95)) + 68|0);
 $111 = HEAP32[$110>>2]|0;
 $112 = ($109|0)==($111|0);
 if (!($112)) {
  $$sroa$09$016$i$i = $109;
  while(1) {
   $113 = ((($$sroa$09$016$i$i)) + 20|0);
   $114 = HEAP32[$113>>2]|0;
   $115 = ($114|0)==(0);
   if (!($115)) {
    $116 = ((($$sroa$09$016$i$i)) + 8|0);
    $117 = HEAP32[$116>>2]|0;
    $118 = ((($$sroa$09$016$i$i)) + 12|0);
    $119 = HEAP32[$118>>2]|0;
    $120 = ($117|0)==($119|0);
    if (!($120)) {
     $121 = ((($119)) + -4|0);
     $122 = HEAP32[$121>>2]|0;
     $123 = ((($$sroa$09$016$i$i)) + 4|0);
     HEAP32[$123>>2] = $122;
     HEAP32[$118>>2] = $121;
    }
    $124 = (($114) + -1)|0;
    HEAP32[$113>>2] = $124;
   }
   $125 = ((($$sroa$09$016$i$i)) + 52|0);
   $126 = ($125|0)==($111|0);
   if ($126) {
    break;
   } else {
    $$sroa$09$016$i$i = $125;
   }
  }
 }
 $127 = ((($95)) + 76|0);
 $128 = HEAP32[$127>>2]|0;
 $129 = ((($95)) + 80|0);
 $130 = HEAP32[$129>>2]|0;
 $131 = ($128|0)==($130|0);
 if (!($131)) {
  $$sroa$03$015$i$i = $128;
  while(1) {
   $132 = ((($$sroa$03$015$i$i)) + 36|0);
   $133 = HEAP32[$132>>2]|0;
   $134 = ($133|0)==(0);
   if (!($134)) {
    $135 = ((($$sroa$03$015$i$i)) + 24|0);
    $136 = HEAP32[$135>>2]|0;
    $137 = ((($$sroa$03$015$i$i)) + 28|0);
    $138 = HEAP32[$137>>2]|0;
    $139 = ($136|0)==($138|0);
    if (!($139)) {
     $140 = ((($138)) + -4|0);
     $141 = HEAP32[$140>>2]|0;
     $142 = ((($$sroa$03$015$i$i)) + 20|0);
     HEAP32[$142>>2] = $141;
     HEAP32[$137>>2] = $140;
    }
    $143 = (($133) + -1)|0;
    HEAP32[$132>>2] = $143;
   }
   $144 = ((($$sroa$03$015$i$i)) + 68|0);
   $145 = HEAP32[$144>>2]|0;
   $146 = ((($$sroa$03$015$i$i)) + 72|0);
   $147 = HEAP32[$146>>2]|0;
   $148 = ($145|0)==($147|0);
   if (!($148)) {
    $$sroa$03$07$i$i$i = $145;
    while(1) {
     $149 = ((($$sroa$03$07$i$i$i)) + 16|0);
     $150 = HEAP32[$149>>2]|0;
     $151 = ($150|0)==(0);
     if (!($151)) {
      $152 = ((($$sroa$03$07$i$i$i)) + 4|0);
      $153 = HEAP32[$152>>2]|0;
      $154 = ((($$sroa$03$07$i$i$i)) + 8|0);
      $155 = HEAP32[$154>>2]|0;
      $156 = ($153|0)==($155|0);
      if (!($156)) {
       $157 = ((($155)) + -4|0);
       $158 = HEAP32[$157>>2]|0;
       HEAP32[$$sroa$03$07$i$i$i>>2] = $158;
       HEAP32[$154>>2] = $157;
      }
      $159 = (($150) + -1)|0;
      HEAP32[$149>>2] = $159;
     }
     $160 = ((($$sroa$03$07$i$i$i)) + 48|0);
     $161 = ($160|0)==($147|0);
     if ($161) {
      break;
     } else {
      $$sroa$03$07$i$i$i = $160;
     }
    }
   }
   $162 = ((($$sroa$03$015$i$i)) + 80|0);
   $163 = ($162|0)==($130|0);
   if ($163) {
    break;
   } else {
    $$sroa$03$015$i$i = $162;
   }
  }
 }
 __ZN3osg10CullingSet23popOccludersCurrentMaskERNSt3__26vectorIPNS_4NodeENS1_9allocatorIS4_EEEE($95,$4);
 STACKTOP = sp;return;
}
function __ZThn56_N3osg23CollectOccludersVisitorD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -56|0);
 __ZN3osg23CollectOccludersVisitorD1Ev($1);
 return;
}
function __ZThn56_N3osg23CollectOccludersVisitorD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -56|0);
 __THREW__ = 0;
 invoke_vi(1530,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch_2()|0;
  $5 = tempRet0;
  __ZdlPv($1);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZdlPv($1);
  return;
 }
}
function __ZTv0_n16_N3osg23CollectOccludersVisitorD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __ZN3osg23CollectOccludersVisitorD1Ev($4);
 return;
}
function __ZTv0_n16_N3osg23CollectOccludersVisitorD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __THREW__ = 0;
 invoke_vi(1530,($4|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $7 = ___cxa_find_matching_catch_2()|0;
  $8 = tempRet0;
  __ZdlPv($4);
  ___resumeException($7|0);
  // unreachable;
 } else {
  __ZdlPv($4);
  return;
 }
}
function __ZTv0_n20_NK3osg23CollectOccludersVisitor9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(432)|0);
 __THREW__ = 0;
 invoke_vi(3578,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch_2()|0;
  $5 = tempRet0;
  __ZdlPv($1);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $6 = HEAP32[$1>>2]|0;
  $7 = ((($6)) + -12|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($1) + ($8)|0);
  return ($9|0);
 }
 return (0)|0;
}
function __ZTv0_n32_NK3osg23CollectOccludersVisitor11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175113|0);
}
function __ZTv0_n36_NK3osg23CollectOccludersVisitor9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (120392|0);
}
function __ZN3osg23CollectOccludersVisitorC1Ev($0) {
 $0 = $0|0;
 var $$2 = 0, $$24 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 396|0);
 __ZN3osg10ReferencedC2Ev($1);
 HEAP32[$1>>2] = (63412);
 $2 = ((($0)) + 408|0);
 ;HEAP32[$2>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;
 $3 = ((($0)) + 420|0);
 HEAP32[$3>>2] = 2;
 $4 = ((($0)) + 424|0);
 HEAP32[$4>>2] = 0;
 __THREW__ = 0;
 invoke_viiii(3522,($0|0),((57176)|0),3,3);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 do {
  if ($6) {
   $24 = ___cxa_find_matching_catch_2()|0;
   $25 = tempRet0;
   $$2 = $25;$$24 = $24;
  } else {
   $7 = ((($0)) + 56|0);
   __THREW__ = 0;
   invoke_vi(3645,($7|0));
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if ($9) {
    $26 = ___cxa_find_matching_catch_2()|0;
    $27 = tempRet0;
    __THREW__ = 0;
    invoke_vii(3284,($0|0),((57176)|0));
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if (!($29)) {
     $$2 = $27;$$24 = $26;
     break;
    }
    $32 = ___cxa_find_matching_catch_3(0|0)|0;
    $33 = tempRet0;
    ___clang_call_terminate($32);
    // unreachable;
   }
   HEAP32[$0>>2] = (56660);
   HEAP32[$1>>2] = (57032);
   HEAP32[$7>>2] = (56868);
   $10 = ((($0)) + 388|0);
   HEAP32[$10>>2] = 0;
   $11 = ((($0)) + 392|0);
   HEAP32[$11>>2] = 0;
   $12 = ((($0)) + 388|0);
   $13 = ((($0)) + 384|0);
   HEAP32[$13>>2] = $12;
   $14 = ((($0)) + 72|0);
   HEAP32[$14>>2] = 15;
   $15 = ((($0)) + 64|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ($16|0)==(0);
   $18 = ((($0)) + 60|0);
   if (!($17)) {
    $21 = ((($0)) + 372|0);
    HEAPF32[$21>>2] = 0.004999999888241291;
    $22 = ((($0)) + 376|0);
    HEAP32[$22>>2] = 10;
    $23 = ((($0)) + 380|0);
    HEAP8[$23>>0] = 0;
    return;
   }
   $19 = HEAP32[$18>>2]|0;
   $20 = $19 & -3;
   HEAP32[$18>>2] = $20;
   $21 = ((($0)) + 372|0);
   HEAPF32[$21>>2] = 0.004999999888241291;
   $22 = ((($0)) + 376|0);
   HEAP32[$22>>2] = 10;
   $23 = ((($0)) + 380|0);
   HEAP8[$23>>0] = 0;
   return;
  }
 } while(0);
 __THREW__ = 0;
 invoke_vi(388,($1|0));
 $30 = __THREW__; __THREW__ = 0;
 $31 = $30&1;
 if ($31) {
  $32 = ___cxa_find_matching_catch_3(0|0)|0;
  $33 = tempRet0;
  ___clang_call_terminate($32);
  // unreachable;
 } else {
  ___resumeException($$24|0);
  // unreachable;
 }
}
function __ZNSt3__26__treeIN3osg20ShadowVolumeOccluderENS_4lessIS2_EENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 }
 $3 = HEAP32[$1>>2]|0;
 __ZNSt3__26__treeIN3osg20ShadowVolumeOccluderENS_4lessIS2_EENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($0,$3);
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 __ZNSt3__26__treeIN3osg20ShadowVolumeOccluderENS_4lessIS2_EENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($0,$5);
 $6 = ((($1)) + 16|0);
 __THREW__ = 0;
 invoke_vi(3586,($6|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch_2()|0;
  $10 = tempRet0;
  ___cxa_call_unexpected(($9|0));
  // unreachable;
 }
 __ZdlPv($1);
 return;
}
function __ZN3osg23CollectOccludersVisitor23removeOccludedOccludersEv($0) {
 $0 = $0|0;
 var $$0$i$i = 0, $$0$i$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i$i = 0, $$0$i$i$i$i$i62 = 0, $$0$i$i$i$i63 = 0, $$0$i$i$i$i66 = 0, $$0$i$i$i49 = 0, $$0$i$i$i56 = 0, $$0$i$i$i68 = 0, $$0$i$i53$sink$be = 0, $$0$i$i53$sink$ph = 0, $$0$i$i53$sink116 = 0, $$043105 = 0, $$044$lcssa = 0, $$044107 = 0, $$045106 = 0, $$08$i$i$i = 0, $$1 = 0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $$in$i$i = 0, $$lcssa97 = 0, $$pre = 0, $$pre127 = 0, $$sroa$077$0$be = 0, $$sroa$077$0113 = 0, $$sroa$083$1$in = 0, $$sroa$083$2$lcssa = 0, $$sroa$083$2104 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0;
 var $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0;
 var $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0;
 var $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy1 = sp + 12|0;
 $$byval_copy = sp + 8|0;
 $1 = sp + 4|0;
 $2 = sp;
 $3 = ((($0)) + 384|0);
 $4 = ((($0)) + 392|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = HEAP32[$3>>2]|0;
 $8 = ((($7)) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if ($10) {
  $11 = ((($7)) + 8|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = HEAP32[$12>>2]|0;
  $14 = ($13|0)==($7|0);
  if ($14) {
   $$0$i$i53$sink$ph = $12;
  } else {
   $18 = $11;
   while(1) {
    $17 = HEAP32[$18>>2]|0;
    $19 = ((($17)) + 8|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = HEAP32[$20>>2]|0;
    $22 = ($21|0)==($17|0);
    if ($22) {
     $$0$i$i53$sink$ph = $20;
     break;
    } else {
     $18 = $19;
    }
   }
  }
 } else {
  $$0$i$i$i$i = $9;
  while(1) {
   $15 = HEAP32[$$0$i$i$i$i>>2]|0;
   $16 = ($15|0)==(0|0);
   if ($16) {
    break;
   } else {
    $$0$i$i$i$i = $15;
   }
  }
  $$0$i$i53$sink$ph = $$0$i$i$i$i;
 }
 $23 = ((($0)) + 388|0);
 $24 = ($$0$i$i53$sink$ph|0)==($23|0);
 if ($24) {
  $146 = $5;
 } else {
  $25 = ((($0)) + 388|0);
  $$0$i$i53$sink116 = $$0$i$i53$sink$ph;$27 = $7;
  while(1) {
   $26 = ((($$0$i$i53$sink116)) + 84|0);
   $28 = ($27|0)==($$0$i$i53$sink116|0);
   L16: do {
    if ($28) {
     $$sroa$083$1$in = $27;
    } else {
     $29 = ((($$0$i$i53$sink116)) + 72|0);
     $30 = ((($$0$i$i53$sink116)) + 88|0);
     $$sroa$077$0113 = $27;
     while(1) {
      $31 = ((($$sroa$077$0113)) + 16|0);
      $32 = (__ZN3osg20ShadowVolumeOccluder8containsERKNSt3__26vectorINS_5Vec3fENS1_9allocatorIS3_EEEE($31,$29)|0);
      if ($32) {
       break;
      }
      $33 = HEAP32[$30>>2]|0;
      $34 = HEAP32[$26>>2]|0;
      $35 = (($33) - ($34))|0;
      $36 = (($35|0) / 48)&-1;
      $37 = ($35|0)==(0);
      $38 = $34;
      if ($37) {
       $$044$lcssa = 0;$$lcssa97 = $36;$109 = $38;$111 = $33;
      } else {
       $$044107 = 0;$$045106 = 0;$72 = $38;
       while(1) {
        $71 = (((($72) + (($$045106*48)|0)|0)) + 36|0);
        $73 = (__ZN3osg20ShadowVolumeOccluder8containsERKNSt3__26vectorINS_5Vec3fENS1_9allocatorIS3_EEEE($31,$71)|0);
        if ($73) {
         $$1 = $$044107;
        } else {
         $74 = ($$044107>>>0)<($$045106>>>0);
         if ($74) {
          $75 = HEAP32[$26>>2]|0;
          $76 = (($75) + (($$045106*48)|0)|0);
          $77 = HEAP32[$76>>2]|0;
          $78 = (($75) + (($$044107*48)|0)|0);
          HEAP32[$78>>2] = $77;
          $79 = (((($75) + (($$044107*48)|0)|0)) + 4|0);
          $80 = (((($75) + (($$045106*48)|0)|0)) + 4|0);
          $81 = HEAP32[$80>>2]|0;
          $82 = (((($75) + (($$045106*48)|0)|0)) + 8|0);
          $83 = HEAP32[$82>>2]|0;
          __ZNSt3__26vectorIjNS_9allocatorIjEEE6assignIPjEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIjNS_15iterator_traitsIS7_E9referenceEEE5valueEvE4typeES7_S7_($79,$81,$83);
          $84 = (((($75) + (($$045106*48)|0)|0)) + 16|0);
          $85 = HEAP32[$84>>2]|0;
          $86 = (((($75) + (($$044107*48)|0)|0)) + 16|0);
          HEAP32[$86>>2] = $85;
          $87 = (((($75) + (($$045106*48)|0)|0)) + 20|0);
          $88 = HEAP32[$87>>2]|0;
          $89 = (((($75) + (($$044107*48)|0)|0)) + 20|0);
          HEAP32[$89>>2] = $88;
          $90 = (((($75) + (($$044107*48)|0)|0)) + 24|0);
          $91 = (((($75) + (($$045106*48)|0)|0)) + 24|0);
          $92 = HEAP32[$91>>2]|0;
          $93 = (((($75) + (($$045106*48)|0)|0)) + 28|0);
          $94 = HEAP32[$93>>2]|0;
          __ZNSt3__26vectorIN3osg5PlaneENS_9allocatorIS2_EEE6assignIPS2_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS2_NS_15iterator_traitsIS9_E9referenceEEE5valueEvE4typeES9_S9_($90,$92,$94);
          $95 = (((($75) + (($$044107*48)|0)|0)) + 36|0);
          $96 = (((($75) + (($$045106*48)|0)|0)) + 36|0);
          $97 = HEAP32[$96>>2]|0;
          $98 = (((($75) + (($$045106*48)|0)|0)) + 40|0);
          $99 = HEAP32[$98>>2]|0;
          __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE6assignIPS2_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS2_NS_15iterator_traitsIS9_E9referenceEEE5valueEvE4typeES9_S9_($95,$97,$99);
         }
         $100 = (($$044107) + 1)|0;
         $$1 = $100;
        }
        $101 = (($$045106) + 1)|0;
        $102 = HEAP32[$30>>2]|0;
        $103 = HEAP32[$26>>2]|0;
        $104 = (($102) - ($103))|0;
        $105 = (($104|0) / 48)&-1;
        $106 = ($101>>>0)<($105>>>0);
        $107 = $103;
        if ($106) {
         $$044107 = $$1;$$045106 = $101;$72 = $107;
        } else {
         $$044$lcssa = $$1;$$lcssa97 = $105;$109 = $107;$111 = $102;
         break;
        }
       }
      }
      $70 = ($$044$lcssa>>>0)<($$lcssa97>>>0);
      if ($70) {
       $108 = (($109) + (($$044$lcssa*48)|0)|0);
       $110 = $108;
       HEAP32[$1>>2] = $110;
       HEAP32[$2>>2] = $111;
       ;HEAP32[$$byval_copy>>2]=HEAP32[$1>>2]|0;
       ;HEAP32[$$byval_copy1>>2]=HEAP32[$2>>2]|0;
       (__ZNSt3__26vectorIN3osg8PolytopeENS_9allocatorIS2_EEE5eraseENS_11__wrap_iterIPKS2_EES9_($26,$$byval_copy,$$byval_copy1)|0);
      }
      $112 = ((($$sroa$077$0113)) + 4|0);
      $113 = HEAP32[$112>>2]|0;
      $114 = ($113|0)==(0|0);
      if ($114) {
       $115 = ((($$sroa$077$0113)) + 8|0);
       $116 = HEAP32[$115>>2]|0;
       $117 = HEAP32[$116>>2]|0;
       $118 = ($117|0)==($$sroa$077$0113|0);
       if ($118) {
        $$sroa$077$0$be = $116;
       } else {
        $123 = $115;
        while(1) {
         $122 = HEAP32[$123>>2]|0;
         $124 = ((($122)) + 8|0);
         $125 = HEAP32[$124>>2]|0;
         $126 = HEAP32[$125>>2]|0;
         $127 = ($126|0)==($122|0);
         if ($127) {
          $$sroa$077$0$be = $125;
          break;
         } else {
          $123 = $124;
         }
        }
       }
      } else {
       $$0$i$i$i56 = $113;
       while(1) {
        $120 = HEAP32[$$0$i$i$i56>>2]|0;
        $121 = ($120|0)==(0|0);
        if ($121) {
         break;
        } else {
         $$0$i$i$i56 = $120;
        }
       }
       $$sroa$077$0$be = $$0$i$i$i56;
      }
      $119 = ($$sroa$077$0$be|0)==($$0$i$i53$sink116|0);
      if ($119) {
       $$sroa$083$1$in = $$0$i$i53$sink116;
       break L16;
      } else {
       $$sroa$077$0113 = $$sroa$077$0$be;
      }
     }
     $39 = HEAP32[$$0$i$i53$sink116>>2]|0;
     $40 = ($39|0)==(0|0);
     if ($40) {
      $$0$i$i$i68 = $$0$i$i53$sink116;
      while(1) {
       $44 = ((($$0$i$i$i68)) + 8|0);
       $45 = HEAP32[$44>>2]|0;
       $46 = HEAP32[$45>>2]|0;
       $47 = ($46|0)==($$0$i$i$i68|0);
       if ($47) {
        $$0$i$i$i68 = $45;
       } else {
        $$08$i$i$i = $45;
        break;
       }
      }
     } else {
      $$0$i$i$i$i66 = $39;
      while(1) {
       $41 = ((($$0$i$i$i$i66)) + 4|0);
       $42 = HEAP32[$41>>2]|0;
       $43 = ($42|0)==(0|0);
       if ($43) {
        $$08$i$i$i = $$0$i$i$i$i66;
        break;
       } else {
        $$0$i$i$i$i66 = $42;
       }
      }
     }
     $48 = ((($$0$i$i53$sink116)) + 4|0);
     $49 = HEAP32[$48>>2]|0;
     $50 = ($49|0)==(0|0);
     if ($50) {
      $51 = ((($$0$i$i53$sink116)) + 8|0);
      $52 = HEAP32[$51>>2]|0;
      $53 = HEAP32[$52>>2]|0;
      $54 = ($53|0)==($$0$i$i53$sink116|0);
      if ($54) {
       $$0$i$i$i$i63 = $52;
      } else {
       $58 = $51;
       while(1) {
        $57 = HEAP32[$58>>2]|0;
        $59 = ((($57)) + 8|0);
        $60 = HEAP32[$59>>2]|0;
        $61 = HEAP32[$60>>2]|0;
        $62 = ($61|0)==($57|0);
        if ($62) {
         $$0$i$i$i$i63 = $60;
         break;
        } else {
         $58 = $59;
        }
       }
      }
     } else {
      $$0$i$i$i$i$i62 = $49;
      while(1) {
       $55 = HEAP32[$$0$i$i$i$i$i62>>2]|0;
       $56 = ($55|0)==(0|0);
       if ($56) {
        break;
       } else {
        $$0$i$i$i$i$i62 = $55;
       }
      }
      $$0$i$i$i$i63 = $$0$i$i$i$i$i62;
     }
     $63 = HEAP32[$3>>2]|0;
     $64 = ($63|0)==($$0$i$i53$sink116|0);
     if ($64) {
      $65 = $$0$i$i$i$i63;
      HEAP32[$3>>2] = $65;
     }
     $66 = HEAP32[$4>>2]|0;
     $67 = (($66) + -1)|0;
     HEAP32[$4>>2] = $67;
     $68 = HEAP32[$25>>2]|0;
     __ZNSt3__213__tree_removeIPNS_16__tree_node_baseIPvEEEEvT_S5_($68,$$0$i$i53$sink116);
     $69 = ((($$0$i$i53$sink116)) + 16|0);
     __ZN3osg20ShadowVolumeOccluderD2Ev($69);
     __ZdlPv($$0$i$i53$sink116);
     $$sroa$083$1$in = $$08$i$i$i;
    }
   } while(0);
   $128 = ((($$sroa$083$1$in)) + 4|0);
   $129 = HEAP32[$128>>2]|0;
   $130 = ($129|0)==(0|0);
   if ($130) {
    $131 = ((($$sroa$083$1$in)) + 8|0);
    $132 = HEAP32[$131>>2]|0;
    $133 = HEAP32[$132>>2]|0;
    $134 = ($133|0)==($$sroa$083$1$in|0);
    if ($134) {
     $$0$i$i53$sink$be = $132;
    } else {
     $139 = $131;
     while(1) {
      $138 = HEAP32[$139>>2]|0;
      $140 = ((($138)) + 8|0);
      $141 = HEAP32[$140>>2]|0;
      $142 = HEAP32[$141>>2]|0;
      $143 = ($142|0)==($138|0);
      if ($143) {
       $$0$i$i53$sink$be = $141;
       break;
      } else {
       $139 = $140;
      }
     }
    }
   } else {
    $$0$i$i$i49 = $129;
    while(1) {
     $136 = HEAP32[$$0$i$i$i49>>2]|0;
     $137 = ($136|0)==(0|0);
     if ($137) {
      break;
     } else {
      $$0$i$i$i49 = $136;
     }
    }
    $$0$i$i53$sink$be = $$0$i$i$i49;
   }
   $135 = ($$0$i$i53$sink$be|0)==($23|0);
   if ($135) {
    break;
   }
   $$pre = HEAP32[$3>>2]|0;
   $$0$i$i53$sink116 = $$0$i$i53$sink$be;$27 = $$pre;
  }
  $$pre127 = HEAP32[$4>>2]|0;
  $146 = $$pre127;
 }
 $144 = ((($0)) + 376|0);
 $145 = HEAP32[$144>>2]|0;
 $147 = ($146>>>0)>($145>>>0);
 if (!($147)) {
  STACKTOP = sp;return;
 }
 $148 = HEAP32[$3>>2]|0;
 $149 = ($145|0)==(0);
 if ($149) {
  $$sroa$083$2$lcssa = $148;
 } else {
  $$043105 = 0;$$sroa$083$2104 = $148;
  while(1) {
   $176 = $$sroa$083$2104;
   $177 = ((($176)) + 4|0);
   $178 = HEAP32[$177>>2]|0;
   $179 = ($178|0)==(0|0);
   if ($179) {
    $180 = ((($176)) + 8|0);
    $181 = HEAP32[$180>>2]|0;
    $182 = HEAP32[$181>>2]|0;
    $183 = ($182|0)==($176|0);
    if ($183) {
     $$0$i$i = $181;
    } else {
     $187 = $180;
     while(1) {
      $186 = HEAP32[$187>>2]|0;
      $188 = ((($186)) + 8|0);
      $189 = HEAP32[$188>>2]|0;
      $190 = HEAP32[$189>>2]|0;
      $191 = ($190|0)==($186|0);
      if ($191) {
       $$0$i$i = $189;
       break;
      } else {
       $187 = $188;
      }
     }
    }
   } else {
    $$0$i$i$i = $178;
    while(1) {
     $184 = HEAP32[$$0$i$i$i>>2]|0;
     $185 = ($184|0)==(0|0);
     if ($185) {
      break;
     } else {
      $$0$i$i$i = $184;
     }
    }
    $$0$i$i = $$0$i$i$i;
   }
   $192 = $$0$i$i;
   $193 = (($$043105) + 1)|0;
   $194 = ($193>>>0)<($145>>>0);
   if ($194) {
    $$043105 = $193;$$sroa$083$2104 = $192;
   } else {
    $$sroa$083$2$lcssa = $192;
    break;
   }
  }
 }
 $150 = $$sroa$083$2$lcssa;
 $151 = ($150|0)==($23|0);
 if ($151) {
  STACKTOP = sp;return;
 }
 $152 = ((($0)) + 388|0);
 $$in$i$i = $150;
 while(1) {
  $153 = ((($$in$i$i)) + 4|0);
  $154 = HEAP32[$153>>2]|0;
  $155 = ($154|0)==(0|0);
  if ($155) {
   $156 = ((($$in$i$i)) + 8|0);
   $157 = HEAP32[$156>>2]|0;
   $158 = HEAP32[$157>>2]|0;
   $159 = ($158|0)==($$in$i$i|0);
   if ($159) {
    $$0$i$i$i$i$i = $157;
   } else {
    $163 = $156;
    while(1) {
     $162 = HEAP32[$163>>2]|0;
     $164 = ((($162)) + 8|0);
     $165 = HEAP32[$164>>2]|0;
     $166 = HEAP32[$165>>2]|0;
     $167 = ($166|0)==($162|0);
     if ($167) {
      $$0$i$i$i$i$i = $165;
      break;
     } else {
      $163 = $164;
     }
    }
   }
  } else {
   $$0$i$i$i$i$i$i = $154;
   while(1) {
    $160 = HEAP32[$$0$i$i$i$i$i$i>>2]|0;
    $161 = ($160|0)==(0|0);
    if ($161) {
     break;
    } else {
     $$0$i$i$i$i$i$i = $160;
    }
   }
   $$0$i$i$i$i$i = $$0$i$i$i$i$i$i;
  }
  $168 = HEAP32[$3>>2]|0;
  $169 = ($168|0)==($$in$i$i|0);
  if ($169) {
   $170 = $$0$i$i$i$i$i;
   HEAP32[$3>>2] = $170;
  }
  $171 = HEAP32[$4>>2]|0;
  $172 = (($171) + -1)|0;
  HEAP32[$4>>2] = $172;
  $173 = HEAP32[$152>>2]|0;
  __ZNSt3__213__tree_removeIPNS_16__tree_node_baseIPvEEEEvT_S5_($173,$$in$i$i);
  $174 = ((($$in$i$i)) + 16|0);
  __ZN3osg20ShadowVolumeOccluderD2Ev($174);
  __ZdlPv($$in$i$i);
  $175 = ($$0$i$i$i$i$i|0)==($23|0);
  if ($175) {
   break;
  } else {
   $$in$i$i = $$0$i$i$i$i$i;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__26vectorIN3osg5PlaneENS_9allocatorIS2_EEE6assignIPS2_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS2_NS_15iterator_traitsIS9_E9referenceEEE5valueEvE4typeES9_S9_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$ = 0, $$0$lcssa$i$i = 0, $$07$i$i = 0, $$07$i$i20 = 0, $$078$i$i = 0, $$09$i$i = 0, $$promoted$i$i18 = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $100 = 0.0, $101 = 0, $102 = 0, $103 = 0.0, $104 = 0, $105 = 0, $106 = 0.0, $107 = 0, $108 = 0, $109 = 0.0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0.0, $24 = 0, $25 = 0.0, $26 = 0, $27 = 0, $28 = 0.0, $29 = 0, $3 = 0, $30 = 0, $31 = 0.0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0.0, $49 = 0, $5 = 0, $50 = 0, $51 = 0.0, $52 = 0;
 var $53 = 0, $54 = 0.0, $55 = 0, $56 = 0, $57 = 0.0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $scevgep$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep5$i$i = 0, $scevgep5$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = $1;
 $4 = $2;
 $5 = (($4) - ($3))|0;
 $6 = (($5|0) / 40)&-1;
 $7 = ((($0)) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$0>>2]|0;
 $10 = (($8) - ($9))|0;
 $11 = (($10|0) / 40)&-1;
 $12 = ($6>>>0)>($11>>>0);
 $13 = $9;
 if ($12) {
  $79 = ($9|0)==(0);
  $80 = $9;
  if ($79) {
   $90 = $8;
  } else {
   $81 = ((($0)) + 4|0);
   $82 = HEAP32[$81>>2]|0;
   $83 = ($82|0)==($13|0);
   if (!($83)) {
    $scevgep$i$i$i$i = ((($82)) + -40|0);
    $84 = $scevgep$i$i$i$i;
    $85 = (($84) - ($9))|0;
    $86 = (($85>>>0) / 40)&-1;
    $87 = $86 ^ -1;
    $scevgep5$i$i$i$i = (($82) + (($87*40)|0)|0);
    HEAP32[$81>>2] = $scevgep5$i$i$i$i;
   }
   __ZdlPv($80);
   HEAP32[$7>>2] = 0;
   HEAP32[$81>>2] = 0;
   HEAP32[$0>>2] = 0;
   $90 = 0;
  }
  $88 = ($6>>>0)>(107374182);
  if ($88) {
   __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
   // unreachable;
  }
  $89 = (($90|0) / 40)&-1;
  $91 = ($89>>>0)<(53687091);
  $92 = $89 << 1;
  $93 = ($92>>>0)<($6>>>0);
  $$sroa$speculated$i = $93 ? $6 : $92;
  $$sroa$speculated$$i = $91 ? $$sroa$speculated$i : 107374182;
  $94 = ($$sroa$speculated$$i>>>0)>(107374182);
  if ($94) {
   __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
   // unreachable;
  }
  $95 = ($$sroa$speculated$$i*40)|0;
  $96 = (__Znwj($95)|0);
  $97 = ((($0)) + 4|0);
  HEAP32[$97>>2] = $96;
  HEAP32[$0>>2] = $96;
  $98 = (($96) + (($$sroa$speculated$$i*40)|0)|0);
  HEAP32[$7>>2] = $98;
  $99 = ($1|0)==($2|0);
  if ($99) {
   return;
  }
  $$07$i$i = $1;$101 = $96;
  while(1) {
   $100 = +HEAPF64[$$07$i$i>>3];
   HEAPF64[$101>>3] = $100;
   $102 = ((($$07$i$i)) + 8|0);
   $103 = +HEAPF64[$102>>3];
   $104 = ((($101)) + 8|0);
   HEAPF64[$104>>3] = $103;
   $105 = ((($$07$i$i)) + 16|0);
   $106 = +HEAPF64[$105>>3];
   $107 = ((($101)) + 16|0);
   HEAPF64[$107>>3] = $106;
   $108 = ((($$07$i$i)) + 24|0);
   $109 = +HEAPF64[$108>>3];
   $110 = ((($101)) + 24|0);
   HEAPF64[$110>>3] = $109;
   $111 = $100 >= 0.0;
   $112 = $111&1;
   $113 = $103 >= 0.0;
   $114 = $113 ? 2 : 0;
   $115 = $114 | $112;
   $116 = $106 >= 0.0;
   $117 = $116 ? 4 : 0;
   $118 = $115 | $117;
   $119 = ((($101)) + 32|0);
   HEAP32[$119>>2] = $118;
   $120 = $118 ^ 7;
   $121 = ((($101)) + 36|0);
   HEAP32[$121>>2] = $120;
   $122 = ((($$07$i$i)) + 40|0);
   $123 = ((($101)) + 40|0);
   $124 = ($122|0)==($2|0);
   if ($124) {
    break;
   } else {
    $$07$i$i = $122;$101 = $123;
   }
  }
  HEAP32[$97>>2] = $123;
  return;
 }
 $14 = ((($0)) + 4|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($15) - ($9))|0;
 $17 = (($16|0) / 40)&-1;
 $18 = ($6>>>0)>($17>>>0);
 $19 = (($1) + (($17*40)|0)|0);
 $$ = $18 ? $19 : $2;
 $20 = ($$|0)==($1|0);
 $21 = $15;
 if ($20) {
  $$0$lcssa$i$i = $13;
 } else {
  $$078$i$i = $1;$$09$i$i = $13;
  while(1) {
   $22 = ($$078$i$i|0)==($$09$i$i|0);
   if (!($22)) {
    $23 = +HEAPF64[$$078$i$i>>3];
    HEAPF64[$$09$i$i>>3] = $23;
    $24 = ((($$078$i$i)) + 8|0);
    $25 = +HEAPF64[$24>>3];
    $26 = ((($$09$i$i)) + 8|0);
    HEAPF64[$26>>3] = $25;
    $27 = ((($$078$i$i)) + 16|0);
    $28 = +HEAPF64[$27>>3];
    $29 = ((($$09$i$i)) + 16|0);
    HEAPF64[$29>>3] = $28;
    $30 = ((($$078$i$i)) + 24|0);
    $31 = +HEAPF64[$30>>3];
    $32 = ((($$09$i$i)) + 24|0);
    HEAPF64[$32>>3] = $31;
    $33 = $23 >= 0.0;
    $34 = $33&1;
    $35 = $25 >= 0.0;
    $36 = $35 ? 2 : 0;
    $37 = $36 | $34;
    $38 = $28 >= 0.0;
    $39 = $38 ? 4 : 0;
    $40 = $37 | $39;
    $41 = ((($$09$i$i)) + 32|0);
    HEAP32[$41>>2] = $40;
    $42 = $40 ^ 7;
    $43 = ((($$09$i$i)) + 36|0);
    HEAP32[$43>>2] = $42;
   }
   $44 = ((($$078$i$i)) + 40|0);
   $45 = ((($$09$i$i)) + 40|0);
   $46 = ($44|0)==($$|0);
   if ($46) {
    $$0$lcssa$i$i = $45;
    break;
   } else {
    $$078$i$i = $44;$$09$i$i = $45;
   }
  }
 }
 if (!($18)) {
  $73 = ($21|0)==($$0$lcssa$i$i|0);
  if ($73) {
   return;
  }
  $scevgep$i$i = ((($21)) + -40|0);
  $74 = $scevgep$i$i;
  $75 = $$0$lcssa$i$i;
  $76 = (($74) - ($75))|0;
  $77 = (($76>>>0) / 40)&-1;
  $78 = $77 ^ -1;
  $scevgep5$i$i = (($21) + (($78*40)|0)|0);
  HEAP32[$14>>2] = $scevgep5$i$i;
  return;
 }
 $47 = ($$|0)==($2|0);
 if ($47) {
  return;
 }
 $$promoted$i$i18 = HEAP32[$14>>2]|0;
 $$07$i$i20 = $19;$49 = $$promoted$i$i18;
 while(1) {
  $48 = +HEAPF64[$$07$i$i20>>3];
  HEAPF64[$49>>3] = $48;
  $50 = ((($$07$i$i20)) + 8|0);
  $51 = +HEAPF64[$50>>3];
  $52 = ((($49)) + 8|0);
  HEAPF64[$52>>3] = $51;
  $53 = ((($$07$i$i20)) + 16|0);
  $54 = +HEAPF64[$53>>3];
  $55 = ((($49)) + 16|0);
  HEAPF64[$55>>3] = $54;
  $56 = ((($$07$i$i20)) + 24|0);
  $57 = +HEAPF64[$56>>3];
  $58 = ((($49)) + 24|0);
  HEAPF64[$58>>3] = $57;
  $59 = $48 >= 0.0;
  $60 = $59&1;
  $61 = $51 >= 0.0;
  $62 = $61 ? 2 : 0;
  $63 = $62 | $60;
  $64 = $54 >= 0.0;
  $65 = $64 ? 4 : 0;
  $66 = $63 | $65;
  $67 = ((($49)) + 32|0);
  HEAP32[$67>>2] = $66;
  $68 = $66 ^ 7;
  $69 = ((($49)) + 36|0);
  HEAP32[$69>>2] = $68;
  $70 = ((($$07$i$i20)) + 40|0);
  $71 = ((($49)) + 40|0);
  $72 = ($70|0)==($2|0);
  if ($72) {
   break;
  } else {
   $$07$i$i20 = $70;$49 = $71;
  }
 }
 HEAP32[$14>>2] = $71;
 return;
}
function __ZNSt3__26vectorIN3osg8PolytopeENS_9allocatorIS2_EEE5eraseENS_11__wrap_iterIPKS2_EES9_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$lcssa$i$i = 0, $$078$i$i = 0, $$09$i$i = 0, $$cast = 0, $$pre = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $9 = 0, $scevgep$i$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i$i$i = 0, $scevgep$i$i$i3$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i$i$i$i$i = 0, $scevgep5$i$i$i4$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = HEAP32[$0>>2]|0;
 $4 = $3;
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) - ($4))|0;
 $7 = (($6|0) / 48)&-1;
 $8 = (($3) + (($7*48)|0)|0);
 $$cast = $5;
 $9 = HEAP32[$2>>2]|0;
 $10 = ($$cast|0)==($9|0);
 if ($10) {
  return ($8|0);
 }
 $11 = $9;
 $12 = (($11) - ($5))|0;
 $13 = (($12|0) / 48)&-1;
 $14 = (($8) + (($13*48)|0)|0);
 $15 = ((($0)) + 4|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($14|0)==($16|0);
 if ($17) {
  $$0$lcssa$i$i = $8;$44 = $14;
 } else {
  $$078$i$i = $14;$$09$i$i = $8;
  while(1) {
   $18 = ($$078$i$i|0)==($$09$i$i|0);
   if (!($18)) {
    $19 = HEAP32[$$078$i$i>>2]|0;
    HEAP32[$$09$i$i>>2] = $19;
    $20 = ((($$09$i$i)) + 4|0);
    $21 = ((($$078$i$i)) + 4|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = ((($$078$i$i)) + 8|0);
    $24 = HEAP32[$23>>2]|0;
    __ZNSt3__26vectorIjNS_9allocatorIjEEE6assignIPjEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIjNS_15iterator_traitsIS7_E9referenceEEE5valueEvE4typeES7_S7_($20,$22,$24);
    $25 = ((($$078$i$i)) + 16|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = ((($$09$i$i)) + 16|0);
    HEAP32[$27>>2] = $26;
    $28 = ((($$078$i$i)) + 20|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = ((($$09$i$i)) + 20|0);
    HEAP32[$30>>2] = $29;
    $31 = ((($$09$i$i)) + 24|0);
    $32 = ((($$078$i$i)) + 24|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = ((($$078$i$i)) + 28|0);
    $35 = HEAP32[$34>>2]|0;
    __ZNSt3__26vectorIN3osg5PlaneENS_9allocatorIS2_EEE6assignIPS2_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS2_NS_15iterator_traitsIS9_E9referenceEEE5valueEvE4typeES9_S9_($31,$33,$35);
    $36 = ((($$09$i$i)) + 36|0);
    $37 = ((($$078$i$i)) + 36|0);
    $38 = HEAP32[$37>>2]|0;
    $39 = ((($$078$i$i)) + 40|0);
    $40 = HEAP32[$39>>2]|0;
    __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE6assignIPS2_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS2_NS_15iterator_traitsIS9_E9referenceEEE5valueEvE4typeES9_S9_($36,$38,$40);
   }
   $41 = ((($$078$i$i)) + 48|0);
   $42 = ((($$09$i$i)) + 48|0);
   $43 = ($41|0)==($16|0);
   if ($43) {
    break;
   } else {
    $$078$i$i = $41;$$09$i$i = $42;
   }
  }
  $$pre = HEAP32[$15>>2]|0;
  $$0$lcssa$i$i = $42;$44 = $$pre;
 }
 $45 = ($44|0)==($$0$lcssa$i$i|0);
 if ($45) {
  return ($8|0);
 } else {
  $47 = $44;
 }
 while(1) {
  $46 = ((($47)) + -48|0);
  HEAP32[$15>>2] = $46;
  $48 = ((($47)) + -12|0);
  $49 = HEAP32[$48>>2]|0;
  $50 = ($49|0)==(0|0);
  if (!($50)) {
   $51 = ((($47)) + -8|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = ($52|0)==($49|0);
   if (!($53)) {
    $scevgep$i$i$i$i$i$i$i$i = ((($52)) + -12|0);
    $54 = $scevgep$i$i$i$i$i$i$i$i;
    $55 = $49;
    $56 = (($54) - ($55))|0;
    $57 = (($56>>>0) / 12)&-1;
    $58 = $57 ^ -1;
    $scevgep5$i$i$i$i$i$i$i$i = (($52) + (($58*12)|0)|0);
    HEAP32[$51>>2] = $scevgep5$i$i$i$i$i$i$i$i;
   }
   __ZdlPv($49);
  }
  $59 = ((($47)) + -24|0);
  $60 = HEAP32[$59>>2]|0;
  $61 = ($60|0)==(0|0);
  if (!($61)) {
   $62 = ((($47)) + -20|0);
   $63 = HEAP32[$62>>2]|0;
   $64 = ($63|0)==($60|0);
   if (!($64)) {
    $scevgep$i$i$i3$i$i$i$i$i = ((($63)) + -40|0);
    $65 = $scevgep$i$i$i3$i$i$i$i$i;
    $66 = $60;
    $67 = (($65) - ($66))|0;
    $68 = (($67>>>0) / 40)&-1;
    $69 = $68 ^ -1;
    $scevgep5$i$i$i4$i$i$i$i$i = (($63) + (($69*40)|0)|0);
    HEAP32[$62>>2] = $scevgep5$i$i$i4$i$i$i$i$i;
   }
   __ZdlPv($60);
  }
  $70 = ((($47)) + -44|0);
  $71 = HEAP32[$70>>2]|0;
  $72 = ($71|0)==(0|0);
  if (!($72)) {
   $75 = ((($47)) + -40|0);
   $76 = HEAP32[$75>>2]|0;
   $77 = ($76|0)==($71|0);
   if (!($77)) {
    $scevgep$i$i$i$i$i$i$i$i$i = ((($76)) + -4|0);
    $78 = $scevgep$i$i$i$i$i$i$i$i$i;
    $79 = $71;
    $80 = (($78) - ($79))|0;
    $81 = $80 >>> 2;
    $82 = $81 ^ -1;
    $scevgep5$i$i$i$i$i$i$i$i$i = (($76) + ($82<<2)|0);
    HEAP32[$75>>2] = $scevgep5$i$i$i$i$i$i$i$i$i;
   }
   __ZdlPv($71);
  }
  $73 = HEAP32[$15>>2]|0;
  $74 = ($73|0)==($$0$lcssa$i$i|0);
  if ($74) {
   break;
  } else {
   $47 = $73;
  }
 }
 return ($8|0);
}
function __ZN3osg9ColorMaskD2Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg14StateAttributeD2Ev($0);
 return;
}
function __ZN3osg9ColorMaskD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1573,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK3osg9ColorMask9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(60)|0);
 __THREW__ = 0;
 invoke_vi(3339,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $5 = ___cxa_find_matching_catch_2()|0;
  $6 = tempRet0;
  __ZdlPv($1);
  ___resumeException($5|0);
  // unreachable;
 } else {
  HEAP32[$1>>2] = (57196);
  $4 = ((($1)) + 56|0);
  HEAP32[$4>>2] = 16843009;
  return ($1|0);
 }
 return (0)|0;
}
function __ZNK3osg9ColorMask5cloneERKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(60)|0);
 __THREW__ = 0;
 invoke_viii(3729,($2|0),($0|0),($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $17 = ___cxa_find_matching_catch_2()|0;
  $18 = tempRet0;
  __ZdlPv($2);
  ___resumeException($17|0);
  // unreachable;
 } else {
  HEAP32[$2>>2] = (57196);
  $5 = ((($2)) + 56|0);
  $6 = ((($0)) + 56|0);
  $7 = HEAP8[$6>>0]|0;
  HEAP8[$5>>0] = $7;
  $8 = ((($2)) + 57|0);
  $9 = ((($0)) + 57|0);
  $10 = HEAP8[$9>>0]|0;
  HEAP8[$8>>0] = $10;
  $11 = ((($2)) + 58|0);
  $12 = ((($0)) + 58|0);
  $13 = HEAP8[$12>>0]|0;
  HEAP8[$11>>0] = $13;
  $14 = ((($2)) + 59|0);
  $15 = ((($0)) + 59|0);
  $16 = HEAP8[$15>>0]|0;
  HEAP8[$14>>0] = $16;
  return ($2|0);
 }
 return (0)|0;
}
function __ZNK3osg9ColorMask12isSameKindAsEPKNS_6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,23864,0)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK3osg9ColorMask11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175113|0);
}
function __ZNK3osg9ColorMask9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (120448|0);
}
function __ZN3osg14StateAttribute16asStateAttributeEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ($0|0);
}
function __ZNK3osg14StateAttribute16asStateAttributeEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ($0|0);
}
function __ZN3osg14StateAttribute21resizeGLObjectBuffersEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZNK3osg14StateAttribute16releaseGLObjectsEPNS_5StateE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN3osg14StateAttribute9asTextureEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZNK3osg14StateAttribute9asTextureEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZNK3osg9ColorMask7getTypeEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 25;
}
function __ZNK3osg14StateAttribute9getMemberEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function __ZNK3osg14StateAttribute18isTextureAttributeEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function __ZNK3osg9ColorMask7compareERKNS_14StateAttributeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$ = 0, $$$ = 0, $$2 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($0|0)==($1|0);
 if ($2) {
  $$2 = 0;
  return ($$2|0);
 }
 $3 = ($0|0)==(0|0);
 if ($3) {
  ___cxa_bad_typeid();
  // unreachable;
 }
 $4 = HEAP32[$0>>2]|0;
 $5 = ((($4)) + -4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$1>>2]|0;
 $8 = ((($7)) + -4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($6)) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($9)) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($11>>>0)<($13>>>0);
 if ($14) {
  $$2 = -1;
  return ($$2|0);
 }
 $15 = ($11|0)==($13|0);
 if (!($15)) {
  $$2 = 1;
  return ($$2|0);
 }
 $16 = ((($0)) + 56|0);
 $17 = HEAP8[$16>>0]|0;
 $18 = ((($1)) + 56|0);
 $19 = HEAP8[$18>>0]|0;
 $20 = ($17&255)<($19&255);
 if ($20) {
  $$2 = -1;
  return ($$2|0);
 }
 $21 = ($19&255)<($17&255);
 if ($21) {
  $$2 = 1;
  return ($$2|0);
 }
 $22 = ((($0)) + 57|0);
 $23 = HEAP8[$22>>0]|0;
 $24 = ((($1)) + 57|0);
 $25 = HEAP8[$24>>0]|0;
 $26 = ($23&255)<($25&255);
 if ($26) {
  $$2 = -1;
  return ($$2|0);
 }
 $27 = ($25&255)<($23&255);
 if ($27) {
  $$2 = 1;
  return ($$2|0);
 }
 $28 = ((($0)) + 58|0);
 $29 = HEAP8[$28>>0]|0;
 $30 = ((($1)) + 58|0);
 $31 = HEAP8[$30>>0]|0;
 $32 = ($29&255)<($31&255);
 if ($32) {
  $$2 = -1;
  return ($$2|0);
 }
 $33 = ($31&255)<($29&255);
 if ($33) {
  $$2 = 1;
  return ($$2|0);
 } else {
  $34 = ((($0)) + 59|0);
  $35 = HEAP8[$34>>0]|0;
  $36 = ((($1)) + 59|0);
  $37 = HEAP8[$36>>0]|0;
  $38 = ($35&255)<($37&255);
  $39 = ($37&255)<($35&255);
  $$ = $39&1;
  $$$ = $38 ? -1 : $$;
  return ($$$|0);
 }
 return (0)|0;
}
function __ZNK3osg14StateAttribute12getModeUsageERNS0_9ModeUsageE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function __ZNK3osg14StateAttribute30checkValidityOfAssociatedModesERNS_5StateE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 1;
}
function __ZNK3osg9ColorMask5applyERNS_5StateE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 56|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ((($0)) + 57|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ((($0)) + 58|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = ((($0)) + 59|0);
 $9 = HEAP8[$8>>0]|0;
 _glColorMask(($3|0),($5|0),($7|0),($9|0));
 return;
}
function __ZNK3osg14StateAttribute16compileGLObjectsERNS_5StateE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN3osg14StateAttributeC2ERKS0_RKNS_6CopyOpE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$09 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i = 0, $scevgep5$i$i$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg6ObjectC2ERKS0_RKNS_6CopyOpE($0,$1,$2);
 HEAP32[$0>>2] = (57384);
 $3 = ((($0)) + 32|0);
 HEAP32[$3>>2] = 0;
 $4 = ((($0)) + 36|0);
 HEAP32[$4>>2] = 0;
 $5 = ((($0)) + 40|0);
 HEAP32[$5>>2] = 0;
 $6 = ((($0)) + 44|0);
 $7 = ((($1)) + 44|0);
 $8 = HEAP32[$7>>2]|0;
 HEAP32[$6>>2] = $8;
 $9 = ($8|0)==(0|0);
 if (!($9)) {
  $10 = ((($8)) + 8|0);
  $11 = HEAP32[$10>>2]|0;HEAP32[$10>>2] = (($11+1)|0);
 }
 $12 = HEAP32[$2>>2]|0;
 $13 = ((($12)) + 60|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ((($1)) + 48|0);
 $16 = HEAP32[$15>>2]|0;
 __THREW__ = 0;
 $17 = (invoke_iii($14|0,($2|0),($16|0))|0);
 $18 = __THREW__; __THREW__ = 0;
 $19 = $18&1;
 if ($19) {
  $44 = ___cxa_find_matching_catch_2()|0;
  $45 = tempRet0;
  $$0 = $45;$$09 = $44;
 } else {
  $20 = ((($0)) + 48|0);
  HEAP32[$20>>2] = $17;
  $21 = ($17|0)==(0|0);
  if (!($21)) {
   $22 = HEAP32[$17>>2]|0;
   $23 = ((($22)) + -16|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = (($17) + ($24)|0);
   $26 = ((($25)) + 8|0);
   $27 = HEAP32[$26>>2]|0;HEAP32[$26>>2] = (($27+1)|0);
  }
  $28 = HEAP32[$2>>2]|0;
  $29 = ((($28)) + 60|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = ((($1)) + 52|0);
  $32 = HEAP32[$31>>2]|0;
  __THREW__ = 0;
  $33 = (invoke_iii($30|0,($2|0),($32|0))|0);
  $34 = __THREW__; __THREW__ = 0;
  $35 = $34&1;
  if (!($35)) {
   $36 = ((($0)) + 52|0);
   HEAP32[$36>>2] = $33;
   $37 = ($33|0)==(0|0);
   if ($37) {
    return;
   }
   $38 = HEAP32[$33>>2]|0;
   $39 = ((($38)) + -16|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = (($33) + ($40)|0);
   $42 = ((($41)) + 8|0);
   $43 = HEAP32[$42>>2]|0;HEAP32[$42>>2] = (($43+1)|0);
   return;
  }
  $46 = ___cxa_find_matching_catch_2()|0;
  $47 = tempRet0;
  $48 = HEAP32[$20>>2]|0;
  $49 = ($48|0)==(0|0);
  if (!($49)) {
   $50 = HEAP32[$48>>2]|0;
   $51 = ((($50)) + -16|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = (($48) + ($52)|0);
   $54 = ((($53)) + 8|0);
   $55 = HEAP32[$54>>2]|0;HEAP32[$54>>2] = (($55-1)|0);
   $56 = ($55|0)==(1);
   if ($56) {
    __THREW__ = 0;
    invoke_viii(3262,($53|0),1,1);
    $57 = __THREW__; __THREW__ = 0;
    $58 = $57&1;
    if ($58) {
     $77 = ___cxa_find_matching_catch_3(0|0)|0;
     $78 = tempRet0;
     ___clang_call_terminate($77);
     // unreachable;
    }
   }
  }
  HEAP32[$20>>2] = 0;
  $$0 = $47;$$09 = $46;
 }
 $59 = HEAP32[$6>>2]|0;
 $60 = ($59|0)==(0|0);
 if (!($60)) {
  $61 = ((($59)) + 8|0);
  $62 = HEAP32[$61>>2]|0;HEAP32[$61>>2] = (($62-1)|0);
  $63 = ($62|0)==(1);
  if ($63) {
   __THREW__ = 0;
   invoke_viii(3262,($59|0),1,1);
   $64 = __THREW__; __THREW__ = 0;
   $65 = $64&1;
   if ($65) {
    $77 = ___cxa_find_matching_catch_3(0|0)|0;
    $78 = tempRet0;
    ___clang_call_terminate($77);
    // unreachable;
   }
  }
 }
 HEAP32[$6>>2] = 0;
 $66 = HEAP32[$3>>2]|0;
 $67 = ($66|0)==(0|0);
 if (!($67)) {
  $68 = HEAP32[$4>>2]|0;
  $69 = ($68|0)==($66|0);
  if (!($69)) {
   $scevgep$i$i$i = ((($68)) + -4|0);
   $70 = $scevgep$i$i$i;
   $71 = $66;
   $72 = (($70) - ($71))|0;
   $73 = $72 >>> 2;
   $74 = $73 ^ -1;
   $scevgep5$i$i$i = (($68) + ($74<<2)|0);
   HEAP32[$4>>2] = $scevgep5$i$i$i;
  }
  __ZdlPv($66);
 }
 __THREW__ = 0;
 invoke_vi(388,($0|0));
 $75 = __THREW__; __THREW__ = 0;
 $76 = $75&1;
 if ($76) {
  $77 = ___cxa_find_matching_catch_3(0|0)|0;
  $78 = tempRet0;
  ___clang_call_terminate($77);
  // unreachable;
 } else {
  ___resumeException($$09|0);
  // unreachable;
 }
}
function __ZN3osg14StateAttributeD2Ev($0) {
 $0 = $0|0;
 var $$0 = 0, $$02 = 0, $$1 = 0, $$13 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $9 = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i12 = 0, $scevgep5$i$i$i = 0, $scevgep5$i$i$i13 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (57384);
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  label = 4;
 } else {
  $4 = HEAP32[$2>>2]|0;
  $5 = ((($4)) + -16|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($2) + ($6)|0);
  $8 = ((($7)) + 8|0);
  $9 = HEAP32[$8>>2]|0;HEAP32[$8>>2] = (($9-1)|0);
  $10 = ($9|0)==(1);
  if ($10) {
   __THREW__ = 0;
   invoke_viii(3262,($7|0),1,1);
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if ($12) {
    $44 = ___cxa_find_matching_catch_2()|0;
    $45 = tempRet0;
    $46 = ((($0)) + 48|0);
    $47 = HEAP32[$46>>2]|0;
    $48 = ($47|0)==(0|0);
    if (!($48)) {
     $49 = HEAP32[$47>>2]|0;
     $50 = ((($49)) + -16|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = (($47) + ($51)|0);
     $53 = ((($52)) + 8|0);
     $54 = HEAP32[$53>>2]|0;HEAP32[$53>>2] = (($54-1)|0);
     $55 = ($54|0)==(1);
     if ($55) {
      __THREW__ = 0;
      invoke_viii(3262,($52|0),1,1);
      $56 = __THREW__; __THREW__ = 0;
      $57 = $56&1;
      if ($57) {
       $83 = ___cxa_find_matching_catch_3(0|0)|0;
       $84 = tempRet0;
       ___clang_call_terminate($83);
       // unreachable;
      }
     }
    }
    HEAP32[$46>>2] = 0;
    $$0 = $45;$$02 = $44;
    label = 21;
   } else {
    label = 4;
   }
  } else {
   label = 4;
  }
 }
 do {
  if ((label|0) == 4) {
   HEAP32[$1>>2] = 0;
   $13 = ((($0)) + 48|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = ($14|0)==(0|0);
   if (!($15)) {
    $16 = HEAP32[$14>>2]|0;
    $17 = ((($16)) + -16|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = (($14) + ($18)|0);
    $20 = ((($19)) + 8|0);
    $21 = HEAP32[$20>>2]|0;HEAP32[$20>>2] = (($21-1)|0);
    $22 = ($21|0)==(1);
    if ($22) {
     __THREW__ = 0;
     invoke_viii(3262,($19|0),1,1);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      $58 = ___cxa_find_matching_catch_2()|0;
      $59 = tempRet0;
      $$0 = $59;$$02 = $58;
      label = 21;
      break;
     }
    }
   }
   HEAP32[$13>>2] = 0;
   $25 = ((($0)) + 44|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = ($26|0)==(0|0);
   if (!($27)) {
    $28 = ((($26)) + 8|0);
    $29 = HEAP32[$28>>2]|0;HEAP32[$28>>2] = (($29-1)|0);
    $30 = ($29|0)==(1);
    if ($30) {
     __THREW__ = 0;
     invoke_viii(3262,($26|0),1,1);
     $31 = __THREW__; __THREW__ = 0;
     $32 = $31&1;
     if ($32) {
      $60 = ___cxa_find_matching_catch_2()|0;
      $61 = tempRet0;
      $$1 = $61;$$13 = $60;
      break;
     }
    }
   }
   HEAP32[$25>>2] = 0;
   $33 = ((($0)) + 32|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = ($34|0)==(0|0);
   if ($35) {
    __ZN3osg6ObjectD2Ev($0);
    return;
   }
   $36 = ((($0)) + 36|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = ($37|0)==($34|0);
   if (!($38)) {
    $scevgep$i$i$i = ((($37)) + -4|0);
    $39 = $scevgep$i$i$i;
    $40 = $34;
    $41 = (($39) - ($40))|0;
    $42 = $41 >>> 2;
    $43 = $42 ^ -1;
    $scevgep5$i$i$i = (($37) + ($43<<2)|0);
    HEAP32[$36>>2] = $scevgep5$i$i$i;
   }
   __ZdlPv($34);
   __ZN3osg6ObjectD2Ev($0);
   return;
  }
 } while(0);
 if ((label|0) == 21) {
  $62 = ((($0)) + 44|0);
  $63 = HEAP32[$62>>2]|0;
  $64 = ($63|0)==(0|0);
  if (!($64)) {
   $65 = ((($63)) + 8|0);
   $66 = HEAP32[$65>>2]|0;HEAP32[$65>>2] = (($66-1)|0);
   $67 = ($66|0)==(1);
   if ($67) {
    __THREW__ = 0;
    invoke_viii(3262,($63|0),1,1);
    $68 = __THREW__; __THREW__ = 0;
    $69 = $68&1;
    if ($69) {
     $83 = ___cxa_find_matching_catch_3(0|0)|0;
     $84 = tempRet0;
     ___clang_call_terminate($83);
     // unreachable;
    }
   }
  }
  HEAP32[$62>>2] = 0;
  $$1 = $$0;$$13 = $$02;
 }
 $70 = ((($0)) + 32|0);
 $71 = HEAP32[$70>>2]|0;
 $72 = ($71|0)==(0|0);
 if (!($72)) {
  $73 = ((($0)) + 36|0);
  $74 = HEAP32[$73>>2]|0;
  $75 = ($74|0)==($71|0);
  if (!($75)) {
   $scevgep$i$i$i12 = ((($74)) + -4|0);
   $76 = $scevgep$i$i$i12;
   $77 = $71;
   $78 = (($76) - ($77))|0;
   $79 = $78 >>> 2;
   $80 = $79 ^ -1;
   $scevgep5$i$i$i13 = (($74) + ($80<<2)|0);
   HEAP32[$73>>2] = $scevgep5$i$i$i13;
  }
  __ZdlPv($71);
 }
 __THREW__ = 0;
 invoke_vi(388,($0|0));
 $81 = __THREW__; __THREW__ = 0;
 $82 = $81&1;
 if ($82) {
  $83 = ___cxa_find_matching_catch_3(0|0)|0;
  $84 = tempRet0;
  ___clang_call_terminate($83);
  // unreachable;
 } else {
  ___resumeException($$13|0);
  // unreachable;
 }
}
function __ZN3osg14StateAttributeD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1573,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK3osg14StateAttribute12isSameKindAsEPKNS_6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,19768,0)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK3osg14StateAttribute11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175113|0);
}
function __ZNK3osg14StateAttribute9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (120458|0);
}
function __ZNK3osg14StateAttribute5applyERNS_5StateE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN3osg9ColorMaskC2Ev($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg14StateAttributeC2Ev($0);
 HEAP32[$0>>2] = (57196);
 $1 = ((($0)) + 56|0);
 HEAP32[$1>>2] = 16843009;
 return;
}
function __ZN3osg20ComputeBoundsVisitorD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $scevgep$i$i$i$i = 0, $scevgep5$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = ((57576));
 $1 = ((($0)) + 92|0);
 HEAP32[$1>>2] = ((57920));
 $2 = ((($0)) + 56|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = ((($0)) + 60|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==($3|0);
  if (!($7)) {
   $scevgep$i$i$i$i = ((($6)) + -128|0);
   $8 = $scevgep$i$i$i$i;
   $9 = $3;
   $10 = (($8) - ($9))|0;
   $11 = $10 >>> 7;
   $12 = $11 ^ -1;
   $scevgep5$i$i$i$i = (($6) + ($12<<7)|0);
   HEAP32[$5>>2] = $scevgep5$i$i$i$i;
  }
  __ZdlPv($3);
 }
 __THREW__ = 0;
 invoke_vii(3284,($0|0),((58064)|0));
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 if (!($14)) {
  __ZN3osg6ObjectD2Ev($1);
  return;
 }
 $15 = ___cxa_find_matching_catch_2()|0;
 $16 = tempRet0;
 __THREW__ = 0;
 invoke_vi(388,($1|0));
 $17 = __THREW__; __THREW__ = 0;
 $18 = $17&1;
 if ($18) {
  $19 = ___cxa_find_matching_catch_3(0|0)|0;
  $20 = tempRet0;
  ___clang_call_terminate($19);
  // unreachable;
 } else {
  ___resumeException($15|0);
  // unreachable;
 }
}
function __ZN3osg20ComputeBoundsVisitorD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, $scevgep$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = ((57576));
 $1 = ((($0)) + 92|0);
 HEAP32[$1>>2] = ((57920));
 $2 = ((($0)) + 56|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = ((($0)) + 60|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==($3|0);
  if (!($7)) {
   $scevgep$i$i$i$i$i = ((($6)) + -128|0);
   $8 = $scevgep$i$i$i$i$i;
   $9 = $3;
   $10 = (($8) - ($9))|0;
   $11 = $10 >>> 7;
   $12 = $11 ^ -1;
   $scevgep5$i$i$i$i$i = (($6) + ($12<<7)|0);
   HEAP32[$5>>2] = $scevgep5$i$i$i$i$i;
  }
  __ZdlPv($3);
 }
 __THREW__ = 0;
 invoke_vii(3284,($0|0),((58064)|0));
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 if ($14) {
  $17 = ___cxa_find_matching_catch_2()|0;
  $18 = tempRet0;
  __THREW__ = 0;
  invoke_vi(388,($1|0));
  $19 = __THREW__; __THREW__ = 0;
  $20 = $19&1;
  if ($20) {
   $21 = ___cxa_find_matching_catch_3(0|0)|0;
   $22 = tempRet0;
   ___clang_call_terminate($21);
   // unreachable;
  } else {
   $eh$lpad$body$index2Z2D = $18;$eh$lpad$body$indexZ2D = $17;
   __ZdlPv($0);
   ___resumeException($eh$lpad$body$indexZ2D|0);
   // unreachable;
  }
 }
 __THREW__ = 0;
 invoke_vi(388,($1|0));
 $15 = __THREW__; __THREW__ = 0;
 $16 = $15&1;
 if (!($16)) {
  __ZdlPv($0);
  return;
 }
 $23 = ___cxa_find_matching_catch_2()|0;
 $24 = tempRet0;
 $eh$lpad$body$index2Z2D = $24;$eh$lpad$body$indexZ2D = $23;
 __ZdlPv($0);
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
}
function __ZNK3osg20ComputeBoundsVisitor11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175113|0);
}
function __ZNK3osg20ComputeBoundsVisitor9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (120490|0);
}
function __ZN3osg20ComputeBoundsVisitor5resetEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i = 0, $scevgep5$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 56|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==($2|0);
 if (!($5)) {
  $scevgep$i$i$i = ((($4)) + -128|0);
  $6 = $scevgep$i$i$i;
  $7 = $2;
  $8 = (($6) - ($7))|0;
  $9 = $8 >>> 7;
  $10 = $9 ^ -1;
  $scevgep5$i$i$i = (($4) + ($10<<7)|0);
  HEAP32[$3>>2] = $scevgep5$i$i$i;
 }
 $11 = ((($0)) + 68|0);
 HEAPF32[$11>>2] = 3.4028234663852886E+38;
 $12 = ((($0)) + 72|0);
 HEAPF32[$12>>2] = 3.4028234663852886E+38;
 $13 = ((($0)) + 76|0);
 HEAPF32[$13>>2] = 3.4028234663852886E+38;
 $14 = ((($0)) + 80|0);
 HEAPF32[$14>>2] = -3.4028234663852886E+38;
 $15 = ((($0)) + 84|0);
 HEAPF32[$15>>2] = -3.4028234663852886E+38;
 $16 = ((($0)) + 88|0);
 HEAPF32[$16>>2] = -3.4028234663852886E+38;
 return;
}
function __ZN3osg20ComputeBoundsVisitor5applyERNS_8DrawableE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__ZNK3osg8Drawable14getBoundingBoxEv($1)|0);
 __ZN3osg20ComputeBoundsVisitor16applyBoundingBoxERKNS_15BoundingBoxImplINS_5Vec3fEEE($0,$2);
 return;
}
function __ZN3osg20ComputeBoundsVisitor5applyERNS_9TransformE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0.0, $100 = 0, $101 = 0, $102 = 0.0, $103 = 0, $104 = 0, $105 = 0.0, $106 = 0, $107 = 0, $108 = 0.0, $109 = 0, $11 = 0, $110 = 0, $111 = 0.0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0.0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $13 = 0, $14 = 0, $15 = 0.0, $16 = 0, $17 = 0, $18 = 0.0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0.0, $22 = 0, $23 = 0, $24 = 0.0, $25 = 0, $26 = 0, $27 = 0.0, $28 = 0, $29 = 0, $3 = 0, $30 = 0.0, $31 = 0, $32 = 0, $33 = 0.0, $34 = 0, $35 = 0, $36 = 0.0, $37 = 0, $38 = 0;
 var $39 = 0.0, $4 = 0, $40 = 0, $41 = 0, $42 = 0.0, $43 = 0, $44 = 0, $45 = 0.0, $46 = 0, $47 = 0, $48 = 0.0, $49 = 0, $5 = 0, $50 = 0, $51 = 0.0, $52 = 0, $53 = 0, $54 = 0.0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0.0, $68 = 0, $69 = 0.0, $7 = 0, $70 = 0, $71 = 0, $72 = 0.0, $73 = 0, $74 = 0;
 var $75 = 0.0, $76 = 0, $77 = 0, $78 = 0.0, $79 = 0, $8 = 0, $80 = 0, $81 = 0.0, $82 = 0, $83 = 0, $84 = 0.0, $85 = 0, $86 = 0, $87 = 0.0, $88 = 0, $89 = 0, $9 = 0, $90 = 0.0, $91 = 0, $92 = 0;
 var $93 = 0.0, $94 = 0, $95 = 0, $96 = 0.0, $97 = 0, $98 = 0, $99 = 0.0, $scevgep5$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(128|0);
 $2 = sp;
 __ZN3osg7Matrixd12makeIdentityEv($2);
 $3 = ((($0)) + 56|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 60|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4|0)==($6|0);
 if (!($7)) {
  $8 = ((($6)) + -128|0);
  $9 = ($8|0)==($2|0);
  if (!($9)) {
   $10 = +HEAPF64[$8>>3];
   HEAPF64[$2>>3] = $10;
   $11 = ((($6)) + -120|0);
   $12 = +HEAPF64[$11>>3];
   $13 = ((($2)) + 8|0);
   HEAPF64[$13>>3] = $12;
   $14 = ((($6)) + -112|0);
   $15 = +HEAPF64[$14>>3];
   $16 = ((($2)) + 16|0);
   HEAPF64[$16>>3] = $15;
   $17 = ((($6)) + -104|0);
   $18 = +HEAPF64[$17>>3];
   $19 = ((($2)) + 24|0);
   HEAPF64[$19>>3] = $18;
   $20 = ((($6)) + -96|0);
   $21 = +HEAPF64[$20>>3];
   $22 = ((($2)) + 32|0);
   HEAPF64[$22>>3] = $21;
   $23 = ((($6)) + -88|0);
   $24 = +HEAPF64[$23>>3];
   $25 = ((($2)) + 40|0);
   HEAPF64[$25>>3] = $24;
   $26 = ((($6)) + -80|0);
   $27 = +HEAPF64[$26>>3];
   $28 = ((($2)) + 48|0);
   HEAPF64[$28>>3] = $27;
   $29 = ((($6)) + -72|0);
   $30 = +HEAPF64[$29>>3];
   $31 = ((($2)) + 56|0);
   HEAPF64[$31>>3] = $30;
   $32 = ((($6)) + -64|0);
   $33 = +HEAPF64[$32>>3];
   $34 = ((($2)) + 64|0);
   HEAPF64[$34>>3] = $33;
   $35 = ((($6)) + -56|0);
   $36 = +HEAPF64[$35>>3];
   $37 = ((($2)) + 72|0);
   HEAPF64[$37>>3] = $36;
   $38 = ((($6)) + -48|0);
   $39 = +HEAPF64[$38>>3];
   $40 = ((($2)) + 80|0);
   HEAPF64[$40>>3] = $39;
   $41 = ((($6)) + -40|0);
   $42 = +HEAPF64[$41>>3];
   $43 = ((($2)) + 88|0);
   HEAPF64[$43>>3] = $42;
   $44 = ((($6)) + -32|0);
   $45 = +HEAPF64[$44>>3];
   $46 = ((($2)) + 96|0);
   HEAPF64[$46>>3] = $45;
   $47 = ((($6)) + -24|0);
   $48 = +HEAPF64[$47>>3];
   $49 = ((($2)) + 104|0);
   HEAPF64[$49>>3] = $48;
   $50 = ((($6)) + -16|0);
   $51 = +HEAPF64[$50>>3];
   $52 = ((($2)) + 112|0);
   HEAPF64[$52>>3] = $51;
   $53 = ((($6)) + -8|0);
   $54 = +HEAPF64[$53>>3];
   $55 = ((($2)) + 120|0);
   HEAPF64[$55>>3] = $54;
  }
 }
 $58 = HEAP32[$1>>2]|0;
 $59 = ((($58)) + 264|0);
 $60 = HEAP32[$59>>2]|0;
 __THREW__ = 0;
 (invoke_iiii($60|0,($1|0),($2|0),($0|0))|0);
 $61 = __THREW__; __THREW__ = 0;
 $62 = $61&1;
 if ($62) {
  $56 = ___cxa_find_matching_catch_2()|0;
  $57 = tempRet0;
  ___resumeException($56|0);
  // unreachable;
 }
 $63 = HEAP32[$5>>2]|0;
 $64 = ((($0)) + 64|0);
 $65 = HEAP32[$64>>2]|0;
 $66 = ($63|0)==($65|0);
 if ($66) {
  __THREW__ = 0;
  invoke_vii(3730,($3|0),($2|0));
  $114 = __THREW__; __THREW__ = 0;
  $115 = $114&1;
  if ($115) {
   $56 = ___cxa_find_matching_catch_2()|0;
   $57 = tempRet0;
   ___resumeException($56|0);
   // unreachable;
  }
 } else {
  $67 = +HEAPF64[$2>>3];
  HEAPF64[$63>>3] = $67;
  $68 = ((($2)) + 8|0);
  $69 = +HEAPF64[$68>>3];
  $70 = ((($63)) + 8|0);
  HEAPF64[$70>>3] = $69;
  $71 = ((($2)) + 16|0);
  $72 = +HEAPF64[$71>>3];
  $73 = ((($63)) + 16|0);
  HEAPF64[$73>>3] = $72;
  $74 = ((($2)) + 24|0);
  $75 = +HEAPF64[$74>>3];
  $76 = ((($63)) + 24|0);
  HEAPF64[$76>>3] = $75;
  $77 = ((($2)) + 32|0);
  $78 = +HEAPF64[$77>>3];
  $79 = ((($63)) + 32|0);
  HEAPF64[$79>>3] = $78;
  $80 = ((($2)) + 40|0);
  $81 = +HEAPF64[$80>>3];
  $82 = ((($63)) + 40|0);
  HEAPF64[$82>>3] = $81;
  $83 = ((($2)) + 48|0);
  $84 = +HEAPF64[$83>>3];
  $85 = ((($63)) + 48|0);
  HEAPF64[$85>>3] = $84;
  $86 = ((($2)) + 56|0);
  $87 = +HEAPF64[$86>>3];
  $88 = ((($63)) + 56|0);
  HEAPF64[$88>>3] = $87;
  $89 = ((($2)) + 64|0);
  $90 = +HEAPF64[$89>>3];
  $91 = ((($63)) + 64|0);
  HEAPF64[$91>>3] = $90;
  $92 = ((($2)) + 72|0);
  $93 = +HEAPF64[$92>>3];
  $94 = ((($63)) + 72|0);
  HEAPF64[$94>>3] = $93;
  $95 = ((($2)) + 80|0);
  $96 = +HEAPF64[$95>>3];
  $97 = ((($63)) + 80|0);
  HEAPF64[$97>>3] = $96;
  $98 = ((($2)) + 88|0);
  $99 = +HEAPF64[$98>>3];
  $100 = ((($63)) + 88|0);
  HEAPF64[$100>>3] = $99;
  $101 = ((($2)) + 96|0);
  $102 = +HEAPF64[$101>>3];
  $103 = ((($63)) + 96|0);
  HEAPF64[$103>>3] = $102;
  $104 = ((($2)) + 104|0);
  $105 = +HEAPF64[$104>>3];
  $106 = ((($63)) + 104|0);
  HEAPF64[$106>>3] = $105;
  $107 = ((($2)) + 112|0);
  $108 = +HEAPF64[$107>>3];
  $109 = ((($63)) + 112|0);
  HEAPF64[$109>>3] = $108;
  $110 = ((($2)) + 120|0);
  $111 = +HEAPF64[$110>>3];
  $112 = ((($63)) + 120|0);
  HEAPF64[$112>>3] = $111;
  $113 = ((($63)) + 128|0);
  HEAP32[$5>>2] = $113;
 }
 $116 = ((($0)) + 16|0);
 $117 = HEAP32[$116>>2]|0;
 switch ($117|0) {
 case 1:  {
  $118 = HEAP32[$1>>2]|0;
  $119 = ((($118)) + 192|0);
  $120 = HEAP32[$119>>2]|0;
  __THREW__ = 0;
  invoke_vii($120|0,($1|0),($0|0));
  $121 = __THREW__; __THREW__ = 0;
  $122 = $121&1;
  if ($122) {
   $56 = ___cxa_find_matching_catch_2()|0;
   $57 = tempRet0;
   ___resumeException($56|0);
   // unreachable;
  } else {
   $128 = HEAP32[$5>>2]|0;
   $scevgep5$i$i$i$i = ((($128)) + -128|0);
   HEAP32[$5>>2] = $scevgep5$i$i$i$i;
   STACKTOP = sp;return;
  }
  break;
 }
 case 0:  {
  $128 = HEAP32[$5>>2]|0;
  $scevgep5$i$i$i$i = ((($128)) + -128|0);
  HEAP32[$5>>2] = $scevgep5$i$i$i$i;
  STACKTOP = sp;return;
  break;
 }
 default: {
  $123 = HEAP32[$1>>2]|0;
  $124 = ((($123)) + 196|0);
  $125 = HEAP32[$124>>2]|0;
  __THREW__ = 0;
  invoke_vii($125|0,($1|0),($0|0));
  $126 = __THREW__; __THREW__ = 0;
  $127 = $126&1;
  if ($127) {
   $56 = ___cxa_find_matching_catch_2()|0;
   $57 = tempRet0;
   ___resumeException($56|0);
   // unreachable;
  } else {
   $128 = HEAP32[$5>>2]|0;
   $scevgep5$i$i$i$i = ((($128)) + -128|0);
   HEAP32[$5>>2] = $scevgep5$i$i$i$i;
   STACKTOP = sp;return;
  }
 }
 }
}
function __ZTv0_n16_N3osg20ComputeBoundsVisitorD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 HEAP32[$4>>2] = ((57576));
 $5 = ((($4)) + 92|0);
 HEAP32[$5>>2] = ((57920));
 $6 = ((($4)) + 56|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = ((($4)) + 60|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10|0)==($7|0);
  if (!($11)) {
   $scevgep$i$i$i$i$i = ((($10)) + -128|0);
   $12 = $scevgep$i$i$i$i$i;
   $13 = $7;
   $14 = (($12) - ($13))|0;
   $15 = $14 >>> 7;
   $16 = $15 ^ -1;
   $scevgep5$i$i$i$i$i = (($10) + ($16<<7)|0);
   HEAP32[$9>>2] = $scevgep5$i$i$i$i$i;
  }
  __ZdlPv($7);
 }
 __THREW__ = 0;
 invoke_vii(3284,($4|0),((58064)|0));
 $17 = __THREW__; __THREW__ = 0;
 $18 = $17&1;
 if (!($18)) {
  __ZN3osg6ObjectD2Ev($5);
  return;
 }
 $19 = ___cxa_find_matching_catch_2()|0;
 $20 = tempRet0;
 __THREW__ = 0;
 invoke_vi(388,($5|0));
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if ($22) {
  $23 = ___cxa_find_matching_catch_3(0|0)|0;
  $24 = tempRet0;
  ___clang_call_terminate($23);
  // unreachable;
 } else {
  ___resumeException($19|0);
  // unreachable;
 }
}
function __ZTv0_n16_N3osg20ComputeBoundsVisitorD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$i$index2Z2D = 0, $eh$lpad$body$i$indexZ2D = 0, $scevgep$i$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 HEAP32[$4>>2] = ((57576));
 $5 = ((($4)) + 92|0);
 HEAP32[$5>>2] = ((57920));
 $6 = ((($4)) + 56|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = ((($4)) + 60|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10|0)==($7|0);
  if (!($11)) {
   $scevgep$i$i$i$i$i$i = ((($10)) + -128|0);
   $12 = $scevgep$i$i$i$i$i$i;
   $13 = $7;
   $14 = (($12) - ($13))|0;
   $15 = $14 >>> 7;
   $16 = $15 ^ -1;
   $scevgep5$i$i$i$i$i$i = (($10) + ($16<<7)|0);
   HEAP32[$9>>2] = $scevgep5$i$i$i$i$i$i;
  }
  __ZdlPv($7);
 }
 __THREW__ = 0;
 invoke_vii(3284,($4|0),((58064)|0));
 $17 = __THREW__; __THREW__ = 0;
 $18 = $17&1;
 if ($18) {
  $21 = ___cxa_find_matching_catch_2()|0;
  $22 = tempRet0;
  __THREW__ = 0;
  invoke_vi(388,($5|0));
  $23 = __THREW__; __THREW__ = 0;
  $24 = $23&1;
  if ($24) {
   $25 = ___cxa_find_matching_catch_3(0|0)|0;
   $26 = tempRet0;
   ___clang_call_terminate($25);
   // unreachable;
  } else {
   $eh$lpad$body$i$index2Z2D = $22;$eh$lpad$body$i$indexZ2D = $21;
   __ZdlPv($4);
   ___resumeException($eh$lpad$body$i$indexZ2D|0);
   // unreachable;
  }
 }
 __THREW__ = 0;
 invoke_vi(388,($5|0));
 $19 = __THREW__; __THREW__ = 0;
 $20 = $19&1;
 if (!($20)) {
  __ZdlPv($4);
  return;
 }
 $27 = ___cxa_find_matching_catch_2()|0;
 $28 = tempRet0;
 $eh$lpad$body$i$index2Z2D = $28;$eh$lpad$body$i$indexZ2D = $27;
 __ZdlPv($4);
 ___resumeException($eh$lpad$body$i$indexZ2D|0);
 // unreachable;
}
function __ZTv0_n32_NK3osg20ComputeBoundsVisitor11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175113|0);
}
function __ZTv0_n36_NK3osg20ComputeBoundsVisitor9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (120490|0);
}
function __ZN3osg20ComputeBoundsVisitor16applyBoundingBoxERKNS_15BoundingBoxImplINS_5Vec3fEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$pre$i48 = 0.0, $10 = 0, $100 = 0.0, $101 = 0.0, $102 = 0.0, $103 = 0.0, $104 = 0, $105 = 0.0, $106 = 0.0, $107 = 0, $108 = 0.0, $109 = 0.0, $11 = 0, $110 = 0.0, $111 = 0, $112 = 0.0, $113 = 0.0, $114 = 0.0, $115 = 0, $116 = 0.0;
 var $117 = 0.0, $118 = 0.0, $119 = 0.0, $12 = 0.0, $120 = 0, $121 = 0.0, $122 = 0, $123 = 0, $124 = 0.0, $125 = 0, $126 = 0, $127 = 0.0, $128 = 0, $129 = 0, $13 = 0, $130 = 0.0, $131 = 0, $132 = 0, $133 = 0.0, $134 = 0;
 var $135 = 0, $136 = 0.0, $137 = 0, $138 = 0, $139 = 0.0, $14 = 0.0, $140 = 0.0, $141 = 0.0, $142 = 0.0, $143 = 0.0, $144 = 0.0, $145 = 0.0, $146 = 0.0, $147 = 0.0, $148 = 0.0, $149 = 0.0, $15 = 0, $150 = 0.0, $151 = 0.0, $152 = 0.0;
 var $153 = 0.0, $154 = 0.0, $155 = 0.0, $156 = 0.0, $157 = 0.0, $158 = 0.0, $159 = 0.0, $16 = 0, $160 = 0.0, $161 = 0.0, $162 = 0.0, $163 = 0.0, $164 = 0.0, $165 = 0.0, $166 = 0.0, $167 = 0.0, $168 = 0.0, $169 = 0.0, $17 = 0.0, $170 = 0.0;
 var $171 = 0.0, $172 = 0.0, $173 = 0.0, $174 = 0.0, $175 = 0.0, $176 = 0.0, $177 = 0.0, $178 = 0.0, $179 = 0.0, $18 = 0, $180 = 0.0, $181 = 0.0, $182 = 0.0, $183 = 0.0, $184 = 0.0, $185 = 0.0, $186 = 0.0, $187 = 0.0, $188 = 0.0, $189 = 0.0;
 var $19 = 0.0, $190 = 0.0, $191 = 0.0, $192 = 0, $193 = 0.0, $194 = 0, $195 = 0.0, $196 = 0, $197 = 0.0, $198 = 0, $199 = 0.0, $2 = 0, $20 = 0, $200 = 0, $201 = 0.0, $202 = 0, $203 = 0.0, $204 = 0.0, $205 = 0.0, $206 = 0.0;
 var $207 = 0.0, $208 = 0.0, $209 = 0.0, $21 = 0, $210 = 0.0, $211 = 0.0, $212 = 0.0, $213 = 0.0, $214 = 0.0, $215 = 0.0, $216 = 0.0, $217 = 0.0, $218 = 0.0, $219 = 0.0, $22 = 0.0, $220 = 0.0, $221 = 0.0, $222 = 0.0, $223 = 0.0, $224 = 0.0;
 var $225 = 0.0, $226 = 0.0, $227 = 0.0, $228 = 0.0, $229 = 0.0, $23 = 0, $230 = 0.0, $231 = 0.0, $232 = 0.0, $233 = 0.0, $234 = 0.0, $235 = 0.0, $236 = 0.0, $237 = 0.0, $238 = 0.0, $239 = 0.0, $24 = 0, $240 = 0.0, $241 = 0.0, $242 = 0.0;
 var $243 = 0.0, $244 = 0.0, $245 = 0.0, $246 = 0.0, $247 = 0.0, $248 = 0.0, $249 = 0.0, $25 = 0.0, $250 = 0.0, $251 = 0.0, $252 = 0.0, $253 = 0.0, $254 = 0.0, $255 = 0.0, $256 = 0.0, $257 = 0, $258 = 0.0, $259 = 0, $26 = 0, $260 = 0.0;
 var $261 = 0, $262 = 0.0, $263 = 0, $264 = 0.0, $265 = 0, $266 = 0.0, $267 = 0, $268 = 0.0, $269 = 0.0, $27 = 0.0, $270 = 0.0, $271 = 0.0, $272 = 0.0, $273 = 0.0, $274 = 0.0, $275 = 0.0, $276 = 0.0, $277 = 0.0, $278 = 0.0, $279 = 0.0;
 var $28 = 0.0, $280 = 0.0, $281 = 0.0, $282 = 0.0, $283 = 0.0, $284 = 0.0, $285 = 0.0, $286 = 0.0, $287 = 0.0, $288 = 0.0, $289 = 0.0, $29 = 0, $290 = 0.0, $291 = 0.0, $292 = 0.0, $293 = 0.0, $294 = 0.0, $295 = 0.0, $296 = 0.0, $297 = 0.0;
 var $298 = 0.0, $299 = 0.0, $3 = 0, $30 = 0.0, $300 = 0.0, $301 = 0.0, $302 = 0.0, $303 = 0.0, $304 = 0.0, $305 = 0.0, $306 = 0.0, $307 = 0.0, $308 = 0.0, $309 = 0.0, $31 = 0, $310 = 0.0, $311 = 0.0, $312 = 0.0, $313 = 0.0, $314 = 0.0;
 var $315 = 0.0, $316 = 0.0, $317 = 0.0, $318 = 0.0, $319 = 0.0, $32 = 0.0, $320 = 0.0, $321 = 0.0, $322 = 0, $323 = 0.0, $324 = 0, $325 = 0.0, $326 = 0, $327 = 0.0, $328 = 0, $329 = 0.0, $33 = 0, $330 = 0, $331 = 0.0, $332 = 0;
 var $333 = 0.0, $334 = 0.0, $335 = 0.0, $336 = 0.0, $337 = 0.0, $338 = 0.0, $339 = 0.0, $34 = 0.0, $340 = 0.0, $341 = 0.0, $342 = 0.0, $343 = 0.0, $344 = 0.0, $345 = 0.0, $346 = 0.0, $347 = 0.0, $348 = 0.0, $349 = 0.0, $35 = 0, $350 = 0.0;
 var $351 = 0.0, $352 = 0.0, $353 = 0.0, $354 = 0.0, $355 = 0.0, $356 = 0.0, $357 = 0.0, $358 = 0.0, $359 = 0.0, $36 = 0.0, $360 = 0.0, $361 = 0.0, $362 = 0.0, $363 = 0.0, $364 = 0.0, $365 = 0.0, $366 = 0.0, $367 = 0.0, $368 = 0.0, $369 = 0.0;
 var $37 = 0, $370 = 0.0, $371 = 0.0, $372 = 0.0, $373 = 0.0, $374 = 0.0, $375 = 0.0, $376 = 0.0, $377 = 0.0, $378 = 0.0, $379 = 0.0, $38 = 0.0, $380 = 0.0, $381 = 0.0, $382 = 0.0, $383 = 0.0, $384 = 0.0, $385 = 0.0, $386 = 0.0, $387 = 0;
 var $388 = 0.0, $389 = 0, $39 = 0, $390 = 0.0, $391 = 0, $392 = 0.0, $393 = 0, $394 = 0.0, $395 = 0, $396 = 0.0, $397 = 0, $398 = 0.0, $399 = 0.0, $4 = 0, $40 = 0.0, $400 = 0.0, $401 = 0.0, $402 = 0.0, $403 = 0.0, $404 = 0.0;
 var $405 = 0.0, $406 = 0.0, $407 = 0.0, $408 = 0.0, $409 = 0.0, $41 = 0, $410 = 0.0, $411 = 0.0, $412 = 0.0, $413 = 0.0, $414 = 0.0, $415 = 0.0, $416 = 0.0, $417 = 0.0, $418 = 0.0, $419 = 0.0, $42 = 0.0, $420 = 0.0, $421 = 0.0, $422 = 0.0;
 var $423 = 0.0, $424 = 0.0, $425 = 0.0, $426 = 0.0, $427 = 0.0, $428 = 0.0, $429 = 0.0, $43 = 0, $430 = 0.0, $431 = 0.0, $432 = 0.0, $433 = 0.0, $434 = 0.0, $435 = 0.0, $436 = 0.0, $437 = 0.0, $438 = 0.0, $439 = 0.0, $44 = 0, $440 = 0.0;
 var $441 = 0.0, $442 = 0.0, $443 = 0.0, $444 = 0.0, $445 = 0.0, $446 = 0.0, $447 = 0.0, $448 = 0.0, $449 = 0.0, $45 = 0.0, $450 = 0.0, $451 = 0.0, $452 = 0, $453 = 0.0, $454 = 0, $455 = 0.0, $456 = 0, $457 = 0.0, $458 = 0, $459 = 0.0;
 var $46 = 0, $460 = 0, $461 = 0.0, $462 = 0, $463 = 0.0, $464 = 0.0, $465 = 0.0, $466 = 0.0, $467 = 0.0, $468 = 0.0, $469 = 0.0, $47 = 0.0, $470 = 0.0, $471 = 0.0, $472 = 0.0, $473 = 0.0, $474 = 0.0, $475 = 0.0, $476 = 0.0, $477 = 0.0;
 var $478 = 0.0, $479 = 0.0, $48 = 0, $480 = 0.0, $481 = 0.0, $482 = 0.0, $483 = 0.0, $484 = 0.0, $485 = 0.0, $486 = 0.0, $487 = 0.0, $488 = 0.0, $489 = 0.0, $49 = 0, $490 = 0.0, $491 = 0.0, $492 = 0.0, $493 = 0.0, $494 = 0.0, $495 = 0.0;
 var $496 = 0.0, $497 = 0.0, $498 = 0.0, $499 = 0.0, $5 = 0, $50 = 0.0, $500 = 0.0, $501 = 0.0, $502 = 0.0, $503 = 0.0, $504 = 0.0, $505 = 0.0, $506 = 0.0, $507 = 0.0, $508 = 0.0, $509 = 0.0, $51 = 0, $510 = 0.0, $511 = 0.0, $512 = 0.0;
 var $513 = 0.0, $514 = 0.0, $515 = 0.0, $516 = 0.0, $517 = 0, $518 = 0.0, $519 = 0, $52 = 0.0, $520 = 0.0, $521 = 0, $522 = 0.0, $523 = 0, $524 = 0.0, $525 = 0, $526 = 0.0, $527 = 0, $528 = 0.0, $529 = 0.0, $53 = 0, $530 = 0.0;
 var $531 = 0.0, $532 = 0.0, $533 = 0.0, $534 = 0.0, $535 = 0.0, $536 = 0.0, $537 = 0.0, $538 = 0.0, $539 = 0.0, $54 = 0, $540 = 0.0, $541 = 0.0, $542 = 0.0, $543 = 0.0, $544 = 0.0, $545 = 0.0, $546 = 0.0, $547 = 0.0, $548 = 0.0, $549 = 0.0;
 var $55 = 0.0, $550 = 0.0, $551 = 0.0, $552 = 0.0, $553 = 0.0, $554 = 0.0, $555 = 0.0, $556 = 0.0, $557 = 0.0, $558 = 0.0, $559 = 0.0, $56 = 0.0, $560 = 0.0, $561 = 0.0, $562 = 0.0, $563 = 0.0, $564 = 0.0, $565 = 0.0, $566 = 0.0, $567 = 0.0;
 var $568 = 0.0, $569 = 0.0, $57 = 0.0, $570 = 0.0, $571 = 0.0, $572 = 0.0, $573 = 0.0, $574 = 0.0, $575 = 0.0, $576 = 0.0, $577 = 0.0, $578 = 0.0, $579 = 0.0, $58 = 0, $580 = 0.0, $581 = 0.0, $582 = 0, $583 = 0.0, $584 = 0, $585 = 0.0;
 var $586 = 0, $587 = 0.0, $588 = 0, $589 = 0.0, $59 = 0.0, $590 = 0, $591 = 0.0, $592 = 0, $593 = 0.0, $6 = 0, $60 = 0.0, $61 = 0.0, $62 = 0.0, $63 = 0, $64 = 0.0, $65 = 0.0, $66 = 0.0, $67 = 0.0, $68 = 0, $69 = 0.0;
 var $7 = 0, $70 = 0.0, $71 = 0.0, $72 = 0, $73 = 0.0, $74 = 0.0, $75 = 0, $76 = 0.0, $77 = 0.0, $78 = 0.0, $79 = 0, $8 = 0.0, $80 = 0.0, $81 = 0.0, $82 = 0.0, $83 = 0, $84 = 0.0, $85 = 0.0, $86 = 0.0, $87 = 0.0;
 var $88 = 0, $89 = 0.0, $9 = 0.0, $90 = 0.0, $91 = 0, $92 = 0.0, $93 = 0.0, $94 = 0.0, $95 = 0, $96 = 0.0, $97 = 0.0, $98 = 0.0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 56|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 60|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 $7 = ((($1)) + 12|0);
 $8 = +HEAPF32[$7>>2];
 $9 = +HEAPF32[$1>>2];
 $10 = !($8 >= $9);
 if ($6) {
  if ($10) {
   return;
  }
  $11 = ((($1)) + 16|0);
  $12 = +HEAPF32[$11>>2];
  $13 = ((($1)) + 4|0);
  $14 = +HEAPF32[$13>>2];
  $15 = !($12 >= $14);
  if ($15) {
   return;
  }
  $16 = ((($1)) + 20|0);
  $17 = +HEAPF32[$16>>2];
  $18 = ((($1)) + 8|0);
  $19 = +HEAPF32[$18>>2];
  $20 = !($17 >= $19);
  if ($20) {
   return;
  }
  $21 = ((($0)) + 68|0);
  $22 = +HEAPF32[$21>>2];
  $23 = $9 < $22;
  if ($23) {
   HEAPF32[$21>>2] = $9;
   $$pre$i48 = +HEAPF32[$7>>2];
   $27 = $$pre$i48;
  } else {
   $27 = $8;
  }
  $24 = ((($0)) + 80|0);
  $25 = +HEAPF32[$24>>2];
  $26 = $27 > $25;
  if ($26) {
   HEAPF32[$24>>2] = $27;
  }
  $28 = +HEAPF32[$13>>2];
  $29 = ((($0)) + 72|0);
  $30 = +HEAPF32[$29>>2];
  $31 = $28 < $30;
  if ($31) {
   HEAPF32[$29>>2] = $28;
  }
  $32 = +HEAPF32[$11>>2];
  $33 = ((($0)) + 84|0);
  $34 = +HEAPF32[$33>>2];
  $35 = $32 > $34;
  if ($35) {
   HEAPF32[$33>>2] = $32;
  }
  $36 = +HEAPF32[$18>>2];
  $37 = ((($0)) + 76|0);
  $38 = +HEAPF32[$37>>2];
  $39 = $36 < $38;
  if ($39) {
   HEAPF32[$37>>2] = $36;
  }
  $40 = +HEAPF32[$16>>2];
  $41 = ((($0)) + 88|0);
  $42 = +HEAPF32[$41>>2];
  $43 = $40 > $42;
  if (!($43)) {
   return;
  }
  HEAPF32[$41>>2] = $40;
  return;
 }
 if ($10) {
  return;
 }
 $44 = ((($1)) + 16|0);
 $45 = +HEAPF32[$44>>2];
 $46 = ((($1)) + 4|0);
 $47 = +HEAPF32[$46>>2];
 $48 = !($45 >= $47);
 if ($48) {
  return;
 }
 $49 = ((($1)) + 20|0);
 $50 = +HEAPF32[$49>>2];
 $51 = ((($1)) + 8|0);
 $52 = +HEAPF32[$51>>2];
 $53 = !($50 >= $52);
 if ($53) {
  return;
 }
 $54 = ((($5)) + -104|0);
 $55 = +HEAPF64[$54>>3];
 $56 = $9;
 $57 = $56 * $55;
 $58 = ((($5)) + -72|0);
 $59 = +HEAPF64[$58>>3];
 $60 = $47;
 $61 = $60 * $59;
 $62 = $57 + $61;
 $63 = ((($5)) + -40|0);
 $64 = +HEAPF64[$63>>3];
 $65 = $52;
 $66 = $65 * $64;
 $67 = $62 + $66;
 $68 = ((($5)) + -8|0);
 $69 = +HEAPF64[$68>>3];
 $70 = $69 + $67;
 $71 = 1.0 / $70;
 $72 = ((($5)) + -128|0);
 $73 = +HEAPF64[$72>>3];
 $74 = $56 * $73;
 $75 = ((($5)) + -96|0);
 $76 = +HEAPF64[$75>>3];
 $77 = $60 * $76;
 $78 = $74 + $77;
 $79 = ((($5)) + -64|0);
 $80 = +HEAPF64[$79>>3];
 $81 = $65 * $80;
 $82 = $78 + $81;
 $83 = ((($5)) + -32|0);
 $84 = +HEAPF64[$83>>3];
 $85 = $84 + $82;
 $86 = $71 * $85;
 $87 = $86;
 $88 = ((($5)) + -120|0);
 $89 = +HEAPF64[$88>>3];
 $90 = $56 * $89;
 $91 = ((($5)) + -88|0);
 $92 = +HEAPF64[$91>>3];
 $93 = $60 * $92;
 $94 = $90 + $93;
 $95 = ((($5)) + -56|0);
 $96 = +HEAPF64[$95>>3];
 $97 = $65 * $96;
 $98 = $94 + $97;
 $99 = ((($5)) + -24|0);
 $100 = +HEAPF64[$99>>3];
 $101 = $100 + $98;
 $102 = $71 * $101;
 $103 = $102;
 $104 = ((($5)) + -112|0);
 $105 = +HEAPF64[$104>>3];
 $106 = $56 * $105;
 $107 = ((($5)) + -80|0);
 $108 = +HEAPF64[$107>>3];
 $109 = $60 * $108;
 $110 = $106 + $109;
 $111 = ((($5)) + -48|0);
 $112 = +HEAPF64[$111>>3];
 $113 = $65 * $112;
 $114 = $110 + $113;
 $115 = ((($5)) + -16|0);
 $116 = +HEAPF64[$115>>3];
 $117 = $116 + $114;
 $118 = $71 * $117;
 $119 = $118;
 $120 = ((($0)) + 68|0);
 $121 = +HEAPF32[$120>>2];
 $122 = $87 < $121;
 if ($122) {
  HEAPF32[$120>>2] = $87;
  $193 = $87;
 } else {
  $193 = $121;
 }
 $123 = ((($0)) + 80|0);
 $124 = +HEAPF32[$123>>2];
 $125 = $87 > $124;
 if ($125) {
  HEAPF32[$123>>2] = $87;
  $195 = $87;
 } else {
  $195 = $124;
 }
 $126 = ((($0)) + 72|0);
 $127 = +HEAPF32[$126>>2];
 $128 = $103 < $127;
 if ($128) {
  HEAPF32[$126>>2] = $103;
  $197 = $103;
 } else {
  $197 = $127;
 }
 $129 = ((($0)) + 84|0);
 $130 = +HEAPF32[$129>>2];
 $131 = $103 > $130;
 if ($131) {
  HEAPF32[$129>>2] = $103;
  $199 = $103;
 } else {
  $199 = $130;
 }
 $132 = ((($0)) + 76|0);
 $133 = +HEAPF32[$132>>2];
 $134 = $119 < $133;
 if ($134) {
  HEAPF32[$132>>2] = $119;
  $201 = $119;
 } else {
  $201 = $133;
 }
 $135 = ((($0)) + 88|0);
 $136 = +HEAPF32[$135>>2];
 $137 = $119 > $136;
 if ($137) {
  HEAPF32[$135>>2] = $119;
  $203 = $119;
 } else {
  $203 = $136;
 }
 $138 = ((($1)) + 12|0);
 $139 = +HEAPF32[$138>>2];
 $140 = +HEAPF32[$46>>2];
 $141 = +HEAPF32[$51>>2];
 $142 = +HEAPF64[$54>>3];
 $143 = $139;
 $144 = $143 * $142;
 $145 = +HEAPF64[$58>>3];
 $146 = $140;
 $147 = $146 * $145;
 $148 = $144 + $147;
 $149 = +HEAPF64[$63>>3];
 $150 = $141;
 $151 = $150 * $149;
 $152 = $148 + $151;
 $153 = +HEAPF64[$68>>3];
 $154 = $153 + $152;
 $155 = 1.0 / $154;
 $156 = +HEAPF64[$72>>3];
 $157 = $143 * $156;
 $158 = +HEAPF64[$75>>3];
 $159 = $146 * $158;
 $160 = $157 + $159;
 $161 = +HEAPF64[$79>>3];
 $162 = $150 * $161;
 $163 = $160 + $162;
 $164 = +HEAPF64[$83>>3];
 $165 = $164 + $163;
 $166 = $155 * $165;
 $167 = $166;
 $168 = +HEAPF64[$88>>3];
 $169 = $143 * $168;
 $170 = +HEAPF64[$91>>3];
 $171 = $146 * $170;
 $172 = $169 + $171;
 $173 = +HEAPF64[$95>>3];
 $174 = $150 * $173;
 $175 = $172 + $174;
 $176 = +HEAPF64[$99>>3];
 $177 = $176 + $175;
 $178 = $155 * $177;
 $179 = $178;
 $180 = +HEAPF64[$104>>3];
 $181 = $143 * $180;
 $182 = +HEAPF64[$107>>3];
 $183 = $146 * $182;
 $184 = $181 + $183;
 $185 = +HEAPF64[$111>>3];
 $186 = $150 * $185;
 $187 = $184 + $186;
 $188 = +HEAPF64[$115>>3];
 $189 = $188 + $187;
 $190 = $155 * $189;
 $191 = $190;
 $192 = $167 < $193;
 if ($192) {
  HEAPF32[$120>>2] = $167;
  $258 = $167;
 } else {
  $258 = $193;
 }
 $194 = $167 > $195;
 if ($194) {
  HEAPF32[$123>>2] = $167;
  $260 = $167;
 } else {
  $260 = $195;
 }
 $196 = $179 < $197;
 if ($196) {
  HEAPF32[$126>>2] = $179;
  $262 = $179;
 } else {
  $262 = $197;
 }
 $198 = $179 > $199;
 if ($198) {
  HEAPF32[$129>>2] = $179;
  $264 = $179;
 } else {
  $264 = $199;
 }
 $200 = $191 < $201;
 if ($200) {
  HEAPF32[$132>>2] = $191;
  $266 = $191;
 } else {
  $266 = $201;
 }
 $202 = $191 > $203;
 if ($202) {
  HEAPF32[$135>>2] = $191;
  $268 = $191;
 } else {
  $268 = $203;
 }
 $204 = +HEAPF32[$1>>2];
 $205 = +HEAPF32[$44>>2];
 $206 = +HEAPF32[$51>>2];
 $207 = +HEAPF64[$54>>3];
 $208 = $204;
 $209 = $208 * $207;
 $210 = +HEAPF64[$58>>3];
 $211 = $205;
 $212 = $211 * $210;
 $213 = $209 + $212;
 $214 = +HEAPF64[$63>>3];
 $215 = $206;
 $216 = $215 * $214;
 $217 = $213 + $216;
 $218 = +HEAPF64[$68>>3];
 $219 = $218 + $217;
 $220 = 1.0 / $219;
 $221 = +HEAPF64[$72>>3];
 $222 = $208 * $221;
 $223 = +HEAPF64[$75>>3];
 $224 = $211 * $223;
 $225 = $222 + $224;
 $226 = +HEAPF64[$79>>3];
 $227 = $215 * $226;
 $228 = $225 + $227;
 $229 = +HEAPF64[$83>>3];
 $230 = $229 + $228;
 $231 = $220 * $230;
 $232 = $231;
 $233 = +HEAPF64[$88>>3];
 $234 = $208 * $233;
 $235 = +HEAPF64[$91>>3];
 $236 = $211 * $235;
 $237 = $234 + $236;
 $238 = +HEAPF64[$95>>3];
 $239 = $215 * $238;
 $240 = $237 + $239;
 $241 = +HEAPF64[$99>>3];
 $242 = $241 + $240;
 $243 = $220 * $242;
 $244 = $243;
 $245 = +HEAPF64[$104>>3];
 $246 = $208 * $245;
 $247 = +HEAPF64[$107>>3];
 $248 = $211 * $247;
 $249 = $246 + $248;
 $250 = +HEAPF64[$111>>3];
 $251 = $215 * $250;
 $252 = $249 + $251;
 $253 = +HEAPF64[$115>>3];
 $254 = $253 + $252;
 $255 = $220 * $254;
 $256 = $255;
 $257 = $232 < $258;
 if ($257) {
  HEAPF32[$120>>2] = $232;
  $323 = $232;
 } else {
  $323 = $258;
 }
 $259 = $232 > $260;
 if ($259) {
  HEAPF32[$123>>2] = $232;
  $325 = $232;
 } else {
  $325 = $260;
 }
 $261 = $244 < $262;
 if ($261) {
  HEAPF32[$126>>2] = $244;
  $327 = $244;
 } else {
  $327 = $262;
 }
 $263 = $244 > $264;
 if ($263) {
  HEAPF32[$129>>2] = $244;
  $329 = $244;
 } else {
  $329 = $264;
 }
 $265 = $256 < $266;
 if ($265) {
  HEAPF32[$132>>2] = $256;
  $331 = $256;
 } else {
  $331 = $266;
 }
 $267 = $256 > $268;
 if ($267) {
  HEAPF32[$135>>2] = $256;
  $333 = $256;
 } else {
  $333 = $268;
 }
 $269 = +HEAPF32[$138>>2];
 $270 = +HEAPF32[$44>>2];
 $271 = +HEAPF32[$51>>2];
 $272 = +HEAPF64[$54>>3];
 $273 = $269;
 $274 = $273 * $272;
 $275 = +HEAPF64[$58>>3];
 $276 = $270;
 $277 = $276 * $275;
 $278 = $274 + $277;
 $279 = +HEAPF64[$63>>3];
 $280 = $271;
 $281 = $280 * $279;
 $282 = $278 + $281;
 $283 = +HEAPF64[$68>>3];
 $284 = $283 + $282;
 $285 = 1.0 / $284;
 $286 = +HEAPF64[$72>>3];
 $287 = $273 * $286;
 $288 = +HEAPF64[$75>>3];
 $289 = $276 * $288;
 $290 = $287 + $289;
 $291 = +HEAPF64[$79>>3];
 $292 = $280 * $291;
 $293 = $290 + $292;
 $294 = +HEAPF64[$83>>3];
 $295 = $294 + $293;
 $296 = $285 * $295;
 $297 = $296;
 $298 = +HEAPF64[$88>>3];
 $299 = $273 * $298;
 $300 = +HEAPF64[$91>>3];
 $301 = $276 * $300;
 $302 = $299 + $301;
 $303 = +HEAPF64[$95>>3];
 $304 = $280 * $303;
 $305 = $302 + $304;
 $306 = +HEAPF64[$99>>3];
 $307 = $306 + $305;
 $308 = $285 * $307;
 $309 = $308;
 $310 = +HEAPF64[$104>>3];
 $311 = $273 * $310;
 $312 = +HEAPF64[$107>>3];
 $313 = $276 * $312;
 $314 = $311 + $313;
 $315 = +HEAPF64[$111>>3];
 $316 = $280 * $315;
 $317 = $314 + $316;
 $318 = +HEAPF64[$115>>3];
 $319 = $318 + $317;
 $320 = $285 * $319;
 $321 = $320;
 $322 = $297 < $323;
 if ($322) {
  HEAPF32[$120>>2] = $297;
  $388 = $297;
 } else {
  $388 = $323;
 }
 $324 = $297 > $325;
 if ($324) {
  HEAPF32[$123>>2] = $297;
  $390 = $297;
 } else {
  $390 = $325;
 }
 $326 = $309 < $327;
 if ($326) {
  HEAPF32[$126>>2] = $309;
  $392 = $309;
 } else {
  $392 = $327;
 }
 $328 = $309 > $329;
 if ($328) {
  HEAPF32[$129>>2] = $309;
  $394 = $309;
 } else {
  $394 = $329;
 }
 $330 = $321 < $331;
 if ($330) {
  HEAPF32[$132>>2] = $321;
  $396 = $321;
 } else {
  $396 = $331;
 }
 $332 = $321 > $333;
 if ($332) {
  HEAPF32[$135>>2] = $321;
  $398 = $321;
 } else {
  $398 = $333;
 }
 $334 = +HEAPF32[$1>>2];
 $335 = +HEAPF32[$46>>2];
 $336 = +HEAPF32[$49>>2];
 $337 = +HEAPF64[$54>>3];
 $338 = $334;
 $339 = $338 * $337;
 $340 = +HEAPF64[$58>>3];
 $341 = $335;
 $342 = $341 * $340;
 $343 = $339 + $342;
 $344 = +HEAPF64[$63>>3];
 $345 = $336;
 $346 = $345 * $344;
 $347 = $343 + $346;
 $348 = +HEAPF64[$68>>3];
 $349 = $348 + $347;
 $350 = 1.0 / $349;
 $351 = +HEAPF64[$72>>3];
 $352 = $338 * $351;
 $353 = +HEAPF64[$75>>3];
 $354 = $341 * $353;
 $355 = $352 + $354;
 $356 = +HEAPF64[$79>>3];
 $357 = $345 * $356;
 $358 = $355 + $357;
 $359 = +HEAPF64[$83>>3];
 $360 = $359 + $358;
 $361 = $350 * $360;
 $362 = $361;
 $363 = +HEAPF64[$88>>3];
 $364 = $338 * $363;
 $365 = +HEAPF64[$91>>3];
 $366 = $341 * $365;
 $367 = $364 + $366;
 $368 = +HEAPF64[$95>>3];
 $369 = $345 * $368;
 $370 = $367 + $369;
 $371 = +HEAPF64[$99>>3];
 $372 = $371 + $370;
 $373 = $350 * $372;
 $374 = $373;
 $375 = +HEAPF64[$104>>3];
 $376 = $338 * $375;
 $377 = +HEAPF64[$107>>3];
 $378 = $341 * $377;
 $379 = $376 + $378;
 $380 = +HEAPF64[$111>>3];
 $381 = $345 * $380;
 $382 = $379 + $381;
 $383 = +HEAPF64[$115>>3];
 $384 = $383 + $382;
 $385 = $350 * $384;
 $386 = $385;
 $387 = $362 < $388;
 if ($387) {
  HEAPF32[$120>>2] = $362;
  $453 = $362;
 } else {
  $453 = $388;
 }
 $389 = $362 > $390;
 if ($389) {
  HEAPF32[$123>>2] = $362;
  $455 = $362;
 } else {
  $455 = $390;
 }
 $391 = $374 < $392;
 if ($391) {
  HEAPF32[$126>>2] = $374;
  $457 = $374;
 } else {
  $457 = $392;
 }
 $393 = $374 > $394;
 if ($393) {
  HEAPF32[$129>>2] = $374;
  $459 = $374;
 } else {
  $459 = $394;
 }
 $395 = $386 < $396;
 if ($395) {
  HEAPF32[$132>>2] = $386;
  $461 = $386;
 } else {
  $461 = $396;
 }
 $397 = $386 > $398;
 if ($397) {
  HEAPF32[$135>>2] = $386;
  $463 = $386;
 } else {
  $463 = $398;
 }
 $399 = +HEAPF32[$138>>2];
 $400 = +HEAPF32[$46>>2];
 $401 = +HEAPF32[$49>>2];
 $402 = +HEAPF64[$54>>3];
 $403 = $399;
 $404 = $403 * $402;
 $405 = +HEAPF64[$58>>3];
 $406 = $400;
 $407 = $406 * $405;
 $408 = $404 + $407;
 $409 = +HEAPF64[$63>>3];
 $410 = $401;
 $411 = $410 * $409;
 $412 = $408 + $411;
 $413 = +HEAPF64[$68>>3];
 $414 = $413 + $412;
 $415 = 1.0 / $414;
 $416 = +HEAPF64[$72>>3];
 $417 = $403 * $416;
 $418 = +HEAPF64[$75>>3];
 $419 = $406 * $418;
 $420 = $417 + $419;
 $421 = +HEAPF64[$79>>3];
 $422 = $410 * $421;
 $423 = $420 + $422;
 $424 = +HEAPF64[$83>>3];
 $425 = $424 + $423;
 $426 = $415 * $425;
 $427 = $426;
 $428 = +HEAPF64[$88>>3];
 $429 = $403 * $428;
 $430 = +HEAPF64[$91>>3];
 $431 = $406 * $430;
 $432 = $429 + $431;
 $433 = +HEAPF64[$95>>3];
 $434 = $410 * $433;
 $435 = $432 + $434;
 $436 = +HEAPF64[$99>>3];
 $437 = $436 + $435;
 $438 = $415 * $437;
 $439 = $438;
 $440 = +HEAPF64[$104>>3];
 $441 = $403 * $440;
 $442 = +HEAPF64[$107>>3];
 $443 = $406 * $442;
 $444 = $441 + $443;
 $445 = +HEAPF64[$111>>3];
 $446 = $410 * $445;
 $447 = $444 + $446;
 $448 = +HEAPF64[$115>>3];
 $449 = $448 + $447;
 $450 = $415 * $449;
 $451 = $450;
 $452 = $427 < $453;
 if ($452) {
  HEAPF32[$120>>2] = $427;
  $518 = $427;
 } else {
  $518 = $453;
 }
 $454 = $427 > $455;
 if ($454) {
  HEAPF32[$123>>2] = $427;
  $520 = $427;
 } else {
  $520 = $455;
 }
 $456 = $439 < $457;
 if ($456) {
  HEAPF32[$126>>2] = $439;
  $522 = $439;
 } else {
  $522 = $457;
 }
 $458 = $439 > $459;
 if ($458) {
  HEAPF32[$129>>2] = $439;
  $524 = $439;
 } else {
  $524 = $459;
 }
 $460 = $451 < $461;
 if ($460) {
  HEAPF32[$132>>2] = $451;
  $526 = $451;
 } else {
  $526 = $461;
 }
 $462 = $451 > $463;
 if ($462) {
  HEAPF32[$135>>2] = $451;
  $528 = $451;
 } else {
  $528 = $463;
 }
 $464 = +HEAPF32[$1>>2];
 $465 = +HEAPF32[$44>>2];
 $466 = +HEAPF32[$49>>2];
 $467 = +HEAPF64[$54>>3];
 $468 = $464;
 $469 = $468 * $467;
 $470 = +HEAPF64[$58>>3];
 $471 = $465;
 $472 = $471 * $470;
 $473 = $469 + $472;
 $474 = +HEAPF64[$63>>3];
 $475 = $466;
 $476 = $475 * $474;
 $477 = $473 + $476;
 $478 = +HEAPF64[$68>>3];
 $479 = $478 + $477;
 $480 = 1.0 / $479;
 $481 = +HEAPF64[$72>>3];
 $482 = $468 * $481;
 $483 = +HEAPF64[$75>>3];
 $484 = $471 * $483;
 $485 = $482 + $484;
 $486 = +HEAPF64[$79>>3];
 $487 = $475 * $486;
 $488 = $485 + $487;
 $489 = +HEAPF64[$83>>3];
 $490 = $489 + $488;
 $491 = $480 * $490;
 $492 = $491;
 $493 = +HEAPF64[$88>>3];
 $494 = $468 * $493;
 $495 = +HEAPF64[$91>>3];
 $496 = $471 * $495;
 $497 = $494 + $496;
 $498 = +HEAPF64[$95>>3];
 $499 = $475 * $498;
 $500 = $497 + $499;
 $501 = +HEAPF64[$99>>3];
 $502 = $501 + $500;
 $503 = $480 * $502;
 $504 = $503;
 $505 = +HEAPF64[$104>>3];
 $506 = $468 * $505;
 $507 = +HEAPF64[$107>>3];
 $508 = $471 * $507;
 $509 = $506 + $508;
 $510 = +HEAPF64[$111>>3];
 $511 = $475 * $510;
 $512 = $509 + $511;
 $513 = +HEAPF64[$115>>3];
 $514 = $513 + $512;
 $515 = $480 * $514;
 $516 = $515;
 $517 = $492 < $518;
 if ($517) {
  HEAPF32[$120>>2] = $492;
  $583 = $492;
 } else {
  $583 = $518;
 }
 $519 = $492 > $520;
 if ($519) {
  HEAPF32[$123>>2] = $492;
  $585 = $492;
 } else {
  $585 = $520;
 }
 $521 = $504 < $522;
 if ($521) {
  HEAPF32[$126>>2] = $504;
  $587 = $504;
 } else {
  $587 = $522;
 }
 $523 = $504 > $524;
 if ($523) {
  HEAPF32[$129>>2] = $504;
  $589 = $504;
 } else {
  $589 = $524;
 }
 $525 = $516 < $526;
 if ($525) {
  HEAPF32[$132>>2] = $516;
  $591 = $516;
 } else {
  $591 = $526;
 }
 $527 = $516 > $528;
 if ($527) {
  HEAPF32[$135>>2] = $516;
  $593 = $516;
 } else {
  $593 = $528;
 }
 $529 = +HEAPF32[$138>>2];
 $530 = +HEAPF32[$44>>2];
 $531 = +HEAPF32[$49>>2];
 $532 = +HEAPF64[$54>>3];
 $533 = $529;
 $534 = $533 * $532;
 $535 = +HEAPF64[$58>>3];
 $536 = $530;
 $537 = $536 * $535;
 $538 = $534 + $537;
 $539 = +HEAPF64[$63>>3];
 $540 = $531;
 $541 = $540 * $539;
 $542 = $538 + $541;
 $543 = +HEAPF64[$68>>3];
 $544 = $543 + $542;
 $545 = 1.0 / $544;
 $546 = +HEAPF64[$72>>3];
 $547 = $533 * $546;
 $548 = +HEAPF64[$75>>3];
 $549 = $536 * $548;
 $550 = $547 + $549;
 $551 = +HEAPF64[$79>>3];
 $552 = $540 * $551;
 $553 = $550 + $552;
 $554 = +HEAPF64[$83>>3];
 $555 = $554 + $553;
 $556 = $545 * $555;
 $557 = $556;
 $558 = +HEAPF64[$88>>3];
 $559 = $533 * $558;
 $560 = +HEAPF64[$91>>3];
 $561 = $536 * $560;
 $562 = $559 + $561;
 $563 = +HEAPF64[$95>>3];
 $564 = $540 * $563;
 $565 = $562 + $564;
 $566 = +HEAPF64[$99>>3];
 $567 = $566 + $565;
 $568 = $545 * $567;
 $569 = $568;
 $570 = +HEAPF64[$104>>3];
 $571 = $533 * $570;
 $572 = +HEAPF64[$107>>3];
 $573 = $536 * $572;
 $574 = $571 + $573;
 $575 = +HEAPF64[$111>>3];
 $576 = $540 * $575;
 $577 = $574 + $576;
 $578 = +HEAPF64[$115>>3];
 $579 = $578 + $577;
 $580 = $545 * $579;
 $581 = $580;
 $582 = $557 < $583;
 if ($582) {
  HEAPF32[$120>>2] = $557;
 }
 $584 = $557 > $585;
 if ($584) {
  HEAPF32[$123>>2] = $557;
 }
 $586 = $569 < $587;
 if ($586) {
  HEAPF32[$126>>2] = $569;
 }
 $588 = $569 > $589;
 if ($588) {
  HEAPF32[$129>>2] = $569;
 }
 $590 = $581 < $591;
 if ($590) {
  HEAPF32[$132>>2] = $581;
 }
 $592 = $581 > $593;
 if (!($592)) {
  return;
 }
 HEAPF32[$135>>2] = $581;
 return;
}
function __ZN3osg20ComputeBoundsVisitorC1ENS_11NodeVisitor13TraversalModeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 92|0);
 __ZN3osg10ReferencedC2Ev($2);
 HEAP32[$2>>2] = (63412);
 $3 = ((($0)) + 104|0);
 ;HEAP32[$3>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;
 $4 = ((($0)) + 116|0);
 HEAP32[$4>>2] = 2;
 $5 = ((($0)) + 120|0);
 HEAP32[$5>>2] = 0;
 __THREW__ = 0;
 invoke_viii(3283,($0|0),((58064)|0),($1|0));
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if (!($7)) {
  HEAP32[$0>>2] = (57576);
  HEAP32[$2>>2] = (57920);
  $8 = ((($0)) + 56|0);
  HEAP32[$8>>2] = 0;
  $9 = ((($0)) + 60|0);
  HEAP32[$9>>2] = 0;
  $10 = ((($0)) + 64|0);
  HEAP32[$10>>2] = 0;
  $11 = ((($0)) + 68|0);
  HEAPF32[$11>>2] = 3.4028234663852886E+38;
  $12 = ((($0)) + 72|0);
  HEAPF32[$12>>2] = 3.4028234663852886E+38;
  $13 = ((($0)) + 76|0);
  HEAPF32[$13>>2] = 3.4028234663852886E+38;
  $14 = ((($0)) + 80|0);
  HEAPF32[$14>>2] = -3.4028234663852886E+38;
  $15 = ((($0)) + 84|0);
  HEAPF32[$15>>2] = -3.4028234663852886E+38;
  $16 = ((($0)) + 88|0);
  HEAPF32[$16>>2] = -3.4028234663852886E+38;
  return;
 }
 $17 = ___cxa_find_matching_catch_2()|0;
 $18 = tempRet0;
 __THREW__ = 0;
 invoke_vi(388,($2|0));
 $19 = __THREW__; __THREW__ = 0;
 $20 = $19&1;
 if ($20) {
  $21 = ___cxa_find_matching_catch_3(0|0)|0;
  $22 = tempRet0;
  ___clang_call_terminate($21);
  // unreachable;
 } else {
  ___resumeException($17|0);
  // unreachable;
 }
}
function __ZN3osg11ContextDataD2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (58084);
 $1 = ((($0)) + 36|0);
 $2 = ((($0)) + 40|0);
 $3 = HEAP32[$2>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIPKSt9type_infoN3osg7ref_ptrINS5_10ReferencedEEEEENS_19__map_value_compareIS4_S9_NS_4lessIS4_EELb1EEENS_9allocatorIS9_EEE7destroyEPNS_11__tree_nodeIS9_PvEE($1,$3);
 $4 = ((($0)) + 32|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  HEAP32[$4>>2] = 0;
  __ZN3osg21GraphicsObjectManagerD2Ev($0);
  return;
 }
 $7 = ((($5)) + 8|0);
 $8 = HEAP32[$7>>2]|0;HEAP32[$7>>2] = (($8-1)|0);
 $9 = ($8|0)==(1);
 if (!($9)) {
  HEAP32[$4>>2] = 0;
  __ZN3osg21GraphicsObjectManagerD2Ev($0);
  return;
 }
 __THREW__ = 0;
 invoke_viii(3262,($5|0),1,1);
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if (!($11)) {
  HEAP32[$4>>2] = 0;
  __ZN3osg21GraphicsObjectManagerD2Ev($0);
  return;
 }
 $12 = ___cxa_find_matching_catch_2()|0;
 $13 = tempRet0;
 __THREW__ = 0;
 invoke_vi(1861,($0|0));
 $14 = __THREW__; __THREW__ = 0;
 $15 = $14&1;
 if ($15) {
  $16 = ___cxa_find_matching_catch_3(0|0)|0;
  $17 = tempRet0;
  ___clang_call_terminate($16);
  // unreachable;
 } else {
  ___resumeException($12|0);
  // unreachable;
 }
}
function __ZN3osg11ContextDataD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (58084);
 $1 = ((($0)) + 36|0);
 $2 = ((($0)) + 40|0);
 $3 = HEAP32[$2>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIPKSt9type_infoN3osg7ref_ptrINS5_10ReferencedEEEEENS_19__map_value_compareIS4_S9_NS_4lessIS4_EELb1EEENS_9allocatorIS9_EEE7destroyEPNS_11__tree_nodeIS9_PvEE($1,$3);
 $4 = ((($0)) + 32|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = ((($5)) + 8|0);
  $8 = HEAP32[$7>>2]|0;HEAP32[$7>>2] = (($8-1)|0);
  $9 = ($8|0)==(1);
  if ($9) {
   __THREW__ = 0;
   invoke_viii(3262,($5|0),1,1);
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if ($11) {
    $14 = ___cxa_find_matching_catch_2()|0;
    $15 = tempRet0;
    __THREW__ = 0;
    invoke_vi(1861,($0|0));
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     $18 = ___cxa_find_matching_catch_3(0|0)|0;
     $19 = tempRet0;
     ___clang_call_terminate($18);
     // unreachable;
    } else {
     $eh$lpad$body$index2Z2D = $15;$eh$lpad$body$indexZ2D = $14;
     __ZdlPv($0);
     ___resumeException($eh$lpad$body$indexZ2D|0);
     // unreachable;
    }
   }
  }
 }
 HEAP32[$4>>2] = 0;
 __THREW__ = 0;
 invoke_vi(1861,($0|0));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if (!($13)) {
  __ZdlPv($0);
  return;
 }
 $20 = ___cxa_find_matching_catch_2()|0;
 $21 = tempRet0;
 $eh$lpad$body$index2Z2D = $21;$eh$lpad$body$indexZ2D = $20;
 __ZdlPv($0);
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
}
function __ZN3osg11ContextData8newFrameEPNS_10FrameStampE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i$i$i = 0, $$sroa$06$0$be = 0, $$sroa$06$010 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 36|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 40|0);
 $5 = ($3|0)==($4|0);
 if ($5) {
  return;
 } else {
  $$sroa$06$010 = $3;
 }
 while(1) {
  $6 = ((($$sroa$06$010)) + 20|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)==(0|0);
  if (!($8)) {
   $9 = (___dynamic_cast($7,26488,24704,0)|0);
   $10 = ($9|0)==(0|0);
   if (!($10)) {
    $11 = HEAP32[$9>>2]|0;
    $12 = ((($11)) + 12|0);
    $13 = HEAP32[$12>>2]|0;
    FUNCTION_TABLE_vii[$13 & 8191]($9,$1);
   }
  }
  $14 = ((($$sroa$06$010)) + 4|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = ($15|0)==(0|0);
  if ($16) {
   $17 = ((($$sroa$06$010)) + 8|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = HEAP32[$18>>2]|0;
   $20 = ($19|0)==($$sroa$06$010|0);
   if ($20) {
    $$sroa$06$0$be = $18;
   } else {
    $25 = $17;
    while(1) {
     $24 = HEAP32[$25>>2]|0;
     $26 = ((($24)) + 8|0);
     $27 = HEAP32[$26>>2]|0;
     $28 = HEAP32[$27>>2]|0;
     $29 = ($28|0)==($24|0);
     if ($29) {
      $$sroa$06$0$be = $27;
      break;
     } else {
      $25 = $26;
     }
    }
   }
  } else {
   $$0$i$i$i$i = $15;
   while(1) {
    $22 = HEAP32[$$0$i$i$i$i>>2]|0;
    $23 = ($22|0)==(0|0);
    if ($23) {
     break;
    } else {
     $$0$i$i$i$i = $22;
    }
   }
   $$sroa$06$0$be = $$0$i$i$i$i;
  }
  $21 = ($$sroa$06$0$be|0)==($4|0);
  if ($21) {
   break;
  } else {
   $$sroa$06$010 = $$sroa$06$0$be;
  }
 }
 return;
}
function __ZN3osg11ContextData10resetStatsEv($0) {
 $0 = $0|0;
 var $$0$i$i$i$i = 0, $$sroa$05$0$be = 0, $$sroa$05$09 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 36|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 40|0);
 $4 = ($2|0)==($3|0);
 if ($4) {
  return;
 } else {
  $$sroa$05$09 = $2;
 }
 while(1) {
  $5 = ((($$sroa$05$09)) + 20|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==(0|0);
  if (!($7)) {
   $8 = (___dynamic_cast($6,26488,24704,0)|0);
   $9 = ($8|0)==(0|0);
   if (!($9)) {
    $10 = HEAP32[$8>>2]|0;
    $11 = ((($10)) + 16|0);
    $12 = HEAP32[$11>>2]|0;
    FUNCTION_TABLE_vi[$12 & 8191]($8);
   }
  }
  $13 = ((($$sroa$05$09)) + 4|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = ($14|0)==(0|0);
  if ($15) {
   $16 = ((($$sroa$05$09)) + 8|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = HEAP32[$17>>2]|0;
   $19 = ($18|0)==($$sroa$05$09|0);
   if ($19) {
    $$sroa$05$0$be = $17;
   } else {
    $24 = $16;
    while(1) {
     $23 = HEAP32[$24>>2]|0;
     $25 = ((($23)) + 8|0);
     $26 = HEAP32[$25>>2]|0;
     $27 = HEAP32[$26>>2]|0;
     $28 = ($27|0)==($23|0);
     if ($28) {
      $$sroa$05$0$be = $26;
      break;
     } else {
      $24 = $25;
     }
    }
   }
  } else {
   $$0$i$i$i$i = $14;
   while(1) {
    $21 = HEAP32[$$0$i$i$i$i>>2]|0;
    $22 = ($21|0)==(0|0);
    if ($22) {
     break;
    } else {
     $$0$i$i$i$i = $21;
    }
   }
   $$sroa$05$0$be = $$0$i$i$i$i;
  }
  $20 = ($$sroa$05$0$be|0)==($3|0);
  if ($20) {
   break;
  } else {
   $$sroa$05$09 = $$sroa$05$0$be;
  }
 }
 return;
}
function __ZN3osg11ContextData11reportStatsERNSt3__213basic_ostreamIcNS1_11char_traitsIcEEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i$i$i = 0, $$sroa$06$0$be = 0, $$sroa$06$010 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 36|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 40|0);
 $5 = ($3|0)==($4|0);
 if ($5) {
  return;
 } else {
  $$sroa$06$010 = $3;
 }
 while(1) {
  $6 = ((($$sroa$06$010)) + 20|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)==(0|0);
  if (!($8)) {
   $9 = (___dynamic_cast($7,26488,24704,0)|0);
   $10 = ($9|0)==(0|0);
   if (!($10)) {
    $11 = HEAP32[$9>>2]|0;
    $12 = ((($11)) + 20|0);
    $13 = HEAP32[$12>>2]|0;
    FUNCTION_TABLE_vii[$13 & 8191]($9,$1);
   }
  }
  $14 = ((($$sroa$06$010)) + 4|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = ($15|0)==(0|0);
  if ($16) {
   $17 = ((($$sroa$06$010)) + 8|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = HEAP32[$18>>2]|0;
   $20 = ($19|0)==($$sroa$06$010|0);
   if ($20) {
    $$sroa$06$0$be = $18;
   } else {
    $25 = $17;
    while(1) {
     $24 = HEAP32[$25>>2]|0;
     $26 = ((($24)) + 8|0);
     $27 = HEAP32[$26>>2]|0;
     $28 = HEAP32[$27>>2]|0;
     $29 = ($28|0)==($24|0);
     if ($29) {
      $$sroa$06$0$be = $27;
      break;
     } else {
      $25 = $26;
     }
    }
   }
  } else {
   $$0$i$i$i$i = $15;
   while(1) {
    $22 = HEAP32[$$0$i$i$i$i>>2]|0;
    $23 = ($22|0)==(0|0);
    if ($23) {
     break;
    } else {
     $$0$i$i$i$i = $22;
    }
   }
   $$sroa$06$0$be = $$0$i$i$i$i;
  }
  $21 = ($$sroa$06$0$be|0)==($4|0);
  if ($21) {
   break;
  } else {
   $$sroa$06$010 = $$sroa$06$0$be;
  }
 }
 return;
}
function __ZNK3osg11ContextData14recomputeStatsERNSt3__213basic_ostreamIcNS1_11char_traitsIcEEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i$i$i = 0, $$sroa$06$0$be = 0, $$sroa$06$010 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 36|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 40|0);
 $5 = ($3|0)==($4|0);
 if ($5) {
  return;
 } else {
  $$sroa$06$010 = $3;
 }
 while(1) {
  $6 = ((($$sroa$06$010)) + 20|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)==(0|0);
  if (!($8)) {
   $9 = (___dynamic_cast($7,26488,24704,0)|0);
   $10 = ($9|0)==(0|0);
   if (!($10)) {
    $11 = HEAP32[$9>>2]|0;
    $12 = ((($11)) + 24|0);
    $13 = HEAP32[$12>>2]|0;
    FUNCTION_TABLE_vii[$13 & 8191]($9,$1);
   }
  }
  $14 = ((($$sroa$06$010)) + 4|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = ($15|0)==(0|0);
  if ($16) {
   $17 = ((($$sroa$06$010)) + 8|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = HEAP32[$18>>2]|0;
   $20 = ($19|0)==($$sroa$06$010|0);
   if ($20) {
    $$sroa$06$0$be = $18;
   } else {
    $25 = $17;
    while(1) {
     $24 = HEAP32[$25>>2]|0;
     $26 = ((($24)) + 8|0);
     $27 = HEAP32[$26>>2]|0;
     $28 = HEAP32[$27>>2]|0;
     $29 = ($28|0)==($24|0);
     if ($29) {
      $$sroa$06$0$be = $27;
      break;
     } else {
      $25 = $26;
     }
    }
   }
  } else {
   $$0$i$i$i$i = $15;
   while(1) {
    $22 = HEAP32[$$0$i$i$i$i>>2]|0;
    $23 = ($22|0)==(0|0);
    if ($23) {
     break;
    } else {
     $$0$i$i$i$i = $22;
    }
   }
   $$sroa$06$0$be = $$0$i$i$i$i;
  }
  $21 = ($$sroa$06$0$be|0)==($4|0);
  if ($21) {
   break;
  } else {
   $$sroa$06$010 = $$sroa$06$0$be;
  }
 }
 return;
}
function __ZN3osg11ContextData21flushDeletedGLObjectsEdRd($0,$1,$2) {
 $0 = $0|0;
 $1 = +$1;
 $2 = $2|0;
 var $$0$i$i$i$i = 0, $$sroa$07$0$be = 0, $$sroa$07$011 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 36|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 40|0);
 $6 = ($4|0)==($5|0);
 if ($6) {
  return;
 } else {
  $$sroa$07$011 = $4;
 }
 while(1) {
  $7 = ((($$sroa$07$011)) + 20|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)==(0|0);
  if (!($9)) {
   $10 = (___dynamic_cast($8,26488,24704,0)|0);
   $11 = ($10|0)==(0|0);
   if (!($11)) {
    $12 = HEAP32[$10>>2]|0;
    $13 = ((($12)) + 28|0);
    $14 = HEAP32[$13>>2]|0;
    FUNCTION_TABLE_vidi[$14 & 4095]($10,$1,$2);
   }
  }
  $15 = ((($$sroa$07$011)) + 4|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($16|0)==(0|0);
  if ($17) {
   $18 = ((($$sroa$07$011)) + 8|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = HEAP32[$19>>2]|0;
   $21 = ($20|0)==($$sroa$07$011|0);
   if ($21) {
    $$sroa$07$0$be = $19;
   } else {
    $26 = $18;
    while(1) {
     $25 = HEAP32[$26>>2]|0;
     $27 = ((($25)) + 8|0);
     $28 = HEAP32[$27>>2]|0;
     $29 = HEAP32[$28>>2]|0;
     $30 = ($29|0)==($25|0);
     if ($30) {
      $$sroa$07$0$be = $28;
      break;
     } else {
      $26 = $27;
     }
    }
   }
  } else {
   $$0$i$i$i$i = $16;
   while(1) {
    $23 = HEAP32[$$0$i$i$i$i>>2]|0;
    $24 = ($23|0)==(0|0);
    if ($24) {
     break;
    } else {
     $$0$i$i$i$i = $23;
    }
   }
   $$sroa$07$0$be = $$0$i$i$i$i;
  }
  $22 = ($$sroa$07$0$be|0)==($5|0);
  if ($22) {
   break;
  } else {
   $$sroa$07$011 = $$sroa$07$0$be;
  }
 }
 return;
}
function __ZN3osg11ContextData24flushAllDeletedGLObjectsEv($0) {
 $0 = $0|0;
 var $$0$i$i$i$i = 0, $$sroa$05$0$be = 0, $$sroa$05$09 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 36|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 40|0);
 $4 = ($2|0)==($3|0);
 if ($4) {
  return;
 } else {
  $$sroa$05$09 = $2;
 }
 while(1) {
  $5 = ((($$sroa$05$09)) + 20|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==(0|0);
  if (!($7)) {
   $8 = (___dynamic_cast($6,26488,24704,0)|0);
   $9 = ($8|0)==(0|0);
   if (!($9)) {
    $10 = HEAP32[$8>>2]|0;
    $11 = ((($10)) + 32|0);
    $12 = HEAP32[$11>>2]|0;
    FUNCTION_TABLE_vi[$12 & 8191]($8);
   }
  }
  $13 = ((($$sroa$05$09)) + 4|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = ($14|0)==(0|0);
  if ($15) {
   $16 = ((($$sroa$05$09)) + 8|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = HEAP32[$17>>2]|0;
   $19 = ($18|0)==($$sroa$05$09|0);
   if ($19) {
    $$sroa$05$0$be = $17;
   } else {
    $24 = $16;
    while(1) {
     $23 = HEAP32[$24>>2]|0;
     $25 = ((($23)) + 8|0);
     $26 = HEAP32[$25>>2]|0;
     $27 = HEAP32[$26>>2]|0;
     $28 = ($27|0)==($23|0);
     if ($28) {
      $$sroa$05$0$be = $26;
      break;
     } else {
      $24 = $25;
     }
    }
   }
  } else {
   $$0$i$i$i$i = $14;
   while(1) {
    $21 = HEAP32[$$0$i$i$i$i>>2]|0;
    $22 = ($21|0)==(0|0);
    if ($22) {
     break;
    } else {
     $$0$i$i$i$i = $21;
    }
   }
   $$sroa$05$0$be = $$0$i$i$i$i;
  }
  $20 = ($$sroa$05$0$be|0)==($3|0);
  if ($20) {
   break;
  } else {
   $$sroa$05$09 = $$sroa$05$0$be;
  }
 }
 return;
}
function __ZN3osg11ContextData18deleteAllGLObjectsEv($0) {
 $0 = $0|0;
 var $$0$i$i$i$i = 0, $$sroa$05$0$be = 0, $$sroa$05$09 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 36|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 40|0);
 $4 = ($2|0)==($3|0);
 if ($4) {
  return;
 } else {
  $$sroa$05$09 = $2;
 }
 while(1) {
  $5 = ((($$sroa$05$09)) + 20|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==(0|0);
  if (!($7)) {
   $8 = (___dynamic_cast($6,26488,24704,0)|0);
   $9 = ($8|0)==(0|0);
   if (!($9)) {
    $10 = HEAP32[$8>>2]|0;
    $11 = ((($10)) + 36|0);
    $12 = HEAP32[$11>>2]|0;
    FUNCTION_TABLE_vi[$12 & 8191]($8);
   }
  }
  $13 = ((($$sroa$05$09)) + 4|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = ($14|0)==(0|0);
  if ($15) {
   $16 = ((($$sroa$05$09)) + 8|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = HEAP32[$17>>2]|0;
   $19 = ($18|0)==($$sroa$05$09|0);
   if ($19) {
    $$sroa$05$0$be = $17;
   } else {
    $24 = $16;
    while(1) {
     $23 = HEAP32[$24>>2]|0;
     $25 = ((($23)) + 8|0);
     $26 = HEAP32[$25>>2]|0;
     $27 = HEAP32[$26>>2]|0;
     $28 = ($27|0)==($23|0);
     if ($28) {
      $$sroa$05$0$be = $26;
      break;
     } else {
      $24 = $25;
     }
    }
   }
  } else {
   $$0$i$i$i$i = $14;
   while(1) {
    $21 = HEAP32[$$0$i$i$i$i>>2]|0;
    $22 = ($21|0)==(0|0);
    if ($22) {
     break;
    } else {
     $$0$i$i$i$i = $21;
    }
   }
   $$sroa$05$0$be = $$0$i$i$i$i;
  }
  $20 = ($$sroa$05$0$be|0)==($3|0);
  if ($20) {
   break;
  } else {
   $$sroa$05$09 = $$sroa$05$0$be;
  }
 }
 return;
}
function __ZN3osg11ContextData19discardAllGLObjectsEv($0) {
 $0 = $0|0;
 var $$0$i$i$i$i = 0, $$sroa$05$0$be = 0, $$sroa$05$09 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 36|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 40|0);
 $4 = ($2|0)==($3|0);
 if ($4) {
  return;
 } else {
  $$sroa$05$09 = $2;
 }
 while(1) {
  $5 = ((($$sroa$05$09)) + 20|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==(0|0);
  if (!($7)) {
   $8 = (___dynamic_cast($6,26488,24704,0)|0);
   $9 = ($8|0)==(0|0);
   if (!($9)) {
    $10 = HEAP32[$8>>2]|0;
    $11 = ((($10)) + 40|0);
    $12 = HEAP32[$11>>2]|0;
    FUNCTION_TABLE_vi[$12 & 8191]($8);
   }
  }
  $13 = ((($$sroa$05$09)) + 4|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = ($14|0)==(0|0);
  if ($15) {
   $16 = ((($$sroa$05$09)) + 8|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = HEAP32[$17>>2]|0;
   $19 = ($18|0)==($$sroa$05$09|0);
   if ($19) {
    $$sroa$05$0$be = $17;
   } else {
    $24 = $16;
    while(1) {
     $23 = HEAP32[$24>>2]|0;
     $25 = ((($23)) + 8|0);
     $26 = HEAP32[$25>>2]|0;
     $27 = HEAP32[$26>>2]|0;
     $28 = ($27|0)==($23|0);
     if ($28) {
      $$sroa$05$0$be = $26;
      break;
     } else {
      $24 = $25;
     }
    }
   }
  } else {
   $$0$i$i$i$i = $14;
   while(1) {
    $21 = HEAP32[$$0$i$i$i$i>>2]|0;
    $22 = ($21|0)==(0|0);
    if ($22) {
     break;
    } else {
     $$0$i$i$i$i = $21;
    }
   }
   $$sroa$05$0$be = $$0$i$i$i$i;
  }
  $20 = ($$sroa$05$0$be|0)==($3|0);
  if ($20) {
   break;
  } else {
   $$sroa$05$09 = $$sroa$05$0$be;
  }
 }
 return;
}
function __ZNSt3__26__treeINS_12__value_typeIPKSt9type_infoN3osg7ref_ptrINS5_10ReferencedEEEEENS_19__map_value_compareIS4_S9_NS_4lessIS4_EELb1EEENS_9allocatorIS9_EEE7destroyEPNS_11__tree_nodeIS9_PvEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 }
 $3 = HEAP32[$1>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIPKSt9type_infoN3osg7ref_ptrINS5_10ReferencedEEEEENS_19__map_value_compareIS4_S9_NS_4lessIS4_EELb1EEENS_9allocatorIS9_EEE7destroyEPNS_11__tree_nodeIS9_PvEE($0,$3);
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIPKSt9type_infoN3osg7ref_ptrINS5_10ReferencedEEEEENS_19__map_value_compareIS4_S9_NS_4lessIS4_EELb1EEENS_9allocatorIS9_EEE7destroyEPNS_11__tree_nodeIS9_PvEE($0,$5);
 $6 = ((($1)) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = ((($7)) + 8|0);
  $10 = HEAP32[$9>>2]|0;HEAP32[$9>>2] = (($10-1)|0);
  $11 = ($10|0)==(1);
  if ($11) {
   __THREW__ = 0;
   invoke_viii(3262,($7|0),1,1);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if ($13) {
    $14 = ___cxa_find_matching_catch_2()|0;
    $15 = tempRet0;
    ___cxa_call_unexpected(($14|0));
    // unreachable;
   }
  }
 }
 __ZdlPv($1);
 return;
}
function __GLOBAL__sub_I_ContextData_cpp() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF32[52017] = 1.0;
 HEAPF32[(208072)>>2] = 0.0;
 HEAPF32[(208076)>>2] = 0.0;
 HEAPF32[52020] = 0.0;
 HEAPF32[(208084)>>2] = 1.0;
 HEAPF32[(208088)>>2] = 0.0;
 HEAPF32[52023] = 0.0;
 HEAPF32[(208096)>>2] = 0.0;
 HEAPF32[(208100)>>2] = 1.0;
 HEAP32[(208108)>>2] = 0;
 HEAP32[(208112)>>2] = 0;
 HEAP32[52026] = (208108);
 (___cxa_atexit((3731|0),(208104|0),(___dso_handle|0))|0);
 __ZN11OpenThreads5MutexC2ENS0_9MutexTypeE(208116,1);
 HEAP32[52029] = (41932);
 (___cxa_atexit((707|0),(208116|0),(___dso_handle|0))|0);
 HEAP32[52032] = 0;
 HEAP32[(208132)>>2] = 0;
 HEAP32[(208136)>>2] = 0;
 (___cxa_atexit((3732|0),(208128|0),(___dso_handle|0))|0);
 return;
}
function __ZNSt3__23mapIjN3osg7ref_ptrINS1_11ContextDataEEENS_4lessIjEENS_9allocatorINS_4pairIKjS4_EEEEED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIjN3osg7ref_ptrINS2_11ContextDataEEEEENS_19__map_value_compareIjS6_NS_4lessIjEELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($0,$2);
 return;
}
function __ZNSt3__213__vector_baseIPN3osg15GraphicsContextENS_9allocatorIS3_EEED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i = 0, $scevgep5$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 $3 = $1;
 if ($2) {
  return;
 }
 $4 = ((($0)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==($1|0);
 if (!($6)) {
  $scevgep$i$i = ((($5)) + -4|0);
  $7 = $scevgep$i$i;
  $8 = (($7) - ($3))|0;
  $9 = $8 >>> 2;
  $10 = $9 ^ -1;
  $scevgep5$i$i = (($5) + ($10<<2)|0);
  HEAP32[$4>>2] = $scevgep5$i$i;
 }
 __ZdlPv($1);
 return;
}
function __ZNSt3__26__treeINS_12__value_typeIjN3osg7ref_ptrINS2_11ContextDataEEEEENS_19__map_value_compareIjS6_NS_4lessIjEELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 }
 $3 = HEAP32[$1>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIjN3osg7ref_ptrINS2_11ContextDataEEEEENS_19__map_value_compareIjS6_NS_4lessIjEELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($0,$3);
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIjN3osg7ref_ptrINS2_11ContextDataEEEEENS_19__map_value_compareIjS6_NS_4lessIjEELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($0,$5);
 $6 = ((($1)) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = ((($7)) + 8|0);
  $10 = HEAP32[$9>>2]|0;HEAP32[$9>>2] = (($10-1)|0);
  $11 = ($10|0)==(1);
  if ($11) {
   __THREW__ = 0;
   invoke_viii(3262,($7|0),1,1);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if ($13) {
    $14 = ___cxa_find_matching_catch_2()|0;
    $15 = tempRet0;
    ___cxa_call_unexpected(($14|0));
    // unreachable;
   }
  }
 }
 __ZdlPv($1);
 return;
}
function __ZN3osg14getContextDataEj($0) {
 $0 = $0|0;
 var $$0$ph$lcssa$i$i$i = 0, $$0$ph13$i$i$i = 0, $$07$ph12$i$i$i = 0, $$0710$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[52029]|0;
 $2 = ((($1)) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 (FUNCTION_TABLE_ii[$3 & 8191](208116)|0);
 $4 = HEAP32[(208108)>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  $23 = 0;
 } else {
  $$0$ph13$i$i$i = (208108);$$07$ph12$i$i$i = $4;
  L2: while(1) {
   $$0710$i$i$i = $$07$ph12$i$i$i;
   while(1) {
    $6 = ((($$0710$i$i$i)) + 16|0);
    $7 = HEAP32[$6>>2]|0;
    $8 = ($7>>>0)<($0>>>0);
    if (!($8)) {
     break;
    }
    $11 = ((($$0710$i$i$i)) + 4|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ($12|0)==(0|0);
    if ($13) {
     $$0$ph$lcssa$i$i$i = $$0$ph13$i$i$i;
     break L2;
    } else {
     $$0710$i$i$i = $12;
    }
   }
   $9 = HEAP32[$$0710$i$i$i>>2]|0;
   $10 = ($9|0)==(0|0);
   if ($10) {
    $$0$ph$lcssa$i$i$i = $$0710$i$i$i;
    break;
   } else {
    $$0$ph13$i$i$i = $$0710$i$i$i;$$07$ph12$i$i$i = $9;
   }
  }
  $14 = ($$0$ph$lcssa$i$i$i|0)==((208108)|0);
  if ($14) {
   $23 = 0;
  } else {
   $15 = ((($$0$ph$lcssa$i$i$i)) + 16|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ($16>>>0)>($0>>>0);
   if ($17) {
    $23 = 0;
   } else {
    $18 = ((($$0$ph$lcssa$i$i$i)) + 20|0);
    $19 = HEAP32[$18>>2]|0;
    $23 = $19;
   }
  }
 }
 $20 = HEAP32[52029]|0;
 $21 = ((($20)) + 12|0);
 $22 = HEAP32[$21>>2]|0;
 (FUNCTION_TABLE_ii[$22 & 8191](208116)|0);
 return ($23|0);
}
function __ZN3osg22getOrCreateContextDataEj($0) {
 $0 = $0|0;
 var $$0$i$i = 0, $$0$ph$i$i = 0, $$014$i = 0, $$024$i$i = 0, $$025$i$i = 0, $$025$i53$i = 0, $$037$i = 0, $$03752$i = 0, $$in$i$i = 0, $$pre$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, dest = 0, label = 0;
 var sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $2 = HEAP32[(208108)>>2]|0;
 $3 = ($2|0)==(0|0);
 do {
  if ($3) {
   $$025$i$i = (208108);$$037$i = (208108);$13 = $2;
   label = 10;
  } else {
   $$0$i$i = (208108);$$024$i$i = $2;$66 = $2;
   while(1) {
    $4 = ((($$024$i$i)) + 16|0);
    $5 = HEAP32[$4>>2]|0;
    $6 = ($5>>>0)>($0>>>0);
    if ($6) {
     $7 = HEAP32[$$024$i$i>>2]|0;
     $8 = ($7|0)==(0|0);
     if ($8) {
      label = 5;
      break;
     } else {
      $$0$ph$i$i = $$024$i$i;$$in$i$i = $7;
     }
    } else {
     $9 = ($5>>>0)<($0>>>0);
     if (!($9)) {
      label = 9;
      break;
     }
     $10 = ((($$024$i$i)) + 4|0);
     $11 = HEAP32[$10>>2]|0;
     $12 = ($11|0)==(0|0);
     if ($12) {
      label = 8;
      break;
     } else {
      $$0$ph$i$i = $10;$$in$i$i = $11;
     }
    }
    $$0$i$i = $$0$ph$i$i;$$024$i$i = $$in$i$i;$66 = $$in$i$i;
   }
   if ((label|0) == 5) {
    $$025$i53$i = $$024$i$i;$$03752$i = $$024$i$i;
    label = 11;
    break;
   }
   else if ((label|0) == 8) {
    $$025$i53$i = $10;$$03752$i = $$024$i$i;
    label = 11;
    break;
   }
   else if ((label|0) == 9) {
    $$025$i$i = $$0$i$i;$$037$i = $$024$i$i;$13 = $66;
    label = 10;
    break;
   }
  }
 } while(0);
 if ((label|0) == 10) {
  $14 = ($13|0)==(0|0);
  if ($14) {
   $$025$i53$i = $$025$i$i;$$03752$i = $$037$i;
   label = 11;
  } else {
   $$014$i = $13;
  }
 }
 if ((label|0) == 11) {
  $15 = (__Znwj(24)|0);
  $16 = ((($15)) + 16|0);
  HEAP32[$16>>2] = $0;
  $17 = ((($15)) + 20|0);
  HEAP32[$17>>2] = 0;
  HEAP32[$15>>2] = 0;
  $18 = ((($15)) + 4|0);
  HEAP32[$18>>2] = 0;
  $19 = ((($15)) + 8|0);
  HEAP32[$19>>2] = $$03752$i;
  HEAP32[$$025$i53$i>>2] = $15;
  $20 = HEAP32[52026]|0;
  $21 = HEAP32[$20>>2]|0;
  $22 = ($21|0)==(0|0);
  if ($22) {
   $25 = $15;
  } else {
   $23 = $21;
   HEAP32[52026] = $23;
   $$pre$i$i = HEAP32[$$025$i53$i>>2]|0;
   $25 = $$pre$i$i;
  }
  $24 = HEAP32[(208108)>>2]|0;
  __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($24,$25);
  $26 = HEAP32[(208112)>>2]|0;
  $27 = (($26) + 1)|0;
  HEAP32[(208112)>>2] = $27;
  $$014$i = $15;
 }
 $28 = ((($$014$i)) + 20|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ($29|0)==(0|0);
 if (!($30)) {
  $65 = HEAP32[$28>>2]|0;
  STACKTOP = sp;return ($65|0);
 }
 $31 = (__Znwj(48)|0);
 __THREW__ = 0;
 $32 = (invoke_ii(3276,16)|0);
 $33 = __THREW__; __THREW__ = 0;
 $34 = $33&1;
 if ($34) {
  $63 = ___cxa_find_matching_catch_2()|0;
  $64 = tempRet0;
  $eh$lpad$body$index2Z2D = $64;$eh$lpad$body$indexZ2D = $63;
  __ZdlPv($31);
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 HEAP32[$1>>2] = $32;
 $35 = ((($1)) + 8|0);
 HEAP32[$35>>2] = -2147483632;
 $36 = ((($1)) + 4|0);
 HEAP32[$36>>2] = 11;
 dest=$32; src=120560; stop=dest+11|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $37 = ((($32)) + 11|0);
 HEAP8[$37>>0] = 0;
 __THREW__ = 0;
 invoke_viii(3719,($31|0),($1|0),($0|0));
 $38 = __THREW__; __THREW__ = 0;
 $39 = $38&1;
 if ($39) {
  $44 = ___cxa_find_matching_catch_2()|0;
  $45 = tempRet0;
  $46 = ((($1)) + 11|0);
  $47 = HEAP8[$46>>0]|0;
  $48 = ($47<<24>>24)<(0);
  if ($48) {
   $49 = HEAP32[$1>>2]|0;
   __ZdlPv($49);
  }
  $eh$lpad$body$index2Z2D = $45;$eh$lpad$body$indexZ2D = $44;
  __ZdlPv($31);
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 $40 = ((($1)) + 11|0);
 $41 = HEAP8[$40>>0]|0;
 $42 = ($41<<24>>24)<(0);
 if ($42) {
  $43 = HEAP32[$1>>2]|0;
  __ZdlPv($43);
 }
 HEAP32[$31>>2] = (58084);
 $50 = ((($31)) + 28|0);
 HEAP32[$50>>2] = 0;
 $51 = ((($31)) + 32|0);
 HEAP32[$51>>2] = 0;
 $52 = ((($31)) + 40|0);
 HEAP32[$52>>2] = 0;
 $53 = ((($31)) + 44|0);
 HEAP32[$53>>2] = 0;
 $54 = ((($31)) + 36|0);
 HEAP32[$54>>2] = $52;
 $55 = HEAP32[$28>>2]|0;
 $56 = ($55|0)==($31|0);
 if ($56) {
  $65 = HEAP32[$28>>2]|0;
  STACKTOP = sp;return ($65|0);
 }
 HEAP32[$28>>2] = $31;
 $57 = ((($31)) + 8|0);
 $58 = HEAP32[$57>>2]|0;HEAP32[$57>>2] = (($58+1)|0);
 $59 = ($55|0)==(0|0);
 if ($59) {
  $65 = HEAP32[$28>>2]|0;
  STACKTOP = sp;return ($65|0);
 }
 $60 = ((($55)) + 8|0);
 $61 = HEAP32[$60>>2]|0;HEAP32[$60>>2] = (($61-1)|0);
 $62 = ($61|0)==(1);
 if (!($62)) {
  $65 = HEAP32[$28>>2]|0;
  STACKTOP = sp;return ($65|0);
 }
 __ZNK3osg10Referenced24signalObserversAndDeleteEbb($55,1,1);
 $65 = HEAP32[$28>>2]|0;
 STACKTOP = sp;return ($65|0);
}
function __ZN3osg11ContextData18createNewContextIDEv() {
 var $$0$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i42 = 0, $$0$ph$i$i = 0, $$0$ph$i$i39 = 0, $$014$i = 0, $$014$i51 = 0, $$024$i$i = 0, $$024$i$i41 = 0, $$025$i$i = 0, $$025$i$i44 = 0, $$025$i53$i = 0, $$025$i53$i46 = 0, $$037$i = 0, $$037$i43 = 0, $$03752$i = 0, $$03752$i47 = 0, $$18 = 0, $$2 = 0, $$26 = 0;
 var $$in$i$i = 0, $$in$i$i38 = 0, $$pre$i$i = 0, $$pre$i$i49 = 0, $$sroa$082$0$be = 0, $$sroa$082$0118 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0;
 var $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0;
 var $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0;
 var $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0;
 var $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0;
 var $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0;
 var $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0;
 var $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0;
 var $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0;
 var $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $eh$lpad$body$index13Z2D = 0, $eh$lpad$body$indexZ2D = 0, $eh$lpad$body15$index7Z2D = 0, $eh$lpad$body15$indexZ2D = 0, $eh$lpad$body28$index2Z2D = 0, $eh$lpad$body28$indexZ2D = 0, $eh$lpad$body32$index19Z2D = 0, $eh$lpad$body32$indexZ2D = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $0 = sp + 32|0;
 $1 = sp + 20|0;
 $2 = sp + 16|0;
 $3 = sp + 4|0;
 $4 = sp;
 $5 = HEAP32[52029]|0;
 $6 = ((($5)) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 (FUNCTION_TABLE_ii[$7 & 8191](208116)|0);
 $8 = HEAP32[52026]|0;
 $9 = ($8|0)==((208108)|0);
 L1: do {
  if ($9) {
   label = 41;
  } else {
   $$sroa$082$0118 = $8;
   while(1) {
    $10 = ((($$sroa$082$0118)) + 20|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)==(0|0);
    if ($12) {
     break;
    }
    $13 = ((($11)) + 28|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ($14|0)==(0);
    if ($15) {
     break;
    }
    $100 = ((($$sroa$082$0118)) + 4|0);
    $101 = HEAP32[$100>>2]|0;
    $102 = ($101|0)==(0|0);
    if ($102) {
     $103 = ((($$sroa$082$0118)) + 8|0);
     $104 = HEAP32[$103>>2]|0;
     $105 = HEAP32[$104>>2]|0;
     $106 = ($105|0)==($$sroa$082$0118|0);
     if ($106) {
      $$sroa$082$0$be = $104;
     } else {
      $111 = $103;
      while(1) {
       $110 = HEAP32[$111>>2]|0;
       $112 = ((($110)) + 8|0);
       $113 = HEAP32[$112>>2]|0;
       $114 = HEAP32[$113>>2]|0;
       $115 = ($114|0)==($110|0);
       if ($115) {
        $$sroa$082$0$be = $113;
        break;
       } else {
        $111 = $112;
       }
      }
     }
    } else {
     $$0$i$i$i$i = $101;
     while(1) {
      $108 = HEAP32[$$0$i$i$i$i>>2]|0;
      $109 = ($108|0)==(0|0);
      if ($109) {
       break;
      } else {
       $$0$i$i$i$i = $108;
      }
     }
     $$sroa$082$0$be = $$0$i$i$i$i;
    }
    $107 = ($$sroa$082$0$be|0)==((208108)|0);
    if ($107) {
     label = 41;
     break L1;
    } else {
     $$sroa$082$0118 = $$sroa$082$0$be;
    }
   }
   __THREW__ = 0;
   $16 = (invoke_ii(3276,48)|0);
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   L15: do {
    if ($18) {
     label = 30;
    } else {
     $19 = ((($$sroa$082$0118)) + 16|0);
     $20 = HEAP32[$19>>2]|0;
     __THREW__ = 0;
     $21 = (invoke_ii(3276,16)|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     do {
      if ($23) {
       $98 = ___cxa_find_matching_catch_2()|0;
       $99 = tempRet0;
       $eh$lpad$body15$index7Z2D = $99;$eh$lpad$body15$indexZ2D = $98;
      } else {
       HEAP32[$3>>2] = $21;
       $24 = ((($3)) + 8|0);
       HEAP32[$24>>2] = -2147483632;
       $25 = ((($3)) + 4|0);
       HEAP32[$25>>2] = 11;
       dest=$21; src=120560; stop=dest+11|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
       $26 = ((($21)) + 11|0);
       HEAP8[$26>>0] = 0;
       __THREW__ = 0;
       invoke_viii(3719,($16|0),($3|0),($20|0));
       $27 = __THREW__; __THREW__ = 0;
       $28 = $27&1;
       if ($28) {
        $33 = ___cxa_find_matching_catch_2()|0;
        $34 = tempRet0;
        $35 = ((($3)) + 11|0);
        $36 = HEAP8[$35>>0]|0;
        $37 = ($36<<24>>24)<(0);
        if ($37) {
         $38 = HEAP32[$3>>2]|0;
         __ZdlPv($38);
        }
        $eh$lpad$body15$index7Z2D = $34;$eh$lpad$body15$indexZ2D = $33;
        break;
       }
       $29 = ((($3)) + 11|0);
       $30 = HEAP8[$29>>0]|0;
       $31 = ($30<<24>>24)<(0);
       if ($31) {
        $32 = HEAP32[$3>>2]|0;
        __ZdlPv($32);
       }
       HEAP32[$16>>2] = (58084);
       $39 = ((($16)) + 28|0);
       HEAP32[$39>>2] = 0;
       $40 = ((($16)) + 32|0);
       HEAP32[$40>>2] = 0;
       $41 = ((($16)) + 40|0);
       HEAP32[$41>>2] = 0;
       $42 = ((($16)) + 44|0);
       HEAP32[$42>>2] = 0;
       $43 = ((($16)) + 36|0);
       HEAP32[$43>>2] = $41;
       $44 = HEAP32[$10>>2]|0;
       $45 = ($44|0)==($16|0);
       if (!($45)) {
        HEAP32[$10>>2] = $16;
        $46 = ((($16)) + 8|0);
        $47 = HEAP32[$46>>2]|0;HEAP32[$46>>2] = (($47+1)|0);
        $48 = ($44|0)==(0|0);
        if (!($48)) {
         $49 = ((($44)) + 8|0);
         $50 = HEAP32[$49>>2]|0;HEAP32[$49>>2] = (($50-1)|0);
         $51 = ($50|0)==(1);
         if ($51) {
          __THREW__ = 0;
          invoke_viii(3262,($44|0),1,1);
          $52 = __THREW__; __THREW__ = 0;
          $53 = $52&1;
          if ($53) {
           label = 30;
           break L15;
          }
         }
        }
       }
       $54 = HEAP32[$10>>2]|0;
       $55 = ((($54)) + 28|0);
       HEAP32[$55>>2] = 1;
       __THREW__ = 0;
       $56 = (invoke_ii(3265,4)|0);
       $57 = __THREW__; __THREW__ = 0;
       $58 = $57&1;
       if ($58) {
        label = 30;
        break L15;
       }
       do {
        if ($56) {
         __THREW__ = 0;
         $59 = (invoke_ii(3266,4)|0);
         $60 = __THREW__; __THREW__ = 0;
         $61 = $60&1;
         if ($61) {
          label = 30;
          break L15;
         }
         __THREW__ = 0;
         $62 = (invoke_iiii(3267,($59|0),(120572|0),54)|0);
         $63 = __THREW__; __THREW__ = 0;
         $64 = $63&1;
         if ($64) {
          label = 30;
          break L15;
         }
         $65 = HEAP32[$19>>2]|0;
         __THREW__ = 0;
         $66 = (invoke_iii(3417,($62|0),($65|0))|0);
         $67 = __THREW__; __THREW__ = 0;
         $68 = $67&1;
         if ($68) {
          label = 30;
          break L15;
         }
         $69 = HEAP32[$66>>2]|0;
         $70 = ((($69)) + -12|0);
         $71 = HEAP32[$70>>2]|0;
         $72 = (($66) + ($71)|0);
         __THREW__ = 0;
         invoke_vii(3257,($2|0),($72|0));
         $73 = __THREW__; __THREW__ = 0;
         $74 = $73&1;
         if ($74) {
          label = 30;
          break L15;
         }
         __THREW__ = 0;
         $75 = (invoke_iii(3255,($2|0),(215188|0))|0);
         $76 = __THREW__; __THREW__ = 0;
         $77 = $76&1;
         if (!($77)) {
          $78 = HEAP32[$75>>2]|0;
          $79 = ((($78)) + 28|0);
          $80 = HEAP32[$79>>2]|0;
          __THREW__ = 0;
          $81 = (invoke_iii($80|0,($75|0),10)|0);
          $82 = __THREW__; __THREW__ = 0;
          $83 = $82&1;
          if (!($83)) {
           __THREW__ = 0;
           invoke_vi(3263,($2|0));
           $84 = __THREW__; __THREW__ = 0;
           $85 = $84&1;
           if ($85) {
            label = 30;
            break L15;
           }
           __THREW__ = 0;
           (invoke_iii(3268,($66|0),($81|0))|0);
           $92 = __THREW__; __THREW__ = 0;
           $93 = $92&1;
           if ($93) {
            label = 30;
            break L15;
           }
           __THREW__ = 0;
           (invoke_ii(3269,($66|0))|0);
           $94 = __THREW__; __THREW__ = 0;
           $95 = $94&1;
           if ($95) {
            label = 30;
            break L15;
           } else {
            break;
           }
          }
         }
         $86 = ___cxa_find_matching_catch_2()|0;
         $87 = tempRet0;
         __THREW__ = 0;
         invoke_vi(3263,($2|0));
         $88 = __THREW__; __THREW__ = 0;
         $89 = $88&1;
         if ($89) {
          $90 = ___cxa_find_matching_catch_3(0|0)|0;
          $91 = tempRet0;
          ___clang_call_terminate($90);
          // unreachable;
         } else {
          $eh$lpad$body28$index2Z2D = $87;$eh$lpad$body28$indexZ2D = $86;
          break L15;
         }
        }
       } while(0);
       $116 = HEAP32[$19>>2]|0;
       $$18 = $116;
       $304 = HEAP32[52029]|0;
       $305 = ((($304)) + 12|0);
       $306 = HEAP32[$305>>2]|0;
       (FUNCTION_TABLE_ii[$306 & 8191](208116)|0);
       STACKTOP = sp;return ($$18|0);
      }
     } while(0);
     __ZdlPv($16);
     $$2 = $eh$lpad$body15$index7Z2D;$$26 = $eh$lpad$body15$indexZ2D;
     break L1;
    }
   } while(0);
   if ((label|0) == 30) {
    $96 = ___cxa_find_matching_catch_2()|0;
    $97 = tempRet0;
    $eh$lpad$body28$index2Z2D = $97;$eh$lpad$body28$indexZ2D = $96;
   }
   $$2 = $eh$lpad$body28$index2Z2D;$$26 = $eh$lpad$body28$indexZ2D;
  }
 } while(0);
 L56: do {
  if ((label|0) == 41) {
   $117 = HEAP32[(208112)>>2]|0;
   __THREW__ = 0;
   $118 = (invoke_ii(3276,48)|0);
   $119 = __THREW__; __THREW__ = 0;
   $120 = $119&1;
   L58: do {
    if ($120) {
     label = 95;
    } else {
     __THREW__ = 0;
     $121 = (invoke_ii(3276,16)|0);
     $122 = __THREW__; __THREW__ = 0;
     $123 = $122&1;
     do {
      if ($123) {
       $255 = ___cxa_find_matching_catch_2()|0;
       $256 = tempRet0;
       $eh$lpad$body32$index19Z2D = $256;$eh$lpad$body32$indexZ2D = $255;
      } else {
       HEAP32[$1>>2] = $121;
       $124 = ((($1)) + 8|0);
       HEAP32[$124>>2] = -2147483632;
       $125 = ((($1)) + 4|0);
       HEAP32[$125>>2] = 11;
       dest=$121; src=120560; stop=dest+11|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
       $126 = ((($121)) + 11|0);
       HEAP8[$126>>0] = 0;
       __THREW__ = 0;
       invoke_viii(3719,($118|0),($1|0),($117|0));
       $127 = __THREW__; __THREW__ = 0;
       $128 = $127&1;
       if ($128) {
        $133 = ___cxa_find_matching_catch_2()|0;
        $134 = tempRet0;
        $135 = ((($1)) + 11|0);
        $136 = HEAP8[$135>>0]|0;
        $137 = ($136<<24>>24)<(0);
        if ($137) {
         $138 = HEAP32[$1>>2]|0;
         __ZdlPv($138);
        }
        $eh$lpad$body32$index19Z2D = $134;$eh$lpad$body32$indexZ2D = $133;
        break;
       }
       $129 = ((($1)) + 11|0);
       $130 = HEAP8[$129>>0]|0;
       $131 = ($130<<24>>24)<(0);
       if ($131) {
        $132 = HEAP32[$1>>2]|0;
        __ZdlPv($132);
       }
       HEAP32[$118>>2] = (58084);
       $139 = ((($118)) + 28|0);
       HEAP32[$139>>2] = 0;
       $140 = ((($118)) + 32|0);
       HEAP32[$140>>2] = 0;
       $141 = ((($118)) + 40|0);
       HEAP32[$141>>2] = 0;
       $142 = ((($118)) + 44|0);
       HEAP32[$142>>2] = 0;
       $143 = ((($118)) + 36|0);
       HEAP32[$143>>2] = $141;
       $144 = HEAP32[(208108)>>2]|0;
       $145 = ($144|0)==(0|0);
       do {
        if ($145) {
         $$025$i$i = (208108);$$037$i = (208108);$155 = $144;
         label = 58;
        } else {
         $$0$i$i = (208108);$$024$i$i = $144;$314 = $144;
         while(1) {
          $146 = ((($$024$i$i)) + 16|0);
          $147 = HEAP32[$146>>2]|0;
          $148 = ($117>>>0)<($147>>>0);
          if ($148) {
           $149 = HEAP32[$$024$i$i>>2]|0;
           $150 = ($149|0)==(0|0);
           if ($150) {
            label = 53;
            break;
           } else {
            $$0$ph$i$i = $$024$i$i;$$in$i$i = $149;
           }
          } else {
           $151 = ($147>>>0)<($117>>>0);
           if (!($151)) {
            label = 57;
            break;
           }
           $152 = ((($$024$i$i)) + 4|0);
           $153 = HEAP32[$152>>2]|0;
           $154 = ($153|0)==(0|0);
           if ($154) {
            label = 56;
            break;
           } else {
            $$0$ph$i$i = $152;$$in$i$i = $153;
           }
          }
          $$0$i$i = $$0$ph$i$i;$$024$i$i = $$in$i$i;$314 = $$in$i$i;
         }
         if ((label|0) == 53) {
          $$025$i53$i = $$024$i$i;$$03752$i = $$024$i$i;
          label = 59;
          break;
         }
         else if ((label|0) == 56) {
          $$025$i53$i = $152;$$03752$i = $$024$i$i;
          label = 59;
          break;
         }
         else if ((label|0) == 57) {
          $$025$i$i = $$0$i$i;$$037$i = $$024$i$i;$155 = $314;
          label = 58;
          break;
         }
        }
       } while(0);
       if ((label|0) == 58) {
        $156 = ($155|0)==(0|0);
        if ($156) {
         $$025$i53$i = $$025$i$i;$$03752$i = $$037$i;
         label = 59;
        } else {
         $$014$i = $155;
        }
       }
       if ((label|0) == 59) {
        __THREW__ = 0;
        $157 = (invoke_ii(3276,24)|0);
        $158 = __THREW__; __THREW__ = 0;
        $159 = $158&1;
        if ($159) {
         label = 95;
         break L58;
        }
        $160 = ((($157)) + 16|0);
        HEAP32[$160>>2] = $117;
        $161 = ((($157)) + 20|0);
        HEAP32[$161>>2] = 0;
        HEAP32[$157>>2] = 0;
        $162 = ((($157)) + 4|0);
        HEAP32[$162>>2] = 0;
        $163 = ((($157)) + 8|0);
        HEAP32[$163>>2] = $$03752$i;
        HEAP32[$$025$i53$i>>2] = $157;
        $164 = HEAP32[52026]|0;
        $165 = HEAP32[$164>>2]|0;
        $166 = ($165|0)==(0|0);
        if ($166) {
         $169 = $157;
        } else {
         $167 = $165;
         HEAP32[52026] = $167;
         $$pre$i$i = HEAP32[$$025$i53$i>>2]|0;
         $169 = $$pre$i$i;
        }
        $168 = HEAP32[(208108)>>2]|0;
        __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($168,$169);
        $170 = HEAP32[(208112)>>2]|0;
        $171 = (($170) + 1)|0;
        HEAP32[(208112)>>2] = $171;
        $$014$i = $157;
       }
       $172 = ((($$014$i)) + 20|0);
       $173 = HEAP32[$172>>2]|0;
       $174 = ($173|0)==($118|0);
       if (!($174)) {
        HEAP32[$172>>2] = $118;
        $175 = ((($118)) + 8|0);
        $176 = HEAP32[$175>>2]|0;HEAP32[$175>>2] = (($176+1)|0);
        $177 = ($173|0)==(0|0);
        if (!($177)) {
         $178 = ((($173)) + 8|0);
         $179 = HEAP32[$178>>2]|0;HEAP32[$178>>2] = (($179-1)|0);
         $180 = ($179|0)==(1);
         if ($180) {
          __THREW__ = 0;
          invoke_viii(3262,($173|0),1,1);
          $181 = __THREW__; __THREW__ = 0;
          $182 = $181&1;
          if ($182) {
           label = 95;
           break L58;
          }
         }
        }
       }
       $183 = HEAP32[(208108)>>2]|0;
       $184 = ($183|0)==(0|0);
       do {
        if ($184) {
         $$025$i$i44 = (208108);$$037$i43 = (208108);$194 = $183;
         label = 76;
        } else {
         $$0$i$i42 = (208108);$$024$i$i41 = $183;$315 = $183;
         while(1) {
          $185 = ((($$024$i$i41)) + 16|0);
          $186 = HEAP32[$185>>2]|0;
          $187 = ($117>>>0)<($186>>>0);
          if ($187) {
           $188 = HEAP32[$$024$i$i41>>2]|0;
           $189 = ($188|0)==(0|0);
           if ($189) {
            label = 71;
            break;
           } else {
            $$0$ph$i$i39 = $$024$i$i41;$$in$i$i38 = $188;
           }
          } else {
           $190 = ($186>>>0)<($117>>>0);
           if (!($190)) {
            label = 75;
            break;
           }
           $191 = ((($$024$i$i41)) + 4|0);
           $192 = HEAP32[$191>>2]|0;
           $193 = ($192|0)==(0|0);
           if ($193) {
            label = 74;
            break;
           } else {
            $$0$ph$i$i39 = $191;$$in$i$i38 = $192;
           }
          }
          $$0$i$i42 = $$0$ph$i$i39;$$024$i$i41 = $$in$i$i38;$315 = $$in$i$i38;
         }
         if ((label|0) == 71) {
          $$025$i53$i46 = $$024$i$i41;$$03752$i47 = $$024$i$i41;
          label = 77;
          break;
         }
         else if ((label|0) == 74) {
          $$025$i53$i46 = $191;$$03752$i47 = $$024$i$i41;
          label = 77;
          break;
         }
         else if ((label|0) == 75) {
          $$025$i$i44 = $$0$i$i42;$$037$i43 = $$024$i$i41;$194 = $315;
          label = 76;
          break;
         }
        }
       } while(0);
       if ((label|0) == 76) {
        $195 = ($194|0)==(0|0);
        if ($195) {
         $$025$i53$i46 = $$025$i$i44;$$03752$i47 = $$037$i43;
         label = 77;
        } else {
         $$014$i51 = $194;
        }
       }
       if ((label|0) == 77) {
        __THREW__ = 0;
        $196 = (invoke_ii(3276,24)|0);
        $197 = __THREW__; __THREW__ = 0;
        $198 = $197&1;
        if ($198) {
         label = 95;
         break L58;
        }
        $199 = ((($196)) + 16|0);
        HEAP32[$199>>2] = $117;
        $200 = ((($196)) + 20|0);
        HEAP32[$200>>2] = 0;
        HEAP32[$196>>2] = 0;
        $201 = ((($196)) + 4|0);
        HEAP32[$201>>2] = 0;
        $202 = ((($196)) + 8|0);
        HEAP32[$202>>2] = $$03752$i47;
        HEAP32[$$025$i53$i46>>2] = $196;
        $203 = HEAP32[52026]|0;
        $204 = HEAP32[$203>>2]|0;
        $205 = ($204|0)==(0|0);
        if ($205) {
         $208 = $196;
        } else {
         $206 = $204;
         HEAP32[52026] = $206;
         $$pre$i$i49 = HEAP32[$$025$i53$i46>>2]|0;
         $208 = $$pre$i$i49;
        }
        $207 = HEAP32[(208108)>>2]|0;
        __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($207,$208);
        $209 = HEAP32[(208112)>>2]|0;
        $210 = (($209) + 1)|0;
        HEAP32[(208112)>>2] = $210;
        $$014$i51 = $196;
       }
       $211 = ((($$014$i51)) + 20|0);
       $212 = HEAP32[$211>>2]|0;
       $213 = ((($212)) + 28|0);
       HEAP32[$213>>2] = 1;
       __THREW__ = 0;
       $214 = (invoke_ii(3265,4)|0);
       $215 = __THREW__; __THREW__ = 0;
       $216 = $215&1;
       if ($216) {
        label = 95;
        break L58;
       }
       L120: do {
        if ($214) {
         __THREW__ = 0;
         $217 = (invoke_ii(3266,4)|0);
         $218 = __THREW__; __THREW__ = 0;
         $219 = $218&1;
         if ($219) {
          label = 95;
          break L58;
         }
         __THREW__ = 0;
         $220 = (invoke_iiii(3267,($217|0),(120627|0),53)|0);
         $221 = __THREW__; __THREW__ = 0;
         $222 = $221&1;
         if ($222) {
          label = 95;
          break L58;
         }
         __THREW__ = 0;
         $223 = (invoke_iii(3417,($220|0),($117|0))|0);
         $224 = __THREW__; __THREW__ = 0;
         $225 = $224&1;
         if ($225) {
          label = 95;
          break L58;
         }
         $226 = HEAP32[$223>>2]|0;
         $227 = ((($226)) + -12|0);
         $228 = HEAP32[$227>>2]|0;
         $229 = (($223) + ($228)|0);
         __THREW__ = 0;
         invoke_vii(3257,($0|0),($229|0));
         $230 = __THREW__; __THREW__ = 0;
         $231 = $230&1;
         if ($231) {
          label = 95;
          break L58;
         }
         __THREW__ = 0;
         $232 = (invoke_iii(3255,($0|0),(215188|0))|0);
         $233 = __THREW__; __THREW__ = 0;
         $234 = $233&1;
         do {
          if (!($234)) {
           $235 = HEAP32[$232>>2]|0;
           $236 = ((($235)) + 28|0);
           $237 = HEAP32[$236>>2]|0;
           __THREW__ = 0;
           $238 = (invoke_iii($237|0,($232|0),10)|0);
           $239 = __THREW__; __THREW__ = 0;
           $240 = $239&1;
           if ($240) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3263,($0|0));
           $241 = __THREW__; __THREW__ = 0;
           $242 = $241&1;
           if ($242) {
            label = 95;
            break L58;
           }
           __THREW__ = 0;
           (invoke_iii(3268,($223|0),($238|0))|0);
           $249 = __THREW__; __THREW__ = 0;
           $250 = $249&1;
           if ($250) {
            label = 95;
            break L58;
           }
           __THREW__ = 0;
           (invoke_ii(3269,($223|0))|0);
           $251 = __THREW__; __THREW__ = 0;
           $252 = $251&1;
           if ($252) {
            label = 95;
            break L58;
           } else {
            break L120;
           }
          }
         } while(0);
         $243 = ___cxa_find_matching_catch_2()|0;
         $244 = tempRet0;
         __THREW__ = 0;
         invoke_vi(3263,($0|0));
         $245 = __THREW__; __THREW__ = 0;
         $246 = $245&1;
         if ($246) {
          $247 = ___cxa_find_matching_catch_3(0|0)|0;
          $248 = tempRet0;
          ___clang_call_terminate($247);
          // unreachable;
         } else {
          $eh$lpad$body$index13Z2D = $244;$eh$lpad$body$indexZ2D = $243;
          break L58;
         }
        }
       } while(0);
       __THREW__ = 0;
       $257 = (invoke_ii(3265,4)|0);
       $258 = __THREW__; __THREW__ = 0;
       $259 = $258&1;
       if ($259) {
        label = 95;
        break L58;
       }
       L137: do {
        if ($257) {
         __THREW__ = 0;
         $260 = (invoke_ii(3266,4)|0);
         $261 = __THREW__; __THREW__ = 0;
         $262 = $261&1;
         if ($262) {
          label = 95;
          break L58;
         }
         __THREW__ = 0;
         $263 = (invoke_iiii(3267,($260|0),(120681|0),44)|0);
         $264 = __THREW__; __THREW__ = 0;
         $265 = $264&1;
         if ($265) {
          label = 95;
          break L58;
         }
         $266 = (($117) + 1)|0;
         __THREW__ = 0;
         $267 = (invoke_iii(3417,($263|0),($266|0))|0);
         $268 = __THREW__; __THREW__ = 0;
         $269 = $268&1;
         if ($269) {
          label = 95;
          break L58;
         }
         $270 = HEAP32[$267>>2]|0;
         $271 = ((($270)) + -12|0);
         $272 = HEAP32[$271>>2]|0;
         $273 = (($267) + ($272)|0);
         __THREW__ = 0;
         invoke_vii(3257,($4|0),($273|0));
         $274 = __THREW__; __THREW__ = 0;
         $275 = $274&1;
         if ($275) {
          label = 95;
          break L58;
         }
         __THREW__ = 0;
         $276 = (invoke_iii(3255,($4|0),(215188|0))|0);
         $277 = __THREW__; __THREW__ = 0;
         $278 = $277&1;
         do {
          if (!($278)) {
           $279 = HEAP32[$276>>2]|0;
           $280 = ((($279)) + 28|0);
           $281 = HEAP32[$280>>2]|0;
           __THREW__ = 0;
           $282 = (invoke_iii($281|0,($276|0),10)|0);
           $283 = __THREW__; __THREW__ = 0;
           $284 = $283&1;
           if ($284) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3263,($4|0));
           $285 = __THREW__; __THREW__ = 0;
           $286 = $285&1;
           if ($286) {
            label = 95;
            break L58;
           }
           __THREW__ = 0;
           (invoke_iii(3268,($267|0),($282|0))|0);
           $293 = __THREW__; __THREW__ = 0;
           $294 = $293&1;
           if ($294) {
            label = 95;
            break L58;
           }
           __THREW__ = 0;
           (invoke_ii(3269,($267|0))|0);
           $295 = __THREW__; __THREW__ = 0;
           $296 = $295&1;
           if ($296) {
            label = 95;
            break L58;
           } else {
            break L137;
           }
          }
         } while(0);
         $287 = ___cxa_find_matching_catch_2()|0;
         $288 = tempRet0;
         __THREW__ = 0;
         invoke_vi(3263,($4|0));
         $289 = __THREW__; __THREW__ = 0;
         $290 = $289&1;
         if ($290) {
          $291 = ___cxa_find_matching_catch_3(0|0)|0;
          $292 = tempRet0;
          ___clang_call_terminate($291);
          // unreachable;
         } else {
          $eh$lpad$body$index13Z2D = $288;$eh$lpad$body$indexZ2D = $287;
          break L58;
         }
        }
       } while(0);
       __THREW__ = 0;
       $297 = (invoke_i(3285)|0);
       $298 = __THREW__; __THREW__ = 0;
       $299 = $298&1;
       if ($299) {
        label = 95;
        break L58;
       }
       $300 = HEAP32[$297>>2]|0;
       $301 = (($117) + 1)|0;
       __THREW__ = 0;
       invoke_vii(3733,($300|0),($301|0));
       $302 = __THREW__; __THREW__ = 0;
       $303 = $302&1;
       if ($303) {
        label = 95;
        break L58;
       } else {
        $$18 = $117;
       }
       $304 = HEAP32[52029]|0;
       $305 = ((($304)) + 12|0);
       $306 = HEAP32[$305>>2]|0;
       (FUNCTION_TABLE_ii[$306 & 8191](208116)|0);
       STACKTOP = sp;return ($$18|0);
      }
     } while(0);
     __ZdlPv($118);
     $$2 = $eh$lpad$body32$index19Z2D;$$26 = $eh$lpad$body32$indexZ2D;
     break L56;
    }
   } while(0);
   if ((label|0) == 95) {
    $253 = ___cxa_find_matching_catch_2()|0;
    $254 = tempRet0;
    $eh$lpad$body$index13Z2D = $254;$eh$lpad$body$indexZ2D = $253;
   }
   $$2 = $eh$lpad$body$index13Z2D;$$26 = $eh$lpad$body$indexZ2D;
  }
 } while(0);
 $307 = HEAP32[52029]|0;
 $308 = ((($307)) + 12|0);
 $309 = HEAP32[$308>>2]|0;
 __THREW__ = 0;
 (invoke_ii($309|0,(208116|0))|0);
 $310 = __THREW__; __THREW__ = 0;
 $311 = $310&1;
 if ($311) {
  $312 = ___cxa_find_matching_catch_3(0|0)|0;
  $313 = tempRet0;
  ___clang_call_terminate($312);
  // unreachable;
 } else {
  ___resumeException($$26|0);
  // unreachable;
 }
 return (0)|0;
}
function __ZN3osg11ContextData15getMaxContextIDEv() {
 var $$$06 = 0, $$0$i$i$i$i = 0, $$06$lcssa = 0, $$0620 = 0, $$sroa$09$0$be = 0, $$sroa$09$019 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[52029]|0;
 $1 = ((($0)) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 (FUNCTION_TABLE_ii[$2 & 8191](208116)|0);
 $3 = HEAP32[52026]|0;
 $4 = ($3|0)==((208108)|0);
 if ($4) {
  $$06$lcssa = 0;
  $5 = HEAP32[52029]|0;
  $6 = ((($5)) + 12|0);
  $7 = HEAP32[$6>>2]|0;
  (FUNCTION_TABLE_ii[$7 & 8191](208116)|0);
  return ($$06$lcssa|0);
 } else {
  $$0620 = 0;$$sroa$09$019 = $3;
 }
 while(1) {
  $8 = ((($$sroa$09$019)) + 16|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($9>>>0)>($$0620>>>0);
  $$$06 = $10 ? $9 : $$0620;
  $11 = ((($$sroa$09$019)) + 4|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($12|0)==(0|0);
  if ($13) {
   $14 = ((($$sroa$09$019)) + 8|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = HEAP32[$15>>2]|0;
   $17 = ($16|0)==($$sroa$09$019|0);
   if ($17) {
    $$sroa$09$0$be = $15;
   } else {
    $22 = $14;
    while(1) {
     $21 = HEAP32[$22>>2]|0;
     $23 = ((($21)) + 8|0);
     $24 = HEAP32[$23>>2]|0;
     $25 = HEAP32[$24>>2]|0;
     $26 = ($25|0)==($21|0);
     if ($26) {
      $$sroa$09$0$be = $24;
      break;
     } else {
      $22 = $23;
     }
    }
   }
  } else {
   $$0$i$i$i$i = $12;
   while(1) {
    $19 = HEAP32[$$0$i$i$i$i>>2]|0;
    $20 = ($19|0)==(0|0);
    if ($20) {
     break;
    } else {
     $$0$i$i$i$i = $19;
    }
   }
   $$sroa$09$0$be = $$0$i$i$i$i;
  }
  $18 = ($$sroa$09$0$be|0)==((208108)|0);
  if ($18) {
   $$06$lcssa = $$$06;
   break;
  } else {
   $$0620 = $$$06;$$sroa$09$019 = $$sroa$09$0$be;
  }
 }
 $5 = HEAP32[52029]|0;
 $6 = ((($5)) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 (FUNCTION_TABLE_ii[$7 & 8191](208116)|0);
 return ($$06$lcssa|0);
}
function __ZN3osg11ContextData28incrementContextIDUsageCountEj($0) {
 $0 = $0|0;
 var $$0 = 0, $$0$i$i = 0, $$0$i$i26 = 0, $$0$i$i46 = 0, $$0$i$i8 = 0, $$0$ph$i$i = 0, $$0$ph$i$i23 = 0, $$0$ph$i$i43 = 0, $$0$ph$i$i5 = 0, $$01 = 0, $$014$i = 0, $$014$i17 = 0, $$014$i35 = 0, $$014$i55 = 0, $$024$i$i = 0, $$024$i$i25 = 0, $$024$i$i45 = 0, $$024$i$i7 = 0, $$025$i$i = 0, $$025$i$i10 = 0;
 var $$025$i$i28 = 0, $$025$i$i48 = 0, $$025$i53$i = 0, $$025$i53$i12 = 0, $$025$i53$i30 = 0, $$025$i53$i50 = 0, $$037$i = 0, $$037$i27 = 0, $$037$i47 = 0, $$037$i9 = 0, $$03752$i = 0, $$03752$i13 = 0, $$03752$i31 = 0, $$03752$i51 = 0, $$in$i$i = 0, $$in$i$i22 = 0, $$in$i$i4 = 0, $$in$i$i42 = 0, $$pre$i$i = 0, $$pre$i$i15 = 0;
 var $$pre$i$i33 = 0, $$pre$i$i53 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0;
 var $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0;
 var $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index7Z2D = 0, $eh$lpad$body$indexZ2D = 0, $eh$lpad$body61$index2Z2D = 0, $eh$lpad$body61$indexZ2D = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp + 12|0;
 $2 = sp;
 $3 = HEAP32[52029]|0;
 $4 = ((($3)) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 (FUNCTION_TABLE_ii[$5 & 8191](208116)|0);
 $6 = HEAP32[(208108)>>2]|0;
 $7 = ($6|0)==(0|0);
 do {
  if ($7) {
   $$025$i$i = (208108);$$037$i = (208108);$17 = $6;
   label = 10;
  } else {
   $$0$i$i = (208108);$$024$i$i = $6;$226 = $6;
   while(1) {
    $8 = ((($$024$i$i)) + 16|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = ($9>>>0)>($0>>>0);
    if ($10) {
     $11 = HEAP32[$$024$i$i>>2]|0;
     $12 = ($11|0)==(0|0);
     if ($12) {
      label = 5;
      break;
     } else {
      $$0$ph$i$i = $$024$i$i;$$in$i$i = $11;
     }
    } else {
     $13 = ($9>>>0)<($0>>>0);
     if (!($13)) {
      label = 9;
      break;
     }
     $14 = ((($$024$i$i)) + 4|0);
     $15 = HEAP32[$14>>2]|0;
     $16 = ($15|0)==(0|0);
     if ($16) {
      label = 8;
      break;
     } else {
      $$0$ph$i$i = $14;$$in$i$i = $15;
     }
    }
    $$0$i$i = $$0$ph$i$i;$$024$i$i = $$in$i$i;$226 = $$in$i$i;
   }
   if ((label|0) == 5) {
    $$025$i53$i = $$024$i$i;$$03752$i = $$024$i$i;
    label = 11;
    break;
   }
   else if ((label|0) == 8) {
    $$025$i53$i = $14;$$03752$i = $$024$i$i;
    label = 11;
    break;
   }
   else if ((label|0) == 9) {
    $$025$i$i = $$0$i$i;$$037$i = $$024$i$i;$17 = $226;
    label = 10;
    break;
   }
  }
 } while(0);
 if ((label|0) == 10) {
  $18 = ($17|0)==(0|0);
  if ($18) {
   $$025$i53$i = $$025$i$i;$$03752$i = $$037$i;
   label = 11;
  } else {
   $$014$i = $17;
   label = 15;
  }
 }
 if ((label|0) == 11) {
  __THREW__ = 0;
  $19 = (invoke_ii(3276,24)|0);
  $20 = __THREW__; __THREW__ = 0;
  $21 = $20&1;
  if ($21) {
   label = 42;
  } else {
   $22 = ((($19)) + 16|0);
   HEAP32[$22>>2] = $0;
   $23 = ((($19)) + 20|0);
   HEAP32[$23>>2] = 0;
   HEAP32[$19>>2] = 0;
   $24 = ((($19)) + 4|0);
   HEAP32[$24>>2] = 0;
   $25 = ((($19)) + 8|0);
   HEAP32[$25>>2] = $$03752$i;
   HEAP32[$$025$i53$i>>2] = $19;
   $26 = HEAP32[52026]|0;
   $27 = HEAP32[$26>>2]|0;
   $28 = ($27|0)==(0|0);
   if ($28) {
    $31 = $19;
   } else {
    $29 = $27;
    HEAP32[52026] = $29;
    $$pre$i$i = HEAP32[$$025$i53$i>>2]|0;
    $31 = $$pre$i$i;
   }
   $30 = HEAP32[(208108)>>2]|0;
   __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($30,$31);
   $32 = HEAP32[(208112)>>2]|0;
   $33 = (($32) + 1)|0;
   HEAP32[(208112)>>2] = $33;
   $$014$i = $19;
   label = 15;
  }
 }
 L21: do {
  if ((label|0) == 15) {
   $34 = ((($$014$i)) + 20|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ($35|0)==(0|0);
   L23: do {
    if ($36) {
     __THREW__ = 0;
     $37 = (invoke_ii(3276,48)|0);
     $38 = __THREW__; __THREW__ = 0;
     $39 = $38&1;
     if ($39) {
      label = 42;
      break L21;
     }
     __THREW__ = 0;
     $40 = (invoke_ii(3276,16)|0);
     $41 = __THREW__; __THREW__ = 0;
     $42 = $41&1;
     do {
      if ($42) {
       $104 = ___cxa_find_matching_catch_2()|0;
       $105 = tempRet0;
       $eh$lpad$body$index7Z2D = $105;$eh$lpad$body$indexZ2D = $104;
      } else {
       HEAP32[$2>>2] = $40;
       $43 = ((($2)) + 8|0);
       HEAP32[$43>>2] = -2147483632;
       $44 = ((($2)) + 4|0);
       HEAP32[$44>>2] = 11;
       dest=$40; src=120560; stop=dest+11|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
       $45 = ((($40)) + 11|0);
       HEAP8[$45>>0] = 0;
       __THREW__ = 0;
       invoke_viii(3719,($37|0),($2|0),($0|0));
       $46 = __THREW__; __THREW__ = 0;
       $47 = $46&1;
       if ($47) {
        $52 = ___cxa_find_matching_catch_2()|0;
        $53 = tempRet0;
        $54 = ((($2)) + 11|0);
        $55 = HEAP8[$54>>0]|0;
        $56 = ($55<<24>>24)<(0);
        if ($56) {
         $57 = HEAP32[$2>>2]|0;
         __ZdlPv($57);
        }
        $eh$lpad$body$index7Z2D = $53;$eh$lpad$body$indexZ2D = $52;
        break;
       }
       $48 = ((($2)) + 11|0);
       $49 = HEAP8[$48>>0]|0;
       $50 = ($49<<24>>24)<(0);
       if ($50) {
        $51 = HEAP32[$2>>2]|0;
        __ZdlPv($51);
       }
       HEAP32[$37>>2] = (58084);
       $58 = ((($37)) + 28|0);
       HEAP32[$58>>2] = 0;
       $59 = ((($37)) + 32|0);
       HEAP32[$59>>2] = 0;
       $60 = ((($37)) + 40|0);
       HEAP32[$60>>2] = 0;
       $61 = ((($37)) + 44|0);
       HEAP32[$61>>2] = 0;
       $62 = ((($37)) + 36|0);
       HEAP32[$62>>2] = $60;
       $63 = HEAP32[(208108)>>2]|0;
       $64 = ($63|0)==(0|0);
       do {
        if ($64) {
         $$025$i$i10 = (208108);$$037$i9 = (208108);$74 = $63;
         label = 33;
        } else {
         $$0$i$i8 = (208108);$$024$i$i7 = $63;$227 = $63;
         while(1) {
          $65 = ((($$024$i$i7)) + 16|0);
          $66 = HEAP32[$65>>2]|0;
          $67 = ($66>>>0)>($0>>>0);
          if ($67) {
           $68 = HEAP32[$$024$i$i7>>2]|0;
           $69 = ($68|0)==(0|0);
           if ($69) {
            label = 28;
            break;
           } else {
            $$0$ph$i$i5 = $$024$i$i7;$$in$i$i4 = $68;
           }
          } else {
           $70 = ($66>>>0)<($0>>>0);
           if (!($70)) {
            label = 32;
            break;
           }
           $71 = ((($$024$i$i7)) + 4|0);
           $72 = HEAP32[$71>>2]|0;
           $73 = ($72|0)==(0|0);
           if ($73) {
            label = 31;
            break;
           } else {
            $$0$ph$i$i5 = $71;$$in$i$i4 = $72;
           }
          }
          $$0$i$i8 = $$0$ph$i$i5;$$024$i$i7 = $$in$i$i4;$227 = $$in$i$i4;
         }
         if ((label|0) == 28) {
          $$025$i53$i12 = $$024$i$i7;$$03752$i13 = $$024$i$i7;
          label = 34;
          break;
         }
         else if ((label|0) == 31) {
          $$025$i53$i12 = $71;$$03752$i13 = $$024$i$i7;
          label = 34;
          break;
         }
         else if ((label|0) == 32) {
          $$025$i$i10 = $$0$i$i8;$$037$i9 = $$024$i$i7;$74 = $227;
          label = 33;
          break;
         }
        }
       } while(0);
       if ((label|0) == 33) {
        $75 = ($74|0)==(0|0);
        if ($75) {
         $$025$i53$i12 = $$025$i$i10;$$03752$i13 = $$037$i9;
         label = 34;
        } else {
         $$014$i17 = $74;
        }
       }
       if ((label|0) == 34) {
        __THREW__ = 0;
        $76 = (invoke_ii(3276,24)|0);
        $77 = __THREW__; __THREW__ = 0;
        $78 = $77&1;
        if ($78) {
         label = 42;
         break L21;
        }
        $79 = ((($76)) + 16|0);
        HEAP32[$79>>2] = $0;
        $80 = ((($76)) + 20|0);
        HEAP32[$80>>2] = 0;
        HEAP32[$76>>2] = 0;
        $81 = ((($76)) + 4|0);
        HEAP32[$81>>2] = 0;
        $82 = ((($76)) + 8|0);
        HEAP32[$82>>2] = $$03752$i13;
        HEAP32[$$025$i53$i12>>2] = $76;
        $83 = HEAP32[52026]|0;
        $84 = HEAP32[$83>>2]|0;
        $85 = ($84|0)==(0|0);
        if ($85) {
         $88 = $76;
        } else {
         $86 = $84;
         HEAP32[52026] = $86;
         $$pre$i$i15 = HEAP32[$$025$i53$i12>>2]|0;
         $88 = $$pre$i$i15;
        }
        $87 = HEAP32[(208108)>>2]|0;
        __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($87,$88);
        $89 = HEAP32[(208112)>>2]|0;
        $90 = (($89) + 1)|0;
        HEAP32[(208112)>>2] = $90;
        $$014$i17 = $76;
       }
       $91 = ((($$014$i17)) + 20|0);
       $92 = HEAP32[$91>>2]|0;
       $93 = ($92|0)==($37|0);
       if ($93) {
        break L23;
       }
       HEAP32[$91>>2] = $37;
       $94 = ((($37)) + 8|0);
       $95 = HEAP32[$94>>2]|0;HEAP32[$94>>2] = (($95+1)|0);
       $96 = ($92|0)==(0|0);
       if ($96) {
        break L23;
       }
       $97 = ((($92)) + 8|0);
       $98 = HEAP32[$97>>2]|0;HEAP32[$97>>2] = (($98-1)|0);
       $99 = ($98|0)==(1);
       if (!($99)) {
        break L23;
       }
       __THREW__ = 0;
       invoke_viii(3262,($92|0),1,1);
       $100 = __THREW__; __THREW__ = 0;
       $101 = $100&1;
       if ($101) {
        label = 42;
        break L21;
       } else {
        break L23;
       }
      }
     } while(0);
     __ZdlPv($37);
     $$0 = $eh$lpad$body$index7Z2D;$$01 = $eh$lpad$body$indexZ2D;
     break L21;
    }
   } while(0);
   $106 = HEAP32[(208108)>>2]|0;
   $107 = ($106|0)==(0|0);
   do {
    if ($107) {
     $$025$i$i28 = (208108);$$037$i27 = (208108);$117 = $106;
     label = 55;
    } else {
     $$0$i$i26 = (208108);$$024$i$i25 = $106;$228 = $106;
     while(1) {
      $108 = ((($$024$i$i25)) + 16|0);
      $109 = HEAP32[$108>>2]|0;
      $110 = ($109>>>0)>($0>>>0);
      if ($110) {
       $111 = HEAP32[$$024$i$i25>>2]|0;
       $112 = ($111|0)==(0|0);
       if ($112) {
        label = 50;
        break;
       } else {
        $$0$ph$i$i23 = $$024$i$i25;$$in$i$i22 = $111;
       }
      } else {
       $113 = ($109>>>0)<($0>>>0);
       if (!($113)) {
        label = 54;
        break;
       }
       $114 = ((($$024$i$i25)) + 4|0);
       $115 = HEAP32[$114>>2]|0;
       $116 = ($115|0)==(0|0);
       if ($116) {
        label = 53;
        break;
       } else {
        $$0$ph$i$i23 = $114;$$in$i$i22 = $115;
       }
      }
      $$0$i$i26 = $$0$ph$i$i23;$$024$i$i25 = $$in$i$i22;$228 = $$in$i$i22;
     }
     if ((label|0) == 50) {
      $$025$i53$i30 = $$024$i$i25;$$03752$i31 = $$024$i$i25;
      label = 56;
      break;
     }
     else if ((label|0) == 53) {
      $$025$i53$i30 = $114;$$03752$i31 = $$024$i$i25;
      label = 56;
      break;
     }
     else if ((label|0) == 54) {
      $$025$i$i28 = $$0$i$i26;$$037$i27 = $$024$i$i25;$117 = $228;
      label = 55;
      break;
     }
    }
   } while(0);
   if ((label|0) == 55) {
    $118 = ($117|0)==(0|0);
    if ($118) {
     $$025$i53$i30 = $$025$i$i28;$$03752$i31 = $$037$i27;
     label = 56;
    } else {
     $$014$i35 = $117;
    }
   }
   if ((label|0) == 56) {
    __THREW__ = 0;
    $119 = (invoke_ii(3276,24)|0);
    $120 = __THREW__; __THREW__ = 0;
    $121 = $120&1;
    if ($121) {
     label = 42;
     break;
    }
    $122 = ((($119)) + 16|0);
    HEAP32[$122>>2] = $0;
    $123 = ((($119)) + 20|0);
    HEAP32[$123>>2] = 0;
    HEAP32[$119>>2] = 0;
    $124 = ((($119)) + 4|0);
    HEAP32[$124>>2] = 0;
    $125 = ((($119)) + 8|0);
    HEAP32[$125>>2] = $$03752$i31;
    HEAP32[$$025$i53$i30>>2] = $119;
    $126 = HEAP32[52026]|0;
    $127 = HEAP32[$126>>2]|0;
    $128 = ($127|0)==(0|0);
    if ($128) {
     $131 = $119;
    } else {
     $129 = $127;
     HEAP32[52026] = $129;
     $$pre$i$i33 = HEAP32[$$025$i53$i30>>2]|0;
     $131 = $$pre$i$i33;
    }
    $130 = HEAP32[(208108)>>2]|0;
    __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($130,$131);
    $132 = HEAP32[(208112)>>2]|0;
    $133 = (($132) + 1)|0;
    HEAP32[(208112)>>2] = $133;
    $$014$i35 = $119;
   }
   $134 = ((($$014$i35)) + 20|0);
   $135 = HEAP32[$134>>2]|0;
   $136 = ((($135)) + 28|0);
   $137 = HEAP32[$136>>2]|0;
   $138 = (($137) + 1)|0;
   HEAP32[$136>>2] = $138;
   __THREW__ = 0;
   $139 = (invoke_ii(3265,3)|0);
   $140 = __THREW__; __THREW__ = 0;
   $141 = $140&1;
   if ($141) {
    label = 42;
   } else {
    if (!($139)) {
     $216 = HEAP32[52029]|0;
     $217 = ((($216)) + 12|0);
     $218 = HEAP32[$217>>2]|0;
     (FUNCTION_TABLE_ii[$218 & 8191](208116)|0);
     STACKTOP = sp;return;
    }
    __THREW__ = 0;
    $142 = (invoke_ii(3266,3)|0);
    $143 = __THREW__; __THREW__ = 0;
    $144 = $143&1;
    if ($144) {
     label = 42;
    } else {
     __THREW__ = 0;
     $145 = (invoke_iiii(3267,($142|0),(120726|0),42)|0);
     $146 = __THREW__; __THREW__ = 0;
     $147 = $146&1;
     if ($147) {
      label = 42;
     } else {
      __THREW__ = 0;
      $148 = (invoke_iii(3417,($145|0),($0|0))|0);
      $149 = __THREW__; __THREW__ = 0;
      $150 = $149&1;
      if ($150) {
       label = 42;
      } else {
       __THREW__ = 0;
       $151 = (invoke_iiii(3267,($148|0),(120769|0),5)|0);
       $152 = __THREW__; __THREW__ = 0;
       $153 = $152&1;
       if ($153) {
        label = 42;
       } else {
        $154 = HEAP32[(208108)>>2]|0;
        $155 = ($154|0)==(0|0);
        do {
         if ($155) {
          $$025$i$i48 = (208108);$$037$i47 = (208108);$165 = $154;
          label = 75;
         } else {
          $$0$i$i46 = (208108);$$024$i$i45 = $154;$229 = $154;
          while(1) {
           $156 = ((($$024$i$i45)) + 16|0);
           $157 = HEAP32[$156>>2]|0;
           $158 = ($157>>>0)>($0>>>0);
           if ($158) {
            $159 = HEAP32[$$024$i$i45>>2]|0;
            $160 = ($159|0)==(0|0);
            if ($160) {
             label = 70;
             break;
            } else {
             $$0$ph$i$i43 = $$024$i$i45;$$in$i$i42 = $159;
            }
           } else {
            $161 = ($157>>>0)<($0>>>0);
            if (!($161)) {
             label = 74;
             break;
            }
            $162 = ((($$024$i$i45)) + 4|0);
            $163 = HEAP32[$162>>2]|0;
            $164 = ($163|0)==(0|0);
            if ($164) {
             label = 73;
             break;
            } else {
             $$0$ph$i$i43 = $162;$$in$i$i42 = $163;
            }
           }
           $$0$i$i46 = $$0$ph$i$i43;$$024$i$i45 = $$in$i$i42;$229 = $$in$i$i42;
          }
          if ((label|0) == 70) {
           $$025$i53$i50 = $$024$i$i45;$$03752$i51 = $$024$i$i45;
           label = 76;
           break;
          }
          else if ((label|0) == 73) {
           $$025$i53$i50 = $162;$$03752$i51 = $$024$i$i45;
           label = 76;
           break;
          }
          else if ((label|0) == 74) {
           $$025$i$i48 = $$0$i$i46;$$037$i47 = $$024$i$i45;$165 = $229;
           label = 75;
           break;
          }
         }
        } while(0);
        if ((label|0) == 75) {
         $166 = ($165|0)==(0|0);
         if ($166) {
          $$025$i53$i50 = $$025$i$i48;$$03752$i51 = $$037$i47;
          label = 76;
         } else {
          $$014$i55 = $165;
         }
        }
        if ((label|0) == 76) {
         __THREW__ = 0;
         $167 = (invoke_ii(3276,24)|0);
         $168 = __THREW__; __THREW__ = 0;
         $169 = $168&1;
         if ($169) {
          label = 42;
          break;
         }
         $170 = ((($167)) + 16|0);
         HEAP32[$170>>2] = $0;
         $171 = ((($167)) + 20|0);
         HEAP32[$171>>2] = 0;
         HEAP32[$167>>2] = 0;
         $172 = ((($167)) + 4|0);
         HEAP32[$172>>2] = 0;
         $173 = ((($167)) + 8|0);
         HEAP32[$173>>2] = $$03752$i51;
         HEAP32[$$025$i53$i50>>2] = $167;
         $174 = HEAP32[52026]|0;
         $175 = HEAP32[$174>>2]|0;
         $176 = ($175|0)==(0|0);
         if ($176) {
          $179 = $167;
         } else {
          $177 = $175;
          HEAP32[52026] = $177;
          $$pre$i$i53 = HEAP32[$$025$i53$i50>>2]|0;
          $179 = $$pre$i$i53;
         }
         $178 = HEAP32[(208108)>>2]|0;
         __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($178,$179);
         $180 = HEAP32[(208112)>>2]|0;
         $181 = (($180) + 1)|0;
         HEAP32[(208112)>>2] = $181;
         $$014$i55 = $167;
        }
        $182 = ((($$014$i55)) + 20|0);
        $183 = HEAP32[$182>>2]|0;
        $184 = ((($183)) + 28|0);
        $185 = HEAP32[$184>>2]|0;
        __THREW__ = 0;
        $186 = (invoke_iii(3417,($151|0),($185|0))|0);
        $187 = __THREW__; __THREW__ = 0;
        $188 = $187&1;
        if ($188) {
         label = 42;
        } else {
         $189 = HEAP32[$186>>2]|0;
         $190 = ((($189)) + -12|0);
         $191 = HEAP32[$190>>2]|0;
         $192 = (($186) + ($191)|0);
         __THREW__ = 0;
         invoke_vii(3257,($1|0),($192|0));
         $193 = __THREW__; __THREW__ = 0;
         $194 = $193&1;
         if ($194) {
          label = 42;
         } else {
          __THREW__ = 0;
          $195 = (invoke_iii(3255,($1|0),(215188|0))|0);
          $196 = __THREW__; __THREW__ = 0;
          $197 = $196&1;
          if (!($197)) {
           $198 = HEAP32[$195>>2]|0;
           $199 = ((($198)) + 28|0);
           $200 = HEAP32[$199>>2]|0;
           __THREW__ = 0;
           $201 = (invoke_iii($200|0,($195|0),10)|0);
           $202 = __THREW__; __THREW__ = 0;
           $203 = $202&1;
           if (!($203)) {
            __THREW__ = 0;
            invoke_vi(3263,($1|0));
            $210 = __THREW__; __THREW__ = 0;
            $211 = $210&1;
            if ($211) {
             label = 42;
             break;
            }
            __THREW__ = 0;
            (invoke_iii(3268,($186|0),($201|0))|0);
            $212 = __THREW__; __THREW__ = 0;
            $213 = $212&1;
            if ($213) {
             label = 42;
             break;
            }
            __THREW__ = 0;
            (invoke_ii(3269,($186|0))|0);
            $214 = __THREW__; __THREW__ = 0;
            $215 = $214&1;
            if ($215) {
             label = 42;
             break;
            }
            $216 = HEAP32[52029]|0;
            $217 = ((($216)) + 12|0);
            $218 = HEAP32[$217>>2]|0;
            (FUNCTION_TABLE_ii[$218 & 8191](208116)|0);
            STACKTOP = sp;return;
           }
          }
          $204 = ___cxa_find_matching_catch_2()|0;
          $205 = tempRet0;
          __THREW__ = 0;
          invoke_vi(3263,($1|0));
          $206 = __THREW__; __THREW__ = 0;
          $207 = $206&1;
          if ($207) {
           $208 = ___cxa_find_matching_catch_3(0|0)|0;
           $209 = tempRet0;
           ___clang_call_terminate($208);
           // unreachable;
          } else {
           $eh$lpad$body61$index2Z2D = $205;$eh$lpad$body61$indexZ2D = $204;
           label = 43;
           break;
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 42) {
  $102 = ___cxa_find_matching_catch_2()|0;
  $103 = tempRet0;
  $eh$lpad$body61$index2Z2D = $103;$eh$lpad$body61$indexZ2D = $102;
  label = 43;
 }
 if ((label|0) == 43) {
  $$0 = $eh$lpad$body61$index2Z2D;$$01 = $eh$lpad$body61$indexZ2D;
 }
 $219 = HEAP32[52029]|0;
 $220 = ((($219)) + 12|0);
 $221 = HEAP32[$220>>2]|0;
 __THREW__ = 0;
 (invoke_ii($221|0,(208116|0))|0);
 $222 = __THREW__; __THREW__ = 0;
 $223 = $222&1;
 if ($223) {
  $224 = ___cxa_find_matching_catch_3(0|0)|0;
  $225 = tempRet0;
  ___clang_call_terminate($224);
  // unreachable;
 } else {
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __ZN3osg11ContextData28decrementContextIDUsageCountEj($0) {
 $0 = $0|0;
 var $$0$i$i = 0, $$0$i$i23 = 0, $$0$i$i41 = 0, $$0$i$i59 = 0, $$0$i$i6 = 0, $$0$ph$i$i = 0, $$0$ph$i$i20 = 0, $$0$ph$i$i3 = 0, $$0$ph$i$i38 = 0, $$0$ph$i$i56 = 0, $$014$i = 0, $$014$i15 = 0, $$014$i32 = 0, $$014$i50 = 0, $$014$i68 = 0, $$024$i$i = 0, $$024$i$i22 = 0, $$024$i$i40 = 0, $$024$i$i5 = 0, $$024$i$i58 = 0;
 var $$025$i$i = 0, $$025$i$i25 = 0, $$025$i$i43 = 0, $$025$i$i61 = 0, $$025$i$i8 = 0, $$025$i53$i = 0, $$025$i53$i10 = 0, $$025$i53$i27 = 0, $$025$i53$i45 = 0, $$025$i53$i63 = 0, $$037$i = 0, $$037$i24 = 0, $$037$i42 = 0, $$037$i60 = 0, $$037$i7 = 0, $$03752$i = 0, $$03752$i11 = 0, $$03752$i28 = 0, $$03752$i46 = 0, $$03752$i64 = 0;
 var $$in$i$i = 0, $$in$i$i19 = 0, $$in$i$i2 = 0, $$in$i$i37 = 0, $$in$i$i55 = 0, $$pre$i$i = 0, $$pre$i$i13 = 0, $$pre$i$i30 = 0, $$pre$i$i48 = 0, $$pre$i$i66 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0;
 var $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0;
 var $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[52029]|0;
 $2 = ((($1)) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 (FUNCTION_TABLE_ii[$3 & 8191](208116)|0);
 $4 = HEAP32[(208108)>>2]|0;
 $5 = ($4|0)==(0|0);
 do {
  if ($5) {
   $$025$i$i = (208108);$$037$i = (208108);$15 = $4;
   label = 10;
  } else {
   $$0$i$i = (208108);$$024$i$i = $4;$182 = $4;
   while(1) {
    $6 = ((($$024$i$i)) + 16|0);
    $7 = HEAP32[$6>>2]|0;
    $8 = ($7>>>0)>($0>>>0);
    if ($8) {
     $9 = HEAP32[$$024$i$i>>2]|0;
     $10 = ($9|0)==(0|0);
     if ($10) {
      label = 5;
      break;
     } else {
      $$0$ph$i$i = $$024$i$i;$$in$i$i = $9;
     }
    } else {
     $11 = ($7>>>0)<($0>>>0);
     if (!($11)) {
      label = 9;
      break;
     }
     $12 = ((($$024$i$i)) + 4|0);
     $13 = HEAP32[$12>>2]|0;
     $14 = ($13|0)==(0|0);
     if ($14) {
      label = 8;
      break;
     } else {
      $$0$ph$i$i = $12;$$in$i$i = $13;
     }
    }
    $$0$i$i = $$0$ph$i$i;$$024$i$i = $$in$i$i;$182 = $$in$i$i;
   }
   if ((label|0) == 5) {
    $$025$i53$i = $$024$i$i;$$03752$i = $$024$i$i;
    label = 11;
    break;
   }
   else if ((label|0) == 8) {
    $$025$i53$i = $12;$$03752$i = $$024$i$i;
    label = 11;
    break;
   }
   else if ((label|0) == 9) {
    $$025$i$i = $$0$i$i;$$037$i = $$024$i$i;$15 = $182;
    label = 10;
    break;
   }
  }
 } while(0);
 if ((label|0) == 10) {
  $16 = ($15|0)==(0|0);
  if ($16) {
   $$025$i53$i = $$025$i$i;$$03752$i = $$037$i;
   label = 11;
  } else {
   $$014$i = $15;
   label = 15;
  }
 }
 if ((label|0) == 11) {
  __THREW__ = 0;
  $17 = (invoke_ii(3276,24)|0);
  $18 = __THREW__; __THREW__ = 0;
  $19 = $18&1;
  if (!($19)) {
   $20 = ((($17)) + 16|0);
   HEAP32[$20>>2] = $0;
   $21 = ((($17)) + 20|0);
   HEAP32[$21>>2] = 0;
   HEAP32[$17>>2] = 0;
   $22 = ((($17)) + 4|0);
   HEAP32[$22>>2] = 0;
   $23 = ((($17)) + 8|0);
   HEAP32[$23>>2] = $$03752$i;
   HEAP32[$$025$i53$i>>2] = $17;
   $24 = HEAP32[52026]|0;
   $25 = HEAP32[$24>>2]|0;
   $26 = ($25|0)==(0|0);
   if ($26) {
    $29 = $17;
   } else {
    $27 = $25;
    HEAP32[52026] = $27;
    $$pre$i$i = HEAP32[$$025$i53$i>>2]|0;
    $29 = $$pre$i$i;
   }
   $28 = HEAP32[(208108)>>2]|0;
   __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($28,$29);
   $30 = HEAP32[(208112)>>2]|0;
   $31 = (($30) + 1)|0;
   HEAP32[(208112)>>2] = $31;
   $$014$i = $17;
   label = 15;
  }
 }
 do {
  if ((label|0) == 15) {
   $32 = ((($$014$i)) + 20|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = ($33|0)==(0|0);
   if ($34) {
    $177 = HEAP32[52029]|0;
    $178 = ((($177)) + 12|0);
    $179 = HEAP32[$178>>2]|0;
    (FUNCTION_TABLE_ii[$179 & 8191](208116)|0);
    return;
   }
   $35 = HEAP32[(208108)>>2]|0;
   $36 = ($35|0)==(0|0);
   do {
    if ($36) {
     $$025$i$i8 = (208108);$$037$i7 = (208108);$46 = $35;
     label = 25;
    } else {
     $$0$i$i6 = (208108);$$024$i$i5 = $35;$183 = $35;
     while(1) {
      $37 = ((($$024$i$i5)) + 16|0);
      $38 = HEAP32[$37>>2]|0;
      $39 = ($38>>>0)>($0>>>0);
      if ($39) {
       $40 = HEAP32[$$024$i$i5>>2]|0;
       $41 = ($40|0)==(0|0);
       if ($41) {
        label = 20;
        break;
       } else {
        $$0$ph$i$i3 = $$024$i$i5;$$in$i$i2 = $40;
       }
      } else {
       $42 = ($38>>>0)<($0>>>0);
       if (!($42)) {
        label = 24;
        break;
       }
       $43 = ((($$024$i$i5)) + 4|0);
       $44 = HEAP32[$43>>2]|0;
       $45 = ($44|0)==(0|0);
       if ($45) {
        label = 23;
        break;
       } else {
        $$0$ph$i$i3 = $43;$$in$i$i2 = $44;
       }
      }
      $$0$i$i6 = $$0$ph$i$i3;$$024$i$i5 = $$in$i$i2;$183 = $$in$i$i2;
     }
     if ((label|0) == 20) {
      $$025$i53$i10 = $$024$i$i5;$$03752$i11 = $$024$i$i5;
      label = 26;
      break;
     }
     else if ((label|0) == 23) {
      $$025$i53$i10 = $43;$$03752$i11 = $$024$i$i5;
      label = 26;
      break;
     }
     else if ((label|0) == 24) {
      $$025$i$i8 = $$0$i$i6;$$037$i7 = $$024$i$i5;$46 = $183;
      label = 25;
      break;
     }
    }
   } while(0);
   if ((label|0) == 25) {
    $47 = ($46|0)==(0|0);
    if ($47) {
     $$025$i53$i10 = $$025$i$i8;$$03752$i11 = $$037$i7;
     label = 26;
    } else {
     $$014$i15 = $46;
    }
   }
   if ((label|0) == 26) {
    __THREW__ = 0;
    $48 = (invoke_ii(3276,24)|0);
    $49 = __THREW__; __THREW__ = 0;
    $50 = $49&1;
    if ($50) {
     break;
    }
    $51 = ((($48)) + 16|0);
    HEAP32[$51>>2] = $0;
    $52 = ((($48)) + 20|0);
    HEAP32[$52>>2] = 0;
    HEAP32[$48>>2] = 0;
    $53 = ((($48)) + 4|0);
    HEAP32[$53>>2] = 0;
    $54 = ((($48)) + 8|0);
    HEAP32[$54>>2] = $$03752$i11;
    HEAP32[$$025$i53$i10>>2] = $48;
    $55 = HEAP32[52026]|0;
    $56 = HEAP32[$55>>2]|0;
    $57 = ($56|0)==(0|0);
    if ($57) {
     $60 = $48;
    } else {
     $58 = $56;
     HEAP32[52026] = $58;
     $$pre$i$i13 = HEAP32[$$025$i53$i10>>2]|0;
     $60 = $$pre$i$i13;
    }
    $59 = HEAP32[(208108)>>2]|0;
    __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($59,$60);
    $61 = HEAP32[(208112)>>2]|0;
    $62 = (($61) + 1)|0;
    HEAP32[(208112)>>2] = $62;
    $$014$i15 = $48;
   }
   $63 = ((($$014$i15)) + 20|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = ((($64)) + 28|0);
   $66 = HEAP32[$65>>2]|0;
   $67 = ($66|0)==(0);
   if (!($67)) {
    $68 = HEAP32[(208108)>>2]|0;
    $69 = ($68|0)==(0|0);
    do {
     if ($69) {
      $$025$i$i25 = (208108);$$037$i24 = (208108);$79 = $68;
      label = 40;
     } else {
      $$0$i$i23 = (208108);$$024$i$i22 = $68;$184 = $68;
      while(1) {
       $70 = ((($$024$i$i22)) + 16|0);
       $71 = HEAP32[$70>>2]|0;
       $72 = ($71>>>0)>($0>>>0);
       if ($72) {
        $73 = HEAP32[$$024$i$i22>>2]|0;
        $74 = ($73|0)==(0|0);
        if ($74) {
         label = 35;
         break;
        } else {
         $$0$ph$i$i20 = $$024$i$i22;$$in$i$i19 = $73;
        }
       } else {
        $75 = ($71>>>0)<($0>>>0);
        if (!($75)) {
         label = 39;
         break;
        }
        $76 = ((($$024$i$i22)) + 4|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = ($77|0)==(0|0);
        if ($78) {
         label = 38;
         break;
        } else {
         $$0$ph$i$i20 = $76;$$in$i$i19 = $77;
        }
       }
       $$0$i$i23 = $$0$ph$i$i20;$$024$i$i22 = $$in$i$i19;$184 = $$in$i$i19;
      }
      if ((label|0) == 35) {
       $$025$i53$i27 = $$024$i$i22;$$03752$i28 = $$024$i$i22;
       label = 41;
       break;
      }
      else if ((label|0) == 38) {
       $$025$i53$i27 = $76;$$03752$i28 = $$024$i$i22;
       label = 41;
       break;
      }
      else if ((label|0) == 39) {
       $$025$i$i25 = $$0$i$i23;$$037$i24 = $$024$i$i22;$79 = $184;
       label = 40;
       break;
      }
     }
    } while(0);
    if ((label|0) == 40) {
     $80 = ($79|0)==(0|0);
     if ($80) {
      $$025$i53$i27 = $$025$i$i25;$$03752$i28 = $$037$i24;
      label = 41;
     } else {
      $$014$i32 = $79;
     }
    }
    if ((label|0) == 41) {
     __THREW__ = 0;
     $81 = (invoke_ii(3276,24)|0);
     $82 = __THREW__; __THREW__ = 0;
     $83 = $82&1;
     if ($83) {
      break;
     }
     $84 = ((($81)) + 16|0);
     HEAP32[$84>>2] = $0;
     $85 = ((($81)) + 20|0);
     HEAP32[$85>>2] = 0;
     HEAP32[$81>>2] = 0;
     $86 = ((($81)) + 4|0);
     HEAP32[$86>>2] = 0;
     $87 = ((($81)) + 8|0);
     HEAP32[$87>>2] = $$03752$i28;
     HEAP32[$$025$i53$i27>>2] = $81;
     $88 = HEAP32[52026]|0;
     $89 = HEAP32[$88>>2]|0;
     $90 = ($89|0)==(0|0);
     if ($90) {
      $93 = $81;
     } else {
      $91 = $89;
      HEAP32[52026] = $91;
      $$pre$i$i30 = HEAP32[$$025$i53$i27>>2]|0;
      $93 = $$pre$i$i30;
     }
     $92 = HEAP32[(208108)>>2]|0;
     __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($92,$93);
     $94 = HEAP32[(208112)>>2]|0;
     $95 = (($94) + 1)|0;
     HEAP32[(208112)>>2] = $95;
     $$014$i32 = $81;
    }
    $96 = ((($$014$i32)) + 20|0);
    $97 = HEAP32[$96>>2]|0;
    $98 = ((($97)) + 28|0);
    $99 = HEAP32[$98>>2]|0;
    $100 = (($99) + -1)|0;
    HEAP32[$98>>2] = $100;
   }
   $108 = HEAP32[(208108)>>2]|0;
   $109 = ($108|0)==(0|0);
   do {
    if ($109) {
     $$025$i$i43 = (208108);$$037$i42 = (208108);$119 = $108;
     label = 56;
    } else {
     $$0$i$i41 = (208108);$$024$i$i40 = $108;$185 = $108;
     while(1) {
      $110 = ((($$024$i$i40)) + 16|0);
      $111 = HEAP32[$110>>2]|0;
      $112 = ($111>>>0)>($0>>>0);
      if ($112) {
       $113 = HEAP32[$$024$i$i40>>2]|0;
       $114 = ($113|0)==(0|0);
       if ($114) {
        label = 51;
        break;
       } else {
        $$0$ph$i$i38 = $$024$i$i40;$$in$i$i37 = $113;
       }
      } else {
       $115 = ($111>>>0)<($0>>>0);
       if (!($115)) {
        label = 55;
        break;
       }
       $116 = ((($$024$i$i40)) + 4|0);
       $117 = HEAP32[$116>>2]|0;
       $118 = ($117|0)==(0|0);
       if ($118) {
        label = 54;
        break;
       } else {
        $$0$ph$i$i38 = $116;$$in$i$i37 = $117;
       }
      }
      $$0$i$i41 = $$0$ph$i$i38;$$024$i$i40 = $$in$i$i37;$185 = $$in$i$i37;
     }
     if ((label|0) == 51) {
      $$025$i53$i45 = $$024$i$i40;$$03752$i46 = $$024$i$i40;
      label = 57;
      break;
     }
     else if ((label|0) == 54) {
      $$025$i53$i45 = $116;$$03752$i46 = $$024$i$i40;
      label = 57;
      break;
     }
     else if ((label|0) == 55) {
      $$025$i$i43 = $$0$i$i41;$$037$i42 = $$024$i$i40;$119 = $185;
      label = 56;
      break;
     }
    }
   } while(0);
   if ((label|0) == 56) {
    $120 = ($119|0)==(0|0);
    if ($120) {
     $$025$i53$i45 = $$025$i$i43;$$03752$i46 = $$037$i42;
     label = 57;
    } else {
     $$014$i50 = $119;
    }
   }
   if ((label|0) == 57) {
    __THREW__ = 0;
    $121 = (invoke_ii(3276,24)|0);
    $122 = __THREW__; __THREW__ = 0;
    $123 = $122&1;
    if ($123) {
     break;
    }
    $124 = ((($121)) + 16|0);
    HEAP32[$124>>2] = $0;
    $125 = ((($121)) + 20|0);
    HEAP32[$125>>2] = 0;
    HEAP32[$121>>2] = 0;
    $126 = ((($121)) + 4|0);
    HEAP32[$126>>2] = 0;
    $127 = ((($121)) + 8|0);
    HEAP32[$127>>2] = $$03752$i46;
    HEAP32[$$025$i53$i45>>2] = $121;
    $128 = HEAP32[52026]|0;
    $129 = HEAP32[$128>>2]|0;
    $130 = ($129|0)==(0|0);
    if ($130) {
     $133 = $121;
    } else {
     $131 = $129;
     HEAP32[52026] = $131;
     $$pre$i$i48 = HEAP32[$$025$i53$i45>>2]|0;
     $133 = $$pre$i$i48;
    }
    $132 = HEAP32[(208108)>>2]|0;
    __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($132,$133);
    $134 = HEAP32[(208112)>>2]|0;
    $135 = (($134) + 1)|0;
    HEAP32[(208112)>>2] = $135;
    $$014$i50 = $121;
   }
   $136 = ((($$014$i50)) + 20|0);
   $137 = HEAP32[$136>>2]|0;
   $138 = ((($137)) + 28|0);
   $139 = HEAP32[$138>>2]|0;
   $140 = ($139|0)==(0);
   if (!($140)) {
    $177 = HEAP32[52029]|0;
    $178 = ((($177)) + 12|0);
    $179 = HEAP32[$178>>2]|0;
    (FUNCTION_TABLE_ii[$179 & 8191](208116)|0);
    return;
   }
   $141 = HEAP32[(208108)>>2]|0;
   $142 = ($141|0)==(0|0);
   do {
    if ($142) {
     $$025$i$i61 = (208108);$$037$i60 = (208108);$152 = $141;
     label = 71;
    } else {
     $$0$i$i59 = (208108);$$024$i$i58 = $141;$186 = $141;
     while(1) {
      $143 = ((($$024$i$i58)) + 16|0);
      $144 = HEAP32[$143>>2]|0;
      $145 = ($144>>>0)>($0>>>0);
      if ($145) {
       $146 = HEAP32[$$024$i$i58>>2]|0;
       $147 = ($146|0)==(0|0);
       if ($147) {
        label = 66;
        break;
       } else {
        $$0$ph$i$i56 = $$024$i$i58;$$in$i$i55 = $146;
       }
      } else {
       $148 = ($144>>>0)<($0>>>0);
       if (!($148)) {
        label = 70;
        break;
       }
       $149 = ((($$024$i$i58)) + 4|0);
       $150 = HEAP32[$149>>2]|0;
       $151 = ($150|0)==(0|0);
       if ($151) {
        label = 69;
        break;
       } else {
        $$0$ph$i$i56 = $149;$$in$i$i55 = $150;
       }
      }
      $$0$i$i59 = $$0$ph$i$i56;$$024$i$i58 = $$in$i$i55;$186 = $$in$i$i55;
     }
     if ((label|0) == 66) {
      $$025$i53$i63 = $$024$i$i58;$$03752$i64 = $$024$i$i58;
      label = 72;
      break;
     }
     else if ((label|0) == 69) {
      $$025$i53$i63 = $149;$$03752$i64 = $$024$i$i58;
      label = 72;
      break;
     }
     else if ((label|0) == 70) {
      $$025$i$i61 = $$0$i$i59;$$037$i60 = $$024$i$i58;$152 = $186;
      label = 71;
      break;
     }
    }
   } while(0);
   if ((label|0) == 71) {
    $153 = ($152|0)==(0|0);
    if ($153) {
     $$025$i53$i63 = $$025$i$i61;$$03752$i64 = $$037$i60;
     label = 72;
    } else {
     $$014$i68 = $152;
    }
   }
   if ((label|0) == 72) {
    __THREW__ = 0;
    $154 = (invoke_ii(3276,24)|0);
    $155 = __THREW__; __THREW__ = 0;
    $156 = $155&1;
    if ($156) {
     break;
    }
    $157 = ((($154)) + 16|0);
    HEAP32[$157>>2] = $0;
    $158 = ((($154)) + 20|0);
    HEAP32[$158>>2] = 0;
    HEAP32[$154>>2] = 0;
    $159 = ((($154)) + 4|0);
    HEAP32[$159>>2] = 0;
    $160 = ((($154)) + 8|0);
    HEAP32[$160>>2] = $$03752$i64;
    HEAP32[$$025$i53$i63>>2] = $154;
    $161 = HEAP32[52026]|0;
    $162 = HEAP32[$161>>2]|0;
    $163 = ($162|0)==(0|0);
    if ($163) {
     $166 = $154;
    } else {
     $164 = $162;
     HEAP32[52026] = $164;
     $$pre$i$i66 = HEAP32[$$025$i53$i63>>2]|0;
     $166 = $$pre$i$i66;
    }
    $165 = HEAP32[(208108)>>2]|0;
    __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($165,$166);
    $167 = HEAP32[(208112)>>2]|0;
    $168 = (($167) + 1)|0;
    HEAP32[(208112)>>2] = $168;
    $$014$i68 = $154;
   }
   $169 = ((($$014$i68)) + 20|0);
   $170 = HEAP32[$169>>2]|0;
   $171 = ($170|0)==(0|0);
   if ($171) {
    $177 = HEAP32[52029]|0;
    $178 = ((($177)) + 12|0);
    $179 = HEAP32[$178>>2]|0;
    (FUNCTION_TABLE_ii[$179 & 8191](208116)|0);
    return;
   }
   HEAP32[$169>>2] = 0;
   $172 = ((($170)) + 8|0);
   $173 = HEAP32[$172>>2]|0;HEAP32[$172>>2] = (($173-1)|0);
   $174 = ($173|0)==(1);
   if (!($174)) {
    $177 = HEAP32[52029]|0;
    $178 = ((($177)) + 12|0);
    $179 = HEAP32[$178>>2]|0;
    (FUNCTION_TABLE_ii[$179 & 8191](208116)|0);
    return;
   }
   __THREW__ = 0;
   invoke_viii(3262,($170|0),1,1);
   $175 = __THREW__; __THREW__ = 0;
   $176 = $175&1;
   if (!($176)) {
    $177 = HEAP32[52029]|0;
    $178 = ((($177)) + 12|0);
    $179 = HEAP32[$178>>2]|0;
    (FUNCTION_TABLE_ii[$179 & 8191](208116)|0);
    return;
   }
  }
 } while(0);
 $101 = ___cxa_find_matching_catch_2()|0;
 $102 = tempRet0;
 $103 = HEAP32[52029]|0;
 $104 = ((($103)) + 12|0);
 $105 = HEAP32[$104>>2]|0;
 __THREW__ = 0;
 (invoke_ii($105|0,(208116|0))|0);
 $106 = __THREW__; __THREW__ = 0;
 $107 = $106&1;
 if ($107) {
  $180 = ___cxa_find_matching_catch_3(0|0)|0;
  $181 = tempRet0;
  ___clang_call_terminate($180);
  // unreachable;
 } else {
  ___resumeException($101|0);
  // unreachable;
 }
}
function __ZN3osg11ContextData23registerGraphicsContextEPNS_15GraphicsContextE($0) {
 $0 = $0|0;
 var $$pre = 0, $$pre$i = 0, $$sroa$0$0$copyload$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i = 0, $scevgep5$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp + 4|0;
 $2 = sp;
 HEAP32[$2>>2] = $0;
 $3 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
 do {
  if ($3) {
   $4 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
   $5 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($4,120775,37)|0);
   $6 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEPKv($5,$0)|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ((($7)) + -12|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($6) + ($9)|0);
   __ZNKSt3__28ios_base6getlocEv($1,$10);
   __THREW__ = 0;
   $11 = (invoke_iii(3255,($1|0),(215188|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[$11>>2]|0;
    $15 = ((($14)) + 28|0);
    $16 = HEAP32[$15>>2]|0;
    __THREW__ = 0;
    $17 = (invoke_iii($16|0,($11|0),10)|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     __ZNSt3__26localeD2Ev($1);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($6,$17)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($6)|0);
     $$pre = HEAP32[$2>>2]|0;
     $26 = $$pre;
     break;
    }
   }
   $20 = ___cxa_find_matching_catch_2()|0;
   $21 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($1|0));
   $22 = __THREW__; __THREW__ = 0;
   $23 = $22&1;
   if ($23) {
    $24 = ___cxa_find_matching_catch_3(0|0)|0;
    $25 = tempRet0;
    ___clang_call_terminate($24);
    // unreachable;
   } else {
    ___resumeException($20|0);
    // unreachable;
   }
  } else {
   $26 = $0;
  }
 } while(0);
 $27 = ($26|0)==(0|0);
 if ($27) {
  STACKTOP = sp;return;
 }
 $28 = HEAP32[52029]|0;
 $29 = ((($28)) + 8|0);
 $30 = HEAP32[$29>>2]|0;
 (FUNCTION_TABLE_ii[$30 & 8191](208116)|0);
 $31 = HEAP32[52032]|0;
 $32 = HEAP32[(208132)>>2]|0;
 $33 = ($31|0)==($32|0);
 $34 = $32;
 L14: do {
  if ($33) {
   $$sroa$0$0$copyload$i = $31;
   label = 12;
  } else {
   $36 = $31;
   while(1) {
    $35 = HEAP32[$36>>2]|0;
    $37 = ($35|0)==($26|0);
    if ($37) {
     $$sroa$0$0$copyload$i = $36;
     label = 12;
     break L14;
    }
    $38 = ((($36)) + 4|0);
    $39 = ($38|0)==($32|0);
    if ($39) {
     $62 = $32;
     break;
    } else {
     $36 = $38;
    }
   }
  }
 } while(0);
 if ((label|0) == 12) {
  $40 = ($$sroa$0$0$copyload$i|0)==($32|0);
  if ($40) {
   $62 = $32;
  } else {
   $41 = ((($$sroa$0$0$copyload$i)) + 4|0);
   $42 = $41;
   $43 = (($34) - ($42))|0;
   $44 = $43 >> 2;
   $45 = ($44|0)==(0);
   if ($45) {
    $47 = $32;
   } else {
    _memmove(($$sroa$0$0$copyload$i|0),($41|0),($43|0))|0;
    $$pre$i = HEAP32[(208132)>>2]|0;
    $47 = $$pre$i;
   }
   $46 = (($$sroa$0$0$copyload$i) + ($44<<2)|0);
   $48 = ($47|0)==($46|0);
   if ($48) {
    $62 = $47;
   } else {
    $scevgep$i$i$i = ((($47)) + -4|0);
    $49 = $scevgep$i$i$i;
    $50 = $46;
    $51 = (($49) - ($50))|0;
    $52 = $51 >>> 2;
    $53 = $52 ^ -1;
    $scevgep5$i$i$i = (($47) + ($53<<2)|0);
    HEAP32[(208132)>>2] = $scevgep5$i$i$i;
    $62 = $scevgep5$i$i$i;
   }
  }
 }
 $61 = HEAP32[(208136)>>2]|0;
 $63 = ($62|0)==($61|0);
 if ($63) {
  __THREW__ = 0;
  invoke_vii(3401,(208128|0),($2|0));
  $67 = __THREW__; __THREW__ = 0;
  $68 = $67&1;
  if ($68) {
   $54 = ___cxa_find_matching_catch_2()|0;
   $55 = tempRet0;
   $56 = HEAP32[52029]|0;
   $57 = ((($56)) + 12|0);
   $58 = HEAP32[$57>>2]|0;
   __THREW__ = 0;
   (invoke_ii($58|0,(208116|0))|0);
   $59 = __THREW__; __THREW__ = 0;
   $60 = $59&1;
   if ($60) {
    $72 = ___cxa_find_matching_catch_3(0|0)|0;
    $73 = tempRet0;
    ___clang_call_terminate($72);
    // unreachable;
   } else {
    ___resumeException($54|0);
    // unreachable;
   }
  }
 } else {
  $64 = HEAP32[$2>>2]|0;
  HEAP32[$62>>2] = $64;
  $65 = HEAP32[(208132)>>2]|0;
  $66 = ((($65)) + 4|0);
  HEAP32[(208132)>>2] = $66;
 }
 $69 = HEAP32[52029]|0;
 $70 = ((($69)) + 12|0);
 $71 = HEAP32[$70>>2]|0;
 (FUNCTION_TABLE_ii[$71 & 8191](208116)|0);
 STACKTOP = sp;return;
}
function __ZN3osg11ContextData25unregisterGraphicsContextEPNS_15GraphicsContextE($0) {
 $0 = $0|0;
 var $$pre$i = 0, $$sroa$0$0$copyload$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i = 0, $scevgep5$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $2 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
 do {
  if ($2) {
   $3 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
   $4 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($3,120813,39)|0);
   $5 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEPKv($4,$0)|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ((($6)) + -12|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($5) + ($8)|0);
   __ZNKSt3__28ios_base6getlocEv($1,$9);
   __THREW__ = 0;
   $10 = (invoke_iii(3255,($1|0),(215188|0))|0);
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if (!($12)) {
    $13 = HEAP32[$10>>2]|0;
    $14 = ((($13)) + 28|0);
    $15 = HEAP32[$14>>2]|0;
    __THREW__ = 0;
    $16 = (invoke_iii($15|0,($10|0),10)|0);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if (!($18)) {
     __ZNSt3__26localeD2Ev($1);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($5,$16)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($5)|0);
     break;
    }
   }
   $19 = ___cxa_find_matching_catch_2()|0;
   $20 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($1|0));
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if ($22) {
    $23 = ___cxa_find_matching_catch_3(0|0)|0;
    $24 = tempRet0;
    ___clang_call_terminate($23);
    // unreachable;
   } else {
    ___resumeException($19|0);
    // unreachable;
   }
  }
 } while(0);
 $25 = ($0|0)==(0|0);
 if ($25) {
  STACKTOP = sp;return;
 }
 $26 = HEAP32[52029]|0;
 $27 = ((($26)) + 8|0);
 $28 = HEAP32[$27>>2]|0;
 (FUNCTION_TABLE_ii[$28 & 8191](208116)|0);
 $29 = HEAP32[52032]|0;
 $30 = HEAP32[(208132)>>2]|0;
 $31 = ($29|0)==($30|0);
 $32 = $30;
 L14: do {
  if ($31) {
   $$sroa$0$0$copyload$i = $29;
   label = 12;
  } else {
   $34 = $29;
   while(1) {
    $33 = HEAP32[$34>>2]|0;
    $35 = ($33|0)==($0|0);
    if ($35) {
     $$sroa$0$0$copyload$i = $34;
     label = 12;
     break L14;
    }
    $36 = ((($34)) + 4|0);
    $37 = ($36|0)==($30|0);
    if ($37) {
     break;
    } else {
     $34 = $36;
    }
   }
  }
 } while(0);
 if ((label|0) == 12) {
  $38 = ($$sroa$0$0$copyload$i|0)==($30|0);
  if (!($38)) {
   $39 = ((($$sroa$0$0$copyload$i)) + 4|0);
   $40 = $39;
   $41 = (($32) - ($40))|0;
   $42 = $41 >> 2;
   $43 = ($42|0)==(0);
   if ($43) {
    $45 = $30;
   } else {
    _memmove(($$sroa$0$0$copyload$i|0),($39|0),($41|0))|0;
    $$pre$i = HEAP32[(208132)>>2]|0;
    $45 = $$pre$i;
   }
   $44 = (($$sroa$0$0$copyload$i) + ($42<<2)|0);
   $46 = ($45|0)==($44|0);
   if (!($46)) {
    $scevgep$i$i$i = ((($45)) + -4|0);
    $47 = $scevgep$i$i$i;
    $48 = $44;
    $49 = (($47) - ($48))|0;
    $50 = $49 >>> 2;
    $51 = $50 ^ -1;
    $scevgep5$i$i$i = (($45) + ($51<<2)|0);
    HEAP32[(208132)>>2] = $scevgep5$i$i$i;
   }
  }
 }
 $52 = HEAP32[52029]|0;
 $53 = ((($52)) + 12|0);
 $54 = HEAP32[$53>>2]|0;
 (FUNCTION_TABLE_ii[$54 & 8191](208116)|0);
 STACKTOP = sp;return;
}
function __ZN3osg11ContextData29getRegisteredGraphicsContextsEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$04 = 0, $$2 = 0, $$26 = 0, $$sroa$016$025 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, $scevgep$i$i$i = 0, $scevgep5$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp + 4|0;
 $3 = sp;
 HEAP32[$0>>2] = 0;
 $4 = ((($0)) + 4|0);
 HEAP32[$4>>2] = 0;
 $5 = ((($0)) + 8|0);
 HEAP32[$5>>2] = 0;
 $6 = HEAP32[52029]|0;
 $7 = ((($6)) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 __THREW__ = 0;
 (invoke_ii($8|0,(208116|0))|0);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 L1: do {
  if ($10) {
   $18 = ___cxa_find_matching_catch_2()|0;
   $19 = tempRet0;
   $$2 = $19;$$26 = $18;
  } else {
   $11 = HEAP32[52032]|0;
   $12 = HEAP32[(208132)>>2]|0;
   $13 = ($11|0)==($12|0);
   L4: do {
    if ($13) {
     label = 4;
    } else {
     $14 = ((($0)) + 8|0);
     $$sroa$016$025 = $11;
     L6: while(1) {
      $20 = HEAP32[$$sroa$016$025>>2]|0;
      HEAP32[$3>>2] = $20;
      $21 = ((($20)) + 48|0);
      $22 = HEAP32[$21>>2]|0;
      $23 = ($22|0)==(0|0);
      $24 = $20;
      do {
       if (!($23)) {
        $25 = ((($22)) + 124|0);
        $26 = HEAP32[$25>>2]|0;
        $27 = ($26|0)==($1|0);
        if ($27) {
         $28 = HEAP32[$4>>2]|0;
         $29 = HEAP32[$14>>2]|0;
         $30 = ($28|0)==($29|0);
         if ($30) {
          __THREW__ = 0;
          invoke_vii(3401,($0|0),($3|0));
          $33 = __THREW__; __THREW__ = 0;
          $34 = $33&1;
          if ($34) {
           break L6;
          } else {
           break;
          }
         } else {
          HEAP32[$28>>2] = $24;
          $31 = HEAP32[$4>>2]|0;
          $32 = ((($31)) + 4|0);
          HEAP32[$4>>2] = $32;
          break;
         }
        }
       }
      } while(0);
      $37 = ((($$sroa$016$025)) + 4|0);
      $38 = HEAP32[(208132)>>2]|0;
      $39 = ($37|0)==($38|0);
      if ($39) {
       label = 4;
       break L4;
      } else {
       $$sroa$016$025 = $37;
      }
     }
     $35 = ___cxa_find_matching_catch_2()|0;
     $36 = tempRet0;
     $$0 = $36;$$04 = $35;
    }
   } while(0);
   if ((label|0) == 4) {
    __THREW__ = 0;
    $15 = (invoke_ii(3265,4)|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    L18: do {
     if ($17) {
      label = 28;
     } else {
      do {
       if ($15) {
        __THREW__ = 0;
        $40 = (invoke_ii(3266,4)|0);
        $41 = __THREW__; __THREW__ = 0;
        $42 = $41&1;
        if ($42) {
         label = 28;
         break L18;
        }
        __THREW__ = 0;
        $43 = (invoke_iiii(3267,($40|0),(120853|0),43)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if ($45) {
         label = 28;
         break L18;
        }
        __THREW__ = 0;
        $46 = (invoke_iii(3417,($43|0),($1|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 28;
         break L18;
        }
        __THREW__ = 0;
        $49 = (invoke_iiii(3267,($46|0),(120897|0),17)|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 28;
         break L18;
        }
        $52 = HEAP32[$4>>2]|0;
        $53 = HEAP32[$0>>2]|0;
        $54 = (($52) - ($53))|0;
        $55 = $54 >> 2;
        __THREW__ = 0;
        $56 = (invoke_iii(3417,($49|0),($55|0))|0);
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 28;
         break L18;
        }
        $59 = HEAP32[$56>>2]|0;
        $60 = ((($59)) + -12|0);
        $61 = HEAP32[$60>>2]|0;
        $62 = (($56) + ($61)|0);
        __THREW__ = 0;
        invoke_vii(3257,($2|0),($62|0));
        $63 = __THREW__; __THREW__ = 0;
        $64 = $63&1;
        if ($64) {
         label = 28;
         break L18;
        }
        __THREW__ = 0;
        $65 = (invoke_iii(3255,($2|0),(215188|0))|0);
        $66 = __THREW__; __THREW__ = 0;
        $67 = $66&1;
        if (!($67)) {
         $68 = HEAP32[$65>>2]|0;
         $69 = ((($68)) + 28|0);
         $70 = HEAP32[$69>>2]|0;
         __THREW__ = 0;
         $71 = (invoke_iii($70|0,($65|0),10)|0);
         $72 = __THREW__; __THREW__ = 0;
         $73 = $72&1;
         if (!($73)) {
          __THREW__ = 0;
          invoke_vi(3263,($2|0));
          $80 = __THREW__; __THREW__ = 0;
          $81 = $80&1;
          if ($81) {
           label = 28;
           break L18;
          }
          __THREW__ = 0;
          (invoke_iii(3268,($56|0),($71|0))|0);
          $82 = __THREW__; __THREW__ = 0;
          $83 = $82&1;
          if ($83) {
           label = 28;
           break L18;
          }
          __THREW__ = 0;
          (invoke_ii(3269,($56|0))|0);
          $84 = __THREW__; __THREW__ = 0;
          $85 = $84&1;
          if ($85) {
           label = 28;
           break L18;
          } else {
           break;
          }
         }
        }
        $74 = ___cxa_find_matching_catch_2()|0;
        $75 = tempRet0;
        __THREW__ = 0;
        invoke_vi(3263,($2|0));
        $76 = __THREW__; __THREW__ = 0;
        $77 = $76&1;
        if ($77) {
         $78 = ___cxa_find_matching_catch_3(0|0)|0;
         $79 = tempRet0;
         ___clang_call_terminate($78);
         // unreachable;
        } else {
         $eh$lpad$body$index2Z2D = $75;$eh$lpad$body$indexZ2D = $74;
         break L18;
        }
       }
      } while(0);
      $88 = HEAP32[52029]|0;
      $89 = ((($88)) + 12|0);
      $90 = HEAP32[$89>>2]|0;
      __THREW__ = 0;
      (invoke_ii($90|0,(208116|0))|0);
      $91 = __THREW__; __THREW__ = 0;
      $92 = $91&1;
      if ($92) {
       $93 = ___cxa_find_matching_catch_2()|0;
       $94 = tempRet0;
       $$2 = $94;$$26 = $93;
       break L1;
      } else {
       STACKTOP = sp;return;
      }
     }
    } while(0);
    if ((label|0) == 28) {
     $86 = ___cxa_find_matching_catch_2()|0;
     $87 = tempRet0;
     $eh$lpad$body$index2Z2D = $87;$eh$lpad$body$indexZ2D = $86;
    }
    $$0 = $eh$lpad$body$index2Z2D;$$04 = $eh$lpad$body$indexZ2D;
   }
   $95 = HEAP32[52029]|0;
   $96 = ((($95)) + 12|0);
   $97 = HEAP32[$96>>2]|0;
   __THREW__ = 0;
   (invoke_ii($97|0,(208116|0))|0);
   $98 = __THREW__; __THREW__ = 0;
   $99 = $98&1;
   if ($99) {
    $109 = ___cxa_find_matching_catch_3(0|0)|0;
    $110 = tempRet0;
    ___clang_call_terminate($109);
    // unreachable;
   } else {
    $$2 = $$0;$$26 = $$04;
   }
  }
 } while(0);
 $100 = HEAP32[$0>>2]|0;
 $101 = ($100|0)==(0|0);
 if ($101) {
  ___resumeException($$26|0);
  // unreachable;
 }
 $102 = HEAP32[$4>>2]|0;
 $103 = ($102|0)==($100|0);
 if (!($103)) {
  $scevgep$i$i$i = ((($102)) + -4|0);
  $104 = $scevgep$i$i$i;
  $105 = $100;
  $106 = (($104) - ($105))|0;
  $107 = $106 >>> 2;
  $108 = $107 ^ -1;
  $scevgep5$i$i$i = (($102) + ($108<<2)|0);
  HEAP32[$4>>2] = $scevgep5$i$i$i;
 }
 __ZdlPv($100);
 ___resumeException($$26|0);
 // unreachable;
}
function __ZN3osg11ContextData25getOrCreateCompileContextEj($0) {
 $0 = $0|0;
 var $$$i = 0, $$0 = 0, $$0$i$i = 0, $$0$i$i51 = 0, $$0$i$i72 = 0, $$0$ph$i$i = 0, $$0$ph$i$i48 = 0, $$0$ph$i$i69 = 0, $$014$i = 0, $$014$i60 = 0, $$014$i81 = 0, $$024$i$i = 0, $$024$i$i50 = 0, $$024$i$i71 = 0, $$025$i$i = 0, $$025$i$i53 = 0, $$025$i$i74 = 0, $$025$i53$i = 0, $$025$i53$i55 = 0, $$025$i53$i76 = 0;
 var $$037$i = 0, $$037$i52 = 0, $$037$i73 = 0, $$03752$i = 0, $$03752$i56 = 0, $$03752$i77 = 0, $$045 = 0, $$135132 = 0, $$139131 = 0, $$2 = 0, $$2$ph = 0, $$3 = 0, $$5 = 0, $$543 = 0, $$6 = 0, $$644 = 0, $$in$i$i = 0, $$in$i$i47 = 0, $$in$i$i68 = 0, $$pr = 0;
 var $$pr$i = 0, $$pre$i$i = 0, $$pre$i$i58 = 0, $$pre$i$i79 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0;
 var $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0;
 var $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0;
 var $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0;
 var $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0;
 var $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0;
 var $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0;
 var $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0;
 var $311 = 0, $312 = 0, $313 = 0, $314 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0;
 var $scevgep$i$i$i = 0, $scevgep$i$i$i100 = 0, $scevgep5$i$i$i = 0, $scevgep5$i$i$i101 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $1 = sp + 16|0;
 $2 = sp + 12|0;
 $3 = sp;
 $4 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
 do {
  if ($4) {
   $5 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
   $6 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($5,120915,34)|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ((($7)) + -12|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($6) + ($9)|0);
   __ZNKSt3__28ios_base6getlocEv($2,$10);
   __THREW__ = 0;
   $11 = (invoke_iii(3255,($2|0),(215188|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[$11>>2]|0;
    $15 = ((($14)) + 28|0);
    $16 = HEAP32[$15>>2]|0;
    __THREW__ = 0;
    $17 = (invoke_iii($16|0,($11|0),10)|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     __ZNSt3__26localeD2Ev($2);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($6,$17)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($6)|0);
     break;
    }
   }
   $20 = ___cxa_find_matching_catch_2()|0;
   $21 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($2|0));
   $22 = __THREW__; __THREW__ = 0;
   $23 = $22&1;
   if ($23) {
    $24 = ___cxa_find_matching_catch_3(0|0)|0;
    $25 = tempRet0;
    ___clang_call_terminate($24);
    // unreachable;
   } else {
    ___resumeException($20|0);
    // unreachable;
   }
  }
 } while(0);
 $26 = HEAP32[52029]|0;
 $27 = ((($26)) + 8|0);
 $28 = HEAP32[$27>>2]|0;
 (FUNCTION_TABLE_ii[$28 & 8191](208116)|0);
 $29 = HEAP32[(208108)>>2]|0;
 $30 = ($29|0)==(0|0);
 do {
  if ($30) {
   $$025$i$i = (208108);$$037$i = (208108);$40 = $29;
   label = 17;
  } else {
   $$0$i$i = (208108);$$024$i$i = $29;$312 = $29;
   while(1) {
    $31 = ((($$024$i$i)) + 16|0);
    $32 = HEAP32[$31>>2]|0;
    $33 = ($32>>>0)>($0>>>0);
    if ($33) {
     $34 = HEAP32[$$024$i$i>>2]|0;
     $35 = ($34|0)==(0|0);
     if ($35) {
      label = 12;
      break;
     } else {
      $$0$ph$i$i = $$024$i$i;$$in$i$i = $34;
     }
    } else {
     $36 = ($32>>>0)<($0>>>0);
     if (!($36)) {
      label = 16;
      break;
     }
     $37 = ((($$024$i$i)) + 4|0);
     $38 = HEAP32[$37>>2]|0;
     $39 = ($38|0)==(0|0);
     if ($39) {
      label = 15;
      break;
     } else {
      $$0$ph$i$i = $37;$$in$i$i = $38;
     }
    }
    $$0$i$i = $$0$ph$i$i;$$024$i$i = $$in$i$i;$312 = $$in$i$i;
   }
   if ((label|0) == 12) {
    $$025$i53$i = $$024$i$i;$$03752$i = $$024$i$i;
    label = 18;
    break;
   }
   else if ((label|0) == 15) {
    $$025$i53$i = $37;$$03752$i = $$024$i$i;
    label = 18;
    break;
   }
   else if ((label|0) == 16) {
    $$025$i$i = $$0$i$i;$$037$i = $$024$i$i;$40 = $312;
    label = 17;
    break;
   }
  }
 } while(0);
 if ((label|0) == 17) {
  $41 = ($40|0)==(0|0);
  if ($41) {
   $$025$i53$i = $$025$i$i;$$03752$i = $$037$i;
   label = 18;
  } else {
   $$014$i = $40;
   label = 22;
  }
 }
 if ((label|0) == 18) {
  __THREW__ = 0;
  $42 = (invoke_ii(3276,24)|0);
  $43 = __THREW__; __THREW__ = 0;
  $44 = $43&1;
  if (!($44)) {
   $45 = ((($42)) + 16|0);
   HEAP32[$45>>2] = $0;
   $46 = ((($42)) + 20|0);
   HEAP32[$46>>2] = 0;
   HEAP32[$42>>2] = 0;
   $47 = ((($42)) + 4|0);
   HEAP32[$47>>2] = 0;
   $48 = ((($42)) + 8|0);
   HEAP32[$48>>2] = $$03752$i;
   HEAP32[$$025$i53$i>>2] = $42;
   $49 = HEAP32[52026]|0;
   $50 = HEAP32[$49>>2]|0;
   $51 = ($50|0)==(0|0);
   if ($51) {
    $54 = $42;
   } else {
    $52 = $50;
    HEAP32[52026] = $52;
    $$pre$i$i = HEAP32[$$025$i53$i>>2]|0;
    $54 = $$pre$i$i;
   }
   $53 = HEAP32[(208108)>>2]|0;
   __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($53,$54);
   $55 = HEAP32[(208112)>>2]|0;
   $56 = (($55) + 1)|0;
   HEAP32[(208112)>>2] = $56;
   $$014$i = $42;
   label = 22;
  }
 }
 do {
  if ((label|0) == 22) {
   $57 = ((($$014$i)) + 20|0);
   $58 = HEAP32[$57>>2]|0;
   $59 = ((($58)) + 32|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = ($60|0)==(0|0);
   if ($61) {
    $$0 = 0;$$045 = 1;
   } else {
    $62 = HEAP32[(208108)>>2]|0;
    $63 = ($62|0)==(0|0);
    do {
     if ($63) {
      $$025$i$i53 = (208108);$$037$i52 = (208108);$73 = $62;
      label = 32;
     } else {
      $$0$i$i51 = (208108);$$024$i$i50 = $62;$313 = $62;
      while(1) {
       $64 = ((($$024$i$i50)) + 16|0);
       $65 = HEAP32[$64>>2]|0;
       $66 = ($65>>>0)>($0>>>0);
       if ($66) {
        $67 = HEAP32[$$024$i$i50>>2]|0;
        $68 = ($67|0)==(0|0);
        if ($68) {
         label = 27;
         break;
        } else {
         $$0$ph$i$i48 = $$024$i$i50;$$in$i$i47 = $67;
        }
       } else {
        $69 = ($65>>>0)<($0>>>0);
        if (!($69)) {
         label = 31;
         break;
        }
        $70 = ((($$024$i$i50)) + 4|0);
        $71 = HEAP32[$70>>2]|0;
        $72 = ($71|0)==(0|0);
        if ($72) {
         label = 30;
         break;
        } else {
         $$0$ph$i$i48 = $70;$$in$i$i47 = $71;
        }
       }
       $$0$i$i51 = $$0$ph$i$i48;$$024$i$i50 = $$in$i$i47;$313 = $$in$i$i47;
      }
      if ((label|0) == 27) {
       $$025$i53$i55 = $$024$i$i50;$$03752$i56 = $$024$i$i50;
       label = 33;
       break;
      }
      else if ((label|0) == 30) {
       $$025$i53$i55 = $70;$$03752$i56 = $$024$i$i50;
       label = 33;
       break;
      }
      else if ((label|0) == 31) {
       $$025$i$i53 = $$0$i$i51;$$037$i52 = $$024$i$i50;$73 = $313;
       label = 32;
       break;
      }
     }
    } while(0);
    if ((label|0) == 32) {
     $74 = ($73|0)==(0|0);
     if ($74) {
      $$025$i53$i55 = $$025$i$i53;$$03752$i56 = $$037$i52;
      label = 33;
     } else {
      $$014$i60 = $73;
     }
    }
    if ((label|0) == 33) {
     __THREW__ = 0;
     $75 = (invoke_ii(3276,24)|0);
     $76 = __THREW__; __THREW__ = 0;
     $77 = $76&1;
     if ($77) {
      break;
     }
     $78 = ((($75)) + 16|0);
     HEAP32[$78>>2] = $0;
     $79 = ((($75)) + 20|0);
     HEAP32[$79>>2] = 0;
     HEAP32[$75>>2] = 0;
     $80 = ((($75)) + 4|0);
     HEAP32[$80>>2] = 0;
     $81 = ((($75)) + 8|0);
     HEAP32[$81>>2] = $$03752$i56;
     HEAP32[$$025$i53$i55>>2] = $75;
     $82 = HEAP32[52026]|0;
     $83 = HEAP32[$82>>2]|0;
     $84 = ($83|0)==(0|0);
     if ($84) {
      $87 = $75;
     } else {
      $85 = $83;
      HEAP32[52026] = $85;
      $$pre$i$i58 = HEAP32[$$025$i53$i55>>2]|0;
      $87 = $$pre$i$i58;
     }
     $86 = HEAP32[(208108)>>2]|0;
     __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($86,$87);
     $88 = HEAP32[(208112)>>2]|0;
     $89 = (($88) + 1)|0;
     HEAP32[(208112)>>2] = $89;
     $$014$i60 = $75;
    }
    $90 = ((($$014$i60)) + 20|0);
    $91 = HEAP32[$90>>2]|0;
    $92 = ((($91)) + 32|0);
    $93 = HEAP32[$92>>2]|0;
    $$0 = $93;$$045 = 0;
   }
   $101 = HEAP32[52029]|0;
   $102 = ((($101)) + 12|0);
   $103 = HEAP32[$102>>2]|0;
   (FUNCTION_TABLE_ii[$103 & 8191](208116)|0);
   if (!($$045)) {
    $$3 = $$0;
    STACKTOP = sp;return ($$3|0);
   }
   __ZN3osg11ContextData29getRegisteredGraphicsContextsEj($3,$0);
   $104 = HEAP32[$3>>2]|0;
   $105 = ((($3)) + 4|0);
   $106 = HEAP32[$105>>2]|0;
   $107 = ($104|0)==($106|0);
   L60: do {
    if ($107) {
     $$2 = 0;$301 = $104;
    } else {
     $108 = HEAP32[$104>>2]|0;
     $109 = ((($108)) + 44|0);
     $110 = HEAP32[$109>>2]|0;
     __THREW__ = 0;
     $111 = (invoke_ii(3276,200)|0);
     $112 = __THREW__; __THREW__ = 0;
     $113 = $112&1;
     L62: do {
      if ($113) {
       $258 = ___cxa_find_matching_catch_2()|0;
       $259 = tempRet0;
       $$5 = $258;$$543 = $259;
      } else {
       __THREW__ = 0;
       invoke_vii(3419,($111|0),(0|0));
       $114 = __THREW__; __THREW__ = 0;
       $115 = $114&1;
       if ($115) {
        $260 = ___cxa_find_matching_catch_2()|0;
        $261 = tempRet0;
        __ZdlPv($111);
        $$5 = $260;$$543 = $261;
        break;
       }
       $116 = ((($110)) + 28|0);
       $117 = HEAP32[$116>>2]|0;
       $118 = ((($111)) + 12|0);
       $119 = ((($111)) + 28|0);
       HEAP32[$119>>2] = $117;
       $120 = ((($110)) + 24|0);
       $121 = HEAP32[$120>>2]|0;
       $122 = ((($111)) + 24|0);
       HEAP32[$122>>2] = $121;
       $123 = ((($110)) + 12|0);
       __THREW__ = 0;
       (invoke_iii(3477,($118|0),($123|0))|0);
       $124 = __THREW__; __THREW__ = 0;
       $125 = $124&1;
       do {
        if (!($125)) {
         $126 = ((($111)) + 40|0);
         HEAP32[$126>>2] = 100;
         $127 = ((($111)) + 44|0);
         HEAP32[$127>>2] = 100;
         $128 = ((($110)) + 76|0);
         $129 = HEAP32[$128>>2]|0;
         $130 = ((($111)) + 76|0);
         HEAP32[$130>>2] = $129;
         $131 = ((($110)) + 84|0);
         $132 = HEAP32[$131>>2]|0;
         $133 = ((($111)) + 84|0);
         HEAP32[$133>>2] = $132;
         $134 = ((($110)) + 80|0);
         $135 = HEAP32[$134>>2]|0;
         $136 = ((($111)) + 80|0);
         HEAP32[$136>>2] = $135;
         $137 = ((($110)) + 88|0);
         $138 = HEAP32[$137>>2]|0;
         $139 = ((($111)) + 88|0);
         HEAP32[$139>>2] = $138;
         $140 = ((($110)) + 92|0);
         $141 = HEAP32[$140>>2]|0;
         $142 = ((($111)) + 92|0);
         HEAP32[$142>>2] = $141;
         $143 = ((($111)) + 168|0);
         $144 = ($108|0)==(0|0);
         if ($144) {
          $150 = 0;
         } else {
          __THREW__ = 0;
          $145 = (invoke_ii(3325,($108|0))|0);
          $146 = __THREW__; __THREW__ = 0;
          $147 = $146&1;
          if ($147) {
           break;
          } else {
           $150 = $145;
          }
         }
         $148 = HEAP32[$143>>2]|0;
         $149 = ($148|0)==($150|0);
         if ($149) {
          $160 = $150;
         } else {
          HEAP32[$143>>2] = $150;
          $151 = ($150|0)==(0|0);
          if (!($151)) {
           $152 = ((($150)) + 8|0);
           $153 = HEAP32[$152>>2]|0;HEAP32[$152>>2] = (($153+1)|0);
          }
          $154 = ($148|0)==(0|0);
          if (!($154)) {
           $155 = ((($148)) + 8|0);
           $156 = HEAP32[$155>>2]|0;HEAP32[$155>>2] = (($156-1)|0);
           $157 = ($156|0)==(1);
           if ($157) {
            __THREW__ = 0;
            invoke_viii(3262,($148|0),1,1);
            $158 = __THREW__; __THREW__ = 0;
            $159 = $158&1;
            if ($159) {
             break;
            }
           }
          }
          $$pr$i = HEAP32[$143>>2]|0;
          $160 = $$pr$i;
         }
         $161 = ($160|0)==(0|0);
         if ($161) {
          $166 = 0;
         } else {
          $162 = ((($160)) + 24|0);
          $163 = HEAP32[$162>>2]|0;
          $164 = ($163|0)!=(0|0);
          $$$i = $164 ? $108 : 0;
          $166 = $$$i;
         }
         $165 = ((($111)) + 172|0);
         HEAP32[$165>>2] = $166;
         $167 = ((($111)) + 108|0);
         HEAP8[$167>>0] = 1;
         __THREW__ = 0;
         $168 = (invoke_ii(3471,($111|0))|0);
         $169 = __THREW__; __THREW__ = 0;
         $170 = $169&1;
         if (!($170)) {
          $171 = ($168|0)==(0|0);
          L87: do {
           if ($171) {
            $$2$ph = 0;
           } else {
            $172 = ((($168)) + 8|0);
            $173 = HEAP32[$172>>2]|0;HEAP32[$172>>2] = (($173+1)|0);
            __THREW__ = 0;
            $174 = (invoke_ii(3380,($168|0))|0);
            $175 = __THREW__; __THREW__ = 0;
            $176 = $175&1;
            do {
             if ($176) {
              label = 95;
             } else {
              if (!($174)) {
               $282 = HEAP32[$172>>2]|0;HEAP32[$172>>2] = (($282-1)|0);
               $283 = ($282|0)==(1);
               if (!($283)) {
                $$2$ph = 0;
                break L87;
               }
               __THREW__ = 0;
               invoke_viii(3262,($168|0),1,1);
               $284 = __THREW__; __THREW__ = 0;
               $285 = $284&1;
               if (!($285)) {
                $$2$ph = 0;
                break L87;
               }
               $286 = ___cxa_find_matching_catch_2()|0;
               $287 = tempRet0;
               $$5 = $286;$$543 = $287;
               break L62;
              }
              $177 = HEAP32[52029]|0;
              $178 = ((($177)) + 8|0);
              $179 = HEAP32[$178>>2]|0;
              __THREW__ = 0;
              (invoke_ii($179|0,(208116|0))|0);
              $180 = __THREW__; __THREW__ = 0;
              $181 = $180&1;
              if ($181) {
               label = 95;
               break;
              }
              $182 = HEAP32[(208108)>>2]|0;
              $183 = ($182|0)==(0|0);
              do {
               if ($183) {
                $$025$i$i74 = (208108);$$037$i73 = (208108);$193 = $182;
                label = 70;
               } else {
                $$0$i$i72 = (208108);$$024$i$i71 = $182;$314 = $182;
                while(1) {
                 $184 = ((($$024$i$i71)) + 16|0);
                 $185 = HEAP32[$184>>2]|0;
                 $186 = ($185>>>0)>($0>>>0);
                 if ($186) {
                  $187 = HEAP32[$$024$i$i71>>2]|0;
                  $188 = ($187|0)==(0|0);
                  if ($188) {
                   label = 65;
                   break;
                  } else {
                   $$0$ph$i$i69 = $$024$i$i71;$$in$i$i68 = $187;
                  }
                 } else {
                  $189 = ($185>>>0)<($0>>>0);
                  if (!($189)) {
                   label = 69;
                   break;
                  }
                  $190 = ((($$024$i$i71)) + 4|0);
                  $191 = HEAP32[$190>>2]|0;
                  $192 = ($191|0)==(0|0);
                  if ($192) {
                   label = 68;
                   break;
                  } else {
                   $$0$ph$i$i69 = $190;$$in$i$i68 = $191;
                  }
                 }
                 $$0$i$i72 = $$0$ph$i$i69;$$024$i$i71 = $$in$i$i68;$314 = $$in$i$i68;
                }
                if ((label|0) == 65) {
                 $$025$i53$i76 = $$024$i$i71;$$03752$i77 = $$024$i$i71;
                 label = 71;
                 break;
                }
                else if ((label|0) == 68) {
                 $$025$i53$i76 = $190;$$03752$i77 = $$024$i$i71;
                 label = 71;
                 break;
                }
                else if ((label|0) == 69) {
                 $$025$i$i74 = $$0$i$i72;$$037$i73 = $$024$i$i71;$193 = $314;
                 label = 70;
                 break;
                }
               }
              } while(0);
              if ((label|0) == 70) {
               $194 = ($193|0)==(0|0);
               if ($194) {
                $$025$i53$i76 = $$025$i$i74;$$03752$i77 = $$037$i73;
                label = 71;
               } else {
                $$014$i81 = $193;
                label = 75;
               }
              }
              do {
               if ((label|0) == 71) {
                __THREW__ = 0;
                $195 = (invoke_ii(3276,24)|0);
                $196 = __THREW__; __THREW__ = 0;
                $197 = $196&1;
                if ($197) {
                 label = 96;
                 break;
                }
                $198 = ((($195)) + 16|0);
                HEAP32[$198>>2] = $0;
                $199 = ((($195)) + 20|0);
                HEAP32[$199>>2] = 0;
                HEAP32[$195>>2] = 0;
                $200 = ((($195)) + 4|0);
                HEAP32[$200>>2] = 0;
                $201 = ((($195)) + 8|0);
                HEAP32[$201>>2] = $$03752$i77;
                HEAP32[$$025$i53$i76>>2] = $195;
                $202 = HEAP32[52026]|0;
                $203 = HEAP32[$202>>2]|0;
                $204 = ($203|0)==(0|0);
                if ($204) {
                 $207 = $195;
                } else {
                 $205 = $203;
                 HEAP32[52026] = $205;
                 $$pre$i$i79 = HEAP32[$$025$i53$i76>>2]|0;
                 $207 = $$pre$i$i79;
                }
                $206 = HEAP32[(208108)>>2]|0;
                __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($206,$207);
                $208 = HEAP32[(208112)>>2]|0;
                $209 = (($208) + 1)|0;
                HEAP32[(208112)>>2] = $209;
                $$014$i81 = $195;
                label = 75;
               }
              } while(0);
              L117: do {
               if ((label|0) == 75) {
                $210 = ((($$014$i81)) + 20|0);
                $211 = HEAP32[$210>>2]|0;
                $212 = ((($211)) + 32|0);
                $213 = HEAP32[$212>>2]|0;
                $214 = ($213|0)==($168|0);
                do {
                 if (!($214)) {
                  HEAP32[$212>>2] = $168;
                  $215 = HEAP32[$172>>2]|0;HEAP32[$172>>2] = (($215+1)|0);
                  $216 = ($213|0)==(0|0);
                  if ($216) {
                   break;
                  }
                  $217 = ((($213)) + 8|0);
                  $218 = HEAP32[$217>>2]|0;HEAP32[$217>>2] = (($218-1)|0);
                  $219 = ($218|0)==(1);
                  if (!($219)) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_viii(3262,($213|0),1,1);
                  $220 = __THREW__; __THREW__ = 0;
                  $221 = $220&1;
                  if ($221) {
                   label = 96;
                   break L117;
                  }
                 }
                } while(0);
                __THREW__ = 0;
                $222 = (invoke_ii(3265,3)|0);
                $223 = __THREW__; __THREW__ = 0;
                $224 = $223&1;
                if ($224) {
                 label = 96;
                 break;
                }
                L125: do {
                 if ($222) {
                  __THREW__ = 0;
                  $225 = (invoke_ii(3266,3)|0);
                  $226 = __THREW__; __THREW__ = 0;
                  $227 = $226&1;
                  if ($227) {
                   label = 96;
                   break L117;
                  }
                  __THREW__ = 0;
                  $228 = (invoke_iiii(3267,($225|0),(120950|0),47)|0);
                  $229 = __THREW__; __THREW__ = 0;
                  $230 = $229&1;
                  if ($230) {
                   label = 96;
                   break L117;
                  }
                  $231 = HEAP32[$228>>2]|0;
                  $232 = ((($231)) + -12|0);
                  $233 = HEAP32[$232>>2]|0;
                  $234 = (($228) + ($233)|0);
                  __THREW__ = 0;
                  invoke_vii(3257,($1|0),($234|0));
                  $235 = __THREW__; __THREW__ = 0;
                  $236 = $235&1;
                  if ($236) {
                   label = 96;
                   break L117;
                  }
                  __THREW__ = 0;
                  $237 = (invoke_iii(3255,($1|0),(215188|0))|0);
                  $238 = __THREW__; __THREW__ = 0;
                  $239 = $238&1;
                  do {
                   if (!($239)) {
                    $240 = HEAP32[$237>>2]|0;
                    $241 = ((($240)) + 28|0);
                    $242 = HEAP32[$241>>2]|0;
                    __THREW__ = 0;
                    $243 = (invoke_iii($242|0,($237|0),10)|0);
                    $244 = __THREW__; __THREW__ = 0;
                    $245 = $244&1;
                    if ($245) {
                     break;
                    }
                    __THREW__ = 0;
                    invoke_vi(3263,($1|0));
                    $252 = __THREW__; __THREW__ = 0;
                    $253 = $252&1;
                    if ($253) {
                     label = 96;
                     break L117;
                    }
                    __THREW__ = 0;
                    (invoke_iii(3268,($228|0),($243|0))|0);
                    $254 = __THREW__; __THREW__ = 0;
                    $255 = $254&1;
                    if ($255) {
                     label = 96;
                     break L117;
                    }
                    __THREW__ = 0;
                    (invoke_ii(3269,($228|0))|0);
                    $256 = __THREW__; __THREW__ = 0;
                    $257 = $256&1;
                    if ($257) {
                     label = 96;
                     break L117;
                    } else {
                     break L125;
                    }
                   }
                  } while(0);
                  $246 = ___cxa_find_matching_catch_2()|0;
                  $247 = tempRet0;
                  __THREW__ = 0;
                  invoke_vi(3263,($1|0));
                  $248 = __THREW__; __THREW__ = 0;
                  $249 = $248&1;
                  if ($249) {
                   $250 = ___cxa_find_matching_catch_3(0|0)|0;
                   $251 = tempRet0;
                   ___clang_call_terminate($250);
                   // unreachable;
                  } else {
                   $eh$lpad$body$index2Z2D = $247;$eh$lpad$body$indexZ2D = $246;
                   break L117;
                  }
                 }
                } while(0);
                __THREW__ = 0;
                (invoke_ii(3335,($168|0))|0);
                $273 = __THREW__; __THREW__ = 0;
                $274 = $273&1;
                if ($274) {
                 label = 96;
                 break;
                }
                $275 = HEAP32[52029]|0;
                $276 = ((($275)) + 12|0);
                $277 = HEAP32[$276>>2]|0;
                __THREW__ = 0;
                (invoke_ii($277|0,(208116|0))|0);
                $278 = __THREW__; __THREW__ = 0;
                $279 = $278&1;
                if (!($279)) {
                 $$2$ph = $168;
                 break L87;
                }
                $280 = ___cxa_find_matching_catch_2()|0;
                $281 = tempRet0;
                $$5 = $280;$$543 = $281;
                break L62;
               }
              } while(0);
              if ((label|0) == 96) {
               $266 = ___cxa_find_matching_catch_2()|0;
               $267 = tempRet0;
               $eh$lpad$body$index2Z2D = $267;$eh$lpad$body$indexZ2D = $266;
              }
              $268 = HEAP32[52029]|0;
              $269 = ((($268)) + 12|0);
              $270 = HEAP32[$269>>2]|0;
              __THREW__ = 0;
              (invoke_ii($270|0,(208116|0))|0);
              $271 = __THREW__; __THREW__ = 0;
              $272 = $271&1;
              if ($272) {
               $310 = ___cxa_find_matching_catch_3(0|0)|0;
               $311 = tempRet0;
               ___clang_call_terminate($310);
               // unreachable;
              } else {
               $$135132 = $eh$lpad$body$indexZ2D;$$139131 = $eh$lpad$body$index2Z2D;
               break;
              }
             }
            } while(0);
            if ((label|0) == 95) {
             $264 = ___cxa_find_matching_catch_2()|0;
             $265 = tempRet0;
             $$135132 = $264;$$139131 = $265;
            }
            $288 = HEAP32[$172>>2]|0;HEAP32[$172>>2] = (($288-1)|0);
            $289 = ($288|0)==(1);
            if (!($289)) {
             $$5 = $$135132;$$543 = $$139131;
             break L62;
            }
            __THREW__ = 0;
            invoke_viii(3262,($168|0),1,1);
            $290 = __THREW__; __THREW__ = 0;
            $291 = $290&1;
            if (!($291)) {
             $$5 = $$135132;$$543 = $$139131;
             break L62;
            }
            $310 = ___cxa_find_matching_catch_3(0|0)|0;
            $311 = tempRet0;
            ___clang_call_terminate($310);
            // unreachable;
           }
          } while(0);
          $$pr = HEAP32[$3>>2]|0;
          $$2 = $$2$ph;$301 = $$pr;
          break L60;
         }
        }
       } while(0);
       $262 = ___cxa_find_matching_catch_2()|0;
       $263 = tempRet0;
       $$5 = $262;$$543 = $263;
      }
     } while(0);
     $292 = HEAP32[$3>>2]|0;
     $293 = ($292|0)==(0|0);
     if (!($293)) {
      $294 = HEAP32[$105>>2]|0;
      $295 = ($294|0)==($292|0);
      if (!($295)) {
       $scevgep$i$i$i = ((($294)) + -4|0);
       $296 = $scevgep$i$i$i;
       $297 = $292;
       $298 = (($296) - ($297))|0;
       $299 = $298 >>> 2;
       $300 = $299 ^ -1;
       $scevgep5$i$i$i = (($294) + ($300<<2)|0);
       HEAP32[$105>>2] = $scevgep5$i$i$i;
      }
      __ZdlPv($292);
     }
     $$6 = $$5;$$644 = $$543;
     ___resumeException($$6|0);
     // unreachable;
    }
   } while(0);
   $302 = ($301|0)==(0|0);
   if (!($302)) {
    $303 = HEAP32[$105>>2]|0;
    $304 = ($303|0)==($301|0);
    if (!($304)) {
     $scevgep$i$i$i100 = ((($303)) + -4|0);
     $305 = $scevgep$i$i$i100;
     $306 = $301;
     $307 = (($305) - ($306))|0;
     $308 = $307 >>> 2;
     $309 = $308 ^ -1;
     $scevgep5$i$i$i101 = (($303) + ($309<<2)|0);
     HEAP32[$105>>2] = $scevgep5$i$i$i101;
    }
    __ZdlPv($301);
   }
   $$3 = $$2;
   STACKTOP = sp;return ($$3|0);
  }
 } while(0);
 $94 = ___cxa_find_matching_catch_2()|0;
 $95 = tempRet0;
 $96 = HEAP32[52029]|0;
 $97 = ((($96)) + 12|0);
 $98 = HEAP32[$97>>2]|0;
 __THREW__ = 0;
 (invoke_ii($98|0,(208116|0))|0);
 $99 = __THREW__; __THREW__ = 0;
 $100 = $99&1;
 if ($100) {
  $310 = ___cxa_find_matching_catch_3(0|0)|0;
  $311 = tempRet0;
  ___clang_call_terminate($310);
  // unreachable;
 }
 $$6 = $94;$$644 = $95;
 ___resumeException($$6|0);
 // unreachable;
 return (0)|0;
}
function __ZNK3osg20CoordinateSystemNode27computeLocalCoordinateFrameERKNS_5Vec3dE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0.0, $12 = 0.0, $13 = 0.0, $14 = 0.0, $15 = 0.0, $16 = 0, $17 = 0.0, $18 = 0.0, $19 = 0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0.0, $25 = 0.0, $26 = 0.0, $27 = 0.0, $28 = 0.0, $29 = 0.0;
 var $3 = 0, $30 = 0.0, $31 = 0.0, $32 = 0.0, $33 = 0.0, $34 = 0, $35 = 0.0, $36 = 0.0, $37 = 0.0, $38 = 0.0, $39 = 0.0, $4 = 0, $40 = 0.0, $41 = 0.0, $42 = 0.0, $43 = 0.0, $44 = 0.0, $45 = 0.0, $46 = 0.0, $47 = 0.0;
 var $48 = 0.0, $49 = 0.0, $5 = 0, $50 = 0.0, $51 = 0.0, $52 = 0.0, $53 = 0.0, $54 = 0.0, $55 = 0.0, $56 = 0.0, $57 = 0.0, $58 = 0.0, $59 = 0.0, $6 = 0, $60 = 0.0, $61 = 0.0, $62 = 0.0, $63 = 0.0, $64 = 0.0, $65 = 0.0;
 var $66 = 0.0, $67 = 0.0, $68 = 0.0, $69 = 0.0, $7 = 0.0, $70 = 0.0, $71 = 0.0, $72 = 0.0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0.0, $82 = 0, $83 = 0.0;
 var $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($1)) + 160|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  $81 = +HEAPF64[$2>>3];
  $82 = ((($2)) + 8|0);
  $83 = +HEAPF64[$82>>3];
  __ZN3osg7Matrixd12makeIdentityEv($0);
  __ZN3osg7Matrixd13makeTranslateEddd($0,$81,$83,0.0);
  return;
 } else {
  __ZN3osg7Matrixd12makeIdentityEv($0);
  $6 = HEAP32[$3>>2]|0;
  $7 = +HEAPF64[$2>>3];
  $8 = ((($2)) + 8|0);
  $9 = +HEAPF64[$8>>3];
  $10 = ((($2)) + 16|0);
  $11 = +HEAPF64[$10>>3];
  $12 = $7 * $7;
  $13 = $9 * $9;
  $14 = $12 + $13;
  $15 = (+Math_sqrt((+$14)));
  $16 = ((($6)) + 32|0);
  $17 = +HEAPF64[$16>>3];
  $18 = $11 * $17;
  $19 = ((($6)) + 40|0);
  $20 = +HEAPF64[$19>>3];
  $21 = $15 * $20;
  $22 = (+Math_atan2((+$18),(+$21)));
  $23 = $17 * $17;
  $24 = $20 * $20;
  $25 = $23 - $24;
  $26 = $25 / $24;
  $27 = (+Math_sin((+$22)));
  $28 = (+Math_cos((+$22)));
  $29 = $20 * $26;
  $30 = $27 * $29;
  $31 = $27 * $30;
  $32 = $27 * $31;
  $33 = $11 + $32;
  $34 = ((($6)) + 48|0);
  $35 = +HEAPF64[$34>>3];
  $36 = $17 * $35;
  $37 = $28 * $36;
  $38 = $28 * $37;
  $39 = $28 * $38;
  $40 = $15 - $39;
  $41 = $33 / $40;
  $42 = (+Math_atan((+$41)));
  $43 = (+Math_atan2((+$9),(+$7)));
  $44 = (+Math_sin((+$42)));
  $45 = $35 * $44;
  $46 = $44 * $45;
  $47 = 1.0 - $46;
  $48 = (+Math_sqrt((+$47)));
  $49 = $17 / $48;
  $50 = (+Math_cos((+$42)));
  $51 = $49 + 0.0;
  $52 = $50 * $51;
  $53 = (+Math_cos((+$43)));
  $54 = $53 * $52;
  $55 = (+Math_sin((+$43)));
  $56 = $55 * $52;
  $57 = 1.0 - $35;
  $58 = $57 * $49;
  $59 = $58 + 0.0;
  $60 = $44 * $59;
  __ZN3osg7Matrixd13makeTranslateEddd($0,$54,$56,$60);
  $61 = $50 * $53;
  $62 = $50 * $55;
  $63 = -$55;
  $64 = $62 * 0.0;
  $65 = $44 * $53;
  $66 = $64 - $65;
  $67 = $44 * $63;
  $68 = $61 * 0.0;
  $69 = $67 - $68;
  $70 = $53 * $61;
  $71 = $62 * $63;
  $72 = $70 - $71;
  HEAPF64[$0>>3] = $63;
  $73 = ((($0)) + 8|0);
  HEAPF64[$73>>3] = $53;
  $74 = ((($0)) + 16|0);
  HEAPF64[$74>>3] = 0.0;
  $75 = ((($0)) + 32|0);
  HEAPF64[$75>>3] = $66;
  $76 = ((($0)) + 40|0);
  HEAPF64[$76>>3] = $69;
  $77 = ((($0)) + 48|0);
  HEAPF64[$77>>3] = $72;
  $78 = ((($0)) + 64|0);
  HEAPF64[$78>>3] = $61;
  $79 = ((($0)) + 72|0);
  HEAPF64[$79>>3] = $62;
  $80 = ((($0)) + 80|0);
  HEAPF64[$80>>3] = $44;
  return;
 }
}
function __ZN3osg6CopyOpD2Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN3osg6CopyOpD0Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($0);
 return;
}
function __ZNK3osg6CopyOpclEPKNS_10ReferencedE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ($1|0);
}
function __ZNK3osg6CopyOpclEPKNS_6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0 = 0;
  return ($$0|0);
 }
 $3 = ((($0)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 & 1;
 $6 = ($5|0)==(0);
 if ($6) {
  $$0 = $1;
  return ($$0|0);
 }
 $7 = (__ZN3osg5cloneINS_6ObjectEEEPT_PKS2_RKNS_6CopyOpE($1,$0)|0);
 $$0 = $7;
 return ($$0|0);
}
function __ZNK3osg6CopyOpclEPKNS_4NodeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$1 = 0;
  return ($$1|0);
 }
 $3 = HEAP32[$1>>2]|0;
 $4 = ((($3)) + 84|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_ii[$5 & 8191]($1)|0);
 $7 = ($6|0)==(0|0);
 if (!($7)) {
  $8 = HEAP32[$0>>2]|0;
  $9 = ((($8)) + 20|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (FUNCTION_TABLE_iii[$10 & 8191]($0,$6)|0);
  $$1 = $11;
  return ($$1|0);
 }
 $12 = ((($0)) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13 & 2;
 $15 = ($14|0)==(0);
 if ($15) {
  $$1 = $1;
  return ($$1|0);
 }
 $16 = (__ZN3osg5cloneINS_4NodeEEEPT_PKS2_RKNS_6CopyOpE($1,$0)|0);
 $$1 = $16;
 return ($$1|0);
}
function __ZNK3osg6CopyOpclEPKNS_8DrawableE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0 = 0;
  return ($$0|0);
 }
 $3 = ((($0)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 & 4;
 $6 = ($5|0)==(0);
 if ($6) {
  $$0 = $1;
  return ($$0|0);
 }
 $7 = (__ZN3osg5cloneINS_8DrawableEEEPT_PKS2_RKNS_6CopyOpE($1,$0)|0);
 $$0 = $7;
 return ($$0|0);
}
function __ZNK3osg6CopyOpclEPKNS_8StateSetE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0 = 0;
  return ($$0|0);
 }
 $3 = ((($0)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 & 8;
 $6 = ($5|0)==(0);
 if ($6) {
  $$0 = $1;
  return ($$0|0);
 }
 $7 = (__ZN3osg5cloneINS_8StateSetEEEPT_PKS2_RKNS_6CopyOpE($1,$0)|0);
 $$0 = $7;
 return ($$0|0);
}
function __ZNK3osg6CopyOpclEPKNS_14StateAttributeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$1 = 0;
  return ($$1|0);
 }
 $3 = ((($0)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 & 16;
 $6 = ($5|0)==(0);
 if ($6) {
  $$1 = $1;
  return ($$1|0);
 }
 $7 = (___dynamic_cast($1,19768,26864,0)|0);
 $8 = ($7|0)==(0|0);
 if ($8) {
  $13 = (__ZN3osg5cloneINS_14StateAttributeEEEPT_PKS2_RKNS_6CopyOpE($1,$0)|0);
  $$1 = $13;
  return ($$1|0);
 } else {
  $9 = HEAP32[$0>>2]|0;
  $10 = ((($9)) + 32|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (FUNCTION_TABLE_iii[$11 & 8191]($0,$7)|0);
  $$1 = $12;
  return ($$1|0);
 }
 return (0)|0;
}
function __ZNK3osg6CopyOpclEPKNS_7TextureE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0 = 0;
  return ($$0|0);
 }
 $3 = ((($0)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 & 32;
 $6 = ($5|0)==(0);
 if ($6) {
  $$0 = $1;
  return ($$0|0);
 }
 $7 = (__ZN3osg5cloneINS_7TextureEEEPT_PKS2_RKNS_6CopyOpE($1,$0)|0);
 $$0 = $7;
 return ($$0|0);
}
function __ZNK3osg6CopyOpclEPKNS_5ImageE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0 = 0;
  return ($$0|0);
 }
 $3 = ((($0)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 & 64;
 $6 = ($5|0)==(0);
 if ($6) {
  $$0 = $1;
  return ($$0|0);
 }
 $7 = (__ZN3osg5cloneINS_5ImageEEEPT_PKS2_RKNS_6CopyOpE($1,$0)|0);
 $$0 = $7;
 return ($$0|0);
}
function __ZNK3osg6CopyOpclEPKNS_5ArrayE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0 = 0;
  return ($$0|0);
 }
 $3 = ((($0)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 & 128;
 $6 = ($5|0)==(0);
 if ($6) {
  $$0 = $1;
  return ($$0|0);
 }
 $7 = (__ZN3osg5cloneINS_5ArrayEEEPT_PKS2_RKNS_6CopyOpE($1,$0)|0);
 $$0 = $7;
 return ($$0|0);
}
function __ZNK3osg6CopyOpclEPKNS_12PrimitiveSetE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0 = 0;
  return ($$0|0);
 }
 $3 = ((($0)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 & 256;
 $6 = ($5|0)==(0);
 if ($6) {
  $$0 = $1;
  return ($$0|0);
 }
 $7 = (__ZN3osg5cloneINS_12PrimitiveSetEEEPT_PKS2_RKNS_6CopyOpE($1,$0)|0);
 $$0 = $7;
 return ($$0|0);
}
function __ZNK3osg6CopyOpclEPKNS_5ShapeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0 = 0;
  return ($$0|0);
 }
 $3 = ((($0)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 & 512;
 $6 = ($5|0)==(0);
 if ($6) {
  $$0 = $1;
  return ($$0|0);
 }
 $7 = (__ZN3osg5cloneINS_5ShapeEEEPT_PKS2_RKNS_6CopyOpE($1,$0)|0);
 $$0 = $7;
 return ($$0|0);
}
function __ZNK3osg6CopyOpclEPKNS_7UniformE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0 = 0;
  return ($$0|0);
 }
 $3 = ((($0)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 & 1024;
 $6 = ($5|0)==(0);
 if ($6) {
  $$0 = $1;
  return ($$0|0);
 }
 $7 = (__ZN3osg5cloneINS_7UniformEEEPT_PKS2_RKNS_6CopyOpE($1,$0)|0);
 $$0 = $7;
 return ($$0|0);
}
function __ZNK3osg6CopyOpclEPKNS_8CallbackE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$1 = 0, $$tr$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$1 = 0;
  return ($$1|0);
 }
 $3 = ((($0)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 & 2048;
 $6 = ($5|0)==(0);
 if ($6) {
  $$1 = $1;
  return ($$1|0);
 }
 $7 = (__ZN3osg5cloneINS_8CallbackEEEPT_PKS2_RKNS_6CopyOpE($1,$0)|0);
 $8 = ($7|0)==(0|0);
 if ($8) {
  $$1 = 0;
  return ($$1|0);
 }
 $9 = ((($7)) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if (!($11)) {
  HEAP32[$9>>2] = 0;
  $12 = HEAP32[$10>>2]|0;
  $13 = ((($12)) + -12|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($10) + ($14)|0);
  $16 = ((($15)) + 8|0);
  $17 = HEAP32[$16>>2]|0;HEAP32[$16>>2] = (($17-1)|0);
  $18 = ($17|0)==(1);
  if ($18) {
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($15,1,1);
  }
 }
 $19 = ((($1)) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)==(0|0);
 if ($21) {
  $$1 = $7;
  return ($$1|0);
 } else {
  $22 = $20;
 }
 while(1) {
  $23 = (__ZN3osg5cloneINS_8CallbackEEEPT_PKS2_RKNS_6CopyOpE($22,$0)|0);
  $24 = ($23|0)==(0|0);
  if (!($24)) {
   $28 = ((($23)) + 4|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = ($29|0)==(0|0);
   if ($30) {
    $$tr$i = $7;
   } else {
    HEAP32[$28>>2] = 0;
    $31 = HEAP32[$29>>2]|0;
    $32 = ((($31)) + -12|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = (($29) + ($33)|0);
    $35 = ((($34)) + 8|0);
    $36 = HEAP32[$35>>2]|0;HEAP32[$35>>2] = (($36-1)|0);
    $37 = ($36|0)==(1);
    if ($37) {
     __ZNK3osg10Referenced24signalObserversAndDeleteEbb($34,1,1);
     $$tr$i = $7;
    } else {
     $$tr$i = $7;
    }
   }
   while(1) {
    $38 = ((($$tr$i)) + 4|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = ($39|0)==(0|0);
    if ($40) {
     break;
    } else {
     $$tr$i = $39;
    }
   }
   HEAP32[$38>>2] = $23;
   $41 = HEAP32[$23>>2]|0;
   $42 = ((($41)) + -12|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = (($23) + ($43)|0);
   $45 = ((($44)) + 8|0);
   $46 = HEAP32[$45>>2]|0;HEAP32[$45>>2] = (($46+1)|0);
  }
  $25 = ((($22)) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = ($26|0)==(0|0);
  if ($27) {
   $$1 = $7;
   break;
  } else {
   $22 = $26;
  }
 }
 return ($$1|0);
}
function __ZNK3osg6CopyOpclEPKNS_22StateAttributeCallbackE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0 = 0;
  return ($$0|0);
 }
 $3 = ((($0)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 & 2048;
 $6 = ($5|0)==(0);
 if ($6) {
  $$0 = $1;
  return ($$0|0);
 }
 $7 = (__ZN3osg5cloneINS_22StateAttributeCallbackEEEPT_PKS2_RKNS_6CopyOpE($1,$0)|0);
 $$0 = $7;
 return ($$0|0);
}
function __ZNK3osg6CopyOpclEPKNS_15UniformCallbackE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0 = 0;
  return ($$0|0);
 }
 $3 = ((($0)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 & 2048;
 $6 = ($5|0)==(0);
 if ($6) {
  $$0 = $1;
  return ($$0|0);
 }
 $7 = (__ZN3osg5cloneINS_15UniformCallbackEEEPT_PKS2_RKNS_6CopyOpE($1,$0)|0);
 $$0 = $7;
 return ($$0|0);
}
function __ZN3osg5cloneINS_15UniformCallbackEEEPT_PKS2_RKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp + 4|0;
 $3 = sp;
 $4 = ($0|0)==(0|0);
 if ($4) {
  $62 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
  if (!($62)) {
   $$1 = 0;
   STACKTOP = sp;return ($$1|0);
  }
  $63 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
  $64 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($63,166509,88)|0);
  $65 = HEAP32[$64>>2]|0;
  $66 = ((($65)) + -12|0);
  $67 = HEAP32[$66>>2]|0;
  $68 = (($64) + ($67)|0);
  __ZNKSt3__28ios_base6getlocEv($3,$68);
  __THREW__ = 0;
  $69 = (invoke_iii(3255,($3|0),(215188|0))|0);
  $70 = __THREW__; __THREW__ = 0;
  $71 = $70&1;
  if (!($71)) {
   $72 = HEAP32[$69>>2]|0;
   $73 = ((($72)) + 28|0);
   $74 = HEAP32[$73>>2]|0;
   __THREW__ = 0;
   $75 = (invoke_iii($74|0,($69|0),10)|0);
   $76 = __THREW__; __THREW__ = 0;
   $77 = $76&1;
   if (!($77)) {
    __ZNSt3__26localeD2Ev($3);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($64,$75)|0);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($64)|0);
    $$1 = 0;
    STACKTOP = sp;return ($$1|0);
   }
  }
  $78 = ___cxa_find_matching_catch_2()|0;
  $79 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3263,($3|0));
  $80 = __THREW__; __THREW__ = 0;
  $81 = $80&1;
  if ($81) {
   $82 = ___cxa_find_matching_catch_3(0|0)|0;
   $83 = tempRet0;
   ___clang_call_terminate($82);
   // unreachable;
  } else {
   ___resumeException($78|0);
   // unreachable;
  }
 }
 $5 = HEAP32[$0>>2]|0;
 $6 = ((($5)) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_iii[$7 & 8191]($0,$1)|0);
 $9 = ($8|0)==(0|0);
 if ($9) {
  label = 9;
 } else {
  $10 = ((($8)) + 8|0);
  $11 = HEAP32[$10>>2]|0;HEAP32[$10>>2] = (($11+1)|0);
  $12 = (___dynamic_cast($8,26112,23208,-1)|0);
  $13 = ($12|0)==(0|0);
  if ($13) {
   label = 9;
  } else {
   __THREW__ = 0;
   (invoke_ii(3335,($8|0))|0);
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if ($15) {
    label = 5;
   } else {
    $$1 = $12;
    STACKTOP = sp;return ($$1|0);
   }
  }
 }
 L19: do {
  if ((label|0) == 9) {
   __THREW__ = 0;
   $23 = (invoke_ii(3265,2)|0);
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   if ($25) {
    label = 5;
   } else {
    do {
     if ($23) {
      __THREW__ = 0;
      $26 = (invoke_ii(3266,2)|0);
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       label = 5;
       break L19;
      }
      __THREW__ = 0;
      $29 = (invoke_iiii(3267,($26|0),(166420|0),88)|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 5;
       break L19;
      }
      $32 = HEAP32[$29>>2]|0;
      $33 = ((($32)) + -12|0);
      $34 = HEAP32[$33>>2]|0;
      $35 = (($29) + ($34)|0);
      __THREW__ = 0;
      invoke_vii(3257,($2|0),($35|0));
      $36 = __THREW__; __THREW__ = 0;
      $37 = $36&1;
      if ($37) {
       label = 5;
       break L19;
      }
      __THREW__ = 0;
      $38 = (invoke_iii(3255,($2|0),(215188|0))|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       $41 = HEAP32[$38>>2]|0;
       $42 = ((($41)) + 28|0);
       $43 = HEAP32[$42>>2]|0;
       __THREW__ = 0;
       $44 = (invoke_iii($43|0,($38|0),10)|0);
       $45 = __THREW__; __THREW__ = 0;
       $46 = $45&1;
       if (!($46)) {
        __THREW__ = 0;
        invoke_vi(3263,($2|0));
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 5;
         break L19;
        }
        __THREW__ = 0;
        (invoke_iii(3268,($29|0),($44|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 5;
         break L19;
        }
        __THREW__ = 0;
        (invoke_ii(3269,($29|0))|0);
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 5;
         break L19;
        } else {
         break;
        }
       }
      }
      $49 = ___cxa_find_matching_catch_2()|0;
      $50 = tempRet0;
      __THREW__ = 0;
      invoke_vi(3263,($2|0));
      $51 = __THREW__; __THREW__ = 0;
      $52 = $51&1;
      if ($52) {
       $53 = ___cxa_find_matching_catch_3(0|0)|0;
       $54 = tempRet0;
       ___clang_call_terminate($53);
       // unreachable;
      } else {
       $eh$lpad$body$index2Z2D = $50;$eh$lpad$body$indexZ2D = $49;
       break L19;
      }
     }
    } while(0);
    if ($9) {
     $$1 = 0;
     STACKTOP = sp;return ($$1|0);
    }
    $59 = ((($8)) + 8|0);
    $60 = HEAP32[$59>>2]|0;HEAP32[$59>>2] = (($60-1)|0);
    $61 = ($60|0)==(1);
    if (!($61)) {
     $$1 = 0;
     STACKTOP = sp;return ($$1|0);
    }
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($8,1,1);
    $$1 = 0;
    STACKTOP = sp;return ($$1|0);
   }
  }
 } while(0);
 if ((label|0) == 5) {
  $16 = ___cxa_find_matching_catch_2()|0;
  $17 = tempRet0;
  $eh$lpad$body$index2Z2D = $17;$eh$lpad$body$indexZ2D = $16;
 }
 if ($9) {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 $18 = ((($8)) + 8|0);
 $19 = HEAP32[$18>>2]|0;HEAP32[$18>>2] = (($19-1)|0);
 $20 = ($19|0)==(1);
 if (!($20)) {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(3262,($8|0),1,1);
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if ($22) {
  $84 = ___cxa_find_matching_catch_3(0|0)|0;
  $85 = tempRet0;
  ___clang_call_terminate($84);
  // unreachable;
 } else {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 return (0)|0;
}
function __ZN3osg5cloneINS_22StateAttributeCallbackEEEPT_PKS2_RKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp + 4|0;
 $3 = sp;
 $4 = ($0|0)==(0|0);
 if ($4) {
  $62 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
  if (!($62)) {
   $$1 = 0;
   STACKTOP = sp;return ($$1|0);
  }
  $63 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
  $64 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($63,166509,88)|0);
  $65 = HEAP32[$64>>2]|0;
  $66 = ((($65)) + -12|0);
  $67 = HEAP32[$66>>2]|0;
  $68 = (($64) + ($67)|0);
  __ZNKSt3__28ios_base6getlocEv($3,$68);
  __THREW__ = 0;
  $69 = (invoke_iii(3255,($3|0),(215188|0))|0);
  $70 = __THREW__; __THREW__ = 0;
  $71 = $70&1;
  if (!($71)) {
   $72 = HEAP32[$69>>2]|0;
   $73 = ((($72)) + 28|0);
   $74 = HEAP32[$73>>2]|0;
   __THREW__ = 0;
   $75 = (invoke_iii($74|0,($69|0),10)|0);
   $76 = __THREW__; __THREW__ = 0;
   $77 = $76&1;
   if (!($77)) {
    __ZNSt3__26localeD2Ev($3);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($64,$75)|0);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($64)|0);
    $$1 = 0;
    STACKTOP = sp;return ($$1|0);
   }
  }
  $78 = ___cxa_find_matching_catch_2()|0;
  $79 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3263,($3|0));
  $80 = __THREW__; __THREW__ = 0;
  $81 = $80&1;
  if ($81) {
   $82 = ___cxa_find_matching_catch_3(0|0)|0;
   $83 = tempRet0;
   ___clang_call_terminate($82);
   // unreachable;
  } else {
   ___resumeException($78|0);
   // unreachable;
  }
 }
 $5 = HEAP32[$0>>2]|0;
 $6 = ((($5)) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_iii[$7 & 8191]($0,$1)|0);
 $9 = ($8|0)==(0|0);
 if ($9) {
  label = 9;
 } else {
  $10 = ((($8)) + 8|0);
  $11 = HEAP32[$10>>2]|0;HEAP32[$10>>2] = (($11+1)|0);
  $12 = (___dynamic_cast($8,26112,23184,-1)|0);
  $13 = ($12|0)==(0|0);
  if ($13) {
   label = 9;
  } else {
   __THREW__ = 0;
   (invoke_ii(3335,($8|0))|0);
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if ($15) {
    label = 5;
   } else {
    $$1 = $12;
    STACKTOP = sp;return ($$1|0);
   }
  }
 }
 L19: do {
  if ((label|0) == 9) {
   __THREW__ = 0;
   $23 = (invoke_ii(3265,2)|0);
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   if ($25) {
    label = 5;
   } else {
    do {
     if ($23) {
      __THREW__ = 0;
      $26 = (invoke_ii(3266,2)|0);
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       label = 5;
       break L19;
      }
      __THREW__ = 0;
      $29 = (invoke_iiii(3267,($26|0),(166420|0),88)|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 5;
       break L19;
      }
      $32 = HEAP32[$29>>2]|0;
      $33 = ((($32)) + -12|0);
      $34 = HEAP32[$33>>2]|0;
      $35 = (($29) + ($34)|0);
      __THREW__ = 0;
      invoke_vii(3257,($2|0),($35|0));
      $36 = __THREW__; __THREW__ = 0;
      $37 = $36&1;
      if ($37) {
       label = 5;
       break L19;
      }
      __THREW__ = 0;
      $38 = (invoke_iii(3255,($2|0),(215188|0))|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       $41 = HEAP32[$38>>2]|0;
       $42 = ((($41)) + 28|0);
       $43 = HEAP32[$42>>2]|0;
       __THREW__ = 0;
       $44 = (invoke_iii($43|0,($38|0),10)|0);
       $45 = __THREW__; __THREW__ = 0;
       $46 = $45&1;
       if (!($46)) {
        __THREW__ = 0;
        invoke_vi(3263,($2|0));
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 5;
         break L19;
        }
        __THREW__ = 0;
        (invoke_iii(3268,($29|0),($44|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 5;
         break L19;
        }
        __THREW__ = 0;
        (invoke_ii(3269,($29|0))|0);
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 5;
         break L19;
        } else {
         break;
        }
       }
      }
      $49 = ___cxa_find_matching_catch_2()|0;
      $50 = tempRet0;
      __THREW__ = 0;
      invoke_vi(3263,($2|0));
      $51 = __THREW__; __THREW__ = 0;
      $52 = $51&1;
      if ($52) {
       $53 = ___cxa_find_matching_catch_3(0|0)|0;
       $54 = tempRet0;
       ___clang_call_terminate($53);
       // unreachable;
      } else {
       $eh$lpad$body$index2Z2D = $50;$eh$lpad$body$indexZ2D = $49;
       break L19;
      }
     }
    } while(0);
    if ($9) {
     $$1 = 0;
     STACKTOP = sp;return ($$1|0);
    }
    $59 = ((($8)) + 8|0);
    $60 = HEAP32[$59>>2]|0;HEAP32[$59>>2] = (($60-1)|0);
    $61 = ($60|0)==(1);
    if (!($61)) {
     $$1 = 0;
     STACKTOP = sp;return ($$1|0);
    }
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($8,1,1);
    $$1 = 0;
    STACKTOP = sp;return ($$1|0);
   }
  }
 } while(0);
 if ((label|0) == 5) {
  $16 = ___cxa_find_matching_catch_2()|0;
  $17 = tempRet0;
  $eh$lpad$body$index2Z2D = $17;$eh$lpad$body$indexZ2D = $16;
 }
 if ($9) {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 $18 = ((($8)) + 8|0);
 $19 = HEAP32[$18>>2]|0;HEAP32[$18>>2] = (($19-1)|0);
 $20 = ($19|0)==(1);
 if (!($20)) {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(3262,($8|0),1,1);
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if ($22) {
  $84 = ___cxa_find_matching_catch_3(0|0)|0;
  $85 = tempRet0;
  ___clang_call_terminate($84);
  // unreachable;
 } else {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 return (0)|0;
}
function __ZN3osg5cloneINS_8CallbackEEEPT_PKS2_RKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp + 4|0;
 $3 = sp;
 $4 = ($0|0)==(0|0);
 if ($4) {
  $62 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
  if (!($62)) {
   $$1 = 0;
   STACKTOP = sp;return ($$1|0);
  }
  $63 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
  $64 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($63,166509,88)|0);
  $65 = HEAP32[$64>>2]|0;
  $66 = ((($65)) + -12|0);
  $67 = HEAP32[$66>>2]|0;
  $68 = (($64) + ($67)|0);
  __ZNKSt3__28ios_base6getlocEv($3,$68);
  __THREW__ = 0;
  $69 = (invoke_iii(3255,($3|0),(215188|0))|0);
  $70 = __THREW__; __THREW__ = 0;
  $71 = $70&1;
  if (!($71)) {
   $72 = HEAP32[$69>>2]|0;
   $73 = ((($72)) + 28|0);
   $74 = HEAP32[$73>>2]|0;
   __THREW__ = 0;
   $75 = (invoke_iii($74|0,($69|0),10)|0);
   $76 = __THREW__; __THREW__ = 0;
   $77 = $76&1;
   if (!($77)) {
    __ZNSt3__26localeD2Ev($3);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($64,$75)|0);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($64)|0);
    $$1 = 0;
    STACKTOP = sp;return ($$1|0);
   }
  }
  $78 = ___cxa_find_matching_catch_2()|0;
  $79 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3263,($3|0));
  $80 = __THREW__; __THREW__ = 0;
  $81 = $80&1;
  if ($81) {
   $82 = ___cxa_find_matching_catch_3(0|0)|0;
   $83 = tempRet0;
   ___clang_call_terminate($82);
   // unreachable;
  } else {
   ___resumeException($78|0);
   // unreachable;
  }
 }
 $5 = HEAP32[$0>>2]|0;
 $6 = ((($5)) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_iii[$7 & 8191]($0,$1)|0);
 $9 = ($8|0)==(0|0);
 if ($9) {
  label = 9;
 } else {
  $10 = ((($8)) + 8|0);
  $11 = HEAP32[$10>>2]|0;HEAP32[$10>>2] = (($11+1)|0);
  $12 = (___dynamic_cast($8,26112,5616,-1)|0);
  $13 = ($12|0)==(0|0);
  if ($13) {
   label = 9;
  } else {
   __THREW__ = 0;
   (invoke_ii(3335,($8|0))|0);
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if ($15) {
    label = 5;
   } else {
    $$1 = $12;
    STACKTOP = sp;return ($$1|0);
   }
  }
 }
 L19: do {
  if ((label|0) == 9) {
   __THREW__ = 0;
   $23 = (invoke_ii(3265,2)|0);
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   if ($25) {
    label = 5;
   } else {
    do {
     if ($23) {
      __THREW__ = 0;
      $26 = (invoke_ii(3266,2)|0);
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       label = 5;
       break L19;
      }
      __THREW__ = 0;
      $29 = (invoke_iiii(3267,($26|0),(166420|0),88)|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 5;
       break L19;
      }
      $32 = HEAP32[$29>>2]|0;
      $33 = ((($32)) + -12|0);
      $34 = HEAP32[$33>>2]|0;
      $35 = (($29) + ($34)|0);
      __THREW__ = 0;
      invoke_vii(3257,($2|0),($35|0));
      $36 = __THREW__; __THREW__ = 0;
      $37 = $36&1;
      if ($37) {
       label = 5;
       break L19;
      }
      __THREW__ = 0;
      $38 = (invoke_iii(3255,($2|0),(215188|0))|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       $41 = HEAP32[$38>>2]|0;
       $42 = ((($41)) + 28|0);
       $43 = HEAP32[$42>>2]|0;
       __THREW__ = 0;
       $44 = (invoke_iii($43|0,($38|0),10)|0);
       $45 = __THREW__; __THREW__ = 0;
       $46 = $45&1;
       if (!($46)) {
        __THREW__ = 0;
        invoke_vi(3263,($2|0));
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 5;
         break L19;
        }
        __THREW__ = 0;
        (invoke_iii(3268,($29|0),($44|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 5;
         break L19;
        }
        __THREW__ = 0;
        (invoke_ii(3269,($29|0))|0);
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 5;
         break L19;
        } else {
         break;
        }
       }
      }
      $49 = ___cxa_find_matching_catch_2()|0;
      $50 = tempRet0;
      __THREW__ = 0;
      invoke_vi(3263,($2|0));
      $51 = __THREW__; __THREW__ = 0;
      $52 = $51&1;
      if ($52) {
       $53 = ___cxa_find_matching_catch_3(0|0)|0;
       $54 = tempRet0;
       ___clang_call_terminate($53);
       // unreachable;
      } else {
       $eh$lpad$body$index2Z2D = $50;$eh$lpad$body$indexZ2D = $49;
       break L19;
      }
     }
    } while(0);
    if ($9) {
     $$1 = 0;
     STACKTOP = sp;return ($$1|0);
    }
    $59 = ((($8)) + 8|0);
    $60 = HEAP32[$59>>2]|0;HEAP32[$59>>2] = (($60-1)|0);
    $61 = ($60|0)==(1);
    if (!($61)) {
     $$1 = 0;
     STACKTOP = sp;return ($$1|0);
    }
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($8,1,1);
    $$1 = 0;
    STACKTOP = sp;return ($$1|0);
   }
  }
 } while(0);
 if ((label|0) == 5) {
  $16 = ___cxa_find_matching_catch_2()|0;
  $17 = tempRet0;
  $eh$lpad$body$index2Z2D = $17;$eh$lpad$body$indexZ2D = $16;
 }
 if ($9) {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 $18 = ((($8)) + 8|0);
 $19 = HEAP32[$18>>2]|0;HEAP32[$18>>2] = (($19-1)|0);
 $20 = ($19|0)==(1);
 if (!($20)) {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(3262,($8|0),1,1);
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if ($22) {
  $84 = ___cxa_find_matching_catch_3(0|0)|0;
  $85 = tempRet0;
  ___clang_call_terminate($84);
  // unreachable;
 } else {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 return (0)|0;
}
function __ZN3osg5cloneINS_7UniformEEEPT_PKS2_RKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp + 4|0;
 $3 = sp;
 $4 = ($0|0)==(0|0);
 if ($4) {
  $62 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
  if (!($62)) {
   $$1 = 0;
   STACKTOP = sp;return ($$1|0);
  }
  $63 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
  $64 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($63,166509,88)|0);
  $65 = HEAP32[$64>>2]|0;
  $66 = ((($65)) + -12|0);
  $67 = HEAP32[$66>>2]|0;
  $68 = (($64) + ($67)|0);
  __ZNKSt3__28ios_base6getlocEv($3,$68);
  __THREW__ = 0;
  $69 = (invoke_iii(3255,($3|0),(215188|0))|0);
  $70 = __THREW__; __THREW__ = 0;
  $71 = $70&1;
  if (!($71)) {
   $72 = HEAP32[$69>>2]|0;
   $73 = ((($72)) + 28|0);
   $74 = HEAP32[$73>>2]|0;
   __THREW__ = 0;
   $75 = (invoke_iii($74|0,($69|0),10)|0);
   $76 = __THREW__; __THREW__ = 0;
   $77 = $76&1;
   if (!($77)) {
    __ZNSt3__26localeD2Ev($3);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($64,$75)|0);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($64)|0);
    $$1 = 0;
    STACKTOP = sp;return ($$1|0);
   }
  }
  $78 = ___cxa_find_matching_catch_2()|0;
  $79 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3263,($3|0));
  $80 = __THREW__; __THREW__ = 0;
  $81 = $80&1;
  if ($81) {
   $82 = ___cxa_find_matching_catch_3(0|0)|0;
   $83 = tempRet0;
   ___clang_call_terminate($82);
   // unreachable;
  } else {
   ___resumeException($78|0);
   // unreachable;
  }
 }
 $5 = HEAP32[$0>>2]|0;
 $6 = ((($5)) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_iii[$7 & 8191]($0,$1)|0);
 $9 = ($8|0)==(0|0);
 if ($9) {
  label = 9;
 } else {
  $10 = ((($8)) + 8|0);
  $11 = HEAP32[$10>>2]|0;HEAP32[$10>>2] = (($11+1)|0);
  $12 = (___dynamic_cast($8,26112,26960,0)|0);
  $13 = ($12|0)==(0|0);
  if ($13) {
   label = 9;
  } else {
   __THREW__ = 0;
   (invoke_ii(3335,($8|0))|0);
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if ($15) {
    label = 5;
   } else {
    $$1 = $12;
    STACKTOP = sp;return ($$1|0);
   }
  }
 }
 L19: do {
  if ((label|0) == 9) {
   __THREW__ = 0;
   $23 = (invoke_ii(3265,2)|0);
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   if ($25) {
    label = 5;
   } else {
    do {
     if ($23) {
      __THREW__ = 0;
      $26 = (invoke_ii(3266,2)|0);
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       label = 5;
       break L19;
      }
      __THREW__ = 0;
      $29 = (invoke_iiii(3267,($26|0),(166420|0),88)|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 5;
       break L19;
      }
      $32 = HEAP32[$29>>2]|0;
      $33 = ((($32)) + -12|0);
      $34 = HEAP32[$33>>2]|0;
      $35 = (($29) + ($34)|0);
      __THREW__ = 0;
      invoke_vii(3257,($2|0),($35|0));
      $36 = __THREW__; __THREW__ = 0;
      $37 = $36&1;
      if ($37) {
       label = 5;
       break L19;
      }
      __THREW__ = 0;
      $38 = (invoke_iii(3255,($2|0),(215188|0))|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       $41 = HEAP32[$38>>2]|0;
       $42 = ((($41)) + 28|0);
       $43 = HEAP32[$42>>2]|0;
       __THREW__ = 0;
       $44 = (invoke_iii($43|0,($38|0),10)|0);
       $45 = __THREW__; __THREW__ = 0;
       $46 = $45&1;
       if (!($46)) {
        __THREW__ = 0;
        invoke_vi(3263,($2|0));
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 5;
         break L19;
        }
        __THREW__ = 0;
        (invoke_iii(3268,($29|0),($44|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 5;
         break L19;
        }
        __THREW__ = 0;
        (invoke_ii(3269,($29|0))|0);
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 5;
         break L19;
        } else {
         break;
        }
       }
      }
      $49 = ___cxa_find_matching_catch_2()|0;
      $50 = tempRet0;
      __THREW__ = 0;
      invoke_vi(3263,($2|0));
      $51 = __THREW__; __THREW__ = 0;
      $52 = $51&1;
      if ($52) {
       $53 = ___cxa_find_matching_catch_3(0|0)|0;
       $54 = tempRet0;
       ___clang_call_terminate($53);
       // unreachable;
      } else {
       $eh$lpad$body$index2Z2D = $50;$eh$lpad$body$indexZ2D = $49;
       break L19;
      }
     }
    } while(0);
    if ($9) {
     $$1 = 0;
     STACKTOP = sp;return ($$1|0);
    }
    $59 = ((($8)) + 8|0);
    $60 = HEAP32[$59>>2]|0;HEAP32[$59>>2] = (($60-1)|0);
    $61 = ($60|0)==(1);
    if (!($61)) {
     $$1 = 0;
     STACKTOP = sp;return ($$1|0);
    }
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($8,1,1);
    $$1 = 0;
    STACKTOP = sp;return ($$1|0);
   }
  }
 } while(0);
 if ((label|0) == 5) {
  $16 = ___cxa_find_matching_catch_2()|0;
  $17 = tempRet0;
  $eh$lpad$body$index2Z2D = $17;$eh$lpad$body$indexZ2D = $16;
 }
 if ($9) {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 $18 = ((($8)) + 8|0);
 $19 = HEAP32[$18>>2]|0;HEAP32[$18>>2] = (($19-1)|0);
 $20 = ($19|0)==(1);
 if (!($20)) {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(3262,($8|0),1,1);
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if ($22) {
  $84 = ___cxa_find_matching_catch_3(0|0)|0;
  $85 = tempRet0;
  ___clang_call_terminate($84);
  // unreachable;
 } else {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 return (0)|0;
}
function __ZN3osg5cloneINS_5ShapeEEEPT_PKS2_RKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp + 4|0;
 $3 = sp;
 $4 = ($0|0)==(0|0);
 if ($4) {
  $62 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
  if (!($62)) {
   $$1 = 0;
   STACKTOP = sp;return ($$1|0);
  }
  $63 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
  $64 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($63,166509,88)|0);
  $65 = HEAP32[$64>>2]|0;
  $66 = ((($65)) + -12|0);
  $67 = HEAP32[$66>>2]|0;
  $68 = (($64) + ($67)|0);
  __ZNKSt3__28ios_base6getlocEv($3,$68);
  __THREW__ = 0;
  $69 = (invoke_iii(3255,($3|0),(215188|0))|0);
  $70 = __THREW__; __THREW__ = 0;
  $71 = $70&1;
  if (!($71)) {
   $72 = HEAP32[$69>>2]|0;
   $73 = ((($72)) + 28|0);
   $74 = HEAP32[$73>>2]|0;
   __THREW__ = 0;
   $75 = (invoke_iii($74|0,($69|0),10)|0);
   $76 = __THREW__; __THREW__ = 0;
   $77 = $76&1;
   if (!($77)) {
    __ZNSt3__26localeD2Ev($3);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($64,$75)|0);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($64)|0);
    $$1 = 0;
    STACKTOP = sp;return ($$1|0);
   }
  }
  $78 = ___cxa_find_matching_catch_2()|0;
  $79 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3263,($3|0));
  $80 = __THREW__; __THREW__ = 0;
  $81 = $80&1;
  if ($81) {
   $82 = ___cxa_find_matching_catch_3(0|0)|0;
   $83 = tempRet0;
   ___clang_call_terminate($82);
   // unreachable;
  } else {
   ___resumeException($78|0);
   // unreachable;
  }
 }
 $5 = HEAP32[$0>>2]|0;
 $6 = ((($5)) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_iii[$7 & 8191]($0,$1)|0);
 $9 = ($8|0)==(0|0);
 if ($9) {
  label = 9;
 } else {
  $10 = ((($8)) + 8|0);
  $11 = HEAP32[$10>>2]|0;HEAP32[$10>>2] = (($11+1)|0);
  $12 = (___dynamic_cast($8,26112,26560,0)|0);
  $13 = ($12|0)==(0|0);
  if ($13) {
   label = 9;
  } else {
   __THREW__ = 0;
   (invoke_ii(3335,($8|0))|0);
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if ($15) {
    label = 5;
   } else {
    $$1 = $12;
    STACKTOP = sp;return ($$1|0);
   }
  }
 }
 L19: do {
  if ((label|0) == 9) {
   __THREW__ = 0;
   $23 = (invoke_ii(3265,2)|0);
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   if ($25) {
    label = 5;
   } else {
    do {
     if ($23) {
      __THREW__ = 0;
      $26 = (invoke_ii(3266,2)|0);
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       label = 5;
       break L19;
      }
      __THREW__ = 0;
      $29 = (invoke_iiii(3267,($26|0),(166420|0),88)|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 5;
       break L19;
      }
      $32 = HEAP32[$29>>2]|0;
      $33 = ((($32)) + -12|0);
      $34 = HEAP32[$33>>2]|0;
      $35 = (($29) + ($34)|0);
      __THREW__ = 0;
      invoke_vii(3257,($2|0),($35|0));
      $36 = __THREW__; __THREW__ = 0;
      $37 = $36&1;
      if ($37) {
       label = 5;
       break L19;
      }
      __THREW__ = 0;
      $38 = (invoke_iii(3255,($2|0),(215188|0))|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       $41 = HEAP32[$38>>2]|0;
       $42 = ((($41)) + 28|0);
       $43 = HEAP32[$42>>2]|0;
       __THREW__ = 0;
       $44 = (invoke_iii($43|0,($38|0),10)|0);
       $45 = __THREW__; __THREW__ = 0;
       $46 = $45&1;
       if (!($46)) {
        __THREW__ = 0;
        invoke_vi(3263,($2|0));
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 5;
         break L19;
        }
        __THREW__ = 0;
        (invoke_iii(3268,($29|0),($44|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 5;
         break L19;
        }
        __THREW__ = 0;
        (invoke_ii(3269,($29|0))|0);
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 5;
         break L19;
        } else {
         break;
        }
       }
      }
      $49 = ___cxa_find_matching_catch_2()|0;
      $50 = tempRet0;
      __THREW__ = 0;
      invoke_vi(3263,($2|0));
      $51 = __THREW__; __THREW__ = 0;
      $52 = $51&1;
      if ($52) {
       $53 = ___cxa_find_matching_catch_3(0|0)|0;
       $54 = tempRet0;
       ___clang_call_terminate($53);
       // unreachable;
      } else {
       $eh$lpad$body$index2Z2D = $50;$eh$lpad$body$indexZ2D = $49;
       break L19;
      }
     }
    } while(0);
    if ($9) {
     $$1 = 0;
     STACKTOP = sp;return ($$1|0);
    }
    $59 = ((($8)) + 8|0);
    $60 = HEAP32[$59>>2]|0;HEAP32[$59>>2] = (($60-1)|0);
    $61 = ($60|0)==(1);
    if (!($61)) {
     $$1 = 0;
     STACKTOP = sp;return ($$1|0);
    }
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($8,1,1);
    $$1 = 0;
    STACKTOP = sp;return ($$1|0);
   }
  }
 } while(0);
 if ((label|0) == 5) {
  $16 = ___cxa_find_matching_catch_2()|0;
  $17 = tempRet0;
  $eh$lpad$body$index2Z2D = $17;$eh$lpad$body$indexZ2D = $16;
 }
 if ($9) {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 $18 = ((($8)) + 8|0);
 $19 = HEAP32[$18>>2]|0;HEAP32[$18>>2] = (($19-1)|0);
 $20 = ($19|0)==(1);
 if (!($20)) {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(3262,($8|0),1,1);
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if ($22) {
  $84 = ___cxa_find_matching_catch_3(0|0)|0;
  $85 = tempRet0;
  ___clang_call_terminate($84);
  // unreachable;
 } else {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 return (0)|0;
}
function __ZN3osg5cloneINS_12PrimitiveSetEEEPT_PKS2_RKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp + 4|0;
 $3 = sp;
 $4 = ($0|0)==(0|0);
 if ($4) {
  $62 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
  if (!($62)) {
   $$1 = 0;
   STACKTOP = sp;return ($$1|0);
  }
  $63 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
  $64 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($63,166509,88)|0);
  $65 = HEAP32[$64>>2]|0;
  $66 = ((($65)) + -12|0);
  $67 = HEAP32[$66>>2]|0;
  $68 = (($64) + ($67)|0);
  __ZNKSt3__28ios_base6getlocEv($3,$68);
  __THREW__ = 0;
  $69 = (invoke_iii(3255,($3|0),(215188|0))|0);
  $70 = __THREW__; __THREW__ = 0;
  $71 = $70&1;
  if (!($71)) {
   $72 = HEAP32[$69>>2]|0;
   $73 = ((($72)) + 28|0);
   $74 = HEAP32[$73>>2]|0;
   __THREW__ = 0;
   $75 = (invoke_iii($74|0,($69|0),10)|0);
   $76 = __THREW__; __THREW__ = 0;
   $77 = $76&1;
   if (!($77)) {
    __ZNSt3__26localeD2Ev($3);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($64,$75)|0);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($64)|0);
    $$1 = 0;
    STACKTOP = sp;return ($$1|0);
   }
  }
  $78 = ___cxa_find_matching_catch_2()|0;
  $79 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3263,($3|0));
  $80 = __THREW__; __THREW__ = 0;
  $81 = $80&1;
  if ($81) {
   $82 = ___cxa_find_matching_catch_3(0|0)|0;
   $83 = tempRet0;
   ___clang_call_terminate($82);
   // unreachable;
  } else {
   ___resumeException($78|0);
   // unreachable;
  }
 }
 $5 = HEAP32[$0>>2]|0;
 $6 = ((($5)) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_iii[$7 & 8191]($0,$1)|0);
 $9 = ($8|0)==(0|0);
 if ($9) {
  label = 9;
 } else {
  $10 = ((($8)) + 8|0);
  $11 = HEAP32[$10>>2]|0;HEAP32[$10>>2] = (($11+1)|0);
  $12 = (___dynamic_cast($8,26112,26360,0)|0);
  $13 = ($12|0)==(0|0);
  if ($13) {
   label = 9;
  } else {
   __THREW__ = 0;
   (invoke_ii(3335,($8|0))|0);
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if ($15) {
    label = 5;
   } else {
    $$1 = $12;
    STACKTOP = sp;return ($$1|0);
   }
  }
 }
 L19: do {
  if ((label|0) == 9) {
   __THREW__ = 0;
   $23 = (invoke_ii(3265,2)|0);
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   if ($25) {
    label = 5;
   } else {
    do {
     if ($23) {
      __THREW__ = 0;
      $26 = (invoke_ii(3266,2)|0);
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       label = 5;
       break L19;
      }
      __THREW__ = 0;
      $29 = (invoke_iiii(3267,($26|0),(166420|0),88)|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 5;
       break L19;
      }
      $32 = HEAP32[$29>>2]|0;
      $33 = ((($32)) + -12|0);
      $34 = HEAP32[$33>>2]|0;
      $35 = (($29) + ($34)|0);
      __THREW__ = 0;
      invoke_vii(3257,($2|0),($35|0));
      $36 = __THREW__; __THREW__ = 0;
      $37 = $36&1;
      if ($37) {
       label = 5;
       break L19;
      }
      __THREW__ = 0;
      $38 = (invoke_iii(3255,($2|0),(215188|0))|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       $41 = HEAP32[$38>>2]|0;
       $42 = ((($41)) + 28|0);
       $43 = HEAP32[$42>>2]|0;
       __THREW__ = 0;
       $44 = (invoke_iii($43|0,($38|0),10)|0);
       $45 = __THREW__; __THREW__ = 0;
       $46 = $45&1;
       if (!($46)) {
        __THREW__ = 0;
        invoke_vi(3263,($2|0));
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 5;
         break L19;
        }
        __THREW__ = 0;
        (invoke_iii(3268,($29|0),($44|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 5;
         break L19;
        }
        __THREW__ = 0;
        (invoke_ii(3269,($29|0))|0);
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 5;
         break L19;
        } else {
         break;
        }
       }
      }
      $49 = ___cxa_find_matching_catch_2()|0;
      $50 = tempRet0;
      __THREW__ = 0;
      invoke_vi(3263,($2|0));
      $51 = __THREW__; __THREW__ = 0;
      $52 = $51&1;
      if ($52) {
       $53 = ___cxa_find_matching_catch_3(0|0)|0;
       $54 = tempRet0;
       ___clang_call_terminate($53);
       // unreachable;
      } else {
       $eh$lpad$body$index2Z2D = $50;$eh$lpad$body$indexZ2D = $49;
       break L19;
      }
     }
    } while(0);
    if ($9) {
     $$1 = 0;
     STACKTOP = sp;return ($$1|0);
    }
    $59 = ((($8)) + 8|0);
    $60 = HEAP32[$59>>2]|0;HEAP32[$59>>2] = (($60-1)|0);
    $61 = ($60|0)==(1);
    if (!($61)) {
     $$1 = 0;
     STACKTOP = sp;return ($$1|0);
    }
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($8,1,1);
    $$1 = 0;
    STACKTOP = sp;return ($$1|0);
   }
  }
 } while(0);
 if ((label|0) == 5) {
  $16 = ___cxa_find_matching_catch_2()|0;
  $17 = tempRet0;
  $eh$lpad$body$index2Z2D = $17;$eh$lpad$body$indexZ2D = $16;
 }
 if ($9) {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 $18 = ((($8)) + 8|0);
 $19 = HEAP32[$18>>2]|0;HEAP32[$18>>2] = (($19-1)|0);
 $20 = ($19|0)==(1);
 if (!($20)) {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(3262,($8|0),1,1);
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if ($22) {
  $84 = ___cxa_find_matching_catch_3(0|0)|0;
  $85 = tempRet0;
  ___clang_call_terminate($84);
  // unreachable;
 } else {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 return (0)|0;
}
function __ZN3osg5cloneINS_5ArrayEEEPT_PKS2_RKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp + 4|0;
 $3 = sp;
 $4 = ($0|0)==(0|0);
 if ($4) {
  $62 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
  if (!($62)) {
   $$1 = 0;
   STACKTOP = sp;return ($$1|0);
  }
  $63 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
  $64 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($63,166509,88)|0);
  $65 = HEAP32[$64>>2]|0;
  $66 = ((($65)) + -12|0);
  $67 = HEAP32[$66>>2]|0;
  $68 = (($64) + ($67)|0);
  __ZNKSt3__28ios_base6getlocEv($3,$68);
  __THREW__ = 0;
  $69 = (invoke_iii(3255,($3|0),(215188|0))|0);
  $70 = __THREW__; __THREW__ = 0;
  $71 = $70&1;
  if (!($71)) {
   $72 = HEAP32[$69>>2]|0;
   $73 = ((($72)) + 28|0);
   $74 = HEAP32[$73>>2]|0;
   __THREW__ = 0;
   $75 = (invoke_iii($74|0,($69|0),10)|0);
   $76 = __THREW__; __THREW__ = 0;
   $77 = $76&1;
   if (!($77)) {
    __ZNSt3__26localeD2Ev($3);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($64,$75)|0);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($64)|0);
    $$1 = 0;
    STACKTOP = sp;return ($$1|0);
   }
  }
  $78 = ___cxa_find_matching_catch_2()|0;
  $79 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3263,($3|0));
  $80 = __THREW__; __THREW__ = 0;
  $81 = $80&1;
  if ($81) {
   $82 = ___cxa_find_matching_catch_3(0|0)|0;
   $83 = tempRet0;
   ___clang_call_terminate($82);
   // unreachable;
  } else {
   ___resumeException($78|0);
   // unreachable;
  }
 }
 $5 = HEAP32[$0>>2]|0;
 $6 = ((($5)) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_iii[$7 & 8191]($0,$1)|0);
 $9 = ($8|0)==(0|0);
 if ($9) {
  label = 9;
 } else {
  $10 = ((($8)) + 8|0);
  $11 = HEAP32[$10>>2]|0;HEAP32[$10>>2] = (($11+1)|0);
  $12 = (___dynamic_cast($8,26112,23016,0)|0);
  $13 = ($12|0)==(0|0);
  if ($13) {
   label = 9;
  } else {
   __THREW__ = 0;
   (invoke_ii(3335,($8|0))|0);
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if ($15) {
    label = 5;
   } else {
    $$1 = $12;
    STACKTOP = sp;return ($$1|0);
   }
  }
 }
 L19: do {
  if ((label|0) == 9) {
   __THREW__ = 0;
   $23 = (invoke_ii(3265,2)|0);
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   if ($25) {
    label = 5;
   } else {
    do {
     if ($23) {
      __THREW__ = 0;
      $26 = (invoke_ii(3266,2)|0);
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       label = 5;
       break L19;
      }
      __THREW__ = 0;
      $29 = (invoke_iiii(3267,($26|0),(166420|0),88)|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 5;
       break L19;
      }
      $32 = HEAP32[$29>>2]|0;
      $33 = ((($32)) + -12|0);
      $34 = HEAP32[$33>>2]|0;
      $35 = (($29) + ($34)|0);
      __THREW__ = 0;
      invoke_vii(3257,($2|0),($35|0));
      $36 = __THREW__; __THREW__ = 0;
      $37 = $36&1;
      if ($37) {
       label = 5;
       break L19;
      }
      __THREW__ = 0;
      $38 = (invoke_iii(3255,($2|0),(215188|0))|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       $41 = HEAP32[$38>>2]|0;
       $42 = ((($41)) + 28|0);
       $43 = HEAP32[$42>>2]|0;
       __THREW__ = 0;
       $44 = (invoke_iii($43|0,($38|0),10)|0);
       $45 = __THREW__; __THREW__ = 0;
       $46 = $45&1;
       if (!($46)) {
        __THREW__ = 0;
        invoke_vi(3263,($2|0));
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 5;
         break L19;
        }
        __THREW__ = 0;
        (invoke_iii(3268,($29|0),($44|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 5;
         break L19;
        }
        __THREW__ = 0;
        (invoke_ii(3269,($29|0))|0);
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 5;
         break L19;
        } else {
         break;
        }
       }
      }
      $49 = ___cxa_find_matching_catch_2()|0;
      $50 = tempRet0;
      __THREW__ = 0;
      invoke_vi(3263,($2|0));
      $51 = __THREW__; __THREW__ = 0;
      $52 = $51&1;
      if ($52) {
       $53 = ___cxa_find_matching_catch_3(0|0)|0;
       $54 = tempRet0;
       ___clang_call_terminate($53);
       // unreachable;
      } else {
       $eh$lpad$body$index2Z2D = $50;$eh$lpad$body$indexZ2D = $49;
       break L19;
      }
     }
    } while(0);
    if ($9) {
     $$1 = 0;
     STACKTOP = sp;return ($$1|0);
    }
    $59 = ((($8)) + 8|0);
    $60 = HEAP32[$59>>2]|0;HEAP32[$59>>2] = (($60-1)|0);
    $61 = ($60|0)==(1);
    if (!($61)) {
     $$1 = 0;
     STACKTOP = sp;return ($$1|0);
    }
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($8,1,1);
    $$1 = 0;
    STACKTOP = sp;return ($$1|0);
   }
  }
 } while(0);
 if ((label|0) == 5) {
  $16 = ___cxa_find_matching_catch_2()|0;
  $17 = tempRet0;
  $eh$lpad$body$index2Z2D = $17;$eh$lpad$body$indexZ2D = $16;
 }
 if ($9) {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 $18 = ((($8)) + 8|0);
 $19 = HEAP32[$18>>2]|0;HEAP32[$18>>2] = (($19-1)|0);
 $20 = ($19|0)==(1);
 if (!($20)) {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(3262,($8|0),1,1);
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if ($22) {
  $84 = ___cxa_find_matching_catch_3(0|0)|0;
  $85 = tempRet0;
  ___clang_call_terminate($84);
  // unreachable;
 } else {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 return (0)|0;
}
function __ZN3osg5cloneINS_5ImageEEEPT_PKS2_RKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp + 4|0;
 $3 = sp;
 $4 = ($0|0)==(0|0);
 if ($4) {
  $62 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
  if (!($62)) {
   $$1 = 0;
   STACKTOP = sp;return ($$1|0);
  }
  $63 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
  $64 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($63,166509,88)|0);
  $65 = HEAP32[$64>>2]|0;
  $66 = ((($65)) + -12|0);
  $67 = HEAP32[$66>>2]|0;
  $68 = (($64) + ($67)|0);
  __ZNKSt3__28ios_base6getlocEv($3,$68);
  __THREW__ = 0;
  $69 = (invoke_iii(3255,($3|0),(215188|0))|0);
  $70 = __THREW__; __THREW__ = 0;
  $71 = $70&1;
  if (!($71)) {
   $72 = HEAP32[$69>>2]|0;
   $73 = ((($72)) + 28|0);
   $74 = HEAP32[$73>>2]|0;
   __THREW__ = 0;
   $75 = (invoke_iii($74|0,($69|0),10)|0);
   $76 = __THREW__; __THREW__ = 0;
   $77 = $76&1;
   if (!($77)) {
    __ZNSt3__26localeD2Ev($3);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($64,$75)|0);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($64)|0);
    $$1 = 0;
    STACKTOP = sp;return ($$1|0);
   }
  }
  $78 = ___cxa_find_matching_catch_2()|0;
  $79 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3263,($3|0));
  $80 = __THREW__; __THREW__ = 0;
  $81 = $80&1;
  if ($81) {
   $82 = ___cxa_find_matching_catch_3(0|0)|0;
   $83 = tempRet0;
   ___clang_call_terminate($82);
   // unreachable;
  } else {
   ___resumeException($78|0);
   // unreachable;
  }
 }
 $5 = HEAP32[$0>>2]|0;
 $6 = ((($5)) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_iii[$7 & 8191]($0,$1)|0);
 $9 = ($8|0)==(0|0);
 if ($9) {
  label = 9;
 } else {
  $10 = ((($8)) + 8|0);
  $11 = HEAP32[$10>>2]|0;HEAP32[$10>>2] = (($11+1)|0);
  $12 = (___dynamic_cast($8,26112,25320,0)|0);
  $13 = ($12|0)==(0|0);
  if ($13) {
   label = 9;
  } else {
   __THREW__ = 0;
   (invoke_ii(3335,($8|0))|0);
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if ($15) {
    label = 5;
   } else {
    $$1 = $12;
    STACKTOP = sp;return ($$1|0);
   }
  }
 }
 L19: do {
  if ((label|0) == 9) {
   __THREW__ = 0;
   $23 = (invoke_ii(3265,2)|0);
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   if ($25) {
    label = 5;
   } else {
    do {
     if ($23) {
      __THREW__ = 0;
      $26 = (invoke_ii(3266,2)|0);
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       label = 5;
       break L19;
      }
      __THREW__ = 0;
      $29 = (invoke_iiii(3267,($26|0),(166420|0),88)|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 5;
       break L19;
      }
      $32 = HEAP32[$29>>2]|0;
      $33 = ((($32)) + -12|0);
      $34 = HEAP32[$33>>2]|0;
      $35 = (($29) + ($34)|0);
      __THREW__ = 0;
      invoke_vii(3257,($2|0),($35|0));
      $36 = __THREW__; __THREW__ = 0;
      $37 = $36&1;
      if ($37) {
       label = 5;
       break L19;
      }
      __THREW__ = 0;
      $38 = (invoke_iii(3255,($2|0),(215188|0))|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       $41 = HEAP32[$38>>2]|0;
       $42 = ((($41)) + 28|0);
       $43 = HEAP32[$42>>2]|0;
       __THREW__ = 0;
       $44 = (invoke_iii($43|0,($38|0),10)|0);
       $45 = __THREW__; __THREW__ = 0;
       $46 = $45&1;
       if (!($46)) {
        __THREW__ = 0;
        invoke_vi(3263,($2|0));
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 5;
         break L19;
        }
        __THREW__ = 0;
        (invoke_iii(3268,($29|0),($44|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 5;
         break L19;
        }
        __THREW__ = 0;
        (invoke_ii(3269,($29|0))|0);
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 5;
         break L19;
        } else {
         break;
        }
       }
      }
      $49 = ___cxa_find_matching_catch_2()|0;
      $50 = tempRet0;
      __THREW__ = 0;
      invoke_vi(3263,($2|0));
      $51 = __THREW__; __THREW__ = 0;
      $52 = $51&1;
      if ($52) {
       $53 = ___cxa_find_matching_catch_3(0|0)|0;
       $54 = tempRet0;
       ___clang_call_terminate($53);
       // unreachable;
      } else {
       $eh$lpad$body$index2Z2D = $50;$eh$lpad$body$indexZ2D = $49;
       break L19;
      }
     }
    } while(0);
    if ($9) {
     $$1 = 0;
     STACKTOP = sp;return ($$1|0);
    }
    $59 = ((($8)) + 8|0);
    $60 = HEAP32[$59>>2]|0;HEAP32[$59>>2] = (($60-1)|0);
    $61 = ($60|0)==(1);
    if (!($61)) {
     $$1 = 0;
     STACKTOP = sp;return ($$1|0);
    }
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($8,1,1);
    $$1 = 0;
    STACKTOP = sp;return ($$1|0);
   }
  }
 } while(0);
 if ((label|0) == 5) {
  $16 = ___cxa_find_matching_catch_2()|0;
  $17 = tempRet0;
  $eh$lpad$body$index2Z2D = $17;$eh$lpad$body$indexZ2D = $16;
 }
 if ($9) {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 $18 = ((($8)) + 8|0);
 $19 = HEAP32[$18>>2]|0;HEAP32[$18>>2] = (($19-1)|0);
 $20 = ($19|0)==(1);
 if (!($20)) {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(3262,($8|0),1,1);
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if ($22) {
  $84 = ___cxa_find_matching_catch_3(0|0)|0;
  $85 = tempRet0;
  ___clang_call_terminate($84);
  // unreachable;
 } else {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 return (0)|0;
}
function __ZN3osg5cloneINS_7TextureEEEPT_PKS2_RKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp + 4|0;
 $3 = sp;
 $4 = ($0|0)==(0|0);
 if ($4) {
  $62 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
  if (!($62)) {
   $$1 = 0;
   STACKTOP = sp;return ($$1|0);
  }
  $63 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
  $64 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($63,166509,88)|0);
  $65 = HEAP32[$64>>2]|0;
  $66 = ((($65)) + -12|0);
  $67 = HEAP32[$66>>2]|0;
  $68 = (($64) + ($67)|0);
  __ZNKSt3__28ios_base6getlocEv($3,$68);
  __THREW__ = 0;
  $69 = (invoke_iii(3255,($3|0),(215188|0))|0);
  $70 = __THREW__; __THREW__ = 0;
  $71 = $70&1;
  if (!($71)) {
   $72 = HEAP32[$69>>2]|0;
   $73 = ((($72)) + 28|0);
   $74 = HEAP32[$73>>2]|0;
   __THREW__ = 0;
   $75 = (invoke_iii($74|0,($69|0),10)|0);
   $76 = __THREW__; __THREW__ = 0;
   $77 = $76&1;
   if (!($77)) {
    __ZNSt3__26localeD2Ev($3);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($64,$75)|0);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($64)|0);
    $$1 = 0;
    STACKTOP = sp;return ($$1|0);
   }
  }
  $78 = ___cxa_find_matching_catch_2()|0;
  $79 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3263,($3|0));
  $80 = __THREW__; __THREW__ = 0;
  $81 = $80&1;
  if ($81) {
   $82 = ___cxa_find_matching_catch_3(0|0)|0;
   $83 = tempRet0;
   ___clang_call_terminate($82);
   // unreachable;
  } else {
   ___resumeException($78|0);
   // unreachable;
  }
 }
 $5 = HEAP32[$0>>2]|0;
 $6 = ((($5)) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_iii[$7 & 8191]($0,$1)|0);
 $9 = ($8|0)==(0|0);
 if ($9) {
  label = 9;
 } else {
  $10 = ((($8)) + 8|0);
  $11 = HEAP32[$10>>2]|0;HEAP32[$10>>2] = (($11+1)|0);
  $12 = (___dynamic_cast($8,26112,26864,0)|0);
  $13 = ($12|0)==(0|0);
  if ($13) {
   label = 9;
  } else {
   __THREW__ = 0;
   (invoke_ii(3335,($8|0))|0);
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if ($15) {
    label = 5;
   } else {
    $$1 = $12;
    STACKTOP = sp;return ($$1|0);
   }
  }
 }
 L19: do {
  if ((label|0) == 9) {
   __THREW__ = 0;
   $23 = (invoke_ii(3265,2)|0);
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   if ($25) {
    label = 5;
   } else {
    do {
     if ($23) {
      __THREW__ = 0;
      $26 = (invoke_ii(3266,2)|0);
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       label = 5;
       break L19;
      }
      __THREW__ = 0;
      $29 = (invoke_iiii(3267,($26|0),(166420|0),88)|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 5;
       break L19;
      }
      $32 = HEAP32[$29>>2]|0;
      $33 = ((($32)) + -12|0);
      $34 = HEAP32[$33>>2]|0;
      $35 = (($29) + ($34)|0);
      __THREW__ = 0;
      invoke_vii(3257,($2|0),($35|0));
      $36 = __THREW__; __THREW__ = 0;
      $37 = $36&1;
      if ($37) {
       label = 5;
       break L19;
      }
      __THREW__ = 0;
      $38 = (invoke_iii(3255,($2|0),(215188|0))|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       $41 = HEAP32[$38>>2]|0;
       $42 = ((($41)) + 28|0);
       $43 = HEAP32[$42>>2]|0;
       __THREW__ = 0;
       $44 = (invoke_iii($43|0,($38|0),10)|0);
       $45 = __THREW__; __THREW__ = 0;
       $46 = $45&1;
       if (!($46)) {
        __THREW__ = 0;
        invoke_vi(3263,($2|0));
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 5;
         break L19;
        }
        __THREW__ = 0;
        (invoke_iii(3268,($29|0),($44|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 5;
         break L19;
        }
        __THREW__ = 0;
        (invoke_ii(3269,($29|0))|0);
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 5;
         break L19;
        } else {
         break;
        }
       }
      }
      $49 = ___cxa_find_matching_catch_2()|0;
      $50 = tempRet0;
      __THREW__ = 0;
      invoke_vi(3263,($2|0));
      $51 = __THREW__; __THREW__ = 0;
      $52 = $51&1;
      if ($52) {
       $53 = ___cxa_find_matching_catch_3(0|0)|0;
       $54 = tempRet0;
       ___clang_call_terminate($53);
       // unreachable;
      } else {
       $eh$lpad$body$index2Z2D = $50;$eh$lpad$body$indexZ2D = $49;
       break L19;
      }
     }
    } while(0);
    if ($9) {
     $$1 = 0;
     STACKTOP = sp;return ($$1|0);
    }
    $59 = ((($8)) + 8|0);
    $60 = HEAP32[$59>>2]|0;HEAP32[$59>>2] = (($60-1)|0);
    $61 = ($60|0)==(1);
    if (!($61)) {
     $$1 = 0;
     STACKTOP = sp;return ($$1|0);
    }
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($8,1,1);
    $$1 = 0;
    STACKTOP = sp;return ($$1|0);
   }
  }
 } while(0);
 if ((label|0) == 5) {
  $16 = ___cxa_find_matching_catch_2()|0;
  $17 = tempRet0;
  $eh$lpad$body$index2Z2D = $17;$eh$lpad$body$indexZ2D = $16;
 }
 if ($9) {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 $18 = ((($8)) + 8|0);
 $19 = HEAP32[$18>>2]|0;HEAP32[$18>>2] = (($19-1)|0);
 $20 = ($19|0)==(1);
 if (!($20)) {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(3262,($8|0),1,1);
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if ($22) {
  $84 = ___cxa_find_matching_catch_3(0|0)|0;
  $85 = tempRet0;
  ___clang_call_terminate($84);
  // unreachable;
 } else {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 return (0)|0;
}
function __ZN3osg5cloneINS_14StateAttributeEEEPT_PKS2_RKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp + 4|0;
 $3 = sp;
 $4 = ($0|0)==(0|0);
 if ($4) {
  $62 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
  if (!($62)) {
   $$1 = 0;
   STACKTOP = sp;return ($$1|0);
  }
  $63 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
  $64 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($63,166509,88)|0);
  $65 = HEAP32[$64>>2]|0;
  $66 = ((($65)) + -12|0);
  $67 = HEAP32[$66>>2]|0;
  $68 = (($64) + ($67)|0);
  __ZNKSt3__28ios_base6getlocEv($3,$68);
  __THREW__ = 0;
  $69 = (invoke_iii(3255,($3|0),(215188|0))|0);
  $70 = __THREW__; __THREW__ = 0;
  $71 = $70&1;
  if (!($71)) {
   $72 = HEAP32[$69>>2]|0;
   $73 = ((($72)) + 28|0);
   $74 = HEAP32[$73>>2]|0;
   __THREW__ = 0;
   $75 = (invoke_iii($74|0,($69|0),10)|0);
   $76 = __THREW__; __THREW__ = 0;
   $77 = $76&1;
   if (!($77)) {
    __ZNSt3__26localeD2Ev($3);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($64,$75)|0);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($64)|0);
    $$1 = 0;
    STACKTOP = sp;return ($$1|0);
   }
  }
  $78 = ___cxa_find_matching_catch_2()|0;
  $79 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3263,($3|0));
  $80 = __THREW__; __THREW__ = 0;
  $81 = $80&1;
  if ($81) {
   $82 = ___cxa_find_matching_catch_3(0|0)|0;
   $83 = tempRet0;
   ___clang_call_terminate($82);
   // unreachable;
  } else {
   ___resumeException($78|0);
   // unreachable;
  }
 }
 $5 = HEAP32[$0>>2]|0;
 $6 = ((($5)) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_iii[$7 & 8191]($0,$1)|0);
 $9 = ($8|0)==(0|0);
 if ($9) {
  label = 9;
 } else {
  $10 = ((($8)) + 8|0);
  $11 = HEAP32[$10>>2]|0;HEAP32[$10>>2] = (($11+1)|0);
  $12 = (___dynamic_cast($8,26112,19768,0)|0);
  $13 = ($12|0)==(0|0);
  if ($13) {
   label = 9;
  } else {
   __THREW__ = 0;
   (invoke_ii(3335,($8|0))|0);
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if ($15) {
    label = 5;
   } else {
    $$1 = $12;
    STACKTOP = sp;return ($$1|0);
   }
  }
 }
 L19: do {
  if ((label|0) == 9) {
   __THREW__ = 0;
   $23 = (invoke_ii(3265,2)|0);
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   if ($25) {
    label = 5;
   } else {
    do {
     if ($23) {
      __THREW__ = 0;
      $26 = (invoke_ii(3266,2)|0);
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       label = 5;
       break L19;
      }
      __THREW__ = 0;
      $29 = (invoke_iiii(3267,($26|0),(166420|0),88)|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 5;
       break L19;
      }
      $32 = HEAP32[$29>>2]|0;
      $33 = ((($32)) + -12|0);
      $34 = HEAP32[$33>>2]|0;
      $35 = (($29) + ($34)|0);
      __THREW__ = 0;
      invoke_vii(3257,($2|0),($35|0));
      $36 = __THREW__; __THREW__ = 0;
      $37 = $36&1;
      if ($37) {
       label = 5;
       break L19;
      }
      __THREW__ = 0;
      $38 = (invoke_iii(3255,($2|0),(215188|0))|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       $41 = HEAP32[$38>>2]|0;
       $42 = ((($41)) + 28|0);
       $43 = HEAP32[$42>>2]|0;
       __THREW__ = 0;
       $44 = (invoke_iii($43|0,($38|0),10)|0);
       $45 = __THREW__; __THREW__ = 0;
       $46 = $45&1;
       if (!($46)) {
        __THREW__ = 0;
        invoke_vi(3263,($2|0));
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 5;
         break L19;
        }
        __THREW__ = 0;
        (invoke_iii(3268,($29|0),($44|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 5;
         break L19;
        }
        __THREW__ = 0;
        (invoke_ii(3269,($29|0))|0);
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 5;
         break L19;
        } else {
         break;
        }
       }
      }
      $49 = ___cxa_find_matching_catch_2()|0;
      $50 = tempRet0;
      __THREW__ = 0;
      invoke_vi(3263,($2|0));
      $51 = __THREW__; __THREW__ = 0;
      $52 = $51&1;
      if ($52) {
       $53 = ___cxa_find_matching_catch_3(0|0)|0;
       $54 = tempRet0;
       ___clang_call_terminate($53);
       // unreachable;
      } else {
       $eh$lpad$body$index2Z2D = $50;$eh$lpad$body$indexZ2D = $49;
       break L19;
      }
     }
    } while(0);
    if ($9) {
     $$1 = 0;
     STACKTOP = sp;return ($$1|0);
    }
    $59 = ((($8)) + 8|0);
    $60 = HEAP32[$59>>2]|0;HEAP32[$59>>2] = (($60-1)|0);
    $61 = ($60|0)==(1);
    if (!($61)) {
     $$1 = 0;
     STACKTOP = sp;return ($$1|0);
    }
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($8,1,1);
    $$1 = 0;
    STACKTOP = sp;return ($$1|0);
   }
  }
 } while(0);
 if ((label|0) == 5) {
  $16 = ___cxa_find_matching_catch_2()|0;
  $17 = tempRet0;
  $eh$lpad$body$index2Z2D = $17;$eh$lpad$body$indexZ2D = $16;
 }
 if ($9) {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 $18 = ((($8)) + 8|0);
 $19 = HEAP32[$18>>2]|0;HEAP32[$18>>2] = (($19-1)|0);
 $20 = ($19|0)==(1);
 if (!($20)) {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(3262,($8|0),1,1);
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if ($22) {
  $84 = ___cxa_find_matching_catch_3(0|0)|0;
  $85 = tempRet0;
  ___clang_call_terminate($84);
  // unreachable;
 } else {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 return (0)|0;
}
function __ZN3osg5cloneINS_8StateSetEEEPT_PKS2_RKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp + 4|0;
 $3 = sp;
 $4 = ($0|0)==(0|0);
 if ($4) {
  $62 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
  if (!($62)) {
   $$1 = 0;
   STACKTOP = sp;return ($$1|0);
  }
  $63 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
  $64 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($63,166509,88)|0);
  $65 = HEAP32[$64>>2]|0;
  $66 = ((($65)) + -12|0);
  $67 = HEAP32[$66>>2]|0;
  $68 = (($64) + ($67)|0);
  __ZNKSt3__28ios_base6getlocEv($3,$68);
  __THREW__ = 0;
  $69 = (invoke_iii(3255,($3|0),(215188|0))|0);
  $70 = __THREW__; __THREW__ = 0;
  $71 = $70&1;
  if (!($71)) {
   $72 = HEAP32[$69>>2]|0;
   $73 = ((($72)) + 28|0);
   $74 = HEAP32[$73>>2]|0;
   __THREW__ = 0;
   $75 = (invoke_iii($74|0,($69|0),10)|0);
   $76 = __THREW__; __THREW__ = 0;
   $77 = $76&1;
   if (!($77)) {
    __ZNSt3__26localeD2Ev($3);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($64,$75)|0);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($64)|0);
    $$1 = 0;
    STACKTOP = sp;return ($$1|0);
   }
  }
  $78 = ___cxa_find_matching_catch_2()|0;
  $79 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3263,($3|0));
  $80 = __THREW__; __THREW__ = 0;
  $81 = $80&1;
  if ($81) {
   $82 = ___cxa_find_matching_catch_3(0|0)|0;
   $83 = tempRet0;
   ___clang_call_terminate($82);
   // unreachable;
  } else {
   ___resumeException($78|0);
   // unreachable;
  }
 }
 $5 = HEAP32[$0>>2]|0;
 $6 = ((($5)) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_iii[$7 & 8191]($0,$1)|0);
 $9 = ($8|0)==(0|0);
 if ($9) {
  label = 9;
 } else {
  $10 = ((($8)) + 8|0);
  $11 = HEAP32[$10>>2]|0;HEAP32[$10>>2] = (($11+1)|0);
  $12 = (___dynamic_cast($8,26112,26648,0)|0);
  $13 = ($12|0)==(0|0);
  if ($13) {
   label = 9;
  } else {
   __THREW__ = 0;
   (invoke_ii(3335,($8|0))|0);
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if ($15) {
    label = 5;
   } else {
    $$1 = $12;
    STACKTOP = sp;return ($$1|0);
   }
  }
 }
 L19: do {
  if ((label|0) == 9) {
   __THREW__ = 0;
   $23 = (invoke_ii(3265,2)|0);
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   if ($25) {
    label = 5;
   } else {
    do {
     if ($23) {
      __THREW__ = 0;
      $26 = (invoke_ii(3266,2)|0);
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       label = 5;
       break L19;
      }
      __THREW__ = 0;
      $29 = (invoke_iiii(3267,($26|0),(166420|0),88)|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 5;
       break L19;
      }
      $32 = HEAP32[$29>>2]|0;
      $33 = ((($32)) + -12|0);
      $34 = HEAP32[$33>>2]|0;
      $35 = (($29) + ($34)|0);
      __THREW__ = 0;
      invoke_vii(3257,($2|0),($35|0));
      $36 = __THREW__; __THREW__ = 0;
      $37 = $36&1;
      if ($37) {
       label = 5;
       break L19;
      }
      __THREW__ = 0;
      $38 = (invoke_iii(3255,($2|0),(215188|0))|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       $41 = HEAP32[$38>>2]|0;
       $42 = ((($41)) + 28|0);
       $43 = HEAP32[$42>>2]|0;
       __THREW__ = 0;
       $44 = (invoke_iii($43|0,($38|0),10)|0);
       $45 = __THREW__; __THREW__ = 0;
       $46 = $45&1;
       if (!($46)) {
        __THREW__ = 0;
        invoke_vi(3263,($2|0));
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 5;
         break L19;
        }
        __THREW__ = 0;
        (invoke_iii(3268,($29|0),($44|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 5;
         break L19;
        }
        __THREW__ = 0;
        (invoke_ii(3269,($29|0))|0);
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 5;
         break L19;
        } else {
         break;
        }
       }
      }
      $49 = ___cxa_find_matching_catch_2()|0;
      $50 = tempRet0;
      __THREW__ = 0;
      invoke_vi(3263,($2|0));
      $51 = __THREW__; __THREW__ = 0;
      $52 = $51&1;
      if ($52) {
       $53 = ___cxa_find_matching_catch_3(0|0)|0;
       $54 = tempRet0;
       ___clang_call_terminate($53);
       // unreachable;
      } else {
       $eh$lpad$body$index2Z2D = $50;$eh$lpad$body$indexZ2D = $49;
       break L19;
      }
     }
    } while(0);
    if ($9) {
     $$1 = 0;
     STACKTOP = sp;return ($$1|0);
    }
    $59 = ((($8)) + 8|0);
    $60 = HEAP32[$59>>2]|0;HEAP32[$59>>2] = (($60-1)|0);
    $61 = ($60|0)==(1);
    if (!($61)) {
     $$1 = 0;
     STACKTOP = sp;return ($$1|0);
    }
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($8,1,1);
    $$1 = 0;
    STACKTOP = sp;return ($$1|0);
   }
  }
 } while(0);
 if ((label|0) == 5) {
  $16 = ___cxa_find_matching_catch_2()|0;
  $17 = tempRet0;
  $eh$lpad$body$index2Z2D = $17;$eh$lpad$body$indexZ2D = $16;
 }
 if ($9) {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 $18 = ((($8)) + 8|0);
 $19 = HEAP32[$18>>2]|0;HEAP32[$18>>2] = (($19-1)|0);
 $20 = ($19|0)==(1);
 if (!($20)) {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(3262,($8|0),1,1);
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if ($22) {
  $84 = ___cxa_find_matching_catch_3(0|0)|0;
  $85 = tempRet0;
  ___clang_call_terminate($84);
  // unreachable;
 } else {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 return (0)|0;
}
function __ZN3osg5cloneINS_8DrawableEEEPT_PKS2_RKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp + 4|0;
 $3 = sp;
 $4 = ($0|0)==(0|0);
 if ($4) {
  $62 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
  if (!($62)) {
   $$1 = 0;
   STACKTOP = sp;return ($$1|0);
  }
  $63 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
  $64 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($63,166509,88)|0);
  $65 = HEAP32[$64>>2]|0;
  $66 = ((($65)) + -12|0);
  $67 = HEAP32[$66>>2]|0;
  $68 = (($64) + ($67)|0);
  __ZNKSt3__28ios_base6getlocEv($3,$68);
  __THREW__ = 0;
  $69 = (invoke_iii(3255,($3|0),(215188|0))|0);
  $70 = __THREW__; __THREW__ = 0;
  $71 = $70&1;
  if (!($71)) {
   $72 = HEAP32[$69>>2]|0;
   $73 = ((($72)) + 28|0);
   $74 = HEAP32[$73>>2]|0;
   __THREW__ = 0;
   $75 = (invoke_iii($74|0,($69|0),10)|0);
   $76 = __THREW__; __THREW__ = 0;
   $77 = $76&1;
   if (!($77)) {
    __ZNSt3__26localeD2Ev($3);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($64,$75)|0);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($64)|0);
    $$1 = 0;
    STACKTOP = sp;return ($$1|0);
   }
  }
  $78 = ___cxa_find_matching_catch_2()|0;
  $79 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3263,($3|0));
  $80 = __THREW__; __THREW__ = 0;
  $81 = $80&1;
  if ($81) {
   $82 = ___cxa_find_matching_catch_3(0|0)|0;
   $83 = tempRet0;
   ___clang_call_terminate($82);
   // unreachable;
  } else {
   ___resumeException($78|0);
   // unreachable;
  }
 }
 $5 = HEAP32[$0>>2]|0;
 $6 = ((($5)) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_iii[$7 & 8191]($0,$1)|0);
 $9 = ($8|0)==(0|0);
 if ($9) {
  label = 9;
 } else {
  $10 = ((($8)) + 8|0);
  $11 = HEAP32[$10>>2]|0;HEAP32[$10>>2] = (($11+1)|0);
  $12 = (___dynamic_cast($8,26112,24472,0)|0);
  $13 = ($12|0)==(0|0);
  if ($13) {
   label = 9;
  } else {
   __THREW__ = 0;
   (invoke_ii(3335,($8|0))|0);
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if ($15) {
    label = 5;
   } else {
    $$1 = $12;
    STACKTOP = sp;return ($$1|0);
   }
  }
 }
 L19: do {
  if ((label|0) == 9) {
   __THREW__ = 0;
   $23 = (invoke_ii(3265,2)|0);
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   if ($25) {
    label = 5;
   } else {
    do {
     if ($23) {
      __THREW__ = 0;
      $26 = (invoke_ii(3266,2)|0);
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       label = 5;
       break L19;
      }
      __THREW__ = 0;
      $29 = (invoke_iiii(3267,($26|0),(166420|0),88)|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 5;
       break L19;
      }
      $32 = HEAP32[$29>>2]|0;
      $33 = ((($32)) + -12|0);
      $34 = HEAP32[$33>>2]|0;
      $35 = (($29) + ($34)|0);
      __THREW__ = 0;
      invoke_vii(3257,($2|0),($35|0));
      $36 = __THREW__; __THREW__ = 0;
      $37 = $36&1;
      if ($37) {
       label = 5;
       break L19;
      }
      __THREW__ = 0;
      $38 = (invoke_iii(3255,($2|0),(215188|0))|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       $41 = HEAP32[$38>>2]|0;
       $42 = ((($41)) + 28|0);
       $43 = HEAP32[$42>>2]|0;
       __THREW__ = 0;
       $44 = (invoke_iii($43|0,($38|0),10)|0);
       $45 = __THREW__; __THREW__ = 0;
       $46 = $45&1;
       if (!($46)) {
        __THREW__ = 0;
        invoke_vi(3263,($2|0));
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 5;
         break L19;
        }
        __THREW__ = 0;
        (invoke_iii(3268,($29|0),($44|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 5;
         break L19;
        }
        __THREW__ = 0;
        (invoke_ii(3269,($29|0))|0);
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 5;
         break L19;
        } else {
         break;
        }
       }
      }
      $49 = ___cxa_find_matching_catch_2()|0;
      $50 = tempRet0;
      __THREW__ = 0;
      invoke_vi(3263,($2|0));
      $51 = __THREW__; __THREW__ = 0;
      $52 = $51&1;
      if ($52) {
       $53 = ___cxa_find_matching_catch_3(0|0)|0;
       $54 = tempRet0;
       ___clang_call_terminate($53);
       // unreachable;
      } else {
       $eh$lpad$body$index2Z2D = $50;$eh$lpad$body$indexZ2D = $49;
       break L19;
      }
     }
    } while(0);
    if ($9) {
     $$1 = 0;
     STACKTOP = sp;return ($$1|0);
    }
    $59 = ((($8)) + 8|0);
    $60 = HEAP32[$59>>2]|0;HEAP32[$59>>2] = (($60-1)|0);
    $61 = ($60|0)==(1);
    if (!($61)) {
     $$1 = 0;
     STACKTOP = sp;return ($$1|0);
    }
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($8,1,1);
    $$1 = 0;
    STACKTOP = sp;return ($$1|0);
   }
  }
 } while(0);
 if ((label|0) == 5) {
  $16 = ___cxa_find_matching_catch_2()|0;
  $17 = tempRet0;
  $eh$lpad$body$index2Z2D = $17;$eh$lpad$body$indexZ2D = $16;
 }
 if ($9) {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 $18 = ((($8)) + 8|0);
 $19 = HEAP32[$18>>2]|0;HEAP32[$18>>2] = (($19-1)|0);
 $20 = ($19|0)==(1);
 if (!($20)) {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(3262,($8|0),1,1);
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if ($22) {
  $84 = ___cxa_find_matching_catch_3(0|0)|0;
  $85 = tempRet0;
  ___clang_call_terminate($84);
  // unreachable;
 } else {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 return (0)|0;
}
function __ZN3osg5cloneINS_4NodeEEEPT_PKS2_RKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp + 4|0;
 $3 = sp;
 $4 = ($0|0)==(0|0);
 if ($4) {
  $62 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
  if (!($62)) {
   $$1 = 0;
   STACKTOP = sp;return ($$1|0);
  }
  $63 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
  $64 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($63,166509,88)|0);
  $65 = HEAP32[$64>>2]|0;
  $66 = ((($65)) + -12|0);
  $67 = HEAP32[$66>>2]|0;
  $68 = (($64) + ($67)|0);
  __ZNKSt3__28ios_base6getlocEv($3,$68);
  __THREW__ = 0;
  $69 = (invoke_iii(3255,($3|0),(215188|0))|0);
  $70 = __THREW__; __THREW__ = 0;
  $71 = $70&1;
  if (!($71)) {
   $72 = HEAP32[$69>>2]|0;
   $73 = ((($72)) + 28|0);
   $74 = HEAP32[$73>>2]|0;
   __THREW__ = 0;
   $75 = (invoke_iii($74|0,($69|0),10)|0);
   $76 = __THREW__; __THREW__ = 0;
   $77 = $76&1;
   if (!($77)) {
    __ZNSt3__26localeD2Ev($3);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($64,$75)|0);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($64)|0);
    $$1 = 0;
    STACKTOP = sp;return ($$1|0);
   }
  }
  $78 = ___cxa_find_matching_catch_2()|0;
  $79 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3263,($3|0));
  $80 = __THREW__; __THREW__ = 0;
  $81 = $80&1;
  if ($81) {
   $82 = ___cxa_find_matching_catch_3(0|0)|0;
   $83 = tempRet0;
   ___clang_call_terminate($82);
   // unreachable;
  } else {
   ___resumeException($78|0);
   // unreachable;
  }
 }
 $5 = HEAP32[$0>>2]|0;
 $6 = ((($5)) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_iii[$7 & 8191]($0,$1)|0);
 $9 = ($8|0)==(0|0);
 if ($9) {
  label = 9;
 } else {
  $10 = ((($8)) + 8|0);
  $11 = HEAP32[$10>>2]|0;HEAP32[$10>>2] = (($11+1)|0);
  $12 = (___dynamic_cast($8,26112,25952,0)|0);
  $13 = ($12|0)==(0|0);
  if ($13) {
   label = 9;
  } else {
   __THREW__ = 0;
   (invoke_ii(3335,($8|0))|0);
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if ($15) {
    label = 5;
   } else {
    $$1 = $12;
    STACKTOP = sp;return ($$1|0);
   }
  }
 }
 L19: do {
  if ((label|0) == 9) {
   __THREW__ = 0;
   $23 = (invoke_ii(3265,2)|0);
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   if ($25) {
    label = 5;
   } else {
    do {
     if ($23) {
      __THREW__ = 0;
      $26 = (invoke_ii(3266,2)|0);
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       label = 5;
       break L19;
      }
      __THREW__ = 0;
      $29 = (invoke_iiii(3267,($26|0),(166420|0),88)|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 5;
       break L19;
      }
      $32 = HEAP32[$29>>2]|0;
      $33 = ((($32)) + -12|0);
      $34 = HEAP32[$33>>2]|0;
      $35 = (($29) + ($34)|0);
      __THREW__ = 0;
      invoke_vii(3257,($2|0),($35|0));
      $36 = __THREW__; __THREW__ = 0;
      $37 = $36&1;
      if ($37) {
       label = 5;
       break L19;
      }
      __THREW__ = 0;
      $38 = (invoke_iii(3255,($2|0),(215188|0))|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       $41 = HEAP32[$38>>2]|0;
       $42 = ((($41)) + 28|0);
       $43 = HEAP32[$42>>2]|0;
       __THREW__ = 0;
       $44 = (invoke_iii($43|0,($38|0),10)|0);
       $45 = __THREW__; __THREW__ = 0;
       $46 = $45&1;
       if (!($46)) {
        __THREW__ = 0;
        invoke_vi(3263,($2|0));
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 5;
         break L19;
        }
        __THREW__ = 0;
        (invoke_iii(3268,($29|0),($44|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 5;
         break L19;
        }
        __THREW__ = 0;
        (invoke_ii(3269,($29|0))|0);
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 5;
         break L19;
        } else {
         break;
        }
       }
      }
      $49 = ___cxa_find_matching_catch_2()|0;
      $50 = tempRet0;
      __THREW__ = 0;
      invoke_vi(3263,($2|0));
      $51 = __THREW__; __THREW__ = 0;
      $52 = $51&1;
      if ($52) {
       $53 = ___cxa_find_matching_catch_3(0|0)|0;
       $54 = tempRet0;
       ___clang_call_terminate($53);
       // unreachable;
      } else {
       $eh$lpad$body$index2Z2D = $50;$eh$lpad$body$indexZ2D = $49;
       break L19;
      }
     }
    } while(0);
    if ($9) {
     $$1 = 0;
     STACKTOP = sp;return ($$1|0);
    }
    $59 = ((($8)) + 8|0);
    $60 = HEAP32[$59>>2]|0;HEAP32[$59>>2] = (($60-1)|0);
    $61 = ($60|0)==(1);
    if (!($61)) {
     $$1 = 0;
     STACKTOP = sp;return ($$1|0);
    }
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($8,1,1);
    $$1 = 0;
    STACKTOP = sp;return ($$1|0);
   }
  }
 } while(0);
 if ((label|0) == 5) {
  $16 = ___cxa_find_matching_catch_2()|0;
  $17 = tempRet0;
  $eh$lpad$body$index2Z2D = $17;$eh$lpad$body$indexZ2D = $16;
 }
 if ($9) {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 $18 = ((($8)) + 8|0);
 $19 = HEAP32[$18>>2]|0;HEAP32[$18>>2] = (($19-1)|0);
 $20 = ($19|0)==(1);
 if (!($20)) {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(3262,($8|0),1,1);
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if ($22) {
  $84 = ___cxa_find_matching_catch_3(0|0)|0;
  $85 = tempRet0;
  ___clang_call_terminate($84);
  // unreachable;
 } else {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 return (0)|0;
}
function __ZN3osg5cloneINS_6ObjectEEEPT_PKS2_RKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body24$index3Z2D = 0, $eh$lpad$body24$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp + 4|0;
 $3 = sp;
 $4 = ($0|0)==(0|0);
 if ($4) {
  $42 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
  if (!($42)) {
   $$1 = 0;
   STACKTOP = sp;return ($$1|0);
  }
  $43 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
  $44 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($43,166509,88)|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = ((($45)) + -12|0);
  $47 = HEAP32[$46>>2]|0;
  $48 = (($44) + ($47)|0);
  __ZNKSt3__28ios_base6getlocEv($3,$48);
  __THREW__ = 0;
  $49 = (invoke_iii(3255,($3|0),(215188|0))|0);
  $50 = __THREW__; __THREW__ = 0;
  $51 = $50&1;
  if (!($51)) {
   $52 = HEAP32[$49>>2]|0;
   $53 = ((($52)) + 28|0);
   $54 = HEAP32[$53>>2]|0;
   __THREW__ = 0;
   $55 = (invoke_iii($54|0,($49|0),10)|0);
   $56 = __THREW__; __THREW__ = 0;
   $57 = $56&1;
   if (!($57)) {
    __ZNSt3__26localeD2Ev($3);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($44,$55)|0);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($44)|0);
    $$1 = 0;
    STACKTOP = sp;return ($$1|0);
   }
  }
  $58 = ___cxa_find_matching_catch_2()|0;
  $59 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3263,($3|0));
  $60 = __THREW__; __THREW__ = 0;
  $61 = $60&1;
  if ($61) {
   $62 = ___cxa_find_matching_catch_3(0|0)|0;
   $63 = tempRet0;
   ___clang_call_terminate($62);
   // unreachable;
  } else {
   ___resumeException($58|0);
   // unreachable;
  }
 }
 $5 = HEAP32[$0>>2]|0;
 $6 = ((($5)) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_iii[$7 & 8191]($0,$1)|0);
 $9 = ($8|0)==(0|0);
 if (!($9)) {
  $10 = ((($8)) + 8|0);
  $11 = HEAP32[$10>>2]|0;HEAP32[$10>>2] = (($11+1)|0);
  __THREW__ = 0;
  (invoke_ii(3335,($8|0))|0);
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if (!($13)) {
   $$1 = $8;
   STACKTOP = sp;return ($$1|0);
  }
  $14 = ___cxa_find_matching_catch_2()|0;
  $15 = tempRet0;
  $16 = HEAP32[$10>>2]|0;HEAP32[$10>>2] = (($16-1)|0);
  $17 = ($16|0)==(1);
  if (!($17)) {
   $eh$lpad$body24$index3Z2D = $15;$eh$lpad$body24$indexZ2D = $14;
   ___resumeException($eh$lpad$body24$indexZ2D|0);
   // unreachable;
  }
  __THREW__ = 0;
  invoke_viii(3262,($8|0),1,1);
  $18 = __THREW__; __THREW__ = 0;
  $19 = $18&1;
  if ($19) {
   $64 = ___cxa_find_matching_catch_3(0|0)|0;
   $65 = tempRet0;
   ___clang_call_terminate($64);
   // unreachable;
  } else {
   $eh$lpad$body24$index3Z2D = $15;$eh$lpad$body24$indexZ2D = $14;
   ___resumeException($eh$lpad$body24$indexZ2D|0);
   // unreachable;
  }
 }
 $20 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
 if (!($20)) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $21 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
 $22 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($21,166420,88)|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ((($23)) + -12|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($22) + ($25)|0);
 __ZNKSt3__28ios_base6getlocEv($2,$26);
 __THREW__ = 0;
 $27 = (invoke_iii(3255,($2|0),(215188|0))|0);
 $28 = __THREW__; __THREW__ = 0;
 $29 = $28&1;
 if (!($29)) {
  $30 = HEAP32[$27>>2]|0;
  $31 = ((($30)) + 28|0);
  $32 = HEAP32[$31>>2]|0;
  __THREW__ = 0;
  $33 = (invoke_iii($32|0,($27|0),10)|0);
  $34 = __THREW__; __THREW__ = 0;
  $35 = $34&1;
  if (!($35)) {
   __ZNSt3__26localeD2Ev($2);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($22,$33)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($22)|0);
   $$1 = 0;
   STACKTOP = sp;return ($$1|0);
  }
 }
 $36 = ___cxa_find_matching_catch_2()|0;
 $37 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($2|0));
 $38 = __THREW__; __THREW__ = 0;
 $39 = $38&1;
 if ($39) {
  $40 = ___cxa_find_matching_catch_3(0|0)|0;
  $41 = tempRet0;
  ___clang_call_terminate($40);
  // unreachable;
 }
 $eh$lpad$body24$index3Z2D = $37;$eh$lpad$body24$indexZ2D = $36;
 ___resumeException($eh$lpad$body24$indexZ2D|0);
 // unreachable;
 return (0)|0;
}
function __ZN3osg10CullingSetD2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $9 = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i14 = 0, $scevgep$i$i$i$i4 = 0, $scevgep$i$i$i3$i = 0, $scevgep$i$i$i3$i9 = 0, $scevgep5$i$i$i$i = 0, $scevgep5$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i15 = 0, $scevgep5$i$i$i$i5 = 0, $scevgep5$i$i$i4$i = 0, $scevgep5$i$i$i4$i10 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (58212);
 $1 = ((($0)) + 76|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 do {
  if (!($3)) {
   $4 = ((($0)) + 80|0);
   while(1) {
    $5 = HEAP32[$4>>2]|0;
    $6 = ($5|0)==($2|0);
    if ($6) {
     label = 6;
     break;
    }
    $7 = ((($5)) + -80|0);
    HEAP32[$4>>2] = $7;
    __THREW__ = 0;
    invoke_vi(3586,($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     label = 5;
     break;
    }
   }
   if ((label|0) == 5) {
    $10 = ___cxa_find_matching_catch_2()|0;
    $11 = tempRet0;
    ___cxa_call_unexpected(($10|0));
    // unreachable;
   }
   else if ((label|0) == 6) {
    $12 = HEAP32[$1>>2]|0;
    __ZdlPv($12);
    break;
   }
  }
 } while(0);
 $13 = ((($0)) + 64|0);
 __THREW__ = 0;
 invoke_vi(3734,($13|0));
 $14 = __THREW__; __THREW__ = 0;
 $15 = $14&1;
 if (!($15)) {
  $16 = ((($0)) + 52|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = ($17|0)==(0|0);
  if (!($18)) {
   $19 = ((($0)) + 56|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = ($20|0)==($17|0);
   if (!($21)) {
    $scevgep$i$i$i$i = ((($20)) + -12|0);
    $22 = $scevgep$i$i$i$i;
    $23 = $17;
    $24 = (($22) - ($23))|0;
    $25 = (($24>>>0) / 12)&-1;
    $26 = $25 ^ -1;
    $scevgep5$i$i$i$i = (($20) + (($26*12)|0)|0);
    HEAP32[$19>>2] = $scevgep5$i$i$i$i;
   }
   __ZdlPv($17);
  }
  $27 = ((($0)) + 40|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = ($28|0)==(0|0);
  if (!($29)) {
   $30 = ((($0)) + 44|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = ($31|0)==($28|0);
   if (!($32)) {
    $scevgep$i$i$i3$i = ((($31)) + -40|0);
    $33 = $scevgep$i$i$i3$i;
    $34 = $28;
    $35 = (($33) - ($34))|0;
    $36 = (($35>>>0) / 40)&-1;
    $37 = $36 ^ -1;
    $scevgep5$i$i$i4$i = (($31) + (($37*40)|0)|0);
    HEAP32[$30>>2] = $scevgep5$i$i$i4$i;
   }
   __ZdlPv($28);
  }
  $38 = ((($0)) + 20|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = ($39|0)==(0|0);
  if ($40) {
   __ZN3osg10ReferencedD2Ev($0);
   return;
  }
  $41 = ((($0)) + 24|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = ($42|0)==($39|0);
  if (!($43)) {
   $scevgep$i$i$i$i$i = ((($42)) + -4|0);
   $44 = $scevgep$i$i$i$i$i;
   $45 = $39;
   $46 = (($44) - ($45))|0;
   $47 = $46 >>> 2;
   $48 = $47 ^ -1;
   $scevgep5$i$i$i$i$i = (($42) + ($48<<2)|0);
   HEAP32[$41>>2] = $scevgep5$i$i$i$i$i;
  }
  __ZdlPv($39);
  __ZN3osg10ReferencedD2Ev($0);
  return;
 }
 $49 = ___cxa_find_matching_catch_2()|0;
 $50 = tempRet0;
 $51 = ((($0)) + 52|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = ($52|0)==(0|0);
 if (!($53)) {
  $54 = ((($0)) + 56|0);
  $55 = HEAP32[$54>>2]|0;
  $56 = ($55|0)==($52|0);
  if (!($56)) {
   $scevgep$i$i$i$i4 = ((($55)) + -12|0);
   $57 = $scevgep$i$i$i$i4;
   $58 = $52;
   $59 = (($57) - ($58))|0;
   $60 = (($59>>>0) / 12)&-1;
   $61 = $60 ^ -1;
   $scevgep5$i$i$i$i5 = (($55) + (($61*12)|0)|0);
   HEAP32[$54>>2] = $scevgep5$i$i$i$i5;
  }
  __ZdlPv($52);
 }
 $62 = ((($0)) + 40|0);
 $63 = HEAP32[$62>>2]|0;
 $64 = ($63|0)==(0|0);
 if (!($64)) {
  $65 = ((($0)) + 44|0);
  $66 = HEAP32[$65>>2]|0;
  $67 = ($66|0)==($63|0);
  if (!($67)) {
   $scevgep$i$i$i3$i9 = ((($66)) + -40|0);
   $68 = $scevgep$i$i$i3$i9;
   $69 = $63;
   $70 = (($68) - ($69))|0;
   $71 = (($70>>>0) / 40)&-1;
   $72 = $71 ^ -1;
   $scevgep5$i$i$i4$i10 = (($66) + (($72*40)|0)|0);
   HEAP32[$65>>2] = $scevgep5$i$i$i4$i10;
  }
  __ZdlPv($63);
 }
 $73 = ((($0)) + 20|0);
 $74 = HEAP32[$73>>2]|0;
 $75 = ($74|0)==(0|0);
 if (!($75)) {
  $76 = ((($0)) + 24|0);
  $77 = HEAP32[$76>>2]|0;
  $78 = ($77|0)==($74|0);
  if (!($78)) {
   $scevgep$i$i$i$i$i14 = ((($77)) + -4|0);
   $79 = $scevgep$i$i$i$i$i14;
   $80 = $74;
   $81 = (($79) - ($80))|0;
   $82 = $81 >>> 2;
   $83 = $82 ^ -1;
   $scevgep5$i$i$i$i$i15 = (($77) + ($83<<2)|0);
   HEAP32[$76>>2] = $scevgep5$i$i$i$i$i15;
  }
  __ZdlPv($74);
 }
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $84 = __THREW__; __THREW__ = 0;
 $85 = $84&1;
 if ($85) {
  $86 = ___cxa_find_matching_catch_3(0|0)|0;
  $87 = tempRet0;
  ___clang_call_terminate($86);
  // unreachable;
 } else {
  ___resumeException($49|0);
  // unreachable;
 }
}
function __ZN3osg10CullingSetD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1617,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNSt3__213__vector_baseINS_4pairIN3osg7ref_ptrINS2_8StateSetEEENS2_8PolytopeEEENS_9allocatorIS7_EEED2Ev($0) {
 $0 = $0|0;
 var $$pre = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i$i$i = 0, $scevgep$i$i$i3$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i$i$i$i$i = 0, $scevgep5$i$i$i4$i$i$i$i$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 }
 $3 = ((($0)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==($1|0);
 do {
  if ($5) {
   $52 = $1;
  } else {
   $7 = $4;
   while(1) {
    $6 = ((($7)) + -52|0);
    HEAP32[$3>>2] = $6;
    $8 = ((($7)) + -12|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = ($9|0)==(0|0);
    if (!($10)) {
     $11 = ((($7)) + -8|0);
     $12 = HEAP32[$11>>2]|0;
     $13 = ($12|0)==($9|0);
     if (!($13)) {
      $scevgep$i$i$i$i$i$i$i$i = ((($12)) + -12|0);
      $14 = $scevgep$i$i$i$i$i$i$i$i;
      $15 = $9;
      $16 = (($14) - ($15))|0;
      $17 = (($16>>>0) / 12)&-1;
      $18 = $17 ^ -1;
      $scevgep5$i$i$i$i$i$i$i$i = (($12) + (($18*12)|0)|0);
      HEAP32[$11>>2] = $scevgep5$i$i$i$i$i$i$i$i;
     }
     __ZdlPv($9);
    }
    $19 = ((($7)) + -24|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = ($20|0)==(0|0);
    if (!($21)) {
     $22 = ((($7)) + -20|0);
     $23 = HEAP32[$22>>2]|0;
     $24 = ($23|0)==($20|0);
     if (!($24)) {
      $scevgep$i$i$i3$i$i$i$i$i = ((($23)) + -40|0);
      $25 = $scevgep$i$i$i3$i$i$i$i$i;
      $26 = $20;
      $27 = (($25) - ($26))|0;
      $28 = (($27>>>0) / 40)&-1;
      $29 = $28 ^ -1;
      $scevgep5$i$i$i4$i$i$i$i$i = (($23) + (($29*40)|0)|0);
      HEAP32[$22>>2] = $scevgep5$i$i$i4$i$i$i$i$i;
     }
     __ZdlPv($20);
    }
    $30 = ((($7)) + -44|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = ($31|0)==(0|0);
    if (!($32)) {
     $33 = ((($7)) + -40|0);
     $34 = HEAP32[$33>>2]|0;
     $35 = ($34|0)==($31|0);
     if (!($35)) {
      $scevgep$i$i$i$i$i$i$i$i$i = ((($34)) + -4|0);
      $36 = $scevgep$i$i$i$i$i$i$i$i$i;
      $37 = $31;
      $38 = (($36) - ($37))|0;
      $39 = $38 >>> 2;
      $40 = $39 ^ -1;
      $scevgep5$i$i$i$i$i$i$i$i$i = (($34) + ($40<<2)|0);
      HEAP32[$33>>2] = $scevgep5$i$i$i$i$i$i$i$i$i;
     }
     __ZdlPv($31);
    }
    $41 = HEAP32[$6>>2]|0;
    $42 = ($41|0)==(0|0);
    if (!($42)) {
     $43 = ((($41)) + 8|0);
     $44 = HEAP32[$43>>2]|0;HEAP32[$43>>2] = (($44-1)|0);
     $45 = ($44|0)==(1);
     if ($45) {
      __THREW__ = 0;
      invoke_viii(3262,($41|0),1,1);
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       label = 19;
       break;
      }
     }
    }
    HEAP32[$6>>2] = 0;
    $48 = HEAP32[$3>>2]|0;
    $49 = ($48|0)==($1|0);
    if ($49) {
     label = 20;
     break;
    } else {
     $7 = $48;
    }
   }
   if ((label|0) == 19) {
    $50 = ___cxa_find_matching_catch_2()|0;
    $51 = tempRet0;
    ___cxa_call_unexpected(($50|0));
    // unreachable;
   }
   else if ((label|0) == 20) {
    $$pre = HEAP32[$0>>2]|0;
    $52 = $$pre;
    break;
   }
  }
 } while(0);
 __ZdlPv($52);
 return;
}
function __ZN3osg10CullingSetC2Ev($0) {
 $0 = $0|0;
 var $$pre$i$i$i = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 __ZN3osg10ReferencedC2Ev($0);
 HEAP32[$0>>2] = (58212);
 $1 = ((($0)) + 32|0);
 $$pre$i$i$i = ((($0)) + 16|0);
 dest=$$pre$i$i$i; stop=dest+48|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAP32[$1>>2] = 1;
 $2 = ((($0)) + 64|0);
 $3 = ((($0)) + 12|0);
 ;HEAP32[$2>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;HEAP32[$2+12>>2]=0|0;HEAP32[$2+16>>2]=0|0;HEAP32[$2+20>>2]=0|0;
 HEAP32[$3>>2] = 31;
 $4 = ((($0)) + 88|0);
 HEAPF32[$4>>2] = 0.0;
 $5 = ((($0)) + 92|0);
 HEAPF32[$5>>2] = 0.0;
 $6 = ((($0)) + 96|0);
 HEAPF32[$6>>2] = 0.0;
 $7 = ((($0)) + 100|0);
 HEAPF32[$7>>2] = 1.0;
 $8 = ((($0)) + 104|0);
 HEAPF32[$8>>2] = 2.0;
 return;
}
function __ZN3osg10CullingSet34disableAndPushOccludersCurrentMaskERNSt3__26vectorIPNS_4NodeENS1_9allocatorIS4_EEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$pre = 0, $$pre$i = 0, $$pre$i$i$i = 0, $$pre13 = 0, $$sroa$02$06$i = 0, $$sroa$04$011 = 0, $$sroa$04$08$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 80|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if ($6) {
  return;
 }
 $7 = ((($1)) + 4|0);
 $$sroa$04$011 = $3;
 while(1) {
  $8 = ((($$sroa$04$011)) + 4|0);
  $9 = ((($$sroa$04$011)) + 8|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = HEAP32[$8>>2]|0;
  $12 = (($10) - ($11))|0;
  $13 = HEAP32[$7>>2]|0;
  $14 = HEAP32[$1>>2]|0;
  $15 = (($13) - ($14))|0;
  $16 = ($12|0)==($15|0);
  $17 = $11;
  $18 = $10;
  L6: do {
   if ($16) {
    $19 = ($17|0)==($18|0);
    if (!($19)) {
     $20 = $14;
     $22 = $17;$24 = $20;
     while(1) {
      $21 = HEAP32[$22>>2]|0;
      $23 = HEAP32[$24>>2]|0;
      $25 = ($21|0)==($23|0);
      if (!($25)) {
       break L6;
      }
      $26 = ((($22)) + 4|0);
      $27 = ((($24)) + 4|0);
      $28 = ($26|0)==($18|0);
      if ($28) {
       break;
      } else {
       $22 = $26;$24 = $27;
      }
     }
    }
    $29 = ((($$sroa$04$011)) + 40|0);
    HEAP32[$29>>2] = 0;
    $30 = ((($$sroa$04$011)) + 68|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = ((($$sroa$04$011)) + 72|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = ($31|0)==($33|0);
    if (!($34)) {
     $$sroa$02$06$i = $31;
     while(1) {
      $35 = ((($$sroa$02$06$i)) + 20|0);
      HEAP32[$35>>2] = 0;
      $36 = ((($$sroa$02$06$i)) + 48|0);
      $37 = ($36|0)==($33|0);
      if ($37) {
       break;
      } else {
       $$sroa$02$06$i = $36;
      }
     }
    }
    $38 = ((($$sroa$04$011)) + 36|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = ($39|0)==(0);
    $$pre$i$i$i = ((($$sroa$04$011)) + 20|0);
    do {
     if ($40) {
      $52 = $31;$54 = $33;
     } else {
      $41 = ((($$sroa$04$011)) + 28|0);
      $42 = HEAP32[$41>>2]|0;
      $43 = ((($$sroa$04$011)) + 32|0);
      $44 = HEAP32[$43>>2]|0;
      $45 = ($42|0)==($44|0);
      if ($45) {
       $48 = ((($$sroa$04$011)) + 24|0);
       __ZNSt3__26vectorIjNS_9allocatorIjEEE21__push_back_slow_pathIKjEEvRT_($48,$$pre$i$i$i);
       $$pre = HEAP32[$30>>2]|0;
       $$pre13 = HEAP32[$32>>2]|0;
       $52 = $$pre;$54 = $$pre13;
       break;
      } else {
       $46 = HEAP32[$$pre$i$i$i>>2]|0;
       HEAP32[$42>>2] = $46;
       $47 = ((($42)) + 4|0);
       HEAP32[$41>>2] = $47;
       $52 = $31;$54 = $33;
       break;
      }
     }
    } while(0);
    $49 = HEAP32[$29>>2]|0;
    HEAP32[$$pre$i$i$i>>2] = $49;
    $50 = HEAP32[$38>>2]|0;
    $51 = (($50) + 1)|0;
    HEAP32[$38>>2] = $51;
    $53 = ($52|0)==($54|0);
    if (!($53)) {
     $$sroa$04$08$i = $52;$76 = $54;
     while(1) {
      $55 = ((($$sroa$04$08$i)) + 20|0);
      $56 = ((($$sroa$04$08$i)) + 16|0);
      $57 = HEAP32[$56>>2]|0;
      $58 = ($57|0)==(0);
      do {
       if ($58) {
        $72 = $76;
       } else {
        $59 = ((($$sroa$04$08$i)) + 8|0);
        $60 = HEAP32[$59>>2]|0;
        $61 = ((($$sroa$04$08$i)) + 12|0);
        $62 = HEAP32[$61>>2]|0;
        $63 = ($60|0)==($62|0);
        if ($63) {
         $66 = ((($$sroa$04$08$i)) + 4|0);
         __ZNSt3__26vectorIjNS_9allocatorIjEEE21__push_back_slow_pathIKjEEvRT_($66,$$sroa$04$08$i);
         $$pre$i = HEAP32[$32>>2]|0;
         $72 = $$pre$i;
         break;
        } else {
         $64 = HEAP32[$$sroa$04$08$i>>2]|0;
         HEAP32[$60>>2] = $64;
         $65 = ((($60)) + 4|0);
         HEAP32[$59>>2] = $65;
         $72 = $76;
         break;
        }
       }
      } while(0);
      $67 = HEAP32[$55>>2]|0;
      HEAP32[$$sroa$04$08$i>>2] = $67;
      $68 = HEAP32[$56>>2]|0;
      $69 = (($68) + 1)|0;
      HEAP32[$56>>2] = $69;
      $70 = ((($$sroa$04$08$i)) + 48|0);
      $71 = ($70|0)==($72|0);
      if ($71) {
       break;
      } else {
       $$sroa$04$08$i = $70;$76 = $72;
      }
     }
    }
   }
  } while(0);
  $73 = ((($$sroa$04$011)) + 80|0);
  $74 = HEAP32[$4>>2]|0;
  $75 = ($73|0)==($74|0);
  if ($75) {
   break;
  } else {
   $$sroa$04$011 = $73;
  }
 }
 return;
}
function __ZN3osg10CullingSet23popOccludersCurrentMaskERNSt3__26vectorIPNS_4NodeENS1_9allocatorIS4_EEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$pre = 0, $$pre11 = 0, $$sroa$03$07$i = 0, $$sroa$03$09 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 80|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if ($6) {
  return;
 }
 $7 = ((($1)) + 4|0);
 $$pre = HEAP32[$7>>2]|0;
 $$pre11 = HEAP32[$1>>2]|0;
 $8 = (($$pre) - ($$pre11))|0;
 $9 = $$pre11;
 $$sroa$03$09 = $3;
 while(1) {
  $10 = ((($$sroa$03$09)) + 4|0);
  $11 = ((($$sroa$03$09)) + 8|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = HEAP32[$10>>2]|0;
  $14 = (($12) - ($13))|0;
  $15 = ($14|0)==($8|0);
  $16 = $13;
  $17 = $12;
  L6: do {
   if ($15) {
    $18 = ($16|0)==($17|0);
    if (!($18)) {
     $20 = $16;$22 = $9;
     while(1) {
      $19 = HEAP32[$20>>2]|0;
      $21 = HEAP32[$22>>2]|0;
      $23 = ($19|0)==($21|0);
      if (!($23)) {
       break L6;
      }
      $24 = ((($20)) + 4|0);
      $25 = ((($22)) + 4|0);
      $26 = ($24|0)==($17|0);
      if ($26) {
       break;
      } else {
       $20 = $24;$22 = $25;
      }
     }
    }
    $27 = ((($$sroa$03$09)) + 36|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = ($28|0)==(0);
    if (!($29)) {
     $30 = ((($$sroa$03$09)) + 24|0);
     $31 = HEAP32[$30>>2]|0;
     $32 = ((($$sroa$03$09)) + 28|0);
     $33 = HEAP32[$32>>2]|0;
     $34 = ($31|0)==($33|0);
     if (!($34)) {
      $35 = ((($33)) + -4|0);
      $36 = HEAP32[$35>>2]|0;
      $37 = ((($$sroa$03$09)) + 20|0);
      HEAP32[$37>>2] = $36;
      HEAP32[$32>>2] = $35;
     }
     $38 = (($28) + -1)|0;
     HEAP32[$27>>2] = $38;
    }
    $39 = ((($$sroa$03$09)) + 68|0);
    $40 = HEAP32[$39>>2]|0;
    $41 = ((($$sroa$03$09)) + 72|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = ($40|0)==($42|0);
    if (!($43)) {
     $$sroa$03$07$i = $40;
     while(1) {
      $44 = ((($$sroa$03$07$i)) + 16|0);
      $45 = HEAP32[$44>>2]|0;
      $46 = ($45|0)==(0);
      if (!($46)) {
       $47 = ((($$sroa$03$07$i)) + 4|0);
       $48 = HEAP32[$47>>2]|0;
       $49 = ((($$sroa$03$07$i)) + 8|0);
       $50 = HEAP32[$49>>2]|0;
       $51 = ($48|0)==($50|0);
       if (!($51)) {
        $52 = ((($50)) + -4|0);
        $53 = HEAP32[$52>>2]|0;
        HEAP32[$$sroa$03$07$i>>2] = $53;
        HEAP32[$49>>2] = $52;
       }
       $54 = (($45) + -1)|0;
       HEAP32[$44>>2] = $54;
      }
      $55 = ((($$sroa$03$07$i)) + 48|0);
      $56 = ($55|0)==($42|0);
      if ($56) {
       break;
      } else {
       $$sroa$03$07$i = $55;
      }
     }
    }
   }
  } while(0);
  $57 = ((($$sroa$03$09)) + 80|0);
  $58 = ($57|0)==($5|0);
  if ($58) {
   break;
  } else {
   $$sroa$03$09 = $57;
  }
 }
 return;
}
function __ZN3osg10CullingSet22computePixelSizeVectorERKNS_8ViewportERKNS_7MatrixdES6_($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0.0, $104 = 0.0, $105 = 0.0, $106 = 0.0, $107 = 0.0, $108 = 0.0, $109 = 0.0, $11 = 0.0, $110 = 0.0, $111 = 0.0, $112 = 0.0, $113 = 0.0, $114 = 0.0, $115 = 0.0, $116 = 0.0, $117 = 0.0;
 var $118 = 0.0, $119 = 0.0, $12 = 0.0, $13 = 0.0, $14 = 0, $15 = 0.0, $16 = 0.0, $17 = 0.0, $18 = 0.0, $19 = 0.0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0, $24 = 0.0, $25 = 0.0, $26 = 0.0, $27 = 0.0, $28 = 0.0, $29 = 0;
 var $30 = 0.0, $31 = 0.0, $32 = 0, $33 = 0.0, $34 = 0.0, $35 = 0.0, $36 = 0.0, $37 = 0, $38 = 0.0, $39 = 0.0, $4 = 0.0, $40 = 0, $41 = 0.0, $42 = 0.0, $43 = 0.0, $44 = 0.0, $45 = 0, $46 = 0.0, $47 = 0, $48 = 0.0;
 var $49 = 0.0, $5 = 0, $50 = 0.0, $51 = 0.0, $52 = 0, $53 = 0.0, $54 = 0.0, $55 = 0.0, $56 = 0.0, $57 = 0.0, $58 = 0.0, $59 = 0.0, $6 = 0.0, $60 = 0, $61 = 0.0, $62 = 0.0, $63 = 0.0, $64 = 0.0, $65 = 0.0, $66 = 0.0;
 var $67 = 0.0, $68 = 0, $69 = 0.0, $7 = 0.0, $70 = 0.0, $71 = 0.0, $72 = 0.0, $73 = 0.0, $74 = 0, $75 = 0.0, $76 = 0.0, $77 = 0.0, $78 = 0.0, $79 = 0.0, $8 = 0.0, $80 = 0.0, $81 = 0, $82 = 0.0, $83 = 0.0, $84 = 0.0;
 var $85 = 0.0, $86 = 0.0, $87 = 0.0, $88 = 0.0, $89 = 0.0, $9 = 0.0, $90 = 0.0, $91 = 0, $92 = 0.0, $93 = 0.0, $94 = 0, $95 = 0.0, $96 = 0.0, $97 = 0.0, $98 = 0.0, $99 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = +HEAPF64[$2>>3];
 $5 = ((($1)) + 72|0);
 $6 = +HEAPF64[$5>>3];
 $7 = $4 * $6;
 $8 = $7 * 0.5;
 $9 = $8;
 $10 = ((($2)) + 64|0);
 $11 = +HEAPF64[$10>>3];
 $12 = $6 * $11;
 $13 = $12 * 0.5;
 $14 = ((($2)) + 88|0);
 $15 = +HEAPF64[$14>>3];
 $16 = $6 * $15;
 $17 = $16 * 0.5;
 $18 = $13 + $17;
 $19 = $18;
 $20 = +HEAPF64[$3>>3];
 $21 = $9;
 $22 = $20 * $21;
 $23 = ((($3)) + 16|0);
 $24 = +HEAPF64[$23>>3];
 $25 = $19;
 $26 = $24 * $25;
 $27 = $22 + $26;
 $28 = $27;
 $29 = ((($3)) + 32|0);
 $30 = +HEAPF64[$29>>3];
 $31 = $21 * $30;
 $32 = ((($3)) + 48|0);
 $33 = +HEAPF64[$32>>3];
 $34 = $33 * $25;
 $35 = $31 + $34;
 $36 = $35;
 $37 = ((($3)) + 64|0);
 $38 = +HEAPF64[$37>>3];
 $39 = $21 * $38;
 $40 = ((($3)) + 80|0);
 $41 = +HEAPF64[$40>>3];
 $42 = $25 * $41;
 $43 = $39 + $42;
 $44 = $43;
 $45 = ((($2)) + 40|0);
 $46 = +HEAPF64[$45>>3];
 $47 = ((($1)) + 80|0);
 $48 = +HEAPF64[$47>>3];
 $49 = $46 * $48;
 $50 = $49 * 0.5;
 $51 = $50;
 $52 = ((($2)) + 72|0);
 $53 = +HEAPF64[$52>>3];
 $54 = $48 * $53;
 $55 = $54 * 0.5;
 $56 = $15 * $48;
 $57 = $56 * 0.5;
 $58 = $57 + $55;
 $59 = $58;
 $60 = ((($3)) + 8|0);
 $61 = +HEAPF64[$60>>3];
 $62 = $51;
 $63 = $61 * $62;
 $64 = $59;
 $65 = $24 * $64;
 $66 = $63 + $65;
 $67 = $66;
 $68 = ((($3)) + 40|0);
 $69 = +HEAPF64[$68>>3];
 $70 = $69 * $62;
 $71 = $33 * $64;
 $72 = $70 + $71;
 $73 = $72;
 $74 = ((($3)) + 72|0);
 $75 = +HEAPF64[$74>>3];
 $76 = $75 * $62;
 $77 = $41 * $64;
 $78 = $76 + $77;
 $79 = $78;
 $80 = $15;
 $81 = ((($2)) + 120|0);
 $82 = +HEAPF64[$81>>3];
 $83 = $82;
 $84 = $80;
 $85 = $24 * $84;
 $86 = $85;
 $87 = $84 * $33;
 $88 = $87;
 $89 = $84 * $41;
 $90 = $89;
 $91 = ((($3)) + 112|0);
 $92 = +HEAPF64[$91>>3];
 $93 = $84 * $92;
 $94 = ((($3)) + 120|0);
 $95 = +HEAPF64[$94>>3];
 $96 = $83;
 $97 = $95 * $96;
 $98 = $93 + $97;
 $99 = $98;
 $100 = ((($0)) + 4|0);
 $101 = ((($0)) + 8|0);
 $102 = ((($0)) + 12|0);
 $103 = $28 * $28;
 $104 = $36 * $36;
 $105 = $103 + $104;
 $106 = $44 * $44;
 $107 = $105 + $106;
 $108 = $67 * $67;
 $109 = $73 * $73;
 $110 = $108 + $109;
 $111 = $79 * $79;
 $112 = $111 + $110;
 $113 = $107 + $112;
 $114 = (+Math_sqrt((+$113)));
 $115 = 0.70710676908493042 / $114;
 $116 = $86 * $115;
 HEAPF32[$0>>2] = $116;
 $117 = $115 * $88;
 HEAPF32[$100>>2] = $117;
 $118 = $115 * $90;
 HEAPF32[$101>>2] = $118;
 $119 = $115 * $99;
 HEAPF32[$102>>2] = $119;
 return;
}
function __ZN3osg12CullSettingsD2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (58232);
 $1 = ((($0)) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = ((($2)) + 8|0);
  $5 = HEAP32[$4>>2]|0;HEAP32[$4>>2] = (($5-1)|0);
  $6 = ($5|0)==(1);
  if ($6) {
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($2,1,1);
  }
 }
 HEAP32[$1>>2] = 0;
 return;
}
function __ZN3osg12CullSettingsD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (58232);
 $1 = ((($0)) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  __ZdlPv($0);
  return;
 }
 $4 = ((($2)) + 8|0);
 $5 = HEAP32[$4>>2]|0;HEAP32[$4>>2] = (($5-1)|0);
 $6 = ($5|0)==(1);
 if (!($6)) {
  __ZdlPv($0);
  return;
 }
 __THREW__ = 0;
 invoke_viii(3262,($2|0),1,1);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch_2()|0;
  $10 = tempRet0;
  __ZdlPv($0);
  ___resumeException($9|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZN3osg12CullSettings11setDefaultsEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 4|0);
 HEAP32[$1>>2] = 2147483647;
 $2 = ((($0)) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = ((($0)) + 16|0);
 HEAP32[$3>>2] = 57;
 $4 = ((($0)) + 20|0);
 HEAPF32[$4>>2] = 1.0;
 $5 = ((($0)) + 24|0);
 HEAPF32[$5>>2] = 2.0;
 $6 = ((($0)) + 12|0);
 HEAP32[$6>>2] = 1;
 $7 = ((($0)) + 32|0);
 HEAPF64[$7>>3] = 5.0000000000000001E-4;
 $8 = ((($0)) + 40|0);
 HEAP8[$8>>0] = 1;
 $9 = ((($0)) + 41|0);
 HEAP8[$9>>0] = 0;
 $10 = ((($0)) + 44|0);
 HEAPF32[$10>>2] = 4.0;
 $11 = ((($0)) + 48|0);
 HEAP32[$11>>2] = 10;
 $12 = ((($0)) + 52|0);
 HEAP32[$12>>2] = -1;
 $13 = ((($0)) + 56|0);
 HEAP32[$13>>2] = -1;
 $14 = ((($0)) + 60|0);
 HEAP32[$14>>2] = -1;
 return;
}
function __ZN3osg12CullSettings19inheritCullSettingsERKS0_j($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0.0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = $2 & 1;
 $4 = ($3|0)==(0);
 if (!($4)) {
  $5 = ((($1)) + 12|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ((($0)) + 12|0);
  HEAP32[$7>>2] = $6;
 }
 $8 = $2 & 32;
 $9 = ($8|0)==(0);
 if (!($9)) {
  $10 = ((($1)) + 32|0);
  $11 = +HEAPF64[$10>>3];
  $12 = ((($0)) + 32|0);
  HEAPF64[$12>>3] = $11;
 }
 $13 = $2 & 64;
 $14 = ($13|0)==(0);
 if (!($14)) {
  $15 = ((($1)) + 40|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = ((($0)) + 40|0);
  HEAP8[$17>>0] = $16;
 }
 $18 = $2 & 128;
 $19 = ($18|0)==(0);
 if (!($19)) {
  $20 = ((($1)) + 41|0);
  $21 = HEAP8[$20>>0]|0;
  $22 = ((($0)) + 41|0);
  HEAP8[$22>>0] = $21;
 }
 $23 = $2 & 256;
 $24 = ($23|0)==(0);
 if (!($24)) {
  $25 = ((($1)) + 44|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = ((($0)) + 44|0);
  HEAP32[$27>>2] = $26;
 }
 $28 = $2 & 512;
 $29 = ($28|0)==(0);
 if (!($29)) {
  $30 = ((($1)) + 48|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = ((($0)) + 48|0);
  HEAP32[$32>>2] = $31;
 }
 $33 = $2 & 1024;
 $34 = ($33|0)==(0);
 if (!($34)) {
  $35 = ((($1)) + 52|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = ((($0)) + 52|0);
  HEAP32[$37>>2] = $36;
 }
 $38 = $2 & 2048;
 $39 = ($38|0)==(0);
 if (!($39)) {
  $40 = ((($1)) + 56|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = ((($0)) + 56|0);
  HEAP32[$42>>2] = $41;
 }
 $43 = $2 & 4096;
 $44 = ($43|0)==(0);
 if (!($44)) {
  $45 = ((($1)) + 60|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = ((($0)) + 60|0);
  HEAP32[$47>>2] = $46;
 }
 $48 = $2 & 2;
 $49 = ($48|0)==(0);
 if (!($49)) {
  $50 = ((($1)) + 16|0);
  $51 = HEAP32[$50>>2]|0;
  $52 = ((($0)) + 16|0);
  HEAP32[$52>>2] = $51;
 }
 $53 = $2 & 4;
 $54 = ($53|0)==(0);
 if (!($54)) {
  $55 = ((($1)) + 20|0);
  $56 = HEAP32[$55>>2]|0;
  $57 = ((($0)) + 20|0);
  HEAP32[$57>>2] = $56;
 }
 $58 = $2 & 8;
 $59 = ($58|0)==(0);
 if (!($59)) {
  $60 = ((($1)) + 24|0);
  $61 = HEAP32[$60>>2]|0;
  $62 = ((($0)) + 24|0);
  HEAP32[$62>>2] = $61;
 }
 $63 = $2 & 16;
 $64 = ($63|0)==(0);
 if ($64) {
  return;
 }
 $65 = ((($0)) + 28|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = ((($1)) + 28|0);
 $68 = HEAP32[$67>>2]|0;
 $69 = ($66|0)==($68|0);
 if ($69) {
  return;
 }
 HEAP32[$65>>2] = $68;
 $70 = ($68|0)==(0|0);
 if (!($70)) {
  $71 = ((($68)) + 8|0);
  $72 = HEAP32[$71>>2]|0;HEAP32[$71>>2] = (($72+1)|0);
 }
 $73 = ($66|0)==(0|0);
 if ($73) {
  return;
 }
 $74 = ((($66)) + 8|0);
 $75 = HEAP32[$74>>2]|0;HEAP32[$74>>2] = (($75-1)|0);
 $76 = ($75|0)==(1);
 if (!($76)) {
  return;
 }
 __ZNK3osg10Referenced24signalObserversAndDeleteEbb($66,1,1);
 return;
}
function __GLOBAL__sub_I_CullSettings_cpp() {
 var $$0$i = 0, $$0$i6 = 0, $$01$i = 0, $$01$i5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0, $9 = 0, dest = 0, label = 0;
 var sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $0 = sp + 36|0;
 $1 = sp + 24|0;
 $2 = sp + 12|0;
 $3 = sp;
 HEAPF32[52035] = 1.0;
 HEAPF32[(208144)>>2] = 0.0;
 HEAPF32[(208148)>>2] = 0.0;
 HEAPF32[52038] = 0.0;
 HEAPF32[(208156)>>2] = 1.0;
 HEAPF32[(208160)>>2] = 0.0;
 HEAPF32[52041] = 0.0;
 HEAPF32[(208168)>>2] = 0.0;
 HEAPF32[(208172)>>2] = 1.0;
 $4 = (__Znwj(48)|0);
 HEAP32[$0>>2] = $4;
 $5 = ((($0)) + 8|0);
 HEAP32[$5>>2] = -2147483600;
 $6 = ((($0)) + 4|0);
 HEAP32[$6>>2] = 32;
 dest=$4; src=121052; stop=dest+32|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $7 = ((($4)) + 32|0);
 HEAP8[$7>>0] = 0;
 ;HEAP32[$1>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;
 __THREW__ = 0;
 $8 = (invoke_ii(3276,112)|0);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if ($10) {
  $27 = ___cxa_find_matching_catch_2()|0;
  $28 = tempRet0;
  $$0$i6 = $28;$$01$i5 = $27;
 } else {
  HEAP32[$1>>2] = $8;
  $11 = ((($1)) + 8|0);
  HEAP32[$11>>2] = -2147483536;
  $12 = ((($1)) + 4|0);
  HEAP32[$12>>2] = 101;
  dest=$8; src=121085; stop=dest+101|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
  $13 = ((($8)) + 101|0);
  HEAP8[$13>>0] = 0;
  __THREW__ = 0;
  $14 = (invoke_i(3459)|0);
  $15 = __THREW__; __THREW__ = 0;
  $16 = $15&1;
  if (!($16)) {
   __THREW__ = 0;
   invoke_viiii(3460,($14|0),2,($0|0),($1|0));
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if (!($18)) {
    $19 = ((($1)) + 11|0);
    $20 = HEAP8[$19>>0]|0;
    $21 = ($20<<24>>24)<(0);
    if ($21) {
     $22 = HEAP32[$1>>2]|0;
     __ZdlPv($22);
    }
    $23 = ((($0)) + 11|0);
    $24 = HEAP8[$23>>0]|0;
    $25 = ($24<<24>>24)<(0);
    if ($25) {
     $26 = HEAP32[$0>>2]|0;
     __ZdlPv($26);
    }
    $39 = (__Znwj(32)|0);
    HEAP32[$2>>2] = $39;
    $40 = ((($2)) + 8|0);
    HEAP32[$40>>2] = -2147483616;
    $41 = ((($2)) + 4|0);
    HEAP32[$41>>2] = 26;
    dest=$39; src=121187; stop=dest+26|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
    $42 = ((($39)) + 26|0);
    HEAP8[$42>>0] = 0;
    ;HEAP32[$3>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;
    __THREW__ = 0;
    $43 = (invoke_ii(3276,96)|0);
    $44 = __THREW__; __THREW__ = 0;
    $45 = $44&1;
    if ($45) {
     $62 = ___cxa_find_matching_catch_2()|0;
     $63 = tempRet0;
     $$0$i = $63;$$01$i = $62;
    } else {
     HEAP32[$3>>2] = $43;
     $46 = ((($3)) + 8|0);
     HEAP32[$46>>2] = -2147483552;
     $47 = ((($3)) + 4|0);
     HEAP32[$47>>2] = 84;
     dest=$43; src=121214; stop=dest+84|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
     $48 = ((($43)) + 84|0);
     HEAP8[$48>>0] = 0;
     __THREW__ = 0;
     $49 = (invoke_i(3459)|0);
     $50 = __THREW__; __THREW__ = 0;
     $51 = $50&1;
     if (!($51)) {
      __THREW__ = 0;
      invoke_viiii(3460,($49|0),2,($2|0),($3|0));
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if (!($53)) {
       $54 = ((($3)) + 11|0);
       $55 = HEAP8[$54>>0]|0;
       $56 = ($55<<24>>24)<(0);
       if ($56) {
        $57 = HEAP32[$3>>2]|0;
        __ZdlPv($57);
       }
       $58 = ((($2)) + 11|0);
       $59 = HEAP8[$58>>0]|0;
       $60 = ($59<<24>>24)<(0);
       if (!($60)) {
        STACKTOP = sp;return;
       }
       $61 = HEAP32[$2>>2]|0;
       __ZdlPv($61);
       STACKTOP = sp;return;
      }
     }
     $64 = ___cxa_find_matching_catch_2()|0;
     $65 = tempRet0;
     $66 = ((($3)) + 11|0);
     $67 = HEAP8[$66>>0]|0;
     $68 = ($67<<24>>24)<(0);
     if ($68) {
      $69 = HEAP32[$3>>2]|0;
      __ZdlPv($69);
      $$0$i = $65;$$01$i = $64;
     } else {
      $$0$i = $65;$$01$i = $64;
     }
    }
    $70 = ((($2)) + 11|0);
    $71 = HEAP8[$70>>0]|0;
    $72 = ($71<<24>>24)<(0);
    if (!($72)) {
     ___resumeException($$01$i|0);
     // unreachable;
    }
    $73 = HEAP32[$2>>2]|0;
    __ZdlPv($73);
    ___resumeException($$01$i|0);
    // unreachable;
   }
  }
  $29 = ___cxa_find_matching_catch_2()|0;
  $30 = tempRet0;
  $31 = ((($1)) + 11|0);
  $32 = HEAP8[$31>>0]|0;
  $33 = ($32<<24>>24)<(0);
  if ($33) {
   $34 = HEAP32[$1>>2]|0;
   __ZdlPv($34);
   $$0$i6 = $30;$$01$i5 = $29;
  } else {
   $$0$i6 = $30;$$01$i5 = $29;
  }
 }
 $35 = ((($0)) + 11|0);
 $36 = HEAP8[$35>>0]|0;
 $37 = ($36<<24>>24)<(0);
 if (!($37)) {
  ___resumeException($$01$i5|0);
  // unreachable;
 }
 $38 = HEAP32[$0>>2]|0;
 __ZdlPv($38);
 ___resumeException($$01$i5|0);
 // unreachable;
}
function __ZN3osg12CullSettingsC2ERKS0_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0.0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (58232);
 $2 = ((($0)) + 28|0);
 HEAP32[$2>>2] = 0;
 $3 = ((($1)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 4|0);
 HEAP32[$5>>2] = $4;
 $6 = ((($1)) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($0)) + 8|0);
 HEAP32[$8>>2] = $7;
 $9 = ((($1)) + 12|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ((($0)) + 12|0);
 HEAP32[$11>>2] = $10;
 $12 = ((($1)) + 16|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($0)) + 16|0);
 HEAP32[$14>>2] = $13;
 $15 = ((($1)) + 20|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ((($0)) + 20|0);
 HEAP32[$17>>2] = $16;
 $18 = ((($1)) + 24|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ((($0)) + 24|0);
 HEAP32[$20>>2] = $19;
 $21 = ((($1)) + 28|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0|0);
 if (!($23)) {
  HEAP32[$2>>2] = $22;
  $24 = ((($22)) + 8|0);
  $25 = HEAP32[$24>>2]|0;HEAP32[$24>>2] = (($25+1)|0);
 }
 $26 = ((($1)) + 32|0);
 $27 = +HEAPF64[$26>>3];
 $28 = ((($0)) + 32|0);
 HEAPF64[$28>>3] = $27;
 $29 = ((($1)) + 40|0);
 $30 = HEAP8[$29>>0]|0;
 $31 = ((($0)) + 40|0);
 HEAP8[$31>>0] = $30;
 $32 = ((($1)) + 41|0);
 $33 = HEAP8[$32>>0]|0;
 $34 = ((($0)) + 41|0);
 HEAP8[$34>>0] = $33;
 $35 = ((($1)) + 44|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = ((($0)) + 44|0);
 HEAP32[$37>>2] = $36;
 $38 = ((($1)) + 48|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = ((($0)) + 48|0);
 HEAP32[$40>>2] = $39;
 $41 = ((($1)) + 52|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ((($0)) + 52|0);
 HEAP32[$43>>2] = $42;
 $44 = ((($1)) + 56|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = ((($0)) + 56|0);
 HEAP32[$46>>2] = $45;
 $47 = ((($1)) + 60|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = ((($0)) + 60|0);
 HEAP32[$49>>2] = $48;
 return;
}
function __ZN3osg12CullSettings15setCullSettingsERKS0_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0.0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 4|0);
 HEAP32[$4>>2] = $3;
 $5 = ((($1)) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($0)) + 8|0);
 HEAP32[$7>>2] = $6;
 $8 = ((($1)) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($0)) + 12|0);
 HEAP32[$10>>2] = $9;
 $11 = ((($1)) + 16|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ((($0)) + 16|0);
 HEAP32[$13>>2] = $12;
 $14 = ((($1)) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ((($0)) + 20|0);
 HEAP32[$16>>2] = $15;
 $17 = ((($1)) + 24|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ((($0)) + 24|0);
 HEAP32[$19>>2] = $18;
 $20 = ((($0)) + 28|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ((($1)) + 28|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($21|0)==($23|0);
 if (!($24)) {
  HEAP32[$20>>2] = $23;
  $25 = ($23|0)==(0|0);
  if (!($25)) {
   $26 = ((($23)) + 8|0);
   $27 = HEAP32[$26>>2]|0;HEAP32[$26>>2] = (($27+1)|0);
  }
  $28 = ($21|0)==(0|0);
  if (!($28)) {
   $29 = ((($21)) + 8|0);
   $30 = HEAP32[$29>>2]|0;HEAP32[$29>>2] = (($30-1)|0);
   $31 = ($30|0)==(1);
   if ($31) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($21,1,1);
   }
  }
 }
 $32 = ((($1)) + 32|0);
 $33 = +HEAPF64[$32>>3];
 $34 = ((($0)) + 32|0);
 HEAPF64[$34>>3] = $33;
 $35 = ((($1)) + 40|0);
 $36 = HEAP8[$35>>0]|0;
 $37 = ((($0)) + 40|0);
 HEAP8[$37>>0] = $36;
 $38 = ((($1)) + 41|0);
 $39 = HEAP8[$38>>0]|0;
 $40 = ((($0)) + 41|0);
 HEAP8[$40>>0] = $39;
 $41 = ((($1)) + 44|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ((($0)) + 44|0);
 HEAP32[$43>>2] = $42;
 $44 = ((($1)) + 48|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = ((($0)) + 48|0);
 HEAP32[$46>>2] = $45;
 $47 = ((($1)) + 52|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = ((($0)) + 52|0);
 HEAP32[$49>>2] = $48;
 $50 = ((($1)) + 56|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = ((($0)) + 56|0);
 HEAP32[$52>>2] = $51;
 $53 = ((($1)) + 60|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = ((($0)) + 60|0);
 HEAP32[$55>>2] = $54;
 return;
}
function __ZN3osg12CullSettings26readEnvironmentalVariablesEv($0) {
 $0 = $0|0;
 var $$sink = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0.0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0.0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp + 8|0;
 $2 = sp + 4|0;
 $3 = sp;
 $4 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
 do {
  if ($4) {
   $5 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
   $6 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($5,121299,42)|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ((($7)) + -12|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($6) + ($9)|0);
   __ZNKSt3__28ios_base6getlocEv($3,$10);
   __THREW__ = 0;
   $11 = (invoke_iii(3255,($3|0),(215188|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[$11>>2]|0;
    $15 = ((($14)) + 28|0);
    $16 = HEAP32[$15>>2]|0;
    __THREW__ = 0;
    $17 = (invoke_iii($16|0,($11|0),10)|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     __ZNSt3__26localeD2Ev($3);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($6,$17)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($6)|0);
     break;
    }
   }
   $20 = ___cxa_find_matching_catch_2()|0;
   $21 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($3|0));
   $22 = __THREW__; __THREW__ = 0;
   $23 = $22&1;
   if ($23) {
    $24 = ___cxa_find_matching_catch_3(0|0)|0;
    $25 = tempRet0;
    ___clang_call_terminate($24);
    // unreachable;
   } else {
    ___resumeException($20|0);
    // unreachable;
   }
  }
 } while(0);
 $26 = (_getenv((121342|0))|0);
 $27 = ($26|0)==(0|0);
 do {
  if (!($27)) {
   $28 = (_strcmp($26,121368)|0);
   $29 = ($28|0)==(0);
   if ($29) {
    $$sink = 0;
    label = 12;
   } else {
    $30 = (_strcmp($26,121392)|0);
    $31 = ($30|0)==(0);
    if ($31) {
     $$sink = 1;
     label = 12;
    } else {
     $32 = (_strcmp($26,121432)|0);
     $33 = ($32|0)==(0);
     if ($33) {
      $$sink = 2;
      label = 12;
     }
    }
   }
   if ((label|0) == 12) {
    $34 = ((($0)) + 12|0);
    HEAP32[$34>>2] = $$sink;
   }
   $35 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
   if ($35) {
    $36 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
    $37 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($36,121466,29)|0);
    $38 = ((($0)) + 12|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi($37,$39)|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = ((($41)) + -12|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = (($40) + ($43)|0);
    __ZNKSt3__28ios_base6getlocEv($2,$44);
    __THREW__ = 0;
    $45 = (invoke_iii(3255,($2|0),(215188|0))|0);
    $46 = __THREW__; __THREW__ = 0;
    $47 = $46&1;
    if (!($47)) {
     $48 = HEAP32[$45>>2]|0;
     $49 = ((($48)) + 28|0);
     $50 = HEAP32[$49>>2]|0;
     __THREW__ = 0;
     $51 = (invoke_iii($50|0,($45|0),10)|0);
     $52 = __THREW__; __THREW__ = 0;
     $53 = $52&1;
     if (!($53)) {
      __ZNSt3__26localeD2Ev($2);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($40,$51)|0);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($40)|0);
      break;
     }
    }
    $54 = ___cxa_find_matching_catch_2()|0;
    $55 = tempRet0;
    __THREW__ = 0;
    invoke_vi(3263,($2|0));
    $56 = __THREW__; __THREW__ = 0;
    $57 = $56&1;
    if ($57) {
     $58 = ___cxa_find_matching_catch_3(0|0)|0;
     $59 = tempRet0;
     ___clang_call_terminate($58);
     // unreachable;
    } else {
     ___resumeException($54|0);
     // unreachable;
    }
   }
  }
 } while(0);
 $60 = (_getenv((121496|0))|0);
 $61 = ($60|0)==(0|0);
 if ($61) {
  STACKTOP = sp;return;
 }
 $62 = (+__ZN3osg13asciiToDoubleEPKc($60));
 $63 = ((($0)) + 32|0);
 HEAPF64[$63>>3] = $62;
 $64 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
 if (!($64)) {
  STACKTOP = sp;return;
 }
 $65 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
 $66 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($65,121515,22)|0);
 $67 = +HEAPF64[$63>>3];
 $68 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEd($66,$67)|0);
 $69 = HEAP32[$68>>2]|0;
 $70 = ((($69)) + -12|0);
 $71 = HEAP32[$70>>2]|0;
 $72 = (($68) + ($71)|0);
 __ZNKSt3__28ios_base6getlocEv($1,$72);
 __THREW__ = 0;
 $73 = (invoke_iii(3255,($1|0),(215188|0))|0);
 $74 = __THREW__; __THREW__ = 0;
 $75 = $74&1;
 if (!($75)) {
  $76 = HEAP32[$73>>2]|0;
  $77 = ((($76)) + 28|0);
  $78 = HEAP32[$77>>2]|0;
  __THREW__ = 0;
  $79 = (invoke_iii($78|0,($73|0),10)|0);
  $80 = __THREW__; __THREW__ = 0;
  $81 = $80&1;
  if (!($81)) {
   __ZNSt3__26localeD2Ev($1);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($68,$79)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($68)|0);
   STACKTOP = sp;return;
  }
 }
 $82 = ___cxa_find_matching_catch_2()|0;
 $83 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($1|0));
 $84 = __THREW__; __THREW__ = 0;
 $85 = $84&1;
 if ($85) {
  $86 = ___cxa_find_matching_catch_3(0|0)|0;
  $87 = tempRet0;
  ___clang_call_terminate($86);
  // unreachable;
 } else {
  ___resumeException($82|0);
  // unreachable;
 }
}
function __ZN3osg9CullStackD2Ev($0) {
 $0 = $0|0;
 var $$1 = 0, $$10 = 0, $$1012 = 0, $$11 = 0, $$1113 = 0, $$13 = 0, $$8 = 0, $$810 = 0, $$9 = 0, $$911 = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i$i108 = 0, $$pre$i$i117 = 0, $$pre$i$i34 = 0, $$pre$i$i39 = 0, $$pre$i$i48 = 0, $$pre$i$i90 = 0, $$pre$i$i99 = 0, $$pre$i57 = 0;
 var $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0;
 var $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0;
 var $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0;
 var $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0;
 var $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0;
 var $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0;
 var $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0;
 var $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0;
 var $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0;
 var $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0;
 var $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0;
 var $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0;
 var $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0;
 var $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0;
 var $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0;
 var $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0;
 var $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0;
 var $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0;
 var $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0;
 var $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0;
 var $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0;
 var $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i$i$i21 = 0, $scevgep$i$i$i$i26 = 0, $scevgep$i$i$i$i72 = 0, $scevgep$i$i$i$i77 = 0, $scevgep$i$i$i$i82 = 0, $scevgep5$i$i$i$i = 0, $scevgep5$i$i$i$i22 = 0, $scevgep5$i$i$i$i27 = 0, $scevgep5$i$i$i$i73 = 0;
 var $scevgep5$i$i$i$i78 = 0, $scevgep5$i$i$i$i83 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (58260);
 __THREW__ = 0;
 invoke_vi(3735,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 L1: do {
  if ($2) {
   $239 = ___cxa_find_matching_catch_2()|0;
   $240 = tempRet0;
   $241 = ((($0)) + 300|0);
   $242 = HEAP32[$241>>2]|0;
   $243 = ($242|0)==(0|0);
   if (!($243)) {
    $244 = ((($0)) + 304|0);
    $245 = HEAP32[$244>>2]|0;
    $246 = ($245|0)==($242|0);
    do {
     if ($246) {
      $260 = $242;
     } else {
      $248 = $245;
      while(1) {
       $247 = ((($248)) + -4|0);
       HEAP32[$244>>2] = $247;
       $249 = HEAP32[$247>>2]|0;
       $250 = ($249|0)==(0|0);
       if (!($250)) {
        $251 = ((($249)) + 8|0);
        $252 = HEAP32[$251>>2]|0;HEAP32[$251>>2] = (($252-1)|0);
        $253 = ($252|0)==(1);
        if ($253) {
         __THREW__ = 0;
         invoke_viii(3262,($249|0),1,1);
         $254 = __THREW__; __THREW__ = 0;
         $255 = $254&1;
         if ($255) {
          label = 108;
          break;
         }
        }
       }
       HEAP32[$247>>2] = 0;
       $256 = HEAP32[$244>>2]|0;
       $257 = ($256|0)==($242|0);
       if ($257) {
        label = 109;
        break;
       } else {
        $248 = $256;
       }
      }
      if ((label|0) == 108) {
       $258 = ___cxa_find_matching_catch_2()|0;
       $259 = tempRet0;
       ___cxa_call_unexpected(($258|0));
       // unreachable;
      }
      else if ((label|0) == 109) {
       $$pre$i57 = HEAP32[$241>>2]|0;
       $260 = $$pre$i57;
       break;
      }
     }
    } while(0);
    __ZdlPv($260);
   }
   $263 = ((($0)) + 296|0);
   $264 = HEAP32[$263>>2]|0;
   $265 = ($264|0)==(0|0);
   if (!($265)) {
    $266 = ((($264)) + 8|0);
    $267 = HEAP32[$266>>2]|0;HEAP32[$266>>2] = (($267-1)|0);
    $268 = ($267|0)==(1);
    if ($268) {
     __THREW__ = 0;
     invoke_viii(3262,($264|0),1,1);
     $269 = __THREW__; __THREW__ = 0;
     $270 = $269&1;
     if ($270) {
      $489 = ___cxa_find_matching_catch_3(0|0)|0;
      $490 = tempRet0;
      ___clang_call_terminate($489);
      // unreachable;
     }
    }
   }
   HEAP32[$263>>2] = 0;
   $$1 = $240;$$13 = $239;
   label = 116;
  } else {
   $3 = ((($0)) + 300|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = ($4|0)==(0|0);
   if (!($5)) {
    $6 = ((($0)) + 304|0);
    $7 = HEAP32[$6>>2]|0;
    $8 = ($7|0)==($4|0);
    do {
     if ($8) {
      $22 = $4;
     } else {
      $10 = $7;
      while(1) {
       $9 = ((($10)) + -4|0);
       HEAP32[$6>>2] = $9;
       $11 = HEAP32[$9>>2]|0;
       $12 = ($11|0)==(0|0);
       if (!($12)) {
        $13 = ((($11)) + 8|0);
        $14 = HEAP32[$13>>2]|0;HEAP32[$13>>2] = (($14-1)|0);
        $15 = ($14|0)==(1);
        if ($15) {
         __THREW__ = 0;
         invoke_viii(3262,($11|0),1,1);
         $16 = __THREW__; __THREW__ = 0;
         $17 = $16&1;
         if ($17) {
          label = 8;
          break;
         }
        }
       }
       HEAP32[$9>>2] = 0;
       $18 = HEAP32[$6>>2]|0;
       $19 = ($18|0)==($4|0);
       if ($19) {
        label = 9;
        break;
       } else {
        $10 = $18;
       }
      }
      if ((label|0) == 8) {
       $20 = ___cxa_find_matching_catch_2()|0;
       $21 = tempRet0;
       ___cxa_call_unexpected(($20|0));
       // unreachable;
      }
      else if ((label|0) == 9) {
       $$pre$i = HEAP32[$3>>2]|0;
       $22 = $$pre$i;
       break;
      }
     }
    } while(0);
    __ZdlPv($22);
   }
   $23 = ((($0)) + 296|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = ($24|0)==(0|0);
   if (!($25)) {
    $26 = ((($24)) + 8|0);
    $27 = HEAP32[$26>>2]|0;HEAP32[$26>>2] = (($27-1)|0);
    $28 = ($27|0)==(1);
    if ($28) {
     __THREW__ = 0;
     invoke_viii(3262,($24|0),1,1);
     $29 = __THREW__; __THREW__ = 0;
     $30 = $29&1;
     if ($30) {
      $261 = ___cxa_find_matching_catch_2()|0;
      $262 = tempRet0;
      $$1 = $262;$$13 = $261;
      label = 116;
      break;
     }
    }
   }
   HEAP32[$23>>2] = 0;
   $31 = ((($0)) + 264|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ($32|0)==(0|0);
   do {
    if (!($33)) {
     $34 = ((($0)) + 268|0);
     while(1) {
      $35 = HEAP32[$34>>2]|0;
      $36 = ($35|0)==($32|0);
      if ($36) {
       label = 19;
       break;
      }
      $37 = ((($35)) + -108|0);
      HEAP32[$34>>2] = $37;
      $38 = HEAP32[$37>>2]|0;
      $39 = ((($38)) + 4|0);
      $40 = HEAP32[$39>>2]|0;
      __THREW__ = 0;
      invoke_vi($40|0,($37|0));
      $41 = __THREW__; __THREW__ = 0;
      $42 = $41&1;
      if ($42) {
       label = 18;
       break;
      }
     }
     if ((label|0) == 18) {
      $43 = ___cxa_find_matching_catch_2()|0;
      $44 = tempRet0;
      ___cxa_call_unexpected(($43|0));
      // unreachable;
     }
     else if ((label|0) == 19) {
      $45 = HEAP32[$31>>2]|0;
      __ZdlPv($45);
      break;
     }
    }
   } while(0);
   $46 = ((($0)) + 252|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = ($47|0)==(0|0);
   do {
    if (!($48)) {
     $49 = ((($0)) + 256|0);
     while(1) {
      $50 = HEAP32[$49>>2]|0;
      $51 = ($50|0)==($47|0);
      if ($51) {
       label = 25;
       break;
      }
      $52 = ((($50)) + -108|0);
      HEAP32[$49>>2] = $52;
      $53 = HEAP32[$52>>2]|0;
      $54 = ((($53)) + 4|0);
      $55 = HEAP32[$54>>2]|0;
      __THREW__ = 0;
      invoke_vi($55|0,($52|0));
      $56 = __THREW__; __THREW__ = 0;
      $57 = $56&1;
      if ($57) {
       label = 24;
       break;
      }
     }
     if ((label|0) == 24) {
      $58 = ___cxa_find_matching_catch_2()|0;
      $59 = tempRet0;
      ___cxa_call_unexpected(($58|0));
      // unreachable;
     }
     else if ((label|0) == 25) {
      $60 = HEAP32[$46>>2]|0;
      __ZdlPv($60);
      break;
     }
    }
   } while(0);
   $61 = ((($0)) + 240|0);
   $62 = HEAP32[$61>>2]|0;
   $63 = ($62|0)==(0|0);
   do {
    if (!($63)) {
     $64 = ((($0)) + 244|0);
     while(1) {
      $65 = HEAP32[$64>>2]|0;
      $66 = ($65|0)==($62|0);
      if ($66) {
       label = 31;
       break;
      }
      $67 = ((($65)) + -108|0);
      HEAP32[$64>>2] = $67;
      $68 = HEAP32[$67>>2]|0;
      $69 = ((($68)) + 4|0);
      $70 = HEAP32[$69>>2]|0;
      __THREW__ = 0;
      invoke_vi($70|0,($67|0));
      $71 = __THREW__; __THREW__ = 0;
      $72 = $71&1;
      if ($72) {
       label = 30;
       break;
      }
     }
     if ((label|0) == 30) {
      $73 = ___cxa_find_matching_catch_2()|0;
      $74 = tempRet0;
      ___cxa_call_unexpected(($73|0));
      // unreachable;
     }
     else if ((label|0) == 31) {
      $75 = HEAP32[$61>>2]|0;
      __ZdlPv($75);
      break;
     }
    }
   } while(0);
   $76 = ((($0)) + 224|0);
   $77 = HEAP32[$76>>2]|0;
   $78 = ($77|0)==(0|0);
   if (!($78)) {
    $79 = ((($0)) + 228|0);
    $80 = HEAP32[$79>>2]|0;
    $81 = ($80|0)==($77|0);
    if (!($81)) {
     $scevgep$i$i$i$i = ((($80)) + -12|0);
     $82 = $scevgep$i$i$i$i;
     $83 = $77;
     $84 = (($82) - ($83))|0;
     $85 = (($84>>>0) / 12)&-1;
     $86 = $85 ^ -1;
     $scevgep5$i$i$i$i = (($80) + (($86*12)|0)|0);
     HEAP32[$79>>2] = $scevgep5$i$i$i$i;
    }
    __ZdlPv($77);
   }
   $87 = ((($0)) + 196|0);
   $88 = HEAP32[$87>>2]|0;
   $89 = ($88|0)==(0|0);
   if (!($89)) {
    $90 = ((($0)) + 200|0);
    $91 = HEAP32[$90>>2]|0;
    $92 = ($91|0)==($88|0);
    if (!($92)) {
     $scevgep$i$i$i$i21 = ((($91)) + -12|0);
     $93 = $scevgep$i$i$i$i21;
     $94 = $88;
     $95 = (($93) - ($94))|0;
     $96 = (($95>>>0) / 12)&-1;
     $97 = $96 ^ -1;
     $scevgep5$i$i$i$i22 = (($91) + (($97*12)|0)|0);
     HEAP32[$90>>2] = $scevgep5$i$i$i$i22;
    }
    __ZdlPv($88);
   }
   $98 = ((($0)) + 168|0);
   $99 = HEAP32[$98>>2]|0;
   $100 = ($99|0)==(0|0);
   if (!($100)) {
    $101 = ((($0)) + 172|0);
    $102 = HEAP32[$101>>2]|0;
    $103 = ($102|0)==($99|0);
    if (!($103)) {
     $scevgep$i$i$i$i26 = ((($102)) + -12|0);
     $104 = $scevgep$i$i$i$i26;
     $105 = $99;
     $106 = (($104) - ($105))|0;
     $107 = (($106>>>0) / 12)&-1;
     $108 = $107 ^ -1;
     $scevgep5$i$i$i$i27 = (($102) + (($108*12)|0)|0);
     HEAP32[$101>>2] = $scevgep5$i$i$i$i27;
    }
    __ZdlPv($99);
   }
   $109 = ((($0)) + 140|0);
   $110 = HEAP32[$109>>2]|0;
   $111 = ($110|0)==(0|0);
   if (!($111)) {
    $112 = ((($0)) + 144|0);
    $113 = HEAP32[$112>>2]|0;
    $114 = ($113|0)==($110|0);
    do {
     if ($114) {
      $128 = $110;
     } else {
      $116 = $113;
      while(1) {
       $115 = ((($116)) + -4|0);
       HEAP32[$112>>2] = $115;
       $117 = HEAP32[$115>>2]|0;
       $118 = ($117|0)==(0|0);
       if (!($118)) {
        $119 = ((($117)) + 8|0);
        $120 = HEAP32[$119>>2]|0;HEAP32[$119>>2] = (($120-1)|0);
        $121 = ($120|0)==(1);
        if ($121) {
         __THREW__ = 0;
         invoke_viii(3262,($117|0),1,1);
         $122 = __THREW__; __THREW__ = 0;
         $123 = $122&1;
         if ($123) {
          label = 50;
          break;
         }
        }
       }
       HEAP32[$115>>2] = 0;
       $124 = HEAP32[$112>>2]|0;
       $125 = ($124|0)==($110|0);
       if ($125) {
        label = 51;
        break;
       } else {
        $116 = $124;
       }
      }
      if ((label|0) == 50) {
       $126 = ___cxa_find_matching_catch_2()|0;
       $127 = tempRet0;
       ___cxa_call_unexpected(($126|0));
       // unreachable;
      }
      else if ((label|0) == 51) {
       $$pre$i$i = HEAP32[$109>>2]|0;
       $128 = $$pre$i$i;
       break;
      }
     }
    } while(0);
    __ZdlPv($128);
   }
   $129 = ((($0)) + 136|0);
   $130 = HEAP32[$129>>2]|0;
   $131 = ($130|0)==(0|0);
   if (!($131)) {
    $132 = ((($130)) + 8|0);
    $133 = HEAP32[$132>>2]|0;HEAP32[$132>>2] = (($133-1)|0);
    $134 = ($133|0)==(1);
    if ($134) {
     __THREW__ = 0;
     invoke_viii(3262,($130|0),1,1);
     $135 = __THREW__; __THREW__ = 0;
     $136 = $135&1;
     if ($136) {
      $349 = ___cxa_find_matching_catch_2()|0;
      $350 = tempRet0;
      $$8 = $350;$$810 = $349;
      label = 161;
      break;
     }
    }
   }
   HEAP32[$129>>2] = 0;
   $137 = ((($0)) + 120|0);
   $138 = HEAP32[$137>>2]|0;
   $139 = ($138|0)==(0|0);
   if (!($139)) {
    $140 = ((($0)) + 124|0);
    $141 = HEAP32[$140>>2]|0;
    $142 = ($141|0)==($138|0);
    do {
     if ($142) {
      $156 = $138;
     } else {
      $144 = $141;
      while(1) {
       $143 = ((($144)) + -4|0);
       HEAP32[$140>>2] = $143;
       $145 = HEAP32[$143>>2]|0;
       $146 = ($145|0)==(0|0);
       if (!($146)) {
        $147 = ((($145)) + 8|0);
        $148 = HEAP32[$147>>2]|0;HEAP32[$147>>2] = (($148-1)|0);
        $149 = ($148|0)==(1);
        if ($149) {
         __THREW__ = 0;
         invoke_viii(3262,($145|0),1,1);
         $150 = __THREW__; __THREW__ = 0;
         $151 = $150&1;
         if ($151) {
          label = 62;
          break;
         }
        }
       }
       HEAP32[$143>>2] = 0;
       $152 = HEAP32[$140>>2]|0;
       $153 = ($152|0)==($138|0);
       if ($153) {
        label = 63;
        break;
       } else {
        $144 = $152;
       }
      }
      if ((label|0) == 62) {
       $154 = ___cxa_find_matching_catch_2()|0;
       $155 = tempRet0;
       ___cxa_call_unexpected(($154|0));
       // unreachable;
      }
      else if ((label|0) == 63) {
       $$pre$i$i34 = HEAP32[$137>>2]|0;
       $156 = $$pre$i$i34;
       break;
      }
     }
    } while(0);
    __ZdlPv($156);
   }
   $157 = ((($0)) + 116|0);
   $158 = HEAP32[$157>>2]|0;
   $159 = ($158|0)==(0|0);
   if (!($159)) {
    $160 = ((($158)) + 8|0);
    $161 = HEAP32[$160>>2]|0;HEAP32[$160>>2] = (($161-1)|0);
    $162 = ($161|0)==(1);
    if ($162) {
     __THREW__ = 0;
     invoke_viii(3262,($158|0),1,1);
     $163 = __THREW__; __THREW__ = 0;
     $164 = $163&1;
     if ($164) {
      $379 = ___cxa_find_matching_catch_2()|0;
      $380 = tempRet0;
      $$9 = $380;$$911 = $379;
      label = 175;
      break;
     }
    }
   }
   HEAP32[$157>>2] = 0;
   $165 = ((($0)) + 100|0);
   $166 = HEAP32[$165>>2]|0;
   $167 = ($166|0)==(0|0);
   if (!($167)) {
    $168 = ((($0)) + 104|0);
    $169 = HEAP32[$168>>2]|0;
    $170 = ($169|0)==($166|0);
    do {
     if ($170) {
      $184 = $166;
     } else {
      $172 = $169;
      L128: while(1) {
       $171 = ((($172)) + -4|0);
       HEAP32[$168>>2] = $171;
       $173 = HEAP32[$171>>2]|0;
       $174 = ($173|0)==(0|0);
       do {
        if (!($174)) {
         $175 = ((($173)) + 8|0);
         $176 = HEAP32[$175>>2]|0;HEAP32[$175>>2] = (($176-1)|0);
         $177 = ($176|0)==(1);
         if (!($177)) {
          break;
         }
         __THREW__ = 0;
         invoke_viii(3262,($173|0),1,1);
         $178 = __THREW__; __THREW__ = 0;
         $179 = $178&1;
         if ($179) {
          label = 74;
          break L128;
         }
        }
       } while(0);
       HEAP32[$171>>2] = 0;
       $180 = HEAP32[$168>>2]|0;
       $181 = ($180|0)==($166|0);
       if ($181) {
        label = 75;
        break;
       } else {
        $172 = $180;
       }
      }
      if ((label|0) == 74) {
       $182 = ___cxa_find_matching_catch_2()|0;
       $183 = tempRet0;
       ___cxa_call_unexpected(($182|0));
       // unreachable;
      }
      else if ((label|0) == 75) {
       $$pre$i$i39 = HEAP32[$165>>2]|0;
       $184 = $$pre$i$i39;
       break;
      }
     }
    } while(0);
    __ZdlPv($184);
   }
   $185 = ((($0)) + 96|0);
   $186 = HEAP32[$185>>2]|0;
   $187 = ($186|0)==(0|0);
   if (!($187)) {
    $188 = ((($186)) + 8|0);
    $189 = HEAP32[$188>>2]|0;HEAP32[$188>>2] = (($189-1)|0);
    $190 = ($189|0)==(1);
    if ($190) {
     __THREW__ = 0;
     invoke_viii(3262,($186|0),1,1);
     $191 = __THREW__; __THREW__ = 0;
     $192 = $191&1;
     if ($192) {
      $409 = ___cxa_find_matching_catch_2()|0;
      $410 = tempRet0;
      $$10 = $410;$$1012 = $409;
      label = 189;
      break;
     }
    }
   }
   HEAP32[$185>>2] = 0;
   $193 = ((($0)) + 80|0);
   $194 = HEAP32[$193>>2]|0;
   $195 = ($194|0)==(0|0);
   if (!($195)) {
    $196 = ((($0)) + 84|0);
    $197 = HEAP32[$196>>2]|0;
    $198 = ($197|0)==($194|0);
    do {
     if ($198) {
      $212 = $194;
     } else {
      $200 = $197;
      L147: while(1) {
       $199 = ((($200)) + -4|0);
       HEAP32[$196>>2] = $199;
       $201 = HEAP32[$199>>2]|0;
       $202 = ($201|0)==(0|0);
       do {
        if (!($202)) {
         $203 = ((($201)) + 8|0);
         $204 = HEAP32[$203>>2]|0;HEAP32[$203>>2] = (($204-1)|0);
         $205 = ($204|0)==(1);
         if (!($205)) {
          break;
         }
         __THREW__ = 0;
         invoke_viii(3262,($201|0),1,1);
         $206 = __THREW__; __THREW__ = 0;
         $207 = $206&1;
         if ($207) {
          label = 86;
          break L147;
         }
        }
       } while(0);
       HEAP32[$199>>2] = 0;
       $208 = HEAP32[$196>>2]|0;
       $209 = ($208|0)==($194|0);
       if ($209) {
        label = 87;
        break;
       } else {
        $200 = $208;
       }
      }
      if ((label|0) == 86) {
       $210 = ___cxa_find_matching_catch_2()|0;
       $211 = tempRet0;
       ___cxa_call_unexpected(($210|0));
       // unreachable;
      }
      else if ((label|0) == 87) {
       $$pre$i$i48 = HEAP32[$193>>2]|0;
       $212 = $$pre$i$i48;
       break;
      }
     }
    } while(0);
    __ZdlPv($212);
   }
   $213 = ((($0)) + 76|0);
   $214 = HEAP32[$213>>2]|0;
   $215 = ($214|0)==(0|0);
   do {
    if (!($215)) {
     $216 = ((($214)) + 8|0);
     $217 = HEAP32[$216>>2]|0;HEAP32[$216>>2] = (($217-1)|0);
     $218 = ($217|0)==(1);
     if ($218) {
      __THREW__ = 0;
      invoke_viii(3262,($214|0),1,1);
      $219 = __THREW__; __THREW__ = 0;
      $220 = $219&1;
      if (!($220)) {
       break;
      }
      $439 = ___cxa_find_matching_catch_2()|0;
      $440 = tempRet0;
      $$11 = $440;$$1113 = $439;
      break L1;
     }
    }
   } while(0);
   HEAP32[$213>>2] = 0;
   $221 = ((($0)) + 64|0);
   $222 = HEAP32[$221>>2]|0;
   $223 = ($222|0)==(0|0);
   do {
    if (!($223)) {
     $224 = ((($0)) + 68|0);
     while(1) {
      $225 = HEAP32[$224>>2]|0;
      $226 = ($225|0)==($222|0);
      if ($226) {
       label = 97;
       break;
      }
      $227 = ((($225)) + -80|0);
      HEAP32[$224>>2] = $227;
      __THREW__ = 0;
      invoke_vi(3586,($227|0));
      $228 = __THREW__; __THREW__ = 0;
      $229 = $228&1;
      if ($229) {
       label = 96;
       break;
      }
     }
     if ((label|0) == 96) {
      $230 = ___cxa_find_matching_catch_2()|0;
      $231 = tempRet0;
      ___cxa_call_unexpected(($230|0));
      // unreachable;
     }
     else if ((label|0) == 97) {
      $232 = HEAP32[$221>>2]|0;
      __ZdlPv($232);
      break;
     }
    }
   } while(0);
   HEAP32[$0>>2] = (58232);
   $233 = ((($0)) + 28|0);
   $234 = HEAP32[$233>>2]|0;
   $235 = ($234|0)==(0|0);
   if ($235) {
    HEAP32[$233>>2] = 0;
    return;
   }
   $236 = ((($234)) + 8|0);
   $237 = HEAP32[$236>>2]|0;HEAP32[$236>>2] = (($237-1)|0);
   $238 = ($237|0)==(1);
   if (!($238)) {
    HEAP32[$233>>2] = 0;
    return;
   }
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($234,1,1);
   HEAP32[$233>>2] = 0;
   return;
  }
 } while(0);
 if ((label|0) == 116) {
  $271 = ((($0)) + 264|0);
  $272 = HEAP32[$271>>2]|0;
  $273 = ($272|0)==(0|0);
  do {
   if (!($273)) {
    $274 = ((($0)) + 268|0);
    while(1) {
     $275 = HEAP32[$274>>2]|0;
     $276 = ($275|0)==($272|0);
     if ($276) {
      label = 121;
      break;
     }
     $277 = ((($275)) + -108|0);
     HEAP32[$274>>2] = $277;
     $278 = HEAP32[$277>>2]|0;
     $279 = ((($278)) + 4|0);
     $280 = HEAP32[$279>>2]|0;
     __THREW__ = 0;
     invoke_vi($280|0,($277|0));
     $281 = __THREW__; __THREW__ = 0;
     $282 = $281&1;
     if ($282) {
      label = 120;
      break;
     }
    }
    if ((label|0) == 120) {
     $283 = ___cxa_find_matching_catch_2()|0;
     $284 = tempRet0;
     ___cxa_call_unexpected(($283|0));
     // unreachable;
    }
    else if ((label|0) == 121) {
     $285 = HEAP32[$271>>2]|0;
     __ZdlPv($285);
     break;
    }
   }
  } while(0);
  $286 = ((($0)) + 252|0);
  $287 = HEAP32[$286>>2]|0;
  $288 = ($287|0)==(0|0);
  do {
   if (!($288)) {
    $289 = ((($0)) + 256|0);
    while(1) {
     $290 = HEAP32[$289>>2]|0;
     $291 = ($290|0)==($287|0);
     if ($291) {
      label = 127;
      break;
     }
     $292 = ((($290)) + -108|0);
     HEAP32[$289>>2] = $292;
     $293 = HEAP32[$292>>2]|0;
     $294 = ((($293)) + 4|0);
     $295 = HEAP32[$294>>2]|0;
     __THREW__ = 0;
     invoke_vi($295|0,($292|0));
     $296 = __THREW__; __THREW__ = 0;
     $297 = $296&1;
     if ($297) {
      label = 126;
      break;
     }
    }
    if ((label|0) == 126) {
     $298 = ___cxa_find_matching_catch_2()|0;
     $299 = tempRet0;
     ___cxa_call_unexpected(($298|0));
     // unreachable;
    }
    else if ((label|0) == 127) {
     $300 = HEAP32[$286>>2]|0;
     __ZdlPv($300);
     break;
    }
   }
  } while(0);
  $301 = ((($0)) + 240|0);
  $302 = HEAP32[$301>>2]|0;
  $303 = ($302|0)==(0|0);
  do {
   if (!($303)) {
    $304 = ((($0)) + 244|0);
    while(1) {
     $305 = HEAP32[$304>>2]|0;
     $306 = ($305|0)==($302|0);
     if ($306) {
      label = 133;
      break;
     }
     $307 = ((($305)) + -108|0);
     HEAP32[$304>>2] = $307;
     $308 = HEAP32[$307>>2]|0;
     $309 = ((($308)) + 4|0);
     $310 = HEAP32[$309>>2]|0;
     __THREW__ = 0;
     invoke_vi($310|0,($307|0));
     $311 = __THREW__; __THREW__ = 0;
     $312 = $311&1;
     if ($312) {
      label = 132;
      break;
     }
    }
    if ((label|0) == 132) {
     $313 = ___cxa_find_matching_catch_2()|0;
     $314 = tempRet0;
     ___cxa_call_unexpected(($313|0));
     // unreachable;
    }
    else if ((label|0) == 133) {
     $315 = HEAP32[$301>>2]|0;
     __ZdlPv($315);
     break;
    }
   }
  } while(0);
  $316 = ((($0)) + 224|0);
  $317 = HEAP32[$316>>2]|0;
  $318 = ($317|0)==(0|0);
  if (!($318)) {
   $319 = ((($0)) + 228|0);
   $320 = HEAP32[$319>>2]|0;
   $321 = ($320|0)==($317|0);
   if (!($321)) {
    $scevgep$i$i$i$i72 = ((($320)) + -12|0);
    $322 = $scevgep$i$i$i$i72;
    $323 = $317;
    $324 = (($322) - ($323))|0;
    $325 = (($324>>>0) / 12)&-1;
    $326 = $325 ^ -1;
    $scevgep5$i$i$i$i73 = (($320) + (($326*12)|0)|0);
    HEAP32[$319>>2] = $scevgep5$i$i$i$i73;
   }
   __ZdlPv($317);
  }
  $327 = ((($0)) + 196|0);
  $328 = HEAP32[$327>>2]|0;
  $329 = ($328|0)==(0|0);
  if (!($329)) {
   $330 = ((($0)) + 200|0);
   $331 = HEAP32[$330>>2]|0;
   $332 = ($331|0)==($328|0);
   if (!($332)) {
    $scevgep$i$i$i$i77 = ((($331)) + -12|0);
    $333 = $scevgep$i$i$i$i77;
    $334 = $328;
    $335 = (($333) - ($334))|0;
    $336 = (($335>>>0) / 12)&-1;
    $337 = $336 ^ -1;
    $scevgep5$i$i$i$i78 = (($331) + (($337*12)|0)|0);
    HEAP32[$330>>2] = $scevgep5$i$i$i$i78;
   }
   __ZdlPv($328);
  }
  $338 = ((($0)) + 168|0);
  $339 = HEAP32[$338>>2]|0;
  $340 = ($339|0)==(0|0);
  if (!($340)) {
   $341 = ((($0)) + 172|0);
   $342 = HEAP32[$341>>2]|0;
   $343 = ($342|0)==($339|0);
   if (!($343)) {
    $scevgep$i$i$i$i82 = ((($342)) + -12|0);
    $344 = $scevgep$i$i$i$i82;
    $345 = $339;
    $346 = (($344) - ($345))|0;
    $347 = (($346>>>0) / 12)&-1;
    $348 = $347 ^ -1;
    $scevgep5$i$i$i$i83 = (($342) + (($348*12)|0)|0);
    HEAP32[$341>>2] = $scevgep5$i$i$i$i83;
   }
   __ZdlPv($339);
  }
  $351 = ((($0)) + 140|0);
  $352 = HEAP32[$351>>2]|0;
  $353 = ($352|0)==(0|0);
  if (!($353)) {
   $354 = ((($0)) + 144|0);
   $355 = HEAP32[$354>>2]|0;
   $356 = ($355|0)==($352|0);
   do {
    if ($356) {
     $370 = $352;
    } else {
     $358 = $355;
     while(1) {
      $357 = ((($358)) + -4|0);
      HEAP32[$354>>2] = $357;
      $359 = HEAP32[$357>>2]|0;
      $360 = ($359|0)==(0|0);
      if (!($360)) {
       $361 = ((($359)) + 8|0);
       $362 = HEAP32[$361>>2]|0;HEAP32[$361>>2] = (($362-1)|0);
       $363 = ($362|0)==(1);
       if ($363) {
        __THREW__ = 0;
        invoke_viii(3262,($359|0),1,1);
        $364 = __THREW__; __THREW__ = 0;
        $365 = $364&1;
        if ($365) {
         label = 153;
         break;
        }
       }
      }
      HEAP32[$357>>2] = 0;
      $366 = HEAP32[$354>>2]|0;
      $367 = ($366|0)==($352|0);
      if ($367) {
       label = 154;
       break;
      } else {
       $358 = $366;
      }
     }
     if ((label|0) == 153) {
      $368 = ___cxa_find_matching_catch_2()|0;
      $369 = tempRet0;
      ___cxa_call_unexpected(($368|0));
      // unreachable;
     }
     else if ((label|0) == 154) {
      $$pre$i$i90 = HEAP32[$351>>2]|0;
      $370 = $$pre$i$i90;
      break;
     }
    }
   } while(0);
   __ZdlPv($370);
  }
  $371 = ((($0)) + 136|0);
  $372 = HEAP32[$371>>2]|0;
  $373 = ($372|0)==(0|0);
  if (!($373)) {
   $374 = ((($372)) + 8|0);
   $375 = HEAP32[$374>>2]|0;HEAP32[$374>>2] = (($375-1)|0);
   $376 = ($375|0)==(1);
   if ($376) {
    __THREW__ = 0;
    invoke_viii(3262,($372|0),1,1);
    $377 = __THREW__; __THREW__ = 0;
    $378 = $377&1;
    if ($378) {
     $489 = ___cxa_find_matching_catch_3(0|0)|0;
     $490 = tempRet0;
     ___clang_call_terminate($489);
     // unreachable;
    }
   }
  }
  HEAP32[$371>>2] = 0;
  $$8 = $$1;$$810 = $$13;
  label = 161;
 }
 if ((label|0) == 161) {
  $381 = ((($0)) + 120|0);
  $382 = HEAP32[$381>>2]|0;
  $383 = ($382|0)==(0|0);
  if (!($383)) {
   $384 = ((($0)) + 124|0);
   $385 = HEAP32[$384>>2]|0;
   $386 = ($385|0)==($382|0);
   do {
    if ($386) {
     $400 = $382;
    } else {
     $388 = $385;
     while(1) {
      $387 = ((($388)) + -4|0);
      HEAP32[$384>>2] = $387;
      $389 = HEAP32[$387>>2]|0;
      $390 = ($389|0)==(0|0);
      if (!($390)) {
       $391 = ((($389)) + 8|0);
       $392 = HEAP32[$391>>2]|0;HEAP32[$391>>2] = (($392-1)|0);
       $393 = ($392|0)==(1);
       if ($393) {
        __THREW__ = 0;
        invoke_viii(3262,($389|0),1,1);
        $394 = __THREW__; __THREW__ = 0;
        $395 = $394&1;
        if ($395) {
         label = 167;
         break;
        }
       }
      }
      HEAP32[$387>>2] = 0;
      $396 = HEAP32[$384>>2]|0;
      $397 = ($396|0)==($382|0);
      if ($397) {
       label = 168;
       break;
      } else {
       $388 = $396;
      }
     }
     if ((label|0) == 167) {
      $398 = ___cxa_find_matching_catch_2()|0;
      $399 = tempRet0;
      ___cxa_call_unexpected(($398|0));
      // unreachable;
     }
     else if ((label|0) == 168) {
      $$pre$i$i99 = HEAP32[$381>>2]|0;
      $400 = $$pre$i$i99;
      break;
     }
    }
   } while(0);
   __ZdlPv($400);
  }
  $401 = ((($0)) + 116|0);
  $402 = HEAP32[$401>>2]|0;
  $403 = ($402|0)==(0|0);
  if (!($403)) {
   $404 = ((($402)) + 8|0);
   $405 = HEAP32[$404>>2]|0;HEAP32[$404>>2] = (($405-1)|0);
   $406 = ($405|0)==(1);
   if ($406) {
    __THREW__ = 0;
    invoke_viii(3262,($402|0),1,1);
    $407 = __THREW__; __THREW__ = 0;
    $408 = $407&1;
    if ($408) {
     $489 = ___cxa_find_matching_catch_3(0|0)|0;
     $490 = tempRet0;
     ___clang_call_terminate($489);
     // unreachable;
    }
   }
  }
  HEAP32[$401>>2] = 0;
  $$9 = $$8;$$911 = $$810;
  label = 175;
 }
 if ((label|0) == 175) {
  $411 = ((($0)) + 100|0);
  $412 = HEAP32[$411>>2]|0;
  $413 = ($412|0)==(0|0);
  if (!($413)) {
   $414 = ((($0)) + 104|0);
   $415 = HEAP32[$414>>2]|0;
   $416 = ($415|0)==($412|0);
   do {
    if ($416) {
     $430 = $412;
    } else {
     $418 = $415;
     while(1) {
      $417 = ((($418)) + -4|0);
      HEAP32[$414>>2] = $417;
      $419 = HEAP32[$417>>2]|0;
      $420 = ($419|0)==(0|0);
      if (!($420)) {
       $421 = ((($419)) + 8|0);
       $422 = HEAP32[$421>>2]|0;HEAP32[$421>>2] = (($422-1)|0);
       $423 = ($422|0)==(1);
       if ($423) {
        __THREW__ = 0;
        invoke_viii(3262,($419|0),1,1);
        $424 = __THREW__; __THREW__ = 0;
        $425 = $424&1;
        if ($425) {
         label = 181;
         break;
        }
       }
      }
      HEAP32[$417>>2] = 0;
      $426 = HEAP32[$414>>2]|0;
      $427 = ($426|0)==($412|0);
      if ($427) {
       label = 182;
       break;
      } else {
       $418 = $426;
      }
     }
     if ((label|0) == 181) {
      $428 = ___cxa_find_matching_catch_2()|0;
      $429 = tempRet0;
      ___cxa_call_unexpected(($428|0));
      // unreachable;
     }
     else if ((label|0) == 182) {
      $$pre$i$i108 = HEAP32[$411>>2]|0;
      $430 = $$pre$i$i108;
      break;
     }
    }
   } while(0);
   __ZdlPv($430);
  }
  $431 = ((($0)) + 96|0);
  $432 = HEAP32[$431>>2]|0;
  $433 = ($432|0)==(0|0);
  if (!($433)) {
   $434 = ((($432)) + 8|0);
   $435 = HEAP32[$434>>2]|0;HEAP32[$434>>2] = (($435-1)|0);
   $436 = ($435|0)==(1);
   if ($436) {
    __THREW__ = 0;
    invoke_viii(3262,($432|0),1,1);
    $437 = __THREW__; __THREW__ = 0;
    $438 = $437&1;
    if ($438) {
     $489 = ___cxa_find_matching_catch_3(0|0)|0;
     $490 = tempRet0;
     ___clang_call_terminate($489);
     // unreachable;
    }
   }
  }
  HEAP32[$431>>2] = 0;
  $$10 = $$9;$$1012 = $$911;
  label = 189;
 }
 if ((label|0) == 189) {
  $441 = ((($0)) + 80|0);
  $442 = HEAP32[$441>>2]|0;
  $443 = ($442|0)==(0|0);
  if (!($443)) {
   $444 = ((($0)) + 84|0);
   $445 = HEAP32[$444>>2]|0;
   $446 = ($445|0)==($442|0);
   do {
    if ($446) {
     $460 = $442;
    } else {
     $448 = $445;
     while(1) {
      $447 = ((($448)) + -4|0);
      HEAP32[$444>>2] = $447;
      $449 = HEAP32[$447>>2]|0;
      $450 = ($449|0)==(0|0);
      if (!($450)) {
       $451 = ((($449)) + 8|0);
       $452 = HEAP32[$451>>2]|0;HEAP32[$451>>2] = (($452-1)|0);
       $453 = ($452|0)==(1);
       if ($453) {
        __THREW__ = 0;
        invoke_viii(3262,($449|0),1,1);
        $454 = __THREW__; __THREW__ = 0;
        $455 = $454&1;
        if ($455) {
         label = 195;
         break;
        }
       }
      }
      HEAP32[$447>>2] = 0;
      $456 = HEAP32[$444>>2]|0;
      $457 = ($456|0)==($442|0);
      if ($457) {
       label = 196;
       break;
      } else {
       $448 = $456;
      }
     }
     if ((label|0) == 195) {
      $458 = ___cxa_find_matching_catch_2()|0;
      $459 = tempRet0;
      ___cxa_call_unexpected(($458|0));
      // unreachable;
     }
     else if ((label|0) == 196) {
      $$pre$i$i117 = HEAP32[$441>>2]|0;
      $460 = $$pre$i$i117;
      break;
     }
    }
   } while(0);
   __ZdlPv($460);
  }
  $461 = ((($0)) + 76|0);
  $462 = HEAP32[$461>>2]|0;
  $463 = ($462|0)==(0|0);
  if (!($463)) {
   $464 = ((($462)) + 8|0);
   $465 = HEAP32[$464>>2]|0;HEAP32[$464>>2] = (($465-1)|0);
   $466 = ($465|0)==(1);
   if ($466) {
    __THREW__ = 0;
    invoke_viii(3262,($462|0),1,1);
    $467 = __THREW__; __THREW__ = 0;
    $468 = $467&1;
    if ($468) {
     $489 = ___cxa_find_matching_catch_3(0|0)|0;
     $490 = tempRet0;
     ___clang_call_terminate($489);
     // unreachable;
    }
   }
  }
  HEAP32[$461>>2] = 0;
  $$11 = $$10;$$1113 = $$1012;
 }
 $469 = ((($0)) + 64|0);
 $470 = HEAP32[$469>>2]|0;
 $471 = ($470|0)==(0|0);
 do {
  if (!($471)) {
   $472 = ((($0)) + 68|0);
   while(1) {
    $473 = HEAP32[$472>>2]|0;
    $474 = ($473|0)==($470|0);
    if ($474) {
     label = 207;
     break;
    }
    $475 = ((($473)) + -80|0);
    HEAP32[$472>>2] = $475;
    __THREW__ = 0;
    invoke_vi(3586,($475|0));
    $476 = __THREW__; __THREW__ = 0;
    $477 = $476&1;
    if ($477) {
     label = 206;
     break;
    }
   }
   if ((label|0) == 206) {
    $478 = ___cxa_find_matching_catch_2()|0;
    $479 = tempRet0;
    ___cxa_call_unexpected(($478|0));
    // unreachable;
   }
   else if ((label|0) == 207) {
    $480 = HEAP32[$469>>2]|0;
    __ZdlPv($480);
    break;
   }
  }
 } while(0);
 HEAP32[$0>>2] = (58232);
 $481 = ((($0)) + 28|0);
 $482 = HEAP32[$481>>2]|0;
 $483 = ($482|0)==(0|0);
 if ($483) {
  HEAP32[$481>>2] = 0;
  ___resumeException($$1113|0);
  // unreachable;
 }
 $484 = ((($482)) + 8|0);
 $485 = HEAP32[$484>>2]|0;HEAP32[$484>>2] = (($485-1)|0);
 $486 = ($485|0)==(1);
 if (!($486)) {
  HEAP32[$481>>2] = 0;
  ___resumeException($$1113|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(3262,($482|0),1,1);
 $487 = __THREW__; __THREW__ = 0;
 $488 = $487&1;
 if ($488) {
  $489 = ___cxa_find_matching_catch_3(0|0)|0;
  $490 = tempRet0;
  ___clang_call_terminate($489);
  // unreachable;
 } else {
  HEAP32[$481>>2] = 0;
  ___resumeException($$1113|0);
  // unreachable;
 }
}
function __ZN3osg9CullStackD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1621,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZN3osg9CullStack5resetEv($0) {
 $0 = $0|0;
 var $$sroa$018$0$$sroa_idx = 0, $$sroa$420$0$$sroa_idx22 = 0, $$sroa$5$0$$sroa_idx24 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i$i$i5 = 0, $scevgep$i$i$i$i9 = 0, $scevgep5$i$i$i$i = 0, $scevgep5$i$i$i$i10 = 0, $scevgep5$i$i$i$i6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 84|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==($2|0);
 L1: do {
  if (!($5)) {
   $7 = $4;
   while(1) {
    $6 = ((($7)) + -4|0);
    HEAP32[$3>>2] = $6;
    $8 = HEAP32[$6>>2]|0;
    $9 = ($8|0)==(0|0);
    if (!($9)) {
     $10 = ((($8)) + 8|0);
     $11 = HEAP32[$10>>2]|0;HEAP32[$10>>2] = (($11-1)|0);
     $12 = ($11|0)==(1);
     if ($12) {
      __THREW__ = 0;
      invoke_viii(3262,($8|0),1,1);
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if ($14) {
       break;
      }
     }
    }
    HEAP32[$6>>2] = 0;
    $15 = HEAP32[$3>>2]|0;
    $16 = ($15|0)==($2|0);
    if ($16) {
     break L1;
    } else {
     $7 = $15;
    }
   }
   $17 = ___cxa_find_matching_catch_2()|0;
   $18 = tempRet0;
   ___cxa_call_unexpected(($17|0));
   // unreachable;
  }
 } while(0);
 $19 = ((($0)) + 92|0);
 HEAP32[$19>>2] = 0;
 $20 = ((($0)) + 100|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ((($0)) + 104|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)==($21|0);
 L10: do {
  if (!($24)) {
   $26 = $23;
   while(1) {
    $25 = ((($26)) + -4|0);
    HEAP32[$22>>2] = $25;
    $27 = HEAP32[$25>>2]|0;
    $28 = ($27|0)==(0|0);
    if (!($28)) {
     $29 = ((($27)) + 8|0);
     $30 = HEAP32[$29>>2]|0;HEAP32[$29>>2] = (($30-1)|0);
     $31 = ($30|0)==(1);
     if ($31) {
      __THREW__ = 0;
      invoke_viii(3262,($27|0),1,1);
      $32 = __THREW__; __THREW__ = 0;
      $33 = $32&1;
      if ($33) {
       break;
      }
     }
    }
    HEAP32[$25>>2] = 0;
    $34 = HEAP32[$22>>2]|0;
    $35 = ($34|0)==($21|0);
    if ($35) {
     break L10;
    } else {
     $26 = $34;
    }
   }
   $36 = ___cxa_find_matching_catch_2()|0;
   $37 = tempRet0;
   ___cxa_call_unexpected(($36|0));
   // unreachable;
  }
 } while(0);
 $38 = ((($0)) + 112|0);
 HEAP32[$38>>2] = 0;
 $39 = ((($0)) + 140|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ((($0)) + 144|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ($42|0)==($40|0);
 L19: do {
  if (!($43)) {
   $45 = $42;
   while(1) {
    $44 = ((($45)) + -4|0);
    HEAP32[$41>>2] = $44;
    $46 = HEAP32[$44>>2]|0;
    $47 = ($46|0)==(0|0);
    if (!($47)) {
     $48 = ((($46)) + 8|0);
     $49 = HEAP32[$48>>2]|0;HEAP32[$48>>2] = (($49-1)|0);
     $50 = ($49|0)==(1);
     if ($50) {
      __THREW__ = 0;
      invoke_viii(3262,($46|0),1,1);
      $51 = __THREW__; __THREW__ = 0;
      $52 = $51&1;
      if ($52) {
       break;
      }
     }
    }
    HEAP32[$44>>2] = 0;
    $53 = HEAP32[$41>>2]|0;
    $54 = ($53|0)==($40|0);
    if ($54) {
     break L19;
    } else {
     $45 = $53;
    }
   }
   $55 = ___cxa_find_matching_catch_2()|0;
   $56 = tempRet0;
   ___cxa_call_unexpected(($55|0));
   // unreachable;
  }
 } while(0);
 $57 = ((($0)) + 152|0);
 HEAP32[$57>>2] = 0;
 $58 = ((($0)) + 168|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = ((($0)) + 172|0);
 $61 = HEAP32[$60>>2]|0;
 $62 = ($61|0)==($59|0);
 if (!($62)) {
  $scevgep$i$i$i$i = ((($61)) + -12|0);
  $63 = $scevgep$i$i$i$i;
  $64 = $59;
  $65 = (($63) - ($64))|0;
  $66 = (($65>>>0) / 12)&-1;
  $67 = $66 ^ -1;
  $scevgep5$i$i$i$i = (($61) + (($67*12)|0)|0);
  HEAP32[$60>>2] = $scevgep5$i$i$i$i;
 }
 $68 = ((($0)) + 180|0);
 $$sroa$018$0$$sroa_idx = ((($0)) + 156|0);
 HEAPF32[$$sroa$018$0$$sroa_idx>>2] = 0.0;
 $$sroa$420$0$$sroa_idx22 = ((($0)) + 160|0);
 HEAPF32[$$sroa$420$0$$sroa_idx22>>2] = 0.0;
 $$sroa$5$0$$sroa_idx24 = ((($0)) + 164|0);
 HEAPF32[$$sroa$5$0$$sroa_idx24>>2] = 0.0;
 HEAP32[$68>>2] = 1;
 $69 = ((($0)) + 196|0);
 $70 = HEAP32[$69>>2]|0;
 $71 = ((($0)) + 200|0);
 $72 = HEAP32[$71>>2]|0;
 $73 = ($72|0)==($70|0);
 if (!($73)) {
  $scevgep$i$i$i$i5 = ((($72)) + -12|0);
  $74 = $scevgep$i$i$i$i5;
  $75 = $70;
  $76 = (($74) - ($75))|0;
  $77 = (($76>>>0) / 12)&-1;
  $78 = $77 ^ -1;
  $scevgep5$i$i$i$i6 = (($72) + (($78*12)|0)|0);
  HEAP32[$71>>2] = $scevgep5$i$i$i$i6;
 }
 $79 = ((($0)) + 208|0);
 HEAP32[$79>>2] = 0;
 $80 = ((($0)) + 224|0);
 $81 = HEAP32[$80>>2]|0;
 $82 = ((($0)) + 228|0);
 $83 = HEAP32[$82>>2]|0;
 $84 = ($83|0)==($81|0);
 if (!($84)) {
  $scevgep$i$i$i$i9 = ((($83)) + -12|0);
  $85 = $scevgep$i$i$i$i9;
  $86 = $81;
  $87 = (($85) - ($86))|0;
  $88 = (($87>>>0) / 12)&-1;
  $89 = $88 ^ -1;
  $scevgep5$i$i$i$i10 = (($83) + (($89*12)|0)|0);
  HEAP32[$82>>2] = $scevgep5$i$i$i$i10;
 }
 $90 = ((($0)) + 236|0);
 HEAP32[$90>>2] = 0;
 $91 = ((($0)) + 240|0);
 $92 = HEAP32[$91>>2]|0;
 $93 = ((($0)) + 244|0);
 while(1) {
  $94 = HEAP32[$93>>2]|0;
  $95 = ($94|0)==($92|0);
  if ($95) {
   break;
  }
  $96 = ((($94)) + -108|0);
  HEAP32[$93>>2] = $96;
  $97 = HEAP32[$96>>2]|0;
  $98 = ((($97)) + 4|0);
  $99 = HEAP32[$98>>2]|0;
  __THREW__ = 0;
  invoke_vi($99|0,($96|0));
  $100 = __THREW__; __THREW__ = 0;
  $101 = $100&1;
  if ($101) {
   label = 28;
   break;
  }
 }
 if ((label|0) == 28) {
  $102 = ___cxa_find_matching_catch_2()|0;
  $103 = tempRet0;
  ___cxa_call_unexpected(($102|0));
  // unreachable;
 }
 $104 = ((($0)) + 252|0);
 $105 = HEAP32[$104>>2]|0;
 $106 = ((($0)) + 256|0);
 while(1) {
  $107 = HEAP32[$106>>2]|0;
  $108 = ($107|0)==($105|0);
  if ($108) {
   label = 33;
   break;
  }
  $109 = ((($107)) + -108|0);
  HEAP32[$106>>2] = $109;
  $110 = HEAP32[$109>>2]|0;
  $111 = ((($110)) + 4|0);
  $112 = HEAP32[$111>>2]|0;
  __THREW__ = 0;
  invoke_vi($112|0,($109|0));
  $113 = __THREW__; __THREW__ = 0;
  $114 = $113&1;
  if ($114) {
   label = 32;
   break;
  }
 }
 if ((label|0) == 32) {
  $115 = ___cxa_find_matching_catch_2()|0;
  $116 = tempRet0;
  ___cxa_call_unexpected(($115|0));
  // unreachable;
 }
 else if ((label|0) == 33) {
  $117 = ((($0)) + 276|0);
  HEAP32[$117>>2] = 0;
  $118 = ((($0)) + 280|0);
  HEAP32[$118>>2] = 0;
  $119 = ((($0)) + 292|0);
  HEAP32[$119>>2] = 3;
  $120 = ((($0)) + 288|0);
  HEAP32[$120>>2] = 4;
  $121 = ((($0)) + 312|0);
  HEAP32[$121>>2] = 0;
  return;
 }
}
function __ZN3osg9CullStackC2Ev($0) {
 $0 = $0|0;
 var $$0 = 0, $$02 = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i$i19 = 0, $$pre$i$i47 = 0, $$pre$i$i52 = 0, $$sroa$0$0$$sroa_idx = 0, $$sroa$5$0$$sroa_idx62 = 0, $$sroa$6$0$$sroa_idx65 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0;
 var $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0;
 var $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0;
 var $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0;
 var $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0;
 var $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0;
 var $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0;
 var $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0;
 var $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0;
 var $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i$i$i35 = 0, $scevgep$i$i$i$i40 = 0, $scevgep5$i$i$i$i = 0, $scevgep5$i$i$i$i36 = 0, $scevgep5$i$i$i$i41 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (58232);
 $1 = ((($0)) + 28|0);
 HEAP32[$1>>2] = 0;
 $2 = HEAP32[(58240)>>2]|0;
 __THREW__ = 0;
 invoke_vi($2|0,($0|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if (!($4)) {
  __THREW__ = 0;
  invoke_vi(3610,($0|0));
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   HEAP32[$0>>2] = (58260);
   $18 = ((($0)) + 64|0);
   $19 = ((($0)) + 68|0);
   $20 = ((($0)) + 156|0);
   $21 = ((($0)) + 240|0);
   $22 = ((($0)) + 244|0);
   $23 = ((($0)) + 252|0);
   $24 = ((($0)) + 256|0);
   $25 = ((($0)) + 264|0);
   $26 = ((($0)) + 268|0);
   $27 = ((($0)) + 296|0);
   $28 = ((($0)) + 300|0);
   $29 = ((($0)) + 304|0);
   $30 = ((($0)) + 284|0);
   _memset(($18|0),0,212)|0;
   ;HEAP32[$27>>2]=0|0;HEAP32[$27+4>>2]=0|0;HEAP32[$27+8>>2]=0|0;HEAP32[$27+12>>2]=0|0;
   HEAPF32[$30>>2] = -1.0;
   $31 = ((($0)) + 288|0);
   HEAP32[$31>>2] = 0;
   $32 = ((($0)) + 292|0);
   HEAP32[$32>>2] = 7;
   $33 = ((($0)) + 312|0);
   HEAP32[$33>>2] = 0;
   __THREW__ = 0;
   $34 = (invoke_ii(3276,160)|0);
   $35 = __THREW__; __THREW__ = 0;
   $36 = $35&1;
   L4: do {
    if ($36) {
     label = 22;
    } else {
     __THREW__ = 0;
     invoke_vii(3435,($34|0),0);
     $37 = __THREW__; __THREW__ = 0;
     $38 = $37&1;
     do {
      if ($38) {
       $80 = ___cxa_find_matching_catch_2()|0;
       $81 = tempRet0;
       $eh$lpad$body$index2Z2D = $81;$eh$lpad$body$indexZ2D = $80;
      } else {
       HEAP32[$34>>2] = (63412);
       $39 = ((($34)) + 12|0);
       ;HEAP32[$39>>2]=0|0;HEAP32[$39+4>>2]=0|0;HEAP32[$39+8>>2]=0|0;
       $40 = ((($34)) + 24|0);
       HEAP32[$40>>2] = 2;
       $41 = ((($34)) + 28|0);
       HEAP32[$41>>2] = 0;
       $42 = ((($34)) + 32|0);
       __THREW__ = 0;
       invoke_vi(3299,($42|0));
       $43 = __THREW__; __THREW__ = 0;
       $44 = $43&1;
       if ($44) {
        $45 = ___cxa_find_matching_catch_2()|0;
        $46 = tempRet0;
        __THREW__ = 0;
        invoke_vi(388,($34|0));
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if (!($48)) {
         $eh$lpad$body$index2Z2D = $46;$eh$lpad$body$indexZ2D = $45;
         break;
        }
        $49 = ___cxa_find_matching_catch_3(0|0)|0;
        $50 = tempRet0;
        ___clang_call_terminate($49);
        // unreachable;
       }
       HEAP32[$34>>2] = (47588);
       $51 = HEAP32[$27>>2]|0;
       $52 = ($51|0)==($34|0);
       if (!($52)) {
        HEAP32[$27>>2] = $34;
        $53 = ((($34)) + 8|0);
        $54 = HEAP32[$53>>2]|0;HEAP32[$53>>2] = (($54+1)|0);
        $55 = ($51|0)==(0|0);
        if (!($55)) {
         $56 = ((($51)) + 8|0);
         $57 = HEAP32[$56>>2]|0;HEAP32[$56>>2] = (($57-1)|0);
         $58 = ($57|0)==(1);
         if ($58) {
          __THREW__ = 0;
          invoke_viii(3262,($51|0),1,1);
          $59 = __THREW__; __THREW__ = 0;
          $60 = $59&1;
          if ($60) {
           label = 22;
           break L4;
          }
         }
        }
       }
       $61 = ((($0)) + 276|0);
       HEAP32[$61>>2] = 0;
       $62 = ((($0)) + 280|0);
       HEAP32[$62>>2] = 0;
       $63 = ((($0)) + 180|0);
       $64 = HEAP32[$63>>2]|0;
       $65 = ($64|0)==(0);
       if ($65) {
        $$sroa$0$0$$sroa_idx = ((($0)) + 156|0);
        HEAPF32[$$sroa$0$0$$sroa_idx>>2] = 0.0;
        $$sroa$5$0$$sroa_idx62 = ((($0)) + 160|0);
        HEAPF32[$$sroa$5$0$$sroa_idx62>>2] = 0.0;
        $$sroa$6$0$$sroa_idx65 = ((($0)) + 164|0);
        HEAPF32[$$sroa$6$0$$sroa_idx65>>2] = 0.0;
        $76 = HEAP32[$63>>2]|0;
        $77 = (($76) + 1)|0;
        HEAP32[$63>>2] = $77;
        return;
       }
       $66 = ((($0)) + 172|0);
       $67 = HEAP32[$66>>2]|0;
       $68 = ((($0)) + 176|0);
       $69 = HEAP32[$68>>2]|0;
       $70 = ($67|0)==($69|0);
       if (!($70)) {
        ;HEAP32[$67>>2]=HEAP32[$20>>2]|0;HEAP32[$67+4>>2]=HEAP32[$20+4>>2]|0;HEAP32[$67+8>>2]=HEAP32[$20+8>>2]|0;
        $71 = HEAP32[$66>>2]|0;
        $72 = ((($71)) + 12|0);
        HEAP32[$66>>2] = $72;
        $$sroa$0$0$$sroa_idx = ((($0)) + 156|0);
        HEAPF32[$$sroa$0$0$$sroa_idx>>2] = 0.0;
        $$sroa$5$0$$sroa_idx62 = ((($0)) + 160|0);
        HEAPF32[$$sroa$5$0$$sroa_idx62>>2] = 0.0;
        $$sroa$6$0$$sroa_idx65 = ((($0)) + 164|0);
        HEAPF32[$$sroa$6$0$$sroa_idx65>>2] = 0.0;
        $76 = HEAP32[$63>>2]|0;
        $77 = (($76) + 1)|0;
        HEAP32[$63>>2] = $77;
        return;
       }
       $73 = ((($0)) + 168|0);
       __THREW__ = 0;
       invoke_vii(3736,($73|0),($20|0));
       $74 = __THREW__; __THREW__ = 0;
       $75 = $74&1;
       if ($75) {
        $82 = ___cxa_find_matching_catch_2()|0;
        $83 = tempRet0;
        $$0 = $83;$$02 = $82;
        break L4;
       } else {
        $$sroa$0$0$$sroa_idx = ((($0)) + 156|0);
        HEAPF32[$$sroa$0$0$$sroa_idx>>2] = 0.0;
        $$sroa$5$0$$sroa_idx62 = ((($0)) + 160|0);
        HEAPF32[$$sroa$5$0$$sroa_idx62>>2] = 0.0;
        $$sroa$6$0$$sroa_idx65 = ((($0)) + 164|0);
        HEAPF32[$$sroa$6$0$$sroa_idx65>>2] = 0.0;
        $76 = HEAP32[$63>>2]|0;
        $77 = (($76) + 1)|0;
        HEAP32[$63>>2] = $77;
        return;
       }
      }
     } while(0);
     __ZdlPv($34);
     $$0 = $eh$lpad$body$index2Z2D;$$02 = $eh$lpad$body$indexZ2D;
    }
   } while(0);
   if ((label|0) == 22) {
    $78 = ___cxa_find_matching_catch_2()|0;
    $79 = tempRet0;
    $$0 = $79;$$02 = $78;
   }
   $84 = HEAP32[$28>>2]|0;
   $85 = ($84|0)==(0|0);
   if (!($85)) {
    $86 = HEAP32[$29>>2]|0;
    $87 = ($86|0)==($84|0);
    do {
     if ($87) {
      $101 = $84;
     } else {
      $89 = $86;
      while(1) {
       $88 = ((($89)) + -4|0);
       HEAP32[$29>>2] = $88;
       $90 = HEAP32[$88>>2]|0;
       $91 = ($90|0)==(0|0);
       if (!($91)) {
        $92 = ((($90)) + 8|0);
        $93 = HEAP32[$92>>2]|0;HEAP32[$92>>2] = (($93-1)|0);
        $94 = ($93|0)==(1);
        if ($94) {
         __THREW__ = 0;
         invoke_viii(3262,($90|0),1,1);
         $95 = __THREW__; __THREW__ = 0;
         $96 = $95&1;
         if ($96) {
          label = 32;
          break;
         }
        }
       }
       HEAP32[$88>>2] = 0;
       $97 = HEAP32[$29>>2]|0;
       $98 = ($97|0)==($84|0);
       if ($98) {
        label = 33;
        break;
       } else {
        $89 = $97;
       }
      }
      if ((label|0) == 32) {
       $99 = ___cxa_find_matching_catch_2()|0;
       $100 = tempRet0;
       ___cxa_call_unexpected(($99|0));
       // unreachable;
      }
      else if ((label|0) == 33) {
       $$pre$i = HEAP32[$28>>2]|0;
       $101 = $$pre$i;
       break;
      }
     }
    } while(0);
    __ZdlPv($101);
   }
   $102 = HEAP32[$27>>2]|0;
   $103 = ($102|0)==(0|0);
   if (!($103)) {
    $104 = ((($102)) + 8|0);
    $105 = HEAP32[$104>>2]|0;HEAP32[$104>>2] = (($105-1)|0);
    $106 = ($105|0)==(1);
    if ($106) {
     __THREW__ = 0;
     invoke_viii(3262,($102|0),1,1);
     $107 = __THREW__; __THREW__ = 0;
     $108 = $107&1;
     if ($108) {
      $310 = ___cxa_find_matching_catch_3(0|0)|0;
      $311 = tempRet0;
      ___clang_call_terminate($310);
      // unreachable;
     }
    }
   }
   HEAP32[$27>>2] = 0;
   $109 = HEAP32[$25>>2]|0;
   $110 = ($109|0)==(0|0);
   do {
    if (!($110)) {
     while(1) {
      $111 = HEAP32[$26>>2]|0;
      $112 = ($111|0)==($109|0);
      if ($112) {
       label = 42;
       break;
      }
      $113 = ((($111)) + -108|0);
      HEAP32[$26>>2] = $113;
      $114 = HEAP32[$113>>2]|0;
      $115 = ((($114)) + 4|0);
      $116 = HEAP32[$115>>2]|0;
      __THREW__ = 0;
      invoke_vi($116|0,($113|0));
      $117 = __THREW__; __THREW__ = 0;
      $118 = $117&1;
      if ($118) {
       label = 41;
       break;
      }
     }
     if ((label|0) == 41) {
      $119 = ___cxa_find_matching_catch_2()|0;
      $120 = tempRet0;
      ___cxa_call_unexpected(($119|0));
      // unreachable;
     }
     else if ((label|0) == 42) {
      $121 = HEAP32[$25>>2]|0;
      __ZdlPv($121);
      break;
     }
    }
   } while(0);
   $122 = HEAP32[$23>>2]|0;
   $123 = ($122|0)==(0|0);
   do {
    if (!($123)) {
     while(1) {
      $124 = HEAP32[$24>>2]|0;
      $125 = ($124|0)==($122|0);
      if ($125) {
       label = 47;
       break;
      }
      $126 = ((($124)) + -108|0);
      HEAP32[$24>>2] = $126;
      $127 = HEAP32[$126>>2]|0;
      $128 = ((($127)) + 4|0);
      $129 = HEAP32[$128>>2]|0;
      __THREW__ = 0;
      invoke_vi($129|0,($126|0));
      $130 = __THREW__; __THREW__ = 0;
      $131 = $130&1;
      if ($131) {
       label = 46;
       break;
      }
     }
     if ((label|0) == 46) {
      $132 = ___cxa_find_matching_catch_2()|0;
      $133 = tempRet0;
      ___cxa_call_unexpected(($132|0));
      // unreachable;
     }
     else if ((label|0) == 47) {
      $134 = HEAP32[$23>>2]|0;
      __ZdlPv($134);
      break;
     }
    }
   } while(0);
   $135 = HEAP32[$21>>2]|0;
   $136 = ($135|0)==(0|0);
   do {
    if (!($136)) {
     while(1) {
      $137 = HEAP32[$22>>2]|0;
      $138 = ($137|0)==($135|0);
      if ($138) {
       label = 52;
       break;
      }
      $139 = ((($137)) + -108|0);
      HEAP32[$22>>2] = $139;
      $140 = HEAP32[$139>>2]|0;
      $141 = ((($140)) + 4|0);
      $142 = HEAP32[$141>>2]|0;
      __THREW__ = 0;
      invoke_vi($142|0,($139|0));
      $143 = __THREW__; __THREW__ = 0;
      $144 = $143&1;
      if ($144) {
       label = 51;
       break;
      }
     }
     if ((label|0) == 51) {
      $145 = ___cxa_find_matching_catch_2()|0;
      $146 = tempRet0;
      ___cxa_call_unexpected(($145|0));
      // unreachable;
     }
     else if ((label|0) == 52) {
      $147 = HEAP32[$21>>2]|0;
      __ZdlPv($147);
      break;
     }
    }
   } while(0);
   $148 = ((($0)) + 224|0);
   $149 = HEAP32[$148>>2]|0;
   $150 = ($149|0)==(0|0);
   if (!($150)) {
    $151 = ((($0)) + 228|0);
    $152 = HEAP32[$151>>2]|0;
    $153 = ($152|0)==($149|0);
    if (!($153)) {
     $scevgep$i$i$i$i = ((($152)) + -12|0);
     $154 = $scevgep$i$i$i$i;
     $155 = $149;
     $156 = (($154) - ($155))|0;
     $157 = (($156>>>0) / 12)&-1;
     $158 = $157 ^ -1;
     $scevgep5$i$i$i$i = (($152) + (($158*12)|0)|0);
     HEAP32[$151>>2] = $scevgep5$i$i$i$i;
    }
    __ZdlPv($149);
   }
   $159 = ((($0)) + 196|0);
   $160 = HEAP32[$159>>2]|0;
   $161 = ($160|0)==(0|0);
   if (!($161)) {
    $162 = ((($0)) + 200|0);
    $163 = HEAP32[$162>>2]|0;
    $164 = ($163|0)==($160|0);
    if (!($164)) {
     $scevgep$i$i$i$i35 = ((($163)) + -12|0);
     $165 = $scevgep$i$i$i$i35;
     $166 = $160;
     $167 = (($165) - ($166))|0;
     $168 = (($167>>>0) / 12)&-1;
     $169 = $168 ^ -1;
     $scevgep5$i$i$i$i36 = (($163) + (($169*12)|0)|0);
     HEAP32[$162>>2] = $scevgep5$i$i$i$i36;
    }
    __ZdlPv($160);
   }
   $170 = ((($0)) + 168|0);
   $171 = HEAP32[$170>>2]|0;
   $172 = ($171|0)==(0|0);
   if (!($172)) {
    $173 = ((($0)) + 172|0);
    $174 = HEAP32[$173>>2]|0;
    $175 = ($174|0)==($171|0);
    if (!($175)) {
     $scevgep$i$i$i$i40 = ((($174)) + -12|0);
     $176 = $scevgep$i$i$i$i40;
     $177 = $171;
     $178 = (($176) - ($177))|0;
     $179 = (($178>>>0) / 12)&-1;
     $180 = $179 ^ -1;
     $scevgep5$i$i$i$i41 = (($174) + (($180*12)|0)|0);
     HEAP32[$173>>2] = $scevgep5$i$i$i$i41;
    }
    __ZdlPv($171);
   }
   $181 = ((($0)) + 140|0);
   $182 = HEAP32[$181>>2]|0;
   $183 = ($182|0)==(0|0);
   if (!($183)) {
    $184 = ((($0)) + 144|0);
    $185 = HEAP32[$184>>2]|0;
    $186 = ($185|0)==($182|0);
    do {
     if ($186) {
      $200 = $182;
     } else {
      $188 = $185;
      while(1) {
       $187 = ((($188)) + -4|0);
       HEAP32[$184>>2] = $187;
       $189 = HEAP32[$187>>2]|0;
       $190 = ($189|0)==(0|0);
       if (!($190)) {
        $191 = ((($189)) + 8|0);
        $192 = HEAP32[$191>>2]|0;HEAP32[$191>>2] = (($192-1)|0);
        $193 = ($192|0)==(1);
        if ($193) {
         __THREW__ = 0;
         invoke_viii(3262,($189|0),1,1);
         $194 = __THREW__; __THREW__ = 0;
         $195 = $194&1;
         if ($195) {
          label = 71;
          break;
         }
        }
       }
       HEAP32[$187>>2] = 0;
       $196 = HEAP32[$184>>2]|0;
       $197 = ($196|0)==($182|0);
       if ($197) {
        label = 72;
        break;
       } else {
        $188 = $196;
       }
      }
      if ((label|0) == 71) {
       $198 = ___cxa_find_matching_catch_2()|0;
       $199 = tempRet0;
       ___cxa_call_unexpected(($198|0));
       // unreachable;
      }
      else if ((label|0) == 72) {
       $$pre$i$i47 = HEAP32[$181>>2]|0;
       $200 = $$pre$i$i47;
       break;
      }
     }
    } while(0);
    __ZdlPv($200);
   }
   $201 = ((($0)) + 136|0);
   $202 = HEAP32[$201>>2]|0;
   $203 = ($202|0)==(0|0);
   if (!($203)) {
    $204 = ((($202)) + 8|0);
    $205 = HEAP32[$204>>2]|0;HEAP32[$204>>2] = (($205-1)|0);
    $206 = ($205|0)==(1);
    if ($206) {
     __THREW__ = 0;
     invoke_viii(3262,($202|0),1,1);
     $207 = __THREW__; __THREW__ = 0;
     $208 = $207&1;
     if ($208) {
      $310 = ___cxa_find_matching_catch_3(0|0)|0;
      $311 = tempRet0;
      ___clang_call_terminate($310);
      // unreachable;
     }
    }
   }
   HEAP32[$201>>2] = 0;
   $209 = ((($0)) + 120|0);
   $210 = HEAP32[$209>>2]|0;
   $211 = ($210|0)==(0|0);
   if (!($211)) {
    $212 = ((($0)) + 124|0);
    $213 = HEAP32[$212>>2]|0;
    $214 = ($213|0)==($210|0);
    do {
     if ($214) {
      $228 = $210;
     } else {
      $216 = $213;
      L115: while(1) {
       $215 = ((($216)) + -4|0);
       HEAP32[$212>>2] = $215;
       $217 = HEAP32[$215>>2]|0;
       $218 = ($217|0)==(0|0);
       do {
        if (!($218)) {
         $219 = ((($217)) + 8|0);
         $220 = HEAP32[$219>>2]|0;HEAP32[$219>>2] = (($220-1)|0);
         $221 = ($220|0)==(1);
         if (!($221)) {
          break;
         }
         __THREW__ = 0;
         invoke_viii(3262,($217|0),1,1);
         $222 = __THREW__; __THREW__ = 0;
         $223 = $222&1;
         if ($223) {
          label = 83;
          break L115;
         }
        }
       } while(0);
       HEAP32[$215>>2] = 0;
       $224 = HEAP32[$212>>2]|0;
       $225 = ($224|0)==($210|0);
       if ($225) {
        label = 84;
        break;
       } else {
        $216 = $224;
       }
      }
      if ((label|0) == 83) {
       $226 = ___cxa_find_matching_catch_2()|0;
       $227 = tempRet0;
       ___cxa_call_unexpected(($226|0));
       // unreachable;
      }
      else if ((label|0) == 84) {
       $$pre$i$i52 = HEAP32[$209>>2]|0;
       $228 = $$pre$i$i52;
       break;
      }
     }
    } while(0);
    __ZdlPv($228);
   }
   $229 = ((($0)) + 116|0);
   $230 = HEAP32[$229>>2]|0;
   $231 = ($230|0)==(0|0);
   if (!($231)) {
    $232 = ((($230)) + 8|0);
    $233 = HEAP32[$232>>2]|0;HEAP32[$232>>2] = (($233-1)|0);
    $234 = ($233|0)==(1);
    if ($234) {
     __THREW__ = 0;
     invoke_viii(3262,($230|0),1,1);
     $235 = __THREW__; __THREW__ = 0;
     $236 = $235&1;
     if ($236) {
      $310 = ___cxa_find_matching_catch_3(0|0)|0;
      $311 = tempRet0;
      ___clang_call_terminate($310);
      // unreachable;
     }
    }
   }
   HEAP32[$229>>2] = 0;
   $237 = ((($0)) + 100|0);
   $238 = HEAP32[$237>>2]|0;
   $239 = ($238|0)==(0|0);
   if (!($239)) {
    $240 = ((($0)) + 104|0);
    $241 = HEAP32[$240>>2]|0;
    $242 = ($241|0)==($238|0);
    do {
     if ($242) {
      $256 = $238;
     } else {
      $244 = $241;
      L134: while(1) {
       $243 = ((($244)) + -4|0);
       HEAP32[$240>>2] = $243;
       $245 = HEAP32[$243>>2]|0;
       $246 = ($245|0)==(0|0);
       do {
        if (!($246)) {
         $247 = ((($245)) + 8|0);
         $248 = HEAP32[$247>>2]|0;HEAP32[$247>>2] = (($248-1)|0);
         $249 = ($248|0)==(1);
         if (!($249)) {
          break;
         }
         __THREW__ = 0;
         invoke_viii(3262,($245|0),1,1);
         $250 = __THREW__; __THREW__ = 0;
         $251 = $250&1;
         if ($251) {
          label = 95;
          break L134;
         }
        }
       } while(0);
       HEAP32[$243>>2] = 0;
       $252 = HEAP32[$240>>2]|0;
       $253 = ($252|0)==($238|0);
       if ($253) {
        label = 96;
        break;
       } else {
        $244 = $252;
       }
      }
      if ((label|0) == 95) {
       $254 = ___cxa_find_matching_catch_2()|0;
       $255 = tempRet0;
       ___cxa_call_unexpected(($254|0));
       // unreachable;
      }
      else if ((label|0) == 96) {
       $$pre$i$i19 = HEAP32[$237>>2]|0;
       $256 = $$pre$i$i19;
       break;
      }
     }
    } while(0);
    __ZdlPv($256);
   }
   $257 = ((($0)) + 96|0);
   $258 = HEAP32[$257>>2]|0;
   $259 = ($258|0)==(0|0);
   do {
    if (!($259)) {
     $260 = ((($258)) + 8|0);
     $261 = HEAP32[$260>>2]|0;HEAP32[$260>>2] = (($261-1)|0);
     $262 = ($261|0)==(1);
     if ($262) {
      __THREW__ = 0;
      invoke_viii(3262,($258|0),1,1);
      $263 = __THREW__; __THREW__ = 0;
      $264 = $263&1;
      if (!($264)) {
       break;
      }
      $310 = ___cxa_find_matching_catch_3(0|0)|0;
      $311 = tempRet0;
      ___clang_call_terminate($310);
      // unreachable;
     }
    }
   } while(0);
   HEAP32[$257>>2] = 0;
   $265 = ((($0)) + 80|0);
   $266 = HEAP32[$265>>2]|0;
   $267 = ($266|0)==(0|0);
   if (!($267)) {
    $268 = ((($0)) + 84|0);
    $269 = HEAP32[$268>>2]|0;
    $270 = ($269|0)==($266|0);
    do {
     if ($270) {
      $284 = $266;
     } else {
      $272 = $269;
      L153: while(1) {
       $271 = ((($272)) + -4|0);
       HEAP32[$268>>2] = $271;
       $273 = HEAP32[$271>>2]|0;
       $274 = ($273|0)==(0|0);
       do {
        if (!($274)) {
         $275 = ((($273)) + 8|0);
         $276 = HEAP32[$275>>2]|0;HEAP32[$275>>2] = (($276-1)|0);
         $277 = ($276|0)==(1);
         if (!($277)) {
          break;
         }
         __THREW__ = 0;
         invoke_viii(3262,($273|0),1,1);
         $278 = __THREW__; __THREW__ = 0;
         $279 = $278&1;
         if ($279) {
          label = 107;
          break L153;
         }
        }
       } while(0);
       HEAP32[$271>>2] = 0;
       $280 = HEAP32[$268>>2]|0;
       $281 = ($280|0)==($266|0);
       if ($281) {
        label = 108;
        break;
       } else {
        $272 = $280;
       }
      }
      if ((label|0) == 107) {
       $282 = ___cxa_find_matching_catch_2()|0;
       $283 = tempRet0;
       ___cxa_call_unexpected(($282|0));
       // unreachable;
      }
      else if ((label|0) == 108) {
       $$pre$i$i = HEAP32[$265>>2]|0;
       $284 = $$pre$i$i;
       break;
      }
     }
    } while(0);
    __ZdlPv($284);
   }
   $285 = ((($0)) + 76|0);
   $286 = HEAP32[$285>>2]|0;
   $287 = ($286|0)==(0|0);
   do {
    if (!($287)) {
     $288 = ((($286)) + 8|0);
     $289 = HEAP32[$288>>2]|0;HEAP32[$288>>2] = (($289-1)|0);
     $290 = ($289|0)==(1);
     if (!($290)) {
      break;
     }
     __THREW__ = 0;
     invoke_viii(3262,($286|0),1,1);
     $291 = __THREW__; __THREW__ = 0;
     $292 = $291&1;
     if (!($292)) {
      break;
     }
     $310 = ___cxa_find_matching_catch_3(0|0)|0;
     $311 = tempRet0;
     ___clang_call_terminate($310);
     // unreachable;
    }
   } while(0);
   HEAP32[$285>>2] = 0;
   $293 = HEAP32[$18>>2]|0;
   $294 = ($293|0)==(0|0);
   do {
    if (!($294)) {
     while(1) {
      $295 = HEAP32[$19>>2]|0;
      $296 = ($295|0)==($293|0);
      if ($296) {
       label = 117;
       break;
      }
      $297 = ((($295)) + -80|0);
      HEAP32[$19>>2] = $297;
      __THREW__ = 0;
      invoke_vi(3586,($297|0));
      $298 = __THREW__; __THREW__ = 0;
      $299 = $298&1;
      if ($299) {
       label = 116;
       break;
      }
     }
     if ((label|0) == 116) {
      $300 = ___cxa_find_matching_catch_2()|0;
      $301 = tempRet0;
      ___cxa_call_unexpected(($300|0));
      // unreachable;
     }
     else if ((label|0) == 117) {
      $302 = HEAP32[$18>>2]|0;
      __ZdlPv($302);
      break;
     }
    }
   } while(0);
   HEAP32[$0>>2] = (58232);
   $303 = HEAP32[$1>>2]|0;
   $304 = ($303|0)==(0|0);
   if ($304) {
    HEAP32[$1>>2] = 0;
    ___resumeException($$02|0);
    // unreachable;
   }
   $305 = ((($303)) + 8|0);
   $306 = HEAP32[$305>>2]|0;HEAP32[$305>>2] = (($306-1)|0);
   $307 = ($306|0)==(1);
   if (!($307)) {
    HEAP32[$1>>2] = 0;
    ___resumeException($$02|0);
    // unreachable;
   }
   __THREW__ = 0;
   invoke_viii(3262,($303|0),1,1);
   $308 = __THREW__; __THREW__ = 0;
   $309 = $308&1;
   if ($309) {
    $310 = ___cxa_find_matching_catch_3(0|0)|0;
    $311 = tempRet0;
    ___clang_call_terminate($310);
    // unreachable;
   } else {
    HEAP32[$1>>2] = 0;
    ___resumeException($$02|0);
    // unreachable;
   }
  }
 }
 $7 = ___cxa_find_matching_catch_2()|0;
 $8 = tempRet0;
 $9 = HEAP32[$1>>2]|0;
 $10 = ($9|0)==(0|0);
 if ($10) {
  HEAP32[$1>>2] = 0;
  ___resumeException($7|0);
  // unreachable;
 }
 $11 = ((($9)) + 8|0);
 $12 = HEAP32[$11>>2]|0;HEAP32[$11>>2] = (($12-1)|0);
 $13 = ($12|0)==(1);
 if (!($13)) {
  HEAP32[$1>>2] = 0;
  ___resumeException($7|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(3262,($9|0),1,1);
 $14 = __THREW__; __THREW__ = 0;
 $15 = $14&1;
 if ($15) {
  $16 = ___cxa_find_matching_catch_3(0|0)|0;
  $17 = tempRet0;
  ___clang_call_terminate($16);
  // unreachable;
 } else {
  HEAP32[$1>>2] = 0;
  ___resumeException($7|0);
  // unreachable;
 }
}
function __ZN3osg9CullStackC2ERKS0_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$03 = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i$i20 = 0, $$pre$i$i48 = 0, $$pre$i$i53 = 0, $$sroa$0$0$$sroa_idx = 0, $$sroa$5$0$$sroa_idx63 = 0, $$sroa$6$0$$sroa_idx66 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0;
 var $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0;
 var $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0;
 var $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0;
 var $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0;
 var $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0;
 var $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0;
 var $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0;
 var $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i$i$i36 = 0, $scevgep$i$i$i$i41 = 0, $scevgep5$i$i$i$i = 0, $scevgep5$i$i$i$i37 = 0, $scevgep5$i$i$i$i42 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg12CullSettingsC2ERKS0_($0,$1);
 HEAP32[$0>>2] = (58260);
 $2 = ((($0)) + 64|0);
 $3 = ((($0)) + 68|0);
 $4 = ((($0)) + 156|0);
 $5 = ((($0)) + 240|0);
 $6 = ((($0)) + 244|0);
 $7 = ((($0)) + 252|0);
 $8 = ((($0)) + 256|0);
 $9 = ((($0)) + 264|0);
 $10 = ((($0)) + 268|0);
 $11 = ((($0)) + 296|0);
 $12 = ((($0)) + 300|0);
 $13 = ((($0)) + 304|0);
 $14 = ((($0)) + 284|0);
 _memset(($2|0),0,212)|0;
 ;HEAP32[$11>>2]=0|0;HEAP32[$11+4>>2]=0|0;HEAP32[$11+8>>2]=0|0;HEAP32[$11+12>>2]=0|0;
 HEAPF32[$14>>2] = -1.0;
 $15 = ((($0)) + 288|0);
 HEAP32[$15>>2] = 0;
 $16 = ((($0)) + 292|0);
 HEAP32[$16>>2] = 7;
 $17 = ((($0)) + 312|0);
 HEAP32[$17>>2] = 0;
 __THREW__ = 0;
 $18 = (invoke_ii(3276,160)|0);
 $19 = __THREW__; __THREW__ = 0;
 $20 = $19&1;
 L1: do {
  if ($20) {
   label = 15;
  } else {
   __THREW__ = 0;
   invoke_vii(3435,($18|0),0);
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   do {
    if ($22) {
     $64 = ___cxa_find_matching_catch_2()|0;
     $65 = tempRet0;
     $eh$lpad$body$index2Z2D = $65;$eh$lpad$body$indexZ2D = $64;
    } else {
     HEAP32[$18>>2] = (63412);
     $23 = ((($18)) + 12|0);
     ;HEAP32[$23>>2]=0|0;HEAP32[$23+4>>2]=0|0;HEAP32[$23+8>>2]=0|0;
     $24 = ((($18)) + 24|0);
     HEAP32[$24>>2] = 2;
     $25 = ((($18)) + 28|0);
     HEAP32[$25>>2] = 0;
     $26 = ((($18)) + 32|0);
     __THREW__ = 0;
     invoke_vi(3299,($26|0));
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     if ($28) {
      $29 = ___cxa_find_matching_catch_2()|0;
      $30 = tempRet0;
      __THREW__ = 0;
      invoke_vi(388,($18|0));
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if (!($32)) {
       $eh$lpad$body$index2Z2D = $30;$eh$lpad$body$indexZ2D = $29;
       break;
      }
      $33 = ___cxa_find_matching_catch_3(0|0)|0;
      $34 = tempRet0;
      ___clang_call_terminate($33);
      // unreachable;
     }
     HEAP32[$18>>2] = (47588);
     $35 = HEAP32[$11>>2]|0;
     $36 = ($35|0)==($18|0);
     if (!($36)) {
      HEAP32[$11>>2] = $18;
      $37 = ((($18)) + 8|0);
      $38 = HEAP32[$37>>2]|0;HEAP32[$37>>2] = (($38+1)|0);
      $39 = ($35|0)==(0|0);
      if (!($39)) {
       $40 = ((($35)) + 8|0);
       $41 = HEAP32[$40>>2]|0;HEAP32[$40>>2] = (($41-1)|0);
       $42 = ($41|0)==(1);
       if ($42) {
        __THREW__ = 0;
        invoke_viii(3262,($35|0),1,1);
        $43 = __THREW__; __THREW__ = 0;
        $44 = $43&1;
        if ($44) {
         label = 15;
         break L1;
        }
       }
      }
     }
     $45 = ((($0)) + 276|0);
     HEAP32[$45>>2] = 0;
     $46 = ((($0)) + 280|0);
     HEAP32[$46>>2] = 0;
     $47 = ((($0)) + 180|0);
     $48 = HEAP32[$47>>2]|0;
     $49 = ($48|0)==(0);
     if ($49) {
      $$sroa$0$0$$sroa_idx = ((($0)) + 156|0);
      HEAPF32[$$sroa$0$0$$sroa_idx>>2] = 0.0;
      $$sroa$5$0$$sroa_idx63 = ((($0)) + 160|0);
      HEAPF32[$$sroa$5$0$$sroa_idx63>>2] = 0.0;
      $$sroa$6$0$$sroa_idx66 = ((($0)) + 164|0);
      HEAPF32[$$sroa$6$0$$sroa_idx66>>2] = 0.0;
      $60 = HEAP32[$47>>2]|0;
      $61 = (($60) + 1)|0;
      HEAP32[$47>>2] = $61;
      return;
     }
     $50 = ((($0)) + 172|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = ((($0)) + 176|0);
     $53 = HEAP32[$52>>2]|0;
     $54 = ($51|0)==($53|0);
     if (!($54)) {
      ;HEAP32[$51>>2]=HEAP32[$4>>2]|0;HEAP32[$51+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$51+8>>2]=HEAP32[$4+8>>2]|0;
      $55 = HEAP32[$50>>2]|0;
      $56 = ((($55)) + 12|0);
      HEAP32[$50>>2] = $56;
      $$sroa$0$0$$sroa_idx = ((($0)) + 156|0);
      HEAPF32[$$sroa$0$0$$sroa_idx>>2] = 0.0;
      $$sroa$5$0$$sroa_idx63 = ((($0)) + 160|0);
      HEAPF32[$$sroa$5$0$$sroa_idx63>>2] = 0.0;
      $$sroa$6$0$$sroa_idx66 = ((($0)) + 164|0);
      HEAPF32[$$sroa$6$0$$sroa_idx66>>2] = 0.0;
      $60 = HEAP32[$47>>2]|0;
      $61 = (($60) + 1)|0;
      HEAP32[$47>>2] = $61;
      return;
     }
     $57 = ((($0)) + 168|0);
     __THREW__ = 0;
     invoke_vii(3736,($57|0),($4|0));
     $58 = __THREW__; __THREW__ = 0;
     $59 = $58&1;
     if ($59) {
      $66 = ___cxa_find_matching_catch_2()|0;
      $67 = tempRet0;
      $$0 = $67;$$03 = $66;
      break L1;
     } else {
      $$sroa$0$0$$sroa_idx = ((($0)) + 156|0);
      HEAPF32[$$sroa$0$0$$sroa_idx>>2] = 0.0;
      $$sroa$5$0$$sroa_idx63 = ((($0)) + 160|0);
      HEAPF32[$$sroa$5$0$$sroa_idx63>>2] = 0.0;
      $$sroa$6$0$$sroa_idx66 = ((($0)) + 164|0);
      HEAPF32[$$sroa$6$0$$sroa_idx66>>2] = 0.0;
      $60 = HEAP32[$47>>2]|0;
      $61 = (($60) + 1)|0;
      HEAP32[$47>>2] = $61;
      return;
     }
    }
   } while(0);
   __ZdlPv($18);
   $$0 = $eh$lpad$body$index2Z2D;$$03 = $eh$lpad$body$indexZ2D;
  }
 } while(0);
 if ((label|0) == 15) {
  $62 = ___cxa_find_matching_catch_2()|0;
  $63 = tempRet0;
  $$0 = $63;$$03 = $62;
 }
 $68 = HEAP32[$12>>2]|0;
 $69 = ($68|0)==(0|0);
 if (!($69)) {
  $70 = HEAP32[$13>>2]|0;
  $71 = ($70|0)==($68|0);
  do {
   if ($71) {
    $85 = $68;
   } else {
    $73 = $70;
    while(1) {
     $72 = ((($73)) + -4|0);
     HEAP32[$13>>2] = $72;
     $74 = HEAP32[$72>>2]|0;
     $75 = ($74|0)==(0|0);
     if (!($75)) {
      $76 = ((($74)) + 8|0);
      $77 = HEAP32[$76>>2]|0;HEAP32[$76>>2] = (($77-1)|0);
      $78 = ($77|0)==(1);
      if ($78) {
       __THREW__ = 0;
       invoke_viii(3262,($74|0),1,1);
       $79 = __THREW__; __THREW__ = 0;
       $80 = $79&1;
       if ($80) {
        label = 25;
        break;
       }
      }
     }
     HEAP32[$72>>2] = 0;
     $81 = HEAP32[$13>>2]|0;
     $82 = ($81|0)==($68|0);
     if ($82) {
      label = 26;
      break;
     } else {
      $73 = $81;
     }
    }
    if ((label|0) == 25) {
     $83 = ___cxa_find_matching_catch_2()|0;
     $84 = tempRet0;
     ___cxa_call_unexpected(($83|0));
     // unreachable;
    }
    else if ((label|0) == 26) {
     $$pre$i = HEAP32[$12>>2]|0;
     $85 = $$pre$i;
     break;
    }
   }
  } while(0);
  __ZdlPv($85);
 }
 $86 = HEAP32[$11>>2]|0;
 $87 = ($86|0)==(0|0);
 if (!($87)) {
  $88 = ((($86)) + 8|0);
  $89 = HEAP32[$88>>2]|0;HEAP32[$88>>2] = (($89-1)|0);
  $90 = ($89|0)==(1);
  if ($90) {
   __THREW__ = 0;
   invoke_viii(3262,($86|0),1,1);
   $91 = __THREW__; __THREW__ = 0;
   $92 = $91&1;
   if ($92) {
    $295 = ___cxa_find_matching_catch_3(0|0)|0;
    $296 = tempRet0;
    ___clang_call_terminate($295);
    // unreachable;
   }
  }
 }
 HEAP32[$11>>2] = 0;
 $93 = HEAP32[$9>>2]|0;
 $94 = ($93|0)==(0|0);
 do {
  if (!($94)) {
   while(1) {
    $95 = HEAP32[$10>>2]|0;
    $96 = ($95|0)==($93|0);
    if ($96) {
     label = 35;
     break;
    }
    $97 = ((($95)) + -108|0);
    HEAP32[$10>>2] = $97;
    $98 = HEAP32[$97>>2]|0;
    $99 = ((($98)) + 4|0);
    $100 = HEAP32[$99>>2]|0;
    __THREW__ = 0;
    invoke_vi($100|0,($97|0));
    $101 = __THREW__; __THREW__ = 0;
    $102 = $101&1;
    if ($102) {
     label = 34;
     break;
    }
   }
   if ((label|0) == 34) {
    $103 = ___cxa_find_matching_catch_2()|0;
    $104 = tempRet0;
    ___cxa_call_unexpected(($103|0));
    // unreachable;
   }
   else if ((label|0) == 35) {
    $105 = HEAP32[$9>>2]|0;
    __ZdlPv($105);
    break;
   }
  }
 } while(0);
 $106 = HEAP32[$7>>2]|0;
 $107 = ($106|0)==(0|0);
 do {
  if (!($107)) {
   while(1) {
    $108 = HEAP32[$8>>2]|0;
    $109 = ($108|0)==($106|0);
    if ($109) {
     label = 40;
     break;
    }
    $110 = ((($108)) + -108|0);
    HEAP32[$8>>2] = $110;
    $111 = HEAP32[$110>>2]|0;
    $112 = ((($111)) + 4|0);
    $113 = HEAP32[$112>>2]|0;
    __THREW__ = 0;
    invoke_vi($113|0,($110|0));
    $114 = __THREW__; __THREW__ = 0;
    $115 = $114&1;
    if ($115) {
     label = 39;
     break;
    }
   }
   if ((label|0) == 39) {
    $116 = ___cxa_find_matching_catch_2()|0;
    $117 = tempRet0;
    ___cxa_call_unexpected(($116|0));
    // unreachable;
   }
   else if ((label|0) == 40) {
    $118 = HEAP32[$7>>2]|0;
    __ZdlPv($118);
    break;
   }
  }
 } while(0);
 $119 = HEAP32[$5>>2]|0;
 $120 = ($119|0)==(0|0);
 do {
  if (!($120)) {
   while(1) {
    $121 = HEAP32[$6>>2]|0;
    $122 = ($121|0)==($119|0);
    if ($122) {
     label = 45;
     break;
    }
    $123 = ((($121)) + -108|0);
    HEAP32[$6>>2] = $123;
    $124 = HEAP32[$123>>2]|0;
    $125 = ((($124)) + 4|0);
    $126 = HEAP32[$125>>2]|0;
    __THREW__ = 0;
    invoke_vi($126|0,($123|0));
    $127 = __THREW__; __THREW__ = 0;
    $128 = $127&1;
    if ($128) {
     label = 44;
     break;
    }
   }
   if ((label|0) == 44) {
    $129 = ___cxa_find_matching_catch_2()|0;
    $130 = tempRet0;
    ___cxa_call_unexpected(($129|0));
    // unreachable;
   }
   else if ((label|0) == 45) {
    $131 = HEAP32[$5>>2]|0;
    __ZdlPv($131);
    break;
   }
  }
 } while(0);
 $132 = ((($0)) + 224|0);
 $133 = HEAP32[$132>>2]|0;
 $134 = ($133|0)==(0|0);
 if (!($134)) {
  $135 = ((($0)) + 228|0);
  $136 = HEAP32[$135>>2]|0;
  $137 = ($136|0)==($133|0);
  if (!($137)) {
   $scevgep$i$i$i$i = ((($136)) + -12|0);
   $138 = $scevgep$i$i$i$i;
   $139 = $133;
   $140 = (($138) - ($139))|0;
   $141 = (($140>>>0) / 12)&-1;
   $142 = $141 ^ -1;
   $scevgep5$i$i$i$i = (($136) + (($142*12)|0)|0);
   HEAP32[$135>>2] = $scevgep5$i$i$i$i;
  }
  __ZdlPv($133);
 }
 $143 = ((($0)) + 196|0);
 $144 = HEAP32[$143>>2]|0;
 $145 = ($144|0)==(0|0);
 if (!($145)) {
  $146 = ((($0)) + 200|0);
  $147 = HEAP32[$146>>2]|0;
  $148 = ($147|0)==($144|0);
  if (!($148)) {
   $scevgep$i$i$i$i36 = ((($147)) + -12|0);
   $149 = $scevgep$i$i$i$i36;
   $150 = $144;
   $151 = (($149) - ($150))|0;
   $152 = (($151>>>0) / 12)&-1;
   $153 = $152 ^ -1;
   $scevgep5$i$i$i$i37 = (($147) + (($153*12)|0)|0);
   HEAP32[$146>>2] = $scevgep5$i$i$i$i37;
  }
  __ZdlPv($144);
 }
 $154 = ((($0)) + 168|0);
 $155 = HEAP32[$154>>2]|0;
 $156 = ($155|0)==(0|0);
 if (!($156)) {
  $157 = ((($0)) + 172|0);
  $158 = HEAP32[$157>>2]|0;
  $159 = ($158|0)==($155|0);
  if (!($159)) {
   $scevgep$i$i$i$i41 = ((($158)) + -12|0);
   $160 = $scevgep$i$i$i$i41;
   $161 = $155;
   $162 = (($160) - ($161))|0;
   $163 = (($162>>>0) / 12)&-1;
   $164 = $163 ^ -1;
   $scevgep5$i$i$i$i42 = (($158) + (($164*12)|0)|0);
   HEAP32[$157>>2] = $scevgep5$i$i$i$i42;
  }
  __ZdlPv($155);
 }
 $165 = ((($0)) + 140|0);
 $166 = HEAP32[$165>>2]|0;
 $167 = ($166|0)==(0|0);
 if (!($167)) {
  $168 = ((($0)) + 144|0);
  $169 = HEAP32[$168>>2]|0;
  $170 = ($169|0)==($166|0);
  do {
   if ($170) {
    $184 = $166;
   } else {
    $172 = $169;
    while(1) {
     $171 = ((($172)) + -4|0);
     HEAP32[$168>>2] = $171;
     $173 = HEAP32[$171>>2]|0;
     $174 = ($173|0)==(0|0);
     if (!($174)) {
      $175 = ((($173)) + 8|0);
      $176 = HEAP32[$175>>2]|0;HEAP32[$175>>2] = (($176-1)|0);
      $177 = ($176|0)==(1);
      if ($177) {
       __THREW__ = 0;
       invoke_viii(3262,($173|0),1,1);
       $178 = __THREW__; __THREW__ = 0;
       $179 = $178&1;
       if ($179) {
        label = 64;
        break;
       }
      }
     }
     HEAP32[$171>>2] = 0;
     $180 = HEAP32[$168>>2]|0;
     $181 = ($180|0)==($166|0);
     if ($181) {
      label = 65;
      break;
     } else {
      $172 = $180;
     }
    }
    if ((label|0) == 64) {
     $182 = ___cxa_find_matching_catch_2()|0;
     $183 = tempRet0;
     ___cxa_call_unexpected(($182|0));
     // unreachable;
    }
    else if ((label|0) == 65) {
     $$pre$i$i48 = HEAP32[$165>>2]|0;
     $184 = $$pre$i$i48;
     break;
    }
   }
  } while(0);
  __ZdlPv($184);
 }
 $185 = ((($0)) + 136|0);
 $186 = HEAP32[$185>>2]|0;
 $187 = ($186|0)==(0|0);
 if (!($187)) {
  $188 = ((($186)) + 8|0);
  $189 = HEAP32[$188>>2]|0;HEAP32[$188>>2] = (($189-1)|0);
  $190 = ($189|0)==(1);
  if ($190) {
   __THREW__ = 0;
   invoke_viii(3262,($186|0),1,1);
   $191 = __THREW__; __THREW__ = 0;
   $192 = $191&1;
   if ($192) {
    $295 = ___cxa_find_matching_catch_3(0|0)|0;
    $296 = tempRet0;
    ___clang_call_terminate($295);
    // unreachable;
   }
  }
 }
 HEAP32[$185>>2] = 0;
 $193 = ((($0)) + 120|0);
 $194 = HEAP32[$193>>2]|0;
 $195 = ($194|0)==(0|0);
 if (!($195)) {
  $196 = ((($0)) + 124|0);
  $197 = HEAP32[$196>>2]|0;
  $198 = ($197|0)==($194|0);
  do {
   if ($198) {
    $212 = $194;
   } else {
    $200 = $197;
    while(1) {
     $199 = ((($200)) + -4|0);
     HEAP32[$196>>2] = $199;
     $201 = HEAP32[$199>>2]|0;
     $202 = ($201|0)==(0|0);
     if (!($202)) {
      $203 = ((($201)) + 8|0);
      $204 = HEAP32[$203>>2]|0;HEAP32[$203>>2] = (($204-1)|0);
      $205 = ($204|0)==(1);
      if ($205) {
       __THREW__ = 0;
       invoke_viii(3262,($201|0),1,1);
       $206 = __THREW__; __THREW__ = 0;
       $207 = $206&1;
       if ($207) {
        label = 76;
        break;
       }
      }
     }
     HEAP32[$199>>2] = 0;
     $208 = HEAP32[$196>>2]|0;
     $209 = ($208|0)==($194|0);
     if ($209) {
      label = 77;
      break;
     } else {
      $200 = $208;
     }
    }
    if ((label|0) == 76) {
     $210 = ___cxa_find_matching_catch_2()|0;
     $211 = tempRet0;
     ___cxa_call_unexpected(($210|0));
     // unreachable;
    }
    else if ((label|0) == 77) {
     $$pre$i$i53 = HEAP32[$193>>2]|0;
     $212 = $$pre$i$i53;
     break;
    }
   }
  } while(0);
  __ZdlPv($212);
 }
 $213 = ((($0)) + 116|0);
 $214 = HEAP32[$213>>2]|0;
 $215 = ($214|0)==(0|0);
 if (!($215)) {
  $216 = ((($214)) + 8|0);
  $217 = HEAP32[$216>>2]|0;HEAP32[$216>>2] = (($217-1)|0);
  $218 = ($217|0)==(1);
  if ($218) {
   __THREW__ = 0;
   invoke_viii(3262,($214|0),1,1);
   $219 = __THREW__; __THREW__ = 0;
   $220 = $219&1;
   if ($220) {
    $295 = ___cxa_find_matching_catch_3(0|0)|0;
    $296 = tempRet0;
    ___clang_call_terminate($295);
    // unreachable;
   }
  }
 }
 HEAP32[$213>>2] = 0;
 $221 = ((($0)) + 100|0);
 $222 = HEAP32[$221>>2]|0;
 $223 = ($222|0)==(0|0);
 if (!($223)) {
  $224 = ((($0)) + 104|0);
  $225 = HEAP32[$224>>2]|0;
  $226 = ($225|0)==($222|0);
  do {
   if ($226) {
    $240 = $222;
   } else {
    $228 = $225;
    L131: while(1) {
     $227 = ((($228)) + -4|0);
     HEAP32[$224>>2] = $227;
     $229 = HEAP32[$227>>2]|0;
     $230 = ($229|0)==(0|0);
     do {
      if (!($230)) {
       $231 = ((($229)) + 8|0);
       $232 = HEAP32[$231>>2]|0;HEAP32[$231>>2] = (($232-1)|0);
       $233 = ($232|0)==(1);
       if (!($233)) {
        break;
       }
       __THREW__ = 0;
       invoke_viii(3262,($229|0),1,1);
       $234 = __THREW__; __THREW__ = 0;
       $235 = $234&1;
       if ($235) {
        label = 88;
        break L131;
       }
      }
     } while(0);
     HEAP32[$227>>2] = 0;
     $236 = HEAP32[$224>>2]|0;
     $237 = ($236|0)==($222|0);
     if ($237) {
      label = 89;
      break;
     } else {
      $228 = $236;
     }
    }
    if ((label|0) == 88) {
     $238 = ___cxa_find_matching_catch_2()|0;
     $239 = tempRet0;
     ___cxa_call_unexpected(($238|0));
     // unreachable;
    }
    else if ((label|0) == 89) {
     $$pre$i$i20 = HEAP32[$221>>2]|0;
     $240 = $$pre$i$i20;
     break;
    }
   }
  } while(0);
  __ZdlPv($240);
 }
 $241 = ((($0)) + 96|0);
 $242 = HEAP32[$241>>2]|0;
 $243 = ($242|0)==(0|0);
 if (!($243)) {
  $244 = ((($242)) + 8|0);
  $245 = HEAP32[$244>>2]|0;HEAP32[$244>>2] = (($245-1)|0);
  $246 = ($245|0)==(1);
  if ($246) {
   __THREW__ = 0;
   invoke_viii(3262,($242|0),1,1);
   $247 = __THREW__; __THREW__ = 0;
   $248 = $247&1;
   if ($248) {
    $295 = ___cxa_find_matching_catch_3(0|0)|0;
    $296 = tempRet0;
    ___clang_call_terminate($295);
    // unreachable;
   }
  }
 }
 HEAP32[$241>>2] = 0;
 $249 = ((($0)) + 80|0);
 $250 = HEAP32[$249>>2]|0;
 $251 = ($250|0)==(0|0);
 if (!($251)) {
  $252 = ((($0)) + 84|0);
  $253 = HEAP32[$252>>2]|0;
  $254 = ($253|0)==($250|0);
  do {
   if ($254) {
    $268 = $250;
   } else {
    $256 = $253;
    L150: while(1) {
     $255 = ((($256)) + -4|0);
     HEAP32[$252>>2] = $255;
     $257 = HEAP32[$255>>2]|0;
     $258 = ($257|0)==(0|0);
     do {
      if (!($258)) {
       $259 = ((($257)) + 8|0);
       $260 = HEAP32[$259>>2]|0;HEAP32[$259>>2] = (($260-1)|0);
       $261 = ($260|0)==(1);
       if (!($261)) {
        break;
       }
       __THREW__ = 0;
       invoke_viii(3262,($257|0),1,1);
       $262 = __THREW__; __THREW__ = 0;
       $263 = $262&1;
       if ($263) {
        label = 100;
        break L150;
       }
      }
     } while(0);
     HEAP32[$255>>2] = 0;
     $264 = HEAP32[$252>>2]|0;
     $265 = ($264|0)==($250|0);
     if ($265) {
      label = 101;
      break;
     } else {
      $256 = $264;
     }
    }
    if ((label|0) == 100) {
     $266 = ___cxa_find_matching_catch_2()|0;
     $267 = tempRet0;
     ___cxa_call_unexpected(($266|0));
     // unreachable;
    }
    else if ((label|0) == 101) {
     $$pre$i$i = HEAP32[$249>>2]|0;
     $268 = $$pre$i$i;
     break;
    }
   }
  } while(0);
  __ZdlPv($268);
 }
 $269 = ((($0)) + 76|0);
 $270 = HEAP32[$269>>2]|0;
 $271 = ($270|0)==(0|0);
 if (!($271)) {
  $272 = ((($270)) + 8|0);
  $273 = HEAP32[$272>>2]|0;HEAP32[$272>>2] = (($273-1)|0);
  $274 = ($273|0)==(1);
  if ($274) {
   __THREW__ = 0;
   invoke_viii(3262,($270|0),1,1);
   $275 = __THREW__; __THREW__ = 0;
   $276 = $275&1;
   if ($276) {
    $295 = ___cxa_find_matching_catch_3(0|0)|0;
    $296 = tempRet0;
    ___clang_call_terminate($295);
    // unreachable;
   }
  }
 }
 HEAP32[$269>>2] = 0;
 $277 = HEAP32[$2>>2]|0;
 $278 = ($277|0)==(0|0);
 do {
  if (!($278)) {
   while(1) {
    $279 = HEAP32[$3>>2]|0;
    $280 = ($279|0)==($277|0);
    if ($280) {
     label = 110;
     break;
    }
    $281 = ((($279)) + -80|0);
    HEAP32[$3>>2] = $281;
    __THREW__ = 0;
    invoke_vi(3586,($281|0));
    $282 = __THREW__; __THREW__ = 0;
    $283 = $282&1;
    if ($283) {
     label = 109;
     break;
    }
   }
   if ((label|0) == 109) {
    $284 = ___cxa_find_matching_catch_2()|0;
    $285 = tempRet0;
    ___cxa_call_unexpected(($284|0));
    // unreachable;
   }
   else if ((label|0) == 110) {
    $286 = HEAP32[$2>>2]|0;
    __ZdlPv($286);
    break;
   }
  }
 } while(0);
 HEAP32[$0>>2] = (58232);
 $287 = ((($0)) + 28|0);
 $288 = HEAP32[$287>>2]|0;
 $289 = ($288|0)==(0|0);
 if ($289) {
  HEAP32[$287>>2] = 0;
  ___resumeException($$03|0);
  // unreachable;
 }
 $290 = ((($288)) + 8|0);
 $291 = HEAP32[$290>>2]|0;HEAP32[$290>>2] = (($291-1)|0);
 $292 = ($291|0)==(1);
 if (!($292)) {
  HEAP32[$287>>2] = 0;
  ___resumeException($$03|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(3262,($288|0),1,1);
 $293 = __THREW__; __THREW__ = 0;
 $294 = $293&1;
 if ($294) {
  $295 = ___cxa_find_matching_catch_3(0|0)|0;
  $296 = tempRet0;
  ___clang_call_terminate($295);
  // unreachable;
 } else {
  HEAP32[$287>>2] = 0;
  ___resumeException($$03|0);
  // unreachable;
 }
}
function __ZN3osg9CullStack14pushCullingSetEv($0) {
 $0 = $0|0;
 var $$0 = 0, $$013 = 0, $$pre = 0, $$pre$i$i = 0, $$pre26 = 0, $$pre27 = 0, $$pre28 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 240|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(240|0);
 $1 = sp + 128|0;
 $2 = sp + 112|0;
 $3 = sp;
 $4 = ((($0)) + 116|0);
 $5 = ((($0)) + 132|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 do {
  if ($7) {
   label = 7;
  } else {
   $8 = ((($0)) + 124|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = ((($0)) + 128|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = ($9|0)==($11|0);
   if ($12) {
    $19 = ((($0)) + 120|0);
    __THREW__ = 0;
    invoke_vii(3636,($19|0),($4|0));
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     break;
    } else {
     label = 7;
     break;
    }
   }
   $13 = HEAP32[$4>>2]|0;
   HEAP32[$9>>2] = $13;
   $14 = ($13|0)==(0|0);
   if ($14) {
    $18 = $9;
   } else {
    $15 = ((($13)) + 8|0);
    $16 = HEAP32[$15>>2]|0;HEAP32[$15>>2] = (($16+1)|0);
    $$pre$i$i = HEAP32[$8>>2]|0;
    $18 = $$pre$i$i;
   }
   $17 = ((($18)) + 4|0);
   HEAP32[$8>>2] = $17;
   label = 7;
  }
 } while(0);
 do {
  if ((label|0) == 7) {
   $22 = HEAP32[$4>>2]|0;
   $23 = ($22|0)==(0|0);
   if (!($23)) {
    HEAP32[$4>>2] = 0;
    $24 = ((($22)) + 8|0);
    $25 = HEAP32[$24>>2]|0;HEAP32[$24>>2] = (($25-1)|0);
    $26 = ($25|0)==(1);
    if ($26) {
     __THREW__ = 0;
     invoke_viii(3262,($22|0),1,1);
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     if ($28) {
      break;
     }
    }
   }
   $29 = HEAP32[$5>>2]|0;
   $30 = (($29) + 1)|0;
   HEAP32[$5>>2] = $30;
   $31 = ((($0)) + 276|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ($32|0)==(0);
   if (!($33)) {
    $105 = ((($0)) + 136|0);
    $106 = HEAP32[$105>>2]|0;
    $107 = ((($0)) + 76|0);
    $108 = HEAP32[$107>>2]|0;
    $109 = ((($108)) + 32|0);
    $110 = ((($0)) + 96|0);
    $111 = HEAP32[$110>>2]|0;
    $112 = ((($111)) + 32|0);
    __ZN3osg10CullingSet22computePixelSizeVectorERKNS_8ViewportERKNS_7MatrixdES6_($2,$106,$109,$112);
    $113 = HEAP32[$31>>2]|0;
    $114 = ((($0)) + 264|0);
    $115 = ((($0)) + 268|0);
    $116 = HEAP32[$115>>2]|0;
    $117 = HEAP32[$114>>2]|0;
    $118 = (($116) - ($117))|0;
    $119 = (($118|0) / 108)&-1;
    $120 = ($113>>>0)<($119>>>0);
    do {
     if ($120) {
      $121 = $117;
      $137 = $113;$139 = $121;
     } else {
      __ZN3osg10CullingSetC2Ev($3);
      $122 = HEAP32[$115>>2]|0;
      $123 = ((($0)) + 272|0);
      $124 = HEAP32[$123>>2]|0;
      $125 = ($122|0)==($124|0);
      if ($125) {
       __THREW__ = 0;
       invoke_vii(3738,($114|0),($3|0));
       $130 = __THREW__; __THREW__ = 0;
       $131 = $130&1;
       if (!($131)) {
        label = 29;
       }
      } else {
       __THREW__ = 0;
       invoke_vii(3737,($122|0),($3|0));
       $126 = __THREW__; __THREW__ = 0;
       $127 = $126&1;
       if (!($127)) {
        $128 = HEAP32[$115>>2]|0;
        $129 = ((($128)) + 108|0);
        HEAP32[$115>>2] = $129;
        label = 29;
       }
      }
      if ((label|0) == 29) {
       __ZN3osg10CullingSetD2Ev($3);
       $$pre = HEAP32[$31>>2]|0;
       $$pre26 = HEAP32[$114>>2]|0;
       $137 = $$pre;$139 = $$pre26;
       break;
      }
      $132 = ___cxa_find_matching_catch_2()|0;
      $133 = tempRet0;
      __THREW__ = 0;
      invoke_vi(1617,($3|0));
      $134 = __THREW__; __THREW__ = 0;
      $135 = $134&1;
      if ($135) {
       $151 = ___cxa_find_matching_catch_3(0|0)|0;
       $152 = tempRet0;
       ___clang_call_terminate($151);
       // unreachable;
      }
      $$0 = $132;$$013 = $133;
      ___resumeException($$0|0);
      // unreachable;
     }
    } while(0);
    $136 = (($137) + 1)|0;
    HEAP32[$31>>2] = $136;
    $138 = (($139) + (($137*108)|0)|0);
    $140 = ((($0)) + 256|0);
    $141 = HEAP32[$140>>2]|0;
    $142 = ((($141)) + -108|0);
    $143 = HEAP32[$110>>2]|0;
    $144 = ((($143)) + 32|0);
    __ZN3osg10CullingSet3setERKS0_RKNS_7MatrixdERKNS_5Vec4fE($138,$142,$144,$2);
    $145 = HEAP32[$31>>2]|0;
    $146 = (($145) + -1)|0;
    $147 = ((($0)) + 264|0);
    $148 = HEAP32[$147>>2]|0;
    $149 = (($148) + (($146*108)|0)|0);
    $150 = ((($0)) + 280|0);
    HEAP32[$150>>2] = $149;
    STACKTOP = sp;return;
   }
   $34 = ((($0)) + 264|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ((($0)) + 268|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = ($35|0)==($37|0);
   do {
    if ($38) {
     __ZN3osg10CullingSetC2Ev($1);
     $39 = HEAP32[$36>>2]|0;
     $40 = ((($0)) + 272|0);
     $41 = HEAP32[$40>>2]|0;
     $42 = ($39|0)==($41|0);
     if ($42) {
      __THREW__ = 0;
      invoke_vii(3738,($34|0),($1|0));
      $47 = __THREW__; __THREW__ = 0;
      $48 = $47&1;
      if (!($48)) {
       label = 16;
      }
     } else {
      __THREW__ = 0;
      invoke_vii(3737,($39|0),($1|0));
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if (!($44)) {
       $45 = HEAP32[$36>>2]|0;
       $46 = ((($45)) + 108|0);
       HEAP32[$36>>2] = $46;
       label = 16;
      }
     }
     if ((label|0) == 16) {
      __ZN3osg10CullingSetD2Ev($1);
      $$pre27 = HEAP32[$31>>2]|0;
      $$pre28 = HEAP32[$34>>2]|0;
      $56 = $$pre27;$58 = $$pre28;
      break;
     }
     $51 = ___cxa_find_matching_catch_2()|0;
     $52 = tempRet0;
     __THREW__ = 0;
     invoke_vi(1617,($1|0));
     $53 = __THREW__; __THREW__ = 0;
     $54 = $53&1;
     if ($54) {
      $151 = ___cxa_find_matching_catch_3(0|0)|0;
      $152 = tempRet0;
      ___clang_call_terminate($151);
      // unreachable;
     }
     $$0 = $51;$$013 = $52;
     ___resumeException($$0|0);
     // unreachable;
    } else {
     $56 = 0;$58 = $35;
    }
   } while(0);
   $55 = (($56) + 1)|0;
   HEAP32[$31>>2] = $55;
   $57 = (($58) + (($56*108)|0)|0);
   $59 = ((($0)) + 256|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = ((($60)) + -108|0);
   $62 = ((($60)) + -96|0);
   $63 = HEAP32[$62>>2]|0;
   $64 = (((($58) + (($56*108)|0)|0)) + 12|0);
   HEAP32[$64>>2] = $63;
   $65 = ($61|0)==($57|0);
   if (!($65)) {
    $66 = ((($60)) + -92|0);
    $67 = HEAP32[$66>>2]|0;
    $68 = (((($58) + (($56*108)|0)|0)) + 16|0);
    HEAP32[$68>>2] = $67;
    $69 = (((($58) + (($56*108)|0)|0)) + 20|0);
    $70 = ((($60)) + -88|0);
    $71 = HEAP32[$70>>2]|0;
    $72 = ((($60)) + -84|0);
    $73 = HEAP32[$72>>2]|0;
    __ZNSt3__26vectorIjNS_9allocatorIjEEE6assignIPjEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIjNS_15iterator_traitsIS7_E9referenceEEE5valueEvE4typeES7_S7_($69,$71,$73);
    $74 = ((($60)) + -76|0);
    $75 = HEAP32[$74>>2]|0;
    $76 = (((($58) + (($56*108)|0)|0)) + 32|0);
    HEAP32[$76>>2] = $75;
    $77 = ((($60)) + -72|0);
    $78 = HEAP32[$77>>2]|0;
    $79 = (((($58) + (($56*108)|0)|0)) + 36|0);
    HEAP32[$79>>2] = $78;
    $80 = (((($58) + (($56*108)|0)|0)) + 40|0);
    $81 = ((($60)) + -68|0);
    $82 = HEAP32[$81>>2]|0;
    $83 = ((($60)) + -64|0);
    $84 = HEAP32[$83>>2]|0;
    __ZNSt3__26vectorIN3osg5PlaneENS_9allocatorIS2_EEE6assignIPS2_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS2_NS_15iterator_traitsIS9_E9referenceEEE5valueEvE4typeES9_S9_($80,$82,$84);
    $85 = (((($58) + (($56*108)|0)|0)) + 52|0);
    $86 = ((($60)) + -56|0);
    $87 = HEAP32[$86>>2]|0;
    $88 = ((($60)) + -52|0);
    $89 = HEAP32[$88>>2]|0;
    __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE6assignIPS2_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS2_NS_15iterator_traitsIS9_E9referenceEEE5valueEvE4typeES9_S9_($85,$87,$89);
    $90 = (((($58) + (($56*108)|0)|0)) + 64|0);
    $91 = ((($60)) + -44|0);
    $92 = HEAP32[$91>>2]|0;
    $93 = ((($60)) + -40|0);
    $94 = HEAP32[$93>>2]|0;
    __ZNSt3__26vectorINS_4pairIN3osg7ref_ptrINS2_8StateSetEEENS2_8PolytopeEEENS_9allocatorIS7_EEE6assignIPS7_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS7_NS_15iterator_traitsISE_E9referenceEEE5valueEvE4typeESE_SE_($90,$92,$94);
    $95 = (((($58) + (($56*108)|0)|0)) + 76|0);
    $96 = ((($60)) + -32|0);
    $97 = HEAP32[$96>>2]|0;
    $98 = ((($60)) + -28|0);
    $99 = HEAP32[$98>>2]|0;
    __ZNSt3__26vectorIN3osg20ShadowVolumeOccluderENS_9allocatorIS2_EEE6assignIPS2_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS2_NS_15iterator_traitsIS9_E9referenceEEE5valueEvE4typeES9_S9_($95,$97,$99);
   }
   $100 = ((($60)) + -20|0);
   $101 = (((($58) + (($56*108)|0)|0)) + 88|0);
   ;HEAP32[$101>>2]=HEAP32[$100>>2]|0;HEAP32[$101+4>>2]=HEAP32[$100+4>>2]|0;HEAP32[$101+8>>2]=HEAP32[$100+8>>2]|0;HEAP32[$101+12>>2]=HEAP32[$100+12>>2]|0;
   $102 = ((($60)) + -4|0);
   $103 = HEAP32[$102>>2]|0;
   $104 = (((($58) + (($56*108)|0)|0)) + 104|0);
   HEAP32[$104>>2] = $103;
   $145 = HEAP32[$31>>2]|0;
   $146 = (($145) + -1)|0;
   $147 = ((($0)) + 264|0);
   $148 = HEAP32[$147>>2]|0;
   $149 = (($148) + (($146*108)|0)|0);
   $150 = ((($0)) + 280|0);
   HEAP32[$150>>2] = $149;
   STACKTOP = sp;return;
  }
 } while(0);
 $49 = ___cxa_find_matching_catch_2()|0;
 $50 = tempRet0;
 $$0 = $49;$$013 = $50;
 ___resumeException($$0|0);
 // unreachable;
}
function __ZN3osg10CullingSetC2ERKS0_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$08 = 0, $$1 = 0, $$19 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i3$i = 0, $scevgep5$i$i$i$i = 0, $scevgep5$i$i$i$i$i = 0, $scevgep5$i$i$i4$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg10ReferencedC2Ev($0);
 HEAP32[$0>>2] = (58212);
 $2 = ((($0)) + 12|0);
 $3 = ((($1)) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$2>>2] = $4;
 $5 = ((($0)) + 16|0);
 $6 = ((($1)) + 16|0);
 __THREW__ = 0;
 invoke_vii(3596,($5|0),($6|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $22 = ___cxa_find_matching_catch_2()|0;
  $23 = tempRet0;
  $$1 = $23;$$19 = $22;
 } else {
  $9 = ((($0)) + 64|0);
  $10 = ((($1)) + 64|0);
  __THREW__ = 0;
  invoke_vii(3739,($9|0),($10|0));
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if ($12) {
   $24 = ___cxa_find_matching_catch_2()|0;
   $25 = tempRet0;
   $$0 = $25;$$08 = $24;
  } else {
   $13 = ((($0)) + 76|0);
   $14 = ((($1)) + 76|0);
   __THREW__ = 0;
   invoke_vii(3740,($13|0),($14|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    $17 = ((($0)) + 88|0);
    $18 = ((($1)) + 88|0);
    ;HEAP32[$17>>2]=HEAP32[$18>>2]|0;HEAP32[$17+4>>2]=HEAP32[$18+4>>2]|0;HEAP32[$17+8>>2]=HEAP32[$18+8>>2]|0;HEAP32[$17+12>>2]=HEAP32[$18+12>>2]|0;
    $19 = ((($0)) + 104|0);
    $20 = ((($1)) + 104|0);
    $21 = HEAP32[$20>>2]|0;
    HEAP32[$19>>2] = $21;
    return;
   }
   $26 = ___cxa_find_matching_catch_2()|0;
   $27 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3734,($9|0));
   $28 = __THREW__; __THREW__ = 0;
   $29 = $28&1;
   if ($29) {
    $65 = ___cxa_find_matching_catch_3(0|0)|0;
    $66 = tempRet0;
    ___clang_call_terminate($65);
    // unreachable;
   } else {
    $$0 = $27;$$08 = $26;
   }
  }
  $30 = ((($0)) + 52|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = ($31|0)==(0|0);
  if (!($32)) {
   $33 = ((($0)) + 56|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = ($34|0)==($31|0);
   if (!($35)) {
    $scevgep$i$i$i$i = ((($34)) + -12|0);
    $36 = $scevgep$i$i$i$i;
    $37 = $31;
    $38 = (($36) - ($37))|0;
    $39 = (($38>>>0) / 12)&-1;
    $40 = $39 ^ -1;
    $scevgep5$i$i$i$i = (($34) + (($40*12)|0)|0);
    HEAP32[$33>>2] = $scevgep5$i$i$i$i;
   }
   __ZdlPv($31);
  }
  $41 = ((($0)) + 40|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = ($42|0)==(0|0);
  if (!($43)) {
   $44 = ((($0)) + 44|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = ($45|0)==($42|0);
   if (!($46)) {
    $scevgep$i$i$i3$i = ((($45)) + -40|0);
    $47 = $scevgep$i$i$i3$i;
    $48 = $42;
    $49 = (($47) - ($48))|0;
    $50 = (($49>>>0) / 40)&-1;
    $51 = $50 ^ -1;
    $scevgep5$i$i$i4$i = (($45) + (($51*40)|0)|0);
    HEAP32[$44>>2] = $scevgep5$i$i$i4$i;
   }
   __ZdlPv($42);
  }
  $52 = ((($0)) + 20|0);
  $53 = HEAP32[$52>>2]|0;
  $54 = ($53|0)==(0|0);
  if ($54) {
   $$1 = $$0;$$19 = $$08;
  } else {
   $55 = ((($0)) + 24|0);
   $56 = HEAP32[$55>>2]|0;
   $57 = ($56|0)==($53|0);
   if (!($57)) {
    $scevgep$i$i$i$i$i = ((($56)) + -4|0);
    $58 = $scevgep$i$i$i$i$i;
    $59 = $53;
    $60 = (($58) - ($59))|0;
    $61 = $60 >>> 2;
    $62 = $61 ^ -1;
    $scevgep5$i$i$i$i$i = (($56) + ($62<<2)|0);
    HEAP32[$55>>2] = $scevgep5$i$i$i$i$i;
   }
   __ZdlPv($53);
   $$1 = $$0;$$19 = $$08;
  }
 }
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $63 = __THREW__; __THREW__ = 0;
 $64 = $63&1;
 if ($64) {
  $65 = ___cxa_find_matching_catch_3(0|0)|0;
  $66 = tempRet0;
  ___clang_call_terminate($65);
  // unreachable;
 } else {
  ___resumeException($$19|0);
  // unreachable;
 }
}
function __ZNSt3__26vectorIN3osg10CullingSetENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$06$i$i = 0, $$pre = 0, $$pre$i = 0, $$sroa$16$0 = 0, $$sroa$16$1 = 0, $$sroa$16$2 = 0, $$sroa$7$0 = 0, $$sroa$7$1 = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = (($5|0) / 108)&-1;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(39768215);
 if ($8) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $9 = ((($0)) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) - ($4))|0;
 $12 = (($11|0) / 108)&-1;
 $13 = ($12>>>0)<(19884107);
 $14 = $12 << 1;
 $15 = ($14>>>0)<($7>>>0);
 $$sroa$speculated$i = $15 ? $7 : $14;
 $$sroa$speculated$$i = $13 ? $$sroa$speculated$i : 39768215;
 $16 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($16) {
   $26 = 0;$79 = 0;
  } else {
   $17 = ($$sroa$speculated$$i>>>0)>(39768215);
   if (!($17)) {
    $23 = ($$sroa$speculated$$i*108)|0;
    $24 = (__Znwj($23)|0);
    $26 = $24;$79 = $24;
    break;
   }
   $18 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($18|0),(204840|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if ($20) {
    $21 = ___cxa_find_matching_catch_2()|0;
    $22 = tempRet0;
    ___cxa_free_exception(($18|0));
    ___resumeException($21|0);
    // unreachable;
   } else {
    HEAP32[$18>>2] = (99824);
    ___cxa_throw(($18|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $25 = (($26) + (($6*108)|0)|0);
 $27 = $25;
 $28 = (($26) + (($$sroa$speculated$$i*108)|0)|0);
 $29 = $28;
 __THREW__ = 0;
 invoke_vii(3737,($25|0),($1|0));
 $30 = __THREW__; __THREW__ = 0;
 $31 = $30&1;
 L13: do {
  if ($31) {
   $$sroa$16$1 = $27;$$sroa$7$1 = $27;
  } else {
   $32 = ((($25)) + 108|0);
   $33 = $32;
   $34 = HEAP32[$0>>2]|0;
   $35 = HEAP32[$2>>2]|0;
   $36 = ($35|0)==($34|0);
   if ($36) {
    $37 = $35;
    $38 = $34;
    $48 = $27;$49 = $38;$80 = $37;
   } else {
    $$06$i$i = $35;$$sroa$7$0 = $27;$40 = $25;
    while(1) {
     $39 = ((($40)) + -108|0);
     $41 = ((($$06$i$i)) + -108|0);
     __THREW__ = 0;
     invoke_vii(3737,($39|0),($41|0));
     $42 = __THREW__; __THREW__ = 0;
     $43 = $42&1;
     if ($43) {
      $$sroa$16$1 = $33;$$sroa$7$1 = $$sroa$7$0;
      break L13;
     }
     $44 = $$sroa$7$0;
     $45 = ((($44)) + -108|0);
     $46 = $45;
     $47 = ($41|0)==($34|0);
     if ($47) {
      break;
     } else {
      $$06$i$i = $41;$$sroa$7$0 = $46;$40 = $45;
     }
    }
    $$pre$i = HEAP32[$0>>2]|0;
    $$pre = HEAP32[$2>>2]|0;
    $48 = $46;$49 = $$pre$i;$80 = $$pre;
   }
   HEAP32[$0>>2] = $48;
   HEAP32[$2>>2] = $33;
   HEAP32[$9>>2] = $29;
   $50 = $49;
   $$sroa$16$0 = $80;
   while(1) {
    $51 = $$sroa$16$0;
    $52 = ($51|0)==($50|0);
    if ($52) {
     break;
    }
    $53 = ((($51)) + -108|0);
    $54 = $53;
    $55 = HEAP32[$53>>2]|0;
    $56 = ((($55)) + 4|0);
    $57 = HEAP32[$56>>2]|0;
    __THREW__ = 0;
    invoke_vi($57|0,($53|0));
    $58 = __THREW__; __THREW__ = 0;
    $59 = $58&1;
    if ($59) {
     label = 18;
     break;
    } else {
     $$sroa$16$0 = $54;
    }
   }
   if ((label|0) == 18) {
    $60 = ___cxa_find_matching_catch_2()|0;
    $61 = tempRet0;
    ___cxa_call_unexpected(($60|0));
    // unreachable;
   }
   $62 = ($49|0)==(0);
   if ($62) {
    return;
   }
   $63 = $49;
   __ZdlPv($63);
   return;
  }
 } while(0);
 $64 = ___cxa_find_matching_catch_2()|0;
 $65 = tempRet0;
 $66 = $$sroa$7$1;
 $$sroa$16$2 = $$sroa$16$1;
 while(1) {
  $67 = $$sroa$16$2;
  $68 = ($67|0)==($66|0);
  if ($68) {
   break;
  }
  $69 = ((($67)) + -108|0);
  $70 = $69;
  $71 = HEAP32[$69>>2]|0;
  $72 = ((($71)) + 4|0);
  $73 = HEAP32[$72>>2]|0;
  __THREW__ = 0;
  invoke_vi($73|0,($69|0));
  $74 = __THREW__; __THREW__ = 0;
  $75 = $74&1;
  if ($75) {
   label = 25;
   break;
  } else {
   $$sroa$16$2 = $70;
  }
 }
 if ((label|0) == 25) {
  $76 = ___cxa_find_matching_catch_2()|0;
  $77 = tempRet0;
  ___cxa_call_unexpected(($76|0));
  // unreachable;
 }
 $78 = ($26|0)==(0|0);
 if ($78) {
  ___resumeException($64|0);
  // unreachable;
 }
 __ZdlPv($79);
 ___resumeException($64|0);
 // unreachable;
}
function __ZNSt3__26vectorINS_4pairIN3osg7ref_ptrINS2_8StateSetEEENS2_8PolytopeEEENS_9allocatorIS7_EEE6assignIPS7_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS7_NS_15iterator_traitsISE_E9referenceEEE5valueEvE4typeESE_SE_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$ = 0, $$0$lcssa$i$i = 0, $$07$i$i = 0, $$07$i$i21 = 0, $$078$i$i = 0, $$09$i$i = 0, $$pre$i$i19 = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0;
 var $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $scevgep$i$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i$i$i = 0, $scevgep$i$i$i3$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i$i$i$i = 0;
 var $scevgep5$i$i$i$i$i$i$i$i$i = 0, $scevgep5$i$i$i4$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = $2;
 $4 = $1;
 $5 = (($3) - ($4))|0;
 $6 = (($5|0) / 52)&-1;
 $7 = ((($0)) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$0>>2]|0;
 $10 = (($8) - ($9))|0;
 $11 = (($10|0) / 52)&-1;
 $12 = ($6>>>0)>($11>>>0);
 $13 = $9;
 if ($12) {
  __ZNSt3__26vectorINS_4pairIN3osg7ref_ptrINS2_8StateSetEEENS2_8PolytopeEEENS_9allocatorIS7_EEE10deallocateEv($0);
  $132 = ($6>>>0)>(82595524);
  if ($132) {
   __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
   // unreachable;
  }
  $133 = HEAP32[$7>>2]|0;
  $134 = HEAP32[$0>>2]|0;
  $135 = (($133) - ($134))|0;
  $136 = (($135|0) / 52)&-1;
  $137 = ($136>>>0)<(41297762);
  $138 = $136 << 1;
  $139 = ($138>>>0)<($6>>>0);
  $$sroa$speculated$i = $139 ? $6 : $138;
  $$sroa$speculated$$i = $137 ? $$sroa$speculated$i : 82595524;
  $140 = ($$sroa$speculated$$i>>>0)>(82595524);
  if ($140) {
   __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
   // unreachable;
  }
  $141 = ($$sroa$speculated$$i*52)|0;
  $142 = (__Znwj($141)|0);
  $143 = ((($0)) + 4|0);
  HEAP32[$143>>2] = $142;
  HEAP32[$0>>2] = $142;
  $144 = (($142) + (($$sroa$speculated$$i*52)|0)|0);
  HEAP32[$7>>2] = $144;
  $145 = ($1|0)==($2|0);
  if ($145) {
   return;
  }
  $$07$i$i = $1;$147 = $142;
  while(1) {
   $146 = HEAP32[$$07$i$i>>2]|0;
   HEAP32[$147>>2] = $146;
   $148 = ($146|0)==(0|0);
   if (!($148)) {
    $149 = ((($146)) + 8|0);
    $150 = HEAP32[$149>>2]|0;HEAP32[$149>>2] = (($150+1)|0);
   }
   $151 = ((($147)) + 4|0);
   $152 = ((($$07$i$i)) + 4|0);
   __THREW__ = 0;
   invoke_vii(3596,($151|0),($152|0));
   $153 = __THREW__; __THREW__ = 0;
   $154 = $153&1;
   if ($154) {
    break;
   }
   $166 = ((($$07$i$i)) + 52|0);
   $167 = HEAP32[$143>>2]|0;
   $168 = ((($167)) + 52|0);
   HEAP32[$143>>2] = $168;
   $169 = ($166|0)==($2|0);
   if ($169) {
    label = 57;
    break;
   } else {
    $$07$i$i = $166;$147 = $168;
   }
  }
  if ((label|0) == 57) {
   return;
  }
  $155 = ___cxa_find_matching_catch_2()|0;
  $156 = tempRet0;
  $157 = HEAP32[$147>>2]|0;
  $158 = ($157|0)==(0|0);
  if ($158) {
   HEAP32[$147>>2] = 0;
   ___resumeException($155|0);
   // unreachable;
  }
  $159 = ((($157)) + 8|0);
  $160 = HEAP32[$159>>2]|0;HEAP32[$159>>2] = (($160-1)|0);
  $161 = ($160|0)==(1);
  if (!($161)) {
   HEAP32[$147>>2] = 0;
   ___resumeException($155|0);
   // unreachable;
  }
  __THREW__ = 0;
  invoke_viii(3262,($157|0),1,1);
  $162 = __THREW__; __THREW__ = 0;
  $163 = $162&1;
  if ($163) {
   $164 = ___cxa_find_matching_catch_3(0|0)|0;
   $165 = tempRet0;
   ___clang_call_terminate($164);
   // unreachable;
  } else {
   HEAP32[$147>>2] = 0;
   ___resumeException($155|0);
   // unreachable;
  }
 }
 $14 = ((($0)) + 4|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($15) - ($9))|0;
 $17 = (($16|0) / 52)&-1;
 $18 = ($6>>>0)>($17>>>0);
 $19 = (($1) + (($17*52)|0)|0);
 $$ = $18 ? $19 : $2;
 $20 = ($$|0)==($1|0);
 if ($20) {
  $$0$lcssa$i$i = $13;
 } else {
  $$078$i$i = $1;$$09$i$i = $13;
  while(1) {
   $21 = HEAP32[$$09$i$i>>2]|0;
   $22 = HEAP32[$$078$i$i>>2]|0;
   $23 = ($21|0)==($22|0);
   if (!($23)) {
    HEAP32[$$09$i$i>>2] = $22;
    $24 = ($22|0)==(0|0);
    if (!($24)) {
     $25 = ((($22)) + 8|0);
     $26 = HEAP32[$25>>2]|0;HEAP32[$25>>2] = (($26+1)|0);
    }
    $27 = ($21|0)==(0|0);
    if (!($27)) {
     $28 = ((($21)) + 8|0);
     $29 = HEAP32[$28>>2]|0;HEAP32[$28>>2] = (($29-1)|0);
     $30 = ($29|0)==(1);
     if ($30) {
      __ZNK3osg10Referenced24signalObserversAndDeleteEbb($21,1,1);
     }
    }
   }
   $31 = ($$078$i$i|0)==($$09$i$i|0);
   if (!($31)) {
    $32 = ((($$078$i$i)) + 4|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = ((($$09$i$i)) + 4|0);
    HEAP32[$34>>2] = $33;
    $35 = ((($$09$i$i)) + 8|0);
    $36 = ((($$078$i$i)) + 8|0);
    $37 = HEAP32[$36>>2]|0;
    $38 = ((($$078$i$i)) + 12|0);
    $39 = HEAP32[$38>>2]|0;
    __ZNSt3__26vectorIjNS_9allocatorIjEEE6assignIPjEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIjNS_15iterator_traitsIS7_E9referenceEEE5valueEvE4typeES7_S7_($35,$37,$39);
    $40 = ((($$078$i$i)) + 20|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = ((($$09$i$i)) + 20|0);
    HEAP32[$42>>2] = $41;
    $43 = ((($$078$i$i)) + 24|0);
    $44 = HEAP32[$43>>2]|0;
    $45 = ((($$09$i$i)) + 24|0);
    HEAP32[$45>>2] = $44;
    $46 = ((($$09$i$i)) + 28|0);
    $47 = ((($$078$i$i)) + 28|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = ((($$078$i$i)) + 32|0);
    $50 = HEAP32[$49>>2]|0;
    __ZNSt3__26vectorIN3osg5PlaneENS_9allocatorIS2_EEE6assignIPS2_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS2_NS_15iterator_traitsIS9_E9referenceEEE5valueEvE4typeES9_S9_($46,$48,$50);
    $51 = ((($$09$i$i)) + 40|0);
    $52 = ((($$078$i$i)) + 40|0);
    $53 = HEAP32[$52>>2]|0;
    $54 = ((($$078$i$i)) + 44|0);
    $55 = HEAP32[$54>>2]|0;
    __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE6assignIPS2_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS2_NS_15iterator_traitsIS9_E9referenceEEE5valueEvE4typeES9_S9_($51,$53,$55);
   }
   $56 = ((($$078$i$i)) + 52|0);
   $57 = ((($$09$i$i)) + 52|0);
   $58 = ($56|0)==($$|0);
   if ($58) {
    $$0$lcssa$i$i = $57;
    break;
   } else {
    $$078$i$i = $56;$$09$i$i = $57;
   }
  }
 }
 if ($18) {
  $59 = ($$|0)==($2|0);
  if ($59) {
   return;
  }
  $$pre$i$i19 = HEAP32[$14>>2]|0;
  $$07$i$i21 = $19;$61 = $$pre$i$i19;
  while(1) {
   $60 = HEAP32[$$07$i$i21>>2]|0;
   HEAP32[$61>>2] = $60;
   $62 = ($60|0)==(0|0);
   if (!($62)) {
    $63 = ((($60)) + 8|0);
    $64 = HEAP32[$63>>2]|0;HEAP32[$63>>2] = (($64+1)|0);
   }
   $65 = ((($61)) + 4|0);
   $66 = ((($$07$i$i21)) + 4|0);
   __THREW__ = 0;
   invoke_vii(3596,($65|0),($66|0));
   $67 = __THREW__; __THREW__ = 0;
   $68 = $67&1;
   if ($68) {
    break;
   }
   $80 = ((($$07$i$i21)) + 52|0);
   $81 = HEAP32[$14>>2]|0;
   $82 = ((($81)) + 52|0);
   HEAP32[$14>>2] = $82;
   $83 = ($80|0)==($2|0);
   if ($83) {
    label = 57;
    break;
   } else {
    $$07$i$i21 = $80;$61 = $82;
   }
  }
  if ((label|0) == 57) {
   return;
  }
  $69 = ___cxa_find_matching_catch_2()|0;
  $70 = tempRet0;
  $71 = HEAP32[$61>>2]|0;
  $72 = ($71|0)==(0|0);
  if ($72) {
   HEAP32[$61>>2] = 0;
   ___resumeException($69|0);
   // unreachable;
  }
  $73 = ((($71)) + 8|0);
  $74 = HEAP32[$73>>2]|0;HEAP32[$73>>2] = (($74-1)|0);
  $75 = ($74|0)==(1);
  if (!($75)) {
   HEAP32[$61>>2] = 0;
   ___resumeException($69|0);
   // unreachable;
  }
  __THREW__ = 0;
  invoke_viii(3262,($71|0),1,1);
  $76 = __THREW__; __THREW__ = 0;
  $77 = $76&1;
  if ($77) {
   $78 = ___cxa_find_matching_catch_3(0|0)|0;
   $79 = tempRet0;
   ___clang_call_terminate($78);
   // unreachable;
  } else {
   HEAP32[$61>>2] = 0;
   ___resumeException($69|0);
   // unreachable;
  }
 }
 $84 = HEAP32[$14>>2]|0;
 $85 = ($84|0)==($$0$lcssa$i$i|0);
 if ($85) {
  return;
 } else {
  $87 = $84;
 }
 while(1) {
  $86 = ((($87)) + -52|0);
  HEAP32[$14>>2] = $86;
  $88 = ((($87)) + -12|0);
  $89 = HEAP32[$88>>2]|0;
  $90 = ($89|0)==(0|0);
  if (!($90)) {
   $91 = ((($87)) + -8|0);
   $92 = HEAP32[$91>>2]|0;
   $93 = ($92|0)==($89|0);
   if (!($93)) {
    $scevgep$i$i$i$i$i$i$i$i = ((($92)) + -12|0);
    $94 = $scevgep$i$i$i$i$i$i$i$i;
    $95 = $89;
    $96 = (($94) - ($95))|0;
    $97 = (($96>>>0) / 12)&-1;
    $98 = $97 ^ -1;
    $scevgep5$i$i$i$i$i$i$i$i = (($92) + (($98*12)|0)|0);
    HEAP32[$91>>2] = $scevgep5$i$i$i$i$i$i$i$i;
   }
   __ZdlPv($89);
  }
  $99 = ((($87)) + -24|0);
  $100 = HEAP32[$99>>2]|0;
  $101 = ($100|0)==(0|0);
  if (!($101)) {
   $102 = ((($87)) + -20|0);
   $103 = HEAP32[$102>>2]|0;
   $104 = ($103|0)==($100|0);
   if (!($104)) {
    $scevgep$i$i$i3$i$i$i$i$i = ((($103)) + -40|0);
    $105 = $scevgep$i$i$i3$i$i$i$i$i;
    $106 = $100;
    $107 = (($105) - ($106))|0;
    $108 = (($107>>>0) / 40)&-1;
    $109 = $108 ^ -1;
    $scevgep5$i$i$i4$i$i$i$i$i = (($103) + (($109*40)|0)|0);
    HEAP32[$102>>2] = $scevgep5$i$i$i4$i$i$i$i$i;
   }
   __ZdlPv($100);
  }
  $110 = ((($87)) + -44|0);
  $111 = HEAP32[$110>>2]|0;
  $112 = ($111|0)==(0|0);
  if (!($112)) {
   $113 = ((($87)) + -40|0);
   $114 = HEAP32[$113>>2]|0;
   $115 = ($114|0)==($111|0);
   if (!($115)) {
    $scevgep$i$i$i$i$i$i$i$i$i = ((($114)) + -4|0);
    $116 = $scevgep$i$i$i$i$i$i$i$i$i;
    $117 = $111;
    $118 = (($116) - ($117))|0;
    $119 = $118 >>> 2;
    $120 = $119 ^ -1;
    $scevgep5$i$i$i$i$i$i$i$i$i = (($114) + ($120<<2)|0);
    HEAP32[$113>>2] = $scevgep5$i$i$i$i$i$i$i$i$i;
   }
   __ZdlPv($111);
  }
  $121 = HEAP32[$86>>2]|0;
  $122 = ($121|0)==(0|0);
  if (!($122)) {
   $123 = ((($121)) + 8|0);
   $124 = HEAP32[$123>>2]|0;HEAP32[$123>>2] = (($124-1)|0);
   $125 = ($124|0)==(1);
   if ($125) {
    __THREW__ = 0;
    invoke_viii(3262,($121|0),1,1);
    $126 = __THREW__; __THREW__ = 0;
    $127 = $126&1;
    if ($127) {
     label = 41;
     break;
    }
   }
  }
  HEAP32[$86>>2] = 0;
  $128 = HEAP32[$14>>2]|0;
  $129 = ($128|0)==($$0$lcssa$i$i|0);
  if ($129) {
   label = 57;
   break;
  } else {
   $87 = $128;
  }
 }
 if ((label|0) == 41) {
  $130 = ___cxa_find_matching_catch_2()|0;
  $131 = tempRet0;
  ___cxa_call_unexpected(($130|0));
  // unreachable;
 }
 else if ((label|0) == 57) {
  return;
 }
}
function __ZNSt3__26vectorIN3osg20ShadowVolumeOccluderENS_9allocatorIS2_EEE6assignIPS2_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS2_NS_15iterator_traitsIS9_E9referenceEEE5valueEvE4typeES9_S9_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$ = 0, $$0$lcssa$i$i = 0, $$07$i$i = 0, $$07$i$i21 = 0, $$078$i$i = 0, $$09$i$i = 0, $$pre$i$i19 = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = $2;
 $4 = $1;
 $5 = (($3) - ($4))|0;
 $6 = (($5|0) / 80)&-1;
 $7 = ((($0)) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$0>>2]|0;
 $10 = (($8) - ($9))|0;
 $11 = (($10|0) / 80)&-1;
 $12 = ($6>>>0)>($11>>>0);
 $13 = $9;
 if (!($12)) {
  $14 = ((($0)) + 4|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (($15) - ($9))|0;
  $17 = (($16|0) / 80)&-1;
  $18 = ($6>>>0)>($17>>>0);
  $19 = (($1) + (($17*80)|0)|0);
  $$ = $18 ? $19 : $2;
  $20 = ($$|0)==($1|0);
  if ($20) {
   $$0$lcssa$i$i = $13;
  } else {
   $$078$i$i = $1;$$09$i$i = $13;
   while(1) {
    (__ZN3osg20ShadowVolumeOccluderaSERKS0_($$09$i$i,$$078$i$i)|0);
    $21 = ((($$078$i$i)) + 80|0);
    $22 = ((($$09$i$i)) + 80|0);
    $23 = ($21|0)==($$|0);
    if ($23) {
     $$0$lcssa$i$i = $22;
     break;
    } else {
     $$078$i$i = $21;$$09$i$i = $22;
    }
   }
  }
  if (!($18)) {
   while(1) {
    $30 = HEAP32[$14>>2]|0;
    $31 = ($30|0)==($$0$lcssa$i$i|0);
    if ($31) {
     label = 24;
     break;
    }
    $32 = ((($30)) + -80|0);
    HEAP32[$14>>2] = $32;
    __THREW__ = 0;
    invoke_vi(3586,($32|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     label = 10;
     break;
    }
   }
   if ((label|0) == 10) {
    $35 = ___cxa_find_matching_catch_2()|0;
    $36 = tempRet0;
    ___cxa_call_unexpected(($35|0));
    // unreachable;
   }
   else if ((label|0) == 24) {
    return;
   }
  }
  $24 = ($$|0)==($2|0);
  if ($24) {
   return;
  }
  $$pre$i$i19 = HEAP32[$14>>2]|0;
  $$07$i$i21 = $19;$25 = $$pre$i$i19;
  while(1) {
   __ZN3osg20ShadowVolumeOccluderC2ERKS0_($25,$$07$i$i21);
   $26 = ((($$07$i$i21)) + 80|0);
   $27 = HEAP32[$14>>2]|0;
   $28 = ((($27)) + 80|0);
   HEAP32[$14>>2] = $28;
   $29 = ($26|0)==($2|0);
   if ($29) {
    break;
   } else {
    $$07$i$i21 = $26;$25 = $28;
   }
  }
  return;
 }
 $37 = ($9|0)==(0);
 do {
  if ($37) {
   $49 = $8;
  } else {
   $38 = ((($0)) + 4|0);
   while(1) {
    $39 = HEAP32[$38>>2]|0;
    $40 = ($39|0)==($13|0);
    if ($40) {
     label = 16;
     break;
    }
    $41 = ((($39)) + -80|0);
    HEAP32[$38>>2] = $41;
    __THREW__ = 0;
    invoke_vi(3586,($41|0));
    $42 = __THREW__; __THREW__ = 0;
    $43 = $42&1;
    if ($43) {
     label = 15;
     break;
    }
   }
   if ((label|0) == 15) {
    $44 = ___cxa_find_matching_catch_2()|0;
    $45 = tempRet0;
    ___cxa_call_unexpected(($44|0));
    // unreachable;
   }
   else if ((label|0) == 16) {
    $46 = HEAP32[$0>>2]|0;
    __ZdlPv($46);
    HEAP32[$7>>2] = 0;
    HEAP32[$38>>2] = 0;
    HEAP32[$0>>2] = 0;
    $49 = 0;
    break;
   }
  }
 } while(0);
 $47 = ($6>>>0)>(53687091);
 if ($47) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $48 = (($49|0) / 80)&-1;
 $50 = ($48>>>0)<(26843545);
 $51 = $48 << 1;
 $52 = ($51>>>0)<($6>>>0);
 $$sroa$speculated$i = $52 ? $6 : $51;
 $$sroa$speculated$$i = $50 ? $$sroa$speculated$i : 53687091;
 $53 = ($$sroa$speculated$$i>>>0)>(53687091);
 if ($53) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $54 = ($$sroa$speculated$$i*80)|0;
 $55 = (__Znwj($54)|0);
 $56 = ((($0)) + 4|0);
 HEAP32[$56>>2] = $55;
 HEAP32[$0>>2] = $55;
 $57 = (($55) + (($$sroa$speculated$$i*80)|0)|0);
 HEAP32[$7>>2] = $57;
 $58 = ($1|0)==($2|0);
 if ($58) {
  return;
 }
 $$07$i$i = $1;$59 = $55;
 while(1) {
  __ZN3osg20ShadowVolumeOccluderC2ERKS0_($59,$$07$i$i);
  $60 = ((($$07$i$i)) + 80|0);
  $61 = HEAP32[$56>>2]|0;
  $62 = ((($61)) + 80|0);
  HEAP32[$56>>2] = $62;
  $63 = ($60|0)==($2|0);
  if ($63) {
   break;
  } else {
   $$07$i$i = $60;$59 = $62;
  }
 }
 return;
}
function __ZN3osg10CullingSet3setERKS0_RKNS_7MatrixdERKNS_5Vec4fE($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$sroa$011$021 = 0, $$sroa$017$022 = 0, $$sroa$04$08$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ((($1)) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($0)) + 12|0);
 HEAP32[$6>>2] = $5;
 $7 = ((($0)) + 64|0);
 $8 = ($0|0)==($1|0);
 if (!($8)) {
  $9 = ((($1)) + 64|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ((($1)) + 68|0);
  $12 = HEAP32[$11>>2]|0;
  __ZNSt3__26vectorINS_4pairIN3osg7ref_ptrINS2_8StateSetEEENS2_8PolytopeEEENS_9allocatorIS7_EEE6assignIPS7_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS7_NS_15iterator_traitsISE_E9referenceEEE5valueEvE4typeESE_SE_($7,$10,$12);
  $13 = ((($0)) + 76|0);
  $14 = ((($1)) + 76|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = ((($1)) + 80|0);
  $17 = HEAP32[$16>>2]|0;
  __ZNSt3__26vectorIN3osg20ShadowVolumeOccluderENS_9allocatorIS2_EEE6assignIPS2_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS2_NS_15iterator_traitsIS9_E9referenceEEE5valueEvE4typeES9_S9_($13,$15,$17);
 }
 $18 = ((($0)) + 88|0);
 ;HEAP32[$18>>2]=HEAP32[$3>>2]|0;HEAP32[$18+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$18+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$18+12>>2]=HEAP32[$3+12>>2]|0;
 $19 = ((($1)) + 104|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ((($0)) + 104|0);
 HEAP32[$21>>2] = $20;
 $22 = ((($0)) + 16|0);
 $23 = ((($1)) + 16|0);
 __ZN3osg8Polytope31setAndTransformProvidingInverseERKS0_RKNS_7MatrixdE($22,$23,$2);
 $24 = HEAP32[$7>>2]|0;
 $25 = ((($0)) + 68|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($24|0)==($26|0);
 if (!($27)) {
  $$sroa$017$022 = $24;
  while(1) {
   $33 = ((($$sroa$017$022)) + 4|0);
   __ZN3osg8Polytope25transformProvidingInverseERKNS_7MatrixdE($33,$2);
   $34 = ((($$sroa$017$022)) + 52|0);
   $35 = HEAP32[$25>>2]|0;
   $36 = ($34|0)==($35|0);
   if ($36) {
    break;
   } else {
    $$sroa$017$022 = $34;
   }
  }
 }
 $28 = ((($0)) + 76|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ((($0)) + 80|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ($29|0)==($31|0);
 if ($32) {
  return;
 } else {
  $$sroa$011$021 = $29;
 }
 while(1) {
  $37 = ((($$sroa$011$021)) + 20|0);
  __ZN3osg8Polytope25transformProvidingInverseERKNS_7MatrixdE($37,$2);
  $38 = ((($$sroa$011$021)) + 68|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = ((($$sroa$011$021)) + 72|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = ($39|0)==($41|0);
  if (!($42)) {
   $$sroa$04$08$i = $39;
   while(1) {
    __ZN3osg8Polytope25transformProvidingInverseERKNS_7MatrixdE($$sroa$04$08$i,$2);
    $43 = ((($$sroa$04$08$i)) + 48|0);
    $44 = HEAP32[$40>>2]|0;
    $45 = ($43|0)==($44|0);
    if ($45) {
     break;
    } else {
     $$sroa$04$08$i = $43;
    }
   }
  }
  $46 = ((($$sroa$011$021)) + 80|0);
  $47 = HEAP32[$30>>2]|0;
  $48 = ($46|0)==($47|0);
  if ($48) {
   break;
  } else {
   $$sroa$011$021 = $46;
  }
 }
 return;
}
function __ZN3osg8Polytope25transformProvidingInverseERKNS_7MatrixdE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$010 = 0, $$sroa$05$09 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0.0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0.0, $32 = 0, $33 = 0.0, $34 = 0.0, $35 = 0.0, $36 = 0.0, $37 = 0.0, $38 = 0.0, $39 = 0.0, $4 = 0, $40 = 0.0, $41 = 0.0;
 var $42 = 0.0, $43 = 0.0, $44 = 0.0, $45 = 0.0, $46 = 0.0, $47 = 0.0, $48 = 0.0, $49 = 0.0, $5 = 0, $50 = 0.0, $51 = 0.0, $52 = 0.0, $53 = 0.0, $54 = 0.0, $55 = 0.0, $56 = 0.0, $57 = 0.0, $58 = 0.0, $59 = 0.0, $6 = 0;
 var $60 = 0.0, $61 = 0.0, $62 = 0.0, $63 = 0.0, $64 = 0.0, $65 = 0.0, $66 = 0.0, $67 = 0.0, $68 = 0.0, $69 = 0.0, $7 = 0, $70 = 0.0, $71 = 0.0, $72 = 0.0, $73 = 0.0, $74 = 0.0, $75 = 0.0, $76 = 0.0, $77 = 0.0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0.0, $9 = 0, $90 = 0.0, $91 = 0.0, $92 = 0.0, $93 = 0.0, $94 = 0.0, $95 = 0.0, $96 = 0.0;
 var $97 = 0.0, $98 = 0.0, $99 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  return;
 }
 $4 = ((($0)) + 20|0);
 HEAP32[$4>>2] = $2;
 $5 = ((($0)) + 24|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($0)) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6|0)==($8|0);
 if ($9) {
  return;
 }
 $10 = ((($1)) + 8|0);
 $11 = ((($1)) + 16|0);
 $12 = ((($1)) + 24|0);
 $13 = ((($1)) + 32|0);
 $14 = ((($1)) + 40|0);
 $15 = ((($1)) + 48|0);
 $16 = ((($1)) + 56|0);
 $17 = ((($1)) + 64|0);
 $18 = ((($1)) + 72|0);
 $19 = ((($1)) + 80|0);
 $20 = ((($1)) + 88|0);
 $21 = ((($1)) + 96|0);
 $22 = ((($1)) + 104|0);
 $23 = ((($1)) + 112|0);
 $24 = ((($1)) + 120|0);
 $$010 = 1;$$sroa$05$09 = $6;
 while(1) {
  $25 = $2 & $$010;
  $26 = ($25|0)==(0);
  if (!($26)) {
   $27 = +HEAPF64[$$sroa$05$09>>3];
   $28 = ((($$sroa$05$09)) + 8|0);
   $29 = +HEAPF64[$28>>3];
   $30 = ((($$sroa$05$09)) + 16|0);
   $31 = +HEAPF64[$30>>3];
   $32 = ((($$sroa$05$09)) + 24|0);
   $33 = +HEAPF64[$32>>3];
   $34 = +HEAPF64[$1>>3];
   $35 = $27 * $34;
   $36 = +HEAPF64[$10>>3];
   $37 = $29 * $36;
   $38 = $35 + $37;
   $39 = +HEAPF64[$11>>3];
   $40 = $31 * $39;
   $41 = $38 + $40;
   $42 = +HEAPF64[$12>>3];
   $43 = $33 * $42;
   $44 = $41 + $43;
   $45 = +HEAPF64[$13>>3];
   $46 = $27 * $45;
   $47 = +HEAPF64[$14>>3];
   $48 = $29 * $47;
   $49 = $46 + $48;
   $50 = +HEAPF64[$15>>3];
   $51 = $31 * $50;
   $52 = $49 + $51;
   $53 = +HEAPF64[$16>>3];
   $54 = $33 * $53;
   $55 = $52 + $54;
   $56 = +HEAPF64[$17>>3];
   $57 = $27 * $56;
   $58 = +HEAPF64[$18>>3];
   $59 = $29 * $58;
   $60 = $57 + $59;
   $61 = +HEAPF64[$19>>3];
   $62 = $31 * $61;
   $63 = $60 + $62;
   $64 = +HEAPF64[$20>>3];
   $65 = $33 * $64;
   $66 = $63 + $65;
   $67 = +HEAPF64[$21>>3];
   $68 = $27 * $67;
   $69 = +HEAPF64[$22>>3];
   $70 = $29 * $69;
   $71 = $68 + $70;
   $72 = +HEAPF64[$23>>3];
   $73 = $31 * $72;
   $74 = $71 + $73;
   $75 = +HEAPF64[$24>>3];
   $76 = $33 * $75;
   $77 = $74 + $76;
   $78 = $44 >= 0.0;
   $79 = $78&1;
   $80 = $55 >= 0.0;
   $81 = $80 ? 2 : 0;
   $82 = $81 | $79;
   $83 = $66 >= 0.0;
   $84 = $83 ? 4 : 0;
   $85 = $82 | $84;
   $86 = ((($$sroa$05$09)) + 32|0);
   HEAP32[$86>>2] = $85;
   $87 = $85 ^ 7;
   $88 = ((($$sroa$05$09)) + 36|0);
   HEAP32[$88>>2] = $87;
   $89 = $44 * $44;
   $90 = $55 * $55;
   $91 = $89 + $90;
   $92 = $66 * $66;
   $93 = $91 + $92;
   $94 = (+Math_sqrt((+$93)));
   $95 = 1.0 / $94;
   $96 = $44 * $95;
   HEAPF64[$$sroa$05$09>>3] = $96;
   $97 = $55 * $95;
   HEAPF64[$28>>3] = $97;
   $98 = $66 * $95;
   HEAPF64[$30>>3] = $98;
   $99 = $77 * $95;
   HEAPF64[$32>>3] = $99;
  }
  $100 = $$010 << 1;
  $101 = ((($$sroa$05$09)) + 40|0);
  $102 = ($101|0)==($8|0);
  if ($102) {
   break;
  } else {
   $$010 = $100;$$sroa$05$09 = $101;
  }
 }
 return;
}
function __ZN3osg20ShadowVolumeOccluderaSERKS0_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $2;
 $3 = ($0|0)==($1|0);
 if (!($3)) {
  $4 = ((($0)) + 4|0);
  $5 = ((($1)) + 4|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ((($1)) + 8|0);
  $8 = HEAP32[$7>>2]|0;
  __ZNSt3__26vectorIPN3osg4NodeENS_9allocatorIS3_EEE6assignIPS3_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS3_NS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_($4,$6,$8);
 }
 $9 = ((($0)) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ((($1)) + 16|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($10|0)==($12|0);
 if (!($13)) {
  HEAP32[$9>>2] = $12;
  $14 = ($12|0)==(0|0);
  if (!($14)) {
   $15 = ((($12)) + 8|0);
   $16 = HEAP32[$15>>2]|0;HEAP32[$15>>2] = (($16+1)|0);
  }
  $17 = ($10|0)==(0|0);
  if (!($17)) {
   $18 = ((($10)) + 8|0);
   $19 = HEAP32[$18>>2]|0;HEAP32[$18>>2] = (($19-1)|0);
   $20 = ($19|0)==(1);
   if ($20) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($10,1,1);
   }
  }
 }
 if ($3) {
  return ($0|0);
 }
 $21 = ((($1)) + 20|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ((($0)) + 20|0);
 HEAP32[$23>>2] = $22;
 $24 = ((($0)) + 24|0);
 $25 = ((($1)) + 24|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ((($1)) + 28|0);
 $28 = HEAP32[$27>>2]|0;
 __ZNSt3__26vectorIjNS_9allocatorIjEEE6assignIPjEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIjNS_15iterator_traitsIS7_E9referenceEEE5valueEvE4typeES7_S7_($24,$26,$28);
 $29 = ((($1)) + 36|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ((($0)) + 36|0);
 HEAP32[$31>>2] = $30;
 $32 = ((($1)) + 40|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ((($0)) + 40|0);
 HEAP32[$34>>2] = $33;
 $35 = ((($0)) + 44|0);
 $36 = ((($1)) + 44|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = ((($1)) + 48|0);
 $39 = HEAP32[$38>>2]|0;
 __ZNSt3__26vectorIN3osg5PlaneENS_9allocatorIS2_EEE6assignIPS2_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS2_NS_15iterator_traitsIS9_E9referenceEEE5valueEvE4typeES9_S9_($35,$37,$39);
 $40 = ((($0)) + 56|0);
 $41 = ((($1)) + 56|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ((($1)) + 60|0);
 $44 = HEAP32[$43>>2]|0;
 __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE6assignIPS2_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS2_NS_15iterator_traitsIS9_E9referenceEEE5valueEvE4typeES9_S9_($40,$42,$44);
 $45 = ((($0)) + 68|0);
 $46 = ((($1)) + 68|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = ((($1)) + 72|0);
 $49 = HEAP32[$48>>2]|0;
 __ZNSt3__26vectorIN3osg8PolytopeENS_9allocatorIS2_EEE6assignIPS2_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS2_NS_15iterator_traitsIS9_E9referenceEEE5valueEvE4typeES9_S9_($45,$47,$49);
 return ($0|0);
}
function __ZNSt3__26vectorIN3osg8PolytopeENS_9allocatorIS2_EEE6assignIPS2_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS2_NS_15iterator_traitsIS9_E9referenceEEE5valueEvE4typeES9_S9_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$ = 0, $$0$lcssa$i$i = 0, $$07$i$i = 0, $$07$i$i21 = 0, $$078$i$i = 0, $$09$i$i = 0, $$pre$i$i19 = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $scevgep$i$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i$i$i = 0, $scevgep$i$i$i3$i$i$i$i$i = 0;
 var $scevgep5$i$i$i$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i$i$i$i$i = 0, $scevgep5$i$i$i4$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = $2;
 $4 = $1;
 $5 = (($3) - ($4))|0;
 $6 = (($5|0) / 48)&-1;
 $7 = ((($0)) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$0>>2]|0;
 $10 = (($8) - ($9))|0;
 $11 = (($10|0) / 48)&-1;
 $12 = ($6>>>0)>($11>>>0);
 $13 = $9;
 if ($12) {
  __ZNSt3__26vectorIN3osg8PolytopeENS_9allocatorIS2_EEE10deallocateEv($0);
  $92 = ($6>>>0)>(89478485);
  if ($92) {
   __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
   // unreachable;
  }
  $93 = HEAP32[$7>>2]|0;
  $94 = HEAP32[$0>>2]|0;
  $95 = (($93) - ($94))|0;
  $96 = (($95|0) / 48)&-1;
  $97 = ($96>>>0)<(44739242);
  $98 = $96 << 1;
  $99 = ($98>>>0)<($6>>>0);
  $$sroa$speculated$i = $99 ? $6 : $98;
  $$sroa$speculated$$i = $97 ? $$sroa$speculated$i : 89478485;
  $100 = ($$sroa$speculated$$i>>>0)>(89478485);
  if ($100) {
   __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
   // unreachable;
  }
  $101 = ($$sroa$speculated$$i*48)|0;
  $102 = (__Znwj($101)|0);
  $103 = ((($0)) + 4|0);
  HEAP32[$103>>2] = $102;
  HEAP32[$0>>2] = $102;
  $104 = (($102) + (($$sroa$speculated$$i*48)|0)|0);
  HEAP32[$7>>2] = $104;
  $105 = ($1|0)==($2|0);
  if ($105) {
   return;
  }
  $$07$i$i = $1;$106 = $102;
  while(1) {
   __ZN3osg8PolytopeC2ERKS0_($106,$$07$i$i);
   $107 = ((($$07$i$i)) + 48|0);
   $108 = HEAP32[$103>>2]|0;
   $109 = ((($108)) + 48|0);
   HEAP32[$103>>2] = $109;
   $110 = ($107|0)==($2|0);
   if ($110) {
    break;
   } else {
    $$07$i$i = $107;$106 = $109;
   }
  }
  return;
 }
 $14 = ((($0)) + 4|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($15) - ($9))|0;
 $17 = (($16|0) / 48)&-1;
 $18 = ($6>>>0)>($17>>>0);
 $19 = (($1) + (($17*48)|0)|0);
 $$ = $18 ? $19 : $2;
 $20 = ($$|0)==($1|0);
 if ($20) {
  $$0$lcssa$i$i = $13;
 } else {
  $$078$i$i = $1;$$09$i$i = $13;
  while(1) {
   $21 = ($$078$i$i|0)==($$09$i$i|0);
   if (!($21)) {
    $22 = HEAP32[$$078$i$i>>2]|0;
    HEAP32[$$09$i$i>>2] = $22;
    $23 = ((($$09$i$i)) + 4|0);
    $24 = ((($$078$i$i)) + 4|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = ((($$078$i$i)) + 8|0);
    $27 = HEAP32[$26>>2]|0;
    __ZNSt3__26vectorIjNS_9allocatorIjEEE6assignIPjEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIjNS_15iterator_traitsIS7_E9referenceEEE5valueEvE4typeES7_S7_($23,$25,$27);
    $28 = ((($$078$i$i)) + 16|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = ((($$09$i$i)) + 16|0);
    HEAP32[$30>>2] = $29;
    $31 = ((($$078$i$i)) + 20|0);
    $32 = HEAP32[$31>>2]|0;
    $33 = ((($$09$i$i)) + 20|0);
    HEAP32[$33>>2] = $32;
    $34 = ((($$09$i$i)) + 24|0);
    $35 = ((($$078$i$i)) + 24|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = ((($$078$i$i)) + 28|0);
    $38 = HEAP32[$37>>2]|0;
    __ZNSt3__26vectorIN3osg5PlaneENS_9allocatorIS2_EEE6assignIPS2_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS2_NS_15iterator_traitsIS9_E9referenceEEE5valueEvE4typeES9_S9_($34,$36,$38);
    $39 = ((($$09$i$i)) + 36|0);
    $40 = ((($$078$i$i)) + 36|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = ((($$078$i$i)) + 40|0);
    $43 = HEAP32[$42>>2]|0;
    __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE6assignIPS2_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS2_NS_15iterator_traitsIS9_E9referenceEEE5valueEvE4typeES9_S9_($39,$41,$43);
   }
   $44 = ((($$078$i$i)) + 48|0);
   $45 = ((($$09$i$i)) + 48|0);
   $46 = ($44|0)==($$|0);
   if ($46) {
    $$0$lcssa$i$i = $45;
    break;
   } else {
    $$078$i$i = $44;$$09$i$i = $45;
   }
  }
 }
 if ($18) {
  $47 = ($$|0)==($2|0);
  if ($47) {
   return;
  }
  $$pre$i$i19 = HEAP32[$14>>2]|0;
  $$07$i$i21 = $19;$48 = $$pre$i$i19;
  while(1) {
   __ZN3osg8PolytopeC2ERKS0_($48,$$07$i$i21);
   $49 = ((($$07$i$i21)) + 48|0);
   $50 = HEAP32[$14>>2]|0;
   $51 = ((($50)) + 48|0);
   HEAP32[$14>>2] = $51;
   $52 = ($49|0)==($2|0);
   if ($52) {
    break;
   } else {
    $$07$i$i21 = $49;$48 = $51;
   }
  }
  return;
 }
 $53 = HEAP32[$14>>2]|0;
 $54 = ($53|0)==($$0$lcssa$i$i|0);
 if ($54) {
  return;
 } else {
  $56 = $53;
 }
 while(1) {
  $55 = ((($56)) + -48|0);
  HEAP32[$14>>2] = $55;
  $57 = ((($56)) + -12|0);
  $58 = HEAP32[$57>>2]|0;
  $59 = ($58|0)==(0|0);
  if (!($59)) {
   $60 = ((($56)) + -8|0);
   $61 = HEAP32[$60>>2]|0;
   $62 = ($61|0)==($58|0);
   if (!($62)) {
    $scevgep$i$i$i$i$i$i$i$i = ((($61)) + -12|0);
    $63 = $scevgep$i$i$i$i$i$i$i$i;
    $64 = $58;
    $65 = (($63) - ($64))|0;
    $66 = (($65>>>0) / 12)&-1;
    $67 = $66 ^ -1;
    $scevgep5$i$i$i$i$i$i$i$i = (($61) + (($67*12)|0)|0);
    HEAP32[$60>>2] = $scevgep5$i$i$i$i$i$i$i$i;
   }
   __ZdlPv($58);
  }
  $68 = ((($56)) + -24|0);
  $69 = HEAP32[$68>>2]|0;
  $70 = ($69|0)==(0|0);
  if (!($70)) {
   $71 = ((($56)) + -20|0);
   $72 = HEAP32[$71>>2]|0;
   $73 = ($72|0)==($69|0);
   if (!($73)) {
    $scevgep$i$i$i3$i$i$i$i$i = ((($72)) + -40|0);
    $74 = $scevgep$i$i$i3$i$i$i$i$i;
    $75 = $69;
    $76 = (($74) - ($75))|0;
    $77 = (($76>>>0) / 40)&-1;
    $78 = $77 ^ -1;
    $scevgep5$i$i$i4$i$i$i$i$i = (($72) + (($78*40)|0)|0);
    HEAP32[$71>>2] = $scevgep5$i$i$i4$i$i$i$i$i;
   }
   __ZdlPv($69);
  }
  $79 = ((($56)) + -44|0);
  $80 = HEAP32[$79>>2]|0;
  $81 = ($80|0)==(0|0);
  if (!($81)) {
   $84 = ((($56)) + -40|0);
   $85 = HEAP32[$84>>2]|0;
   $86 = ($85|0)==($80|0);
   if (!($86)) {
    $scevgep$i$i$i$i$i$i$i$i$i = ((($85)) + -4|0);
    $87 = $scevgep$i$i$i$i$i$i$i$i$i;
    $88 = $80;
    $89 = (($87) - ($88))|0;
    $90 = $89 >>> 2;
    $91 = $90 ^ -1;
    $scevgep5$i$i$i$i$i$i$i$i$i = (($85) + ($91<<2)|0);
    HEAP32[$84>>2] = $scevgep5$i$i$i$i$i$i$i$i$i;
   }
   __ZdlPv($80);
  }
  $82 = HEAP32[$14>>2]|0;
  $83 = ($82|0)==($$0$lcssa$i$i|0);
  if ($83) {
   break;
  } else {
   $56 = $82;
  }
 }
 return;
}
function __ZNSt3__26vectorIN3osg8PolytopeENS_9allocatorIS2_EEE10deallocateEv($0) {
 $0 = $0|0;
 var $$pre = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i$i$i$i = 0, $scevgep$i$i$i3$i$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i$i$i$i$i$i = 0, $scevgep5$i$i$i4$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 }
 $3 = ((($0)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==($1|0);
 if ($5) {
  $43 = $1;
 } else {
  $7 = $4;
  while(1) {
   $6 = ((($7)) + -48|0);
   HEAP32[$3>>2] = $6;
   $8 = ((($7)) + -12|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = ($9|0)==(0|0);
   if (!($10)) {
    $11 = ((($7)) + -8|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ($12|0)==($9|0);
    if (!($13)) {
     $scevgep$i$i$i$i$i$i$i$i$i = ((($12)) + -12|0);
     $14 = $scevgep$i$i$i$i$i$i$i$i$i;
     $15 = $9;
     $16 = (($14) - ($15))|0;
     $17 = (($16>>>0) / 12)&-1;
     $18 = $17 ^ -1;
     $scevgep5$i$i$i$i$i$i$i$i$i = (($12) + (($18*12)|0)|0);
     HEAP32[$11>>2] = $scevgep5$i$i$i$i$i$i$i$i$i;
    }
    __ZdlPv($9);
   }
   $19 = ((($7)) + -24|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = ($20|0)==(0|0);
   if (!($21)) {
    $22 = ((($7)) + -20|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = ($23|0)==($20|0);
    if (!($24)) {
     $scevgep$i$i$i3$i$i$i$i$i$i = ((($23)) + -40|0);
     $25 = $scevgep$i$i$i3$i$i$i$i$i$i;
     $26 = $20;
     $27 = (($25) - ($26))|0;
     $28 = (($27>>>0) / 40)&-1;
     $29 = $28 ^ -1;
     $scevgep5$i$i$i4$i$i$i$i$i$i = (($23) + (($29*40)|0)|0);
     HEAP32[$22>>2] = $scevgep5$i$i$i4$i$i$i$i$i$i;
    }
    __ZdlPv($20);
   }
   $30 = ((($7)) + -44|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = ($31|0)==(0|0);
   if (!($32)) {
    $35 = ((($7)) + -40|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = ($36|0)==($31|0);
    if (!($37)) {
     $scevgep$i$i$i$i$i$i$i$i$i$i = ((($36)) + -4|0);
     $38 = $scevgep$i$i$i$i$i$i$i$i$i$i;
     $39 = $31;
     $40 = (($38) - ($39))|0;
     $41 = $40 >>> 2;
     $42 = $41 ^ -1;
     $scevgep5$i$i$i$i$i$i$i$i$i$i = (($36) + ($42<<2)|0);
     HEAP32[$35>>2] = $scevgep5$i$i$i$i$i$i$i$i$i$i;
    }
    __ZdlPv($31);
   }
   $33 = HEAP32[$3>>2]|0;
   $34 = ($33|0)==($1|0);
   if ($34) {
    break;
   } else {
    $7 = $33;
   }
  }
  $$pre = HEAP32[$0>>2]|0;
  $43 = $$pre;
 }
 __ZdlPv($43);
 $44 = ((($0)) + 8|0);
 HEAP32[$44>>2] = 0;
 HEAP32[$3>>2] = 0;
 HEAP32[$0>>2] = 0;
 return;
}
function __ZNSt3__26vectorINS_4pairIN3osg7ref_ptrINS2_8StateSetEEENS2_8PolytopeEEENS_9allocatorIS7_EEE10deallocateEv($0) {
 $0 = $0|0;
 var $$pre = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i$i$i$i = 0, $scevgep$i$i$i3$i$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i$i$i$i$i$i = 0, $scevgep5$i$i$i4$i$i$i$i$i$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 }
 $3 = ((($0)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==($1|0);
 do {
  if ($5) {
   $52 = $1;
  } else {
   $7 = $4;
   while(1) {
    $6 = ((($7)) + -52|0);
    HEAP32[$3>>2] = $6;
    $8 = ((($7)) + -12|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = ($9|0)==(0|0);
    if (!($10)) {
     $11 = ((($7)) + -8|0);
     $12 = HEAP32[$11>>2]|0;
     $13 = ($12|0)==($9|0);
     if (!($13)) {
      $scevgep$i$i$i$i$i$i$i$i$i = ((($12)) + -12|0);
      $14 = $scevgep$i$i$i$i$i$i$i$i$i;
      $15 = $9;
      $16 = (($14) - ($15))|0;
      $17 = (($16>>>0) / 12)&-1;
      $18 = $17 ^ -1;
      $scevgep5$i$i$i$i$i$i$i$i$i = (($12) + (($18*12)|0)|0);
      HEAP32[$11>>2] = $scevgep5$i$i$i$i$i$i$i$i$i;
     }
     __ZdlPv($9);
    }
    $19 = ((($7)) + -24|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = ($20|0)==(0|0);
    if (!($21)) {
     $22 = ((($7)) + -20|0);
     $23 = HEAP32[$22>>2]|0;
     $24 = ($23|0)==($20|0);
     if (!($24)) {
      $scevgep$i$i$i3$i$i$i$i$i$i = ((($23)) + -40|0);
      $25 = $scevgep$i$i$i3$i$i$i$i$i$i;
      $26 = $20;
      $27 = (($25) - ($26))|0;
      $28 = (($27>>>0) / 40)&-1;
      $29 = $28 ^ -1;
      $scevgep5$i$i$i4$i$i$i$i$i$i = (($23) + (($29*40)|0)|0);
      HEAP32[$22>>2] = $scevgep5$i$i$i4$i$i$i$i$i$i;
     }
     __ZdlPv($20);
    }
    $30 = ((($7)) + -44|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = ($31|0)==(0|0);
    if (!($32)) {
     $33 = ((($7)) + -40|0);
     $34 = HEAP32[$33>>2]|0;
     $35 = ($34|0)==($31|0);
     if (!($35)) {
      $scevgep$i$i$i$i$i$i$i$i$i$i = ((($34)) + -4|0);
      $36 = $scevgep$i$i$i$i$i$i$i$i$i$i;
      $37 = $31;
      $38 = (($36) - ($37))|0;
      $39 = $38 >>> 2;
      $40 = $39 ^ -1;
      $scevgep5$i$i$i$i$i$i$i$i$i$i = (($34) + ($40<<2)|0);
      HEAP32[$33>>2] = $scevgep5$i$i$i$i$i$i$i$i$i$i;
     }
     __ZdlPv($31);
    }
    $41 = HEAP32[$6>>2]|0;
    $42 = ($41|0)==(0|0);
    if (!($42)) {
     $43 = ((($41)) + 8|0);
     $44 = HEAP32[$43>>2]|0;HEAP32[$43>>2] = (($44-1)|0);
     $45 = ($44|0)==(1);
     if ($45) {
      __THREW__ = 0;
      invoke_viii(3262,($41|0),1,1);
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       label = 19;
       break;
      }
     }
    }
    HEAP32[$6>>2] = 0;
    $48 = HEAP32[$3>>2]|0;
    $49 = ($48|0)==($1|0);
    if ($49) {
     label = 20;
     break;
    } else {
     $7 = $48;
    }
   }
   if ((label|0) == 19) {
    $50 = ___cxa_find_matching_catch_2()|0;
    $51 = tempRet0;
    ___cxa_call_unexpected(($50|0));
    // unreachable;
   }
   else if ((label|0) == 20) {
    $$pre = HEAP32[$0>>2]|0;
    $52 = $$pre;
    break;
   }
  }
 } while(0);
 __ZdlPv($52);
 $53 = ((($0)) + 8|0);
 HEAP32[$53>>2] = 0;
 HEAP32[$3>>2] = 0;
 HEAP32[$0>>2] = 0;
 return;
}
function __ZNSt3__26vectorINS_4pairIN3osg7ref_ptrINS2_8StateSetEEENS2_8PolytopeEEENS_9allocatorIS7_EEEC2ERKSA_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$07$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = 0;
 $2 = ((($0)) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = ((($0)) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$1>>2]|0;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 52)&-1;
 $9 = ($7|0)==(0);
 if ($9) {
  return;
 }
 $10 = ($8>>>0)>(82595524);
 if ($10) {
  __THREW__ = 0;
  invoke_vi(3307,($0|0));
  $11 = __THREW__; __THREW__ = 0;
  label = 16;
 } else {
  __THREW__ = 0;
  $12 = (invoke_ii(3276,($7|0))|0);
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if ($14) {
   label = 16;
  } else {
   HEAP32[$2>>2] = $12;
   HEAP32[$0>>2] = $12;
   $15 = (($12) + (($8*52)|0)|0);
   $16 = ((($0)) + 8|0);
   HEAP32[$16>>2] = $15;
   $17 = HEAP32[$1>>2]|0;
   $18 = HEAP32[$4>>2]|0;
   $19 = ($17|0)==($18|0);
   if ($19) {
    return;
   }
   $$07$i$i = $17;$21 = $12;
   while(1) {
    $20 = HEAP32[$$07$i$i>>2]|0;
    HEAP32[$21>>2] = $20;
    $22 = ($20|0)==(0|0);
    if (!($22)) {
     $23 = ((($20)) + 8|0);
     $24 = HEAP32[$23>>2]|0;HEAP32[$23>>2] = (($24+1)|0);
    }
    $25 = ((($21)) + 4|0);
    $26 = ((($$07$i$i)) + 4|0);
    __THREW__ = 0;
    invoke_vii(3596,($25|0),($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    $40 = ((($$07$i$i)) + 52|0);
    $41 = HEAP32[$2>>2]|0;
    $42 = ((($41)) + 52|0);
    HEAP32[$2>>2] = $42;
    $43 = ($40|0)==($18|0);
    if ($43) {
     label = 18;
     break;
    } else {
     $$07$i$i = $40;$21 = $42;
    }
   }
   if ((label|0) == 18) {
    return;
   }
   $29 = ___cxa_find_matching_catch_2()|0;
   $30 = tempRet0;
   $31 = HEAP32[$21>>2]|0;
   $32 = ($31|0)==(0|0);
   if (!($32)) {
    $33 = ((($31)) + 8|0);
    $34 = HEAP32[$33>>2]|0;HEAP32[$33>>2] = (($34-1)|0);
    $35 = ($34|0)==(1);
    if ($35) {
     __THREW__ = 0;
     invoke_viii(3262,($31|0),1,1);
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if ($37) {
      $38 = ___cxa_find_matching_catch_3(0|0)|0;
      $39 = tempRet0;
      ___clang_call_terminate($38);
      // unreachable;
     }
    }
   }
   HEAP32[$21>>2] = 0;
   $eh$lpad$body$index2Z2D = $30;$eh$lpad$body$indexZ2D = $29;
  }
 }
 if ((label|0) == 16) {
  $44 = ___cxa_find_matching_catch_2()|0;
  $45 = tempRet0;
  $eh$lpad$body$index2Z2D = $45;$eh$lpad$body$indexZ2D = $44;
 }
 __THREW__ = 0;
 invoke_vi(3734,($0|0));
 $46 = __THREW__; __THREW__ = 0;
 $47 = $46&1;
 if ($47) {
  $48 = ___cxa_find_matching_catch_3(0|0)|0;
  $49 = tempRet0;
  ___clang_call_terminate($48);
  // unreachable;
 } else {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
}
function __ZNSt3__26vectorIN3osg20ShadowVolumeOccluderENS_9allocatorIS2_EEEC2ERKS5_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$07$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = 0;
 $2 = ((($0)) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = ((($0)) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$1>>2]|0;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 80)&-1;
 $9 = ($7|0)==(0);
 if ($9) {
  return;
 }
 $10 = ($8>>>0)>(53687091);
 L4: do {
  if ($10) {
   __THREW__ = 0;
   invoke_vi(3307,($0|0));
   $11 = __THREW__; __THREW__ = 0;
  } else {
   __THREW__ = 0;
   $12 = (invoke_ii(3276,($7|0))|0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if (!($14)) {
    HEAP32[$2>>2] = $12;
    HEAP32[$0>>2] = $12;
    $15 = (($12) + (($8*80)|0)|0);
    $16 = ((($0)) + 8|0);
    HEAP32[$16>>2] = $15;
    $17 = HEAP32[$1>>2]|0;
    $18 = HEAP32[$4>>2]|0;
    $19 = ($17|0)==($18|0);
    if ($19) {
     return;
    }
    $$07$i$i = $17;$20 = $12;
    while(1) {
     __THREW__ = 0;
     invoke_vii(3587,($20|0),($$07$i$i|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break L4;
     }
     $23 = ((($$07$i$i)) + 80|0);
     $24 = HEAP32[$2>>2]|0;
     $25 = ((($24)) + 80|0);
     HEAP32[$2>>2] = $25;
     $26 = ($23|0)==($18|0);
     if ($26) {
      break;
     } else {
      $$07$i$i = $23;$20 = $25;
     }
    }
    return;
   }
  }
 } while(0);
 $27 = ___cxa_find_matching_catch_2()|0;
 $28 = tempRet0;
 $29 = HEAP32[$0>>2]|0;
 $30 = ($29|0)==(0|0);
 if ($30) {
  ___resumeException($27|0);
  // unreachable;
 }
 while(1) {
  $31 = HEAP32[$2>>2]|0;
  $32 = ($31|0)==($29|0);
  if ($32) {
   break;
  }
  $33 = ((($31)) + -80|0);
  HEAP32[$2>>2] = $33;
  __THREW__ = 0;
  invoke_vi(3586,($33|0));
  $34 = __THREW__; __THREW__ = 0;
  $35 = $34&1;
  if ($35) {
   label = 12;
   break;
  }
 }
 if ((label|0) == 12) {
  $36 = ___cxa_find_matching_catch_2()|0;
  $37 = tempRet0;
  ___cxa_call_unexpected(($36|0));
  // unreachable;
 }
 $38 = HEAP32[$0>>2]|0;
 __ZdlPv($38);
 ___resumeException($27|0);
 // unreachable;
}
function __ZN3osg9CullStack13popCullingSetEv($0) {
 $0 = $0|0;
 var $$pre$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 132|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if (!($3)) {
  $4 = ((($0)) + 120|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ((($0)) + 124|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($5|0)==($7|0);
  do {
   if ($8) {
    $37 = $2;
   } else {
    $9 = ((($0)) + 116|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = ((($7)) + -4|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ($10|0)==($12|0);
    if (!($13)) {
     HEAP32[$9>>2] = $12;
     $14 = ($12|0)==(0|0);
     if (!($14)) {
      $15 = ((($12)) + 8|0);
      $16 = HEAP32[$15>>2]|0;HEAP32[$15>>2] = (($16+1)|0);
     }
     $17 = ($10|0)==(0|0);
     if (!($17)) {
      $18 = ((($10)) + 8|0);
      $19 = HEAP32[$18>>2]|0;HEAP32[$18>>2] = (($19-1)|0);
      $20 = ($19|0)==(1);
      if ($20) {
       __ZNK3osg10Referenced24signalObserversAndDeleteEbb($10,1,1);
      }
     }
    }
    $21 = HEAP32[$6>>2]|0;
    $22 = ((($21)) + -4|0);
    $24 = $21;
    while(1) {
     $23 = ((($24)) + -4|0);
     HEAP32[$6>>2] = $23;
     $25 = HEAP32[$23>>2]|0;
     $26 = ($25|0)==(0|0);
     if (!($26)) {
      $27 = ((($25)) + 8|0);
      $28 = HEAP32[$27>>2]|0;HEAP32[$27>>2] = (($28-1)|0);
      $29 = ($28|0)==(1);
      if ($29) {
       __THREW__ = 0;
       invoke_viii(3262,($25|0),1,1);
       $30 = __THREW__; __THREW__ = 0;
       $31 = $30&1;
       if ($31) {
        label = 14;
        break;
       }
      }
     }
     HEAP32[$23>>2] = 0;
     $32 = HEAP32[$6>>2]|0;
     $33 = ($32|0)==($22|0);
     if ($33) {
      label = 15;
      break;
     } else {
      $24 = $32;
     }
    }
    if ((label|0) == 14) {
     $34 = ___cxa_find_matching_catch_2()|0;
     $35 = tempRet0;
     ___cxa_call_unexpected(($34|0));
     // unreachable;
    }
    else if ((label|0) == 15) {
     $$pre$i = HEAP32[$1>>2]|0;
     $37 = $$pre$i;
     break;
    }
   }
  } while(0);
  $36 = (($37) + -1)|0;
  HEAP32[$1>>2] = $36;
 }
 $38 = ((($0)) + 276|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($39) + -1)|0;
 HEAP32[$38>>2] = $40;
 $41 = ($40|0)==(0);
 if ($41) {
  return;
 }
 $42 = ((($0)) + 280|0);
 $43 = ((($0)) + 264|0);
 $44 = (($39) + -2)|0;
 $45 = HEAP32[$43>>2]|0;
 $46 = (($45) + (($44*108)|0)|0);
 HEAP32[$42>>2] = $46;
 return;
}
function __ZN3osg9CullStack12pushViewportEPNS_8ViewportE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$pre$i$i = 0, $$pre$i$i5 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 136|0);
 $3 = ($1|0)==(0|0);
 if (!($3)) {
  $4 = ((($1)) + 8|0);
  $5 = HEAP32[$4>>2]|0;HEAP32[$4>>2] = (($5+1)|0);
 }
 $6 = ((($0)) + 152|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0);
 do {
  if ($8) {
   label = 9;
  } else {
   $9 = ((($0)) + 144|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ((($0)) + 148|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = ($10|0)==($12|0);
   if ($13) {
    $20 = ((($0)) + 140|0);
    __THREW__ = 0;
    invoke_vii(3741,($20|0),($2|0));
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if ($22) {
     break;
    } else {
     label = 9;
     break;
    }
   }
   $14 = HEAP32[$2>>2]|0;
   HEAP32[$10>>2] = $14;
   $15 = ($14|0)==(0|0);
   if ($15) {
    $19 = $10;
   } else {
    $16 = ((($14)) + 8|0);
    $17 = HEAP32[$16>>2]|0;HEAP32[$16>>2] = (($17+1)|0);
    $$pre$i$i = HEAP32[$9>>2]|0;
    $19 = $$pre$i$i;
   }
   $18 = ((($19)) + 4|0);
   HEAP32[$9>>2] = $18;
   label = 9;
  }
 } while(0);
 do {
  if ((label|0) == 9) {
   $23 = HEAP32[$2>>2]|0;
   $24 = ($23|0)==($1|0);
   if (!($24)) {
    HEAP32[$2>>2] = $1;
    if (!($3)) {
     $25 = ((($1)) + 8|0);
     $26 = HEAP32[$25>>2]|0;HEAP32[$25>>2] = (($26+1)|0);
    }
    $27 = ($23|0)==(0|0);
    if (!($27)) {
     $28 = ((($23)) + 8|0);
     $29 = HEAP32[$28>>2]|0;HEAP32[$28>>2] = (($29-1)|0);
     $30 = ($29|0)==(1);
     if ($30) {
      __THREW__ = 0;
      invoke_viii(3262,($23|0),1,1);
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if ($32) {
       break;
      }
     }
    }
   }
   $33 = HEAP32[$6>>2]|0;
   $34 = (($33) + 1)|0;
   HEAP32[$6>>2] = $34;
   if (!($3)) {
    $35 = ((($1)) + 8|0);
    $36 = HEAP32[$35>>2]|0;HEAP32[$35>>2] = (($36-1)|0);
    $37 = ($36|0)==(1);
    if ($37) {
     __ZNK3osg10Referenced24signalObserversAndDeleteEbb($1,1,1);
    }
   }
   $38 = ((($0)) + 116|0);
   $39 = ((($0)) + 132|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = ($40|0)==(0);
   do {
    if (!($41)) {
     $42 = ((($0)) + 124|0);
     $43 = HEAP32[$42>>2]|0;
     $44 = ((($0)) + 128|0);
     $45 = HEAP32[$44>>2]|0;
     $46 = ($43|0)==($45|0);
     if ($46) {
      $53 = ((($0)) + 120|0);
      __ZNSt3__26vectorIN3osg7ref_ptrINS1_10RefMatrixdEEENS_9allocatorIS4_EEE21__push_back_slow_pathIKS4_EEvRT_($53,$38);
      break;
     }
     $47 = HEAP32[$38>>2]|0;
     HEAP32[$43>>2] = $47;
     $48 = ($47|0)==(0|0);
     if ($48) {
      $52 = $43;
     } else {
      $49 = ((($47)) + 8|0);
      $50 = HEAP32[$49>>2]|0;HEAP32[$49>>2] = (($50+1)|0);
      $$pre$i$i5 = HEAP32[$42>>2]|0;
      $52 = $$pre$i$i5;
     }
     $51 = ((($52)) + 4|0);
     HEAP32[$42>>2] = $51;
    }
   } while(0);
   $54 = HEAP32[$38>>2]|0;
   $55 = ($54|0)==(0|0);
   if ($55) {
    $59 = HEAP32[$39>>2]|0;
    $60 = (($59) + 1)|0;
    HEAP32[$39>>2] = $60;
    return;
   }
   HEAP32[$38>>2] = 0;
   $56 = ((($54)) + 8|0);
   $57 = HEAP32[$56>>2]|0;HEAP32[$56>>2] = (($57-1)|0);
   $58 = ($57|0)==(1);
   if (!($58)) {
    $59 = HEAP32[$39>>2]|0;
    $60 = (($59) + 1)|0;
    HEAP32[$39>>2] = $60;
    return;
   }
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($54,1,1);
   $59 = HEAP32[$39>>2]|0;
   $60 = (($59) + 1)|0;
   HEAP32[$39>>2] = $60;
   return;
  }
 } while(0);
 $61 = ___cxa_find_matching_catch_2()|0;
 $62 = tempRet0;
 if ($3) {
  ___resumeException($61|0);
  // unreachable;
 }
 $63 = ((($1)) + 8|0);
 $64 = HEAP32[$63>>2]|0;HEAP32[$63>>2] = (($64-1)|0);
 $65 = ($64|0)==(1);
 if (!($65)) {
  ___resumeException($61|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(3262,($1|0),1,1);
 $66 = __THREW__; __THREW__ = 0;
 $67 = $66&1;
 if ($67) {
  $68 = ___cxa_find_matching_catch_3(0|0)|0;
  $69 = tempRet0;
  ___clang_call_terminate($68);
  // unreachable;
 } else {
  ___resumeException($61|0);
  // unreachable;
 }
}
function __ZNSt3__26vectorIN3osg7ref_ptrINS1_8ViewportEEENS_9allocatorIS4_EEE21__push_back_slow_pathIKS4_EEvRT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$06$i$i = 0, $$pre = 0, $$pre$i = 0, $$pre38 = 0, $$pre39 = 0, $$sroa$7$0 = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(1073741823);
 $9 = $4;
 $10 = $3;
 if ($8) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $11 = ((($0)) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) - ($4))|0;
 $14 = $13 >> 2;
 $15 = ($14>>>0)<(536870911);
 $16 = $13 >> 1;
 $17 = ($16>>>0)<($7>>>0);
 $$sroa$speculated$i = $17 ? $7 : $16;
 $$sroa$speculated$$i = $15 ? $$sroa$speculated$i : 1073741823;
 $18 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($18) {
   $28 = 0;
  } else {
   $19 = ($$sroa$speculated$$i>>>0)>(1073741823);
   if (!($19)) {
    $25 = $$sroa$speculated$$i << 2;
    $26 = (__Znwj($25)|0);
    $28 = $26;
    break;
   }
   $20 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($20|0),(204840|0));
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if ($22) {
    $23 = ___cxa_find_matching_catch_2()|0;
    $24 = tempRet0;
    ___cxa_free_exception(($20|0));
    ___resumeException($23|0);
    // unreachable;
   } else {
    HEAP32[$20>>2] = (99824);
    ___cxa_throw(($20|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $27 = (($28) + ($6<<2)|0);
 $29 = $27;
 $30 = (($28) + ($$sroa$speculated$$i<<2)|0);
 $31 = $30;
 $32 = HEAP32[$1>>2]|0;
 HEAP32[$27>>2] = $32;
 $33 = ($32|0)==(0|0);
 if ($33) {
  $38 = $10;$40 = $9;
 } else {
  $34 = ((($32)) + 8|0);
  $35 = HEAP32[$34>>2]|0;HEAP32[$34>>2] = (($35+1)|0);
  $$pre = HEAP32[$0>>2]|0;
  $$pre38 = HEAP32[$2>>2]|0;
  $38 = $$pre38;$40 = $$pre;
 }
 $36 = ((($27)) + 4|0);
 $37 = $36;
 $39 = ($38|0)==($40|0);
 if ($39) {
  $41 = $38;
  $53 = $29;$54 = $41;$56 = $38;
 } else {
  $$06$i$i = $38;$$sroa$7$0 = $29;$44 = $27;
  while(1) {
   $42 = ((($$06$i$i)) + -4|0);
   $43 = ((($44)) + -4|0);
   $45 = HEAP32[$42>>2]|0;
   HEAP32[$43>>2] = $45;
   $46 = ($45|0)==(0|0);
   if (!($46)) {
    $47 = ((($45)) + 8|0);
    $48 = HEAP32[$47>>2]|0;HEAP32[$47>>2] = (($48+1)|0);
   }
   $49 = $$sroa$7$0;
   $50 = ((($49)) + -4|0);
   $51 = $50;
   $52 = ($42|0)==($40|0);
   if ($52) {
    break;
   } else {
    $$06$i$i = $42;$$sroa$7$0 = $51;$44 = $50;
   }
  }
  $$pre$i = HEAP32[$0>>2]|0;
  $$pre39 = HEAP32[$2>>2]|0;
  $53 = $51;$54 = $$pre$i;$56 = $$pre39;
 }
 HEAP32[$0>>2] = $53;
 HEAP32[$2>>2] = $37;
 HEAP32[$11>>2] = $31;
 $55 = $54;
 $57 = ($56|0)==($55|0);
 L25: do {
  if (!($57)) {
   $59 = $56;
   while(1) {
    $58 = ((($59)) + -4|0);
    $60 = HEAP32[$58>>2]|0;
    $61 = ($60|0)==(0|0);
    if (!($61)) {
     $62 = ((($60)) + 8|0);
     $63 = HEAP32[$62>>2]|0;HEAP32[$62>>2] = (($63-1)|0);
     $64 = ($63|0)==(1);
     if ($64) {
      __THREW__ = 0;
      invoke_viii(3262,($60|0),1,1);
      $65 = __THREW__; __THREW__ = 0;
      $66 = $65&1;
      if ($66) {
       break;
      }
     }
    }
    HEAP32[$58>>2] = 0;
    $67 = ($58|0)==($55|0);
    if ($67) {
     break L25;
    } else {
     $59 = $58;
    }
   }
   $68 = ___cxa_find_matching_catch_2()|0;
   $69 = tempRet0;
   ___cxa_call_unexpected(($68|0));
   // unreachable;
  }
 } while(0);
 $70 = ($54|0)==(0);
 if ($70) {
  return;
 }
 $71 = $54;
 __ZdlPv($71);
 return;
}
function __ZN3osg9CullStack11popViewportEv($0) {
 $0 = $0|0;
 var $$pre$i = 0, $$pre$i2 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 152|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if (!($3)) {
  $4 = ((($0)) + 140|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ((($0)) + 144|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($5|0)==($7|0);
  do {
   if ($8) {
    $37 = $2;
   } else {
    $9 = ((($0)) + 136|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = ((($7)) + -4|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ($10|0)==($12|0);
    if (!($13)) {
     HEAP32[$9>>2] = $12;
     $14 = ($12|0)==(0|0);
     if (!($14)) {
      $15 = ((($12)) + 8|0);
      $16 = HEAP32[$15>>2]|0;HEAP32[$15>>2] = (($16+1)|0);
     }
     $17 = ($10|0)==(0|0);
     if (!($17)) {
      $18 = ((($10)) + 8|0);
      $19 = HEAP32[$18>>2]|0;HEAP32[$18>>2] = (($19-1)|0);
      $20 = ($19|0)==(1);
      if ($20) {
       __ZNK3osg10Referenced24signalObserversAndDeleteEbb($10,1,1);
      }
     }
    }
    $21 = HEAP32[$6>>2]|0;
    $22 = ((($21)) + -4|0);
    $24 = $21;
    while(1) {
     $23 = ((($24)) + -4|0);
     HEAP32[$6>>2] = $23;
     $25 = HEAP32[$23>>2]|0;
     $26 = ($25|0)==(0|0);
     if (!($26)) {
      $27 = ((($25)) + 8|0);
      $28 = HEAP32[$27>>2]|0;HEAP32[$27>>2] = (($28-1)|0);
      $29 = ($28|0)==(1);
      if ($29) {
       __THREW__ = 0;
       invoke_viii(3262,($25|0),1,1);
       $30 = __THREW__; __THREW__ = 0;
       $31 = $30&1;
       if ($31) {
        label = 14;
        break;
       }
      }
     }
     HEAP32[$23>>2] = 0;
     $32 = HEAP32[$6>>2]|0;
     $33 = ($32|0)==($22|0);
     if ($33) {
      label = 15;
      break;
     } else {
      $24 = $32;
     }
    }
    if ((label|0) == 14) {
     $34 = ___cxa_find_matching_catch_2()|0;
     $35 = tempRet0;
     ___cxa_call_unexpected(($34|0));
     // unreachable;
    }
    else if ((label|0) == 15) {
     $$pre$i = HEAP32[$1>>2]|0;
     $37 = $$pre$i;
     break;
    }
   }
  } while(0);
  $36 = (($37) + -1)|0;
  HEAP32[$1>>2] = $36;
 }
 $38 = ((($0)) + 132|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = ($39|0)==(0);
 if ($40) {
  return;
 }
 $41 = ((($0)) + 120|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ((($0)) + 124|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = ($42|0)==($44|0);
 do {
  if ($45) {
   $74 = $39;
  } else {
   $46 = ((($0)) + 116|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = ((($44)) + -4|0);
   $49 = HEAP32[$48>>2]|0;
   $50 = ($47|0)==($49|0);
   if (!($50)) {
    HEAP32[$46>>2] = $49;
    $51 = ($49|0)==(0|0);
    if (!($51)) {
     $52 = ((($49)) + 8|0);
     $53 = HEAP32[$52>>2]|0;HEAP32[$52>>2] = (($53+1)|0);
    }
    $54 = ($47|0)==(0|0);
    if (!($54)) {
     $55 = ((($47)) + 8|0);
     $56 = HEAP32[$55>>2]|0;HEAP32[$55>>2] = (($56-1)|0);
     $57 = ($56|0)==(1);
     if ($57) {
      __ZNK3osg10Referenced24signalObserversAndDeleteEbb($47,1,1);
     }
    }
   }
   $58 = HEAP32[$43>>2]|0;
   $59 = ((($58)) + -4|0);
   $61 = $58;
   while(1) {
    $60 = ((($61)) + -4|0);
    HEAP32[$43>>2] = $60;
    $62 = HEAP32[$60>>2]|0;
    $63 = ($62|0)==(0|0);
    if (!($63)) {
     $64 = ((($62)) + 8|0);
     $65 = HEAP32[$64>>2]|0;HEAP32[$64>>2] = (($65-1)|0);
     $66 = ($65|0)==(1);
     if ($66) {
      __THREW__ = 0;
      invoke_viii(3262,($62|0),1,1);
      $67 = __THREW__; __THREW__ = 0;
      $68 = $67&1;
      if ($68) {
       label = 30;
       break;
      }
     }
    }
    HEAP32[$60>>2] = 0;
    $69 = HEAP32[$43>>2]|0;
    $70 = ($69|0)==($59|0);
    if ($70) {
     label = 31;
     break;
    } else {
     $61 = $69;
    }
   }
   if ((label|0) == 30) {
    $71 = ___cxa_find_matching_catch_2()|0;
    $72 = tempRet0;
    ___cxa_call_unexpected(($71|0));
    // unreachable;
   }
   else if ((label|0) == 31) {
    $$pre$i2 = HEAP32[$38>>2]|0;
    $74 = $$pre$i2;
    break;
   }
  }
 } while(0);
 $73 = (($74) + -1)|0;
 HEAP32[$38>>2] = $73;
 return;
}
function __ZN3osg9CullStack20pushProjectionMatrixEPNS_10RefMatrixdE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$011 = 0, $$pre$i$i = 0, $$sroa$018$028 = 0, $10 = 0, $100 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(112|0);
 $2 = sp;
 $3 = ((($0)) + 76|0);
 $4 = ($1|0)==(0|0);
 if (!($4)) {
  $5 = ((($1)) + 8|0);
  $6 = HEAP32[$5>>2]|0;HEAP32[$5>>2] = (($6+1)|0);
 }
 $7 = ((($0)) + 92|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0);
 do {
  if ($9) {
   label = 9;
  } else {
   $10 = ((($0)) + 84|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = ((($0)) + 88|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = ($11|0)==($13|0);
   if ($14) {
    $21 = ((($0)) + 80|0);
    __THREW__ = 0;
    invoke_vii(3636,($21|0),($3|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    } else {
     label = 9;
     break;
    }
   }
   $15 = HEAP32[$3>>2]|0;
   HEAP32[$11>>2] = $15;
   $16 = ($15|0)==(0|0);
   if ($16) {
    $20 = $11;
   } else {
    $17 = ((($15)) + 8|0);
    $18 = HEAP32[$17>>2]|0;HEAP32[$17>>2] = (($18+1)|0);
    $$pre$i$i = HEAP32[$10>>2]|0;
    $20 = $$pre$i$i;
   }
   $19 = ((($20)) + 4|0);
   HEAP32[$10>>2] = $19;
   label = 9;
  }
 } while(0);
 do {
  if ((label|0) == 9) {
   $24 = HEAP32[$3>>2]|0;
   $25 = ($24|0)==($1|0);
   if (!($25)) {
    HEAP32[$3>>2] = $1;
    if (!($4)) {
     $26 = ((($1)) + 8|0);
     $27 = HEAP32[$26>>2]|0;HEAP32[$26>>2] = (($27+1)|0);
    }
    $28 = ($24|0)==(0|0);
    if (!($28)) {
     $29 = ((($24)) + 8|0);
     $30 = HEAP32[$29>>2]|0;HEAP32[$29>>2] = (($30-1)|0);
     $31 = ($30|0)==(1);
     if ($31) {
      __THREW__ = 0;
      invoke_viii(3262,($24|0),1,1);
      $32 = __THREW__; __THREW__ = 0;
      $33 = $32&1;
      if ($33) {
       break;
      }
     }
    }
   }
   $34 = HEAP32[$7>>2]|0;
   $35 = (($34) + 1)|0;
   HEAP32[$7>>2] = $35;
   if (!($4)) {
    $36 = ((($1)) + 8|0);
    $37 = HEAP32[$36>>2]|0;HEAP32[$36>>2] = (($37-1)|0);
    $38 = ($37|0)==(1);
    if ($38) {
     __ZNK3osg10Referenced24signalObserversAndDeleteEbb($1,1,1);
    }
   }
   __ZN3osg10CullingSetC2Ev($2);
   $39 = ((($0)) + 256|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = ((($0)) + 260|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = ($40|0)==($42|0);
   if ($43) {
    $48 = ((($0)) + 252|0);
    __THREW__ = 0;
    invoke_vii(3738,($48|0),($2|0));
    $49 = __THREW__; __THREW__ = 0;
    $50 = $49&1;
    if ($50) {
     label = 29;
    }
   } else {
    __THREW__ = 0;
    invoke_vii(3737,($40|0),($2|0));
    $44 = __THREW__; __THREW__ = 0;
    $45 = $44&1;
    if ($45) {
     label = 29;
    } else {
     $46 = HEAP32[$39>>2]|0;
     $47 = ((($46)) + 108|0);
     HEAP32[$39>>2] = $47;
    }
   }
   if ((label|0) == 29) {
    $81 = ___cxa_find_matching_catch_2()|0;
    $82 = tempRet0;
    __THREW__ = 0;
    invoke_vi(1617,($2|0));
    $83 = __THREW__; __THREW__ = 0;
    $84 = $83&1;
    if ($84) {
     $99 = ___cxa_find_matching_catch_3(0|0)|0;
     $100 = tempRet0;
     ___clang_call_terminate($99);
     // unreachable;
    }
    $$0 = $81;$$011 = $82;
    ___resumeException($$0|0);
    // unreachable;
   }
   __ZN3osg10CullingSetD2Ev($2);
   $51 = HEAP32[$39>>2]|0;
   $52 = ((($51)) + -92|0);
   $53 = ((($0)) + 16|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = $54 & 2;
   $56 = ($55|0)!=(0);
   $57 = $54 & 4;
   $58 = ($57|0)!=(0);
   __ZN3osg8Polytope16setToUnitFrustumEbb($52,$56,$58);
   $59 = ((($1)) + 32|0);
   __ZN3osg8Polytope25transformProvidingInverseERKNS_7MatrixdE($52,$59);
   $60 = HEAP32[$53>>2]|0;
   $61 = ((($51)) + -96|0);
   HEAP32[$61>>2] = $60;
   $62 = ((($0)) + 24|0);
   $63 = HEAP32[$62>>2]|0;
   $64 = ((($51)) + -4|0);
   HEAP32[$64>>2] = $63;
   $65 = ((($0)) + 64|0);
   $66 = HEAP32[$65>>2]|0;
   $67 = ((($0)) + 68|0);
   $68 = HEAP32[$67>>2]|0;
   $69 = ($66|0)==($68|0);
   if ($69) {
    $73 = ((($0)) + 284|0);
    HEAPF32[$73>>2] = -1.0;
    __ZN3osg9CullStack14pushCullingSetEv($0);
    STACKTOP = sp;return;
   }
   $70 = ((($51)) + -28|0);
   $71 = ((($51)) + -24|0);
   $72 = ((($51)) + -32|0);
   $$sroa$018$028 = $66;
   while(1) {
    $85 = ((($$sroa$018$028)) + 16|0);
    $86 = HEAP32[$85>>2]|0;
    $87 = ($86|0)==(0|0);
    do {
     if (!($87)) {
      $88 = ((($86)) + 32|0);
      $89 = (__ZNK3osg7Matrixd7compareERKS0_($59,$88)|0);
      $90 = ($89|0)==(0);
      if ($90) {
       $91 = HEAP32[$70>>2]|0;
       $92 = HEAP32[$71>>2]|0;
       $93 = ($91|0)==($92|0);
       if ($93) {
        __ZNSt3__26vectorIN3osg20ShadowVolumeOccluderENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($72,$$sroa$018$028);
        break;
       } else {
        __ZN3osg20ShadowVolumeOccluderC2ERKS0_($91,$$sroa$018$028);
        $94 = HEAP32[$70>>2]|0;
        $95 = ((($94)) + 80|0);
        HEAP32[$70>>2] = $95;
        break;
       }
      }
     }
    } while(0);
    $96 = ((($$sroa$018$028)) + 80|0);
    $97 = HEAP32[$67>>2]|0;
    $98 = ($96|0)==($97|0);
    if ($98) {
     break;
    } else {
     $$sroa$018$028 = $96;
    }
   }
   $73 = ((($0)) + 284|0);
   HEAPF32[$73>>2] = -1.0;
   __ZN3osg9CullStack14pushCullingSetEv($0);
   STACKTOP = sp;return;
  }
 } while(0);
 $74 = ___cxa_find_matching_catch_2()|0;
 $75 = tempRet0;
 if (!($4)) {
  $76 = ((($1)) + 8|0);
  $77 = HEAP32[$76>>2]|0;HEAP32[$76>>2] = (($77-1)|0);
  $78 = ($77|0)==(1);
  if ($78) {
   __THREW__ = 0;
   invoke_viii(3262,($1|0),1,1);
   $79 = __THREW__; __THREW__ = 0;
   $80 = $79&1;
   if ($80) {
    $99 = ___cxa_find_matching_catch_3(0|0)|0;
    $100 = tempRet0;
    ___clang_call_terminate($99);
    // unreachable;
   }
  }
 }
 $$0 = $74;$$011 = $75;
 ___resumeException($$0|0);
 // unreachable;
}
function __ZN3osg8Polytope16setToUnitFrustumEbb($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$03$i = 0, $$pre = 0, $$pre10 = 0, $$pre11 = 0, $$pre7 = 0, $$pre8 = 0, $$pre9 = 0, $10 = 0, $100 = 0, $101 = 0.0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0.0, $121 = 0, $122 = 0.0, $123 = 0, $124 = 0.0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0.0, $144 = 0, $145 = 0.0, $146 = 0, $147 = 0.0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $19 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0.0, $29 = 0, $3 = 0, $30 = 0.0, $31 = 0, $32 = 0.0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0.0, $52 = 0, $53 = 0.0, $54 = 0, $55 = 0.0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0.0;
 var $75 = 0, $76 = 0.0, $77 = 0, $78 = 0.0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0.0, $98 = 0, $99 = 0.0, $scevgep$i$i$i = 0, $scevgep5$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 240|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(240|0);
 $3 = sp + 200|0;
 $4 = sp + 160|0;
 $5 = sp + 120|0;
 $6 = sp + 80|0;
 $7 = sp + 40|0;
 $8 = sp;
 $9 = ((($0)) + 24|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ((($0)) + 28|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==($10|0);
 if ($13) {
  $25 = $10;
 } else {
  $scevgep$i$i$i = ((($12)) + -40|0);
  $14 = $scevgep$i$i$i;
  $15 = $10;
  $16 = (($14) - ($15))|0;
  $17 = (($16>>>0) / 40)&-1;
  $18 = $17 ^ -1;
  $scevgep5$i$i$i = (($12) + (($18*40)|0)|0);
  HEAP32[$11>>2] = $scevgep5$i$i$i;
  $25 = $scevgep5$i$i$i;
 }
 HEAPF64[$3>>3] = 1.0;
 $19 = ((($3)) + 8|0);
 $20 = ((($3)) + 24|0);
 ;HEAP32[$19>>2]=0|0;HEAP32[$19+4>>2]=0|0;HEAP32[$19+8>>2]=0|0;HEAP32[$19+12>>2]=0|0;
 HEAPF64[$20>>3] = 1.0;
 $21 = ((($3)) + 32|0);
 HEAP32[$21>>2] = 7;
 $22 = ((($3)) + 36|0);
 HEAP32[$22>>2] = 0;
 $23 = ((($0)) + 32|0);
 $24 = HEAP32[$23>>2]|0;
 $26 = ($25|0)==($24|0);
 if ($26) {
  __ZNSt3__26vectorIN3osg5PlaneENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($9,$3);
  $$pre = HEAP32[$11>>2]|0;
  $$pre7 = HEAP32[$23>>2]|0;
  $47 = $$pre;$49 = $$pre7;
 } else {
  $27 = ((($3)) + 16|0);
  HEAPF64[$25>>3] = 1.0;
  $28 = +HEAPF64[$19>>3];
  $29 = ((($25)) + 8|0);
  HEAPF64[$29>>3] = $28;
  $30 = +HEAPF64[$27>>3];
  $31 = ((($25)) + 16|0);
  HEAPF64[$31>>3] = $30;
  $32 = +HEAPF64[$20>>3];
  $33 = ((($25)) + 24|0);
  HEAPF64[$33>>3] = $32;
  $34 = $28 >= 0.0;
  $35 = $34 ? 3 : 1;
  $36 = $30 >= 0.0;
  $37 = $36 ? 4 : 0;
  $38 = $35 | $37;
  $39 = ((($25)) + 32|0);
  HEAP32[$39>>2] = $38;
  $40 = $38 ^ 7;
  $41 = ((($25)) + 36|0);
  HEAP32[$41>>2] = $40;
  $42 = ((($25)) + 40|0);
  HEAP32[$11>>2] = $42;
  $47 = $42;$49 = $24;
 }
 HEAPF64[$4>>3] = -1.0;
 $43 = ((($4)) + 8|0);
 $44 = ((($4)) + 24|0);
 ;HEAP32[$43>>2]=0|0;HEAP32[$43+4>>2]=0|0;HEAP32[$43+8>>2]=0|0;HEAP32[$43+12>>2]=0|0;
 HEAPF64[$44>>3] = 1.0;
 $45 = ((($4)) + 32|0);
 HEAP32[$45>>2] = 6;
 $46 = ((($4)) + 36|0);
 HEAP32[$46>>2] = 1;
 $48 = ($47|0)==($49|0);
 if ($48) {
  __ZNSt3__26vectorIN3osg5PlaneENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($9,$4);
  $$pre8 = HEAP32[$11>>2]|0;
  $$pre9 = HEAP32[$23>>2]|0;
  $71 = $$pre8;$73 = $$pre9;
 } else {
  $50 = ((($4)) + 16|0);
  HEAPF64[$47>>3] = -1.0;
  $51 = +HEAPF64[$43>>3];
  $52 = ((($47)) + 8|0);
  HEAPF64[$52>>3] = $51;
  $53 = +HEAPF64[$50>>3];
  $54 = ((($47)) + 16|0);
  HEAPF64[$54>>3] = $53;
  $55 = +HEAPF64[$44>>3];
  $56 = ((($47)) + 24|0);
  HEAPF64[$56>>3] = $55;
  $57 = $51 >= 0.0;
  $58 = $57 ? 2 : 0;
  $59 = $53 >= 0.0;
  $60 = $59 ? 4 : 0;
  $61 = $58 | $60;
  $62 = ((($47)) + 32|0);
  HEAP32[$62>>2] = $61;
  $63 = $61 ^ 7;
  $64 = ((($47)) + 36|0);
  HEAP32[$64>>2] = $63;
  $65 = ((($47)) + 40|0);
  HEAP32[$11>>2] = $65;
  $71 = $65;$73 = $49;
 }
 HEAPF64[$5>>3] = 0.0;
 $66 = ((($5)) + 8|0);
 HEAPF64[$66>>3] = 1.0;
 $67 = ((($5)) + 16|0);
 HEAPF64[$67>>3] = 0.0;
 $68 = ((($5)) + 24|0);
 HEAPF64[$68>>3] = 1.0;
 $69 = ((($5)) + 32|0);
 HEAP32[$69>>2] = 7;
 $70 = ((($5)) + 36|0);
 HEAP32[$70>>2] = 0;
 $72 = ($71|0)==($73|0);
 if ($72) {
  __ZNSt3__26vectorIN3osg5PlaneENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($9,$5);
  $$pre10 = HEAP32[$11>>2]|0;
  $$pre11 = HEAP32[$23>>2]|0;
  $94 = $$pre10;$96 = $$pre11;
 } else {
  HEAPF64[$71>>3] = 0.0;
  $74 = +HEAPF64[$66>>3];
  $75 = ((($71)) + 8|0);
  HEAPF64[$75>>3] = $74;
  $76 = +HEAPF64[$67>>3];
  $77 = ((($71)) + 16|0);
  HEAPF64[$77>>3] = $76;
  $78 = +HEAPF64[$68>>3];
  $79 = ((($71)) + 24|0);
  HEAPF64[$79>>3] = $78;
  $80 = $74 >= 0.0;
  $81 = $80 ? 3 : 1;
  $82 = $76 >= 0.0;
  $83 = $82 ? 4 : 0;
  $84 = $81 | $83;
  $85 = ((($71)) + 32|0);
  HEAP32[$85>>2] = $84;
  $86 = $84 ^ 7;
  $87 = ((($71)) + 36|0);
  HEAP32[$87>>2] = $86;
  $88 = ((($71)) + 40|0);
  HEAP32[$11>>2] = $88;
  $94 = $88;$96 = $73;
 }
 HEAPF64[$6>>3] = 0.0;
 $89 = ((($6)) + 8|0);
 HEAPF64[$89>>3] = -1.0;
 $90 = ((($6)) + 16|0);
 HEAPF64[$90>>3] = 0.0;
 $91 = ((($6)) + 24|0);
 HEAPF64[$91>>3] = 1.0;
 $92 = ((($6)) + 32|0);
 HEAP32[$92>>2] = 5;
 $93 = ((($6)) + 36|0);
 HEAP32[$93>>2] = 2;
 $95 = ($94|0)==($96|0);
 if ($95) {
  __ZNSt3__26vectorIN3osg5PlaneENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($9,$6);
 } else {
  HEAPF64[$94>>3] = 0.0;
  $97 = +HEAPF64[$89>>3];
  $98 = ((($94)) + 8|0);
  HEAPF64[$98>>3] = $97;
  $99 = +HEAPF64[$90>>3];
  $100 = ((($94)) + 16|0);
  HEAPF64[$100>>3] = $99;
  $101 = +HEAPF64[$91>>3];
  $102 = ((($94)) + 24|0);
  HEAPF64[$102>>3] = $101;
  $103 = $97 >= 0.0;
  $104 = $103 ? 3 : 1;
  $105 = $99 >= 0.0;
  $106 = $105 ? 4 : 0;
  $107 = $104 | $106;
  $108 = ((($94)) + 32|0);
  HEAP32[$108>>2] = $107;
  $109 = $107 ^ 7;
  $110 = ((($94)) + 36|0);
  HEAP32[$110>>2] = $109;
  $111 = ((($94)) + 40|0);
  HEAP32[$11>>2] = $111;
 }
 if ($1) {
  $112 = ((($7)) + 16|0);
  ;HEAP32[$7>>2]=0|0;HEAP32[$7+4>>2]=0|0;HEAP32[$7+8>>2]=0|0;HEAP32[$7+12>>2]=0|0;
  HEAPF64[$112>>3] = 1.0;
  $113 = ((($7)) + 24|0);
  HEAPF64[$113>>3] = 1.0;
  $114 = ((($7)) + 32|0);
  HEAP32[$114>>2] = 7;
  $115 = ((($7)) + 36|0);
  HEAP32[$115>>2] = 0;
  $116 = HEAP32[$11>>2]|0;
  $117 = HEAP32[$23>>2]|0;
  $118 = ($116|0)==($117|0);
  if ($118) {
   __ZNSt3__26vectorIN3osg5PlaneENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($9,$7);
  } else {
   $119 = ((($7)) + 8|0);
   HEAPF64[$116>>3] = 0.0;
   $120 = +HEAPF64[$119>>3];
   $121 = ((($116)) + 8|0);
   HEAPF64[$121>>3] = $120;
   $122 = +HEAPF64[$112>>3];
   $123 = ((($116)) + 16|0);
   HEAPF64[$123>>3] = $122;
   $124 = +HEAPF64[$113>>3];
   $125 = ((($116)) + 24|0);
   HEAPF64[$125>>3] = $124;
   $126 = $120 >= 0.0;
   $127 = $126 ? 3 : 1;
   $128 = $122 >= 0.0;
   $129 = $128 ? 4 : 0;
   $130 = $127 | $129;
   $131 = ((($116)) + 32|0);
   HEAP32[$131>>2] = $130;
   $132 = $130 ^ 7;
   $133 = ((($116)) + 36|0);
   HEAP32[$133>>2] = $132;
   $134 = ((($116)) + 40|0);
   HEAP32[$11>>2] = $134;
  }
 }
 if ($2) {
  $135 = ((($8)) + 16|0);
  ;HEAP32[$8>>2]=0|0;HEAP32[$8+4>>2]=0|0;HEAP32[$8+8>>2]=0|0;HEAP32[$8+12>>2]=0|0;
  HEAPF64[$135>>3] = -1.0;
  $136 = ((($8)) + 24|0);
  HEAPF64[$136>>3] = 1.0;
  $137 = ((($8)) + 32|0);
  HEAP32[$137>>2] = 3;
  $138 = ((($8)) + 36|0);
  HEAP32[$138>>2] = 4;
  $139 = HEAP32[$11>>2]|0;
  $140 = HEAP32[$23>>2]|0;
  $141 = ($139|0)==($140|0);
  if ($141) {
   __ZNSt3__26vectorIN3osg5PlaneENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($9,$8);
  } else {
   $142 = ((($8)) + 8|0);
   HEAPF64[$139>>3] = 0.0;
   $143 = +HEAPF64[$142>>3];
   $144 = ((($139)) + 8|0);
   HEAPF64[$144>>3] = $143;
   $145 = +HEAPF64[$135>>3];
   $146 = ((($139)) + 16|0);
   HEAPF64[$146>>3] = $145;
   $147 = +HEAPF64[$136>>3];
   $148 = ((($139)) + 24|0);
   HEAPF64[$148>>3] = $147;
   $149 = $143 >= 0.0;
   $150 = $149 ? 3 : 1;
   $151 = $145 >= 0.0;
   $152 = $151 ? 4 : 0;
   $153 = $150 | $152;
   $154 = ((($139)) + 32|0);
   HEAP32[$154>>2] = $153;
   $155 = $153 ^ 7;
   $156 = ((($139)) + 36|0);
   HEAP32[$156>>2] = $155;
   $157 = ((($139)) + 40|0);
   HEAP32[$11>>2] = $157;
  }
 }
 $158 = ((($0)) + 20|0);
 HEAP32[$158>>2] = 0;
 $159 = HEAP32[$11>>2]|0;
 $160 = HEAP32[$9>>2]|0;
 $161 = ($159|0)==($160|0);
 if (!($161)) {
  $162 = (($159) - ($160))|0;
  $163 = (($162|0) / 40)&-1;
  $$03$i = 0;$177 = 0;
  while(1) {
   $176 = $177 << 1;
   $164 = $176 | 1;
   $178 = (($$03$i) + 1)|0;
   $179 = ($178>>>0)<($163>>>0);
   if ($179) {
    $$03$i = $178;$177 = $164;
   } else {
    break;
   }
  }
  HEAP32[$158>>2] = $164;
 }
 $165 = ((($0)) + 16|0);
 $166 = HEAP32[$165>>2]|0;
 $167 = ($166|0)==(0);
 if ($167) {
  $180 = HEAP32[$158>>2]|0;
  HEAP32[$0>>2] = $180;
  $181 = HEAP32[$165>>2]|0;
  $182 = (($181) + 1)|0;
  HEAP32[$165>>2] = $182;
  STACKTOP = sp;return;
 }
 $168 = ((($0)) + 8|0);
 $169 = HEAP32[$168>>2]|0;
 $170 = ((($0)) + 12|0);
 $171 = HEAP32[$170>>2]|0;
 $172 = ($169|0)==($171|0);
 if ($172) {
  $175 = ((($0)) + 4|0);
  __ZNSt3__26vectorIjNS_9allocatorIjEEE21__push_back_slow_pathIKjEEvRT_($175,$0);
  $180 = HEAP32[$158>>2]|0;
  HEAP32[$0>>2] = $180;
  $181 = HEAP32[$165>>2]|0;
  $182 = (($181) + 1)|0;
  HEAP32[$165>>2] = $182;
  STACKTOP = sp;return;
 } else {
  $173 = HEAP32[$0>>2]|0;
  HEAP32[$169>>2] = $173;
  $174 = ((($169)) + 4|0);
  HEAP32[$168>>2] = $174;
  $180 = HEAP32[$158>>2]|0;
  HEAP32[$0>>2] = $180;
  $181 = HEAP32[$165>>2]|0;
  $182 = (($181) + 1)|0;
  HEAP32[$165>>2] = $182;
  STACKTOP = sp;return;
 }
}
function __ZN3osg9CullStack19popProjectionMatrixEv($0) {
 $0 = $0|0;
 var $$pre$i = 0, $$pre$i1 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 92|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if (!($3)) {
  $4 = ((($0)) + 80|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ((($0)) + 84|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($5|0)==($7|0);
  do {
   if ($8) {
    $37 = $2;
   } else {
    $9 = ((($0)) + 76|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = ((($7)) + -4|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ($10|0)==($12|0);
    if (!($13)) {
     HEAP32[$9>>2] = $12;
     $14 = ($12|0)==(0|0);
     if (!($14)) {
      $15 = ((($12)) + 8|0);
      $16 = HEAP32[$15>>2]|0;HEAP32[$15>>2] = (($16+1)|0);
     }
     $17 = ($10|0)==(0|0);
     if (!($17)) {
      $18 = ((($10)) + 8|0);
      $19 = HEAP32[$18>>2]|0;HEAP32[$18>>2] = (($19-1)|0);
      $20 = ($19|0)==(1);
      if ($20) {
       __ZNK3osg10Referenced24signalObserversAndDeleteEbb($10,1,1);
      }
     }
    }
    $21 = HEAP32[$6>>2]|0;
    $22 = ((($21)) + -4|0);
    $24 = $21;
    while(1) {
     $23 = ((($24)) + -4|0);
     HEAP32[$6>>2] = $23;
     $25 = HEAP32[$23>>2]|0;
     $26 = ($25|0)==(0|0);
     if (!($26)) {
      $27 = ((($25)) + 8|0);
      $28 = HEAP32[$27>>2]|0;HEAP32[$27>>2] = (($28-1)|0);
      $29 = ($28|0)==(1);
      if ($29) {
       __THREW__ = 0;
       invoke_viii(3262,($25|0),1,1);
       $30 = __THREW__; __THREW__ = 0;
       $31 = $30&1;
       if ($31) {
        label = 14;
        break;
       }
      }
     }
     HEAP32[$23>>2] = 0;
     $32 = HEAP32[$6>>2]|0;
     $33 = ($32|0)==($22|0);
     if ($33) {
      label = 15;
      break;
     } else {
      $24 = $32;
     }
    }
    if ((label|0) == 14) {
     $34 = ___cxa_find_matching_catch_2()|0;
     $35 = tempRet0;
     ___cxa_call_unexpected(($34|0));
     // unreachable;
    }
    else if ((label|0) == 15) {
     $$pre$i = HEAP32[$1>>2]|0;
     $37 = $$pre$i;
     break;
    }
   }
  } while(0);
  $36 = (($37) + -1)|0;
  HEAP32[$1>>2] = $36;
 }
 $38 = ((($0)) + 256|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = ((($39)) + -108|0);
 $42 = $39;
 while(1) {
  $41 = ((($42)) + -108|0);
  HEAP32[$38>>2] = $41;
  $43 = HEAP32[$41>>2]|0;
  $44 = ((($43)) + 4|0);
  $45 = HEAP32[$44>>2]|0;
  __THREW__ = 0;
  invoke_vi($45|0,($41|0));
  $46 = __THREW__; __THREW__ = 0;
  $47 = $46&1;
  if ($47) {
   label = 20;
   break;
  }
  $$pre$i1 = HEAP32[$38>>2]|0;
  $48 = ($$pre$i1|0)==($40|0);
  if ($48) {
   label = 21;
   break;
  } else {
   $42 = $$pre$i1;
  }
 }
 if ((label|0) == 20) {
  $49 = ___cxa_find_matching_catch_2()|0;
  $50 = tempRet0;
  ___cxa_call_unexpected(($49|0));
  // unreachable;
 }
 else if ((label|0) == 21) {
  $51 = ((($0)) + 284|0);
  HEAPF32[$51>>2] = -1.0;
  __ZN3osg9CullStack13popCullingSetEv($0);
  return;
 }
}
function __ZN3osg9CullStack19pushModelViewMatrixEPNS_10RefMatrixdENS_9Transform14ReferenceFrameE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$2 = 0, $$212 = 0, $$3 = 0, $$313 = 0, $$pre = 0, $$pre$i$i = 0, $$sink = 0, $$sroa$0107$0$$sroa_idx = 0, $$sroa$0118$0$$sroa_idx = 0, $$sroa$0132$0$$sroa_idx = 0, $$sroa$044$0$$sroa_idx = 0, $$sroa$065$0 = 0.0, $$sroa$065$0$$sroa_idx = 0, $$sroa$065$0$copyload = 0.0, $$sroa$082$0$$sroa_idx = 0, $$sroa$093$0$$sroa_idx = 0, $$sroa$5$0$$sroa_idx49 = 0, $$sroa$5110$0$$sroa_idx113 = 0, $$sroa$5121$0$$sroa_idx124 = 0, $$sroa$5135$0$$sroa_idx138 = 0;
 var $$sroa$585$0$$sroa_idx88 = 0, $$sroa$596$0$$sroa_idx99 = 0, $$sroa$6100$0$$sroa_idx103 = 0, $$sroa$6114$0$$sroa_idx117 = 0, $$sroa$6125$0$$sroa_idx128 = 0, $$sroa$6139$0$$sroa_idx142 = 0, $$sroa$650$0$$sroa_idx53 = 0, $$sroa$689$0$$sroa_idx92 = 0, $$sroa$7$0 = 0.0, $$sroa$7$0$$sroa_idx70 = 0, $$sroa$7$0$copyload = 0.0, $$sroa$9$0 = 0.0, $$sroa$9$0$$sroa_idx75 = 0, $$sroa$9$0$copyload = 0.0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0.0, $115 = 0.0, $116 = 0.0, $117 = 0.0, $118 = 0, $119 = 0.0, $12 = 0, $120 = 0, $121 = 0.0, $122 = 0.0;
 var $123 = 0.0, $124 = 0.0, $125 = 0, $126 = 0.0, $127 = 0, $128 = 0.0, $129 = 0.0, $13 = 0, $130 = 0.0, $131 = 0.0, $132 = 0, $133 = 0.0, $134 = 0.0, $135 = 0.0, $136 = 0.0, $137 = 0.0, $138 = 0, $139 = 0.0, $14 = 0, $140 = 0.0;
 var $141 = 0.0, $142 = 0, $143 = 0.0, $144 = 0.0, $145 = 0.0, $146 = 0.0, $147 = 0.0, $148 = 0.0, $149 = 0.0, $15 = 0, $150 = 0, $151 = 0.0, $152 = 0.0, $153 = 0, $154 = 0.0, $155 = 0.0, $156 = 0.0, $157 = 0, $158 = 0.0, $159 = 0.0;
 var $16 = 0, $160 = 0.0, $161 = 0.0, $162 = 0.0, $163 = 0.0, $164 = 0.0, $165 = 0, $166 = 0.0, $167 = 0.0, $168 = 0, $169 = 0.0, $17 = 0, $170 = 0.0, $171 = 0.0, $172 = 0, $173 = 0.0, $174 = 0.0, $175 = 0.0, $176 = 0.0, $177 = 0.0;
 var $178 = 0.0, $179 = 0.0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0;
 var $196 = 0, $197 = 0, $198 = 0, $199 = 0.0, $20 = 0, $200 = 0, $201 = 0.0, $202 = 0, $203 = 0.0, $204 = 0.0, $205 = 0.0, $206 = 0.0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0;
 var $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0;
 var $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0;
 var $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0.0, $259 = 0, $26 = 0, $260 = 0.0, $261 = 0, $262 = 0.0, $263 = 0.0, $264 = 0.0, $265 = 0.0, $266 = 0, $267 = 0, $268 = 0;
 var $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0;
 var $287 = 0.0, $288 = 0, $289 = 0, $29 = 0, $290 = 0.0, $291 = 0, $292 = 0, $293 = 0.0, $294 = 0, $295 = 0, $296 = 0.0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0;
 var $304 = 0, $305 = 0.0, $306 = 0.0, $307 = 0.0, $308 = 0, $309 = 0.0, $31 = 0, $310 = 0.0, $311 = 0.0, $312 = 0.0, $313 = 0, $314 = 0.0, $315 = 0.0, $316 = 0.0, $317 = 0.0, $318 = 0, $319 = 0.0, $32 = 0, $320 = 0.0, $321 = 0.0;
 var $322 = 0.0, $323 = 0.0, $324 = 0, $325 = 0.0, $326 = 0.0, $327 = 0.0, $328 = 0, $329 = 0.0, $33 = 0, $330 = 0.0, $331 = 0.0, $332 = 0, $333 = 0.0, $334 = 0.0, $335 = 0.0, $336 = 0.0, $337 = 0, $338 = 0.0, $339 = 0.0, $34 = 0;
 var $340 = 0, $341 = 0.0, $342 = 0.0, $343 = 0.0, $344 = 0, $345 = 0.0, $346 = 0.0, $347 = 0.0, $348 = 0, $349 = 0.0, $35 = 0, $350 = 0.0, $351 = 0.0, $352 = 0.0, $353 = 0, $354 = 0.0, $355 = 0.0, $356 = 0, $357 = 0.0, $358 = 0.0;
 var $359 = 0.0, $36 = 0, $360 = 0, $361 = 0.0, $362 = 0.0, $363 = 0.0, $364 = 0, $365 = 0.0, $366 = 0.0, $367 = 0.0, $368 = 0.0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0;
 var $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0.0, $394 = 0.0;
 var $395 = 0.0, $396 = 0, $397 = 0.0, $398 = 0.0, $399 = 0.0, $4 = 0, $40 = 0, $400 = 0.0, $401 = 0, $402 = 0.0, $403 = 0.0, $404 = 0.0, $405 = 0.0, $406 = 0, $407 = 0.0, $408 = 0.0, $409 = 0.0, $41 = 0, $410 = 0.0, $411 = 0.0;
 var $412 = 0, $413 = 0.0, $414 = 0.0, $415 = 0.0, $416 = 0, $417 = 0.0, $418 = 0.0, $419 = 0.0, $42 = 0, $420 = 0.0, $421 = 0.0, $422 = 0.0, $423 = 0.0, $424 = 0, $425 = 0.0, $426 = 0.0, $427 = 0, $428 = 0.0, $429 = 0.0, $43 = 0;
 var $430 = 0.0, $431 = 0, $432 = 0.0, $433 = 0.0, $434 = 0.0, $435 = 0.0, $436 = 0.0, $437 = 0.0, $438 = 0.0, $439 = 0, $44 = 0, $440 = 0.0, $441 = 0.0, $442 = 0, $443 = 0.0, $444 = 0.0, $445 = 0.0, $446 = 0, $447 = 0.0, $448 = 0.0;
 var $449 = 0.0, $45 = 0, $450 = 0.0, $451 = 0.0, $452 = 0.0, $453 = 0.0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0.0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0;
 var $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0.0, $475 = 0.0, $476 = 0, $477 = 0.0, $478 = 0.0, $479 = 0, $48 = 0, $480 = 0.0, $481 = 0.0, $482 = 0, $483 = 0, $484 = 0;
 var $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0.0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0.0, $53 = 0, $54 = 0, $55 = 0.0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0.0, $73 = 0, $74 = 0.0, $75 = 0;
 var $76 = 0.0, $77 = 0.0, $78 = 0.0, $79 = 0.0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 256|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(256|0);
 $3 = sp + 128|0;
 $4 = sp;
 $5 = ((($0)) + 96|0);
 $6 = ((($0)) + 112|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0);
 if ($8) {
  $281 = 0;
 } else {
  $9 = HEAP32[$5>>2]|0;
  $281 = $9;
 }
 $10 = ($1|0)==(0|0);
 if ($10) {
  $13 = $7;
 } else {
  $11 = ((($1)) + 8|0);
  $12 = HEAP32[$11>>2]|0;HEAP32[$11>>2] = (($12+1)|0);
  $$pre = HEAP32[$6>>2]|0;
  $13 = $$pre;
 }
 $14 = ($13|0)==(0);
 do {
  if ($14) {
   label = 11;
  } else {
   $15 = ((($0)) + 104|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ((($0)) + 108|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = ($16|0)==($18|0);
   if ($19) {
    $26 = ((($0)) + 100|0);
    __THREW__ = 0;
    invoke_vii(3636,($26|0),($5|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    } else {
     label = 11;
     break;
    }
   }
   $20 = HEAP32[$5>>2]|0;
   HEAP32[$16>>2] = $20;
   $21 = ($20|0)==(0|0);
   if ($21) {
    $25 = $16;
   } else {
    $22 = ((($20)) + 8|0);
    $23 = HEAP32[$22>>2]|0;HEAP32[$22>>2] = (($23+1)|0);
    $$pre$i$i = HEAP32[$15>>2]|0;
    $25 = $$pre$i$i;
   }
   $24 = ((($25)) + 4|0);
   HEAP32[$15>>2] = $24;
   label = 11;
  }
 } while(0);
 do {
  if ((label|0) == 11) {
   $29 = HEAP32[$5>>2]|0;
   $30 = ($29|0)==($1|0);
   if (!($30)) {
    HEAP32[$5>>2] = $1;
    if (!($10)) {
     $31 = ((($1)) + 8|0);
     $32 = HEAP32[$31>>2]|0;HEAP32[$31>>2] = (($32+1)|0);
    }
    $33 = ($29|0)==(0|0);
    if (!($33)) {
     $34 = ((($29)) + 8|0);
     $35 = HEAP32[$34>>2]|0;HEAP32[$34>>2] = (($35-1)|0);
     $36 = ($35|0)==(1);
     if ($36) {
      __THREW__ = 0;
      invoke_viii(3262,($29|0),1,1);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
     }
    }
   }
   $39 = HEAP32[$6>>2]|0;
   $40 = (($39) + 1)|0;
   HEAP32[$6>>2] = $40;
   if (!($10)) {
    $41 = ((($1)) + 8|0);
    $42 = HEAP32[$41>>2]|0;HEAP32[$41>>2] = (($42-1)|0);
    $43 = ($42|0)==(1);
    if ($43) {
     __ZNK3osg10Referenced24signalObserversAndDeleteEbb($1,1,1);
    }
   }
   __ZN3osg9CullStack14pushCullingSetEv($0);
   __ZN3osg7Matrixd12makeIdentityEv($3);
   $44 = ((($1)) + 32|0);
   $45 = ((($1)) + 56|0);
   $46 = +HEAPF64[$45>>3];
   $47 = $46 == 0.0;
   if ($47) {
    $48 = ((($1)) + 88|0);
    $49 = +HEAPF64[$48>>3];
    $50 = $49 == 0.0;
    if ($50) {
     $51 = ((($1)) + 120|0);
     $52 = +HEAPF64[$51>>3];
     $53 = $52 == 0.0;
     if ($53) {
      $54 = ((($1)) + 152|0);
      $55 = +HEAPF64[$54>>3];
      $56 = $55 == 1.0;
      if ($56) {
       __THREW__ = 0;
       (invoke_iii(3303,($3|0),($44|0))|0);
       $57 = __THREW__; __THREW__ = 0;
       $58 = $57&1;
       if ($58) {
        label = 31;
       } else {
        label = 26;
       }
      } else {
       label = 25;
      }
     } else {
      label = 25;
     }
    } else {
     label = 25;
    }
   } else {
    label = 25;
   }
   if ((label|0) == 25) {
    __THREW__ = 0;
    (invoke_iii(3304,($3|0),($44|0))|0);
    $59 = __THREW__; __THREW__ = 0;
    $60 = $59&1;
    if ($60) {
     label = 31;
    } else {
     label = 26;
    }
   }
   L36: do {
    if ((label|0) == 26) {
     L38: do {
      switch ($2|0) {
      case 0:  {
       $70 = ((($0)) + 184|0);
       $71 = ((($3)) + 96|0);
       $72 = +HEAPF64[$71>>3];
       $73 = ((($3)) + 104|0);
       $74 = +HEAPF64[$73>>3];
       $75 = ((($3)) + 112|0);
       $76 = +HEAPF64[$75>>3];
       $77 = $72;
       $78 = $74;
       $79 = $76;
       $80 = ((($0)) + 208|0);
       $81 = HEAP32[$80>>2]|0;
       $82 = ($81|0)==(0);
       do {
        if (!($82)) {
         $83 = ((($0)) + 200|0);
         $84 = HEAP32[$83>>2]|0;
         $85 = ((($0)) + 204|0);
         $86 = HEAP32[$85>>2]|0;
         $87 = ($84|0)==($86|0);
         if (!($87)) {
          ;HEAP32[$84>>2]=HEAP32[$70>>2]|0;HEAP32[$84+4>>2]=HEAP32[$70+4>>2]|0;HEAP32[$84+8>>2]=HEAP32[$70+8>>2]|0;
          $88 = HEAP32[$83>>2]|0;
          $89 = ((($88)) + 12|0);
          HEAP32[$83>>2] = $89;
          break;
         }
         $90 = ((($0)) + 196|0);
         __THREW__ = 0;
         invoke_vii(3736,($90|0),($70|0));
         $91 = __THREW__; __THREW__ = 0;
         $92 = $91&1;
         if ($92) {
          $193 = ___cxa_find_matching_catch_2()|0;
          $194 = tempRet0;
          $$2 = $194;$$212 = $193;
          break L36;
         }
        }
       } while(0);
       $$sroa$0132$0$$sroa_idx = ((($0)) + 184|0);
       HEAPF32[$$sroa$0132$0$$sroa_idx>>2] = $77;
       $$sroa$5135$0$$sroa_idx138 = ((($0)) + 188|0);
       HEAPF32[$$sroa$5135$0$$sroa_idx138>>2] = $78;
       $$sroa$6139$0$$sroa_idx142 = ((($0)) + 192|0);
       HEAPF32[$$sroa$6139$0$$sroa_idx142>>2] = $79;
       $93 = HEAP32[$80>>2]|0;
       $94 = (($93) + 1)|0;
       HEAP32[$80>>2] = $94;
       $95 = ((($0)) + 156|0);
       $96 = ((($0)) + 156|0);
       $97 = ((($0)) + 180|0);
       $98 = HEAP32[$97>>2]|0;
       $99 = ($98|0)==(0);
       do {
        if (!($99)) {
         $100 = ((($0)) + 172|0);
         $101 = HEAP32[$100>>2]|0;
         $102 = ((($0)) + 176|0);
         $103 = HEAP32[$102>>2]|0;
         $104 = ($101|0)==($103|0);
         if ($104) {
          $107 = ((($0)) + 168|0);
          __THREW__ = 0;
          invoke_vii(3736,($107|0),($96|0));
          $108 = __THREW__; __THREW__ = 0;
          $109 = $108&1;
          if ($109) {
           label = 31;
           break L36;
          } else {
           break;
          }
         } else {
          ;HEAP32[$101>>2]=HEAP32[$96>>2]|0;HEAP32[$101+4>>2]=HEAP32[$96+4>>2]|0;HEAP32[$101+8>>2]=HEAP32[$96+8>>2]|0;
          $105 = HEAP32[$100>>2]|0;
          $106 = ((($105)) + 12|0);
          HEAP32[$100>>2] = $106;
          break;
         }
        }
       } while(0);
       ;HEAP32[$96>>2]=HEAP32[$95>>2]|0;HEAP32[$96+4>>2]=HEAP32[$95+4>>2]|0;HEAP32[$96+8>>2]=HEAP32[$95+8>>2]|0;
       $110 = HEAP32[$97>>2]|0;
       $111 = (($110) + 1)|0;
       HEAP32[$97>>2] = $111;
       $112 = ((($0)) + 212|0);
       $113 = ((($3)) + 24|0);
       $114 = +HEAPF64[$113>>3];
       $115 = +HEAPF32[$95>>2];
       $116 = $115;
       $117 = $114 * $116;
       $118 = ((($3)) + 56|0);
       $119 = +HEAPF64[$118>>3];
       $120 = ((($0)) + 160|0);
       $121 = +HEAPF32[$120>>2];
       $122 = $121;
       $123 = $119 * $122;
       $124 = $117 + $123;
       $125 = ((($3)) + 88|0);
       $126 = +HEAPF64[$125>>3];
       $127 = ((($0)) + 164|0);
       $128 = +HEAPF32[$127>>2];
       $129 = $128;
       $130 = $126 * $129;
       $131 = $124 + $130;
       $132 = ((($3)) + 120|0);
       $133 = +HEAPF64[$132>>3];
       $134 = $133 + $131;
       $135 = 1.0 / $134;
       $136 = +HEAPF64[$3>>3];
       $137 = $116 * $136;
       $138 = ((($3)) + 32|0);
       $139 = +HEAPF64[$138>>3];
       $140 = $122 * $139;
       $141 = $137 + $140;
       $142 = ((($3)) + 64|0);
       $143 = +HEAPF64[$142>>3];
       $144 = $129 * $143;
       $145 = $141 + $144;
       $146 = +HEAPF64[$71>>3];
       $147 = $146 + $145;
       $148 = $135 * $147;
       $149 = $148;
       $150 = ((($3)) + 8|0);
       $151 = +HEAPF64[$150>>3];
       $152 = $116 * $151;
       $153 = ((($3)) + 40|0);
       $154 = +HEAPF64[$153>>3];
       $155 = $122 * $154;
       $156 = $152 + $155;
       $157 = ((($3)) + 72|0);
       $158 = +HEAPF64[$157>>3];
       $159 = $129 * $158;
       $160 = $156 + $159;
       $161 = +HEAPF64[$73>>3];
       $162 = $161 + $160;
       $163 = $135 * $162;
       $164 = $163;
       $165 = ((($3)) + 16|0);
       $166 = +HEAPF64[$165>>3];
       $167 = $116 * $166;
       $168 = ((($3)) + 48|0);
       $169 = +HEAPF64[$168>>3];
       $170 = $122 * $169;
       $171 = $167 + $170;
       $172 = ((($3)) + 80|0);
       $173 = +HEAPF64[$172>>3];
       $174 = $129 * $173;
       $175 = $171 + $174;
       $176 = +HEAPF64[$75>>3];
       $177 = $176 + $175;
       $178 = $135 * $177;
       $179 = $178;
       $180 = ((($0)) + 236|0);
       $181 = HEAP32[$180>>2]|0;
       $182 = ($181|0)==(0);
       do {
        if (!($182)) {
         $183 = ((($0)) + 228|0);
         $184 = HEAP32[$183>>2]|0;
         $185 = ((($0)) + 232|0);
         $186 = HEAP32[$185>>2]|0;
         $187 = ($184|0)==($186|0);
         if (!($187)) {
          ;HEAP32[$184>>2]=HEAP32[$112>>2]|0;HEAP32[$184+4>>2]=HEAP32[$112+4>>2]|0;HEAP32[$184+8>>2]=HEAP32[$112+8>>2]|0;
          $188 = HEAP32[$183>>2]|0;
          $189 = ((($188)) + 12|0);
          HEAP32[$183>>2] = $189;
          break;
         }
         $190 = ((($0)) + 224|0);
         __THREW__ = 0;
         invoke_vii(3736,($190|0),($112|0));
         $191 = __THREW__; __THREW__ = 0;
         $192 = $191&1;
         if ($192) {
          $195 = ___cxa_find_matching_catch_2()|0;
          $196 = tempRet0;
          $$2 = $196;$$212 = $195;
          break L36;
         }
        }
       } while(0);
       $$sroa$0118$0$$sroa_idx = ((($0)) + 212|0);
       HEAPF32[$$sroa$0118$0$$sroa_idx>>2] = $149;
       $$sroa$5121$0$$sroa_idx124 = ((($0)) + 216|0);
       HEAPF32[$$sroa$5121$0$$sroa_idx124>>2] = $164;
       $$sroa$6125$0$$sroa_idx128 = ((($0)) + 220|0);
       HEAPF32[$$sroa$6125$0$$sroa_idx128>>2] = $179;
       $$sink = $180;
       break;
      }
      case 1:  {
       $197 = ((($0)) + 184|0);
       $198 = ((($3)) + 96|0);
       $199 = +HEAPF64[$198>>3];
       $200 = ((($3)) + 104|0);
       $201 = +HEAPF64[$200>>3];
       $202 = ((($3)) + 112|0);
       $203 = +HEAPF64[$202>>3];
       $204 = $199;
       $205 = $201;
       $206 = $203;
       $207 = ((($0)) + 208|0);
       $208 = HEAP32[$207>>2]|0;
       $209 = ($208|0)==(0);
       do {
        if (!($209)) {
         $210 = ((($0)) + 200|0);
         $211 = HEAP32[$210>>2]|0;
         $212 = ((($0)) + 204|0);
         $213 = HEAP32[$212>>2]|0;
         $214 = ($211|0)==($213|0);
         if (!($214)) {
          ;HEAP32[$211>>2]=HEAP32[$197>>2]|0;HEAP32[$211+4>>2]=HEAP32[$197+4>>2]|0;HEAP32[$211+8>>2]=HEAP32[$197+8>>2]|0;
          $215 = HEAP32[$210>>2]|0;
          $216 = ((($215)) + 12|0);
          HEAP32[$210>>2] = $216;
          break;
         }
         $217 = ((($0)) + 196|0);
         __THREW__ = 0;
         invoke_vii(3736,($217|0),($197|0));
         $218 = __THREW__; __THREW__ = 0;
         $219 = $218&1;
         if ($219) {
          $252 = ___cxa_find_matching_catch_2()|0;
          $253 = tempRet0;
          $$2 = $253;$$212 = $252;
          break L36;
         }
        }
       } while(0);
       $$sroa$0107$0$$sroa_idx = ((($0)) + 184|0);
       HEAPF32[$$sroa$0107$0$$sroa_idx>>2] = $204;
       $$sroa$5110$0$$sroa_idx113 = ((($0)) + 188|0);
       HEAPF32[$$sroa$5110$0$$sroa_idx113>>2] = $205;
       $$sroa$6114$0$$sroa_idx117 = ((($0)) + 192|0);
       HEAPF32[$$sroa$6114$0$$sroa_idx117>>2] = $206;
       $220 = HEAP32[$207>>2]|0;
       $221 = (($220) + 1)|0;
       HEAP32[$207>>2] = $221;
       $222 = ((($0)) + 156|0);
       $223 = ((($0)) + 180|0);
       $224 = HEAP32[$223>>2]|0;
       $225 = ($224|0)==(0);
       do {
        if (!($225)) {
         $226 = ((($0)) + 172|0);
         $227 = HEAP32[$226>>2]|0;
         $228 = ((($0)) + 176|0);
         $229 = HEAP32[$228>>2]|0;
         $230 = ($227|0)==($229|0);
         if (!($230)) {
          ;HEAP32[$227>>2]=HEAP32[$222>>2]|0;HEAP32[$227+4>>2]=HEAP32[$222+4>>2]|0;HEAP32[$227+8>>2]=HEAP32[$222+8>>2]|0;
          $231 = HEAP32[$226>>2]|0;
          $232 = ((($231)) + 12|0);
          HEAP32[$226>>2] = $232;
          break;
         }
         $233 = ((($0)) + 168|0);
         __THREW__ = 0;
         invoke_vii(3736,($233|0),($222|0));
         $234 = __THREW__; __THREW__ = 0;
         $235 = $234&1;
         if ($235) {
          $254 = ___cxa_find_matching_catch_2()|0;
          $255 = tempRet0;
          $$2 = $255;$$212 = $254;
          break L36;
         }
        }
       } while(0);
       $$sroa$093$0$$sroa_idx = ((($0)) + 156|0);
       HEAPF32[$$sroa$093$0$$sroa_idx>>2] = 0.0;
       $$sroa$596$0$$sroa_idx99 = ((($0)) + 160|0);
       HEAPF32[$$sroa$596$0$$sroa_idx99>>2] = 0.0;
       $$sroa$6100$0$$sroa_idx103 = ((($0)) + 164|0);
       HEAPF32[$$sroa$6100$0$$sroa_idx103>>2] = 0.0;
       $236 = HEAP32[$223>>2]|0;
       $237 = (($236) + 1)|0;
       HEAP32[$223>>2] = $237;
       $238 = ((($0)) + 212|0);
       $239 = ((($0)) + 236|0);
       $240 = HEAP32[$239>>2]|0;
       $241 = ($240|0)==(0);
       do {
        if (!($241)) {
         $242 = ((($0)) + 228|0);
         $243 = HEAP32[$242>>2]|0;
         $244 = ((($0)) + 232|0);
         $245 = HEAP32[$244>>2]|0;
         $246 = ($243|0)==($245|0);
         if ($246) {
          $249 = ((($0)) + 224|0);
          __THREW__ = 0;
          invoke_vii(3736,($249|0),($238|0));
          $250 = __THREW__; __THREW__ = 0;
          $251 = $250&1;
          if ($251) {
           label = 31;
           break L36;
          } else {
           break;
          }
         } else {
          ;HEAP32[$243>>2]=HEAP32[$238>>2]|0;HEAP32[$243+4>>2]=HEAP32[$238+4>>2]|0;HEAP32[$243+8>>2]=HEAP32[$238+8>>2]|0;
          $247 = HEAP32[$242>>2]|0;
          $248 = ((($247)) + 12|0);
          HEAP32[$242>>2] = $248;
          break;
         }
        }
       } while(0);
       ;HEAP32[$238>>2]=HEAP32[$197>>2]|0;HEAP32[$238+4>>2]=HEAP32[$197+4>>2]|0;HEAP32[$238+8>>2]=HEAP32[$197+8>>2]|0;
       $$sink = $239;
       break;
      }
      case 2:  {
       $256 = ((($0)) + 184|0);
       $257 = ((($3)) + 96|0);
       $258 = +HEAPF64[$257>>3];
       $259 = ((($3)) + 104|0);
       $260 = +HEAPF64[$259>>3];
       $261 = ((($3)) + 112|0);
       $262 = +HEAPF64[$261>>3];
       $263 = $258;
       $264 = $260;
       $265 = $262;
       $266 = ((($0)) + 208|0);
       $267 = HEAP32[$266>>2]|0;
       $268 = ($267|0)==(0);
       do {
        if (!($268)) {
         $269 = ((($0)) + 200|0);
         $270 = HEAP32[$269>>2]|0;
         $271 = ((($0)) + 204|0);
         $272 = HEAP32[$271>>2]|0;
         $273 = ($270|0)==($272|0);
         if (!($273)) {
          ;HEAP32[$270>>2]=HEAP32[$256>>2]|0;HEAP32[$270+4>>2]=HEAP32[$256+4>>2]|0;HEAP32[$270+8>>2]=HEAP32[$256+8>>2]|0;
          $274 = HEAP32[$269>>2]|0;
          $275 = ((($274)) + 12|0);
          HEAP32[$269>>2] = $275;
          break;
         }
         $276 = ((($0)) + 196|0);
         __THREW__ = 0;
         invoke_vii(3736,($276|0),($256|0));
         $277 = __THREW__; __THREW__ = 0;
         $278 = $277&1;
         if ($278) {
          $369 = ___cxa_find_matching_catch_2()|0;
          $370 = tempRet0;
          $$2 = $370;$$212 = $369;
          break L36;
         }
        }
       } while(0);
       $$sroa$082$0$$sroa_idx = ((($0)) + 184|0);
       HEAPF32[$$sroa$082$0$$sroa_idx>>2] = $263;
       $$sroa$585$0$$sroa_idx88 = ((($0)) + 188|0);
       HEAPF32[$$sroa$585$0$$sroa_idx88>>2] = $264;
       $$sroa$689$0$$sroa_idx92 = ((($0)) + 192|0);
       HEAPF32[$$sroa$689$0$$sroa_idx92>>2] = $265;
       $279 = HEAP32[$266>>2]|0;
       $280 = (($279) + 1)|0;
       HEAP32[$266>>2] = $280;
       $$sroa$065$0$$sroa_idx = ((($0)) + 156|0);
       $$sroa$065$0$copyload = +HEAPF32[$$sroa$065$0$$sroa_idx>>2];
       $$sroa$7$0$$sroa_idx70 = ((($0)) + 160|0);
       $$sroa$7$0$copyload = +HEAPF32[$$sroa$7$0$$sroa_idx70>>2];
       $$sroa$9$0$$sroa_idx75 = ((($0)) + 164|0);
       $$sroa$9$0$copyload = +HEAPF32[$$sroa$9$0$$sroa_idx75>>2];
       $282 = ($281|0)==(0|0);
       do {
        if ($282) {
         $$sroa$065$0 = $$sroa$065$0$copyload;$$sroa$7$0 = $$sroa$7$0$copyload;$$sroa$9$0 = $$sroa$9$0$copyload;
         label = 79;
        } else {
         __THREW__ = 0;
         invoke_vi(3299,($4|0));
         $283 = __THREW__; __THREW__ = 0;
         $284 = $283&1;
         if (!($284)) {
          $285 = ((($281)) + 32|0);
          $286 = ((($281)) + 56|0);
          $287 = +HEAPF64[$286>>3];
          $288 = $287 == 0.0;
          if ($288) {
           $289 = ((($281)) + 88|0);
           $290 = +HEAPF64[$289>>3];
           $291 = $290 == 0.0;
           if ($291) {
            $292 = ((($281)) + 120|0);
            $293 = +HEAPF64[$292>>3];
            $294 = $293 == 0.0;
            if ($294) {
             $295 = ((($281)) + 152|0);
             $296 = +HEAPF64[$295>>3];
             $297 = $296 == 1.0;
             if ($297) {
              __THREW__ = 0;
              (invoke_iii(3303,($4|0),($285|0))|0);
              $298 = __THREW__; __THREW__ = 0;
              $299 = $298&1;
              if (!($299)) {
               label = 74;
              }
             } else {
              label = 73;
             }
            } else {
             label = 73;
            }
           } else {
            label = 73;
           }
          } else {
           label = 73;
          }
          if ((label|0) == 73) {
           __THREW__ = 0;
           (invoke_iii(3304,($4|0),($285|0))|0);
           $300 = __THREW__; __THREW__ = 0;
           $301 = $300&1;
           if (!($301)) {
            label = 74;
           }
          }
          if ((label|0) == 74) {
           __THREW__ = 0;
           invoke_vii(3302,($4|0),($44|0));
           $302 = __THREW__; __THREW__ = 0;
           $303 = $302&1;
           if (!($303)) {
            $304 = ((($4)) + 24|0);
            $305 = +HEAPF64[$304>>3];
            $306 = $$sroa$065$0$copyload;
            $307 = $306 * $305;
            $308 = ((($4)) + 56|0);
            $309 = +HEAPF64[$308>>3];
            $310 = $$sroa$7$0$copyload;
            $311 = $310 * $309;
            $312 = $307 + $311;
            $313 = ((($4)) + 88|0);
            $314 = +HEAPF64[$313>>3];
            $315 = $$sroa$9$0$copyload;
            $316 = $315 * $314;
            $317 = $312 + $316;
            $318 = ((($4)) + 120|0);
            $319 = +HEAPF64[$318>>3];
            $320 = $319 + $317;
            $321 = 1.0 / $320;
            $322 = +HEAPF64[$4>>3];
            $323 = $306 * $322;
            $324 = ((($4)) + 32|0);
            $325 = +HEAPF64[$324>>3];
            $326 = $310 * $325;
            $327 = $323 + $326;
            $328 = ((($4)) + 64|0);
            $329 = +HEAPF64[$328>>3];
            $330 = $315 * $329;
            $331 = $327 + $330;
            $332 = ((($4)) + 96|0);
            $333 = +HEAPF64[$332>>3];
            $334 = $333 + $331;
            $335 = $321 * $334;
            $336 = $335;
            $337 = ((($4)) + 8|0);
            $338 = +HEAPF64[$337>>3];
            $339 = $306 * $338;
            $340 = ((($4)) + 40|0);
            $341 = +HEAPF64[$340>>3];
            $342 = $310 * $341;
            $343 = $339 + $342;
            $344 = ((($4)) + 72|0);
            $345 = +HEAPF64[$344>>3];
            $346 = $315 * $345;
            $347 = $343 + $346;
            $348 = ((($4)) + 104|0);
            $349 = +HEAPF64[$348>>3];
            $350 = $349 + $347;
            $351 = $321 * $350;
            $352 = $351;
            $353 = ((($4)) + 16|0);
            $354 = +HEAPF64[$353>>3];
            $355 = $306 * $354;
            $356 = ((($4)) + 48|0);
            $357 = +HEAPF64[$356>>3];
            $358 = $310 * $357;
            $359 = $355 + $358;
            $360 = ((($4)) + 80|0);
            $361 = +HEAPF64[$360>>3];
            $362 = $315 * $361;
            $363 = $359 + $362;
            $364 = ((($4)) + 112|0);
            $365 = +HEAPF64[$364>>3];
            $366 = $365 + $363;
            $367 = $321 * $366;
            $368 = $367;
            $$sroa$065$0 = $336;$$sroa$7$0 = $352;$$sroa$9$0 = $368;
            label = 79;
            break;
           }
          }
          $373 = ___cxa_find_matching_catch_2()|0;
          $374 = tempRet0;
          $$2 = $374;$$212 = $373;
          break L36;
         }
        }
       } while(0);
       L103: do {
        if ((label|0) == 79) {
         $375 = ((($0)) + 156|0);
         $376 = ((($0)) + 180|0);
         $377 = HEAP32[$376>>2]|0;
         $378 = ($377|0)==(0);
         do {
          if (!($378)) {
           $379 = ((($0)) + 172|0);
           $380 = HEAP32[$379>>2]|0;
           $381 = ((($0)) + 176|0);
           $382 = HEAP32[$381>>2]|0;
           $383 = ($380|0)==($382|0);
           if ($383) {
            $386 = ((($0)) + 168|0);
            __THREW__ = 0;
            invoke_vii(3736,($386|0),($375|0));
            $387 = __THREW__; __THREW__ = 0;
            $388 = $387&1;
            if ($388) {
             break L103;
            } else {
             break;
            }
           } else {
            ;HEAP32[$380>>2]=HEAP32[$375>>2]|0;HEAP32[$380+4>>2]=HEAP32[$375+4>>2]|0;HEAP32[$380+8>>2]=HEAP32[$375+8>>2]|0;
            $384 = HEAP32[$379>>2]|0;
            $385 = ((($384)) + 12|0);
            HEAP32[$379>>2] = $385;
            break;
           }
          }
         } while(0);
         HEAPF32[$$sroa$065$0$$sroa_idx>>2] = $$sroa$065$0;
         HEAPF32[$$sroa$7$0$$sroa_idx70>>2] = $$sroa$7$0;
         HEAPF32[$$sroa$9$0$$sroa_idx75>>2] = $$sroa$9$0;
         $389 = HEAP32[$376>>2]|0;
         $390 = (($389) + 1)|0;
         HEAP32[$376>>2] = $390;
         $391 = ((($0)) + 212|0);
         $392 = ((($3)) + 24|0);
         $393 = +HEAPF64[$392>>3];
         $394 = $$sroa$065$0;
         $395 = $393 * $394;
         $396 = ((($3)) + 56|0);
         $397 = +HEAPF64[$396>>3];
         $398 = $$sroa$7$0;
         $399 = $397 * $398;
         $400 = $395 + $399;
         $401 = ((($3)) + 88|0);
         $402 = +HEAPF64[$401>>3];
         $403 = $$sroa$9$0;
         $404 = $402 * $403;
         $405 = $400 + $404;
         $406 = ((($3)) + 120|0);
         $407 = +HEAPF64[$406>>3];
         $408 = $407 + $405;
         $409 = 1.0 / $408;
         $410 = +HEAPF64[$3>>3];
         $411 = $394 * $410;
         $412 = ((($3)) + 32|0);
         $413 = +HEAPF64[$412>>3];
         $414 = $398 * $413;
         $415 = $411 + $414;
         $416 = ((($3)) + 64|0);
         $417 = +HEAPF64[$416>>3];
         $418 = $403 * $417;
         $419 = $415 + $418;
         $420 = +HEAPF64[$257>>3];
         $421 = $420 + $419;
         $422 = $409 * $421;
         $423 = $422;
         $424 = ((($3)) + 8|0);
         $425 = +HEAPF64[$424>>3];
         $426 = $394 * $425;
         $427 = ((($3)) + 40|0);
         $428 = +HEAPF64[$427>>3];
         $429 = $398 * $428;
         $430 = $426 + $429;
         $431 = ((($3)) + 72|0);
         $432 = +HEAPF64[$431>>3];
         $433 = $403 * $432;
         $434 = $430 + $433;
         $435 = +HEAPF64[$259>>3];
         $436 = $435 + $434;
         $437 = $409 * $436;
         $438 = $437;
         $439 = ((($3)) + 16|0);
         $440 = +HEAPF64[$439>>3];
         $441 = $394 * $440;
         $442 = ((($3)) + 48|0);
         $443 = +HEAPF64[$442>>3];
         $444 = $398 * $443;
         $445 = $441 + $444;
         $446 = ((($3)) + 80|0);
         $447 = +HEAPF64[$446>>3];
         $448 = $403 * $447;
         $449 = $445 + $448;
         $450 = +HEAPF64[$261>>3];
         $451 = $450 + $449;
         $452 = $409 * $451;
         $453 = $452;
         $454 = ((($0)) + 236|0);
         $455 = HEAP32[$454>>2]|0;
         $456 = ($455|0)==(0);
         do {
          if (!($456)) {
           $457 = ((($0)) + 228|0);
           $458 = HEAP32[$457>>2]|0;
           $459 = ((($0)) + 232|0);
           $460 = HEAP32[$459>>2]|0;
           $461 = ($458|0)==($460|0);
           if (!($461)) {
            ;HEAP32[$458>>2]=HEAP32[$391>>2]|0;HEAP32[$458+4>>2]=HEAP32[$391+4>>2]|0;HEAP32[$458+8>>2]=HEAP32[$391+8>>2]|0;
            $462 = HEAP32[$457>>2]|0;
            $463 = ((($462)) + 12|0);
            HEAP32[$457>>2] = $463;
            break;
           }
           $464 = ((($0)) + 224|0);
           __THREW__ = 0;
           invoke_vii(3736,($464|0),($391|0));
           $465 = __THREW__; __THREW__ = 0;
           $466 = $465&1;
           if ($466) {
            $467 = ___cxa_find_matching_catch_2()|0;
            $468 = tempRet0;
            $$2 = $468;$$212 = $467;
            break L36;
           }
          }
         } while(0);
         $$sroa$044$0$$sroa_idx = ((($0)) + 212|0);
         HEAPF32[$$sroa$044$0$$sroa_idx>>2] = $423;
         $$sroa$5$0$$sroa_idx49 = ((($0)) + 216|0);
         HEAPF32[$$sroa$5$0$$sroa_idx49>>2] = $438;
         $$sroa$650$0$$sroa_idx53 = ((($0)) + 220|0);
         HEAPF32[$$sroa$650$0$$sroa_idx53>>2] = $453;
         $$sink = $454;
         break L38;
        }
       } while(0);
       $371 = ___cxa_find_matching_catch_2()|0;
       $372 = tempRet0;
       $$2 = $372;$$212 = $371;
       break L36;
       break;
      }
      default: {
       $471 = ((($0)) + 96|0);
       $472 = HEAP32[$471>>2]|0;
       $473 = ((($472)) + 48|0);
       $474 = +HEAPF64[$473>>3];
       $475 = $474;
       $476 = ((($472)) + 80|0);
       $477 = +HEAPF64[$476>>3];
       $478 = $477;
       $479 = ((($472)) + 112|0);
       $480 = +HEAPF64[$479>>3];
       $481 = $480;
       $482 = $475 <= -0.0;
       $483 = $482&1;
       $484 = $478 <= -0.0;
       $485 = $484 ? 2 : 0;
       $486 = $485 | $483;
       $487 = $481 <= -0.0;
       $488 = $487 ? 4 : 0;
       $489 = $486 | $488;
       $490 = ((($0)) + 292|0);
       HEAP32[$490>>2] = $489;
       $491 = $489 ^ 7;
       $492 = ((($0)) + 288|0);
       HEAP32[$492>>2] = $491;
       STACKTOP = sp;return;
      }
      }
     } while(0);
     $469 = HEAP32[$$sink>>2]|0;
     $470 = (($469) + 1)|0;
     HEAP32[$$sink>>2] = $470;
     $471 = ((($0)) + 96|0);
     $472 = HEAP32[$471>>2]|0;
     $473 = ((($472)) + 48|0);
     $474 = +HEAPF64[$473>>3];
     $475 = $474;
     $476 = ((($472)) + 80|0);
     $477 = +HEAPF64[$476>>3];
     $478 = $477;
     $479 = ((($472)) + 112|0);
     $480 = +HEAPF64[$479>>3];
     $481 = $480;
     $482 = $475 <= -0.0;
     $483 = $482&1;
     $484 = $478 <= -0.0;
     $485 = $484 ? 2 : 0;
     $486 = $485 | $483;
     $487 = $481 <= -0.0;
     $488 = $487 ? 4 : 0;
     $489 = $486 | $488;
     $490 = ((($0)) + 292|0);
     HEAP32[$490>>2] = $489;
     $491 = $489 ^ 7;
     $492 = ((($0)) + 288|0);
     HEAP32[$492>>2] = $491;
     STACKTOP = sp;return;
    }
   } while(0);
   if ((label|0) == 31) {
    $68 = ___cxa_find_matching_catch_2()|0;
    $69 = tempRet0;
    $$2 = $69;$$212 = $68;
   }
   $$3 = $$2;$$313 = $$212;
   ___resumeException($$313|0);
   // unreachable;
  }
 } while(0);
 $61 = ___cxa_find_matching_catch_2()|0;
 $62 = tempRet0;
 if (!($10)) {
  $63 = ((($1)) + 8|0);
  $64 = HEAP32[$63>>2]|0;HEAP32[$63>>2] = (($64-1)|0);
  $65 = ($64|0)==(1);
  if ($65) {
   __THREW__ = 0;
   invoke_viii(3262,($1|0),1,1);
   $66 = __THREW__; __THREW__ = 0;
   $67 = $66&1;
   if ($67) {
    $493 = ___cxa_find_matching_catch_3(0|0)|0;
    $494 = tempRet0;
    ___clang_call_terminate($493);
    // unreachable;
   }
  }
 }
 $$3 = $62;$$313 = $61;
 ___resumeException($$313|0);
 // unreachable;
}
function __ZN3osg9CullStack18popModelViewMatrixEv($0) {
 $0 = $0|0;
 var $$pre$i = 0, $$sroa$08$0 = 0, $$sroa$510$0 = 0, $$sroa$8$0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0.0, $77 = 0.0, $78 = 0;
 var $79 = 0.0, $8 = 0, $80 = 0.0, $81 = 0, $82 = 0.0, $83 = 0.0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $phitmp = 0, $phitmp13 = 0, $phitmp14 = 0, $phitmp15 = 0, $phitmp16 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 112|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if (!($3)) {
  $4 = ((($0)) + 100|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ((($0)) + 104|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($5|0)==($7|0);
  do {
   if ($8) {
    $37 = $2;
   } else {
    $9 = ((($0)) + 96|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = ((($7)) + -4|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ($10|0)==($12|0);
    if (!($13)) {
     HEAP32[$9>>2] = $12;
     $14 = ($12|0)==(0|0);
     if (!($14)) {
      $15 = ((($12)) + 8|0);
      $16 = HEAP32[$15>>2]|0;HEAP32[$15>>2] = (($16+1)|0);
     }
     $17 = ($10|0)==(0|0);
     if (!($17)) {
      $18 = ((($10)) + 8|0);
      $19 = HEAP32[$18>>2]|0;HEAP32[$18>>2] = (($19-1)|0);
      $20 = ($19|0)==(1);
      if ($20) {
       __ZNK3osg10Referenced24signalObserversAndDeleteEbb($10,1,1);
      }
     }
    }
    $21 = HEAP32[$6>>2]|0;
    $22 = ((($21)) + -4|0);
    $24 = $21;
    while(1) {
     $23 = ((($24)) + -4|0);
     HEAP32[$6>>2] = $23;
     $25 = HEAP32[$23>>2]|0;
     $26 = ($25|0)==(0|0);
     if (!($26)) {
      $27 = ((($25)) + 8|0);
      $28 = HEAP32[$27>>2]|0;HEAP32[$27>>2] = (($28-1)|0);
      $29 = ($28|0)==(1);
      if ($29) {
       __THREW__ = 0;
       invoke_viii(3262,($25|0),1,1);
       $30 = __THREW__; __THREW__ = 0;
       $31 = $30&1;
       if ($31) {
        label = 14;
        break;
       }
      }
     }
     HEAP32[$23>>2] = 0;
     $32 = HEAP32[$6>>2]|0;
     $33 = ($32|0)==($22|0);
     if ($33) {
      label = 15;
      break;
     } else {
      $24 = $32;
     }
    }
    if ((label|0) == 14) {
     $34 = ___cxa_find_matching_catch_2()|0;
     $35 = tempRet0;
     ___cxa_call_unexpected(($34|0));
     // unreachable;
    }
    else if ((label|0) == 15) {
     $$pre$i = HEAP32[$1>>2]|0;
     $37 = $$pre$i;
     break;
    }
   }
  } while(0);
  $36 = (($37) + -1)|0;
  HEAP32[$1>>2] = $36;
 }
 $38 = ((($0)) + 184|0);
 $39 = ((($0)) + 208|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ($40|0)==(0);
 if (!($41)) {
  $42 = ((($0)) + 196|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = ((($0)) + 200|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = ($43|0)==($45|0);
  if (!($46)) {
   $47 = ((($45)) + -12|0);
   ;HEAP32[$38>>2]=HEAP32[$47>>2]|0;HEAP32[$38+4>>2]=HEAP32[$47+4>>2]|0;HEAP32[$38+8>>2]=HEAP32[$47+8>>2]|0;
   HEAP32[$44>>2] = $47;
  }
  $48 = (($40) + -1)|0;
  HEAP32[$39>>2] = $48;
 }
 $49 = ((($0)) + 156|0);
 $50 = ((($0)) + 180|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = ($51|0)==(0);
 if (!($52)) {
  $53 = ((($0)) + 168|0);
  $54 = HEAP32[$53>>2]|0;
  $55 = ((($0)) + 172|0);
  $56 = HEAP32[$55>>2]|0;
  $57 = ($54|0)==($56|0);
  if (!($57)) {
   $58 = ((($56)) + -12|0);
   ;HEAP32[$49>>2]=HEAP32[$58>>2]|0;HEAP32[$49+4>>2]=HEAP32[$58+4>>2]|0;HEAP32[$49+8>>2]=HEAP32[$58+8>>2]|0;
   HEAP32[$55>>2] = $58;
  }
  $59 = (($51) + -1)|0;
  HEAP32[$50>>2] = $59;
 }
 $60 = ((($0)) + 212|0);
 $61 = ((($0)) + 236|0);
 $62 = HEAP32[$61>>2]|0;
 $63 = ($62|0)==(0);
 if (!($63)) {
  $64 = ((($0)) + 224|0);
  $65 = HEAP32[$64>>2]|0;
  $66 = ((($0)) + 228|0);
  $67 = HEAP32[$66>>2]|0;
  $68 = ($65|0)==($67|0);
  if (!($68)) {
   $69 = ((($67)) + -12|0);
   ;HEAP32[$60>>2]=HEAP32[$69>>2]|0;HEAP32[$60+4>>2]=HEAP32[$69+4>>2]|0;HEAP32[$60+8>>2]=HEAP32[$69+8>>2]|0;
   HEAP32[$66>>2] = $69;
  }
  $70 = (($62) + -1)|0;
  HEAP32[$61>>2] = $70;
 }
 __ZN3osg9CullStack13popCullingSetEv($0);
 $71 = HEAP32[$1>>2]|0;
 $72 = ($71|0)==(0);
 if ($72) {
  $$sroa$08$0 = 1;$$sroa$510$0 = 2;$$sroa$8$0 = 0;
  $84 = $$sroa$08$0&1;
  $85 = $84 | $$sroa$510$0;
  $86 = $85 | $$sroa$8$0;
  $87 = ((($0)) + 292|0);
  HEAP32[$87>>2] = $86;
  $88 = $86 ^ 7;
  $89 = ((($0)) + 288|0);
  HEAP32[$89>>2] = $88;
  return;
 }
 $73 = ((($0)) + 96|0);
 $74 = HEAP32[$73>>2]|0;
 $75 = ((($74)) + 48|0);
 $76 = +HEAPF64[$75>>3];
 $77 = $76;
 $78 = ((($74)) + 80|0);
 $79 = +HEAPF64[$78>>3];
 $80 = $79;
 $81 = ((($74)) + 112|0);
 $82 = +HEAPF64[$81>>3];
 $83 = $82;
 $phitmp = $77 <= -0.0;
 $phitmp13 = $80 <= -0.0;
 $phitmp14 = $phitmp13 ? 2 : 0;
 $phitmp15 = $83 <= -0.0;
 $phitmp16 = $phitmp15 ? 4 : 0;
 $$sroa$08$0 = $phitmp;$$sroa$510$0 = $phitmp14;$$sroa$8$0 = $phitmp16;
 $84 = $$sroa$08$0&1;
 $85 = $84 | $$sroa$510$0;
 $86 = $85 | $$sroa$8$0;
 $87 = ((($0)) + 292|0);
 HEAP32[$87>>2] = $86;
 $88 = $86 ^ 7;
 $89 = ((($0)) + 288|0);
 HEAP32[$89>>2] = $88;
 return;
}
function __ZN3osg9CullStack20computeFrustumVolumeEv($0) {
 $0 = $0|0;
 var $$sink$i = 0, $1 = 0, $10 = 0.0, $100 = 0.0, $101 = 0.0, $102 = 0.0, $103 = 0.0, $104 = 0.0, $105 = 0.0, $106 = 0.0, $107 = 0.0, $108 = 0.0, $109 = 0.0, $11 = 0, $110 = 0.0, $111 = 0.0, $112 = 0.0, $113 = 0.0, $114 = 0.0, $115 = 0.0;
 var $116 = 0.0, $117 = 0.0, $118 = 0.0, $119 = 0.0, $12 = 0, $120 = 0.0, $121 = 0.0, $122 = 0.0, $123 = 0.0, $124 = 0.0, $125 = 0.0, $126 = 0.0, $127 = 0.0, $128 = 0.0, $129 = 0.0, $13 = 0.0, $130 = 0.0, $131 = 0.0, $132 = 0.0, $133 = 0.0;
 var $134 = 0.0, $135 = 0.0, $136 = 0.0, $137 = 0.0, $138 = 0.0, $139 = 0.0, $14 = 0, $140 = 0.0, $141 = 0.0, $142 = 0.0, $143 = 0.0, $144 = 0.0, $145 = 0.0, $146 = 0.0, $147 = 0.0, $148 = 0.0, $149 = 0.0, $15 = 0, $150 = 0.0, $151 = 0.0;
 var $152 = 0.0, $153 = 0.0, $154 = 0.0, $155 = 0.0, $156 = 0.0, $157 = 0.0, $158 = 0.0, $159 = 0.0, $16 = 0.0, $160 = 0.0, $161 = 0.0, $162 = 0.0, $163 = 0.0, $164 = 0.0, $165 = 0.0, $166 = 0.0, $167 = 0.0, $168 = 0.0, $169 = 0.0, $17 = 0;
 var $170 = 0.0, $171 = 0.0, $172 = 0.0, $173 = 0.0, $174 = 0.0, $175 = 0.0, $176 = 0.0, $177 = 0.0, $178 = 0.0, $179 = 0.0, $18 = 0, $180 = 0.0, $181 = 0.0, $182 = 0.0, $183 = 0.0, $184 = 0.0, $185 = 0.0, $186 = 0.0, $187 = 0.0, $188 = 0.0;
 var $189 = 0.0, $19 = 0.0, $190 = 0.0, $191 = 0.0, $192 = 0.0, $193 = 0.0, $194 = 0.0, $195 = 0.0, $196 = 0.0, $197 = 0.0, $198 = 0.0, $199 = 0.0, $2 = 0, $20 = 0, $200 = 0.0, $201 = 0.0, $202 = 0.0, $203 = 0.0, $204 = 0.0, $205 = 0.0;
 var $206 = 0.0, $207 = 0.0, $208 = 0.0, $209 = 0.0, $21 = 0, $210 = 0.0, $211 = 0.0, $212 = 0.0, $213 = 0.0, $214 = 0.0, $215 = 0.0, $216 = 0.0, $217 = 0.0, $218 = 0.0, $219 = 0.0, $22 = 0, $220 = 0.0, $221 = 0.0, $222 = 0.0, $223 = 0.0;
 var $224 = 0.0, $225 = 0.0, $226 = 0.0, $227 = 0.0, $228 = 0.0, $229 = 0.0, $23 = 0, $230 = 0.0, $231 = 0.0, $232 = 0.0, $233 = 0.0, $234 = 0.0, $235 = 0.0, $236 = 0.0, $237 = 0.0, $238 = 0.0, $239 = 0.0, $24 = 0, $240 = 0.0, $241 = 0.0;
 var $242 = 0.0, $243 = 0.0, $244 = 0.0, $245 = 0.0, $246 = 0.0, $247 = 0.0, $248 = 0.0, $249 = 0.0, $25 = 0, $250 = 0.0, $251 = 0.0, $252 = 0.0, $253 = 0.0, $254 = 0.0, $255 = 0.0, $256 = 0.0, $257 = 0.0, $258 = 0.0, $259 = 0.0, $26 = 0.0;
 var $260 = 0.0, $261 = 0.0, $262 = 0.0, $263 = 0.0, $264 = 0.0, $265 = 0.0, $266 = 0.0, $267 = 0.0, $268 = 0.0, $269 = 0.0, $27 = 0, $270 = 0.0, $271 = 0.0, $272 = 0.0, $273 = 0.0, $274 = 0.0, $275 = 0.0, $276 = 0.0, $277 = 0.0, $278 = 0.0;
 var $279 = 0.0, $28 = 0.0, $280 = 0.0, $281 = 0.0, $282 = 0.0, $283 = 0.0, $284 = 0.0, $285 = 0.0, $286 = 0.0, $287 = 0.0, $288 = 0.0, $289 = 0.0, $29 = 0.0, $290 = 0.0, $291 = 0.0, $292 = 0.0, $293 = 0.0, $294 = 0.0, $295 = 0.0, $296 = 0.0;
 var $297 = 0.0, $298 = 0.0, $299 = 0.0, $3 = 0, $30 = 0.0, $300 = 0.0, $301 = 0.0, $302 = 0.0, $303 = 0.0, $304 = 0.0, $305 = 0.0, $306 = 0.0, $307 = 0.0, $308 = 0.0, $309 = 0.0, $31 = 0, $310 = 0.0, $311 = 0.0, $312 = 0.0, $313 = 0.0;
 var $314 = 0.0, $315 = 0.0, $316 = 0.0, $317 = 0.0, $318 = 0.0, $319 = 0.0, $32 = 0.0, $320 = 0.0, $321 = 0.0, $322 = 0.0, $323 = 0.0, $324 = 0.0, $325 = 0.0, $326 = 0.0, $327 = 0.0, $328 = 0.0, $329 = 0.0, $33 = 0.0, $330 = 0.0, $331 = 0.0;
 var $332 = 0.0, $333 = 0.0, $334 = 0.0, $335 = 0.0, $336 = 0, $337 = 0, $338 = 0, $34 = 0, $35 = 0.0, $36 = 0.0, $37 = 0.0, $38 = 0.0, $39 = 0, $4 = 0, $40 = 0.0, $41 = 0.0, $42 = 0.0, $43 = 0, $44 = 0.0, $45 = 0.0;
 var $46 = 0, $47 = 0.0, $48 = 0.0, $49 = 0.0, $5 = 0, $50 = 0.0, $51 = 0, $52 = 0.0, $53 = 0, $54 = 0.0, $55 = 0.0, $56 = 0.0, $57 = 0, $58 = 0.0, $59 = 0.0, $6 = 0, $60 = 0, $61 = 0.0, $62 = 0.0, $63 = 0.0;
 var $64 = 0.0, $65 = 0, $66 = 0.0, $67 = 0, $68 = 0.0, $69 = 0.0, $7 = 0, $70 = 0.0, $71 = 0, $72 = 0.0, $73 = 0.0, $74 = 0, $75 = 0.0, $76 = 0.0, $77 = 0.0, $78 = 0.0, $79 = 0.0, $8 = 0, $80 = 0.0, $81 = 0.0;
 var $82 = 0.0, $83 = 0.0, $84 = 0.0, $85 = 0.0, $86 = 0.0, $87 = 0.0, $88 = 0.0, $89 = 0.0, $9 = 0, $90 = 0.0, $91 = 0.0, $92 = 0.0, $93 = 0.0, $94 = 0.0, $95 = 0.0, $96 = 0.0, $97 = 0.0, $98 = 0.0, $99 = 0.0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(128|0);
 $1 = sp;
 __ZN3osg7Matrixd12makeIdentityEv($1);
 $2 = ((($0)) + 92|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 $5 = ((($0)) + 76|0);
 $6 = ((($0)) + 296|0);
 $$sink$i = $4 ? $6 : $5;
 $7 = HEAP32[$$sink$i>>2]|0;
 $8 = ((($7)) + 32|0);
 $9 = ((($7)) + 56|0);
 $10 = +HEAPF64[$9>>3];
 $11 = $10 == 0.0;
 if ($11) {
  $12 = ((($7)) + 88|0);
  $13 = +HEAPF64[$12>>3];
  $14 = $13 == 0.0;
  if ($14) {
   $15 = ((($7)) + 120|0);
   $16 = +HEAPF64[$15>>3];
   $17 = $16 == 0.0;
   if ($17) {
    $18 = ((($7)) + 152|0);
    $19 = +HEAPF64[$18>>3];
    $20 = $19 == 1.0;
    if ($20) {
     __THREW__ = 0;
     (invoke_iii(3303,($1|0),($8|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      $337 = ___cxa_find_matching_catch_2()|0;
      $338 = tempRet0;
      ___resumeException($337|0);
      // unreachable;
     }
    } else {
     label = 6;
    }
   } else {
    label = 6;
   }
  } else {
   label = 6;
  }
 } else {
  label = 6;
 }
 if ((label|0) == 6) {
  __THREW__ = 0;
  (invoke_iii(3304,($1|0),($8|0))|0);
  $23 = __THREW__; __THREW__ = 0;
  $24 = $23&1;
  if ($24) {
   $337 = ___cxa_find_matching_catch_2()|0;
   $338 = tempRet0;
   ___resumeException($337|0);
   // unreachable;
  }
 }
 $25 = ((($1)) + 24|0);
 $26 = +HEAPF64[$25>>3];
 $27 = ((($1)) + 56|0);
 $28 = +HEAPF64[$27>>3];
 $29 = -$28;
 $30 = $29 - $26;
 $31 = ((($1)) + 88|0);
 $32 = +HEAPF64[$31>>3];
 $33 = $30 - $32;
 $34 = ((($1)) + 120|0);
 $35 = +HEAPF64[$34>>3];
 $36 = $35 + $33;
 $37 = 1.0 / $36;
 $38 = +HEAPF64[$1>>3];
 $39 = ((($1)) + 32|0);
 $40 = +HEAPF64[$39>>3];
 $41 = -$40;
 $42 = $41 - $38;
 $43 = ((($1)) + 64|0);
 $44 = +HEAPF64[$43>>3];
 $45 = $42 - $44;
 $46 = ((($1)) + 96|0);
 $47 = +HEAPF64[$46>>3];
 $48 = $47 + $45;
 $49 = $37 * $48;
 $50 = $49;
 $51 = ((($1)) + 8|0);
 $52 = +HEAPF64[$51>>3];
 $53 = ((($1)) + 40|0);
 $54 = +HEAPF64[$53>>3];
 $55 = -$54;
 $56 = $55 - $52;
 $57 = ((($1)) + 72|0);
 $58 = +HEAPF64[$57>>3];
 $59 = $56 - $58;
 $60 = ((($1)) + 104|0);
 $61 = +HEAPF64[$60>>3];
 $62 = $61 + $59;
 $63 = $37 * $62;
 $64 = $63;
 $65 = ((($1)) + 16|0);
 $66 = +HEAPF64[$65>>3];
 $67 = ((($1)) + 48|0);
 $68 = +HEAPF64[$67>>3];
 $69 = -$68;
 $70 = $69 - $66;
 $71 = ((($1)) + 80|0);
 $72 = +HEAPF64[$71>>3];
 $73 = $70 - $72;
 $74 = ((($1)) + 112|0);
 $75 = +HEAPF64[$74>>3];
 $76 = $75 + $73;
 $77 = $37 * $76;
 $78 = $77;
 $79 = $28 - $26;
 $80 = $79 - $32;
 $81 = $35 + $80;
 $82 = 1.0 / $81;
 $83 = $40 - $38;
 $84 = $83 - $44;
 $85 = $47 + $84;
 $86 = $82 * $85;
 $87 = $86;
 $88 = $54 - $52;
 $89 = $88 - $58;
 $90 = $61 + $89;
 $91 = $82 * $90;
 $92 = $91;
 $93 = $68 - $66;
 $94 = $93 - $72;
 $95 = $75 + $94;
 $96 = $82 * $95;
 $97 = $96;
 $98 = $26 + $28;
 $99 = $98 - $32;
 $100 = $35 + $99;
 $101 = 1.0 / $100;
 $102 = $38 + $40;
 $103 = $102 - $44;
 $104 = $47 + $103;
 $105 = $101 * $104;
 $106 = $105;
 $107 = $52 + $54;
 $108 = $107 - $58;
 $109 = $61 + $108;
 $110 = $101 * $109;
 $111 = $110;
 $112 = $66 + $68;
 $113 = $112 - $72;
 $114 = $75 + $113;
 $115 = $101 * $114;
 $116 = $115;
 $117 = $26 - $28;
 $118 = $117 - $32;
 $119 = $35 + $118;
 $120 = 1.0 / $119;
 $121 = $38 - $40;
 $122 = $121 - $44;
 $123 = $47 + $122;
 $124 = $120 * $123;
 $125 = $124;
 $126 = $52 - $54;
 $127 = $126 - $58;
 $128 = $61 + $127;
 $129 = $120 * $128;
 $130 = $129;
 $131 = $66 - $68;
 $132 = $131 - $72;
 $133 = $75 + $132;
 $134 = $120 * $133;
 $135 = $134;
 $136 = $30 + $32;
 $137 = $35 + $136;
 $138 = 1.0 / $137;
 $139 = $42 + $44;
 $140 = $47 + $139;
 $141 = $138 * $140;
 $142 = $141;
 $143 = $56 + $58;
 $144 = $61 + $143;
 $145 = $138 * $144;
 $146 = $145;
 $147 = $70 + $72;
 $148 = $75 + $147;
 $149 = $138 * $148;
 $150 = $149;
 $151 = $79 + $32;
 $152 = $35 + $151;
 $153 = 1.0 / $152;
 $154 = $83 + $44;
 $155 = $47 + $154;
 $156 = $153 * $155;
 $157 = $156;
 $158 = $88 + $58;
 $159 = $61 + $158;
 $160 = $153 * $159;
 $161 = $160;
 $162 = $93 + $72;
 $163 = $75 + $162;
 $164 = $153 * $163;
 $165 = $164;
 $166 = $98 + $32;
 $167 = $35 + $166;
 $168 = 1.0 / $167;
 $169 = $102 + $44;
 $170 = $47 + $169;
 $171 = $168 * $170;
 $172 = $171;
 $173 = $107 + $58;
 $174 = $61 + $173;
 $175 = $168 * $174;
 $176 = $175;
 $177 = $112 + $72;
 $178 = $75 + $177;
 $179 = $168 * $178;
 $180 = $179;
 $181 = $117 + $32;
 $182 = $35 + $181;
 $183 = 1.0 / $182;
 $184 = $121 + $44;
 $185 = $47 + $184;
 $186 = $183 * $185;
 $187 = $186;
 $188 = $126 + $58;
 $189 = $61 + $188;
 $190 = $183 * $189;
 $191 = $190;
 $192 = $131 + $72;
 $193 = $75 + $192;
 $194 = $183 * $193;
 $195 = $194;
 $196 = $87 - $106;
 $197 = $92 - $111;
 $198 = $97 - $116;
 $199 = $50 - $87;
 $200 = $64 - $92;
 $201 = $78 - $97;
 $202 = $197 * $201;
 $203 = $200 * $198;
 $204 = $202 - $203;
 $205 = $199 * $198;
 $206 = $196 * $201;
 $207 = $205 - $206;
 $208 = $196 * $200;
 $209 = $199 * $197;
 $210 = $208 - $209;
 $211 = $142 - $87;
 $212 = $146 - $92;
 $213 = $150 - $97;
 $214 = $211 * $204;
 $215 = $212 * $207;
 $216 = $214 + $215;
 $217 = $210 * $213;
 $218 = $217 + $216;
 $219 = (+Math_abs((+$218)));
 $220 = $157 - $172;
 $221 = $161 - $176;
 $222 = $165 - $180;
 $223 = $142 - $157;
 $224 = $146 - $161;
 $225 = $150 - $165;
 $226 = $221 * $225;
 $227 = $224 * $222;
 $228 = $226 - $227;
 $229 = $223 * $222;
 $230 = $220 * $225;
 $231 = $229 - $230;
 $232 = $220 * $224;
 $233 = $223 * $221;
 $234 = $232 - $233;
 $235 = $87 - $157;
 $236 = $92 - $161;
 $237 = $97 - $165;
 $238 = $235 * $228;
 $239 = $236 * $231;
 $240 = $238 + $239;
 $241 = $234 * $237;
 $242 = $241 + $240;
 $243 = (+Math_abs((+$242)));
 $244 = $219 + $243;
 $245 = $172 - $87;
 $246 = $176 - $92;
 $247 = $180 - $97;
 $248 = $142 - $172;
 $249 = $146 - $176;
 $250 = $150 - $180;
 $251 = $246 * $250;
 $252 = $249 * $247;
 $253 = $251 - $252;
 $254 = $248 * $247;
 $255 = $245 * $250;
 $256 = $254 - $255;
 $257 = $245 * $249;
 $258 = $248 * $246;
 $259 = $257 - $258;
 $260 = $106 - $172;
 $261 = $111 - $176;
 $262 = $116 - $180;
 $263 = $260 * $253;
 $264 = $261 * $256;
 $265 = $263 + $264;
 $266 = $259 * $262;
 $267 = $266 + $265;
 $268 = (+Math_abs((+$267)));
 $269 = $244 + $268;
 $270 = $106 - $125;
 $271 = $111 - $130;
 $272 = $116 - $135;
 $273 = $271 * $198;
 $274 = $197 * $272;
 $275 = $273 - $274;
 $276 = $196 * $272;
 $277 = $270 * $198;
 $278 = $276 - $277;
 $279 = $270 * $197;
 $280 = $196 * $271;
 $281 = $279 - $280;
 $282 = $142 - $106;
 $283 = $146 - $111;
 $284 = $150 - $116;
 $285 = $282 * $275;
 $286 = $283 * $278;
 $287 = $285 + $286;
 $288 = $281 * $284;
 $289 = $288 + $287;
 $290 = (+Math_abs((+$289)));
 $291 = $172 - $187;
 $292 = $176 - $191;
 $293 = $180 - $195;
 $294 = $292 * $250;
 $295 = $249 * $293;
 $296 = $294 - $295;
 $297 = $248 * $293;
 $298 = $291 * $250;
 $299 = $297 - $298;
 $300 = $291 * $249;
 $301 = $248 * $292;
 $302 = $300 - $301;
 $303 = $260 * $296;
 $304 = $261 * $299;
 $305 = $303 + $304;
 $306 = $302 * $262;
 $307 = $306 + $305;
 $308 = (+Math_abs((+$307)));
 $309 = $290 + $308;
 $310 = $187 - $106;
 $311 = $191 - $111;
 $312 = $195 - $116;
 $313 = $142 - $187;
 $314 = $146 - $191;
 $315 = $150 - $195;
 $316 = $311 * $315;
 $317 = $314 * $312;
 $318 = $316 - $317;
 $319 = $313 * $312;
 $320 = $310 * $315;
 $321 = $319 - $320;
 $322 = $310 * $314;
 $323 = $313 * $311;
 $324 = $322 - $323;
 $325 = $125 - $187;
 $326 = $130 - $191;
 $327 = $135 - $195;
 $328 = $325 * $318;
 $329 = $326 * $321;
 $330 = $328 + $329;
 $331 = $324 * $327;
 $332 = $331 + $330;
 $333 = (+Math_abs((+$332)));
 $334 = $309 + $333;
 $335 = $269 + $334;
 $336 = ((($0)) + 284|0);
 HEAPF32[$336>>2] = $335;
 STACKTOP = sp;return;
}
function __ZN3osg15DisplaySettingsD2Ev($0) {
 $0 = $0|0;
 var $$pre$i = 0, $$pre$i$i$i = 0, $$pre$i5 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (58292);
 $1 = ((($0)) + 184|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = ((($0)) + 188|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==($2|0);
  do {
   if ($6) {
    $20 = $2;
   } else {
    $8 = $5;
    while(1) {
     $7 = ((($8)) + -4|0);
     HEAP32[$4>>2] = $7;
     $9 = HEAP32[$7>>2]|0;
     $10 = ($9|0)==(0|0);
     if (!($10)) {
      $11 = ((($9)) + 8|0);
      $12 = HEAP32[$11>>2]|0;HEAP32[$11>>2] = (($12-1)|0);
      $13 = ($12|0)==(1);
      if ($13) {
       __THREW__ = 0;
       invoke_viii(3262,($9|0),1,1);
       $14 = __THREW__; __THREW__ = 0;
       $15 = $14&1;
       if ($15) {
        label = 7;
        break;
       }
      }
     }
     HEAP32[$7>>2] = 0;
     $16 = HEAP32[$4>>2]|0;
     $17 = ($16|0)==($2|0);
     if ($17) {
      label = 8;
      break;
     } else {
      $8 = $16;
     }
    }
    if ((label|0) == 7) {
     $18 = ___cxa_find_matching_catch_2()|0;
     $19 = tempRet0;
     ___cxa_call_unexpected(($18|0));
     // unreachable;
    }
    else if ((label|0) == 8) {
     $$pre$i = HEAP32[$1>>2]|0;
     $20 = $$pre$i;
     break;
    }
   }
  } while(0);
  __ZdlPv($20);
 }
 $21 = ((($0)) + 172|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0|0);
 if (!($23)) {
  $24 = ((($0)) + 176|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = ($25|0)==($22|0);
  if ($26) {
   $35 = $22;
  } else {
   $28 = $25;
   while(1) {
    $27 = ((($28)) + -12|0);
    HEAP32[$24>>2] = $27;
    $29 = ((($27)) + 11|0);
    $30 = HEAP8[$29>>0]|0;
    $31 = ($30<<24>>24)<(0);
    if ($31) {
     $34 = HEAP32[$27>>2]|0;
     __ZdlPv($34);
     $$pre$i$i$i = HEAP32[$24>>2]|0;
     $32 = $$pre$i$i$i;
    } else {
     $32 = $27;
    }
    $33 = ($32|0)==($22|0);
    if ($33) {
     break;
    } else {
     $28 = $32;
    }
   }
   $$pre$i5 = HEAP32[$21>>2]|0;
   $35 = $$pre$i5;
  }
  __ZdlPv($35);
 }
 $36 = ((($0)) + 132|0);
 $37 = ((($36)) + 11|0);
 $38 = HEAP8[$37>>0]|0;
 $39 = ($38<<24>>24)<(0);
 if ($39) {
  $40 = HEAP32[$36>>2]|0;
  __ZdlPv($40);
 }
 $41 = ((($0)) + 104|0);
 $42 = ((($41)) + 11|0);
 $43 = HEAP8[$42>>0]|0;
 $44 = ($43<<24>>24)<(0);
 if (!($44)) {
  __ZN3osg10ReferencedD2Ev($0);
  return;
 }
 $45 = HEAP32[$41>>2]|0;
 __ZdlPv($45);
 __ZN3osg10ReferencedD2Ev($0);
 return;
}
function __ZN3osg15DisplaySettingsD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1623,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK3osg15DisplaySettings38computeLeftEyeProjectionImplementationERKNS_7MatrixdE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$024 = 0.0, $$025 = 0.0, $$2 = 0, $$223 = 0, $10 = 0, $11 = 0.0, $12 = 0.0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0.0, $28 = 0.0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0.0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 512|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(512|0);
 $3 = sp + 384|0;
 $4 = sp + 256|0;
 $5 = sp + 128|0;
 $6 = sp;
 $7 = ((($1)) + 24|0);
 $8 = +HEAPF32[$7>>2];
 $9 = $8;
 $10 = ((($1)) + 36|0);
 $11 = +HEAPF32[$10>>2];
 $12 = $11;
 $13 = ((($1)) + 56|0);
 $14 = HEAP8[$13>>0]|0;
 $15 = ($14<<24>>24)==(0);
 L1: do {
  if ($15) {
   $$024 = 1.0;$$025 = 1.0;
  } else {
   $16 = ((($1)) + 20|0);
   $17 = HEAP32[$16>>2]|0;
   switch ($17|0) {
   case 2:  {
    $$024 = 1.0;$$025 = 2.0;
    break L1;
    break;
   }
   case 3:  {
    $$024 = 2.0;$$025 = 1.0;
    break L1;
    break;
   }
   default: {
    $$024 = 1.0;$$025 = 1.0;
    break L1;
   }
   }
  }
 } while(0);
 $18 = ((($1)) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)==(3);
 if ($20) {
  __ZN3osg7Matrixd12makeIdentityEv($3);
  __ZN3osg7Matrixd9makeScaleEddd($3,$$025,$$024,1.0);
  __THREW__ = 0;
  invoke_vi(3299,($0|0));
  $21 = __THREW__; __THREW__ = 0;
  $22 = $21&1;
  if (!($22)) {
   __THREW__ = 0;
   invoke_viii(3300,($0|0),($3|0),($2|0));
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if (!($24)) {
    STACKTOP = sp;return;
   }
  }
  $25 = ___cxa_find_matching_catch_2()|0;
  $26 = tempRet0;
  $$2 = $26;$$223 = $25;
  ___resumeException($$223|0);
  // unreachable;
 }
 $27 = $12 * 2.0;
 $28 = $9 / $27;
 __ZN3osg7MatrixdC2Edddddddddddddddd($5,1.0,0.0,0.0,0.0,0.0,1.0,0.0,0.0,$28,0.0,1.0,0.0,0.0,0.0,0.0,1.0);
 __THREW__ = 0;
 invoke_vi(3299,($6|0));
 $29 = __THREW__; __THREW__ = 0;
 $30 = $29&1;
 if (!($30)) {
  __THREW__ = 0;
  invoke_viddd(3305,($6|0),(+$$025),(+$$024),1.0);
  $31 = __THREW__; __THREW__ = 0;
  $32 = $31&1;
  if (!($32)) {
   __THREW__ = 0;
   invoke_vi(3299,($4|0));
   $33 = __THREW__; __THREW__ = 0;
   $34 = $33&1;
   if (!($34)) {
    __THREW__ = 0;
    invoke_viii(3300,($4|0),($5|0),($6|0));
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if (!($36)) {
     __THREW__ = 0;
     invoke_vi(3299,($0|0));
     $37 = __THREW__; __THREW__ = 0;
     $38 = $37&1;
     if (!($38)) {
      __THREW__ = 0;
      invoke_viii(3300,($0|0),($4|0),($2|0));
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       STACKTOP = sp;return;
      }
     }
    }
   }
  }
 }
 $41 = ___cxa_find_matching_catch_2()|0;
 $42 = tempRet0;
 $$2 = $42;$$223 = $41;
 ___resumeException($$223|0);
 // unreachable;
}
function __ZNK3osg15DisplaySettings32computeLeftEyeViewImplementationERKNS_7MatrixdEd($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = +$3;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $4 = 0, $5 = 0, $6 = 0.0, $7 = 0.0, $8 = 0.0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(128|0);
 $4 = sp;
 $5 = ((($1)) + 24|0);
 $6 = +HEAPF32[$5>>2];
 $7 = $6;
 $8 = $7 * 0.5;
 $9 = $8 * $3;
 __ZN3osg7MatrixdC2Edddddddddddddddd($4,1.0,0.0,0.0,0.0,0.0,1.0,0.0,0.0,0.0,0.0,1.0,0.0,$9,0.0,0.0,1.0);
 __THREW__ = 0;
 invoke_vi(3299,($0|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if (!($11)) {
  __THREW__ = 0;
  invoke_viii(3300,($0|0),($2|0),($4|0));
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if (!($13)) {
   STACKTOP = sp;return;
  }
 }
 $14 = ___cxa_find_matching_catch_2()|0;
 $15 = tempRet0;
 ___resumeException($14|0);
 // unreachable;
}
function __ZNK3osg15DisplaySettings39computeRightEyeProjectionImplementationERKNS_7MatrixdE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$024 = 0.0, $$025 = 0.0, $$2 = 0, $$223 = 0, $10 = 0, $11 = 0.0, $12 = 0.0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0.0, $28 = 0.0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0.0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 512|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(512|0);
 $3 = sp + 384|0;
 $4 = sp + 256|0;
 $5 = sp + 128|0;
 $6 = sp;
 $7 = ((($1)) + 24|0);
 $8 = +HEAPF32[$7>>2];
 $9 = $8;
 $10 = ((($1)) + 36|0);
 $11 = +HEAPF32[$10>>2];
 $12 = $11;
 $13 = ((($1)) + 56|0);
 $14 = HEAP8[$13>>0]|0;
 $15 = ($14<<24>>24)==(0);
 L1: do {
  if ($15) {
   $$024 = 1.0;$$025 = 1.0;
  } else {
   $16 = ((($1)) + 20|0);
   $17 = HEAP32[$16>>2]|0;
   switch ($17|0) {
   case 2:  {
    $$024 = 1.0;$$025 = 2.0;
    break L1;
    break;
   }
   case 3:  {
    $$024 = 2.0;$$025 = 1.0;
    break L1;
    break;
   }
   default: {
    $$024 = 1.0;$$025 = 1.0;
    break L1;
   }
   }
  }
 } while(0);
 $18 = ((($1)) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)==(3);
 if ($20) {
  __ZN3osg7Matrixd12makeIdentityEv($3);
  __ZN3osg7Matrixd9makeScaleEddd($3,$$025,$$024,1.0);
  __THREW__ = 0;
  invoke_vi(3299,($0|0));
  $21 = __THREW__; __THREW__ = 0;
  $22 = $21&1;
  if (!($22)) {
   __THREW__ = 0;
   invoke_viii(3300,($0|0),($3|0),($2|0));
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if (!($24)) {
    STACKTOP = sp;return;
   }
  }
  $25 = ___cxa_find_matching_catch_2()|0;
  $26 = tempRet0;
  $$2 = $26;$$223 = $25;
  ___resumeException($$223|0);
  // unreachable;
 }
 $27 = -$9;
 $28 = $12 * 2.0;
 $29 = $27 / $28;
 __ZN3osg7MatrixdC2Edddddddddddddddd($5,1.0,0.0,0.0,0.0,0.0,1.0,0.0,0.0,$29,0.0,1.0,0.0,0.0,0.0,0.0,1.0);
 __THREW__ = 0;
 invoke_vi(3299,($6|0));
 $30 = __THREW__; __THREW__ = 0;
 $31 = $30&1;
 if (!($31)) {
  __THREW__ = 0;
  invoke_viddd(3305,($6|0),(+$$025),(+$$024),1.0);
  $32 = __THREW__; __THREW__ = 0;
  $33 = $32&1;
  if (!($33)) {
   __THREW__ = 0;
   invoke_vi(3299,($4|0));
   $34 = __THREW__; __THREW__ = 0;
   $35 = $34&1;
   if (!($35)) {
    __THREW__ = 0;
    invoke_viii(3300,($4|0),($5|0),($6|0));
    $36 = __THREW__; __THREW__ = 0;
    $37 = $36&1;
    if (!($37)) {
     __THREW__ = 0;
     invoke_vi(3299,($0|0));
     $38 = __THREW__; __THREW__ = 0;
     $39 = $38&1;
     if (!($39)) {
      __THREW__ = 0;
      invoke_viii(3300,($0|0),($4|0),($2|0));
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if (!($41)) {
       STACKTOP = sp;return;
      }
     }
    }
   }
  }
 }
 $42 = ___cxa_find_matching_catch_2()|0;
 $43 = tempRet0;
 $$2 = $43;$$223 = $42;
 ___resumeException($$223|0);
 // unreachable;
}
function __ZNK3osg15DisplaySettings33computeRightEyeViewImplementationERKNS_7MatrixdEd($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = +$3;
 var $10 = 0.0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $4 = 0, $5 = 0, $6 = 0.0, $7 = 0.0, $8 = 0.0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(128|0);
 $4 = sp;
 $5 = ((($1)) + 24|0);
 $6 = +HEAPF32[$5>>2];
 $7 = $6;
 $8 = $7 * 0.5;
 $9 = $8 * $3;
 $10 = -$9;
 __ZN3osg7MatrixdC2Edddddddddddddddd($4,1.0,0.0,0.0,0.0,0.0,1.0,0.0,0.0,0.0,0.0,1.0,0.0,$10,0.0,0.0,1.0);
 __THREW__ = 0;
 invoke_vi(3299,($0|0));
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if ($12) {
  $15 = ___cxa_find_matching_catch_2()|0;
  $16 = tempRet0;
  ___resumeException($15|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(3300,($0|0),($2|0),($4|0));
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 if ($14) {
  $15 = ___cxa_find_matching_catch_2()|0;
  $16 = tempRet0;
  ___resumeException($15|0);
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __GLOBAL__sub_I_DisplaySettings_cpp() {
 var $$0$i = 0, $$0$i107 = 0, $$0$i115 = 0, $$0$i123 = 0, $$0$i131 = 0, $$0$i139 = 0, $$0$i14 = 0, $$0$i147 = 0, $$0$i155 = 0, $$0$i163 = 0, $$0$i171 = 0, $$0$i179 = 0, $$0$i187 = 0, $$0$i195 = 0, $$0$i203 = 0, $$0$i211 = 0, $$0$i219 = 0, $$0$i227 = 0, $$0$i235 = 0, $$0$i243 = 0;
 var $$0$i251 = 0, $$0$i27 = 0, $$0$i35 = 0, $$0$i43 = 0, $$0$i51 = 0, $$0$i59 = 0, $$0$i6 = 0, $$0$i67 = 0, $$0$i75 = 0, $$0$i83 = 0, $$0$i91 = 0, $$0$i99 = 0, $$01$i = 0, $$01$i106 = 0, $$01$i114 = 0, $$01$i122 = 0, $$01$i13 = 0, $$01$i130 = 0, $$01$i138 = 0, $$01$i146 = 0;
 var $$01$i154 = 0, $$01$i162 = 0, $$01$i170 = 0, $$01$i178 = 0, $$01$i186 = 0, $$01$i194 = 0, $$01$i202 = 0, $$01$i210 = 0, $$01$i218 = 0, $$01$i226 = 0, $$01$i234 = 0, $$01$i242 = 0, $$01$i250 = 0, $$01$i26 = 0, $$01$i34 = 0, $$01$i42 = 0, $$01$i5 = 0, $$01$i50 = 0, $$01$i58 = 0, $$01$i66 = 0;
 var $$01$i74 = 0, $$01$i82 = 0, $$01$i90 = 0, $$01$i98 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $1000 = 0, $1001 = 0, $1002 = 0, $1003 = 0, $1004 = 0, $1005 = 0, $1006 = 0, $1007 = 0, $1008 = 0, $1009 = 0, $101 = 0, $1010 = 0;
 var $1011 = 0, $1012 = 0, $1013 = 0, $1014 = 0, $1015 = 0, $1016 = 0, $1017 = 0, $1018 = 0, $1019 = 0, $102 = 0, $1020 = 0, $1021 = 0, $1022 = 0, $1023 = 0, $1024 = 0, $1025 = 0, $1026 = 0, $1027 = 0, $1028 = 0, $1029 = 0;
 var $103 = 0, $1030 = 0, $1031 = 0, $1032 = 0, $1033 = 0, $1034 = 0, $1035 = 0, $1036 = 0, $1037 = 0, $1038 = 0, $1039 = 0, $104 = 0, $1040 = 0, $1041 = 0, $1042 = 0, $1043 = 0, $1044 = 0, $1045 = 0, $1046 = 0, $1047 = 0;
 var $1048 = 0, $1049 = 0, $105 = 0, $1050 = 0, $1051 = 0, $1052 = 0, $1053 = 0, $1054 = 0, $1055 = 0, $1056 = 0, $1057 = 0, $1058 = 0, $1059 = 0, $106 = 0, $1060 = 0, $1061 = 0, $1062 = 0, $1063 = 0, $1064 = 0, $1065 = 0;
 var $1066 = 0, $1067 = 0, $1068 = 0, $1069 = 0, $107 = 0, $1070 = 0, $1071 = 0, $1072 = 0, $1073 = 0, $1074 = 0, $1075 = 0, $1076 = 0, $1077 = 0, $1078 = 0, $1079 = 0, $108 = 0, $1080 = 0, $1081 = 0, $1082 = 0, $1083 = 0;
 var $1084 = 0, $1085 = 0, $1086 = 0, $1087 = 0, $1088 = 0, $1089 = 0, $109 = 0, $1090 = 0, $1091 = 0, $1092 = 0, $1093 = 0, $1094 = 0, $1095 = 0, $1096 = 0, $1097 = 0, $1098 = 0, $1099 = 0, $11 = 0, $110 = 0, $1100 = 0;
 var $1101 = 0, $1102 = 0, $1103 = 0, $1104 = 0, $1105 = 0, $1106 = 0, $1107 = 0, $1108 = 0, $1109 = 0, $111 = 0, $1110 = 0, $1111 = 0, $1112 = 0, $1113 = 0, $1114 = 0, $1115 = 0, $1116 = 0, $1117 = 0, $1118 = 0, $1119 = 0;
 var $112 = 0, $1120 = 0, $1121 = 0, $1122 = 0, $1123 = 0, $1124 = 0, $1125 = 0, $1126 = 0, $1127 = 0, $1128 = 0, $1129 = 0, $113 = 0, $1130 = 0, $1131 = 0, $1132 = 0, $1133 = 0, $1134 = 0, $1135 = 0, $1136 = 0, $1137 = 0;
 var $1138 = 0, $1139 = 0, $114 = 0, $1140 = 0, $1141 = 0, $1142 = 0, $1143 = 0, $1144 = 0, $1145 = 0, $1146 = 0, $1147 = 0, $1148 = 0, $1149 = 0, $115 = 0, $1150 = 0, $1151 = 0, $1152 = 0, $1153 = 0, $1154 = 0, $1155 = 0;
 var $1156 = 0, $1157 = 0, $1158 = 0, $1159 = 0, $116 = 0, $1160 = 0, $1161 = 0, $1162 = 0, $1163 = 0, $1164 = 0, $1165 = 0, $1166 = 0, $1167 = 0, $1168 = 0, $1169 = 0, $117 = 0, $1170 = 0, $1171 = 0, $1172 = 0, $1173 = 0;
 var $1174 = 0, $1175 = 0, $1176 = 0, $1177 = 0, $1178 = 0, $1179 = 0, $118 = 0, $1180 = 0, $1181 = 0, $1182 = 0, $1183 = 0, $1184 = 0, $1185 = 0, $1186 = 0, $1187 = 0, $1188 = 0, $1189 = 0, $119 = 0, $1190 = 0, $1191 = 0;
 var $1192 = 0, $1193 = 0, $1194 = 0, $1195 = 0, $1196 = 0, $1197 = 0, $1198 = 0, $1199 = 0, $12 = 0, $120 = 0, $1200 = 0, $1201 = 0, $1202 = 0, $1203 = 0, $1204 = 0, $1205 = 0, $1206 = 0, $1207 = 0, $1208 = 0, $1209 = 0;
 var $121 = 0, $1210 = 0, $1211 = 0, $1212 = 0, $1213 = 0, $1214 = 0, $1215 = 0, $1216 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0;
 var $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0;
 var $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0;
 var $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0;
 var $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0;
 var $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0;
 var $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0;
 var $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0;
 var $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0;
 var $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0;
 var $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0;
 var $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0;
 var $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0;
 var $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0;
 var $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0;
 var $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0;
 var $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0;
 var $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0;
 var $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0;
 var $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0;
 var $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0;
 var $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0;
 var $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0;
 var $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0;
 var $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0;
 var $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0;
 var $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0;
 var $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0;
 var $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0;
 var $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0;
 var $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0;
 var $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0;
 var $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0;
 var $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0;
 var $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0;
 var $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = 0, $834 = 0, $835 = 0;
 var $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0, $850 = 0, $851 = 0, $852 = 0, $853 = 0;
 var $854 = 0, $855 = 0, $856 = 0, $857 = 0, $858 = 0, $859 = 0, $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0, $869 = 0, $87 = 0, $870 = 0, $871 = 0;
 var $872 = 0, $873 = 0, $874 = 0, $875 = 0, $876 = 0, $877 = 0, $878 = 0, $879 = 0, $88 = 0, $880 = 0, $881 = 0, $882 = 0, $883 = 0, $884 = 0, $885 = 0, $886 = 0, $887 = 0, $888 = 0, $889 = 0, $89 = 0;
 var $890 = 0, $891 = 0, $892 = 0, $893 = 0, $894 = 0, $895 = 0, $896 = 0, $897 = 0, $898 = 0, $899 = 0, $9 = 0, $90 = 0, $900 = 0, $901 = 0, $902 = 0, $903 = 0, $904 = 0, $905 = 0, $906 = 0, $907 = 0;
 var $908 = 0, $909 = 0, $91 = 0, $910 = 0, $911 = 0, $912 = 0, $913 = 0, $914 = 0, $915 = 0, $916 = 0, $917 = 0, $918 = 0, $919 = 0, $92 = 0, $920 = 0, $921 = 0, $922 = 0, $923 = 0, $924 = 0, $925 = 0;
 var $926 = 0, $927 = 0, $928 = 0, $929 = 0, $93 = 0, $930 = 0, $931 = 0, $932 = 0, $933 = 0, $934 = 0, $935 = 0, $936 = 0, $937 = 0, $938 = 0, $939 = 0, $94 = 0, $940 = 0, $941 = 0, $942 = 0, $943 = 0;
 var $944 = 0, $945 = 0, $946 = 0, $947 = 0, $948 = 0, $949 = 0, $95 = 0, $950 = 0, $951 = 0, $952 = 0, $953 = 0, $954 = 0, $955 = 0, $956 = 0, $957 = 0, $958 = 0, $959 = 0, $96 = 0, $960 = 0, $961 = 0;
 var $962 = 0, $963 = 0, $964 = 0, $965 = 0, $966 = 0, $967 = 0, $968 = 0, $969 = 0, $97 = 0, $970 = 0, $971 = 0, $972 = 0, $973 = 0, $974 = 0, $975 = 0, $976 = 0, $977 = 0, $978 = 0, $979 = 0, $98 = 0;
 var $980 = 0, $981 = 0, $982 = 0, $983 = 0, $984 = 0, $985 = 0, $986 = 0, $987 = 0, $988 = 0, $989 = 0, $99 = 0, $990 = 0, $991 = 0, $992 = 0, $993 = 0, $994 = 0, $995 = 0, $996 = 0, $997 = 0, $998 = 0;
 var $999 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 800|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(800|0);
 $0 = sp + 780|0;
 $1 = sp + 768|0;
 $2 = sp + 756|0;
 $3 = sp + 744|0;
 $4 = sp + 732|0;
 $5 = sp + 720|0;
 $6 = sp + 708|0;
 $7 = sp + 696|0;
 $8 = sp + 684|0;
 $9 = sp + 672|0;
 $10 = sp + 660|0;
 $11 = sp + 648|0;
 $12 = sp + 636|0;
 $13 = sp + 624|0;
 $14 = sp + 612|0;
 $15 = sp + 600|0;
 $16 = sp + 588|0;
 $17 = sp + 576|0;
 $18 = sp + 564|0;
 $19 = sp + 552|0;
 $20 = sp + 540|0;
 $21 = sp + 528|0;
 $22 = sp + 516|0;
 $23 = sp + 504|0;
 $24 = sp + 492|0;
 $25 = sp + 480|0;
 $26 = sp + 468|0;
 $27 = sp + 456|0;
 $28 = sp + 444|0;
 $29 = sp + 432|0;
 $30 = sp + 420|0;
 $31 = sp + 408|0;
 $32 = sp + 396|0;
 $33 = sp + 384|0;
 $34 = sp + 372|0;
 $35 = sp + 360|0;
 $36 = sp + 348|0;
 $37 = sp + 336|0;
 $38 = sp + 324|0;
 $39 = sp + 312|0;
 $40 = sp + 300|0;
 $41 = sp + 288|0;
 $42 = sp + 276|0;
 $43 = sp + 264|0;
 $44 = sp + 252|0;
 $45 = sp + 240|0;
 $46 = sp + 228|0;
 $47 = sp + 216|0;
 $48 = sp + 204|0;
 $49 = sp + 192|0;
 $50 = sp + 180|0;
 $51 = sp + 168|0;
 $52 = sp + 156|0;
 $53 = sp + 144|0;
 $54 = sp + 132|0;
 $55 = sp + 120|0;
 $56 = sp + 108|0;
 $57 = sp + 96|0;
 $58 = sp + 84|0;
 $59 = sp;
 $60 = sp + 72|0;
 $61 = sp + 60|0;
 $62 = sp + 48|0;
 $63 = sp + 36|0;
 $64 = sp + 24|0;
 $65 = sp + 12|0;
 HEAPF32[52044] = 1.0;
 HEAPF32[(208180)>>2] = 0.0;
 HEAPF32[(208184)>>2] = 0.0;
 HEAPF32[52047] = 0.0;
 HEAPF32[(208192)>>2] = 1.0;
 HEAPF32[(208196)>>2] = 0.0;
 HEAPF32[52050] = 0.0;
 HEAPF32[(208204)>>2] = 0.0;
 HEAPF32[(208208)>>2] = 1.0;
 (__ZN3osg15DisplaySettings8instanceEv()|0);
 $66 = (__Znwj(32)|0);
 HEAP32[$62>>2] = $66;
 $67 = ((($62)) + 8|0);
 HEAP32[$67>>2] = -2147483616;
 $68 = ((($62)) + 4|0);
 HEAP32[$68>>2] = 23;
 dest=$66; src=121579; stop=dest+23|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $69 = ((($66)) + 23|0);
 HEAP8[$69>>0] = 0;
 ;HEAP32[$63>>2]=0|0;HEAP32[$63+4>>2]=0|0;HEAP32[$63+8>>2]=0|0;
 __THREW__ = 0;
 $70 = (invoke_ii(3276,64)|0);
 $71 = __THREW__; __THREW__ = 0;
 $72 = $71&1;
 if ($72) {
  $89 = ___cxa_find_matching_catch_2()|0;
  $90 = tempRet0;
  $$0$i6 = $90;$$01$i5 = $89;
 } else {
  HEAP32[$63>>2] = $70;
  $73 = ((($63)) + 8|0);
  HEAP32[$73>>2] = -2147483584;
  $74 = ((($63)) + 4|0);
  HEAP32[$74>>2] = 59;
  dest=$70; src=121603; stop=dest+59|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
  $75 = ((($70)) + 59|0);
  HEAP8[$75>>0] = 0;
  __THREW__ = 0;
  $76 = (invoke_i(3459)|0);
  $77 = __THREW__; __THREW__ = 0;
  $78 = $77&1;
  if (!($78)) {
   __THREW__ = 0;
   invoke_viiii(3460,($76|0),2,($62|0),($63|0));
   $79 = __THREW__; __THREW__ = 0;
   $80 = $79&1;
   if (!($80)) {
    $81 = ((($63)) + 11|0);
    $82 = HEAP8[$81>>0]|0;
    $83 = ($82<<24>>24)<(0);
    if ($83) {
     $84 = HEAP32[$63>>2]|0;
     __ZdlPv($84);
    }
    $85 = ((($62)) + 11|0);
    $86 = HEAP8[$85>>0]|0;
    $87 = ($86<<24>>24)<(0);
    if ($87) {
     $88 = HEAP32[$62>>2]|0;
     __ZdlPv($88);
    }
    $101 = (__Znwj(32)|0);
    HEAP32[$60>>2] = $101;
    $102 = ((($60)) + 8|0);
    HEAP32[$102>>2] = -2147483616;
    $103 = ((($60)) + 4|0);
    HEAP32[$103>>2] = 22;
    dest=$101; src=121663; stop=dest+22|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
    $104 = ((($101)) + 22|0);
    HEAP8[$104>>0] = 0;
    ;HEAP32[$61>>2]=0|0;HEAP32[$61+4>>2]=0|0;HEAP32[$61+8>>2]=0|0;
    __THREW__ = 0;
    $105 = (invoke_ii(3276,128)|0);
    $106 = __THREW__; __THREW__ = 0;
    $107 = $106&1;
    if ($107) {
     $124 = ___cxa_find_matching_catch_2()|0;
     $125 = tempRet0;
     $$0$i14 = $125;$$01$i13 = $124;
    } else {
     HEAP32[$61>>2] = $105;
     $108 = ((($61)) + 8|0);
     HEAP32[$108>>2] = -2147483520;
     $109 = ((($61)) + 4|0);
     HEAP32[$109>>2] = 127;
     dest=$105; src=121686; stop=dest+127|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
     $110 = ((($105)) + 127|0);
     HEAP8[$110>>0] = 0;
     __THREW__ = 0;
     $111 = (invoke_i(3459)|0);
     $112 = __THREW__; __THREW__ = 0;
     $113 = $112&1;
     if (!($113)) {
      __THREW__ = 0;
      invoke_viiii(3460,($111|0),2,($60|0),($61|0));
      $114 = __THREW__; __THREW__ = 0;
      $115 = $114&1;
      if (!($115)) {
       $116 = ((($61)) + 11|0);
       $117 = HEAP8[$116>>0]|0;
       $118 = ($117<<24>>24)<(0);
       if ($118) {
        $119 = HEAP32[$61>>2]|0;
        __ZdlPv($119);
       }
       $120 = ((($60)) + 11|0);
       $121 = HEAP8[$120>>0]|0;
       $122 = ($121<<24>>24)<(0);
       if ($122) {
        $123 = HEAP32[$60>>2]|0;
        __ZdlPv($123);
       }
       $136 = (__Znwj(32)|0);
       HEAP32[$58>>2] = $136;
       $137 = ((($58)) + 8|0);
       HEAP32[$137>>2] = -2147483616;
       $138 = ((($58)) + 4|0);
       HEAP32[$138>>2] = 17;
       dest=$136; src=121814; stop=dest+17|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
       $139 = ((($136)) + 17|0);
       HEAP8[$139>>0] = 0;
       ;HEAP32[$59>>2]=0|0;HEAP32[$59+4>>2]=0|0;HEAP32[$59+8>>2]=0|0;
       $140 = ((($59)) + 11|0);
       HEAP8[$140>>0] = 8;
       $141 = $59;
       $142 = $141;
       HEAP32[$142>>2] = 541476431;
       $143 = (($141) + 4)|0;
       $144 = $143;
       HEAP32[$144>>2] = 1313808508;
       $145 = ((($59)) + 8|0);
       HEAP8[$145>>0] = 0;
       __THREW__ = 0;
       $146 = (invoke_i(3459)|0);
       $147 = __THREW__; __THREW__ = 0;
       $148 = $147&1;
       if (!($148)) {
        __THREW__ = 0;
        invoke_viiii(3460,($146|0),2,($58|0),($59|0));
        $149 = __THREW__; __THREW__ = 0;
        $150 = $149&1;
        if (!($150)) {
         $151 = HEAP8[$140>>0]|0;
         $152 = ($151<<24>>24)<(0);
         if ($152) {
          $153 = HEAP32[$59>>2]|0;
          __ZdlPv($153);
         }
         $154 = ((($58)) + 11|0);
         $155 = HEAP8[$154>>0]|0;
         $156 = ($155<<24>>24)<(0);
         if ($156) {
          $157 = HEAP32[$58>>2]|0;
          __ZdlPv($157);
         }
         $167 = (__Znwj(32)|0);
         HEAP32[$56>>2] = $167;
         $168 = ((($56)) + 8|0);
         HEAP32[$168>>2] = -2147483616;
         $169 = ((($56)) + 4|0);
         HEAP32[$169>>2] = 26;
         dest=$167; src=121832; stop=dest+26|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
         $170 = ((($167)) + 26|0);
         HEAP8[$170>>0] = 0;
         ;HEAP32[$57>>2]=0|0;HEAP32[$57+4>>2]=0|0;HEAP32[$57+8>>2]=0|0;
         __THREW__ = 0;
         $171 = (invoke_ii(3276,32)|0);
         $172 = __THREW__; __THREW__ = 0;
         $173 = $172&1;
         do {
          if ($173) {
           $190 = ___cxa_find_matching_catch_2()|0;
           $191 = tempRet0;
           $$0$i27 = $191;$$01$i26 = $190;
          } else {
           HEAP32[$57>>2] = $171;
           $174 = ((($57)) + 8|0);
           HEAP32[$174>>2] = -2147483616;
           $175 = ((($57)) + 4|0);
           HEAP32[$175>>2] = 31;
           dest=$171; src=121859; stop=dest+31|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
           $176 = ((($171)) + 31|0);
           HEAP8[$176>>0] = 0;
           __THREW__ = 0;
           $177 = (invoke_i(3459)|0);
           $178 = __THREW__; __THREW__ = 0;
           $179 = $178&1;
           do {
            if (!($179)) {
             __THREW__ = 0;
             invoke_viiii(3460,($177|0),2,($56|0),($57|0));
             $180 = __THREW__; __THREW__ = 0;
             $181 = $180&1;
             if ($181) {
              break;
             }
             $182 = ((($57)) + 11|0);
             $183 = HEAP8[$182>>0]|0;
             $184 = ($183<<24>>24)<(0);
             if ($184) {
              $185 = HEAP32[$57>>2]|0;
              __ZdlPv($185);
             }
             $186 = ((($56)) + 11|0);
             $187 = HEAP8[$186>>0]|0;
             $188 = ($187<<24>>24)<(0);
             if ($188) {
              $189 = HEAP32[$56>>2]|0;
              __ZdlPv($189);
             }
             $202 = (__Znwj(32)|0);
             HEAP32[$54>>2] = $202;
             $203 = ((($54)) + 8|0);
             HEAP32[$203>>2] = -2147483616;
             $204 = ((($54)) + 4|0);
             HEAP32[$204>>2] = 27;
             dest=$202; src=121891; stop=dest+27|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
             $205 = ((($202)) + 27|0);
             HEAP8[$205>>0] = 0;
             ;HEAP32[$55>>2]=0|0;HEAP32[$55+4>>2]=0|0;HEAP32[$55+8>>2]=0|0;
             __THREW__ = 0;
             $206 = (invoke_ii(3276,48)|0);
             $207 = __THREW__; __THREW__ = 0;
             $208 = $207&1;
             do {
              if ($208) {
               $225 = ___cxa_find_matching_catch_2()|0;
               $226 = tempRet0;
               $$0$i35 = $226;$$01$i34 = $225;
              } else {
               HEAP32[$55>>2] = $206;
               $209 = ((($55)) + 8|0);
               HEAP32[$209>>2] = -2147483600;
               $210 = ((($55)) + 4|0);
               HEAP32[$210>>2] = 42;
               dest=$206; src=121919; stop=dest+42|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
               $211 = ((($206)) + 42|0);
               HEAP8[$211>>0] = 0;
               __THREW__ = 0;
               $212 = (invoke_i(3459)|0);
               $213 = __THREW__; __THREW__ = 0;
               $214 = $213&1;
               do {
                if (!($214)) {
                 __THREW__ = 0;
                 invoke_viiii(3460,($212|0),2,($54|0),($55|0));
                 $215 = __THREW__; __THREW__ = 0;
                 $216 = $215&1;
                 if ($216) {
                  break;
                 }
                 $217 = ((($55)) + 11|0);
                 $218 = HEAP8[$217>>0]|0;
                 $219 = ($218<<24>>24)<(0);
                 if ($219) {
                  $220 = HEAP32[$55>>2]|0;
                  __ZdlPv($220);
                 }
                 $221 = ((($54)) + 11|0);
                 $222 = HEAP8[$221>>0]|0;
                 $223 = ($222<<24>>24)<(0);
                 if ($223) {
                  $224 = HEAP32[$54>>2]|0;
                  __ZdlPv($224);
                 }
                 $237 = (__Znwj(32)|0);
                 HEAP32[$52>>2] = $237;
                 $238 = ((($52)) + 8|0);
                 HEAP32[$238>>2] = -2147483616;
                 $239 = ((($52)) + 4|0);
                 HEAP32[$239>>2] = 25;
                 dest=$237; src=121962; stop=dest+25|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                 $240 = ((($237)) + 25|0);
                 HEAP8[$240>>0] = 0;
                 ;HEAP32[$53>>2]=0|0;HEAP32[$53+4>>2]=0|0;HEAP32[$53+8>>2]=0|0;
                 __THREW__ = 0;
                 $241 = (invoke_ii(3276,32)|0);
                 $242 = __THREW__; __THREW__ = 0;
                 $243 = $242&1;
                 do {
                  if ($243) {
                   $260 = ___cxa_find_matching_catch_2()|0;
                   $261 = tempRet0;
                   $$0$i43 = $261;$$01$i42 = $260;
                  } else {
                   HEAP32[$53>>2] = $241;
                   $244 = ((($53)) + 8|0);
                   HEAP32[$244>>2] = -2147483616;
                   $245 = ((($53)) + 4|0);
                   HEAP32[$245>>2] = 23;
                   dest=$241; src=121988; stop=dest+23|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                   $246 = ((($241)) + 23|0);
                   HEAP8[$246>>0] = 0;
                   __THREW__ = 0;
                   $247 = (invoke_i(3459)|0);
                   $248 = __THREW__; __THREW__ = 0;
                   $249 = $248&1;
                   do {
                    if (!($249)) {
                     __THREW__ = 0;
                     invoke_viiii(3460,($247|0),2,($52|0),($53|0));
                     $250 = __THREW__; __THREW__ = 0;
                     $251 = $250&1;
                     if ($251) {
                      break;
                     }
                     $252 = ((($53)) + 11|0);
                     $253 = HEAP8[$252>>0]|0;
                     $254 = ($253<<24>>24)<(0);
                     if ($254) {
                      $255 = HEAP32[$53>>2]|0;
                      __ZdlPv($255);
                     }
                     $256 = ((($52)) + 11|0);
                     $257 = HEAP8[$256>>0]|0;
                     $258 = ($257<<24>>24)<(0);
                     if ($258) {
                      $259 = HEAP32[$52>>2]|0;
                      __ZdlPv($259);
                     }
                     $272 = (__Znwj(32)|0);
                     HEAP32[$50>>2] = $272;
                     $273 = ((($50)) + 8|0);
                     HEAP32[$273>>2] = -2147483616;
                     $274 = ((($50)) + 4|0);
                     HEAP32[$274>>2] = 24;
                     dest=$272; src=122012; stop=dest+24|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                     $275 = ((($272)) + 24|0);
                     HEAP8[$275>>0] = 0;
                     ;HEAP32[$51>>2]=0|0;HEAP32[$51+4>>2]=0|0;HEAP32[$51+8>>2]=0|0;
                     __THREW__ = 0;
                     $276 = (invoke_ii(3276,32)|0);
                     $277 = __THREW__; __THREW__ = 0;
                     $278 = $277&1;
                     do {
                      if ($278) {
                       $295 = ___cxa_find_matching_catch_2()|0;
                       $296 = tempRet0;
                       $$0$i51 = $296;$$01$i50 = $295;
                      } else {
                       HEAP32[$51>>2] = $276;
                       $279 = ((($51)) + 8|0);
                       HEAP32[$279>>2] = -2147483616;
                       $280 = ((($51)) + 4|0);
                       HEAP32[$280>>2] = 22;
                       dest=$276; src=122037; stop=dest+22|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                       $281 = ((($276)) + 22|0);
                       HEAP8[$281>>0] = 0;
                       __THREW__ = 0;
                       $282 = (invoke_i(3459)|0);
                       $283 = __THREW__; __THREW__ = 0;
                       $284 = $283&1;
                       do {
                        if (!($284)) {
                         __THREW__ = 0;
                         invoke_viiii(3460,($282|0),2,($50|0),($51|0));
                         $285 = __THREW__; __THREW__ = 0;
                         $286 = $285&1;
                         if ($286) {
                          break;
                         }
                         $287 = ((($51)) + 11|0);
                         $288 = HEAP8[$287>>0]|0;
                         $289 = ($288<<24>>24)<(0);
                         if ($289) {
                          $290 = HEAP32[$51>>2]|0;
                          __ZdlPv($290);
                         }
                         $291 = ((($50)) + 11|0);
                         $292 = HEAP8[$291>>0]|0;
                         $293 = ($292<<24>>24)<(0);
                         if ($293) {
                          $294 = HEAP32[$50>>2]|0;
                          __ZdlPv($294);
                         }
                         $307 = (__Znwj(48)|0);
                         HEAP32[$48>>2] = $307;
                         $308 = ((($48)) + 8|0);
                         HEAP32[$308>>2] = -2147483600;
                         $309 = ((($48)) + 4|0);
                         HEAP32[$309>>2] = 46;
                         dest=$307; src=122060; stop=dest+46|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                         $310 = ((($307)) + 46|0);
                         HEAP8[$310>>0] = 0;
                         ;HEAP32[$49>>2]=0|0;HEAP32[$49+4>>2]=0|0;HEAP32[$49+8>>2]=0|0;
                         __THREW__ = 0;
                         $311 = (invoke_ii(3276,64)|0);
                         $312 = __THREW__; __THREW__ = 0;
                         $313 = $312&1;
                         do {
                          if ($313) {
                           $330 = ___cxa_find_matching_catch_2()|0;
                           $331 = tempRet0;
                           $$0$i59 = $331;$$01$i58 = $330;
                          } else {
                           HEAP32[$49>>2] = $311;
                           $314 = ((($49)) + 8|0);
                           HEAP32[$314>>2] = -2147483584;
                           $315 = ((($49)) + 4|0);
                           HEAP32[$315>>2] = 48;
                           dest=$311; src=122107; stop=dest+48|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                           $316 = ((($311)) + 48|0);
                           HEAP8[$316>>0] = 0;
                           __THREW__ = 0;
                           $317 = (invoke_i(3459)|0);
                           $318 = __THREW__; __THREW__ = 0;
                           $319 = $318&1;
                           do {
                            if (!($319)) {
                             __THREW__ = 0;
                             invoke_viiii(3460,($317|0),2,($48|0),($49|0));
                             $320 = __THREW__; __THREW__ = 0;
                             $321 = $320&1;
                             if ($321) {
                              break;
                             }
                             $322 = ((($49)) + 11|0);
                             $323 = HEAP8[$322>>0]|0;
                             $324 = ($323<<24>>24)<(0);
                             if ($324) {
                              $325 = HEAP32[$49>>2]|0;
                              __ZdlPv($325);
                             }
                             $326 = ((($48)) + 11|0);
                             $327 = HEAP8[$326>>0]|0;
                             $328 = ($327<<24>>24)<(0);
                             if ($328) {
                              $329 = HEAP32[$48>>2]|0;
                              __ZdlPv($329);
                             }
                             $342 = (__Znwj(48)|0);
                             HEAP32[$46>>2] = $342;
                             $343 = ((($46)) + 8|0);
                             HEAP32[$343>>2] = -2147483600;
                             $344 = ((($46)) + 4|0);
                             HEAP32[$344>>2] = 46;
                             dest=$342; src=122156; stop=dest+46|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                             $345 = ((($342)) + 46|0);
                             HEAP8[$345>>0] = 0;
                             ;HEAP32[$47>>2]=0|0;HEAP32[$47+4>>2]=0|0;HEAP32[$47+8>>2]=0|0;
                             __THREW__ = 0;
                             $346 = (invoke_ii(3276,48)|0);
                             $347 = __THREW__; __THREW__ = 0;
                             $348 = $347&1;
                             do {
                              if ($348) {
                               $365 = ___cxa_find_matching_catch_2()|0;
                               $366 = tempRet0;
                               $$0$i67 = $366;$$01$i66 = $365;
                              } else {
                               HEAP32[$47>>2] = $346;
                               $349 = ((($47)) + 8|0);
                               HEAP32[$349>>2] = -2147483600;
                               $350 = ((($47)) + 4|0);
                               HEAP32[$350>>2] = 35;
                               dest=$346; src=122203; stop=dest+35|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                               $351 = ((($346)) + 35|0);
                               HEAP8[$351>>0] = 0;
                               __THREW__ = 0;
                               $352 = (invoke_i(3459)|0);
                               $353 = __THREW__; __THREW__ = 0;
                               $354 = $353&1;
                               do {
                                if (!($354)) {
                                 __THREW__ = 0;
                                 invoke_viiii(3460,($352|0),2,($46|0),($47|0));
                                 $355 = __THREW__; __THREW__ = 0;
                                 $356 = $355&1;
                                 if ($356) {
                                  break;
                                 }
                                 $357 = ((($47)) + 11|0);
                                 $358 = HEAP8[$357>>0]|0;
                                 $359 = ($358<<24>>24)<(0);
                                 if ($359) {
                                  $360 = HEAP32[$47>>2]|0;
                                  __ZdlPv($360);
                                 }
                                 $361 = ((($46)) + 11|0);
                                 $362 = HEAP8[$361>>0]|0;
                                 $363 = ($362<<24>>24)<(0);
                                 if ($363) {
                                  $364 = HEAP32[$46>>2]|0;
                                  __ZdlPv($364);
                                 }
                                 $377 = (__Znwj(48)|0);
                                 HEAP32[$44>>2] = $377;
                                 $378 = ((($44)) + 8|0);
                                 HEAP32[$378>>2] = -2147483600;
                                 $379 = ((($44)) + 4|0);
                                 HEAP32[$379>>2] = 44;
                                 dest=$377; src=122239; stop=dest+44|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                                 $380 = ((($377)) + 44|0);
                                 HEAP8[$380>>0] = 0;
                                 ;HEAP32[$45>>2]=0|0;HEAP32[$45+4>>2]=0|0;HEAP32[$45+8>>2]=0|0;
                                 __THREW__ = 0;
                                 $381 = (invoke_ii(3276,64)|0);
                                 $382 = __THREW__; __THREW__ = 0;
                                 $383 = $382&1;
                                 do {
                                  if ($383) {
                                   $400 = ___cxa_find_matching_catch_2()|0;
                                   $401 = tempRet0;
                                   $$0$i75 = $401;$$01$i74 = $400;
                                  } else {
                                   HEAP32[$45>>2] = $381;
                                   $384 = ((($45)) + 8|0);
                                   HEAP32[$384>>2] = -2147483584;
                                   $385 = ((($45)) + 4|0);
                                   HEAP32[$385>>2] = 48;
                                   dest=$381; src=122284; stop=dest+48|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                                   $386 = ((($381)) + 48|0);
                                   HEAP8[$386>>0] = 0;
                                   __THREW__ = 0;
                                   $387 = (invoke_i(3459)|0);
                                   $388 = __THREW__; __THREW__ = 0;
                                   $389 = $388&1;
                                   do {
                                    if (!($389)) {
                                     __THREW__ = 0;
                                     invoke_viiii(3460,($387|0),2,($44|0),($45|0));
                                     $390 = __THREW__; __THREW__ = 0;
                                     $391 = $390&1;
                                     if ($391) {
                                      break;
                                     }
                                     $392 = ((($45)) + 11|0);
                                     $393 = HEAP8[$392>>0]|0;
                                     $394 = ($393<<24>>24)<(0);
                                     if ($394) {
                                      $395 = HEAP32[$45>>2]|0;
                                      __ZdlPv($395);
                                     }
                                     $396 = ((($44)) + 11|0);
                                     $397 = HEAP8[$396>>0]|0;
                                     $398 = ($397<<24>>24)<(0);
                                     if ($398) {
                                      $399 = HEAP32[$44>>2]|0;
                                      __ZdlPv($399);
                                     }
                                     $412 = (__Znwj(64)|0);
                                     HEAP32[$42>>2] = $412;
                                     $413 = ((($42)) + 8|0);
                                     HEAP32[$413>>2] = -2147483584;
                                     $414 = ((($42)) + 4|0);
                                     HEAP32[$414>>2] = 48;
                                     dest=$412; src=122333; stop=dest+48|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                                     $415 = ((($412)) + 48|0);
                                     HEAP8[$415>>0] = 0;
                                     ;HEAP32[$43>>2]=0|0;HEAP32[$43+4>>2]=0|0;HEAP32[$43+8>>2]=0|0;
                                     __THREW__ = 0;
                                     $416 = (invoke_ii(3276,192)|0);
                                     $417 = __THREW__; __THREW__ = 0;
                                     $418 = $417&1;
                                     do {
                                      if ($418) {
                                       $435 = ___cxa_find_matching_catch_2()|0;
                                       $436 = tempRet0;
                                       $$0$i83 = $436;$$01$i82 = $435;
                                      } else {
                                       HEAP32[$43>>2] = $416;
                                       $419 = ((($43)) + 8|0);
                                       HEAP32[$419>>2] = -2147483456;
                                       $420 = ((($43)) + 4|0);
                                       HEAP32[$420>>2] = 188;
                                       _memcpy(($416|0),(122382|0),188)|0;
                                       $421 = ((($416)) + 188|0);
                                       HEAP8[$421>>0] = 0;
                                       __THREW__ = 0;
                                       $422 = (invoke_i(3459)|0);
                                       $423 = __THREW__; __THREW__ = 0;
                                       $424 = $423&1;
                                       do {
                                        if (!($424)) {
                                         __THREW__ = 0;
                                         invoke_viiii(3460,($422|0),2,($42|0),($43|0));
                                         $425 = __THREW__; __THREW__ = 0;
                                         $426 = $425&1;
                                         if ($426) {
                                          break;
                                         }
                                         $427 = ((($43)) + 11|0);
                                         $428 = HEAP8[$427>>0]|0;
                                         $429 = ($428<<24>>24)<(0);
                                         if ($429) {
                                          $430 = HEAP32[$43>>2]|0;
                                          __ZdlPv($430);
                                         }
                                         $431 = ((($42)) + 11|0);
                                         $432 = HEAP8[$431>>0]|0;
                                         $433 = ($432<<24>>24)<(0);
                                         if ($433) {
                                          $434 = HEAP32[$42>>2]|0;
                                          __ZdlPv($434);
                                         }
                                         $447 = (__Znwj(48)|0);
                                         HEAP32[$40>>2] = $447;
                                         $448 = ((($40)) + 8|0);
                                         HEAP32[$448>>2] = -2147483600;
                                         $449 = ((($40)) + 4|0);
                                         HEAP32[$449>>2] = 44;
                                         dest=$447; src=122571; stop=dest+44|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                                         $450 = ((($447)) + 44|0);
                                         HEAP8[$450>>0] = 0;
                                         ;HEAP32[$41>>2]=0|0;HEAP32[$41+4>>2]=0|0;HEAP32[$41+8>>2]=0|0;
                                         __THREW__ = 0;
                                         $451 = (invoke_ii(3276,48)|0);
                                         $452 = __THREW__; __THREW__ = 0;
                                         $453 = $452&1;
                                         do {
                                          if ($453) {
                                           $470 = ___cxa_find_matching_catch_2()|0;
                                           $471 = tempRet0;
                                           $$0$i91 = $471;$$01$i90 = $470;
                                          } else {
                                           HEAP32[$41>>2] = $451;
                                           $454 = ((($41)) + 8|0);
                                           HEAP32[$454>>2] = -2147483600;
                                           $455 = ((($41)) + 4|0);
                                           HEAP32[$455>>2] = 35;
                                           dest=$451; src=122203; stop=dest+35|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                                           $456 = ((($451)) + 35|0);
                                           HEAP8[$456>>0] = 0;
                                           __THREW__ = 0;
                                           $457 = (invoke_i(3459)|0);
                                           $458 = __THREW__; __THREW__ = 0;
                                           $459 = $458&1;
                                           do {
                                            if (!($459)) {
                                             __THREW__ = 0;
                                             invoke_viiii(3460,($457|0),2,($40|0),($41|0));
                                             $460 = __THREW__; __THREW__ = 0;
                                             $461 = $460&1;
                                             if ($461) {
                                              break;
                                             }
                                             $462 = ((($41)) + 11|0);
                                             $463 = HEAP8[$462>>0]|0;
                                             $464 = ($463<<24>>24)<(0);
                                             if ($464) {
                                              $465 = HEAP32[$41>>2]|0;
                                              __ZdlPv($465);
                                             }
                                             $466 = ((($40)) + 11|0);
                                             $467 = HEAP8[$466>>0]|0;
                                             $468 = ($467<<24>>24)<(0);
                                             if ($468) {
                                              $469 = HEAP32[$40>>2]|0;
                                              __ZdlPv($469);
                                             }
                                             $482 = (__Znwj(48)|0);
                                             HEAP32[$38>>2] = $482;
                                             $483 = ((($38)) + 8|0);
                                             HEAP32[$483>>2] = -2147483600;
                                             $484 = ((($38)) + 4|0);
                                             HEAP32[$484>>2] = 41;
                                             dest=$482; src=122616; stop=dest+41|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                                             $485 = ((($482)) + 41|0);
                                             HEAP8[$485>>0] = 0;
                                             ;HEAP32[$39>>2]=0|0;HEAP32[$39+4>>2]=0|0;HEAP32[$39+8>>2]=0|0;
                                             __THREW__ = 0;
                                             $486 = (invoke_ii(3276,80)|0);
                                             $487 = __THREW__; __THREW__ = 0;
                                             $488 = $487&1;
                                             do {
                                              if ($488) {
                                               $505 = ___cxa_find_matching_catch_2()|0;
                                               $506 = tempRet0;
                                               $$0$i99 = $506;$$01$i98 = $505;
                                              } else {
                                               HEAP32[$39>>2] = $486;
                                               $489 = ((($39)) + 8|0);
                                               HEAP32[$489>>2] = -2147483568;
                                               $490 = ((($39)) + 4|0);
                                               HEAP32[$490>>2] = 65;
                                               dest=$486; src=122658; stop=dest+65|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                                               $491 = ((($486)) + 65|0);
                                               HEAP8[$491>>0] = 0;
                                               __THREW__ = 0;
                                               $492 = (invoke_i(3459)|0);
                                               $493 = __THREW__; __THREW__ = 0;
                                               $494 = $493&1;
                                               do {
                                                if (!($494)) {
                                                 __THREW__ = 0;
                                                 invoke_viiii(3460,($492|0),2,($38|0),($39|0));
                                                 $495 = __THREW__; __THREW__ = 0;
                                                 $496 = $495&1;
                                                 if ($496) {
                                                  break;
                                                 }
                                                 $497 = ((($39)) + 11|0);
                                                 $498 = HEAP8[$497>>0]|0;
                                                 $499 = ($498<<24>>24)<(0);
                                                 if ($499) {
                                                  $500 = HEAP32[$39>>2]|0;
                                                  __ZdlPv($500);
                                                 }
                                                 $501 = ((($38)) + 11|0);
                                                 $502 = HEAP8[$501>>0]|0;
                                                 $503 = ($502<<24>>24)<(0);
                                                 if ($503) {
                                                  $504 = HEAP32[$38>>2]|0;
                                                  __ZdlPv($504);
                                                 }
                                                 $517 = (__Znwj(32)|0);
                                                 HEAP32[$36>>2] = $517;
                                                 $518 = ((($36)) + 8|0);
                                                 HEAP32[$518>>2] = -2147483616;
                                                 $519 = ((($36)) + 4|0);
                                                 HEAP32[$519>>2] = 27;
                                                 dest=$517; src=122724; stop=dest+27|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                                                 $520 = ((($517)) + 27|0);
                                                 HEAP8[$520>>0] = 0;
                                                 ;HEAP32[$37>>2]=0|0;HEAP32[$37+4>>2]=0|0;HEAP32[$37+8>>2]=0|0;
                                                 __THREW__ = 0;
                                                 $521 = (invoke_ii(3276,80)|0);
                                                 $522 = __THREW__; __THREW__ = 0;
                                                 $523 = $522&1;
                                                 do {
                                                  if ($523) {
                                                   $540 = ___cxa_find_matching_catch_2()|0;
                                                   $541 = tempRet0;
                                                   $$0$i107 = $541;$$01$i106 = $540;
                                                  } else {
                                                   HEAP32[$37>>2] = $521;
                                                   $524 = ((($37)) + 8|0);
                                                   HEAP32[$524>>2] = -2147483568;
                                                   $525 = ((($37)) + 4|0);
                                                   HEAP32[$525>>2] = 76;
                                                   dest=$521; src=122752; stop=dest+76|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                                                   $526 = ((($521)) + 76|0);
                                                   HEAP8[$526>>0] = 0;
                                                   __THREW__ = 0;
                                                   $527 = (invoke_i(3459)|0);
                                                   $528 = __THREW__; __THREW__ = 0;
                                                   $529 = $528&1;
                                                   do {
                                                    if (!($529)) {
                                                     __THREW__ = 0;
                                                     invoke_viiii(3460,($527|0),2,($36|0),($37|0));
                                                     $530 = __THREW__; __THREW__ = 0;
                                                     $531 = $530&1;
                                                     if ($531) {
                                                      break;
                                                     }
                                                     $532 = ((($37)) + 11|0);
                                                     $533 = HEAP8[$532>>0]|0;
                                                     $534 = ($533<<24>>24)<(0);
                                                     if ($534) {
                                                      $535 = HEAP32[$37>>2]|0;
                                                      __ZdlPv($535);
                                                     }
                                                     $536 = ((($36)) + 11|0);
                                                     $537 = HEAP8[$536>>0]|0;
                                                     $538 = ($537<<24>>24)<(0);
                                                     if ($538) {
                                                      $539 = HEAP32[$36>>2]|0;
                                                      __ZdlPv($539);
                                                     }
                                                     $552 = (__Znwj(48)|0);
                                                     HEAP32[$34>>2] = $552;
                                                     $553 = ((($34)) + 8|0);
                                                     HEAP32[$553>>2] = -2147483600;
                                                     $554 = ((($34)) + 4|0);
                                                     HEAP32[$554>>2] = 34;
                                                     dest=$552; src=122829; stop=dest+34|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                                                     $555 = ((($552)) + 34|0);
                                                     HEAP8[$555>>0] = 0;
                                                     ;HEAP32[$35>>2]=0|0;HEAP32[$35+4>>2]=0|0;HEAP32[$35+8>>2]=0|0;
                                                     __THREW__ = 0;
                                                     $556 = (invoke_ii(3276,128)|0);
                                                     $557 = __THREW__; __THREW__ = 0;
                                                     $558 = $557&1;
                                                     do {
                                                      if ($558) {
                                                       $575 = ___cxa_find_matching_catch_2()|0;
                                                       $576 = tempRet0;
                                                       $$0$i115 = $576;$$01$i114 = $575;
                                                      } else {
                                                       HEAP32[$35>>2] = $556;
                                                       $559 = ((($35)) + 8|0);
                                                       HEAP32[$559>>2] = -2147483520;
                                                       $560 = ((($35)) + 4|0);
                                                       HEAP32[$560>>2] = 115;
                                                       dest=$556; src=122864; stop=dest+115|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                                                       $561 = ((($556)) + 115|0);
                                                       HEAP8[$561>>0] = 0;
                                                       __THREW__ = 0;
                                                       $562 = (invoke_i(3459)|0);
                                                       $563 = __THREW__; __THREW__ = 0;
                                                       $564 = $563&1;
                                                       do {
                                                        if (!($564)) {
                                                         __THREW__ = 0;
                                                         invoke_viiii(3460,($562|0),2,($34|0),($35|0));
                                                         $565 = __THREW__; __THREW__ = 0;
                                                         $566 = $565&1;
                                                         if ($566) {
                                                          break;
                                                         }
                                                         $567 = ((($35)) + 11|0);
                                                         $568 = HEAP8[$567>>0]|0;
                                                         $569 = ($568<<24>>24)<(0);
                                                         if ($569) {
                                                          $570 = HEAP32[$35>>2]|0;
                                                          __ZdlPv($570);
                                                         }
                                                         $571 = ((($34)) + 11|0);
                                                         $572 = HEAP8[$571>>0]|0;
                                                         $573 = ($572<<24>>24)<(0);
                                                         if ($573) {
                                                          $574 = HEAP32[$34>>2]|0;
                                                          __ZdlPv($574);
                                                         }
                                                         $587 = (__Znwj(48)|0);
                                                         HEAP32[$32>>2] = $587;
                                                         $588 = ((($32)) + 8|0);
                                                         HEAP32[$588>>2] = -2147483600;
                                                         $589 = ((($32)) + 4|0);
                                                         HEAP32[$589>>2] = 35;
                                                         dest=$587; src=122980; stop=dest+35|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                                                         $590 = ((($587)) + 35|0);
                                                         HEAP8[$590>>0] = 0;
                                                         ;HEAP32[$33>>2]=0|0;HEAP32[$33+4>>2]=0|0;HEAP32[$33+8>>2]=0|0;
                                                         __THREW__ = 0;
                                                         $591 = (invoke_ii(3276,96)|0);
                                                         $592 = __THREW__; __THREW__ = 0;
                                                         $593 = $592&1;
                                                         do {
                                                          if ($593) {
                                                           $610 = ___cxa_find_matching_catch_2()|0;
                                                           $611 = tempRet0;
                                                           $$0$i123 = $611;$$01$i122 = $610;
                                                          } else {
                                                           HEAP32[$33>>2] = $591;
                                                           $594 = ((($33)) + 8|0);
                                                           HEAP32[$594>>2] = -2147483552;
                                                           $595 = ((($33)) + 4|0);
                                                           HEAP32[$595>>2] = 94;
                                                           dest=$591; src=123016; stop=dest+94|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                                                           $596 = ((($591)) + 94|0);
                                                           HEAP8[$596>>0] = 0;
                                                           __THREW__ = 0;
                                                           $597 = (invoke_i(3459)|0);
                                                           $598 = __THREW__; __THREW__ = 0;
                                                           $599 = $598&1;
                                                           do {
                                                            if (!($599)) {
                                                             __THREW__ = 0;
                                                             invoke_viiii(3460,($597|0),2,($32|0),($33|0));
                                                             $600 = __THREW__; __THREW__ = 0;
                                                             $601 = $600&1;
                                                             if ($601) {
                                                              break;
                                                             }
                                                             $602 = ((($33)) + 11|0);
                                                             $603 = HEAP8[$602>>0]|0;
                                                             $604 = ($603<<24>>24)<(0);
                                                             if ($604) {
                                                              $605 = HEAP32[$33>>2]|0;
                                                              __ZdlPv($605);
                                                             }
                                                             $606 = ((($32)) + 11|0);
                                                             $607 = HEAP8[$606>>0]|0;
                                                             $608 = ($607<<24>>24)<(0);
                                                             if ($608) {
                                                              $609 = HEAP32[$32>>2]|0;
                                                              __ZdlPv($609);
                                                             }
                                                             $622 = (__Znwj(32)|0);
                                                             HEAP32[$30>>2] = $622;
                                                             $623 = ((($30)) + 8|0);
                                                             HEAP32[$623>>2] = -2147483616;
                                                             $624 = ((($30)) + 4|0);
                                                             HEAP32[$624>>2] = 30;
                                                             dest=$622; src=123111; stop=dest+30|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                                                             $625 = ((($622)) + 30|0);
                                                             HEAP8[$625>>0] = 0;
                                                             ;HEAP32[$31>>2]=0|0;HEAP32[$31+4>>2]=0|0;HEAP32[$31+8>>2]=0|0;
                                                             __THREW__ = 0;
                                                             $626 = (invoke_ii(3276,80)|0);
                                                             $627 = __THREW__; __THREW__ = 0;
                                                             $628 = $627&1;
                                                             do {
                                                              if ($628) {
                                                               $645 = ___cxa_find_matching_catch_2()|0;
                                                               $646 = tempRet0;
                                                               $$0$i131 = $646;$$01$i130 = $645;
                                                              } else {
                                                               HEAP32[$31>>2] = $626;
                                                               $629 = ((($31)) + 8|0);
                                                               HEAP32[$629>>2] = -2147483568;
                                                               $630 = ((($31)) + 4|0);
                                                               HEAP32[$630>>2] = 76;
                                                               dest=$626; src=123142; stop=dest+76|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                                                               $631 = ((($626)) + 76|0);
                                                               HEAP8[$631>>0] = 0;
                                                               __THREW__ = 0;
                                                               $632 = (invoke_i(3459)|0);
                                                               $633 = __THREW__; __THREW__ = 0;
                                                               $634 = $633&1;
                                                               do {
                                                                if (!($634)) {
                                                                 __THREW__ = 0;
                                                                 invoke_viiii(3460,($632|0),2,($30|0),($31|0));
                                                                 $635 = __THREW__; __THREW__ = 0;
                                                                 $636 = $635&1;
                                                                 if ($636) {
                                                                  break;
                                                                 }
                                                                 $637 = ((($31)) + 11|0);
                                                                 $638 = HEAP8[$637>>0]|0;
                                                                 $639 = ($638<<24>>24)<(0);
                                                                 if ($639) {
                                                                  $640 = HEAP32[$31>>2]|0;
                                                                  __ZdlPv($640);
                                                                 }
                                                                 $641 = ((($30)) + 11|0);
                                                                 $642 = HEAP8[$641>>0]|0;
                                                                 $643 = ($642<<24>>24)<(0);
                                                                 if ($643) {
                                                                  $644 = HEAP32[$30>>2]|0;
                                                                  __ZdlPv($644);
                                                                 }
                                                                 $657 = (__Znwj(48)|0);
                                                                 HEAP32[$28>>2] = $657;
                                                                 $658 = ((($28)) + 8|0);
                                                                 HEAP32[$658>>2] = -2147483600;
                                                                 $659 = ((($28)) + 4|0);
                                                                 HEAP32[$659>>2] = 35;
                                                                 dest=$657; src=123219; stop=dest+35|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                                                                 $660 = ((($657)) + 35|0);
                                                                 HEAP8[$660>>0] = 0;
                                                                 ;HEAP32[$29>>2]=0|0;HEAP32[$29+4>>2]=0|0;HEAP32[$29+8>>2]=0|0;
                                                                 __THREW__ = 0;
                                                                 $661 = (invoke_ii(3276,112)|0);
                                                                 $662 = __THREW__; __THREW__ = 0;
                                                                 $663 = $662&1;
                                                                 do {
                                                                  if ($663) {
                                                                   $680 = ___cxa_find_matching_catch_2()|0;
                                                                   $681 = tempRet0;
                                                                   $$0$i139 = $681;$$01$i138 = $680;
                                                                  } else {
                                                                   HEAP32[$29>>2] = $661;
                                                                   $664 = ((($29)) + 8|0);
                                                                   HEAP32[$664>>2] = -2147483536;
                                                                   $665 = ((($29)) + 4|0);
                                                                   HEAP32[$665>>2] = 103;
                                                                   dest=$661; src=123255; stop=dest+103|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                                                                   $666 = ((($661)) + 103|0);
                                                                   HEAP8[$666>>0] = 0;
                                                                   __THREW__ = 0;
                                                                   $667 = (invoke_i(3459)|0);
                                                                   $668 = __THREW__; __THREW__ = 0;
                                                                   $669 = $668&1;
                                                                   do {
                                                                    if (!($669)) {
                                                                     __THREW__ = 0;
                                                                     invoke_viiii(3460,($667|0),2,($28|0),($29|0));
                                                                     $670 = __THREW__; __THREW__ = 0;
                                                                     $671 = $670&1;
                                                                     if ($671) {
                                                                      break;
                                                                     }
                                                                     $672 = ((($29)) + 11|0);
                                                                     $673 = HEAP8[$672>>0]|0;
                                                                     $674 = ($673<<24>>24)<(0);
                                                                     if ($674) {
                                                                      $675 = HEAP32[$29>>2]|0;
                                                                      __ZdlPv($675);
                                                                     }
                                                                     $676 = ((($28)) + 11|0);
                                                                     $677 = HEAP8[$676>>0]|0;
                                                                     $678 = ($677<<24>>24)<(0);
                                                                     if ($678) {
                                                                      $679 = HEAP32[$28>>2]|0;
                                                                      __ZdlPv($679);
                                                                     }
                                                                     $692 = (__Znwj(32)|0);
                                                                     HEAP32[$26>>2] = $692;
                                                                     $693 = ((($26)) + 8|0);
                                                                     HEAP32[$693>>2] = -2147483616;
                                                                     $694 = ((($26)) + 4|0);
                                                                     HEAP32[$694>>2] = 23;
                                                                     dest=$692; src=123359; stop=dest+23|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                                                                     $695 = ((($692)) + 23|0);
                                                                     HEAP8[$695>>0] = 0;
                                                                     ;HEAP32[$27>>2]=0|0;HEAP32[$27+4>>2]=0|0;HEAP32[$27+8>>2]=0|0;
                                                                     __THREW__ = 0;
                                                                     $696 = (invoke_ii(3276,80)|0);
                                                                     $697 = __THREW__; __THREW__ = 0;
                                                                     $698 = $697&1;
                                                                     do {
                                                                      if ($698) {
                                                                       $715 = ___cxa_find_matching_catch_2()|0;
                                                                       $716 = tempRet0;
                                                                       $$0$i147 = $716;$$01$i146 = $715;
                                                                      } else {
                                                                       HEAP32[$27>>2] = $696;
                                                                       $699 = ((($27)) + 8|0);
                                                                       HEAP32[$699>>2] = -2147483568;
                                                                       $700 = ((($27)) + 4|0);
                                                                       HEAP32[$700>>2] = 66;
                                                                       dest=$696; src=123383; stop=dest+66|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                                                                       $701 = ((($696)) + 66|0);
                                                                       HEAP8[$701>>0] = 0;
                                                                       __THREW__ = 0;
                                                                       $702 = (invoke_i(3459)|0);
                                                                       $703 = __THREW__; __THREW__ = 0;
                                                                       $704 = $703&1;
                                                                       do {
                                                                        if (!($704)) {
                                                                         __THREW__ = 0;
                                                                         invoke_viiii(3460,($702|0),2,($26|0),($27|0));
                                                                         $705 = __THREW__; __THREW__ = 0;
                                                                         $706 = $705&1;
                                                                         if ($706) {
                                                                          break;
                                                                         }
                                                                         $707 = ((($27)) + 11|0);
                                                                         $708 = HEAP8[$707>>0]|0;
                                                                         $709 = ($708<<24>>24)<(0);
                                                                         if ($709) {
                                                                          $710 = HEAP32[$27>>2]|0;
                                                                          __ZdlPv($710);
                                                                         }
                                                                         $711 = ((($26)) + 11|0);
                                                                         $712 = HEAP8[$711>>0]|0;
                                                                         $713 = ($712<<24>>24)<(0);
                                                                         if ($713) {
                                                                          $714 = HEAP32[$26>>2]|0;
                                                                          __ZdlPv($714);
                                                                         }
                                                                         $727 = (__Znwj(32)|0);
                                                                         HEAP32[$24>>2] = $727;
                                                                         $728 = ((($24)) + 8|0);
                                                                         HEAP32[$728>>2] = -2147483616;
                                                                         $729 = ((($24)) + 4|0);
                                                                         HEAP32[$729>>2] = 27;
                                                                         dest=$727; src=123450; stop=dest+27|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                                                                         $730 = ((($727)) + 27|0);
                                                                         HEAP8[$730>>0] = 0;
                                                                         ;HEAP32[$25>>2]=0|0;HEAP32[$25+4>>2]=0|0;HEAP32[$25+8>>2]=0|0;
                                                                         __THREW__ = 0;
                                                                         $731 = (invoke_ii(3276,64)|0);
                                                                         $732 = __THREW__; __THREW__ = 0;
                                                                         $733 = $732&1;
                                                                         do {
                                                                          if ($733) {
                                                                           $750 = ___cxa_find_matching_catch_2()|0;
                                                                           $751 = tempRet0;
                                                                           $$0$i155 = $751;$$01$i154 = $750;
                                                                          } else {
                                                                           HEAP32[$25>>2] = $731;
                                                                           $734 = ((($25)) + 8|0);
                                                                           HEAP32[$734>>2] = -2147483584;
                                                                           $735 = ((($25)) + 4|0);
                                                                           HEAP32[$735>>2] = 56;
                                                                           dest=$731; src=123478; stop=dest+56|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                                                                           $736 = ((($731)) + 56|0);
                                                                           HEAP8[$736>>0] = 0;
                                                                           __THREW__ = 0;
                                                                           $737 = (invoke_i(3459)|0);
                                                                           $738 = __THREW__; __THREW__ = 0;
                                                                           $739 = $738&1;
                                                                           do {
                                                                            if (!($739)) {
                                                                             __THREW__ = 0;
                                                                             invoke_viiii(3460,($737|0),2,($24|0),($25|0));
                                                                             $740 = __THREW__; __THREW__ = 0;
                                                                             $741 = $740&1;
                                                                             if ($741) {
                                                                              break;
                                                                             }
                                                                             $742 = ((($25)) + 11|0);
                                                                             $743 = HEAP8[$742>>0]|0;
                                                                             $744 = ($743<<24>>24)<(0);
                                                                             if ($744) {
                                                                              $745 = HEAP32[$25>>2]|0;
                                                                              __ZdlPv($745);
                                                                             }
                                                                             $746 = ((($24)) + 11|0);
                                                                             $747 = HEAP8[$746>>0]|0;
                                                                             $748 = ($747<<24>>24)<(0);
                                                                             if ($748) {
                                                                              $749 = HEAP32[$24>>2]|0;
                                                                              __ZdlPv($749);
                                                                             }
                                                                             $762 = (__Znwj(48)|0);
                                                                             HEAP32[$22>>2] = $762;
                                                                             $763 = ((($22)) + 8|0);
                                                                             HEAP32[$763>>2] = -2147483600;
                                                                             $764 = ((($22)) + 4|0);
                                                                             HEAP32[$764>>2] = 33;
                                                                             dest=$762; src=123535; stop=dest+33|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                                                                             $765 = ((($762)) + 33|0);
                                                                             HEAP8[$765>>0] = 0;
                                                                             ;HEAP32[$23>>2]=0|0;HEAP32[$23+4>>2]=0|0;HEAP32[$23+8>>2]=0|0;
                                                                             __THREW__ = 0;
                                                                             $766 = (invoke_ii(3276,80)|0);
                                                                             $767 = __THREW__; __THREW__ = 0;
                                                                             $768 = $767&1;
                                                                             do {
                                                                              if ($768) {
                                                                               $785 = ___cxa_find_matching_catch_2()|0;
                                                                               $786 = tempRet0;
                                                                               $$0$i163 = $786;$$01$i162 = $785;
                                                                              } else {
                                                                               HEAP32[$23>>2] = $766;
                                                                               $769 = ((($23)) + 8|0);
                                                                               HEAP32[$769>>2] = -2147483568;
                                                                               $770 = ((($23)) + 4|0);
                                                                               HEAP32[$770>>2] = 69;
                                                                               dest=$766; src=123569; stop=dest+69|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                                                                               $771 = ((($766)) + 69|0);
                                                                               HEAP8[$771>>0] = 0;
                                                                               __THREW__ = 0;
                                                                               $772 = (invoke_i(3459)|0);
                                                                               $773 = __THREW__; __THREW__ = 0;
                                                                               $774 = $773&1;
                                                                               do {
                                                                                if (!($774)) {
                                                                                 __THREW__ = 0;
                                                                                 invoke_viiii(3460,($772|0),2,($22|0),($23|0));
                                                                                 $775 = __THREW__; __THREW__ = 0;
                                                                                 $776 = $775&1;
                                                                                 if ($776) {
                                                                                  break;
                                                                                 }
                                                                                 $777 = ((($23)) + 11|0);
                                                                                 $778 = HEAP8[$777>>0]|0;
                                                                                 $779 = ($778<<24>>24)<(0);
                                                                                 if ($779) {
                                                                                  $780 = HEAP32[$23>>2]|0;
                                                                                  __ZdlPv($780);
                                                                                 }
                                                                                 $781 = ((($22)) + 11|0);
                                                                                 $782 = HEAP8[$781>>0]|0;
                                                                                 $783 = ($782<<24>>24)<(0);
                                                                                 if ($783) {
                                                                                  $784 = HEAP32[$22>>2]|0;
                                                                                  __ZdlPv($784);
                                                                                 }
                                                                                 $797 = (__Znwj(32)|0);
                                                                                 HEAP32[$20>>2] = $797;
                                                                                 $798 = ((($20)) + 8|0);
                                                                                 HEAP32[$798>>2] = -2147483616;
                                                                                 $799 = ((($20)) + 4|0);
                                                                                 HEAP32[$799>>2] = 23;
                                                                                 dest=$797; src=123639; stop=dest+23|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                                                                                 $800 = ((($797)) + 23|0);
                                                                                 HEAP8[$800>>0] = 0;
                                                                                 ;HEAP32[$21>>2]=0|0;HEAP32[$21+4>>2]=0|0;HEAP32[$21+8>>2]=0|0;
                                                                                 __THREW__ = 0;
                                                                                 $801 = (invoke_ii(3276,80)|0);
                                                                                 $802 = __THREW__; __THREW__ = 0;
                                                                                 $803 = $802&1;
                                                                                 do {
                                                                                  if ($803) {
                                                                                   $820 = ___cxa_find_matching_catch_2()|0;
                                                                                   $821 = tempRet0;
                                                                                   $$0$i171 = $821;$$01$i170 = $820;
                                                                                  } else {
                                                                                   HEAP32[$21>>2] = $801;
                                                                                   $804 = ((($21)) + 8|0);
                                                                                   HEAP32[$804>>2] = -2147483568;
                                                                                   $805 = ((($21)) + 4|0);
                                                                                   HEAP32[$805>>2] = 68;
                                                                                   dest=$801; src=123663; stop=dest+68|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                                                                                   $806 = ((($801)) + 68|0);
                                                                                   HEAP8[$806>>0] = 0;
                                                                                   __THREW__ = 0;
                                                                                   $807 = (invoke_i(3459)|0);
                                                                                   $808 = __THREW__; __THREW__ = 0;
                                                                                   $809 = $808&1;
                                                                                   do {
                                                                                    if (!($809)) {
                                                                                     __THREW__ = 0;
                                                                                     invoke_viiii(3460,($807|0),2,($20|0),($21|0));
                                                                                     $810 = __THREW__; __THREW__ = 0;
                                                                                     $811 = $810&1;
                                                                                     if ($811) {
                                                                                      break;
                                                                                     }
                                                                                     $812 = ((($21)) + 11|0);
                                                                                     $813 = HEAP8[$812>>0]|0;
                                                                                     $814 = ($813<<24>>24)<(0);
                                                                                     if ($814) {
                                                                                      $815 = HEAP32[$21>>2]|0;
                                                                                      __ZdlPv($815);
                                                                                     }
                                                                                     $816 = ((($20)) + 11|0);
                                                                                     $817 = HEAP8[$816>>0]|0;
                                                                                     $818 = ($817<<24>>24)<(0);
                                                                                     if ($818) {
                                                                                      $819 = HEAP32[$20>>2]|0;
                                                                                      __ZdlPv($819);
                                                                                     }
                                                                                     $832 = (__Znwj(48)|0);
                                                                                     HEAP32[$18>>2] = $832;
                                                                                     $833 = ((($18)) + 8|0);
                                                                                     HEAP32[$833>>2] = -2147483600;
                                                                                     $834 = ((($18)) + 4|0);
                                                                                     HEAP32[$834>>2] = 42;
                                                                                     dest=$832; src=123732; stop=dest+42|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                                                                                     $835 = ((($832)) + 42|0);
                                                                                     HEAP8[$835>>0] = 0;
                                                                                     ;HEAP32[$19>>2]=0|0;HEAP32[$19+4>>2]=0|0;HEAP32[$19+8>>2]=0|0;
                                                                                     __THREW__ = 0;
                                                                                     $836 = (invoke_ii(3276,112)|0);
                                                                                     $837 = __THREW__; __THREW__ = 0;
                                                                                     $838 = $837&1;
                                                                                     do {
                                                                                      if ($838) {
                                                                                       $855 = ___cxa_find_matching_catch_2()|0;
                                                                                       $856 = tempRet0;
                                                                                       $$0$i179 = $856;$$01$i178 = $855;
                                                                                      } else {
                                                                                       HEAP32[$19>>2] = $836;
                                                                                       $839 = ((($19)) + 8|0);
                                                                                       HEAP32[$839>>2] = -2147483536;
                                                                                       $840 = ((($19)) + 4|0);
                                                                                       HEAP32[$840>>2] = 103;
                                                                                       dest=$836; src=123775; stop=dest+103|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                                                                                       $841 = ((($836)) + 103|0);
                                                                                       HEAP8[$841>>0] = 0;
                                                                                       __THREW__ = 0;
                                                                                       $842 = (invoke_i(3459)|0);
                                                                                       $843 = __THREW__; __THREW__ = 0;
                                                                                       $844 = $843&1;
                                                                                       do {
                                                                                        if (!($844)) {
                                                                                         __THREW__ = 0;
                                                                                         invoke_viiii(3460,($842|0),2,($18|0),($19|0));
                                                                                         $845 = __THREW__; __THREW__ = 0;
                                                                                         $846 = $845&1;
                                                                                         if ($846) {
                                                                                          break;
                                                                                         }
                                                                                         $847 = ((($19)) + 11|0);
                                                                                         $848 = HEAP8[$847>>0]|0;
                                                                                         $849 = ($848<<24>>24)<(0);
                                                                                         if ($849) {
                                                                                          $850 = HEAP32[$19>>2]|0;
                                                                                          __ZdlPv($850);
                                                                                         }
                                                                                         $851 = ((($18)) + 11|0);
                                                                                         $852 = HEAP8[$851>>0]|0;
                                                                                         $853 = ($852<<24>>24)<(0);
                                                                                         if ($853) {
                                                                                          $854 = HEAP32[$18>>2]|0;
                                                                                          __ZdlPv($854);
                                                                                         }
                                                                                         $867 = (__Znwj(48)|0);
                                                                                         HEAP32[$16>>2] = $867;
                                                                                         $868 = ((($16)) + 8|0);
                                                                                         HEAP32[$868>>2] = -2147483600;
                                                                                         $869 = ((($16)) + 4|0);
                                                                                         HEAP32[$869>>2] = 43;
                                                                                         dest=$867; src=123879; stop=dest+43|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                                                                                         $870 = ((($867)) + 43|0);
                                                                                         HEAP8[$870>>0] = 0;
                                                                                         ;HEAP32[$17>>2]=0|0;HEAP32[$17+4>>2]=0|0;HEAP32[$17+8>>2]=0|0;
                                                                                         __THREW__ = 0;
                                                                                         $871 = (invoke_ii(3276,112)|0);
                                                                                         $872 = __THREW__; __THREW__ = 0;
                                                                                         $873 = $872&1;
                                                                                         do {
                                                                                          if ($873) {
                                                                                           $890 = ___cxa_find_matching_catch_2()|0;
                                                                                           $891 = tempRet0;
                                                                                           $$0$i187 = $891;$$01$i186 = $890;
                                                                                          } else {
                                                                                           HEAP32[$17>>2] = $871;
                                                                                           $874 = ((($17)) + 8|0);
                                                                                           HEAP32[$874>>2] = -2147483536;
                                                                                           $875 = ((($17)) + 4|0);
                                                                                           HEAP32[$875>>2] = 104;
                                                                                           dest=$871; src=123923; stop=dest+104|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                                                                                           $876 = ((($871)) + 104|0);
                                                                                           HEAP8[$876>>0] = 0;
                                                                                           __THREW__ = 0;
                                                                                           $877 = (invoke_i(3459)|0);
                                                                                           $878 = __THREW__; __THREW__ = 0;
                                                                                           $879 = $878&1;
                                                                                           do {
                                                                                            if (!($879)) {
                                                                                             __THREW__ = 0;
                                                                                             invoke_viiii(3460,($877|0),2,($16|0),($17|0));
                                                                                             $880 = __THREW__; __THREW__ = 0;
                                                                                             $881 = $880&1;
                                                                                             if ($881) {
                                                                                              break;
                                                                                             }
                                                                                             $882 = ((($17)) + 11|0);
                                                                                             $883 = HEAP8[$882>>0]|0;
                                                                                             $884 = ($883<<24>>24)<(0);
                                                                                             if ($884) {
                                                                                              $885 = HEAP32[$17>>2]|0;
                                                                                              __ZdlPv($885);
                                                                                             }
                                                                                             $886 = ((($16)) + 11|0);
                                                                                             $887 = HEAP8[$886>>0]|0;
                                                                                             $888 = ($887<<24>>24)<(0);
                                                                                             if ($888) {
                                                                                              $889 = HEAP32[$16>>2]|0;
                                                                                              __ZdlPv($889);
                                                                                             }
                                                                                             $902 = (__Znwj(48)|0);
                                                                                             HEAP32[$14>>2] = $902;
                                                                                             $903 = ((($14)) + 8|0);
                                                                                             HEAP32[$903>>2] = -2147483600;
                                                                                             $904 = ((($14)) + 4|0);
                                                                                             HEAP32[$904>>2] = 36;
                                                                                             dest=$902; src=124028; stop=dest+36|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                                                                                             $905 = ((($902)) + 36|0);
                                                                                             HEAP8[$905>>0] = 0;
                                                                                             ;HEAP32[$15>>2]=0|0;HEAP32[$15+4>>2]=0|0;HEAP32[$15+8>>2]=0|0;
                                                                                             __THREW__ = 0;
                                                                                             $906 = (invoke_ii(3276,64)|0);
                                                                                             $907 = __THREW__; __THREW__ = 0;
                                                                                             $908 = $907&1;
                                                                                             do {
                                                                                              if ($908) {
                                                                                               $925 = ___cxa_find_matching_catch_2()|0;
                                                                                               $926 = tempRet0;
                                                                                               $$0$i195 = $926;$$01$i194 = $925;
                                                                                              } else {
                                                                                               HEAP32[$15>>2] = $906;
                                                                                               $909 = ((($15)) + 8|0);
                                                                                               HEAP32[$909>>2] = -2147483584;
                                                                                               $910 = ((($15)) + 4|0);
                                                                                               HEAP32[$910>>2] = 55;
                                                                                               dest=$906; src=124065; stop=dest+55|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                                                                                               $911 = ((($906)) + 55|0);
                                                                                               HEAP8[$911>>0] = 0;
                                                                                               __THREW__ = 0;
                                                                                               $912 = (invoke_i(3459)|0);
                                                                                               $913 = __THREW__; __THREW__ = 0;
                                                                                               $914 = $913&1;
                                                                                               do {
                                                                                                if (!($914)) {
                                                                                                 __THREW__ = 0;
                                                                                                 invoke_viiii(3460,($912|0),2,($14|0),($15|0));
                                                                                                 $915 = __THREW__; __THREW__ = 0;
                                                                                                 $916 = $915&1;
                                                                                                 if ($916) {
                                                                                                  break;
                                                                                                 }
                                                                                                 $917 = ((($15)) + 11|0);
                                                                                                 $918 = HEAP8[$917>>0]|0;
                                                                                                 $919 = ($918<<24>>24)<(0);
                                                                                                 if ($919) {
                                                                                                  $920 = HEAP32[$15>>2]|0;
                                                                                                  __ZdlPv($920);
                                                                                                 }
                                                                                                 $921 = ((($14)) + 11|0);
                                                                                                 $922 = HEAP8[$921>>0]|0;
                                                                                                 $923 = ($922<<24>>24)<(0);
                                                                                                 if ($923) {
                                                                                                  $924 = HEAP32[$14>>2]|0;
                                                                                                  __ZdlPv($924);
                                                                                                 }
                                                                                                 $937 = (__Znwj(32)|0);
                                                                                                 HEAP32[$12>>2] = $937;
                                                                                                 $938 = ((($12)) + 8|0);
                                                                                                 HEAP32[$938>>2] = -2147483616;
                                                                                                 $939 = ((($12)) + 4|0);
                                                                                                 HEAP32[$939>>2] = 27;
                                                                                                 dest=$937; src=124121; stop=dest+27|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                                                                                                 $940 = ((($937)) + 27|0);
                                                                                                 HEAP8[$940>>0] = 0;
                                                                                                 ;HEAP32[$13>>2]=0|0;HEAP32[$13+4>>2]=0|0;HEAP32[$13+8>>2]=0|0;
                                                                                                 __THREW__ = 0;
                                                                                                 $941 = (invoke_ii(3276,80)|0);
                                                                                                 $942 = __THREW__; __THREW__ = 0;
                                                                                                 $943 = $942&1;
                                                                                                 do {
                                                                                                  if ($943) {
                                                                                                   $960 = ___cxa_find_matching_catch_2()|0;
                                                                                                   $961 = tempRet0;
                                                                                                   $$0$i203 = $961;$$01$i202 = $960;
                                                                                                  } else {
                                                                                                   HEAP32[$13>>2] = $941;
                                                                                                   $944 = ((($13)) + 8|0);
                                                                                                   HEAP32[$944>>2] = -2147483568;
                                                                                                   $945 = ((($13)) + 4|0);
                                                                                                   HEAP32[$945>>2] = 68;
                                                                                                   dest=$941; src=124149; stop=dest+68|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                                                                                                   $946 = ((($941)) + 68|0);
                                                                                                   HEAP8[$946>>0] = 0;
                                                                                                   __THREW__ = 0;
                                                                                                   $947 = (invoke_i(3459)|0);
                                                                                                   $948 = __THREW__; __THREW__ = 0;
                                                                                                   $949 = $948&1;
                                                                                                   do {
                                                                                                    if (!($949)) {
                                                                                                     __THREW__ = 0;
                                                                                                     invoke_viiii(3460,($947|0),2,($12|0),($13|0));
                                                                                                     $950 = __THREW__; __THREW__ = 0;
                                                                                                     $951 = $950&1;
                                                                                                     if ($951) {
                                                                                                      break;
                                                                                                     }
                                                                                                     $952 = ((($13)) + 11|0);
                                                                                                     $953 = HEAP8[$952>>0]|0;
                                                                                                     $954 = ($953<<24>>24)<(0);
                                                                                                     if ($954) {
                                                                                                      $955 = HEAP32[$13>>2]|0;
                                                                                                      __ZdlPv($955);
                                                                                                     }
                                                                                                     $956 = ((($12)) + 11|0);
                                                                                                     $957 = HEAP8[$956>>0]|0;
                                                                                                     $958 = ($957<<24>>24)<(0);
                                                                                                     if ($958) {
                                                                                                      $959 = HEAP32[$12>>2]|0;
                                                                                                      __ZdlPv($959);
                                                                                                     }
                                                                                                     $972 = (__Znwj(48)|0);
                                                                                                     HEAP32[$10>>2] = $972;
                                                                                                     $973 = ((($10)) + 8|0);
                                                                                                     HEAP32[$973>>2] = -2147483600;
                                                                                                     $974 = ((($10)) + 4|0);
                                                                                                     HEAP32[$974>>2] = 34;
                                                                                                     dest=$972; src=124218; stop=dest+34|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                                                                                                     $975 = ((($972)) + 34|0);
                                                                                                     HEAP8[$975>>0] = 0;
                                                                                                     ;HEAP32[$11>>2]=0|0;HEAP32[$11+4>>2]=0|0;HEAP32[$11+8>>2]=0|0;
                                                                                                     __THREW__ = 0;
                                                                                                     $976 = (invoke_ii(3276,80)|0);
                                                                                                     $977 = __THREW__; __THREW__ = 0;
                                                                                                     $978 = $977&1;
                                                                                                     do {
                                                                                                      if ($978) {
                                                                                                       $995 = ___cxa_find_matching_catch_2()|0;
                                                                                                       $996 = tempRet0;
                                                                                                       $$0$i211 = $996;$$01$i210 = $995;
                                                                                                      } else {
                                                                                                       HEAP32[$11>>2] = $976;
                                                                                                       $979 = ((($11)) + 8|0);
                                                                                                       HEAP32[$979>>2] = -2147483568;
                                                                                                       $980 = ((($11)) + 4|0);
                                                                                                       HEAP32[$980>>2] = 75;
                                                                                                       dest=$976; src=124253; stop=dest+75|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                                                                                                       $981 = ((($976)) + 75|0);
                                                                                                       HEAP8[$981>>0] = 0;
                                                                                                       __THREW__ = 0;
                                                                                                       $982 = (invoke_i(3459)|0);
                                                                                                       $983 = __THREW__; __THREW__ = 0;
                                                                                                       $984 = $983&1;
                                                                                                       do {
                                                                                                        if (!($984)) {
                                                                                                         __THREW__ = 0;
                                                                                                         invoke_viiii(3460,($982|0),2,($10|0),($11|0));
                                                                                                         $985 = __THREW__; __THREW__ = 0;
                                                                                                         $986 = $985&1;
                                                                                                         if ($986) {
                                                                                                          break;
                                                                                                         }
                                                                                                         $987 = ((($11)) + 11|0);
                                                                                                         $988 = HEAP8[$987>>0]|0;
                                                                                                         $989 = ($988<<24>>24)<(0);
                                                                                                         if ($989) {
                                                                                                          $990 = HEAP32[$11>>2]|0;
                                                                                                          __ZdlPv($990);
                                                                                                         }
                                                                                                         $991 = ((($10)) + 11|0);
                                                                                                         $992 = HEAP8[$991>>0]|0;
                                                                                                         $993 = ($992<<24>>24)<(0);
                                                                                                         if ($993) {
                                                                                                          $994 = HEAP32[$10>>2]|0;
                                                                                                          __ZdlPv($994);
                                                                                                         }
                                                                                                         $1007 = (__Znwj(32)|0);
                                                                                                         HEAP32[$8>>2] = $1007;
                                                                                                         $1008 = ((($8)) + 8|0);
                                                                                                         HEAP32[$1008>>2] = -2147483616;
                                                                                                         $1009 = ((($8)) + 4|0);
                                                                                                         HEAP32[$1009>>2] = 24;
                                                                                                         dest=$1007; src=124329; stop=dest+24|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                                                                                                         $1010 = ((($1007)) + 24|0);
                                                                                                         HEAP8[$1010>>0] = 0;
                                                                                                         ;HEAP32[$9>>2]=0|0;HEAP32[$9+4>>2]=0|0;HEAP32[$9+8>>2]=0|0;
                                                                                                         __THREW__ = 0;
                                                                                                         $1011 = (invoke_ii(3276,80)|0);
                                                                                                         $1012 = __THREW__; __THREW__ = 0;
                                                                                                         $1013 = $1012&1;
                                                                                                         do {
                                                                                                          if ($1013) {
                                                                                                           $1030 = ___cxa_find_matching_catch_2()|0;
                                                                                                           $1031 = tempRet0;
                                                                                                           $$0$i219 = $1031;$$01$i218 = $1030;
                                                                                                          } else {
                                                                                                           HEAP32[$9>>2] = $1011;
                                                                                                           $1014 = ((($9)) + 8|0);
                                                                                                           HEAP32[$1014>>2] = -2147483568;
                                                                                                           $1015 = ((($9)) + 4|0);
                                                                                                           HEAP32[$1015>>2] = 68;
                                                                                                           dest=$1011; src=124354; stop=dest+68|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                                                                                                           $1016 = ((($1011)) + 68|0);
                                                                                                           HEAP8[$1016>>0] = 0;
                                                                                                           __THREW__ = 0;
                                                                                                           $1017 = (invoke_i(3459)|0);
                                                                                                           $1018 = __THREW__; __THREW__ = 0;
                                                                                                           $1019 = $1018&1;
                                                                                                           do {
                                                                                                            if (!($1019)) {
                                                                                                             __THREW__ = 0;
                                                                                                             invoke_viiii(3460,($1017|0),2,($8|0),($9|0));
                                                                                                             $1020 = __THREW__; __THREW__ = 0;
                                                                                                             $1021 = $1020&1;
                                                                                                             if ($1021) {
                                                                                                              break;
                                                                                                             }
                                                                                                             $1022 = ((($9)) + 11|0);
                                                                                                             $1023 = HEAP8[$1022>>0]|0;
                                                                                                             $1024 = ($1023<<24>>24)<(0);
                                                                                                             if ($1024) {
                                                                                                              $1025 = HEAP32[$9>>2]|0;
                                                                                                              __ZdlPv($1025);
                                                                                                             }
                                                                                                             $1026 = ((($8)) + 11|0);
                                                                                                             $1027 = HEAP8[$1026>>0]|0;
                                                                                                             $1028 = ($1027<<24>>24)<(0);
                                                                                                             if ($1028) {
                                                                                                              $1029 = HEAP32[$8>>2]|0;
                                                                                                              __ZdlPv($1029);
                                                                                                             }
                                                                                                             $1042 = (__Znwj(32)|0);
                                                                                                             HEAP32[$6>>2] = $1042;
                                                                                                             $1043 = ((($6)) + 8|0);
                                                                                                             HEAP32[$1043>>2] = -2147483616;
                                                                                                             $1044 = ((($6)) + 4|0);
                                                                                                             HEAP32[$1044>>2] = 21;
                                                                                                             dest=$1042; src=124423; stop=dest+21|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                                                                                                             $1045 = ((($1042)) + 21|0);
                                                                                                             HEAP8[$1045>>0] = 0;
                                                                                                             ;HEAP32[$7>>2]=0|0;HEAP32[$7+4>>2]=0|0;HEAP32[$7+8>>2]=0|0;
                                                                                                             __THREW__ = 0;
                                                                                                             $1046 = (invoke_ii(3276,80)|0);
                                                                                                             $1047 = __THREW__; __THREW__ = 0;
                                                                                                             $1048 = $1047&1;
                                                                                                             do {
                                                                                                              if ($1048) {
                                                                                                               $1065 = ___cxa_find_matching_catch_2()|0;
                                                                                                               $1066 = tempRet0;
                                                                                                               $$0$i227 = $1066;$$01$i226 = $1065;
                                                                                                              } else {
                                                                                                               HEAP32[$7>>2] = $1046;
                                                                                                               $1049 = ((($7)) + 8|0);
                                                                                                               HEAP32[$1049>>2] = -2147483568;
                                                                                                               $1050 = ((($7)) + 4|0);
                                                                                                               HEAP32[$1050>>2] = 73;
                                                                                                               dest=$1046; src=124445; stop=dest+73|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                                                                                                               $1051 = ((($1046)) + 73|0);
                                                                                                               HEAP8[$1051>>0] = 0;
                                                                                                               __THREW__ = 0;
                                                                                                               $1052 = (invoke_i(3459)|0);
                                                                                                               $1053 = __THREW__; __THREW__ = 0;
                                                                                                               $1054 = $1053&1;
                                                                                                               do {
                                                                                                                if (!($1054)) {
                                                                                                                 __THREW__ = 0;
                                                                                                                 invoke_viiii(3460,($1052|0),2,($6|0),($7|0));
                                                                                                                 $1055 = __THREW__; __THREW__ = 0;
                                                                                                                 $1056 = $1055&1;
                                                                                                                 if ($1056) {
                                                                                                                  break;
                                                                                                                 }
                                                                                                                 $1057 = ((($7)) + 11|0);
                                                                                                                 $1058 = HEAP8[$1057>>0]|0;
                                                                                                                 $1059 = ($1058<<24>>24)<(0);
                                                                                                                 if ($1059) {
                                                                                                                  $1060 = HEAP32[$7>>2]|0;
                                                                                                                  __ZdlPv($1060);
                                                                                                                 }
                                                                                                                 $1061 = ((($6)) + 11|0);
                                                                                                                 $1062 = HEAP8[$1061>>0]|0;
                                                                                                                 $1063 = ($1062<<24>>24)<(0);
                                                                                                                 if ($1063) {
                                                                                                                  $1064 = HEAP32[$6>>2]|0;
                                                                                                                  __ZdlPv($1064);
                                                                                                                 }
                                                                                                                 $1077 = (__Znwj(48)|0);
                                                                                                                 HEAP32[$4>>2] = $1077;
                                                                                                                 $1078 = ((($4)) + 8|0);
                                                                                                                 HEAP32[$1078>>2] = -2147483600;
                                                                                                                 $1079 = ((($4)) + 4|0);
                                                                                                                 HEAP32[$1079>>2] = 42;
                                                                                                                 dest=$1077; src=124519; stop=dest+42|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                                                                                                                 $1080 = ((($1077)) + 42|0);
                                                                                                                 HEAP8[$1080>>0] = 0;
                                                                                                                 ;HEAP32[$5>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;
                                                                                                                 __THREW__ = 0;
                                                                                                                 $1081 = (invoke_ii(3276,112)|0);
                                                                                                                 $1082 = __THREW__; __THREW__ = 0;
                                                                                                                 $1083 = $1082&1;
                                                                                                                 do {
                                                                                                                  if ($1083) {
                                                                                                                   $1100 = ___cxa_find_matching_catch_2()|0;
                                                                                                                   $1101 = tempRet0;
                                                                                                                   $$0$i235 = $1101;$$01$i234 = $1100;
                                                                                                                  } else {
                                                                                                                   HEAP32[$5>>2] = $1081;
                                                                                                                   $1084 = ((($5)) + 8|0);
                                                                                                                   HEAP32[$1084>>2] = -2147483536;
                                                                                                                   $1085 = ((($5)) + 4|0);
                                                                                                                   HEAP32[$1085>>2] = 103;
                                                                                                                   dest=$1081; src=124562; stop=dest+103|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                                                                                                                   $1086 = ((($1081)) + 103|0);
                                                                                                                   HEAP8[$1086>>0] = 0;
                                                                                                                   __THREW__ = 0;
                                                                                                                   $1087 = (invoke_i(3459)|0);
                                                                                                                   $1088 = __THREW__; __THREW__ = 0;
                                                                                                                   $1089 = $1088&1;
                                                                                                                   do {
                                                                                                                    if (!($1089)) {
                                                                                                                     __THREW__ = 0;
                                                                                                                     invoke_viiii(3460,($1087|0),2,($4|0),($5|0));
                                                                                                                     $1090 = __THREW__; __THREW__ = 0;
                                                                                                                     $1091 = $1090&1;
                                                                                                                     if ($1091) {
                                                                                                                      break;
                                                                                                                     }
                                                                                                                     $1092 = ((($5)) + 11|0);
                                                                                                                     $1093 = HEAP8[$1092>>0]|0;
                                                                                                                     $1094 = ($1093<<24>>24)<(0);
                                                                                                                     if ($1094) {
                                                                                                                      $1095 = HEAP32[$5>>2]|0;
                                                                                                                      __ZdlPv($1095);
                                                                                                                     }
                                                                                                                     $1096 = ((($4)) + 11|0);
                                                                                                                     $1097 = HEAP8[$1096>>0]|0;
                                                                                                                     $1098 = ($1097<<24>>24)<(0);
                                                                                                                     if ($1098) {
                                                                                                                      $1099 = HEAP32[$4>>2]|0;
                                                                                                                      __ZdlPv($1099);
                                                                                                                     }
                                                                                                                     $1112 = (__Znwj(32)|0);
                                                                                                                     HEAP32[$2>>2] = $1112;
                                                                                                                     $1113 = ((($2)) + 8|0);
                                                                                                                     HEAP32[$1113>>2] = -2147483616;
                                                                                                                     $1114 = ((($2)) + 4|0);
                                                                                                                     HEAP32[$1114>>2] = 31;
                                                                                                                     dest=$1112; src=124666; stop=dest+31|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                                                                                                                     $1115 = ((($1112)) + 31|0);
                                                                                                                     HEAP8[$1115>>0] = 0;
                                                                                                                     ;HEAP32[$3>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;
                                                                                                                     __THREW__ = 0;
                                                                                                                     $1116 = (invoke_ii(3276,96)|0);
                                                                                                                     $1117 = __THREW__; __THREW__ = 0;
                                                                                                                     $1118 = $1117&1;
                                                                                                                     do {
                                                                                                                      if ($1118) {
                                                                                                                       $1135 = ___cxa_find_matching_catch_2()|0;
                                                                                                                       $1136 = tempRet0;
                                                                                                                       $$0$i243 = $1136;$$01$i242 = $1135;
                                                                                                                      } else {
                                                                                                                       HEAP32[$3>>2] = $1116;
                                                                                                                       $1119 = ((($3)) + 8|0);
                                                                                                                       HEAP32[$1119>>2] = -2147483552;
                                                                                                                       $1120 = ((($3)) + 4|0);
                                                                                                                       HEAP32[$1120>>2] = 82;
                                                                                                                       dest=$1116; src=124698; stop=dest+82|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                                                                                                                       $1121 = ((($1116)) + 82|0);
                                                                                                                       HEAP8[$1121>>0] = 0;
                                                                                                                       __THREW__ = 0;
                                                                                                                       $1122 = (invoke_i(3459)|0);
                                                                                                                       $1123 = __THREW__; __THREW__ = 0;
                                                                                                                       $1124 = $1123&1;
                                                                                                                       do {
                                                                                                                        if (!($1124)) {
                                                                                                                         __THREW__ = 0;
                                                                                                                         invoke_viiii(3460,($1122|0),2,($2|0),($3|0));
                                                                                                                         $1125 = __THREW__; __THREW__ = 0;
                                                                                                                         $1126 = $1125&1;
                                                                                                                         if ($1126) {
                                                                                                                          break;
                                                                                                                         }
                                                                                                                         $1127 = ((($3)) + 11|0);
                                                                                                                         $1128 = HEAP8[$1127>>0]|0;
                                                                                                                         $1129 = ($1128<<24>>24)<(0);
                                                                                                                         if ($1129) {
                                                                                                                          $1130 = HEAP32[$3>>2]|0;
                                                                                                                          __ZdlPv($1130);
                                                                                                                         }
                                                                                                                         $1131 = ((($2)) + 11|0);
                                                                                                                         $1132 = HEAP8[$1131>>0]|0;
                                                                                                                         $1133 = ($1132<<24>>24)<(0);
                                                                                                                         if ($1133) {
                                                                                                                          $1134 = HEAP32[$2>>2]|0;
                                                                                                                          __ZdlPv($1134);
                                                                                                                         }
                                                                                                                         $1147 = (__Znwj(32)|0);
                                                                                                                         HEAP32[$0>>2] = $1147;
                                                                                                                         $1148 = ((($0)) + 8|0);
                                                                                                                         HEAP32[$1148>>2] = -2147483616;
                                                                                                                         $1149 = ((($0)) + 4|0);
                                                                                                                         HEAP32[$1149>>2] = 31;
                                                                                                                         dest=$1147; src=124781; stop=dest+31|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                                                                                                                         $1150 = ((($1147)) + 31|0);
                                                                                                                         HEAP8[$1150>>0] = 0;
                                                                                                                         ;HEAP32[$1>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;
                                                                                                                         __THREW__ = 0;
                                                                                                                         $1151 = (invoke_ii(3276,96)|0);
                                                                                                                         $1152 = __THREW__; __THREW__ = 0;
                                                                                                                         $1153 = $1152&1;
                                                                                                                         do {
                                                                                                                          if ($1153) {
                                                                                                                           $1170 = ___cxa_find_matching_catch_2()|0;
                                                                                                                           $1171 = tempRet0;
                                                                                                                           $$0$i251 = $1171;$$01$i250 = $1170;
                                                                                                                          } else {
                                                                                                                           HEAP32[$1>>2] = $1151;
                                                                                                                           $1154 = ((($1)) + 8|0);
                                                                                                                           HEAP32[$1154>>2] = -2147483552;
                                                                                                                           $1155 = ((($1)) + 4|0);
                                                                                                                           HEAP32[$1155>>2] = 87;
                                                                                                                           dest=$1151; src=124813; stop=dest+87|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                                                                                                                           $1156 = ((($1151)) + 87|0);
                                                                                                                           HEAP8[$1156>>0] = 0;
                                                                                                                           __THREW__ = 0;
                                                                                                                           $1157 = (invoke_i(3459)|0);
                                                                                                                           $1158 = __THREW__; __THREW__ = 0;
                                                                                                                           $1159 = $1158&1;
                                                                                                                           do {
                                                                                                                            if (!($1159)) {
                                                                                                                             __THREW__ = 0;
                                                                                                                             invoke_viiii(3460,($1157|0),2,($0|0),($1|0));
                                                                                                                             $1160 = __THREW__; __THREW__ = 0;
                                                                                                                             $1161 = $1160&1;
                                                                                                                             if ($1161) {
                                                                                                                              break;
                                                                                                                             }
                                                                                                                             $1162 = ((($1)) + 11|0);
                                                                                                                             $1163 = HEAP8[$1162>>0]|0;
                                                                                                                             $1164 = ($1163<<24>>24)<(0);
                                                                                                                             if ($1164) {
                                                                                                                              $1165 = HEAP32[$1>>2]|0;
                                                                                                                              __ZdlPv($1165);
                                                                                                                             }
                                                                                                                             $1166 = ((($0)) + 11|0);
                                                                                                                             $1167 = HEAP8[$1166>>0]|0;
                                                                                                                             $1168 = ($1167<<24>>24)<(0);
                                                                                                                             if ($1168) {
                                                                                                                              $1169 = HEAP32[$0>>2]|0;
                                                                                                                              __ZdlPv($1169);
                                                                                                                             }
                                                                                                                             $1182 = (__Znwj(32)|0);
                                                                                                                             HEAP32[$64>>2] = $1182;
                                                                                                                             $1183 = ((($64)) + 8|0);
                                                                                                                             HEAP32[$1183>>2] = -2147483616;
                                                                                                                             $1184 = ((($64)) + 4|0);
                                                                                                                             HEAP32[$1184>>2] = 30;
                                                                                                                             dest=$1182; src=124901; stop=dest+30|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                                                                                                                             $1185 = ((($1182)) + 30|0);
                                                                                                                             HEAP8[$1185>>0] = 0;
                                                                                                                             ;HEAP32[$65>>2]=0|0;HEAP32[$65+4>>2]=0|0;HEAP32[$65+8>>2]=0|0;
                                                                                                                             __THREW__ = 0;
                                                                                                                             $1186 = (invoke_ii(3276,128)|0);
                                                                                                                             $1187 = __THREW__; __THREW__ = 0;
                                                                                                                             $1188 = $1187&1;
                                                                                                                             do {
                                                                                                                              if ($1188) {
                                                                                                                               $1205 = ___cxa_find_matching_catch_2()|0;
                                                                                                                               $1206 = tempRet0;
                                                                                                                               $$0$i = $1206;$$01$i = $1205;
                                                                                                                              } else {
                                                                                                                               HEAP32[$65>>2] = $1186;
                                                                                                                               $1189 = ((($65)) + 8|0);
                                                                                                                               HEAP32[$1189>>2] = -2147483520;
                                                                                                                               $1190 = ((($65)) + 4|0);
                                                                                                                               HEAP32[$1190>>2] = 124;
                                                                                                                               dest=$1186; src=124932; stop=dest+124|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                                                                                                                               $1191 = ((($1186)) + 124|0);
                                                                                                                               HEAP8[$1191>>0] = 0;
                                                                                                                               __THREW__ = 0;
                                                                                                                               $1192 = (invoke_i(3459)|0);
                                                                                                                               $1193 = __THREW__; __THREW__ = 0;
                                                                                                                               $1194 = $1193&1;
                                                                                                                               do {
                                                                                                                                if (!($1194)) {
                                                                                                                                 __THREW__ = 0;
                                                                                                                                 invoke_viiii(3460,($1192|0),2,($64|0),($65|0));
                                                                                                                                 $1195 = __THREW__; __THREW__ = 0;
                                                                                                                                 $1196 = $1195&1;
                                                                                                                                 if ($1196) {
                                                                                                                                  break;
                                                                                                                                 }
                                                                                                                                 $1197 = ((($65)) + 11|0);
                                                                                                                                 $1198 = HEAP8[$1197>>0]|0;
                                                                                                                                 $1199 = ($1198<<24>>24)<(0);
                                                                                                                                 if ($1199) {
                                                                                                                                  $1200 = HEAP32[$65>>2]|0;
                                                                                                                                  __ZdlPv($1200);
                                                                                                                                 }
                                                                                                                                 $1201 = ((($64)) + 11|0);
                                                                                                                                 $1202 = HEAP8[$1201>>0]|0;
                                                                                                                                 $1203 = ($1202<<24>>24)<(0);
                                                                                                                                 if (!($1203)) {
                                                                                                                                  STACKTOP = sp;return;
                                                                                                                                 }
                                                                                                                                 $1204 = HEAP32[$64>>2]|0;
                                                                                                                                 __ZdlPv($1204);
                                                                                                                                 STACKTOP = sp;return;
                                                                                                                                }
                                                                                                                               } while(0);
                                                                                                                               $1207 = ___cxa_find_matching_catch_2()|0;
                                                                                                                               $1208 = tempRet0;
                                                                                                                               $1209 = ((($65)) + 11|0);
                                                                                                                               $1210 = HEAP8[$1209>>0]|0;
                                                                                                                               $1211 = ($1210<<24>>24)<(0);
                                                                                                                               if (!($1211)) {
                                                                                                                                $$0$i = $1208;$$01$i = $1207;
                                                                                                                                break;
                                                                                                                               }
                                                                                                                               $1212 = HEAP32[$65>>2]|0;
                                                                                                                               __ZdlPv($1212);
                                                                                                                               $$0$i = $1208;$$01$i = $1207;
                                                                                                                              }
                                                                                                                             } while(0);
                                                                                                                             $1213 = ((($64)) + 11|0);
                                                                                                                             $1214 = HEAP8[$1213>>0]|0;
                                                                                                                             $1215 = ($1214<<24>>24)<(0);
                                                                                                                             if (!($1215)) {
                                                                                                                              ___resumeException($$01$i|0);
                                                                                                                              // unreachable;
                                                                                                                             }
                                                                                                                             $1216 = HEAP32[$64>>2]|0;
                                                                                                                             __ZdlPv($1216);
                                                                                                                             ___resumeException($$01$i|0);
                                                                                                                             // unreachable;
                                                                                                                            }
                                                                                                                           } while(0);
                                                                                                                           $1172 = ___cxa_find_matching_catch_2()|0;
                                                                                                                           $1173 = tempRet0;
                                                                                                                           $1174 = ((($1)) + 11|0);
                                                                                                                           $1175 = HEAP8[$1174>>0]|0;
                                                                                                                           $1176 = ($1175<<24>>24)<(0);
                                                                                                                           if (!($1176)) {
                                                                                                                            $$0$i251 = $1173;$$01$i250 = $1172;
                                                                                                                            break;
                                                                                                                           }
                                                                                                                           $1177 = HEAP32[$1>>2]|0;
                                                                                                                           __ZdlPv($1177);
                                                                                                                           $$0$i251 = $1173;$$01$i250 = $1172;
                                                                                                                          }
                                                                                                                         } while(0);
                                                                                                                         $1178 = ((($0)) + 11|0);
                                                                                                                         $1179 = HEAP8[$1178>>0]|0;
                                                                                                                         $1180 = ($1179<<24>>24)<(0);
                                                                                                                         if (!($1180)) {
                                                                                                                          ___resumeException($$01$i250|0);
                                                                                                                          // unreachable;
                                                                                                                         }
                                                                                                                         $1181 = HEAP32[$0>>2]|0;
                                                                                                                         __ZdlPv($1181);
                                                                                                                         ___resumeException($$01$i250|0);
                                                                                                                         // unreachable;
                                                                                                                        }
                                                                                                                       } while(0);
                                                                                                                       $1137 = ___cxa_find_matching_catch_2()|0;
                                                                                                                       $1138 = tempRet0;
                                                                                                                       $1139 = ((($3)) + 11|0);
                                                                                                                       $1140 = HEAP8[$1139>>0]|0;
                                                                                                                       $1141 = ($1140<<24>>24)<(0);
                                                                                                                       if (!($1141)) {
                                                                                                                        $$0$i243 = $1138;$$01$i242 = $1137;
                                                                                                                        break;
                                                                                                                       }
                                                                                                                       $1142 = HEAP32[$3>>2]|0;
                                                                                                                       __ZdlPv($1142);
                                                                                                                       $$0$i243 = $1138;$$01$i242 = $1137;
                                                                                                                      }
                                                                                                                     } while(0);
                                                                                                                     $1143 = ((($2)) + 11|0);
                                                                                                                     $1144 = HEAP8[$1143>>0]|0;
                                                                                                                     $1145 = ($1144<<24>>24)<(0);
                                                                                                                     if (!($1145)) {
                                                                                                                      ___resumeException($$01$i242|0);
                                                                                                                      // unreachable;
                                                                                                                     }
                                                                                                                     $1146 = HEAP32[$2>>2]|0;
                                                                                                                     __ZdlPv($1146);
                                                                                                                     ___resumeException($$01$i242|0);
                                                                                                                     // unreachable;
                                                                                                                    }
                                                                                                                   } while(0);
                                                                                                                   $1102 = ___cxa_find_matching_catch_2()|0;
                                                                                                                   $1103 = tempRet0;
                                                                                                                   $1104 = ((($5)) + 11|0);
                                                                                                                   $1105 = HEAP8[$1104>>0]|0;
                                                                                                                   $1106 = ($1105<<24>>24)<(0);
                                                                                                                   if (!($1106)) {
                                                                                                                    $$0$i235 = $1103;$$01$i234 = $1102;
                                                                                                                    break;
                                                                                                                   }
                                                                                                                   $1107 = HEAP32[$5>>2]|0;
                                                                                                                   __ZdlPv($1107);
                                                                                                                   $$0$i235 = $1103;$$01$i234 = $1102;
                                                                                                                  }
                                                                                                                 } while(0);
                                                                                                                 $1108 = ((($4)) + 11|0);
                                                                                                                 $1109 = HEAP8[$1108>>0]|0;
                                                                                                                 $1110 = ($1109<<24>>24)<(0);
                                                                                                                 if (!($1110)) {
                                                                                                                  ___resumeException($$01$i234|0);
                                                                                                                  // unreachable;
                                                                                                                 }
                                                                                                                 $1111 = HEAP32[$4>>2]|0;
                                                                                                                 __ZdlPv($1111);
                                                                                                                 ___resumeException($$01$i234|0);
                                                                                                                 // unreachable;
                                                                                                                }
                                                                                                               } while(0);
                                                                                                               $1067 = ___cxa_find_matching_catch_2()|0;
                                                                                                               $1068 = tempRet0;
                                                                                                               $1069 = ((($7)) + 11|0);
                                                                                                               $1070 = HEAP8[$1069>>0]|0;
                                                                                                               $1071 = ($1070<<24>>24)<(0);
                                                                                                               if (!($1071)) {
                                                                                                                $$0$i227 = $1068;$$01$i226 = $1067;
                                                                                                                break;
                                                                                                               }
                                                                                                               $1072 = HEAP32[$7>>2]|0;
                                                                                                               __ZdlPv($1072);
                                                                                                               $$0$i227 = $1068;$$01$i226 = $1067;
                                                                                                              }
                                                                                                             } while(0);
                                                                                                             $1073 = ((($6)) + 11|0);
                                                                                                             $1074 = HEAP8[$1073>>0]|0;
                                                                                                             $1075 = ($1074<<24>>24)<(0);
                                                                                                             if (!($1075)) {
                                                                                                              ___resumeException($$01$i226|0);
                                                                                                              // unreachable;
                                                                                                             }
                                                                                                             $1076 = HEAP32[$6>>2]|0;
                                                                                                             __ZdlPv($1076);
                                                                                                             ___resumeException($$01$i226|0);
                                                                                                             // unreachable;
                                                                                                            }
                                                                                                           } while(0);
                                                                                                           $1032 = ___cxa_find_matching_catch_2()|0;
                                                                                                           $1033 = tempRet0;
                                                                                                           $1034 = ((($9)) + 11|0);
                                                                                                           $1035 = HEAP8[$1034>>0]|0;
                                                                                                           $1036 = ($1035<<24>>24)<(0);
                                                                                                           if (!($1036)) {
                                                                                                            $$0$i219 = $1033;$$01$i218 = $1032;
                                                                                                            break;
                                                                                                           }
                                                                                                           $1037 = HEAP32[$9>>2]|0;
                                                                                                           __ZdlPv($1037);
                                                                                                           $$0$i219 = $1033;$$01$i218 = $1032;
                                                                                                          }
                                                                                                         } while(0);
                                                                                                         $1038 = ((($8)) + 11|0);
                                                                                                         $1039 = HEAP8[$1038>>0]|0;
                                                                                                         $1040 = ($1039<<24>>24)<(0);
                                                                                                         if (!($1040)) {
                                                                                                          ___resumeException($$01$i218|0);
                                                                                                          // unreachable;
                                                                                                         }
                                                                                                         $1041 = HEAP32[$8>>2]|0;
                                                                                                         __ZdlPv($1041);
                                                                                                         ___resumeException($$01$i218|0);
                                                                                                         // unreachable;
                                                                                                        }
                                                                                                       } while(0);
                                                                                                       $997 = ___cxa_find_matching_catch_2()|0;
                                                                                                       $998 = tempRet0;
                                                                                                       $999 = ((($11)) + 11|0);
                                                                                                       $1000 = HEAP8[$999>>0]|0;
                                                                                                       $1001 = ($1000<<24>>24)<(0);
                                                                                                       if (!($1001)) {
                                                                                                        $$0$i211 = $998;$$01$i210 = $997;
                                                                                                        break;
                                                                                                       }
                                                                                                       $1002 = HEAP32[$11>>2]|0;
                                                                                                       __ZdlPv($1002);
                                                                                                       $$0$i211 = $998;$$01$i210 = $997;
                                                                                                      }
                                                                                                     } while(0);
                                                                                                     $1003 = ((($10)) + 11|0);
                                                                                                     $1004 = HEAP8[$1003>>0]|0;
                                                                                                     $1005 = ($1004<<24>>24)<(0);
                                                                                                     if (!($1005)) {
                                                                                                      ___resumeException($$01$i210|0);
                                                                                                      // unreachable;
                                                                                                     }
                                                                                                     $1006 = HEAP32[$10>>2]|0;
                                                                                                     __ZdlPv($1006);
                                                                                                     ___resumeException($$01$i210|0);
                                                                                                     // unreachable;
                                                                                                    }
                                                                                                   } while(0);
                                                                                                   $962 = ___cxa_find_matching_catch_2()|0;
                                                                                                   $963 = tempRet0;
                                                                                                   $964 = ((($13)) + 11|0);
                                                                                                   $965 = HEAP8[$964>>0]|0;
                                                                                                   $966 = ($965<<24>>24)<(0);
                                                                                                   if (!($966)) {
                                                                                                    $$0$i203 = $963;$$01$i202 = $962;
                                                                                                    break;
                                                                                                   }
                                                                                                   $967 = HEAP32[$13>>2]|0;
                                                                                                   __ZdlPv($967);
                                                                                                   $$0$i203 = $963;$$01$i202 = $962;
                                                                                                  }
                                                                                                 } while(0);
                                                                                                 $968 = ((($12)) + 11|0);
                                                                                                 $969 = HEAP8[$968>>0]|0;
                                                                                                 $970 = ($969<<24>>24)<(0);
                                                                                                 if (!($970)) {
                                                                                                  ___resumeException($$01$i202|0);
                                                                                                  // unreachable;
                                                                                                 }
                                                                                                 $971 = HEAP32[$12>>2]|0;
                                                                                                 __ZdlPv($971);
                                                                                                 ___resumeException($$01$i202|0);
                                                                                                 // unreachable;
                                                                                                }
                                                                                               } while(0);
                                                                                               $927 = ___cxa_find_matching_catch_2()|0;
                                                                                               $928 = tempRet0;
                                                                                               $929 = ((($15)) + 11|0);
                                                                                               $930 = HEAP8[$929>>0]|0;
                                                                                               $931 = ($930<<24>>24)<(0);
                                                                                               if (!($931)) {
                                                                                                $$0$i195 = $928;$$01$i194 = $927;
                                                                                                break;
                                                                                               }
                                                                                               $932 = HEAP32[$15>>2]|0;
                                                                                               __ZdlPv($932);
                                                                                               $$0$i195 = $928;$$01$i194 = $927;
                                                                                              }
                                                                                             } while(0);
                                                                                             $933 = ((($14)) + 11|0);
                                                                                             $934 = HEAP8[$933>>0]|0;
                                                                                             $935 = ($934<<24>>24)<(0);
                                                                                             if (!($935)) {
                                                                                              ___resumeException($$01$i194|0);
                                                                                              // unreachable;
                                                                                             }
                                                                                             $936 = HEAP32[$14>>2]|0;
                                                                                             __ZdlPv($936);
                                                                                             ___resumeException($$01$i194|0);
                                                                                             // unreachable;
                                                                                            }
                                                                                           } while(0);
                                                                                           $892 = ___cxa_find_matching_catch_2()|0;
                                                                                           $893 = tempRet0;
                                                                                           $894 = ((($17)) + 11|0);
                                                                                           $895 = HEAP8[$894>>0]|0;
                                                                                           $896 = ($895<<24>>24)<(0);
                                                                                           if (!($896)) {
                                                                                            $$0$i187 = $893;$$01$i186 = $892;
                                                                                            break;
                                                                                           }
                                                                                           $897 = HEAP32[$17>>2]|0;
                                                                                           __ZdlPv($897);
                                                                                           $$0$i187 = $893;$$01$i186 = $892;
                                                                                          }
                                                                                         } while(0);
                                                                                         $898 = ((($16)) + 11|0);
                                                                                         $899 = HEAP8[$898>>0]|0;
                                                                                         $900 = ($899<<24>>24)<(0);
                                                                                         if (!($900)) {
                                                                                          ___resumeException($$01$i186|0);
                                                                                          // unreachable;
                                                                                         }
                                                                                         $901 = HEAP32[$16>>2]|0;
                                                                                         __ZdlPv($901);
                                                                                         ___resumeException($$01$i186|0);
                                                                                         // unreachable;
                                                                                        }
                                                                                       } while(0);
                                                                                       $857 = ___cxa_find_matching_catch_2()|0;
                                                                                       $858 = tempRet0;
                                                                                       $859 = ((($19)) + 11|0);
                                                                                       $860 = HEAP8[$859>>0]|0;
                                                                                       $861 = ($860<<24>>24)<(0);
                                                                                       if (!($861)) {
                                                                                        $$0$i179 = $858;$$01$i178 = $857;
                                                                                        break;
                                                                                       }
                                                                                       $862 = HEAP32[$19>>2]|0;
                                                                                       __ZdlPv($862);
                                                                                       $$0$i179 = $858;$$01$i178 = $857;
                                                                                      }
                                                                                     } while(0);
                                                                                     $863 = ((($18)) + 11|0);
                                                                                     $864 = HEAP8[$863>>0]|0;
                                                                                     $865 = ($864<<24>>24)<(0);
                                                                                     if (!($865)) {
                                                                                      ___resumeException($$01$i178|0);
                                                                                      // unreachable;
                                                                                     }
                                                                                     $866 = HEAP32[$18>>2]|0;
                                                                                     __ZdlPv($866);
                                                                                     ___resumeException($$01$i178|0);
                                                                                     // unreachable;
                                                                                    }
                                                                                   } while(0);
                                                                                   $822 = ___cxa_find_matching_catch_2()|0;
                                                                                   $823 = tempRet0;
                                                                                   $824 = ((($21)) + 11|0);
                                                                                   $825 = HEAP8[$824>>0]|0;
                                                                                   $826 = ($825<<24>>24)<(0);
                                                                                   if (!($826)) {
                                                                                    $$0$i171 = $823;$$01$i170 = $822;
                                                                                    break;
                                                                                   }
                                                                                   $827 = HEAP32[$21>>2]|0;
                                                                                   __ZdlPv($827);
                                                                                   $$0$i171 = $823;$$01$i170 = $822;
                                                                                  }
                                                                                 } while(0);
                                                                                 $828 = ((($20)) + 11|0);
                                                                                 $829 = HEAP8[$828>>0]|0;
                                                                                 $830 = ($829<<24>>24)<(0);
                                                                                 if (!($830)) {
                                                                                  ___resumeException($$01$i170|0);
                                                                                  // unreachable;
                                                                                 }
                                                                                 $831 = HEAP32[$20>>2]|0;
                                                                                 __ZdlPv($831);
                                                                                 ___resumeException($$01$i170|0);
                                                                                 // unreachable;
                                                                                }
                                                                               } while(0);
                                                                               $787 = ___cxa_find_matching_catch_2()|0;
                                                                               $788 = tempRet0;
                                                                               $789 = ((($23)) + 11|0);
                                                                               $790 = HEAP8[$789>>0]|0;
                                                                               $791 = ($790<<24>>24)<(0);
                                                                               if (!($791)) {
                                                                                $$0$i163 = $788;$$01$i162 = $787;
                                                                                break;
                                                                               }
                                                                               $792 = HEAP32[$23>>2]|0;
                                                                               __ZdlPv($792);
                                                                               $$0$i163 = $788;$$01$i162 = $787;
                                                                              }
                                                                             } while(0);
                                                                             $793 = ((($22)) + 11|0);
                                                                             $794 = HEAP8[$793>>0]|0;
                                                                             $795 = ($794<<24>>24)<(0);
                                                                             if (!($795)) {
                                                                              ___resumeException($$01$i162|0);
                                                                              // unreachable;
                                                                             }
                                                                             $796 = HEAP32[$22>>2]|0;
                                                                             __ZdlPv($796);
                                                                             ___resumeException($$01$i162|0);
                                                                             // unreachable;
                                                                            }
                                                                           } while(0);
                                                                           $752 = ___cxa_find_matching_catch_2()|0;
                                                                           $753 = tempRet0;
                                                                           $754 = ((($25)) + 11|0);
                                                                           $755 = HEAP8[$754>>0]|0;
                                                                           $756 = ($755<<24>>24)<(0);
                                                                           if (!($756)) {
                                                                            $$0$i155 = $753;$$01$i154 = $752;
                                                                            break;
                                                                           }
                                                                           $757 = HEAP32[$25>>2]|0;
                                                                           __ZdlPv($757);
                                                                           $$0$i155 = $753;$$01$i154 = $752;
                                                                          }
                                                                         } while(0);
                                                                         $758 = ((($24)) + 11|0);
                                                                         $759 = HEAP8[$758>>0]|0;
                                                                         $760 = ($759<<24>>24)<(0);
                                                                         if (!($760)) {
                                                                          ___resumeException($$01$i154|0);
                                                                          // unreachable;
                                                                         }
                                                                         $761 = HEAP32[$24>>2]|0;
                                                                         __ZdlPv($761);
                                                                         ___resumeException($$01$i154|0);
                                                                         // unreachable;
                                                                        }
                                                                       } while(0);
                                                                       $717 = ___cxa_find_matching_catch_2()|0;
                                                                       $718 = tempRet0;
                                                                       $719 = ((($27)) + 11|0);
                                                                       $720 = HEAP8[$719>>0]|0;
                                                                       $721 = ($720<<24>>24)<(0);
                                                                       if (!($721)) {
                                                                        $$0$i147 = $718;$$01$i146 = $717;
                                                                        break;
                                                                       }
                                                                       $722 = HEAP32[$27>>2]|0;
                                                                       __ZdlPv($722);
                                                                       $$0$i147 = $718;$$01$i146 = $717;
                                                                      }
                                                                     } while(0);
                                                                     $723 = ((($26)) + 11|0);
                                                                     $724 = HEAP8[$723>>0]|0;
                                                                     $725 = ($724<<24>>24)<(0);
                                                                     if (!($725)) {
                                                                      ___resumeException($$01$i146|0);
                                                                      // unreachable;
                                                                     }
                                                                     $726 = HEAP32[$26>>2]|0;
                                                                     __ZdlPv($726);
                                                                     ___resumeException($$01$i146|0);
                                                                     // unreachable;
                                                                    }
                                                                   } while(0);
                                                                   $682 = ___cxa_find_matching_catch_2()|0;
                                                                   $683 = tempRet0;
                                                                   $684 = ((($29)) + 11|0);
                                                                   $685 = HEAP8[$684>>0]|0;
                                                                   $686 = ($685<<24>>24)<(0);
                                                                   if (!($686)) {
                                                                    $$0$i139 = $683;$$01$i138 = $682;
                                                                    break;
                                                                   }
                                                                   $687 = HEAP32[$29>>2]|0;
                                                                   __ZdlPv($687);
                                                                   $$0$i139 = $683;$$01$i138 = $682;
                                                                  }
                                                                 } while(0);
                                                                 $688 = ((($28)) + 11|0);
                                                                 $689 = HEAP8[$688>>0]|0;
                                                                 $690 = ($689<<24>>24)<(0);
                                                                 if (!($690)) {
                                                                  ___resumeException($$01$i138|0);
                                                                  // unreachable;
                                                                 }
                                                                 $691 = HEAP32[$28>>2]|0;
                                                                 __ZdlPv($691);
                                                                 ___resumeException($$01$i138|0);
                                                                 // unreachable;
                                                                }
                                                               } while(0);
                                                               $647 = ___cxa_find_matching_catch_2()|0;
                                                               $648 = tempRet0;
                                                               $649 = ((($31)) + 11|0);
                                                               $650 = HEAP8[$649>>0]|0;
                                                               $651 = ($650<<24>>24)<(0);
                                                               if (!($651)) {
                                                                $$0$i131 = $648;$$01$i130 = $647;
                                                                break;
                                                               }
                                                               $652 = HEAP32[$31>>2]|0;
                                                               __ZdlPv($652);
                                                               $$0$i131 = $648;$$01$i130 = $647;
                                                              }
                                                             } while(0);
                                                             $653 = ((($30)) + 11|0);
                                                             $654 = HEAP8[$653>>0]|0;
                                                             $655 = ($654<<24>>24)<(0);
                                                             if (!($655)) {
                                                              ___resumeException($$01$i130|0);
                                                              // unreachable;
                                                             }
                                                             $656 = HEAP32[$30>>2]|0;
                                                             __ZdlPv($656);
                                                             ___resumeException($$01$i130|0);
                                                             // unreachable;
                                                            }
                                                           } while(0);
                                                           $612 = ___cxa_find_matching_catch_2()|0;
                                                           $613 = tempRet0;
                                                           $614 = ((($33)) + 11|0);
                                                           $615 = HEAP8[$614>>0]|0;
                                                           $616 = ($615<<24>>24)<(0);
                                                           if (!($616)) {
                                                            $$0$i123 = $613;$$01$i122 = $612;
                                                            break;
                                                           }
                                                           $617 = HEAP32[$33>>2]|0;
                                                           __ZdlPv($617);
                                                           $$0$i123 = $613;$$01$i122 = $612;
                                                          }
                                                         } while(0);
                                                         $618 = ((($32)) + 11|0);
                                                         $619 = HEAP8[$618>>0]|0;
                                                         $620 = ($619<<24>>24)<(0);
                                                         if (!($620)) {
                                                          ___resumeException($$01$i122|0);
                                                          // unreachable;
                                                         }
                                                         $621 = HEAP32[$32>>2]|0;
                                                         __ZdlPv($621);
                                                         ___resumeException($$01$i122|0);
                                                         // unreachable;
                                                        }
                                                       } while(0);
                                                       $577 = ___cxa_find_matching_catch_2()|0;
                                                       $578 = tempRet0;
                                                       $579 = ((($35)) + 11|0);
                                                       $580 = HEAP8[$579>>0]|0;
                                                       $581 = ($580<<24>>24)<(0);
                                                       if (!($581)) {
                                                        $$0$i115 = $578;$$01$i114 = $577;
                                                        break;
                                                       }
                                                       $582 = HEAP32[$35>>2]|0;
                                                       __ZdlPv($582);
                                                       $$0$i115 = $578;$$01$i114 = $577;
                                                      }
                                                     } while(0);
                                                     $583 = ((($34)) + 11|0);
                                                     $584 = HEAP8[$583>>0]|0;
                                                     $585 = ($584<<24>>24)<(0);
                                                     if (!($585)) {
                                                      ___resumeException($$01$i114|0);
                                                      // unreachable;
                                                     }
                                                     $586 = HEAP32[$34>>2]|0;
                                                     __ZdlPv($586);
                                                     ___resumeException($$01$i114|0);
                                                     // unreachable;
                                                    }
                                                   } while(0);
                                                   $542 = ___cxa_find_matching_catch_2()|0;
                                                   $543 = tempRet0;
                                                   $544 = ((($37)) + 11|0);
                                                   $545 = HEAP8[$544>>0]|0;
                                                   $546 = ($545<<24>>24)<(0);
                                                   if (!($546)) {
                                                    $$0$i107 = $543;$$01$i106 = $542;
                                                    break;
                                                   }
                                                   $547 = HEAP32[$37>>2]|0;
                                                   __ZdlPv($547);
                                                   $$0$i107 = $543;$$01$i106 = $542;
                                                  }
                                                 } while(0);
                                                 $548 = ((($36)) + 11|0);
                                                 $549 = HEAP8[$548>>0]|0;
                                                 $550 = ($549<<24>>24)<(0);
                                                 if (!($550)) {
                                                  ___resumeException($$01$i106|0);
                                                  // unreachable;
                                                 }
                                                 $551 = HEAP32[$36>>2]|0;
                                                 __ZdlPv($551);
                                                 ___resumeException($$01$i106|0);
                                                 // unreachable;
                                                }
                                               } while(0);
                                               $507 = ___cxa_find_matching_catch_2()|0;
                                               $508 = tempRet0;
                                               $509 = ((($39)) + 11|0);
                                               $510 = HEAP8[$509>>0]|0;
                                               $511 = ($510<<24>>24)<(0);
                                               if (!($511)) {
                                                $$0$i99 = $508;$$01$i98 = $507;
                                                break;
                                               }
                                               $512 = HEAP32[$39>>2]|0;
                                               __ZdlPv($512);
                                               $$0$i99 = $508;$$01$i98 = $507;
                                              }
                                             } while(0);
                                             $513 = ((($38)) + 11|0);
                                             $514 = HEAP8[$513>>0]|0;
                                             $515 = ($514<<24>>24)<(0);
                                             if (!($515)) {
                                              ___resumeException($$01$i98|0);
                                              // unreachable;
                                             }
                                             $516 = HEAP32[$38>>2]|0;
                                             __ZdlPv($516);
                                             ___resumeException($$01$i98|0);
                                             // unreachable;
                                            }
                                           } while(0);
                                           $472 = ___cxa_find_matching_catch_2()|0;
                                           $473 = tempRet0;
                                           $474 = ((($41)) + 11|0);
                                           $475 = HEAP8[$474>>0]|0;
                                           $476 = ($475<<24>>24)<(0);
                                           if (!($476)) {
                                            $$0$i91 = $473;$$01$i90 = $472;
                                            break;
                                           }
                                           $477 = HEAP32[$41>>2]|0;
                                           __ZdlPv($477);
                                           $$0$i91 = $473;$$01$i90 = $472;
                                          }
                                         } while(0);
                                         $478 = ((($40)) + 11|0);
                                         $479 = HEAP8[$478>>0]|0;
                                         $480 = ($479<<24>>24)<(0);
                                         if (!($480)) {
                                          ___resumeException($$01$i90|0);
                                          // unreachable;
                                         }
                                         $481 = HEAP32[$40>>2]|0;
                                         __ZdlPv($481);
                                         ___resumeException($$01$i90|0);
                                         // unreachable;
                                        }
                                       } while(0);
                                       $437 = ___cxa_find_matching_catch_2()|0;
                                       $438 = tempRet0;
                                       $439 = ((($43)) + 11|0);
                                       $440 = HEAP8[$439>>0]|0;
                                       $441 = ($440<<24>>24)<(0);
                                       if (!($441)) {
                                        $$0$i83 = $438;$$01$i82 = $437;
                                        break;
                                       }
                                       $442 = HEAP32[$43>>2]|0;
                                       __ZdlPv($442);
                                       $$0$i83 = $438;$$01$i82 = $437;
                                      }
                                     } while(0);
                                     $443 = ((($42)) + 11|0);
                                     $444 = HEAP8[$443>>0]|0;
                                     $445 = ($444<<24>>24)<(0);
                                     if (!($445)) {
                                      ___resumeException($$01$i82|0);
                                      // unreachable;
                                     }
                                     $446 = HEAP32[$42>>2]|0;
                                     __ZdlPv($446);
                                     ___resumeException($$01$i82|0);
                                     // unreachable;
                                    }
                                   } while(0);
                                   $402 = ___cxa_find_matching_catch_2()|0;
                                   $403 = tempRet0;
                                   $404 = ((($45)) + 11|0);
                                   $405 = HEAP8[$404>>0]|0;
                                   $406 = ($405<<24>>24)<(0);
                                   if (!($406)) {
                                    $$0$i75 = $403;$$01$i74 = $402;
                                    break;
                                   }
                                   $407 = HEAP32[$45>>2]|0;
                                   __ZdlPv($407);
                                   $$0$i75 = $403;$$01$i74 = $402;
                                  }
                                 } while(0);
                                 $408 = ((($44)) + 11|0);
                                 $409 = HEAP8[$408>>0]|0;
                                 $410 = ($409<<24>>24)<(0);
                                 if (!($410)) {
                                  ___resumeException($$01$i74|0);
                                  // unreachable;
                                 }
                                 $411 = HEAP32[$44>>2]|0;
                                 __ZdlPv($411);
                                 ___resumeException($$01$i74|0);
                                 // unreachable;
                                }
                               } while(0);
                               $367 = ___cxa_find_matching_catch_2()|0;
                               $368 = tempRet0;
                               $369 = ((($47)) + 11|0);
                               $370 = HEAP8[$369>>0]|0;
                               $371 = ($370<<24>>24)<(0);
                               if (!($371)) {
                                $$0$i67 = $368;$$01$i66 = $367;
                                break;
                               }
                               $372 = HEAP32[$47>>2]|0;
                               __ZdlPv($372);
                               $$0$i67 = $368;$$01$i66 = $367;
                              }
                             } while(0);
                             $373 = ((($46)) + 11|0);
                             $374 = HEAP8[$373>>0]|0;
                             $375 = ($374<<24>>24)<(0);
                             if (!($375)) {
                              ___resumeException($$01$i66|0);
                              // unreachable;
                             }
                             $376 = HEAP32[$46>>2]|0;
                             __ZdlPv($376);
                             ___resumeException($$01$i66|0);
                             // unreachable;
                            }
                           } while(0);
                           $332 = ___cxa_find_matching_catch_2()|0;
                           $333 = tempRet0;
                           $334 = ((($49)) + 11|0);
                           $335 = HEAP8[$334>>0]|0;
                           $336 = ($335<<24>>24)<(0);
                           if (!($336)) {
                            $$0$i59 = $333;$$01$i58 = $332;
                            break;
                           }
                           $337 = HEAP32[$49>>2]|0;
                           __ZdlPv($337);
                           $$0$i59 = $333;$$01$i58 = $332;
                          }
                         } while(0);
                         $338 = ((($48)) + 11|0);
                         $339 = HEAP8[$338>>0]|0;
                         $340 = ($339<<24>>24)<(0);
                         if (!($340)) {
                          ___resumeException($$01$i58|0);
                          // unreachable;
                         }
                         $341 = HEAP32[$48>>2]|0;
                         __ZdlPv($341);
                         ___resumeException($$01$i58|0);
                         // unreachable;
                        }
                       } while(0);
                       $297 = ___cxa_find_matching_catch_2()|0;
                       $298 = tempRet0;
                       $299 = ((($51)) + 11|0);
                       $300 = HEAP8[$299>>0]|0;
                       $301 = ($300<<24>>24)<(0);
                       if (!($301)) {
                        $$0$i51 = $298;$$01$i50 = $297;
                        break;
                       }
                       $302 = HEAP32[$51>>2]|0;
                       __ZdlPv($302);
                       $$0$i51 = $298;$$01$i50 = $297;
                      }
                     } while(0);
                     $303 = ((($50)) + 11|0);
                     $304 = HEAP8[$303>>0]|0;
                     $305 = ($304<<24>>24)<(0);
                     if (!($305)) {
                      ___resumeException($$01$i50|0);
                      // unreachable;
                     }
                     $306 = HEAP32[$50>>2]|0;
                     __ZdlPv($306);
                     ___resumeException($$01$i50|0);
                     // unreachable;
                    }
                   } while(0);
                   $262 = ___cxa_find_matching_catch_2()|0;
                   $263 = tempRet0;
                   $264 = ((($53)) + 11|0);
                   $265 = HEAP8[$264>>0]|0;
                   $266 = ($265<<24>>24)<(0);
                   if (!($266)) {
                    $$0$i43 = $263;$$01$i42 = $262;
                    break;
                   }
                   $267 = HEAP32[$53>>2]|0;
                   __ZdlPv($267);
                   $$0$i43 = $263;$$01$i42 = $262;
                  }
                 } while(0);
                 $268 = ((($52)) + 11|0);
                 $269 = HEAP8[$268>>0]|0;
                 $270 = ($269<<24>>24)<(0);
                 if (!($270)) {
                  ___resumeException($$01$i42|0);
                  // unreachable;
                 }
                 $271 = HEAP32[$52>>2]|0;
                 __ZdlPv($271);
                 ___resumeException($$01$i42|0);
                 // unreachable;
                }
               } while(0);
               $227 = ___cxa_find_matching_catch_2()|0;
               $228 = tempRet0;
               $229 = ((($55)) + 11|0);
               $230 = HEAP8[$229>>0]|0;
               $231 = ($230<<24>>24)<(0);
               if (!($231)) {
                $$0$i35 = $228;$$01$i34 = $227;
                break;
               }
               $232 = HEAP32[$55>>2]|0;
               __ZdlPv($232);
               $$0$i35 = $228;$$01$i34 = $227;
              }
             } while(0);
             $233 = ((($54)) + 11|0);
             $234 = HEAP8[$233>>0]|0;
             $235 = ($234<<24>>24)<(0);
             if (!($235)) {
              ___resumeException($$01$i34|0);
              // unreachable;
             }
             $236 = HEAP32[$54>>2]|0;
             __ZdlPv($236);
             ___resumeException($$01$i34|0);
             // unreachable;
            }
           } while(0);
           $192 = ___cxa_find_matching_catch_2()|0;
           $193 = tempRet0;
           $194 = ((($57)) + 11|0);
           $195 = HEAP8[$194>>0]|0;
           $196 = ($195<<24>>24)<(0);
           if (!($196)) {
            $$0$i27 = $193;$$01$i26 = $192;
            break;
           }
           $197 = HEAP32[$57>>2]|0;
           __ZdlPv($197);
           $$0$i27 = $193;$$01$i26 = $192;
          }
         } while(0);
         $198 = ((($56)) + 11|0);
         $199 = HEAP8[$198>>0]|0;
         $200 = ($199<<24>>24)<(0);
         if (!($200)) {
          ___resumeException($$01$i26|0);
          // unreachable;
         }
         $201 = HEAP32[$56>>2]|0;
         __ZdlPv($201);
         ___resumeException($$01$i26|0);
         // unreachable;
        }
       }
       $158 = ___cxa_find_matching_catch_2()|0;
       $159 = tempRet0;
       $160 = HEAP8[$140>>0]|0;
       $161 = ($160<<24>>24)<(0);
       if ($161) {
        $162 = HEAP32[$59>>2]|0;
        __ZdlPv($162);
       }
       $163 = ((($58)) + 11|0);
       $164 = HEAP8[$163>>0]|0;
       $165 = ($164<<24>>24)<(0);
       if (!($165)) {
        ___resumeException($158|0);
        // unreachable;
       }
       $166 = HEAP32[$58>>2]|0;
       __ZdlPv($166);
       ___resumeException($158|0);
       // unreachable;
      }
     }
     $126 = ___cxa_find_matching_catch_2()|0;
     $127 = tempRet0;
     $128 = ((($61)) + 11|0);
     $129 = HEAP8[$128>>0]|0;
     $130 = ($129<<24>>24)<(0);
     if ($130) {
      $131 = HEAP32[$61>>2]|0;
      __ZdlPv($131);
      $$0$i14 = $127;$$01$i13 = $126;
     } else {
      $$0$i14 = $127;$$01$i13 = $126;
     }
    }
    $132 = ((($60)) + 11|0);
    $133 = HEAP8[$132>>0]|0;
    $134 = ($133<<24>>24)<(0);
    if (!($134)) {
     ___resumeException($$01$i13|0);
     // unreachable;
    }
    $135 = HEAP32[$60>>2]|0;
    __ZdlPv($135);
    ___resumeException($$01$i13|0);
    // unreachable;
   }
  }
  $91 = ___cxa_find_matching_catch_2()|0;
  $92 = tempRet0;
  $93 = ((($63)) + 11|0);
  $94 = HEAP8[$93>>0]|0;
  $95 = ($94<<24>>24)<(0);
  if ($95) {
   $96 = HEAP32[$63>>2]|0;
   __ZdlPv($96);
   $$0$i6 = $92;$$01$i5 = $91;
  } else {
   $$0$i6 = $92;$$01$i5 = $91;
  }
 }
 $97 = ((($62)) + 11|0);
 $98 = HEAP8[$97>>0]|0;
 $99 = ($98<<24>>24)<(0);
 if (!($99)) {
  ___resumeException($$01$i5|0);
  // unreachable;
 }
 $100 = HEAP32[$62>>2]|0;
 __ZdlPv($100);
 ___resumeException($$01$i5|0);
 // unreachable;
}
function __ZN3osg15DisplaySettings8instanceEv() {
 var $$0 = 0, $$01 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[206024]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  return (208212|0);
 }
 $2 = (___cxa_guard_acquire(206024)|0);
 $3 = ($2|0)==(0);
 if ($3) {
  return (208212|0);
 }
 __THREW__ = 0;
 $4 = (invoke_ii(3276,200)|0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $11 = ___cxa_find_matching_catch_2()|0;
  $12 = tempRet0;
  $$0 = $12;$$01 = $11;
  ___resumeException($$01|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_vi(3742,($4|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $13 = ___cxa_find_matching_catch_2()|0;
  $14 = tempRet0;
  __ZdlPv($4);
  $$0 = $14;$$01 = $13;
  ___resumeException($$01|0);
  // unreachable;
 } else {
  HEAP32[52053] = $4;
  $9 = ((($4)) + 8|0);
  $10 = HEAP32[$9>>2]|0;HEAP32[$9>>2] = (($10+1)|0);
  (___cxa_atexit((3743|0),(208212|0),(___dso_handle|0))|0);
  return (208212|0);
 }
 return (0)|0;
}
function __ZN3osg15DisplaySettingsC2Ev($0) {
 $0 = $0|0;
 var $$pre$i = 0, $$pre$i$i$i = 0, $$pre$i9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg10ReferencedC2Eb($0,1);
 HEAP32[$0>>2] = (58292);
 $1 = ((($0)) + 104|0);
 ;HEAP32[$1>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;
 $2 = ((($0)) + 132|0);
 ;HEAP32[$2>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;
 $3 = ((($0)) + 172|0);
 $4 = ((($0)) + 176|0);
 $5 = ((($0)) + 184|0);
 $6 = ((($0)) + 188|0);
 ;HEAP32[$3>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;HEAP32[$3+12>>2]=0|0;HEAP32[$3+16>>2]=0|0;HEAP32[$3+20>>2]=0|0;
 __THREW__ = 0;
 invoke_vi(3744,($0|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if (!($8)) {
  __THREW__ = 0;
  invoke_vi(3745,($0|0));
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   return;
  }
 }
 $11 = ___cxa_find_matching_catch_2()|0;
 $12 = tempRet0;
 $13 = HEAP32[$5>>2]|0;
 $14 = ($13|0)==(0|0);
 if (!($14)) {
  $15 = HEAP32[$6>>2]|0;
  $16 = ($15|0)==($13|0);
  do {
   if ($16) {
    $30 = $13;
   } else {
    $18 = $15;
    while(1) {
     $17 = ((($18)) + -4|0);
     HEAP32[$6>>2] = $17;
     $19 = HEAP32[$17>>2]|0;
     $20 = ($19|0)==(0|0);
     if (!($20)) {
      $21 = ((($19)) + 8|0);
      $22 = HEAP32[$21>>2]|0;HEAP32[$21>>2] = (($22-1)|0);
      $23 = ($22|0)==(1);
      if ($23) {
       __THREW__ = 0;
       invoke_viii(3262,($19|0),1,1);
       $24 = __THREW__; __THREW__ = 0;
       $25 = $24&1;
       if ($25) {
        label = 10;
        break;
       }
      }
     }
     HEAP32[$17>>2] = 0;
     $26 = HEAP32[$6>>2]|0;
     $27 = ($26|0)==($13|0);
     if ($27) {
      label = 11;
      break;
     } else {
      $18 = $26;
     }
    }
    if ((label|0) == 10) {
     $28 = ___cxa_find_matching_catch_2()|0;
     $29 = tempRet0;
     ___cxa_call_unexpected(($28|0));
     // unreachable;
    }
    else if ((label|0) == 11) {
     $$pre$i9 = HEAP32[$5>>2]|0;
     $30 = $$pre$i9;
     break;
    }
   }
  } while(0);
  __ZdlPv($30);
 }
 $31 = HEAP32[$3>>2]|0;
 $32 = ($31|0)==(0|0);
 if (!($32)) {
  $33 = HEAP32[$4>>2]|0;
  $34 = ($33|0)==($31|0);
  if ($34) {
   $43 = $31;
  } else {
   $36 = $33;
   while(1) {
    $35 = ((($36)) + -12|0);
    HEAP32[$4>>2] = $35;
    $37 = ((($35)) + 11|0);
    $38 = HEAP8[$37>>0]|0;
    $39 = ($38<<24>>24)<(0);
    if ($39) {
     $42 = HEAP32[$35>>2]|0;
     __ZdlPv($42);
     $$pre$i$i$i = HEAP32[$4>>2]|0;
     $40 = $$pre$i$i$i;
    } else {
     $40 = $35;
    }
    $41 = ($40|0)==($31|0);
    if ($41) {
     break;
    } else {
     $36 = $40;
    }
   }
   $$pre$i = HEAP32[$3>>2]|0;
   $43 = $$pre$i;
  }
  __ZdlPv($43);
 }
 $44 = ((($2)) + 11|0);
 $45 = HEAP8[$44>>0]|0;
 $46 = ($45<<24>>24)<(0);
 if ($46) {
  $47 = HEAP32[$2>>2]|0;
  __ZdlPv($47);
 }
 $48 = ((($1)) + 11|0);
 $49 = HEAP8[$48>>0]|0;
 $50 = ($49<<24>>24)<(0);
 if ($50) {
  $51 = HEAP32[$1>>2]|0;
  __ZdlPv($51);
 }
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $52 = __THREW__; __THREW__ = 0;
 $53 = $52&1;
 if ($53) {
  $54 = ___cxa_find_matching_catch_3(0|0)|0;
  $55 = tempRet0;
  ___clang_call_terminate($54);
  // unreachable;
 } else {
  ___resumeException($11|0);
  // unreachable;
 }
}
function __ZN3osg7ref_ptrINS_15DisplaySettingsEED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = ((($1)) + 8|0);
  $4 = HEAP32[$3>>2]|0;HEAP32[$3>>2] = (($4-1)|0);
  $5 = ($4|0)==(1);
  if ($5) {
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($1,1,1);
  }
 }
 HEAP32[$0>>2] = 0;
 return;
}
function __ZN3osg15DisplaySettings11setDefaultsEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $2 = ((($0)) + 12|0);
 HEAP32[$2>>2] = 0;
 $3 = ((($0)) + 16|0);
 HEAP8[$3>>0] = 0;
 $4 = ((($0)) + 20|0);
 HEAP32[$4>>2] = 1;
 $5 = ((($0)) + 24|0);
 HEAPF32[$5>>2] = 0.05000000074505806;
 $6 = ((($0)) + 28|0);
 HEAPF32[$6>>2] = 0.32499998807907104;
 $7 = ((($0)) + 32|0);
 HEAPF32[$7>>2] = 0.25999999046325684;
 $8 = ((($0)) + 36|0);
 HEAPF32[$8>>2] = 0.5;
 $9 = ((($0)) + 40|0);
 $10 = ((($0)) + 57|0);
 ;HEAP32[$9>>2]=0|0;HEAP32[$9+4>>2]=0|0;HEAP32[$9+8>>2]=0|0;HEAP32[$9+12>>2]=0|0;HEAP8[$9+16>>0]=0|0;
 HEAP8[$10>>0] = 1;
 $11 = ((($0)) + 58|0);
 HEAP8[$11>>0] = 1;
 $12 = ((($0)) + 59|0);
 HEAP8[$12>>0] = 1;
 $13 = ((($0)) + 60|0);
 $14 = ((($0)) + 84|0);
 ;HEAP32[$13>>2]=0|0;HEAP32[$13+4>>2]=0|0;HEAP32[$13+8>>2]=0|0;HEAP32[$13+12>>2]=0|0;HEAP32[$13+16>>2]=0|0;HEAP32[$13+20>>2]=0|0;
 HEAP32[$14>>2] = 32;
 $15 = ((($0)) + 88|0);
 HEAP32[$15>>2] = 0;
 $16 = ((($0)) + 92|0);
 HEAP8[$16>>0] = 0;
 $17 = ((($0)) + 93|0);
 HEAP8[$17>>0] = 0;
 $18 = ((($0)) + 94|0);
 HEAP8[$18>>0] = 1;
 $19 = ((($0)) + 96|0);
 HEAP32[$19>>2] = 2;
 $20 = ((($0)) + 100|0);
 HEAP32[$20>>2] = 1;
 $21 = ((($0)) + 116|0);
 HEAP32[$21>>2] = 0;
 $22 = ((($0)) + 120|0);
 HEAP32[$22>>2] = 0;
 $23 = ((($0)) + 124|0);
 HEAP32[$23>>2] = 5;
 $24 = ((($0)) + 128|0);
 HEAP32[$24>>2] = 5;
 $25 = ((($0)) + 132|0);
 (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($25,143373)|0);
 $26 = ((($0)) + 144|0);
 $27 = ((($0)) + 164|0);
 ;HEAP32[$26>>2]=0|0;HEAP32[$26+4>>2]=0|0;HEAP32[$26+8>>2]=0|0;HEAP32[$26+12>>2]=0|0;HEAP32[$26+16>>2]=0|0;
 HEAP32[$27>>2] = 2;
 $28 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
 if (!($28)) {
  $50 = ((($0)) + 168|0);
  HEAP8[$50>>0] = 0;
  $51 = ((($0)) + 196|0);
  HEAP32[$51>>2] = 0;
  STACKTOP = sp;return;
 }
 $29 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
 $30 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($29,126431,29)|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ((($31)) + -12|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = (($30) + ($33)|0);
 __ZNKSt3__28ios_base6getlocEv($1,$34);
 __THREW__ = 0;
 $35 = (invoke_iii(3255,($1|0),(215188|0))|0);
 $36 = __THREW__; __THREW__ = 0;
 $37 = $36&1;
 if (!($37)) {
  $38 = HEAP32[$35>>2]|0;
  $39 = ((($38)) + 28|0);
  $40 = HEAP32[$39>>2]|0;
  __THREW__ = 0;
  $41 = (invoke_iii($40|0,($35|0),10)|0);
  $42 = __THREW__; __THREW__ = 0;
  $43 = $42&1;
  if (!($43)) {
   __ZNSt3__26localeD2Ev($1);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($30,$41)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($30)|0);
   $50 = ((($0)) + 168|0);
   HEAP8[$50>>0] = 0;
   $51 = ((($0)) + 196|0);
   HEAP32[$51>>2] = 0;
   STACKTOP = sp;return;
  }
 }
 $44 = ___cxa_find_matching_catch_2()|0;
 $45 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($1|0));
 $46 = __THREW__; __THREW__ = 0;
 $47 = $46&1;
 if ($47) {
  $48 = ___cxa_find_matching_catch_3(0|0)|0;
  $49 = tempRet0;
  ___clang_call_terminate($48);
  // unreachable;
 } else {
  ___resumeException($44|0);
  // unreachable;
 }
}
function __ZN3osg15DisplaySettings26readEnvironmentalVariablesEv($0) {
 $0 = $0|0;
 var $$0 = 0, $$0106 = 0, $$0108 = 0, $$0109$lcssa = 0, $$0109253 = 0, $$0110254 = 0, $$016$i$i = 0, $$016$i$i201 = 0, $$017$i$i = 0, $$017$i$i202 = 0, $$02729$i$i$i = 0, $$02729$i$i$i114 = 0, $$02729$i$i$i125 = 0, $$02729$i$i$i136 = 0, $$02729$i$i$i147 = 0, $$02729$i$i$i158 = 0, $$02729$i$i$i169 = 0, $$02729$i$i$i180 = 0, $$02729$i$i$i191 = 0, $$1 = 0;
 var $$1107 = 0, $$pre = 0, $$pre$phi274Z2D = 0, $$pre270 = 0, $$pre271 = 0, $$pre273$pre$phiZZ2D = 0, $$pre276 = 0, $$sink$sink = 0, $$sink3$sink = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0;
 var $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0;
 var $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0;
 var $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0;
 var $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0;
 var $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0;
 var $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0;
 var $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0;
 var $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0;
 var $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0;
 var $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0;
 var $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0;
 var $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0;
 var $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0;
 var $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0;
 var $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0;
 var $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0;
 var $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0;
 var $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0;
 var $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0;
 var $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0;
 var $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0;
 var $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0;
 var $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0;
 var $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0;
 var $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0;
 var $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0;
 var $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0.0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $65 = 0.0, $66 = 0, $67 = 0, $68 = 0, $69 = 0.0, $7 = 0;
 var $70 = 0.0, $71 = 0, $72 = 0, $73 = 0, $74 = 0.0, $75 = 0.0, $76 = 0, $77 = 0, $78 = 0, $79 = 0.0, $8 = 0, $80 = 0.0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $or$cond236 = 0, $or$cond237 = 0, $or$cond238 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(80|0);
 $1 = sp + 64|0;
 $2 = sp + 60|0;
 $3 = sp + 56|0;
 $4 = sp + 48|0;
 $5 = sp + 36|0;
 $6 = sp + 24|0;
 $7 = sp + 12|0;
 $8 = sp + 69|0;
 $9 = sp;
 $10 = sp + 68|0;
 $11 = (_getenv((125057|0))|0);
 $12 = ($11|0)==(0|0);
 do {
  if (!($12)) {
   $13 = (_strcmp($11,125074)|0);
   $14 = ($13|0)==(0);
   if ($14) {
    $15 = ((($0)) + 12|0);
    HEAP32[$15>>2] = 0;
    break;
   }
   $16 = (_strcmp($11,125082)|0);
   $17 = ($16|0)==(0);
   if ($17) {
    $18 = ((($0)) + 12|0);
    HEAP32[$18>>2] = 1;
    break;
   }
   $19 = (_strcmp($11,125092)|0);
   $20 = ($19|0)==(0);
   if ($20) {
    $21 = ((($0)) + 12|0);
    HEAP32[$21>>2] = 2;
    break;
   }
   $22 = (_strcmp($11,125107)|0);
   $23 = ($22|0)==(0);
   if ($23) {
    $24 = ((($0)) + 12|0);
    HEAP32[$24>>2] = 3;
   }
  }
 } while(0);
 $25 = (_getenv((125128|0))|0);
 $26 = ($25|0)==(0|0);
 do {
  if (!($26)) {
   $27 = (_strcmp($25,125144)|0);
   $28 = ($27|0)==(0);
   if ($28) {
    $29 = ((($0)) + 20|0);
    HEAP32[$29>>2] = 0;
    break;
   }
   $30 = (_strcmp($25,125156)|0);
   $31 = ($30|0)==(0);
   if ($31) {
    $32 = ((($0)) + 20|0);
    HEAP32[$32>>2] = 1;
    break;
   }
   $33 = (_strcmp($25,125167)|0);
   $34 = ($33|0)==(0);
   if ($34) {
    $35 = ((($0)) + 20|0);
    HEAP32[$35>>2] = 2;
    break;
   }
   $36 = (_strcmp($25,125184)|0);
   $37 = ($36|0)==(0);
   if ($37) {
    $38 = ((($0)) + 20|0);
    HEAP32[$38>>2] = 3;
    break;
   }
   $39 = (_strcmp($25,125199)|0);
   $40 = ($39|0)==(0);
   if ($40) {
    $41 = ((($0)) + 20|0);
    HEAP32[$41>>2] = 4;
    break;
   }
   $42 = (_strcmp($25,125208)|0);
   $43 = ($42|0)==(0);
   if ($43) {
    $44 = ((($0)) + 20|0);
    HEAP32[$44>>2] = 5;
    break;
   }
   $45 = (_strcmp($25,125218)|0);
   $46 = ($45|0)==(0);
   if ($46) {
    $47 = ((($0)) + 20|0);
    HEAP32[$47>>2] = 6;
    break;
   }
   $48 = (_strcmp($25,125239)|0);
   $49 = ($48|0)==(0);
   if ($49) {
    $50 = ((($0)) + 20|0);
    HEAP32[$50>>2] = 7;
    break;
   }
   $51 = (_strcmp($25,125258)|0);
   $52 = ($51|0)==(0);
   if ($52) {
    $53 = ((($0)) + 20|0);
    HEAP32[$53>>2] = 8;
   }
  }
 } while(0);
 $54 = (_getenv((125271|0))|0);
 $55 = ($54|0)==(0|0);
 do {
  if (!($55)) {
   $56 = (_strcmp($54,167116)|0);
   $57 = ($56|0)==(0);
   if ($57) {
    $58 = ((($0)) + 16|0);
    HEAP8[$58>>0] = 0;
    break;
   }
   $59 = (_strcmp($54,165306)|0);
   $60 = ($59|0)==(0);
   if ($60) {
    $61 = ((($0)) + 16|0);
    HEAP8[$61>>0] = 1;
   }
  }
 } while(0);
 $62 = (_getenv((125282|0))|0);
 $63 = ($62|0)==(0|0);
 if (!($63)) {
  $64 = (+__ZN3osg13asciiToDoubleEPKc($62));
  $65 = $64;
  $66 = ((($0)) + 24|0);
  HEAPF32[$66>>2] = $65;
 }
 $67 = (_getenv((125301|0))|0);
 $68 = ($67|0)==(0|0);
 if (!($68)) {
  $69 = (+__ZN3osg13asciiToDoubleEPKc($67));
  $70 = $69;
  $71 = ((($0)) + 28|0);
  HEAPF32[$71>>2] = $70;
 }
 $72 = (_getenv((125318|0))|0);
 $73 = ($72|0)==(0|0);
 if (!($73)) {
  $74 = (+__ZN3osg13asciiToDoubleEPKc($72));
  $75 = $74;
  $76 = ((($0)) + 32|0);
  HEAPF32[$76>>2] = $75;
 }
 $77 = (_getenv((125336|0))|0);
 $78 = ($77|0)==(0|0);
 if (!($78)) {
  $79 = (+__ZN3osg13asciiToDoubleEPKc($77));
  $80 = $79;
  $81 = ((($0)) + 36|0);
  HEAPF32[$81>>2] = $80;
 }
 $82 = (_getenv((125356|0))|0);
 $83 = ($82|0)==(0|0);
 do {
  if (!($83)) {
   $84 = (_strcmp($82,125396)|0);
   $85 = ($84|0)==(0);
   if ($85) {
    $86 = ((($0)) + 40|0);
    HEAP32[$86>>2] = 0;
    break;
   }
   $87 = (_strcmp($82,125419)|0);
   $88 = ($87|0)==(0);
   if ($88) {
    $89 = ((($0)) + 40|0);
    HEAP32[$89>>2] = 1;
   }
  }
 } while(0);
 $90 = (_getenv((125443|0))|0);
 $91 = ($90|0)==(0|0);
 if (!($91)) {
  $92 = (_atoi($90)|0);
  $93 = ((($0)) + 44|0);
  HEAP32[$93>>2] = $92;
 }
 $94 = (_getenv((125482|0))|0);
 $95 = ($94|0)==(0|0);
 do {
  if (!($95)) {
   $96 = (_strcmp($94,125520)|0);
   $97 = ($96|0)==(0);
   if ($97) {
    $98 = ((($0)) + 48|0);
    HEAP32[$98>>2] = 0;
    break;
   }
   $99 = (_strcmp($94,125542)|0);
   $100 = ($99|0)==(0);
   if ($100) {
    $101 = ((($0)) + 48|0);
    HEAP32[$101>>2] = 1;
   }
  }
 } while(0);
 $102 = (_getenv((125567|0))|0);
 $103 = ($102|0)==(0|0);
 do {
  if (!($103)) {
   $104 = (_strcmp($102,167116)|0);
   $105 = ($104|0)==(0);
   if ($105) {
    $106 = ((($0)) + 56|0);
    HEAP8[$106>>0] = 0;
    break;
   }
   $107 = (_strcmp($102,165306)|0);
   $108 = ($107|0)==(0);
   if ($108) {
    $109 = ((($0)) + 56|0);
    HEAP8[$109>>0] = 1;
   }
  }
 } while(0);
 $110 = (_getenv((125609|0))|0);
 $111 = ($110|0)==(0|0);
 if (!($111)) {
  $112 = (_atoi($110)|0);
  $113 = ((($0)) + 52|0);
  HEAP32[$113>>2] = $112;
 }
 $114 = (_getenv((125646|0))|0);
 $115 = ($114|0)==(0|0);
 if (!($115)) {
  $116 = (_atoi($114)|0);
  $117 = ((($0)) + 84|0);
  HEAP32[$117>>2] = $116;
 }
 $118 = (_getenv((125682|0))|0);
 $119 = ($118|0)==(0|0);
 do {
  if (!($119)) {
   $120 = (_strcmp($118,167116)|0);
   $121 = ($120|0)==(0);
   if ($121) {
    $122 = ((($0)) + 92|0);
    HEAP8[$122>>0] = 0;
    break;
   }
   $123 = (_strcmp($118,165306)|0);
   $124 = ($123|0)==(0);
   if ($124) {
    $125 = ((($0)) + 92|0);
    HEAP8[$125>>0] = 1;
   }
  }
 } while(0);
 $126 = (_getenv((125703|0))|0);
 $127 = ($126|0)==(0|0);
 do {
  if (!($127)) {
   $128 = (_strcmp($126,167116)|0);
   $129 = ($128|0)==(0);
   if ($129) {
    $130 = ((($0)) + 93|0);
    HEAP8[$130>>0] = 0;
    break;
   }
   $131 = (_strcmp($126,165306)|0);
   $132 = ($131|0)==(0);
   if ($132) {
    $133 = ((($0)) + 93|0);
    HEAP8[$133>>0] = 1;
   }
  }
 } while(0);
 $134 = (_getenv((125731|0))|0);
 $135 = ($134|0)==(0|0);
 do {
  if (!($135)) {
   $136 = (_strcmp($134,167116)|0);
   $137 = ($136|0)==(0);
   if ($137) {
    $138 = ((($0)) + 94|0);
    HEAP8[$138>>0] = 0;
    break;
   }
   $139 = (_strcmp($134,165306)|0);
   $140 = ($139|0)==(0);
   if ($140) {
    $141 = ((($0)) + 94|0);
    HEAP8[$141>>0] = 1;
   }
  }
 } while(0);
 $142 = (_getenv((125760|0))|0);
 $143 = ($142|0)==(0|0);
 if (!($143)) {
  $144 = (_atoi($142)|0);
  $145 = ((($0)) + 96|0);
  HEAP32[$145>>2] = $144;
 }
 $146 = (_getenv((125785|0))|0);
 $147 = ($146|0)==(0|0);
 if (!($147)) {
  $148 = (_atoi($146)|0);
  $149 = ((($0)) + 100|0);
  HEAP32[$149>>2] = $148;
 }
 $150 = (_getenv((125815|0))|0);
 $151 = ($150|0)==(0|0);
 if (!($151)) {
  $152 = (_atoi($150)|0);
  $153 = ((($0)) + 88|0);
  HEAP32[$153>>2] = $152;
 }
 $154 = (_getenv((125833|0))|0);
 $155 = ($154|0)==(0|0);
 if (!($155)) {
  $156 = (_atoi($154)|0);
  $157 = ((($0)) + 116|0);
  HEAP32[$157>>2] = $156;
 }
 $158 = (_getenv((125855|0))|0);
 $159 = ($158|0)==(0|0);
 if (!($159)) {
  $160 = (_atoi($158)|0);
  $161 = ((($0)) + 120|0);
  HEAP32[$161>>2] = $160;
 }
 $162 = ((($0)) + 124|0);
 HEAP32[$4>>2] = $162;
 $163 = ((($4)) + 4|0);
 $164 = ((($0)) + 128|0);
 HEAP32[$163>>2] = $164;
 $165 = ((($5)) + 11|0);
 $166 = ((($5)) + 4|0);
 $167 = ((($5)) + 8|0);
 $$0110254 = 0;
 while(1) {
  $170 = (58320 + ($$0110254<<2)|0);
  $171 = HEAP32[$170>>2]|0;
  $172 = (_getenv(($171|0))|0);
  $173 = ($172|0)==(0|0);
  if (!($173)) {
   ;HEAP32[$5>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;
   $174 = (_strlen($172)|0);
   $175 = ($174>>>0)>(4294967279);
   if ($175) {
    label = 92;
    break;
   }
   $176 = ($174>>>0)<(11);
   if ($176) {
    $181 = $174&255;
    HEAP8[$165>>0] = $181;
    $182 = ($174|0)==(0);
    if ($182) {
     $$017$i$i = $5;
    } else {
     $$016$i$i = $5;
     label = 96;
    }
   } else {
    $177 = (($174) + 16)|0;
    $178 = $177 & -16;
    $179 = (__Znwj($178)|0);
    HEAP32[$5>>2] = $179;
    $180 = $178 | -2147483648;
    HEAP32[$167>>2] = $180;
    HEAP32[$166>>2] = $174;
    $$016$i$i = $179;
    label = 96;
   }
   if ((label|0) == 96) {
    label = 0;
    _memcpy(($$016$i$i|0),($172|0),($174|0))|0;
    $$017$i$i = $$016$i$i;
   }
   $183 = (($$017$i$i) + ($174)|0);
   HEAP8[$183>>0] = 0;
   $184 = HEAP8[$165>>0]|0;
   $185 = ($184<<24>>24)<(0);
   $186 = HEAP32[$5>>2]|0;
   $187 = $185 ? $186 : $5;
   $188 = HEAP32[$166>>2]|0;
   $189 = $184&255;
   $190 = $185 ? $188 : $189;
   $191 = (($187) + ($190)|0);
   $192 = $191;
   $193 = $187;
   $194 = ($190|0)<(3);
   L138: do {
    if ($194) {
     $212 = $186;$214 = $188;
    } else {
     $$02729$i$i$i = $187;$196 = $190;
     while(1) {
      $195 = (($196) + -2)|0;
      $197 = ($195|0)==(0);
      if ($197) {
       $212 = $186;$214 = $188;
       break L138;
      }
      $198 = (_memchr($$02729$i$i$i,79,$195)|0);
      $199 = ($198|0)==(0|0);
      if ($199) {
       $212 = $186;$214 = $188;
       break L138;
      }
      $200 = (_memcmp($198,167116,3)|0);
      $201 = ($200|0)==(0);
      if ($201) {
       break;
      }
      $202 = ((($198)) + 1|0);
      $203 = $202;
      $204 = (($192) - ($203))|0;
      $205 = ($204|0)<(3);
      if ($205) {
       $212 = $186;$214 = $188;
       break L138;
      } else {
       $$02729$i$i$i = $202;$196 = $204;
      }
     }
     $206 = ($198|0)==($191|0);
     if ($206) {
      $212 = $186;$214 = $188;
      break;
     }
     $207 = $198;
     $208 = (($207) - ($193))|0;
     $209 = ($208|0)==(-1);
     if ($209) {
      $212 = $186;$214 = $188;
      break;
     }
     $210 = (($4) + ($$0110254<<2)|0);
     $211 = HEAP32[$210>>2]|0;
     HEAP32[$211>>2] = 0;
     $$pre = HEAP32[$5>>2]|0;
     $$pre270 = HEAP32[$166>>2]|0;
     $212 = $$pre;$214 = $$pre270;
    }
   } while(0);
   $213 = $185 ? $212 : $5;
   $215 = $185 ? $214 : $189;
   $216 = (($213) + ($215)|0);
   $217 = $216;
   $218 = $213;
   $219 = ($215|0)<(8);
   L148: do {
    if ($219) {
     label = 112;
    } else {
     $$02729$i$i$i114 = $213;$221 = $215;
     while(1) {
      $220 = (($221) + -7)|0;
      $222 = ($220|0)==(0);
      if ($222) {
       label = 112;
       break L148;
      }
      $223 = (_memchr($$02729$i$i$i114,126,$220)|0);
      $224 = ($223|0)==(0|0);
      if ($224) {
       label = 112;
       break L148;
      }
      $225 = (_memcmp($223,125898,8)|0);
      $226 = ($225|0)==(0);
      if ($226) {
       break;
      }
      $227 = ((($223)) + 1|0);
      $228 = $227;
      $229 = (($217) - ($228))|0;
      $230 = ($229|0)<(8);
      if ($230) {
       label = 112;
       break L148;
      } else {
       $$02729$i$i$i114 = $227;$221 = $229;
      }
     }
     $231 = ($223|0)==($216|0);
     $232 = $223;
     $233 = (($232) - ($218))|0;
     $234 = ($233|0)==(-1);
     $or$cond = $231 | $234;
     if ($or$cond) {
      label = 112;
      break;
     }
     $235 = (($4) + ($$0110254<<2)|0);
     $236 = HEAP32[$235>>2]|0;
     $237 = HEAP32[$236>>2]|0;
     $238 = $237 ^ 5;
     HEAP32[$236>>2] = $238;
    }
   } while(0);
   L156: do {
    if ((label|0) == 112) {
     label = 0;
     $239 = ($215|0)<(7);
     if ($239) {
      break;
     } else {
      $$02729$i$i$i125 = $213;$241 = $215;
     }
     while(1) {
      $240 = (($241) + -6)|0;
      $242 = ($240|0)==(0);
      if ($242) {
       break L156;
      }
      $243 = (_memchr($$02729$i$i$i125,68,$240)|0);
      $244 = ($243|0)==(0|0);
      if ($244) {
       break L156;
      }
      $245 = (_memcmp($243,165469,7)|0);
      $246 = ($245|0)==(0);
      if ($246) {
       break;
      }
      $247 = ((($243)) + 1|0);
      $248 = $247;
      $249 = (($217) - ($248))|0;
      $250 = ($249|0)<(7);
      if ($250) {
       break L156;
      } else {
       $$02729$i$i$i125 = $247;$241 = $249;
      }
     }
     $251 = ($243|0)==($216|0);
     if ($251) {
      break;
     }
     $252 = $243;
     $253 = (($252) - ($218))|0;
     $254 = ($253|0)==(-1);
     if ($254) {
      break;
     }
     $255 = (($4) + ($$0110254<<2)|0);
     $256 = HEAP32[$255>>2]|0;
     $257 = HEAP32[$256>>2]|0;
     $258 = $257 | 5;
     HEAP32[$256>>2] = $258;
    }
   } while(0);
   $259 = HEAP32[$5>>2]|0;
   $260 = $185 ? $259 : $5;
   $261 = HEAP32[$166>>2]|0;
   $262 = $185 ? $261 : $189;
   $263 = (($260) + ($262)|0);
   $264 = $263;
   $265 = $260;
   $266 = ($262|0)<(6);
   L167: do {
    if ($266) {
     label = 127;
    } else {
     $$02729$i$i$i136 = $260;$268 = $262;
     while(1) {
      $267 = (($268) + -5)|0;
      $269 = ($267|0)==(0);
      if ($269) {
       label = 127;
       break L167;
      }
      $270 = (_memchr($$02729$i$i$i136,126,$267)|0);
      $271 = ($270|0)==(0|0);
      if ($271) {
       label = 127;
       break L167;
      }
      $272 = (_memcmp($270,125907,6)|0);
      $273 = ($272|0)==(0);
      if ($273) {
       break;
      }
      $274 = ((($270)) + 1|0);
      $275 = $274;
      $276 = (($264) - ($275))|0;
      $277 = ($276|0)<(6);
      if ($277) {
       label = 127;
       break L167;
      } else {
       $$02729$i$i$i136 = $274;$268 = $276;
      }
     }
     $278 = ($270|0)==($263|0);
     $279 = $270;
     $280 = (($279) - ($265))|0;
     $281 = ($280|0)==(-1);
     $or$cond236 = $278 | $281;
     if ($or$cond236) {
      label = 127;
      break;
     }
     $282 = (($4) + ($$0110254<<2)|0);
     $283 = HEAP32[$282>>2]|0;
     $284 = HEAP32[$283>>2]|0;
     $285 = $284 ^ 4;
     HEAP32[$283>>2] = $285;
    }
   } while(0);
   L175: do {
    if ((label|0) == 127) {
     label = 0;
     $286 = ($262|0)<(5);
     if ($286) {
      break;
     } else {
      $$02729$i$i$i147 = $260;$288 = $262;
     }
     while(1) {
      $287 = (($288) + -4)|0;
      $289 = ($287|0)==(0);
      if ($289) {
       break L175;
      }
      $290 = (_memchr($$02729$i$i$i147,67,$287)|0);
      $291 = ($290|0)==(0|0);
      if ($291) {
       break L175;
      }
      $292 = (_memcmp($290,125914,5)|0);
      $293 = ($292|0)==(0);
      if ($293) {
       break;
      }
      $294 = ((($290)) + 1|0);
      $295 = $294;
      $296 = (($264) - ($295))|0;
      $297 = ($296|0)<(5);
      if ($297) {
       break L175;
      } else {
       $$02729$i$i$i147 = $294;$288 = $296;
      }
     }
     $298 = ($290|0)==($263|0);
     if ($298) {
      break;
     }
     $299 = $290;
     $300 = (($299) - ($265))|0;
     $301 = ($300|0)==(-1);
     if ($301) {
      break;
     }
     $302 = (($4) + ($$0110254<<2)|0);
     $303 = HEAP32[$302>>2]|0;
     $304 = HEAP32[$303>>2]|0;
     $305 = $304 | 4;
     HEAP32[$303>>2] = $305;
    }
   } while(0);
   $306 = HEAP32[$5>>2]|0;
   $307 = $185 ? $306 : $5;
   $308 = HEAP32[$166>>2]|0;
   $309 = $185 ? $308 : $189;
   $310 = (($307) + ($309)|0);
   $311 = $310;
   $312 = $307;
   $313 = ($309|0)<(6);
   L186: do {
    if ($313) {
     label = 142;
    } else {
     $$02729$i$i$i158 = $307;$315 = $309;
     while(1) {
      $314 = (($315) + -5)|0;
      $316 = ($314|0)==(0);
      if ($316) {
       label = 142;
       break L186;
      }
      $317 = (_memchr($$02729$i$i$i158,126,$314)|0);
      $318 = ($317|0)==(0|0);
      if ($318) {
       label = 142;
       break L186;
      }
      $319 = (_memcmp($317,125920,6)|0);
      $320 = ($319|0)==(0);
      if ($320) {
       break;
      }
      $321 = ((($317)) + 1|0);
      $322 = $321;
      $323 = (($311) - ($322))|0;
      $324 = ($323|0)<(6);
      if ($324) {
       label = 142;
       break L186;
      } else {
       $$02729$i$i$i158 = $321;$315 = $323;
      }
     }
     $325 = ($317|0)==($310|0);
     $326 = $317;
     $327 = (($326) - ($312))|0;
     $328 = ($327|0)==(-1);
     $or$cond237 = $325 | $328;
     if ($or$cond237) {
      label = 142;
      break;
     }
     $329 = (($4) + ($$0110254<<2)|0);
     $330 = HEAP32[$329>>2]|0;
     $331 = HEAP32[$330>>2]|0;
     $332 = $331 ^ 1;
     HEAP32[$330>>2] = $332;
    }
   } while(0);
   L194: do {
    if ((label|0) == 142) {
     label = 0;
     $333 = ($309|0)<(5);
     if ($333) {
      break;
     } else {
      $$02729$i$i$i169 = $307;$335 = $309;
     }
     while(1) {
      $334 = (($335) + -4)|0;
      $336 = ($334|0)==(0);
      if ($336) {
       break L194;
      }
      $337 = (_memchr($$02729$i$i$i169,68,$334)|0);
      $338 = ($337|0)==(0|0);
      if ($338) {
       break L194;
      }
      $339 = (_memcmp($337,170760,5)|0);
      $340 = ($339|0)==(0);
      if ($340) {
       break;
      }
      $341 = ((($337)) + 1|0);
      $342 = $341;
      $343 = (($311) - ($342))|0;
      $344 = ($343|0)<(5);
      if ($344) {
       break L194;
      } else {
       $$02729$i$i$i169 = $341;$335 = $343;
      }
     }
     $345 = ($337|0)==($310|0);
     if ($345) {
      break;
     }
     $346 = $337;
     $347 = (($346) - ($312))|0;
     $348 = ($347|0)==(-1);
     if ($348) {
      break;
     }
     $349 = (($4) + ($$0110254<<2)|0);
     $350 = HEAP32[$349>>2]|0;
     $351 = HEAP32[$350>>2]|0;
     $352 = $351 | 1;
     HEAP32[$350>>2] = $352;
    }
   } while(0);
   $353 = HEAP32[$5>>2]|0;
   $354 = $185 ? $353 : $5;
   $355 = HEAP32[$166>>2]|0;
   $356 = $185 ? $355 : $189;
   $357 = (($354) + ($356)|0);
   $358 = $357;
   $359 = $354;
   $360 = ($356|0)<(8);
   L205: do {
    if ($360) {
     label = 157;
    } else {
     $$02729$i$i$i180 = $354;$362 = $356;
     while(1) {
      $361 = (($362) + -7)|0;
      $363 = ($361|0)==(0);
      if ($363) {
       label = 157;
       break L205;
      }
      $364 = (_memchr($$02729$i$i$i180,126,$361)|0);
      $365 = ($364|0)==(0|0);
      if ($365) {
       label = 157;
       break L205;
      }
      $366 = (_memcmp($364,125927,8)|0);
      $367 = ($366|0)==(0);
      if ($367) {
       break;
      }
      $368 = ((($364)) + 1|0);
      $369 = $368;
      $370 = (($358) - ($369))|0;
      $371 = ($370|0)<(8);
      if ($371) {
       label = 157;
       break L205;
      } else {
       $$02729$i$i$i180 = $368;$362 = $370;
      }
     }
     $372 = ($364|0)==($357|0);
     $373 = $364;
     $374 = (($373) - ($359))|0;
     $375 = ($374|0)==(-1);
     $or$cond238 = $372 | $375;
     if ($or$cond238) {
      label = 157;
      break;
     }
     $376 = (($4) + ($$0110254<<2)|0);
     $377 = HEAP32[$376>>2]|0;
     $378 = HEAP32[$377>>2]|0;
     $379 = $378 ^ 2;
     HEAP32[$377>>2] = $379;
    }
   } while(0);
   L213: do {
    if ((label|0) == 157) {
     label = 0;
     $380 = ($356|0)<(7);
     if ($380) {
      break;
     } else {
      $$02729$i$i$i191 = $354;$382 = $356;
     }
     while(1) {
      $381 = (($382) + -6)|0;
      $383 = ($381|0)==(0);
      if ($383) {
       break L213;
      }
      $384 = (_memchr($$02729$i$i$i191,83,$381)|0);
      $385 = ($384|0)==(0|0);
      if ($385) {
       break L213;
      }
      $386 = (_memcmp($384,125936,7)|0);
      $387 = ($386|0)==(0);
      if ($387) {
       break;
      }
      $388 = ((($384)) + 1|0);
      $389 = $388;
      $390 = (($358) - ($389))|0;
      $391 = ($390|0)<(7);
      if ($391) {
       break L213;
      } else {
       $$02729$i$i$i191 = $388;$382 = $390;
      }
     }
     $392 = ($384|0)==($357|0);
     if ($392) {
      break;
     }
     $393 = $384;
     $394 = (($393) - ($359))|0;
     $395 = ($394|0)==(-1);
     if ($395) {
      break;
     }
     $396 = (($4) + ($$0110254<<2)|0);
     $397 = HEAP32[$396>>2]|0;
     $398 = HEAP32[$397>>2]|0;
     $399 = $398 | 2;
     HEAP32[$397>>2] = $399;
    }
   } while(0);
   if ($185) {
    $400 = HEAP32[$5>>2]|0;
    __ZdlPv($400);
   }
  }
  $401 = (($$0110254) + 1)|0;
  $402 = ($401>>>0)<(2);
  if ($402) {
   $$0110254 = $401;
  } else {
   break;
  }
 }
 if ((label|0) == 92) {
  __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv($5);
  // unreachable;
 }
 $168 = (_getenv((125883|0))|0);
 $169 = ($168|0)==(0|0);
 if ($169) {
  $403 = (_getenv((125944|0))|0);
  $404 = ($403|0)==(0|0);
  if (!($404)) {
   $$0108 = $403;
   label = 170;
  }
 } else {
  $$0108 = $168;
  label = 170;
 }
 if ((label|0) == 170) {
  $405 = ((($0)) + 132|0);
  (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($405,$$0108)|0);
 }
 $406 = (_getenv((125967|0))|0);
 $407 = ($406|0)==(0|0);
 if (!($407)) {
  $408 = (_atoi($406)|0);
  $409 = ((($0)) + 144|0);
  HEAP32[$409>>2] = $408;
 }
 $410 = (_getenv((125988|0))|0);
 $411 = ($410|0)==(0|0);
 if (!($411)) {
  $412 = (_atoi($410)|0);
  $413 = ((($0)) + 148|0);
  HEAP32[$413>>2] = $412;
 }
 $414 = (_getenv((126016|0))|0);
 $415 = ($414|0)==(0|0);
 do {
  if (!($415)) {
   $416 = (_strcmp($414,165469)|0);
   $417 = ($416|0)==(0);
   if ($417) {
    $418 = ((($0)) + 152|0);
    HEAP32[$418>>2] = 0;
    break;
   }
   $419 = (_strcmp($414,126032)|0);
   $420 = ($419|0)==(0);
   if ($420) {
    $421 = ((($0)) + 152|0);
    HEAP32[$421>>2] = 1;
    break;
   }
   $422 = (_strcmp($414,126041)|0);
   $423 = ($422|0)==(0);
   if ($423) {
    $424 = ((($0)) + 152|0);
    HEAP32[$424>>2] = 2;
    break;
   }
   $425 = (_strcmp($414,156745)|0);
   $426 = ($425|0)==(0);
   if (!($426)) {
    break;
   }
   $427 = ((($0)) + 152|0);
   HEAP32[$427>>2] = 3;
  }
 } while(0);
 $428 = (_getenv((126046|0))|0);
 $429 = ($428|0)==(0|0);
 if (!($429)) {
  $430 = (_strcmp($428,167116)|0);
  $431 = ($430|0)==(0);
  do {
   if ($431) {
    $$sink$sink = 0;
   } else {
    $432 = (_strcmp($428,165306)|0);
    $433 = ($432|0)==(0);
    if ($433) {
     $$sink$sink = 1;
     break;
    }
    $434 = (_atoi($428)|0);
    $$sink$sink = $434;
   }
  } while(0);
  $435 = ((($0)) + 156|0);
  HEAP32[$435>>2] = $$sink$sink;
 }
 $436 = (_getenv((126068|0))|0);
 $437 = ($436|0)==(0|0);
 if (!($437)) {
  $438 = (_strcmp($436,126091)|0);
  $439 = ($438|0)==(0);
  L264: do {
   if ($439) {
    label = 192;
   } else {
    $440 = (_strcmp($436,165254)|0);
    $441 = ($440|0)==(0);
    if ($441) {
     label = 192;
     break;
    }
    $464 = (_strcmp($436,126163)|0);
    $465 = ($464|0)==(0);
    do {
     if (!($465)) {
      $466 = (_strcmp($436,126183)|0);
      $467 = ($466|0)==(0);
      if ($467) {
       break;
      }
      $490 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
      if (!($490)) {
       $$sink3$sink = 0;
       break L264;
      }
      $491 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
      $492 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($491,126237,43)|0);
      $493 = HEAP32[$492>>2]|0;
      $494 = ((($493)) + -12|0);
      $495 = HEAP32[$494>>2]|0;
      $496 = (($492) + ($495)|0);
      __ZNKSt3__28ios_base6getlocEv($1,$496);
      __THREW__ = 0;
      $497 = (invoke_iii(3255,($1|0),(215188|0))|0);
      $498 = __THREW__; __THREW__ = 0;
      $499 = $498&1;
      do {
       if (!($499)) {
        $500 = HEAP32[$497>>2]|0;
        $501 = ((($500)) + 28|0);
        $502 = HEAP32[$501>>2]|0;
        __THREW__ = 0;
        $503 = (invoke_iii($502|0,($497|0),10)|0);
        $504 = __THREW__; __THREW__ = 0;
        $505 = $504&1;
        if ($505) {
         break;
        }
        __ZNSt3__26localeD2Ev($1);
        (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($492,$503)|0);
        (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($492)|0);
        $$sink3$sink = 0;
        break L264;
       }
      } while(0);
      $506 = ___cxa_find_matching_catch_2()|0;
      $507 = tempRet0;
      __THREW__ = 0;
      invoke_vi(3263,($1|0));
      $508 = __THREW__; __THREW__ = 0;
      $509 = $508&1;
      if ($509) {
       $510 = ___cxa_find_matching_catch_3(0|0)|0;
       $511 = tempRet0;
       ___clang_call_terminate($510);
       // unreachable;
      } else {
       ___resumeException($506|0);
       // unreachable;
      }
     }
    } while(0);
    $468 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
    if (!($468)) {
     $$sink3$sink = 2;
     break;
    }
    $469 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
    $470 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($469,126187,49)|0);
    $471 = HEAP32[$470>>2]|0;
    $472 = ((($471)) + -12|0);
    $473 = HEAP32[$472>>2]|0;
    $474 = (($470) + ($473)|0);
    __ZNKSt3__28ios_base6getlocEv($2,$474);
    __THREW__ = 0;
    $475 = (invoke_iii(3255,($2|0),(215188|0))|0);
    $476 = __THREW__; __THREW__ = 0;
    $477 = $476&1;
    do {
     if (!($477)) {
      $478 = HEAP32[$475>>2]|0;
      $479 = ((($478)) + 28|0);
      $480 = HEAP32[$479>>2]|0;
      __THREW__ = 0;
      $481 = (invoke_iii($480|0,($475|0),10)|0);
      $482 = __THREW__; __THREW__ = 0;
      $483 = $482&1;
      if ($483) {
       break;
      }
      __ZNSt3__26localeD2Ev($2);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($470,$481)|0);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($470)|0);
      $$sink3$sink = 2;
      break L264;
     }
    } while(0);
    $484 = ___cxa_find_matching_catch_2()|0;
    $485 = tempRet0;
    __THREW__ = 0;
    invoke_vi(3263,($2|0));
    $486 = __THREW__; __THREW__ = 0;
    $487 = $486&1;
    if ($487) {
     $488 = ___cxa_find_matching_catch_3(0|0)|0;
     $489 = tempRet0;
     ___clang_call_terminate($488);
     // unreachable;
    } else {
     ___resumeException($484|0);
     // unreachable;
    }
   }
  } while(0);
  L287: do {
   if ((label|0) == 192) {
    $442 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
    if (!($442)) {
     $$sink3$sink = 1;
     break;
    }
    $443 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
    $444 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($443,126112,50)|0);
    $445 = HEAP32[$444>>2]|0;
    $446 = ((($445)) + -12|0);
    $447 = HEAP32[$446>>2]|0;
    $448 = (($444) + ($447)|0);
    __ZNKSt3__28ios_base6getlocEv($3,$448);
    __THREW__ = 0;
    $449 = (invoke_iii(3255,($3|0),(215188|0))|0);
    $450 = __THREW__; __THREW__ = 0;
    $451 = $450&1;
    do {
     if (!($451)) {
      $452 = HEAP32[$449>>2]|0;
      $453 = ((($452)) + 28|0);
      $454 = HEAP32[$453>>2]|0;
      __THREW__ = 0;
      $455 = (invoke_iii($454|0,($449|0),10)|0);
      $456 = __THREW__; __THREW__ = 0;
      $457 = $456&1;
      if ($457) {
       break;
      }
      __ZNSt3__26localeD2Ev($3);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($444,$455)|0);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($444)|0);
      $$sink3$sink = 1;
      break L287;
     }
    } while(0);
    $458 = ___cxa_find_matching_catch_2()|0;
    $459 = tempRet0;
    __THREW__ = 0;
    invoke_vi(3263,($3|0));
    $460 = __THREW__; __THREW__ = 0;
    $461 = $460&1;
    if ($461) {
     $462 = ___cxa_find_matching_catch_3(0|0)|0;
     $463 = tempRet0;
     ___clang_call_terminate($462);
     // unreachable;
    } else {
     ___resumeException($458|0);
     // unreachable;
    }
   }
  } while(0);
  $512 = ((($0)) + 160|0);
  HEAP32[$512>>2] = $$sink3$sink;
 }
 $513 = (_getenv((126281|0))|0);
 $514 = ($513|0)==(0|0);
 do {
  if (!($514)) {
   $515 = (_strcmp($513,126297)|0);
   $516 = ($515|0)==(0);
   if ($516) {
    $517 = ((($0)) + 164|0);
    HEAP32[$517>>2] = 1;
    break;
   }
   $518 = (_strcmp($513,126301)|0);
   $519 = ($518|0)==(0);
   if ($519) {
    $520 = ((($0)) + 164|0);
    HEAP32[$520>>2] = 3;
    break;
   }
   $521 = (_strcmp($513,126305)|0);
   $522 = ($521|0)==(0);
   if ($522) {
    $523 = ((($0)) + 164|0);
    HEAP32[$523>>2] = 2;
    break;
   }
   $524 = (_strcmp($513,126311)|0);
   $525 = ($524|0)==(0);
   if ($525) {
    $526 = ((($0)) + 164|0);
    HEAP32[$526>>2] = 4;
    break;
   }
   $527 = (_strcmp($513,126317)|0);
   $528 = ($527|0)==(0);
   if (!($528)) {
    break;
   }
   $529 = ((($0)) + 164|0);
   HEAP32[$529>>2] = 0;
  }
 } while(0);
 $530 = (_getenv((126322|0))|0);
 $531 = ($530|0)==(0|0);
 do {
  if (!($531)) {
   $532 = (_strcmp($530,167116)|0);
   $533 = ($532|0)==(0);
   if ($533) {
    $534 = ((($0)) + 168|0);
    HEAP8[$534>>0] = 0;
    break;
   }
   $535 = (_strcmp($530,165306)|0);
   $536 = ($535|0)==(0);
   if (!($536)) {
    break;
   }
   $537 = ((($0)) + 168|0);
   HEAP8[$537>>0] = 1;
  }
 } while(0);
 $538 = (_getenv((126335|0))|0);
 $539 = ($538|0)==(0|0);
 if (!($539)) {
  ;HEAP32[$6>>2]=0|0;HEAP32[$6+4>>2]=0|0;HEAP32[$6+8>>2]=0|0;
  $540 = (_strlen($538)|0);
  $541 = ($540>>>0)>(4294967279);
  if ($541) {
   __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv($6);
   // unreachable;
  }
  $542 = ($540>>>0)<(11);
  if ($542) {
   $549 = $540&255;
   $550 = ((($6)) + 11|0);
   HEAP8[$550>>0] = $549;
   $551 = ($540|0)==(0);
   if ($551) {
    $$017$i$i202 = $6;$$pre$phi274Z2D = $550;
   } else {
    $$016$i$i201 = $6;$$pre273$pre$phiZZ2D = $550;
    label = 238;
   }
  } else {
   $543 = (($540) + 16)|0;
   $544 = $543 & -16;
   $545 = (__Znwj($544)|0);
   HEAP32[$6>>2] = $545;
   $546 = $544 | -2147483648;
   $547 = ((($6)) + 8|0);
   HEAP32[$547>>2] = $546;
   $548 = ((($6)) + 4|0);
   HEAP32[$548>>2] = $540;
   $$pre276 = ((($6)) + 11|0);
   $$016$i$i201 = $545;$$pre273$pre$phiZZ2D = $$pre276;
   label = 238;
  }
  if ((label|0) == 238) {
   _memcpy(($$016$i$i201|0),($538|0),($540|0))|0;
   $$017$i$i202 = $$016$i$i201;$$pre$phi274Z2D = $$pre273$pre$phiZZ2D;
  }
  $552 = (($$017$i$i202) + ($540)|0);
  HEAP8[$552>>0] = 0;
  $553 = HEAP8[$$pre$phi274Z2D>>0]|0;
  $554 = ($553<<24>>24)<(0);
  $555 = ((($6)) + 4|0);
  $556 = HEAP32[$555>>2]|0;
  $557 = $553&255;
  $558 = $554 ? $556 : $557;
  $559 = ($558|0)==(0);
  L333: do {
   if ($559) {
    $627 = $553;
   } else {
    $560 = (__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE4findEcj($6,58,0)|0);
    $561 = ($560|0)==(-1);
    L335: do {
     if ($561) {
      $$0109$lcssa = 0;
      label = 254;
     } else {
      $562 = ((($0)) + 176|0);
      $563 = ((($0)) + 180|0);
      $564 = ((($0)) + 172|0);
      $565 = ((($7)) + 11|0);
      $$0109253 = 0;$567 = $560;
      while(1) {
       $566 = (($567) - ($$0109253))|0;
       __THREW__ = 0;
       invoke_viiiii(3746,($7|0),($6|0),($$0109253|0),($566|0),($8|0));
       $568 = __THREW__; __THREW__ = 0;
       $569 = $568&1;
       if ($569) {
        label = 250;
        break;
       }
       $570 = HEAP32[$562>>2]|0;
       $571 = HEAP32[$563>>2]|0;
       $572 = ($570|0)==($571|0);
       if ($572) {
        __THREW__ = 0;
        invoke_vii(3747,($564|0),($7|0));
        $577 = __THREW__; __THREW__ = 0;
        $578 = $577&1;
        if ($578) {
         label = 251;
         break;
        }
       } else {
        __THREW__ = 0;
        invoke_vii(3457,($570|0),($7|0));
        $573 = __THREW__; __THREW__ = 0;
        $574 = $573&1;
        if ($574) {
         label = 251;
         break;
        }
        $575 = HEAP32[$562>>2]|0;
        $576 = ((($575)) + 12|0);
        HEAP32[$562>>2] = $576;
       }
       $579 = HEAP8[$565>>0]|0;
       $580 = ($579<<24>>24)<(0);
       if ($580) {
        $581 = HEAP32[$7>>2]|0;
        __ZdlPv($581);
       }
       $582 = (($567) + 1)|0;
       $583 = (__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE4findEcj($6,58,$582)|0);
       $584 = ($583|0)==(-1);
       if ($584) {
        $$0109$lcssa = $582;
        label = 254;
        break L335;
       } else {
        $$0109253 = $582;$567 = $583;
       }
      }
      do {
       if ((label|0) == 250) {
        $585 = ___cxa_find_matching_catch_2()|0;
        $586 = tempRet0;
        $$0 = $586;$$0106 = $585;
       }
       else if ((label|0) == 251) {
        $587 = ___cxa_find_matching_catch_2()|0;
        $588 = tempRet0;
        $589 = HEAP8[$565>>0]|0;
        $590 = ($589<<24>>24)<(0);
        if (!($590)) {
         $$0 = $588;$$0106 = $587;
         break;
        }
        $591 = HEAP32[$7>>2]|0;
        __ZdlPv($591);
        $$0 = $588;$$0106 = $587;
       }
      } while(0);
      $$1 = $$0;$$1107 = $$0106;
     }
    } while(0);
    L353: do {
     if ((label|0) == 254) {
      __THREW__ = 0;
      invoke_viiiii(3746,($9|0),($6|0),($$0109$lcssa|0),-1,($10|0));
      $592 = __THREW__; __THREW__ = 0;
      $593 = $592&1;
      if ($593) {
       $614 = ___cxa_find_matching_catch_2()|0;
       $615 = tempRet0;
       $$1 = $615;$$1107 = $614;
       break;
      }
      $594 = ((($9)) + 11|0);
      $595 = HEAP8[$594>>0]|0;
      $596 = ($595<<24>>24)<(0);
      $597 = ((($9)) + 4|0);
      $598 = HEAP32[$597>>2]|0;
      $599 = $595&255;
      $600 = $596 ? $598 : $599;
      $601 = ($600|0)==(0);
      L358: do {
       if (!($601)) {
        $602 = ((($0)) + 176|0);
        $603 = HEAP32[$602>>2]|0;
        $604 = ((($0)) + 180|0);
        $605 = HEAP32[$604>>2]|0;
        $606 = ($603|0)==($605|0);
        do {
         if ($606) {
          $611 = ((($0)) + 172|0);
          __THREW__ = 0;
          invoke_vii(3747,($611|0),($9|0));
          $612 = __THREW__; __THREW__ = 0;
          $613 = $612&1;
          if (!($613)) {
           break L358;
          }
         } else {
          __THREW__ = 0;
          invoke_vii(3457,($603|0),($9|0));
          $607 = __THREW__; __THREW__ = 0;
          $608 = $607&1;
          if ($608) {
           break;
          }
          $609 = HEAP32[$602>>2]|0;
          $610 = ((($609)) + 12|0);
          HEAP32[$602>>2] = $610;
          break L358;
         }
        } while(0);
        $616 = ___cxa_find_matching_catch_2()|0;
        $617 = tempRet0;
        $618 = HEAP8[$594>>0]|0;
        $619 = ($618<<24>>24)<(0);
        if ($619) {
         $620 = HEAP32[$9>>2]|0;
         __ZdlPv($620);
        }
        $$1 = $617;$$1107 = $616;
        break L353;
       }
      } while(0);
      $621 = HEAP8[$594>>0]|0;
      $622 = ($621<<24>>24)<(0);
      if ($622) {
       $623 = HEAP32[$9>>2]|0;
       __ZdlPv($623);
      }
      $$pre271 = HEAP8[$$pre$phi274Z2D>>0]|0;
      $627 = $$pre271;
      break L333;
     }
    } while(0);
    $624 = HEAP8[$$pre$phi274Z2D>>0]|0;
    $625 = ($624<<24>>24)<(0);
    if (!($625)) {
     ___resumeException($$1107|0);
     // unreachable;
    }
    $626 = HEAP32[$6>>2]|0;
    __ZdlPv($626);
    ___resumeException($$1107|0);
    // unreachable;
   }
  } while(0);
  $628 = ($627<<24>>24)<(0);
  if ($628) {
   $629 = HEAP32[$6>>2]|0;
   __ZdlPv($629);
  }
 }
 $630 = (_getenv((126354|0))|0);
 $631 = ($630|0)==(0|0);
 do {
  if (!($631)) {
   $632 = (_strcmp($630,126375)|0);
   $633 = ($632|0)==(0);
   if ($633) {
    $634 = ((($0)) + 196|0);
    HEAP32[$634>>2] = 0;
    break;
   }
   $635 = (_strcmp($630,126385)|0);
   $636 = ($635|0)==(0);
   if ($636) {
    $637 = ((($0)) + 196|0);
    HEAP32[$637>>2] = 1;
    break;
   }
   $638 = (_strcmp($630,126396)|0);
   $639 = ($638|0)==(0);
   if (!($639)) {
    break;
   }
   $640 = ((($0)) + 196|0);
   HEAP32[$640>>2] = 2;
  }
 } while(0);
 $641 = (_getenv((126407|0))|0);
 $642 = ($641|0)==(0|0);
 if ($642) {
  STACKTOP = sp;return;
 }
 $643 = (_atoi($641)|0);
 HEAP32[14570] = $643;
 STACKTOP = sp;return;
}
function __ZNSt3__26vectorINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS4_IS6_EEE21__push_back_slow_pathIKS6_EEvRT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$06$i$i = 0, $$pre = 0, $$pre$i = 0, $$sroa$16$0 = 0, $$sroa$7$0 = 0, $$sroa$7$1 = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = (($5|0) / 12)&-1;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(357913941);
 if ($8) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $9 = ((($0)) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) - ($4))|0;
 $12 = (($11|0) / 12)&-1;
 $13 = ($12>>>0)<(178956970);
 $14 = $12 << 1;
 $15 = ($14>>>0)<($7>>>0);
 $$sroa$speculated$i = $15 ? $7 : $14;
 $$sroa$speculated$$i = $13 ? $$sroa$speculated$i : 357913941;
 $16 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($16) {
   $26 = 0;$74 = 0;
  } else {
   $17 = ($$sroa$speculated$$i>>>0)>(357913941);
   if (!($17)) {
    $23 = ($$sroa$speculated$$i*12)|0;
    $24 = (__Znwj($23)|0);
    $26 = $24;$74 = $24;
    break;
   }
   $18 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($18|0),(204840|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if ($20) {
    $21 = ___cxa_find_matching_catch_2()|0;
    $22 = tempRet0;
    ___cxa_free_exception(($18|0));
    ___resumeException($21|0);
    // unreachable;
   } else {
    HEAP32[$18>>2] = (99824);
    ___cxa_throw(($18|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $25 = (($26) + (($6*12)|0)|0);
 $27 = $25;
 $28 = (($26) + (($$sroa$speculated$$i*12)|0)|0);
 $29 = $28;
 __THREW__ = 0;
 invoke_vii(3457,($25|0),($1|0));
 $30 = __THREW__; __THREW__ = 0;
 $31 = $30&1;
 L13: do {
  if ($31) {
   $$sroa$16$0 = $27;$$sroa$7$1 = $27;
  } else {
   $32 = ((($25)) + 12|0);
   $33 = $32;
   $34 = HEAP32[$0>>2]|0;
   $35 = HEAP32[$2>>2]|0;
   $36 = ($35|0)==($34|0);
   if ($36) {
    $37 = $34;
    $47 = $27;$48 = $37;$50 = $34;
   } else {
    $$06$i$i = $35;$$sroa$7$0 = $27;$39 = $25;
    while(1) {
     $38 = ((($39)) + -12|0);
     $40 = ((($$06$i$i)) + -12|0);
     __THREW__ = 0;
     invoke_vii(3457,($38|0),($40|0));
     $41 = __THREW__; __THREW__ = 0;
     $42 = $41&1;
     if ($42) {
      $$sroa$16$0 = $33;$$sroa$7$1 = $$sroa$7$0;
      break L13;
     }
     $43 = $$sroa$7$0;
     $44 = ((($43)) + -12|0);
     $45 = $44;
     $46 = ($40|0)==($34|0);
     if ($46) {
      break;
     } else {
      $$06$i$i = $40;$$sroa$7$0 = $45;$39 = $44;
     }
    }
    $$pre$i = HEAP32[$0>>2]|0;
    $$pre = HEAP32[$2>>2]|0;
    $47 = $45;$48 = $$pre$i;$50 = $$pre;
   }
   HEAP32[$0>>2] = $47;
   HEAP32[$2>>2] = $33;
   HEAP32[$9>>2] = $29;
   $49 = $48;
   $51 = ($50|0)==($49|0);
   if (!($51)) {
    $53 = $50;
    while(1) {
     $52 = ((($53)) + -12|0);
     $54 = ((($52)) + 11|0);
     $55 = HEAP8[$54>>0]|0;
     $56 = ($55<<24>>24)<(0);
     if ($56) {
      $58 = HEAP32[$52>>2]|0;
      __ZdlPv($58);
     }
     $57 = ($52|0)==($49|0);
     if ($57) {
      break;
     } else {
      $53 = $52;
     }
    }
   }
   $59 = ($48|0)==(0);
   if ($59) {
    return;
   }
   $60 = $48;
   __ZdlPv($60);
   return;
  }
 } while(0);
 $61 = ___cxa_find_matching_catch_2()|0;
 $62 = tempRet0;
 $63 = $$sroa$7$1;
 $64 = $$sroa$16$0;
 $65 = ($64|0)==($63|0);
 if (!($65)) {
  $67 = $64;
  while(1) {
   $66 = ((($67)) + -12|0);
   $68 = ((($66)) + 11|0);
   $69 = HEAP8[$68>>0]|0;
   $70 = ($69<<24>>24)<(0);
   if ($70) {
    $72 = HEAP32[$66>>2]|0;
    __ZdlPv($72);
   }
   $71 = ($66|0)==($63|0);
   if ($71) {
    break;
   } else {
    $67 = $66;
   }
  }
 }
 $73 = ($26|0)==(0|0);
 if ($73) {
  ___resumeException($61|0);
  // unreachable;
 }
 __ZdlPv($74);
 ___resumeException($61|0);
 // unreachable;
}
function __ZN3osg15DisplaySettingsC2ERKS0_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$pre$i = 0, $$pre$i$i$i = 0, $$pre$i10 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg10ReferencedC2Eb($0,1);
 HEAP32[$0>>2] = (58292);
 $2 = ((($0)) + 104|0);
 ;HEAP32[$2>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;
 $3 = ((($0)) + 132|0);
 ;HEAP32[$3>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;
 $4 = ((($0)) + 172|0);
 $5 = ((($0)) + 176|0);
 $6 = ((($0)) + 184|0);
 $7 = ((($0)) + 188|0);
 ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;HEAP32[$4+12>>2]=0|0;HEAP32[$4+16>>2]=0|0;HEAP32[$4+20>>2]=0|0;
 __THREW__ = 0;
 invoke_vii(3748,($0|0),($1|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if (!($9)) {
  return;
 }
 $10 = ___cxa_find_matching_catch_2()|0;
 $11 = tempRet0;
 $12 = HEAP32[$6>>2]|0;
 $13 = ($12|0)==(0|0);
 if (!($13)) {
  $14 = HEAP32[$7>>2]|0;
  $15 = ($14|0)==($12|0);
  do {
   if ($15) {
    $29 = $12;
   } else {
    $17 = $14;
    while(1) {
     $16 = ((($17)) + -4|0);
     HEAP32[$7>>2] = $16;
     $18 = HEAP32[$16>>2]|0;
     $19 = ($18|0)==(0|0);
     if (!($19)) {
      $20 = ((($18)) + 8|0);
      $21 = HEAP32[$20>>2]|0;HEAP32[$20>>2] = (($21-1)|0);
      $22 = ($21|0)==(1);
      if ($22) {
       __THREW__ = 0;
       invoke_viii(3262,($18|0),1,1);
       $23 = __THREW__; __THREW__ = 0;
       $24 = $23&1;
       if ($24) {
        label = 9;
        break;
       }
      }
     }
     HEAP32[$16>>2] = 0;
     $25 = HEAP32[$7>>2]|0;
     $26 = ($25|0)==($12|0);
     if ($26) {
      label = 10;
      break;
     } else {
      $17 = $25;
     }
    }
    if ((label|0) == 9) {
     $27 = ___cxa_find_matching_catch_2()|0;
     $28 = tempRet0;
     ___cxa_call_unexpected(($27|0));
     // unreachable;
    }
    else if ((label|0) == 10) {
     $$pre$i10 = HEAP32[$6>>2]|0;
     $29 = $$pre$i10;
     break;
    }
   }
  } while(0);
  __ZdlPv($29);
 }
 $30 = HEAP32[$4>>2]|0;
 $31 = ($30|0)==(0|0);
 if (!($31)) {
  $32 = HEAP32[$5>>2]|0;
  $33 = ($32|0)==($30|0);
  if ($33) {
   $42 = $30;
  } else {
   $35 = $32;
   while(1) {
    $34 = ((($35)) + -12|0);
    HEAP32[$5>>2] = $34;
    $36 = ((($34)) + 11|0);
    $37 = HEAP8[$36>>0]|0;
    $38 = ($37<<24>>24)<(0);
    if ($38) {
     $41 = HEAP32[$34>>2]|0;
     __ZdlPv($41);
     $$pre$i$i$i = HEAP32[$5>>2]|0;
     $39 = $$pre$i$i$i;
    } else {
     $39 = $34;
    }
    $40 = ($39|0)==($30|0);
    if ($40) {
     break;
    } else {
     $35 = $39;
    }
   }
   $$pre$i = HEAP32[$4>>2]|0;
   $42 = $$pre$i;
  }
  __ZdlPv($42);
 }
 $43 = ((($3)) + 11|0);
 $44 = HEAP8[$43>>0]|0;
 $45 = ($44<<24>>24)<(0);
 if ($45) {
  $46 = HEAP32[$3>>2]|0;
  __ZdlPv($46);
 }
 $47 = ((($2)) + 11|0);
 $48 = HEAP8[$47>>0]|0;
 $49 = ($48<<24>>24)<(0);
 if ($49) {
  $50 = HEAP32[$2>>2]|0;
  __ZdlPv($50);
 }
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $51 = __THREW__; __THREW__ = 0;
 $52 = $51&1;
 if ($52) {
  $53 = ___cxa_find_matching_catch_3(0|0)|0;
  $54 = tempRet0;
  ___clang_call_terminate($53);
  // unreachable;
 } else {
  ___resumeException($10|0);
  // unreachable;
 }
}
function __ZN3osg15DisplaySettings18setDisplaySettingsERKS0_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0;
 var $136 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 12|0);
 HEAP32[$4>>2] = $3;
 $5 = ((($1)) + 16|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = ((($0)) + 16|0);
 HEAP8[$7>>0] = $6;
 $8 = ((($1)) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($0)) + 20|0);
 HEAP32[$10>>2] = $9;
 $11 = ((($1)) + 24|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ((($0)) + 24|0);
 HEAP32[$13>>2] = $12;
 $14 = ((($1)) + 28|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ((($0)) + 28|0);
 HEAP32[$16>>2] = $15;
 $17 = ((($1)) + 32|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ((($0)) + 32|0);
 HEAP32[$19>>2] = $18;
 $20 = ((($1)) + 36|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ((($0)) + 36|0);
 HEAP32[$22>>2] = $21;
 $23 = ((($1)) + 40|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ((($0)) + 40|0);
 HEAP32[$25>>2] = $24;
 $26 = ((($1)) + 44|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ((($0)) + 44|0);
 HEAP32[$28>>2] = $27;
 $29 = ((($1)) + 48|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ((($0)) + 48|0);
 HEAP32[$31>>2] = $30;
 $32 = ((($1)) + 52|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ((($0)) + 52|0);
 HEAP32[$34>>2] = $33;
 $35 = ((($1)) + 56|0);
 $36 = HEAP8[$35>>0]|0;
 $37 = ((($0)) + 56|0);
 HEAP8[$37>>0] = $36;
 $38 = ((($1)) + 57|0);
 $39 = HEAP8[$38>>0]|0;
 $40 = ((($0)) + 57|0);
 HEAP8[$40>>0] = $39;
 $41 = ((($1)) + 58|0);
 $42 = HEAP8[$41>>0]|0;
 $43 = ((($0)) + 58|0);
 HEAP8[$43>>0] = $42;
 $44 = ((($1)) + 59|0);
 $45 = HEAP8[$44>>0]|0;
 $46 = ((($0)) + 59|0);
 HEAP8[$46>>0] = $45;
 $47 = ((($1)) + 60|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = ((($0)) + 60|0);
 HEAP32[$49>>2] = $48;
 $50 = ((($1)) + 64|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = ((($0)) + 64|0);
 HEAP32[$52>>2] = $51;
 $53 = ((($1)) + 68|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = ((($0)) + 68|0);
 HEAP32[$55>>2] = $54;
 $56 = ((($1)) + 72|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = ((($0)) + 72|0);
 HEAP32[$58>>2] = $57;
 $59 = ((($1)) + 76|0);
 $60 = HEAP32[$59>>2]|0;
 $61 = ((($0)) + 76|0);
 HEAP32[$61>>2] = $60;
 $62 = ((($1)) + 80|0);
 $63 = HEAP32[$62>>2]|0;
 $64 = ((($0)) + 80|0);
 HEAP32[$64>>2] = $63;
 $65 = ((($1)) + 84|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = ((($0)) + 84|0);
 HEAP32[$67>>2] = $66;
 $68 = ((($1)) + 88|0);
 $69 = HEAP32[$68>>2]|0;
 $70 = ((($0)) + 88|0);
 HEAP32[$70>>2] = $69;
 $71 = ((($1)) + 92|0);
 $72 = HEAP8[$71>>0]|0;
 $73 = ((($0)) + 92|0);
 HEAP8[$73>>0] = $72;
 $74 = ((($1)) + 93|0);
 $75 = HEAP8[$74>>0]|0;
 $76 = ((($0)) + 93|0);
 HEAP8[$76>>0] = $75;
 $77 = ((($1)) + 94|0);
 $78 = HEAP8[$77>>0]|0;
 $79 = ((($0)) + 94|0);
 HEAP8[$79>>0] = $78;
 $80 = ((($1)) + 96|0);
 $81 = HEAP32[$80>>2]|0;
 $82 = ((($0)) + 96|0);
 HEAP32[$82>>2] = $81;
 $83 = ((($1)) + 100|0);
 $84 = HEAP32[$83>>2]|0;
 $85 = ((($0)) + 100|0);
 HEAP32[$85>>2] = $84;
 $86 = ((($1)) + 104|0);
 $87 = ((($0)) + 104|0);
 (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEaSERKS5_($87,$86)|0);
 $88 = ((($1)) + 116|0);
 $89 = HEAP32[$88>>2]|0;
 $90 = ((($0)) + 116|0);
 HEAP32[$90>>2] = $89;
 $91 = ((($1)) + 120|0);
 $92 = HEAP32[$91>>2]|0;
 $93 = ((($0)) + 120|0);
 HEAP32[$93>>2] = $92;
 $94 = ((($1)) + 124|0);
 $95 = HEAP32[$94>>2]|0;
 $96 = ((($0)) + 124|0);
 HEAP32[$96>>2] = $95;
 $97 = ((($1)) + 128|0);
 $98 = HEAP32[$97>>2]|0;
 $99 = ((($0)) + 128|0);
 HEAP32[$99>>2] = $98;
 $100 = ((($1)) + 132|0);
 $101 = ((($0)) + 132|0);
 (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEaSERKS5_($101,$100)|0);
 $102 = ((($1)) + 144|0);
 $103 = HEAP32[$102>>2]|0;
 $104 = ((($0)) + 144|0);
 HEAP32[$104>>2] = $103;
 $105 = ((($1)) + 148|0);
 $106 = HEAP32[$105>>2]|0;
 $107 = ((($0)) + 148|0);
 HEAP32[$107>>2] = $106;
 $108 = ((($1)) + 152|0);
 $109 = HEAP32[$108>>2]|0;
 $110 = ((($0)) + 152|0);
 HEAP32[$110>>2] = $109;
 $111 = ((($1)) + 160|0);
 $112 = HEAP32[$111>>2]|0;
 $113 = ((($0)) + 160|0);
 HEAP32[$113>>2] = $112;
 $114 = ((($1)) + 164|0);
 $115 = HEAP32[$114>>2]|0;
 $116 = ((($0)) + 164|0);
 HEAP32[$116>>2] = $115;
 $117 = ((($1)) + 168|0);
 $118 = HEAP8[$117>>0]|0;
 $119 = ((($0)) + 168|0);
 HEAP8[$119>>0] = $118;
 $120 = ($0|0)==($1|0);
 if ($120) {
  $131 = ((($1)) + 196|0);
  $132 = HEAP32[$131>>2]|0;
  $133 = ((($0)) + 196|0);
  HEAP32[$133>>2] = $132;
  $134 = ((($1)) + 156|0);
  $135 = HEAP32[$134>>2]|0;
  $136 = ((($0)) + 156|0);
  HEAP32[$136>>2] = $135;
  return;
 }
 $121 = ((($0)) + 172|0);
 $122 = ((($1)) + 172|0);
 $123 = HEAP32[$122>>2]|0;
 $124 = ((($1)) + 176|0);
 $125 = HEAP32[$124>>2]|0;
 __ZNSt3__26vectorINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS4_IS6_EEE6assignIPS6_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS6_NS_15iterator_traitsISC_E9referenceEEE5valueEvE4typeESC_SC_($121,$123,$125);
 $126 = ((($0)) + 184|0);
 $127 = ((($1)) + 184|0);
 $128 = HEAP32[$127>>2]|0;
 $129 = ((($1)) + 188|0);
 $130 = HEAP32[$129>>2]|0;
 __ZNSt3__26vectorIN3osg7ref_ptrINS1_6ObjectEEENS_9allocatorIS4_EEE6assignIPS4_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS4_NS_15iterator_traitsISB_E9referenceEEE5valueEvE4typeESB_SB_($126,$128,$130);
 $131 = ((($1)) + 196|0);
 $132 = HEAP32[$131>>2]|0;
 $133 = ((($0)) + 196|0);
 HEAP32[$133>>2] = $132;
 $134 = ((($1)) + 156|0);
 $135 = HEAP32[$134>>2]|0;
 $136 = ((($0)) + 156|0);
 HEAP32[$136>>2] = $135;
 return;
}
function __ZNSt3__26vectorINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS4_IS6_EEE6assignIPS6_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS6_NS_15iterator_traitsISC_E9referenceEEE5valueEvE4typeESC_SC_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$ = 0, $$0$lcssa$i$i = 0, $$07$i$i = 0, $$07$i$i21 = 0, $$078$i$i = 0, $$09$i$i = 0, $$pre$i = 0, $$pre$i$i$i$i = 0, $$pre$i$i19 = 0, $$pre$i$i25 = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $3 = $2;
 $4 = $1;
 $5 = (($3) - ($4))|0;
 $6 = (($5|0) / 12)&-1;
 $7 = ((($0)) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$0>>2]|0;
 $10 = (($8) - ($9))|0;
 $11 = (($10|0) / 12)&-1;
 $12 = ($6>>>0)>($11>>>0);
 $13 = $9;
 if (!($12)) {
  $14 = ((($0)) + 4|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (($15) - ($9))|0;
  $17 = (($16|0) / 12)&-1;
  $18 = ($6>>>0)>($17>>>0);
  $19 = (($1) + (($17*12)|0)|0);
  $$ = $18 ? $19 : $2;
  $20 = ($$|0)==($1|0);
  if ($20) {
   $$0$lcssa$i$i = $13;
  } else {
   $$078$i$i = $1;$$09$i$i = $13;
   while(1) {
    (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEaSERKS5_($$09$i$i,$$078$i$i)|0);
    $21 = ((($$078$i$i)) + 12|0);
    $22 = ((($$09$i$i)) + 12|0);
    $23 = ($21|0)==($$|0);
    if ($23) {
     $$0$lcssa$i$i = $22;
     break;
    } else {
     $$078$i$i = $21;$$09$i$i = $22;
    }
   }
  }
  if ($18) {
   $24 = ($$|0)==($2|0);
   if ($24) {
    return;
   }
   $$pre$i$i19 = HEAP32[$14>>2]|0;
   $$07$i$i21 = $19;$25 = $$pre$i$i19;
   while(1) {
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_($25,$$07$i$i21);
    $26 = ((($$07$i$i21)) + 12|0);
    $27 = HEAP32[$14>>2]|0;
    $28 = ((($27)) + 12|0);
    HEAP32[$14>>2] = $28;
    $29 = ($26|0)==($2|0);
    if ($29) {
     break;
    } else {
     $$07$i$i21 = $26;$25 = $28;
    }
   }
   return;
  }
  $30 = HEAP32[$14>>2]|0;
  $31 = ($30|0)==($$0$lcssa$i$i|0);
  if ($31) {
   return;
  } else {
   $33 = $30;
  }
  while(1) {
   $32 = ((($33)) + -12|0);
   HEAP32[$14>>2] = $32;
   $34 = ((($32)) + 11|0);
   $35 = HEAP8[$34>>0]|0;
   $36 = ($35<<24>>24)<(0);
   if ($36) {
    $39 = HEAP32[$32>>2]|0;
    __ZdlPv($39);
    $$pre$i$i25 = HEAP32[$14>>2]|0;
    $37 = $$pre$i$i25;
   } else {
    $37 = $32;
   }
   $38 = ($37|0)==($$0$lcssa$i$i|0);
   if ($38) {
    break;
   } else {
    $33 = $37;
   }
  }
  return;
 }
 $40 = ($9|0)==(0);
 if ($40) {
  $56 = $8;
 } else {
  $41 = $9;
  $42 = ((($0)) + 4|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = ($43|0)==($13|0);
  if ($44) {
   $53 = $41;
  } else {
   $46 = $43;
   while(1) {
    $45 = ((($46)) + -12|0);
    HEAP32[$42>>2] = $45;
    $47 = ((($45)) + 11|0);
    $48 = HEAP8[$47>>0]|0;
    $49 = ($48<<24>>24)<(0);
    if ($49) {
     $52 = HEAP32[$45>>2]|0;
     __ZdlPv($52);
     $$pre$i$i$i$i = HEAP32[$42>>2]|0;
     $50 = $$pre$i$i$i$i;
    } else {
     $50 = $45;
    }
    $51 = ($50|0)==($13|0);
    if ($51) {
     break;
    } else {
     $46 = $50;
    }
   }
   $$pre$i = HEAP32[$0>>2]|0;
   $53 = $$pre$i;
  }
  __ZdlPv($53);
  HEAP32[$7>>2] = 0;
  HEAP32[$42>>2] = 0;
  HEAP32[$0>>2] = 0;
  $56 = 0;
 }
 $54 = ($6>>>0)>(357913941);
 if ($54) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $55 = (($56|0) / 12)&-1;
 $57 = ($55>>>0)<(178956970);
 $58 = $55 << 1;
 $59 = ($58>>>0)<($6>>>0);
 $$sroa$speculated$i = $59 ? $6 : $58;
 $$sroa$speculated$$i = $57 ? $$sroa$speculated$i : 357913941;
 $60 = ($$sroa$speculated$$i>>>0)>(357913941);
 if ($60) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $61 = ($$sroa$speculated$$i*12)|0;
 $62 = (__Znwj($61)|0);
 $63 = ((($0)) + 4|0);
 HEAP32[$63>>2] = $62;
 HEAP32[$0>>2] = $62;
 $64 = (($62) + (($$sroa$speculated$$i*12)|0)|0);
 HEAP32[$7>>2] = $64;
 $65 = ($1|0)==($2|0);
 if ($65) {
  return;
 }
 $$07$i$i = $1;$66 = $62;
 while(1) {
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_($66,$$07$i$i);
  $67 = ((($$07$i$i)) + 12|0);
  $68 = HEAP32[$63>>2]|0;
  $69 = ((($68)) + 12|0);
  HEAP32[$63>>2] = $69;
  $70 = ($67|0)==($2|0);
  if ($70) {
   break;
  } else {
   $$07$i$i = $67;$66 = $69;
  }
 }
 return;
}
function __ZNSt3__26vectorIN3osg7ref_ptrINS1_6ObjectEEENS_9allocatorIS4_EEE6assignIPS4_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS4_NS_15iterator_traitsISB_E9referenceEEE5valueEvE4typeESB_SB_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$ = 0, $$0$lcssa$i$i = 0, $$07$i$i = 0, $$07$i$i21 = 0, $$078$i$i = 0, $$09$i$i = 0, $$pre$i = 0, $$pre$i$i19 = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = $2;
 $4 = $1;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 $7 = ((($0)) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$0>>2]|0;
 $10 = (($8) - ($9))|0;
 $11 = $10 >> 2;
 $12 = ($6>>>0)>($11>>>0);
 $13 = $9;
 if ($12) {
  $59 = ($9|0)==(0);
  if ($59) {
   $80 = $8;
  } else {
   $60 = $9;
   $61 = ((($0)) + 4|0);
   $62 = HEAP32[$61>>2]|0;
   $63 = ($62|0)==($13|0);
   do {
    if ($63) {
     $77 = $60;
    } else {
     $65 = $62;
     while(1) {
      $64 = ((($65)) + -4|0);
      HEAP32[$61>>2] = $64;
      $66 = HEAP32[$64>>2]|0;
      $67 = ($66|0)==(0|0);
      if (!($67)) {
       $68 = ((($66)) + 8|0);
       $69 = HEAP32[$68>>2]|0;HEAP32[$68>>2] = (($69-1)|0);
       $70 = ($69|0)==(1);
       if ($70) {
        __THREW__ = 0;
        invoke_viii(3262,($66|0),1,1);
        $71 = __THREW__; __THREW__ = 0;
        $72 = $71&1;
        if ($72) {
         label = 28;
         break;
        }
       }
      }
      HEAP32[$64>>2] = 0;
      $73 = HEAP32[$61>>2]|0;
      $74 = ($73|0)==($13|0);
      if ($74) {
       label = 29;
       break;
      } else {
       $65 = $73;
      }
     }
     if ((label|0) == 28) {
      $75 = ___cxa_find_matching_catch_2()|0;
      $76 = tempRet0;
      ___cxa_call_unexpected(($75|0));
      // unreachable;
     }
     else if ((label|0) == 29) {
      $$pre$i = HEAP32[$0>>2]|0;
      $77 = $$pre$i;
      break;
     }
    }
   } while(0);
   __ZdlPv($77);
   HEAP32[$7>>2] = 0;
   HEAP32[$61>>2] = 0;
   HEAP32[$0>>2] = 0;
   $80 = 0;
  }
  $78 = ($6>>>0)>(1073741823);
  if ($78) {
   __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
   // unreachable;
  }
  $79 = $80 >> 2;
  $81 = ($79>>>0)<(536870911);
  $82 = $80 >> 1;
  $83 = ($82>>>0)<($6>>>0);
  $$sroa$speculated$i = $83 ? $6 : $82;
  $$sroa$speculated$$i = $81 ? $$sroa$speculated$i : 1073741823;
  $84 = ($$sroa$speculated$$i>>>0)>(1073741823);
  if ($84) {
   __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
   // unreachable;
  }
  $85 = $$sroa$speculated$$i << 2;
  $86 = (__Znwj($85)|0);
  $87 = ((($0)) + 4|0);
  HEAP32[$87>>2] = $86;
  HEAP32[$0>>2] = $86;
  $88 = (($86) + ($$sroa$speculated$$i<<2)|0);
  HEAP32[$7>>2] = $88;
  $89 = ($1|0)==($2|0);
  if ($89) {
   return;
  }
  $$07$i$i = $1;$91 = $86;
  while(1) {
   $90 = HEAP32[$$07$i$i>>2]|0;
   HEAP32[$91>>2] = $90;
   $92 = ($90|0)==(0|0);
   if (!($92)) {
    $93 = ((($90)) + 8|0);
    $94 = HEAP32[$93>>2]|0;HEAP32[$93>>2] = (($94+1)|0);
   }
   $95 = ((($$07$i$i)) + 4|0);
   $96 = HEAP32[$87>>2]|0;
   $97 = ((($96)) + 4|0);
   HEAP32[$87>>2] = $97;
   $98 = ($95|0)==($2|0);
   if ($98) {
    break;
   } else {
    $$07$i$i = $95;$91 = $97;
   }
  }
  return;
 }
 $14 = ((($0)) + 4|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($15) - ($9))|0;
 $17 = $16 >> 2;
 $18 = ($6>>>0)>($17>>>0);
 $19 = (($1) + ($17<<2)|0);
 $$ = $18 ? $19 : $2;
 $20 = ($$|0)==($1|0);
 if ($20) {
  $$0$lcssa$i$i = $13;
 } else {
  $$078$i$i = $1;$$09$i$i = $13;
  while(1) {
   $21 = HEAP32[$$09$i$i>>2]|0;
   $22 = HEAP32[$$078$i$i>>2]|0;
   $23 = ($21|0)==($22|0);
   if (!($23)) {
    HEAP32[$$09$i$i>>2] = $22;
    $24 = ($22|0)==(0|0);
    if (!($24)) {
     $25 = ((($22)) + 8|0);
     $26 = HEAP32[$25>>2]|0;HEAP32[$25>>2] = (($26+1)|0);
    }
    $27 = ($21|0)==(0|0);
    if (!($27)) {
     $28 = ((($21)) + 8|0);
     $29 = HEAP32[$28>>2]|0;HEAP32[$28>>2] = (($29-1)|0);
     $30 = ($29|0)==(1);
     if ($30) {
      __ZNK3osg10Referenced24signalObserversAndDeleteEbb($21,1,1);
     }
    }
   }
   $31 = ((($$078$i$i)) + 4|0);
   $32 = ((($$09$i$i)) + 4|0);
   $33 = ($31|0)==($$|0);
   if ($33) {
    $$0$lcssa$i$i = $32;
    break;
   } else {
    $$078$i$i = $31;$$09$i$i = $32;
   }
  }
 }
 if ($18) {
  $34 = ($$|0)==($2|0);
  if ($34) {
   return;
  }
  $$pre$i$i19 = HEAP32[$14>>2]|0;
  $$07$i$i21 = $19;$36 = $$pre$i$i19;
  while(1) {
   $35 = HEAP32[$$07$i$i21>>2]|0;
   HEAP32[$36>>2] = $35;
   $37 = ($35|0)==(0|0);
   if (!($37)) {
    $38 = ((($35)) + 8|0);
    $39 = HEAP32[$38>>2]|0;HEAP32[$38>>2] = (($39+1)|0);
   }
   $40 = ((($$07$i$i21)) + 4|0);
   $41 = HEAP32[$14>>2]|0;
   $42 = ((($41)) + 4|0);
   HEAP32[$14>>2] = $42;
   $43 = ($40|0)==($2|0);
   if ($43) {
    break;
   } else {
    $$07$i$i21 = $40;$36 = $42;
   }
  }
  return;
 }
 $44 = HEAP32[$14>>2]|0;
 $45 = ($44|0)==($$0$lcssa$i$i|0);
 if ($45) {
  return;
 } else {
  $47 = $44;
 }
 while(1) {
  $46 = ((($47)) + -4|0);
  HEAP32[$14>>2] = $46;
  $48 = HEAP32[$46>>2]|0;
  $49 = ($48|0)==(0|0);
  if (!($49)) {
   $50 = ((($48)) + 8|0);
   $51 = HEAP32[$50>>2]|0;HEAP32[$50>>2] = (($51-1)|0);
   $52 = ($51|0)==(1);
   if ($52) {
    __THREW__ = 0;
    invoke_viii(3262,($48|0),1,1);
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if ($54) {
     label = 21;
     break;
    }
   }
  }
  HEAP32[$46>>2] = 0;
  $55 = HEAP32[$14>>2]|0;
  $56 = ($55|0)==($$0$lcssa$i$i|0);
  if ($56) {
   label = 40;
   break;
  } else {
   $47 = $55;
  }
 }
 if ((label|0) == 21) {
  $57 = ___cxa_find_matching_catch_2()|0;
  $58 = tempRet0;
  ___cxa_call_unexpected(($57|0));
  // unreachable;
 }
 else if ((label|0) == 40) {
  return;
 }
}
function __ZN3osg15DisplaySettings30setMaxNumberOfGraphicsContextsEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 84|0);
 HEAP32[$2>>2] = $1;
 return;
}
function __ZNK3osg15DisplaySettings30getMaxNumberOfGraphicsContextsEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 84|0);
 $2 = HEAP32[$1>>2]|0;
 return ($2|0);
}
function __ZN3osg8Drawable21setThreadSafeRefUnrefEb($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg6Object21setThreadSafeRefUnrefEb($0,$1);
 $2 = ((($0)) + 120|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = HEAP32[$3>>2]|0;
  $6 = HEAP32[$5>>2]|0;
  FUNCTION_TABLE_vii[$6 & 8191]($3,$1);
 }
 $7 = ((($0)) + 212|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if ($9) {
  return;
 }
 $10 = HEAP32[$8>>2]|0;
 $11 = ((($10)) + -12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($8) + ($12)|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP32[$14>>2]|0;
 FUNCTION_TABLE_vii[$15 & 8191]($13,$1);
 return;
}
function __ZN3osg8DrawableD2Ev($0) {
 $0 = $0|0;
 var $$0 = 0, $$0$i31 = 0, $$02 = 0, $$3 = 0, $$35 = 0, $$4 = 0, $$46 = 0, $$pre = 0, $$pre$i$i = 0, $$pre$i$i14 = 0, $$pre32 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0;
 var $143 = 0, $144 = 0, $145 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i$i$i18 = 0, $scevgep5$i$i$i$i = 0, $scevgep5$i$i$i$i19 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (58336);
 $1 = ((($0)) + 200|0);
 $2 = ((($0)) + 204|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$1>>2]|0;
 $5 = ($3|0)==($4|0);
 L1: do {
  if ($5) {
   label = 6;
  } else {
   $$0$i31 = 0;$145 = $3;$6 = $4;
   while(1) {
    $7 = $6;
    $8 = (($7) + ($$0$i31<<2)|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = ($9|0)==(0|0);
    if ($10) {
     $15 = $6;$16 = $145;
    } else {
     __THREW__ = 0;
     invoke_vi(3749,($9|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      break;
     }
     $$pre = HEAP32[$2>>2]|0;
     $$pre32 = HEAP32[$1>>2]|0;
     $15 = $$pre32;$16 = $$pre;
    }
    $13 = (($$0$i31) + 1)|0;
    $14 = (($16) - ($15))|0;
    $17 = $14 >> 2;
    $18 = ($13>>>0)<($17>>>0);
    if ($18) {
     $$0$i31 = $13;$145 = $16;$6 = $15;
    } else {
     label = 6;
     break L1;
    }
   }
   $76 = ___cxa_find_matching_catch_2()|0;
   $77 = tempRet0;
   $78 = ((($0)) + 212|0);
   $79 = HEAP32[$78>>2]|0;
   $80 = ($79|0)==(0|0);
   if (!($80)) {
    $81 = HEAP32[$79>>2]|0;
    $82 = ((($81)) + -12|0);
    $83 = HEAP32[$82>>2]|0;
    $84 = (($79) + ($83)|0);
    $85 = ((($84)) + 8|0);
    $86 = HEAP32[$85>>2]|0;HEAP32[$85>>2] = (($86-1)|0);
    $87 = ($86|0)==(1);
    if ($87) {
     __THREW__ = 0;
     invoke_viii(3262,($84|0),1,1);
     $88 = __THREW__; __THREW__ = 0;
     $89 = $88&1;
     if ($89) {
      $143 = ___cxa_find_matching_catch_3(0|0)|0;
      $144 = tempRet0;
      ___clang_call_terminate($143);
      // unreachable;
     }
    }
   }
   HEAP32[$78>>2] = 0;
   $$0 = $77;$$02 = $76;
   label = 34;
  }
 } while(0);
 do {
  if ((label|0) == 6) {
   $19 = ((($0)) + 212|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = ($20|0)==(0|0);
   if (!($21)) {
    $22 = HEAP32[$20>>2]|0;
    $23 = ((($22)) + -12|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = (($20) + ($24)|0);
    $26 = ((($25)) + 8|0);
    $27 = HEAP32[$26>>2]|0;HEAP32[$26>>2] = (($27-1)|0);
    $28 = ($27|0)==(1);
    if ($28) {
     __THREW__ = 0;
     invoke_viii(3262,($25|0),1,1);
     $29 = __THREW__; __THREW__ = 0;
     $30 = $29&1;
     if ($30) {
      $90 = ___cxa_find_matching_catch_2()|0;
      $91 = tempRet0;
      $$0 = $91;$$02 = $90;
      label = 34;
      break;
     }
    }
   }
   HEAP32[$19>>2] = 0;
   $31 = HEAP32[$1>>2]|0;
   $32 = ($31|0)==(0|0);
   if (!($32)) {
    $33 = HEAP32[$2>>2]|0;
    $34 = ($33|0)==($31|0);
    do {
     if ($34) {
      $48 = $31;
     } else {
      $36 = $33;
      while(1) {
       $35 = ((($36)) + -4|0);
       HEAP32[$2>>2] = $35;
       $37 = HEAP32[$35>>2]|0;
       $38 = ($37|0)==(0|0);
       if (!($38)) {
        $39 = ((($37)) + 8|0);
        $40 = HEAP32[$39>>2]|0;HEAP32[$39>>2] = (($40-1)|0);
        $41 = ($40|0)==(1);
        if ($41) {
         __THREW__ = 0;
         invoke_viii(3262,($37|0),1,1);
         $42 = __THREW__; __THREW__ = 0;
         $43 = $42&1;
         if ($43) {
          label = 15;
          break;
         }
        }
       }
       HEAP32[$35>>2] = 0;
       $44 = HEAP32[$2>>2]|0;
       $45 = ($44|0)==($31|0);
       if ($45) {
        label = 16;
        break;
       } else {
        $36 = $44;
       }
      }
      if ((label|0) == 15) {
       $46 = ___cxa_find_matching_catch_2()|0;
       $47 = tempRet0;
       ___cxa_call_unexpected(($46|0));
       // unreachable;
      }
      else if ((label|0) == 16) {
       $$pre$i$i = HEAP32[$1>>2]|0;
       $48 = $$pre$i$i;
       break;
      }
     }
    } while(0);
    __ZdlPv($48);
   }
   $49 = ((($0)) + 188|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = ($50|0)==(0|0);
   if (!($51)) {
    $52 = ((($0)) + 192|0);
    $53 = HEAP32[$52>>2]|0;
    $54 = ($53|0)==($50|0);
    if (!($54)) {
     $scevgep$i$i$i$i = ((($53)) + -4|0);
     $55 = $scevgep$i$i$i$i;
     $56 = $50;
     $57 = (($55) - ($56))|0;
     $58 = $57 >>> 2;
     $59 = $58 ^ -1;
     $scevgep5$i$i$i$i = (($53) + ($59<<2)|0);
     HEAP32[$52>>2] = $scevgep5$i$i$i$i;
    }
    __ZdlPv($50);
   }
   $60 = ((($0)) + 176|0);
   $61 = HEAP32[$60>>2]|0;
   $62 = ($61|0)==(0|0);
   if (!($62)) {
    $63 = ((($61)) + 8|0);
    $64 = HEAP32[$63>>2]|0;HEAP32[$63>>2] = (($64-1)|0);
    $65 = ($64|0)==(1);
    if ($65) {
     __THREW__ = 0;
     invoke_viii(3262,($61|0),1,1);
     $66 = __THREW__; __THREW__ = 0;
     $67 = $66&1;
     if ($67) {
      $121 = ___cxa_find_matching_catch_2()|0;
      $122 = tempRet0;
      $$3 = $122;$$35 = $121;
      label = 53;
      break;
     }
    }
   }
   HEAP32[$60>>2] = 0;
   $68 = ((($0)) + 148|0);
   $69 = HEAP32[$68>>2]|0;
   $70 = ($69|0)==(0|0);
   if ($70) {
    HEAP32[$68>>2] = 0;
    __ZN3osg4NodeD2Ev($0);
    return;
   }
   $71 = ((($69)) + 8|0);
   $72 = HEAP32[$71>>2]|0;HEAP32[$71>>2] = (($72-1)|0);
   $73 = ($72|0)==(1);
   if (!($73)) {
    HEAP32[$68>>2] = 0;
    __ZN3osg4NodeD2Ev($0);
    return;
   }
   __THREW__ = 0;
   invoke_viii(3262,($69|0),1,1);
   $74 = __THREW__; __THREW__ = 0;
   $75 = $74&1;
   if ($75) {
    $131 = ___cxa_find_matching_catch_2()|0;
    $132 = tempRet0;
    $$4 = $132;$$46 = $131;
    break;
   } else {
    HEAP32[$68>>2] = 0;
    __ZN3osg4NodeD2Ev($0);
    return;
   }
  }
 } while(0);
 if ((label|0) == 34) {
  $92 = HEAP32[$1>>2]|0;
  $93 = ($92|0)==(0|0);
  if (!($93)) {
   $94 = HEAP32[$2>>2]|0;
   $95 = ($94|0)==($92|0);
   do {
    if ($95) {
     $109 = $92;
    } else {
     $97 = $94;
     while(1) {
      $96 = ((($97)) + -4|0);
      HEAP32[$2>>2] = $96;
      $98 = HEAP32[$96>>2]|0;
      $99 = ($98|0)==(0|0);
      if (!($99)) {
       $100 = ((($98)) + 8|0);
       $101 = HEAP32[$100>>2]|0;HEAP32[$100>>2] = (($101-1)|0);
       $102 = ($101|0)==(1);
       if ($102) {
        __THREW__ = 0;
        invoke_viii(3262,($98|0),1,1);
        $103 = __THREW__; __THREW__ = 0;
        $104 = $103&1;
        if ($104) {
         label = 40;
         break;
        }
       }
      }
      HEAP32[$96>>2] = 0;
      $105 = HEAP32[$2>>2]|0;
      $106 = ($105|0)==($92|0);
      if ($106) {
       label = 41;
       break;
      } else {
       $97 = $105;
      }
     }
     if ((label|0) == 40) {
      $107 = ___cxa_find_matching_catch_2()|0;
      $108 = tempRet0;
      ___cxa_call_unexpected(($107|0));
      // unreachable;
     }
     else if ((label|0) == 41) {
      $$pre$i$i14 = HEAP32[$1>>2]|0;
      $109 = $$pre$i$i14;
      break;
     }
    }
   } while(0);
   __ZdlPv($109);
  }
  $110 = ((($0)) + 188|0);
  $111 = HEAP32[$110>>2]|0;
  $112 = ($111|0)==(0|0);
  if (!($112)) {
   $113 = ((($0)) + 192|0);
   $114 = HEAP32[$113>>2]|0;
   $115 = ($114|0)==($111|0);
   if (!($115)) {
    $scevgep$i$i$i$i18 = ((($114)) + -4|0);
    $116 = $scevgep$i$i$i$i18;
    $117 = $111;
    $118 = (($116) - ($117))|0;
    $119 = $118 >>> 2;
    $120 = $119 ^ -1;
    $scevgep5$i$i$i$i19 = (($114) + ($120<<2)|0);
    HEAP32[$113>>2] = $scevgep5$i$i$i$i19;
   }
   __ZdlPv($111);
  }
  $123 = ((($0)) + 176|0);
  $124 = HEAP32[$123>>2]|0;
  $125 = ($124|0)==(0|0);
  if (!($125)) {
   $126 = ((($124)) + 8|0);
   $127 = HEAP32[$126>>2]|0;HEAP32[$126>>2] = (($127-1)|0);
   $128 = ($127|0)==(1);
   if ($128) {
    __THREW__ = 0;
    invoke_viii(3262,($124|0),1,1);
    $129 = __THREW__; __THREW__ = 0;
    $130 = $129&1;
    if ($130) {
     $143 = ___cxa_find_matching_catch_3(0|0)|0;
     $144 = tempRet0;
     ___clang_call_terminate($143);
     // unreachable;
    }
   }
  }
  HEAP32[$123>>2] = 0;
  $$3 = $$0;$$35 = $$02;
  label = 53;
 }
 if ((label|0) == 53) {
  $133 = ((($0)) + 148|0);
  $134 = HEAP32[$133>>2]|0;
  $135 = ($134|0)==(0|0);
  if (!($135)) {
   $136 = ((($134)) + 8|0);
   $137 = HEAP32[$136>>2]|0;HEAP32[$136>>2] = (($137-1)|0);
   $138 = ($137|0)==(1);
   if ($138) {
    __THREW__ = 0;
    invoke_viii(3262,($134|0),1,1);
    $139 = __THREW__; __THREW__ = 0;
    $140 = $139&1;
    if ($140) {
     $143 = ___cxa_find_matching_catch_3(0|0)|0;
     $144 = tempRet0;
     ___clang_call_terminate($143);
     // unreachable;
    }
   }
  }
  HEAP32[$133>>2] = 0;
  $$4 = $$3;$$46 = $$35;
 }
 __THREW__ = 0;
 invoke_vi(2026,($0|0));
 $141 = __THREW__; __THREW__ = 0;
 $142 = $141&1;
 if ($142) {
  $143 = ___cxa_find_matching_catch_3(0|0)|0;
  $144 = tempRet0;
  ___clang_call_terminate($143);
  // unreachable;
 } else {
  ___resumeException($$46|0);
  // unreachable;
 }
}
function __ZN3osg8DrawableD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1630,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK3osg8Drawable9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(216)|0);
 __THREW__ = 0;
 invoke_vi(3750,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch_2()|0;
  $5 = tempRet0;
  __ZdlPv($1);
  ___resumeException($4|0);
  // unreachable;
 } else {
  return ($1|0);
 }
 return (0)|0;
}
function __ZNK3osg8Drawable5cloneERKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(216)|0);
 __THREW__ = 0;
 invoke_viii(3751,($2|0),($0|0),($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch_2()|0;
  $6 = tempRet0;
  __ZdlPv($2);
  ___resumeException($5|0);
  // unreachable;
 } else {
  return ($2|0);
 }
 return (0)|0;
}
function __ZNK3osg8Drawable12isSameKindAsEPKNS_6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,24472,0)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK3osg8Drawable11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175113|0);
}
function __ZNK3osg8Drawable9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (126708|0);
}
function __ZN3osg8Drawable10asDrawableEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ($0|0);
}
function __ZNK3osg8Drawable10asDrawableEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ($0|0);
}
function __ZN3osg8Drawable19computeDataVarianceEv($0) {
 $0 = $0|0;
 var $$0$off0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(2);
 if (!($3)) {
  return;
 }
 $4 = ((($0)) + 84|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $7 = ((($0)) + 92|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)==(0|0);
  if ($9) {
   $10 = ((($0)) + 100|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = ($11|0)==(0|0);
   if ($12) {
    $$0$off0 = 1;
   } else {
    label = 5;
   }
  } else {
   label = 5;
  }
 } else {
  label = 5;
 }
 if ((label|0) == 5) {
  $$0$off0 = 0;
 }
 HEAP32[$1>>2] = $$0$off0;
 return;
}
function __ZN3osg8Drawable21resizeGLObjectBuffersEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $scevgep$i$i$i$i = 0, $scevgep5$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = ((($0)) + 120|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if (!($5)) {
  $6 = HEAP32[$4>>2]|0;
  $7 = ((($6)) + 132|0);
  $8 = HEAP32[$7>>2]|0;
  FUNCTION_TABLE_vii[$8 & 8191]($4,$1);
 }
 $9 = ((($0)) + 212|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if (!($11)) {
  $12 = HEAP32[$10>>2]|0;
  $13 = ((($12)) + -12|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($10) + ($14)|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ((($16)) + 132|0);
  $18 = HEAP32[$17>>2]|0;
  FUNCTION_TABLE_vii[$18 & 8191]($15,$1);
 }
 $19 = ((($0)) + 188|0);
 HEAP32[$2>>2] = 0;
 $20 = ((($0)) + 192|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = HEAP32[$19>>2]|0;
 $23 = (($21) - ($22))|0;
 $24 = $23 >> 2;
 $25 = ($24>>>0)<($1>>>0);
 $26 = $22;
 $27 = $21;
 if ($25) {
  $28 = (($1) - ($24))|0;
  __ZNSt3__26vectorIjNS_9allocatorIjEEE8__appendEjRKj($19,$28,$2);
 } else {
  $29 = ($24>>>0)>($1>>>0);
  if ($29) {
   $30 = (($26) + ($1<<2)|0);
   $31 = ($27|0)==($30|0);
   if (!($31)) {
    $scevgep$i$i$i$i = ((($27)) + -4|0);
    $32 = $scevgep$i$i$i$i;
    $33 = $30;
    $34 = (($32) - ($33))|0;
    $35 = $34 >>> 2;
    $36 = $35 ^ -1;
    $scevgep5$i$i$i$i = (($27) + ($36<<2)|0);
    HEAP32[$20>>2] = $scevgep5$i$i$i$i;
   }
  }
 }
 $37 = ((($0)) + 200|0);
 $38 = ((($0)) + 204|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = HEAP32[$37>>2]|0;
 $41 = (($39) - ($40))|0;
 $42 = $41 >> 2;
 $43 = ($42>>>0)<($1>>>0);
 $44 = $40;
 $45 = $39;
 if ($43) {
  $46 = (($1) - ($42))|0;
  __ZNSt3__26vectorIN3osg7ref_ptrINS1_16VertexArrayStateEEENS_9allocatorIS4_EEE8__appendEj($37,$46);
  STACKTOP = sp;return;
 }
 $47 = ($42>>>0)>($1>>>0);
 if (!($47)) {
  STACKTOP = sp;return;
 }
 $48 = (($44) + ($1<<2)|0);
 $49 = ($45|0)==($48|0);
 if ($49) {
  STACKTOP = sp;return;
 } else {
  $51 = $45;
 }
 while(1) {
  $50 = ((($51)) + -4|0);
  HEAP32[$38>>2] = $50;
  $52 = HEAP32[$50>>2]|0;
  $53 = ($52|0)==(0|0);
  if (!($53)) {
   $54 = ((($52)) + 8|0);
   $55 = HEAP32[$54>>2]|0;HEAP32[$54>>2] = (($55-1)|0);
   $56 = ($55|0)==(1);
   if ($56) {
    __THREW__ = 0;
    invoke_viii(3262,($52|0),1,1);
    $57 = __THREW__; __THREW__ = 0;
    $58 = $57&1;
    if ($58) {
     label = 18;
     break;
    }
   }
  }
  HEAP32[$50>>2] = 0;
  $59 = HEAP32[$38>>2]|0;
  $60 = ($59|0)==($48|0);
  if ($60) {
   label = 19;
   break;
  } else {
   $51 = $59;
  }
 }
 if ((label|0) == 18) {
  $61 = ___cxa_find_matching_catch_2()|0;
  $62 = tempRet0;
  ___cxa_call_unexpected(($61|0));
  // unreachable;
 }
 else if ((label|0) == 19) {
  STACKTOP = sp;return;
 }
}
function __ZNK3osg8Drawable16releaseGLObjectsEPNS_5StateE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$pre$i = 0, $$pre$pre$i = 0, $10 = 0, $100 = 0, $101 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $scevgep$i$i$i$i = 0, $scevgep5$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = ((($0)) + 120|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if (!($5)) {
  $6 = HEAP32[$4>>2]|0;
  $7 = ((($6)) + 136|0);
  $8 = HEAP32[$7>>2]|0;
  FUNCTION_TABLE_vii[$8 & 8191]($4,$1);
 }
 $9 = ((($0)) + 212|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if (!($11)) {
  $12 = HEAP32[$10>>2]|0;
  $13 = ((($12)) + -12|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($10) + ($14)|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ((($16)) + 136|0);
  $18 = HEAP32[$17>>2]|0;
  FUNCTION_TABLE_vii[$18 & 8191]($15,$1);
 }
 $19 = ($1|0)==(0|0);
 if ($19) {
  $99 = HEAP32[$0>>2]|0;
  $100 = ((($99)) + 220|0);
  $101 = HEAP32[$100>>2]|0;
  FUNCTION_TABLE_vi[$101 & 8191]($0);
  STACKTOP = sp;return;
 }
 $20 = ((($1)) + 124|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ((($0)) + 181|0);
 $23 = HEAP8[$22>>0]|0;
 $24 = ($23<<24>>24)==(0);
 if (!($24)) {
  $25 = ((($0)) + 188|0);
  $26 = ((($0)) + 192|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = HEAP32[$25>>2]|0;
  $29 = (($27) - ($28))|0;
  $30 = $29 >> 2;
  $31 = ($30>>>0)>($21>>>0);
  $32 = $28;
  if ($31) {
   $46 = $32;
  } else {
   $33 = (($21) + 1)|0;
   HEAP32[$2>>2] = 0;
   $34 = ($33>>>0)>($30>>>0);
   $35 = $27;
   if ($34) {
    $36 = (($33) - ($30))|0;
    __ZNSt3__26vectorIjNS_9allocatorIjEEE8__appendEjRKj($25,$36,$2);
    $$pre$pre$i = HEAP32[$25>>2]|0;
    $$pre$i = $$pre$pre$i;
   } else {
    $37 = ($33>>>0)<($30>>>0);
    if ($37) {
     $38 = (($32) + ($33<<2)|0);
     $39 = ($35|0)==($38|0);
     if ($39) {
      $$pre$i = $32;
     } else {
      $scevgep$i$i$i$i = ((($35)) + -4|0);
      $40 = $scevgep$i$i$i$i;
      $41 = $38;
      $42 = (($40) - ($41))|0;
      $43 = $42 >>> 2;
      $44 = $43 ^ -1;
      $scevgep5$i$i$i$i = (($35) + ($44<<2)|0);
      HEAP32[$26>>2] = $scevgep5$i$i$i$i;
      $$pre$i = $32;
     }
    } else {
     $$pre$i = $32;
    }
   }
   $46 = $$pre$i;
  }
  $45 = (($46) + ($21<<2)|0);
  $47 = HEAP32[$45>>2]|0;
  $48 = ($47|0)==(0);
  if (!($48)) {
   $49 = HEAP32[$0>>2]|0;
   $50 = ((($49)) + 224|0);
   $51 = HEAP32[$50>>2]|0;
   $52 = (FUNCTION_TABLE_ii[$51 & 8191]($0)|0);
   $53 = (__ZN3osg22getOrCreateContextDataEj($21)|0);
   $54 = (__ZN3osg11ContextData3getI18DisplayListManagerEEPT_v($53)|0);
   __ZN18DisplayListManager17deleteDisplayListEjj($54,$47,$52);
   HEAP32[$45>>2] = 0;
  }
 }
 $55 = ((($0)) + 200|0);
 $56 = ((($0)) + 204|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = HEAP32[$55>>2]|0;
 $59 = (($57) - ($58))|0;
 $60 = $59 >> 2;
 $61 = ($21>>>0)<($60>>>0);
 if (!($61)) {
  STACKTOP = sp;return;
 }
 $62 = $58;
 $63 = (($62) + ($21<<2)|0);
 $64 = HEAP32[$63>>2]|0;
 $65 = ($64|0)==(0|0);
 if ($65) {
  STACKTOP = sp;return;
 }
 __ZN3osg16VertexArrayState7releaseEv($64);
 $66 = HEAP32[$56>>2]|0;
 $67 = HEAP32[$55>>2]|0;
 $68 = (($66) - ($67))|0;
 $69 = $68 >> 2;
 $70 = ($69>>>0)>($21>>>0);
 L30: do {
  if (!($70)) {
   $71 = (($21) + 1)|0;
   $72 = ($71>>>0)>($69>>>0);
   $73 = $67;
   $74 = $66;
   if ($72) {
    $75 = (($71) - ($69))|0;
    __ZNSt3__26vectorIN3osg7ref_ptrINS1_16VertexArrayStateEEENS_9allocatorIS4_EEE8__appendEj($55,$75);
    break;
   }
   $76 = ($71>>>0)<($69>>>0);
   if ($76) {
    $77 = (($73) + ($71<<2)|0);
    $78 = ($74|0)==($77|0);
    if (!($78)) {
     $80 = $74;
     while(1) {
      $79 = ((($80)) + -4|0);
      HEAP32[$56>>2] = $79;
      $81 = HEAP32[$79>>2]|0;
      $82 = ($81|0)==(0|0);
      if (!($82)) {
       $83 = ((($81)) + 8|0);
       $84 = HEAP32[$83>>2]|0;HEAP32[$83>>2] = (($84-1)|0);
       $85 = ($84|0)==(1);
       if ($85) {
        __THREW__ = 0;
        invoke_viii(3262,($81|0),1,1);
        $86 = __THREW__; __THREW__ = 0;
        $87 = $86&1;
        if ($87) {
         break;
        }
       }
      }
      HEAP32[$79>>2] = 0;
      $88 = HEAP32[$56>>2]|0;
      $89 = ($88|0)==($77|0);
      if ($89) {
       break L30;
      } else {
       $80 = $88;
      }
     }
     $90 = ___cxa_find_matching_catch_2()|0;
     $91 = tempRet0;
     ___cxa_call_unexpected(($90|0));
     // unreachable;
    }
   }
  }
 } while(0);
 $92 = HEAP32[$55>>2]|0;
 $93 = (($92) + ($21<<2)|0);
 $94 = HEAP32[$93>>2]|0;
 $95 = ($94|0)==(0|0);
 if ($95) {
  STACKTOP = sp;return;
 }
 HEAP32[$93>>2] = 0;
 $96 = ((($94)) + 8|0);
 $97 = HEAP32[$96>>2]|0;HEAP32[$96>>2] = (($97-1)|0);
 $98 = ($97|0)==(1);
 if (!($98)) {
  STACKTOP = sp;return;
 }
 __ZNK3osg10Referenced24signalObserversAndDeleteEbb($94,1,1);
 STACKTOP = sp;return;
}
function __ZN3osg4Node7asGroupEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZNK3osg4Node7asGroupEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZN3osg8Drawable6acceptERNS_11NodeVisitorE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$byval_copy = 0, $$pre$i$i = 0, $$sink$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i = 0, $scevgep5$i$i$i$i = 0, $scevgep5$i$i$i$sink$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy = sp + 8|0;
 $2 = sp + 4|0;
 $3 = sp;
 $4 = ((($1)) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($1)) + 24|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($0)) + 116|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $9 | $7;
 $11 = $10 & $5;
 $12 = ($11|0)==(0);
 if ($12) {
  STACKTOP = sp;return;
 }
 HEAP32[$2>>2] = $0;
 $13 = ((($1)) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(1);
 $16 = ((($1)) + 28|0);
 $17 = $0;
 do {
  if ($15) {
   $25 = HEAP32[$16>>2]|0;
   HEAP32[$3>>2] = $25;
   ;HEAP32[$$byval_copy>>2]=HEAP32[$3>>2]|0;
   (__ZNSt3__26vectorIPN3osg4NodeENS_9allocatorIS3_EEE6insertENS_11__wrap_iterIPKS3_EERS8_($16,$$byval_copy,$2)|0);
  } else {
   $18 = ((($1)) + 32|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ((($1)) + 36|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = ($19|0)==($21|0);
   if ($22) {
    __ZNSt3__26vectorIPN3osg4NodeENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_($16,$2);
    break;
   } else {
    HEAP32[$19>>2] = $17;
    $23 = HEAP32[$18>>2]|0;
    $24 = ((($23)) + 4|0);
    HEAP32[$18>>2] = $24;
    break;
   }
  }
 } while(0);
 $26 = HEAP32[$1>>2]|0;
 $27 = ((($26)) + 100|0);
 $28 = HEAP32[$27>>2]|0;
 FUNCTION_TABLE_vii[$28 & 8191]($1,$0);
 $29 = HEAP32[$13>>2]|0;
 $30 = ($29|0)==(1);
 do {
  if ($30) {
   $34 = ((($1)) + 28|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ((($35)) + 4|0);
   $37 = ((($1)) + 32|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = $36;
   $40 = (($38) - ($39))|0;
   $41 = $40 >> 2;
   $42 = ($41|0)==(0);
   $43 = $38;
   if ($42) {
    $45 = $43;
   } else {
    _memmove(($35|0),($36|0),($40|0))|0;
    $$pre$i$i = HEAP32[$37>>2]|0;
    $45 = $$pre$i$i;
   }
   $44 = (($35) + ($41<<2)|0);
   $46 = ($45|0)==($44|0);
   if ($46) {
    STACKTOP = sp;return;
   } else {
    $scevgep$i$i$i$i = ((($45)) + -4|0);
    $47 = $scevgep$i$i$i$i;
    $48 = $44;
    $49 = (($47) - ($48))|0;
    $50 = $49 >>> 2;
    $51 = $50 ^ -1;
    $scevgep5$i$i$i$i = (($45) + ($51<<2)|0);
    $$sink$i = $37;$scevgep5$i$i$i$sink$i = $scevgep5$i$i$i$i;
    break;
   }
  } else {
   $31 = ((($1)) + 32|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ((($32)) + -4|0);
   $$sink$i = $31;$scevgep5$i$i$i$sink$i = $33;
  }
 } while(0);
 HEAP32[$$sink$i>>2] = $scevgep5$i$i$i$sink$i;
 STACKTOP = sp;return;
}
function __ZN3osg4Node8traverseERNS_11NodeVisitorE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZNK3osg8Drawable12computeBoundEv($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__ZNK3osg8Drawable14getBoundingBoxEv($1)|0);
 HEAPF32[$0>>2] = 0.0;
 $3 = ((($0)) + 4|0);
 HEAPF32[$3>>2] = 0.0;
 $4 = ((($0)) + 8|0);
 HEAPF32[$4>>2] = 0.0;
 $5 = ((($0)) + 12|0);
 HEAPF32[$5>>2] = -1.0;
 __ZN3osg18BoundingSphereImplINS_5Vec3fEE8expandByIS1_EEvRKNS_15BoundingBoxImplIT_EE($0,$2);
 return;
}
function __ZNK3osg8Drawable18computeBoundingBoxEv($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(64|0);
 $2 = sp;
 HEAP32[$2>>2] = (58620);
 $3 = ((($2)) + 28|0);
 HEAPF32[$3>>2] = 3.4028234663852886E+38;
 $4 = ((($2)) + 32|0);
 HEAPF32[$4>>2] = 3.4028234663852886E+38;
 $5 = ((($2)) + 36|0);
 HEAPF32[$5>>2] = 3.4028234663852886E+38;
 $6 = ((($2)) + 40|0);
 HEAPF32[$6>>2] = -3.4028234663852886E+38;
 $7 = ((($2)) + 44|0);
 HEAPF32[$7>>2] = -3.4028234663852886E+38;
 $8 = ((($2)) + 48|0);
 HEAPF32[$8>>2] = -3.4028234663852886E+38;
 $9 = ((($2)) + 4|0);
 ;HEAP32[$9>>2]=0|0;HEAP32[$9+4>>2]=0|0;HEAP32[$9+8>>2]=0|0;HEAP32[$9+12>>2]=0|0;HEAP32[$9+16>>2]=0|0;HEAP32[$9+20>>2]=0|0;
 $10 = HEAP32[$1>>2]|0;
 $11 = ((($10)) + 264|0);
 $12 = HEAP32[$11>>2]|0;
 __THREW__ = 0;
 invoke_vii($12|0,($1|0),($2|0));
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 if ($14) {
  $16 = ___cxa_find_matching_catch_2()|0;
  $17 = tempRet0;
  ___resumeException($16|0);
  // unreachable;
 } else {
  $15 = ((($2)) + 28|0);
  ;HEAP32[$0>>2]=HEAP32[$15>>2]|0;HEAP32[$0+4>>2]=HEAP32[$15+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$15+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$15+12>>2]|0;HEAP32[$0+16>>2]=HEAP32[$15+16>>2]|0;HEAP32[$0+20>>2]=HEAP32[$15+20>>2]|0;
  STACKTOP = sp;return;
 }
}
function __ZN3osg8Drawable8setShapeEPNS_5ShapeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 176|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==($1|0);
 if ($4) {
  return;
 }
 HEAP32[$2>>2] = $1;
 $5 = ($1|0)==(0|0);
 if (!($5)) {
  $6 = ((($1)) + 8|0);
  $7 = HEAP32[$6>>2]|0;HEAP32[$6>>2] = (($7+1)|0);
 }
 $8 = ($3|0)==(0|0);
 if ($8) {
  return;
 }
 $9 = ((($3)) + 8|0);
 $10 = HEAP32[$9>>2]|0;HEAP32[$9>>2] = (($10-1)|0);
 $11 = ($10|0)==(1);
 if (!($11)) {
  return;
 }
 __ZNK3osg10Referenced24signalObserversAndDeleteEbb($3,1,1);
 return;
}
function __ZN3osg8Drawable25setUseVertexBufferObjectsEb($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = $1&1;
 $3 = ((($0)) + 183|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = $1&1;
 $7 = ($5|0)==($6|0);
 if ($7) {
  return;
 }
 $8 = ($4<<24>>24)==(0);
 if (!($8)) {
  $9 = HEAP32[$0>>2]|0;
  $10 = ((($9)) + 220|0);
  $11 = HEAP32[$10>>2]|0;
  FUNCTION_TABLE_vi[$11 & 8191]($0);
 }
 HEAP8[$3>>0] = $2;
 return;
}
function __ZN3osg8Drawable16dirtyDisplayListEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + 220|0);
 $3 = HEAP32[$2>>2]|0;
 FUNCTION_TABLE_vi[$3 & 8191]($0);
 return;
}
function __ZN3osg8Drawable14dirtyGLObjectsEv($0) {
 $0 = $0|0;
 var $$08 = 0, $$pre = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 200|0);
 $2 = ((($0)) + 204|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$1>>2]|0;
 $5 = ($3|0)==($4|0);
 if ($5) {
  return;
 } else {
  $$08 = 0;$17 = $3;$6 = $4;
 }
 while(1) {
  $7 = $6;
  $8 = (($7) + ($$08<<2)|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($9|0)==(0|0);
  if ($10) {
   $13 = $6;$14 = $17;
  } else {
   __ZN3osg16VertexArrayState5dirtyEv($9);
   $$pre = HEAP32[$2>>2]|0;
   $$pre9 = HEAP32[$1>>2]|0;
   $13 = $$pre9;$14 = $$pre;
  }
  $11 = (($$08) + 1)|0;
  $12 = (($14) - ($13))|0;
  $15 = $12 >> 2;
  $16 = ($11>>>0)<($15>>>0);
  if ($16) {
   $$08 = $11;$17 = $14;$6 = $13;
  } else {
   break;
  }
 }
 return;
}
function __ZNK3osg8Drawable19getGLObjectSizeHintEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function __ZNK3osg8Drawable16compileGLObjectsERNS_10RenderInfoE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZNK3osg8Drawable22createVertexArrayStateERNS_10RenderInfoE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(108)|0);
 $3 = HEAP32[$1>>2]|0;
 __THREW__ = 0;
 invoke_vii(3752,($2|0),($3|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch_2()|0;
  $7 = tempRet0;
  __ZdlPv($2);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN3osg16VertexArrayState20assignAllDispatchersEv($2);
  return ($2|0);
 }
 return (0)|0;
}
function __ZN3osg8Drawable15setDrawCallbackEPNS0_12DrawCallbackE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 212|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==($1|0);
 if (!($4)) {
  HEAP32[$2>>2] = $1;
  $5 = ($1|0)==(0|0);
  if (!($5)) {
   $6 = HEAP32[$1>>2]|0;
   $7 = ((($6)) + -12|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($1) + ($8)|0);
   $10 = ((($9)) + 8|0);
   $11 = HEAP32[$10>>2]|0;HEAP32[$10>>2] = (($11+1)|0);
  }
  $12 = ($3|0)==(0|0);
  if (!($12)) {
   $13 = HEAP32[$3>>2]|0;
   $14 = ((($13)) + -12|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (($3) + ($15)|0);
   $17 = ((($16)) + 8|0);
   $18 = HEAP32[$17>>2]|0;HEAP32[$17>>2] = (($18-1)|0);
   $19 = ($18|0)==(1);
   if ($19) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($16,1,1);
   }
  }
 }
 $20 = HEAP32[$0>>2]|0;
 $21 = ((($20)) + 216|0);
 $22 = HEAP32[$21>>2]|0;
 FUNCTION_TABLE_vi[$22 & 8191]($0);
 return;
}
function __ZNK3osg8Drawable18drawImplementationERNS_10RenderInfoE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZNK3osg8Drawable8supportsERKNS0_16AttributeFunctorE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function __ZN3osg8Drawable6acceptERNS0_16AttributeFunctorE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZNK3osg8Drawable8supportsERKNS0_21ConstAttributeFunctorE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function __ZNK3osg8Drawable6acceptERNS0_21ConstAttributeFunctorE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZNK3osg8Drawable8supportsERKNS_16PrimitiveFunctorE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function __ZNK3osg8Drawable6acceptERNS_16PrimitiveFunctorE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZNK3osg8Drawable8supportsERKNS_21PrimitiveIndexFunctorE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function __ZNK3osg8Drawable6acceptERNS_21PrimitiveIndexFunctorE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN12ComputeBoundD0Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($0);
 return;
}
function __ZN12ComputeBound14setVertexArrayEjPKN3osg5Vec2fE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 4|0);
 HEAP32[$3>>2] = $2;
 return;
}
function __ZN12ComputeBound14setVertexArrayEjPKN3osg5Vec3fE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 8|0);
 HEAP32[$3>>2] = $2;
 return;
}
function __ZN12ComputeBound14setVertexArrayEjPKN3osg5Vec4fE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 12|0);
 HEAP32[$3>>2] = $2;
 return;
}
function __ZN12ComputeBound14setVertexArrayEjPKN3osg5Vec2dE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 16|0);
 HEAP32[$3>>2] = $2;
 return;
}
function __ZN12ComputeBound14setVertexArrayEjPKN3osg5Vec3dE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 20|0);
 HEAP32[$3>>2] = $2;
 return;
}
function __ZN12ComputeBound14setVertexArrayEjPKN3osg5Vec4dE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 24|0);
 HEAP32[$3>>2] = $2;
 return;
}
function __ZN12ComputeBound10drawArraysEjii($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$05$i = 0, $$05$i19 = 0, $$05$i21 = 0, $$05$i23 = 0, $$05$i25 = 0, $$05$i27 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ((($0)) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = (($3) + ($2))|0;
  $8 = (($5) + (($7*12)|0)|0);
  $9 = ($3|0)>(0);
  if (!($9)) {
   return;
  }
  $10 = (($5) + (($2*12)|0)|0);
  $$05$i = $10;
  while(1) {
   $11 = HEAP32[$0>>2]|0;
   $12 = ((($11)) + 56|0);
   $13 = HEAP32[$12>>2]|0;
   FUNCTION_TABLE_vii[$13 & 8191]($0,$$05$i);
   $14 = ((($$05$i)) + 12|0);
   $15 = ($14>>>0)<($8>>>0);
   if ($15) {
    $$05$i = $14;
   } else {
    break;
   }
  }
  return;
 }
 $16 = ((($0)) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==(0|0);
 if (!($18)) {
  $19 = (($3) + ($2))|0;
  $20 = (($17) + ($19<<3)|0);
  $21 = ($3|0)>(0);
  if (!($21)) {
   return;
  }
  $22 = (($17) + ($2<<3)|0);
  $$05$i19 = $22;
  while(1) {
   $23 = HEAP32[$0>>2]|0;
   $24 = ((($23)) + 52|0);
   $25 = HEAP32[$24>>2]|0;
   FUNCTION_TABLE_vii[$25 & 8191]($0,$$05$i19);
   $26 = ((($$05$i19)) + 8|0);
   $27 = ($26>>>0)<($20>>>0);
   if ($27) {
    $$05$i19 = $26;
   } else {
    break;
   }
  }
  return;
 }
 $28 = ((($0)) + 12|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ($29|0)==(0|0);
 if (!($30)) {
  $31 = (($3) + ($2))|0;
  $32 = (($29) + ($31<<4)|0);
  $33 = ($3|0)>(0);
  if (!($33)) {
   return;
  }
  $34 = (($29) + ($2<<4)|0);
  $$05$i21 = $34;
  while(1) {
   $35 = HEAP32[$0>>2]|0;
   $36 = ((($35)) + 60|0);
   $37 = HEAP32[$36>>2]|0;
   FUNCTION_TABLE_vii[$37 & 8191]($0,$$05$i21);
   $38 = ((($$05$i21)) + 16|0);
   $39 = ($38>>>0)<($32>>>0);
   if ($39) {
    $$05$i21 = $38;
   } else {
    break;
   }
  }
  return;
 }
 $40 = ((($0)) + 16|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = ($41|0)==(0|0);
 if (!($42)) {
  $43 = (($3) + ($2))|0;
  $44 = (($41) + ($43<<4)|0);
  $45 = ($3|0)>(0);
  if (!($45)) {
   return;
  }
  $46 = (($41) + ($2<<4)|0);
  $$05$i23 = $46;
  while(1) {
   $47 = HEAP32[$0>>2]|0;
   $48 = ((($47)) + 64|0);
   $49 = HEAP32[$48>>2]|0;
   FUNCTION_TABLE_vii[$49 & 8191]($0,$$05$i23);
   $50 = ((($$05$i23)) + 16|0);
   $51 = ($50>>>0)<($44>>>0);
   if ($51) {
    $$05$i23 = $50;
   } else {
    break;
   }
  }
  return;
 }
 $52 = ((($0)) + 20|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = ($53|0)==(0|0);
 if (!($54)) {
  $55 = (($3) + ($2))|0;
  $56 = (($53) + (($55*24)|0)|0);
  $57 = ($3|0)>(0);
  if (!($57)) {
   return;
  }
  $58 = (($53) + (($2*24)|0)|0);
  $$05$i25 = $58;
  while(1) {
   $59 = HEAP32[$0>>2]|0;
   $60 = ((($59)) + 68|0);
   $61 = HEAP32[$60>>2]|0;
   FUNCTION_TABLE_vii[$61 & 8191]($0,$$05$i25);
   $62 = ((($$05$i25)) + 24|0);
   $63 = ($62>>>0)<($56>>>0);
   if ($63) {
    $$05$i25 = $62;
   } else {
    break;
   }
  }
  return;
 }
 $64 = ((($0)) + 24|0);
 $65 = HEAP32[$64>>2]|0;
 $66 = ($65|0)==(0|0);
 if ($66) {
  return;
 }
 $67 = (($3) + ($2))|0;
 $68 = (($65) + ($67<<5)|0);
 $69 = ($3|0)>(0);
 if (!($69)) {
  return;
 }
 $70 = (($65) + ($2<<5)|0);
 $$05$i27 = $70;
 while(1) {
  $71 = HEAP32[$0>>2]|0;
  $72 = ((($71)) + 72|0);
  $73 = HEAP32[$72>>2]|0;
  FUNCTION_TABLE_vii[$73 & 8191]($0,$$05$i27);
  $74 = ((($$05$i27)) + 32|0);
  $75 = ($74>>>0)<($68>>>0);
  if ($75) {
   $$05$i27 = $74;
  } else {
   break;
  }
 }
 return;
}
function __ZN12ComputeBound12drawElementsEjiPKh($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$06$i = 0, $$06$i19 = 0, $$06$i22 = 0, $$06$i25 = 0, $$06$i28 = 0, $$06$i31 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $8 = 0, $9 = 0, $exitcond$i = 0, $exitcond$i20 = 0;
 var $exitcond$i23 = 0, $exitcond$i26 = 0, $exitcond$i29 = 0, $exitcond$i32 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ((($0)) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = (($3) + ($2)|0);
  $8 = ($2|0)>(0);
  if (!($8)) {
   return;
  }
  $$06$i = $3;
  while(1) {
   $9 = HEAP32[$0>>2]|0;
   $10 = ((($9)) + 56|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = HEAP8[$$06$i>>0]|0;
   $13 = $12&255;
   $14 = (($5) + (($13*12)|0)|0);
   FUNCTION_TABLE_vii[$11 & 8191]($0,$14);
   $15 = ((($$06$i)) + 1|0);
   $exitcond$i = ($15|0)==($7|0);
   if ($exitcond$i) {
    break;
   } else {
    $$06$i = $15;
   }
  }
  return;
 }
 $16 = ((($0)) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==(0|0);
 if (!($18)) {
  $19 = (($3) + ($2)|0);
  $20 = ($2|0)>(0);
  if (!($20)) {
   return;
  }
  $$06$i19 = $3;
  while(1) {
   $21 = HEAP32[$0>>2]|0;
   $22 = ((($21)) + 52|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = HEAP8[$$06$i19>>0]|0;
   $25 = $24&255;
   $26 = (($17) + ($25<<3)|0);
   FUNCTION_TABLE_vii[$23 & 8191]($0,$26);
   $27 = ((($$06$i19)) + 1|0);
   $exitcond$i20 = ($27|0)==($19|0);
   if ($exitcond$i20) {
    break;
   } else {
    $$06$i19 = $27;
   }
  }
  return;
 }
 $28 = ((($0)) + 12|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ($29|0)==(0|0);
 if (!($30)) {
  $31 = (($3) + ($2)|0);
  $32 = ($2|0)>(0);
  if (!($32)) {
   return;
  }
  $$06$i22 = $3;
  while(1) {
   $33 = HEAP32[$0>>2]|0;
   $34 = ((($33)) + 60|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = HEAP8[$$06$i22>>0]|0;
   $37 = $36&255;
   $38 = (($29) + ($37<<4)|0);
   FUNCTION_TABLE_vii[$35 & 8191]($0,$38);
   $39 = ((($$06$i22)) + 1|0);
   $exitcond$i23 = ($39|0)==($31|0);
   if ($exitcond$i23) {
    break;
   } else {
    $$06$i22 = $39;
   }
  }
  return;
 }
 $40 = ((($0)) + 16|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = ($41|0)==(0|0);
 if (!($42)) {
  $43 = (($3) + ($2)|0);
  $44 = ($2|0)>(0);
  if (!($44)) {
   return;
  }
  $$06$i25 = $3;
  while(1) {
   $45 = HEAP32[$0>>2]|0;
   $46 = ((($45)) + 64|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = HEAP8[$$06$i25>>0]|0;
   $49 = $48&255;
   $50 = (($41) + ($49<<4)|0);
   FUNCTION_TABLE_vii[$47 & 8191]($0,$50);
   $51 = ((($$06$i25)) + 1|0);
   $exitcond$i26 = ($51|0)==($43|0);
   if ($exitcond$i26) {
    break;
   } else {
    $$06$i25 = $51;
   }
  }
  return;
 }
 $52 = ((($0)) + 20|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = ($53|0)==(0|0);
 if (!($54)) {
  $55 = (($3) + ($2)|0);
  $56 = ($2|0)>(0);
  if (!($56)) {
   return;
  }
  $$06$i28 = $3;
  while(1) {
   $57 = HEAP32[$0>>2]|0;
   $58 = ((($57)) + 68|0);
   $59 = HEAP32[$58>>2]|0;
   $60 = HEAP8[$$06$i28>>0]|0;
   $61 = $60&255;
   $62 = (($53) + (($61*24)|0)|0);
   FUNCTION_TABLE_vii[$59 & 8191]($0,$62);
   $63 = ((($$06$i28)) + 1|0);
   $exitcond$i29 = ($63|0)==($55|0);
   if ($exitcond$i29) {
    break;
   } else {
    $$06$i28 = $63;
   }
  }
  return;
 }
 $64 = ((($0)) + 24|0);
 $65 = HEAP32[$64>>2]|0;
 $66 = ($65|0)==(0|0);
 if ($66) {
  return;
 }
 $67 = (($3) + ($2)|0);
 $68 = ($2|0)>(0);
 if (!($68)) {
  return;
 }
 $$06$i31 = $3;
 while(1) {
  $69 = HEAP32[$0>>2]|0;
  $70 = ((($69)) + 72|0);
  $71 = HEAP32[$70>>2]|0;
  $72 = HEAP8[$$06$i31>>0]|0;
  $73 = $72&255;
  $74 = (($65) + ($73<<5)|0);
  FUNCTION_TABLE_vii[$71 & 8191]($0,$74);
  $75 = ((($$06$i31)) + 1|0);
  $exitcond$i32 = ($75|0)==($67|0);
  if ($exitcond$i32) {
   break;
  } else {
   $$06$i31 = $75;
  }
 }
 return;
}
function __ZN12ComputeBound12drawElementsEjiPKt($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$06$i = 0, $$06$i19 = 0, $$06$i21 = 0, $$06$i23 = 0, $$06$i25 = 0, $$06$i27 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ((($0)) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = (($3) + ($2<<1)|0);
  $8 = ($2|0)>(0);
  if (!($8)) {
   return;
  }
  $$06$i = $3;
  while(1) {
   $9 = HEAP32[$0>>2]|0;
   $10 = ((($9)) + 56|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = HEAP16[$$06$i>>1]|0;
   $13 = $12&65535;
   $14 = (($5) + (($13*12)|0)|0);
   FUNCTION_TABLE_vii[$11 & 8191]($0,$14);
   $15 = ((($$06$i)) + 2|0);
   $16 = ($15>>>0)<($7>>>0);
   if ($16) {
    $$06$i = $15;
   } else {
    break;
   }
  }
  return;
 }
 $17 = ((($0)) + 4|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ($18|0)==(0|0);
 if (!($19)) {
  $20 = (($3) + ($2<<1)|0);
  $21 = ($2|0)>(0);
  if (!($21)) {
   return;
  }
  $$06$i19 = $3;
  while(1) {
   $22 = HEAP32[$0>>2]|0;
   $23 = ((($22)) + 52|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = HEAP16[$$06$i19>>1]|0;
   $26 = $25&65535;
   $27 = (($18) + ($26<<3)|0);
   FUNCTION_TABLE_vii[$24 & 8191]($0,$27);
   $28 = ((($$06$i19)) + 2|0);
   $29 = ($28>>>0)<($20>>>0);
   if ($29) {
    $$06$i19 = $28;
   } else {
    break;
   }
  }
  return;
 }
 $30 = ((($0)) + 12|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ($31|0)==(0|0);
 if (!($32)) {
  $33 = (($3) + ($2<<1)|0);
  $34 = ($2|0)>(0);
  if (!($34)) {
   return;
  }
  $$06$i21 = $3;
  while(1) {
   $35 = HEAP32[$0>>2]|0;
   $36 = ((($35)) + 60|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = HEAP16[$$06$i21>>1]|0;
   $39 = $38&65535;
   $40 = (($31) + ($39<<4)|0);
   FUNCTION_TABLE_vii[$37 & 8191]($0,$40);
   $41 = ((($$06$i21)) + 2|0);
   $42 = ($41>>>0)<($33>>>0);
   if ($42) {
    $$06$i21 = $41;
   } else {
    break;
   }
  }
  return;
 }
 $43 = ((($0)) + 16|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = ($44|0)==(0|0);
 if (!($45)) {
  $46 = (($3) + ($2<<1)|0);
  $47 = ($2|0)>(0);
  if (!($47)) {
   return;
  }
  $$06$i23 = $3;
  while(1) {
   $48 = HEAP32[$0>>2]|0;
   $49 = ((($48)) + 64|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = HEAP16[$$06$i23>>1]|0;
   $52 = $51&65535;
   $53 = (($44) + ($52<<4)|0);
   FUNCTION_TABLE_vii[$50 & 8191]($0,$53);
   $54 = ((($$06$i23)) + 2|0);
   $55 = ($54>>>0)<($46>>>0);
   if ($55) {
    $$06$i23 = $54;
   } else {
    break;
   }
  }
  return;
 }
 $56 = ((($0)) + 20|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = ($57|0)==(0|0);
 if (!($58)) {
  $59 = (($3) + ($2<<1)|0);
  $60 = ($2|0)>(0);
  if (!($60)) {
   return;
  }
  $$06$i25 = $3;
  while(1) {
   $61 = HEAP32[$0>>2]|0;
   $62 = ((($61)) + 68|0);
   $63 = HEAP32[$62>>2]|0;
   $64 = HEAP16[$$06$i25>>1]|0;
   $65 = $64&65535;
   $66 = (($57) + (($65*24)|0)|0);
   FUNCTION_TABLE_vii[$63 & 8191]($0,$66);
   $67 = ((($$06$i25)) + 2|0);
   $68 = ($67>>>0)<($59>>>0);
   if ($68) {
    $$06$i25 = $67;
   } else {
    break;
   }
  }
  return;
 }
 $69 = ((($0)) + 24|0);
 $70 = HEAP32[$69>>2]|0;
 $71 = ($70|0)==(0|0);
 if ($71) {
  return;
 }
 $72 = (($3) + ($2<<1)|0);
 $73 = ($2|0)>(0);
 if (!($73)) {
  return;
 }
 $$06$i27 = $3;
 while(1) {
  $74 = HEAP32[$0>>2]|0;
  $75 = ((($74)) + 72|0);
  $76 = HEAP32[$75>>2]|0;
  $77 = HEAP16[$$06$i27>>1]|0;
  $78 = $77&65535;
  $79 = (($70) + ($78<<5)|0);
  FUNCTION_TABLE_vii[$76 & 8191]($0,$79);
  $80 = ((($$06$i27)) + 2|0);
  $81 = ($80>>>0)<($72>>>0);
  if ($81) {
   $$06$i27 = $80;
  } else {
   break;
  }
 }
 return;
}
function __ZN12ComputeBound12drawElementsEjiPKj($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$06$i = 0, $$06$i19 = 0, $$06$i21 = 0, $$06$i23 = 0, $$06$i25 = 0, $$06$i27 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ((($0)) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = (($3) + ($2<<2)|0);
  $8 = ($2|0)>(0);
  if (!($8)) {
   return;
  }
  $$06$i = $3;
  while(1) {
   $9 = HEAP32[$0>>2]|0;
   $10 = ((($9)) + 56|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = HEAP32[$$06$i>>2]|0;
   $13 = (($5) + (($12*12)|0)|0);
   FUNCTION_TABLE_vii[$11 & 8191]($0,$13);
   $14 = ((($$06$i)) + 4|0);
   $15 = ($14>>>0)<($7>>>0);
   if ($15) {
    $$06$i = $14;
   } else {
    break;
   }
  }
  return;
 }
 $16 = ((($0)) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==(0|0);
 if (!($18)) {
  $19 = (($3) + ($2<<2)|0);
  $20 = ($2|0)>(0);
  if (!($20)) {
   return;
  }
  $$06$i19 = $3;
  while(1) {
   $21 = HEAP32[$0>>2]|0;
   $22 = ((($21)) + 52|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = HEAP32[$$06$i19>>2]|0;
   $25 = (($17) + ($24<<3)|0);
   FUNCTION_TABLE_vii[$23 & 8191]($0,$25);
   $26 = ((($$06$i19)) + 4|0);
   $27 = ($26>>>0)<($19>>>0);
   if ($27) {
    $$06$i19 = $26;
   } else {
    break;
   }
  }
  return;
 }
 $28 = ((($0)) + 12|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ($29|0)==(0|0);
 if (!($30)) {
  $31 = (($3) + ($2<<2)|0);
  $32 = ($2|0)>(0);
  if (!($32)) {
   return;
  }
  $$06$i21 = $3;
  while(1) {
   $33 = HEAP32[$0>>2]|0;
   $34 = ((($33)) + 60|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = HEAP32[$$06$i21>>2]|0;
   $37 = (($29) + ($36<<4)|0);
   FUNCTION_TABLE_vii[$35 & 8191]($0,$37);
   $38 = ((($$06$i21)) + 4|0);
   $39 = ($38>>>0)<($31>>>0);
   if ($39) {
    $$06$i21 = $38;
   } else {
    break;
   }
  }
  return;
 }
 $40 = ((($0)) + 16|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = ($41|0)==(0|0);
 if (!($42)) {
  $43 = (($3) + ($2<<2)|0);
  $44 = ($2|0)>(0);
  if (!($44)) {
   return;
  }
  $$06$i23 = $3;
  while(1) {
   $45 = HEAP32[$0>>2]|0;
   $46 = ((($45)) + 64|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = HEAP32[$$06$i23>>2]|0;
   $49 = (($41) + ($48<<4)|0);
   FUNCTION_TABLE_vii[$47 & 8191]($0,$49);
   $50 = ((($$06$i23)) + 4|0);
   $51 = ($50>>>0)<($43>>>0);
   if ($51) {
    $$06$i23 = $50;
   } else {
    break;
   }
  }
  return;
 }
 $52 = ((($0)) + 20|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = ($53|0)==(0|0);
 if (!($54)) {
  $55 = (($3) + ($2<<2)|0);
  $56 = ($2|0)>(0);
  if (!($56)) {
   return;
  }
  $$06$i25 = $3;
  while(1) {
   $57 = HEAP32[$0>>2]|0;
   $58 = ((($57)) + 68|0);
   $59 = HEAP32[$58>>2]|0;
   $60 = HEAP32[$$06$i25>>2]|0;
   $61 = (($53) + (($60*24)|0)|0);
   FUNCTION_TABLE_vii[$59 & 8191]($0,$61);
   $62 = ((($$06$i25)) + 4|0);
   $63 = ($62>>>0)<($55>>>0);
   if ($63) {
    $$06$i25 = $62;
   } else {
    break;
   }
  }
  return;
 }
 $64 = ((($0)) + 24|0);
 $65 = HEAP32[$64>>2]|0;
 $66 = ($65|0)==(0|0);
 if ($66) {
  return;
 }
 $67 = (($3) + ($2<<2)|0);
 $68 = ($2|0)>(0);
 if (!($68)) {
  return;
 }
 $$06$i27 = $3;
 while(1) {
  $69 = HEAP32[$0>>2]|0;
  $70 = ((($69)) + 72|0);
  $71 = HEAP32[$70>>2]|0;
  $72 = HEAP32[$$06$i27>>2]|0;
  $73 = (($65) + ($72<<5)|0);
  FUNCTION_TABLE_vii[$71 & 8191]($0,$73);
  $74 = ((($$06$i27)) + 4|0);
  $75 = ($74>>>0)<($67>>>0);
  if ($75) {
   $$06$i27 = $74;
  } else {
   break;
  }
 }
 return;
}
function __ZN12ComputeBound5beginEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN12ComputeBound6vertexERKN3osg5Vec2fE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0.0, $13 = 0, $14 = 0, $15 = 0.0, $16 = 0, $17 = 0, $18 = 0.0, $19 = 0, $2 = 0.0, $20 = 0, $21 = 0.0, $22 = 0, $3 = 0, $4 = 0.0, $5 = 0, $6 = 0.0, $7 = 0, $8 = 0;
 var $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = +HEAPF32[$1>>2];
 $3 = ((($1)) + 4|0);
 $4 = +HEAPF32[$3>>2];
 $5 = ((($0)) + 28|0);
 $6 = +HEAPF32[$5>>2];
 $7 = $2 < $6;
 if ($7) {
  HEAPF32[$5>>2] = $2;
 }
 $8 = ((($0)) + 40|0);
 $9 = +HEAPF32[$8>>2];
 $10 = $2 > $9;
 if ($10) {
  HEAPF32[$8>>2] = $2;
 }
 $11 = ((($0)) + 32|0);
 $12 = +HEAPF32[$11>>2];
 $13 = $4 < $12;
 if ($13) {
  HEAPF32[$11>>2] = $4;
 }
 $14 = ((($0)) + 44|0);
 $15 = +HEAPF32[$14>>2];
 $16 = $4 > $15;
 if ($16) {
  HEAPF32[$14>>2] = $4;
 }
 $17 = ((($0)) + 36|0);
 $18 = +HEAPF32[$17>>2];
 $19 = $18 > 0.0;
 if ($19) {
  HEAPF32[$17>>2] = 0.0;
 }
 $20 = ((($0)) + 48|0);
 $21 = +HEAPF32[$20>>2];
 $22 = $21 < 0.0;
 if (!($22)) {
  return;
 }
 HEAPF32[$20>>2] = 0.0;
 return;
}
function __ZN12ComputeBound6vertexERKN3osg5Vec3fE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$pre$i = 0.0, $$pre13$i = 0.0, $$pre14$i = 0.0, $10 = 0, $11 = 0.0, $12 = 0, $13 = 0.0, $14 = 0, $15 = 0, $16 = 0.0, $17 = 0, $18 = 0.0, $19 = 0, $2 = 0.0, $20 = 0.0, $21 = 0, $22 = 0.0, $23 = 0, $24 = 0, $25 = 0.0;
 var $26 = 0, $27 = 0.0, $3 = 0, $4 = 0.0, $5 = 0, $6 = 0, $7 = 0.0, $8 = 0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = +HEAPF32[$1>>2];
 $3 = ((($0)) + 28|0);
 $4 = +HEAPF32[$3>>2];
 $5 = $2 < $4;
 if ($5) {
  HEAPF32[$3>>2] = $2;
  $$pre$i = +HEAPF32[$1>>2];
  $9 = $$pre$i;
 } else {
  $9 = $2;
 }
 $6 = ((($0)) + 40|0);
 $7 = +HEAPF32[$6>>2];
 $8 = $9 > $7;
 if ($8) {
  HEAPF32[$6>>2] = $9;
 }
 $10 = ((($1)) + 4|0);
 $11 = +HEAPF32[$10>>2];
 $12 = ((($0)) + 32|0);
 $13 = +HEAPF32[$12>>2];
 $14 = $11 < $13;
 if ($14) {
  HEAPF32[$12>>2] = $11;
  $$pre13$i = +HEAPF32[$10>>2];
  $18 = $$pre13$i;
 } else {
  $18 = $11;
 }
 $15 = ((($0)) + 44|0);
 $16 = +HEAPF32[$15>>2];
 $17 = $18 > $16;
 if ($17) {
  HEAPF32[$15>>2] = $18;
 }
 $19 = ((($1)) + 8|0);
 $20 = +HEAPF32[$19>>2];
 $21 = ((($0)) + 36|0);
 $22 = +HEAPF32[$21>>2];
 $23 = $20 < $22;
 if ($23) {
  HEAPF32[$21>>2] = $20;
  $$pre14$i = +HEAPF32[$19>>2];
  $27 = $$pre14$i;
 } else {
  $27 = $20;
 }
 $24 = ((($0)) + 48|0);
 $25 = +HEAPF32[$24>>2];
 $26 = $27 > $25;
 if (!($26)) {
  return;
 }
 HEAPF32[$24>>2] = $27;
 return;
}
function __ZN12ComputeBound6vertexERKN3osg5Vec4fE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0.0, $11 = 0.0, $12 = 0.0, $13 = 0, $14 = 0.0, $15 = 0, $16 = 0, $17 = 0.0, $18 = 0, $19 = 0, $2 = 0, $20 = 0.0, $21 = 0, $22 = 0, $23 = 0.0, $24 = 0, $25 = 0, $26 = 0.0, $27 = 0, $28 = 0;
 var $29 = 0.0, $3 = 0.0, $30 = 0, $4 = 0, $5 = 0.0, $6 = 0, $7 = 0.0, $8 = 0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 12|0);
 $3 = +HEAPF32[$2>>2];
 $4 = $3 != 0.0;
 if (!($4)) {
  return;
 }
 $5 = +HEAPF32[$1>>2];
 $6 = ((($1)) + 4|0);
 $7 = +HEAPF32[$6>>2];
 $8 = ((($1)) + 8|0);
 $9 = +HEAPF32[$8>>2];
 $10 = $5 / $3;
 $11 = $7 / $3;
 $12 = $9 / $3;
 $13 = ((($0)) + 28|0);
 $14 = +HEAPF32[$13>>2];
 $15 = $10 < $14;
 if ($15) {
  HEAPF32[$13>>2] = $10;
 }
 $16 = ((($0)) + 40|0);
 $17 = +HEAPF32[$16>>2];
 $18 = $10 > $17;
 if ($18) {
  HEAPF32[$16>>2] = $10;
 }
 $19 = ((($0)) + 32|0);
 $20 = +HEAPF32[$19>>2];
 $21 = $11 < $20;
 if ($21) {
  HEAPF32[$19>>2] = $11;
 }
 $22 = ((($0)) + 44|0);
 $23 = +HEAPF32[$22>>2];
 $24 = $11 > $23;
 if ($24) {
  HEAPF32[$22>>2] = $11;
 }
 $25 = ((($0)) + 36|0);
 $26 = +HEAPF32[$25>>2];
 $27 = $12 < $26;
 if ($27) {
  HEAPF32[$25>>2] = $12;
 }
 $28 = ((($0)) + 48|0);
 $29 = +HEAPF32[$28>>2];
 $30 = $12 > $29;
 if (!($30)) {
  return;
 }
 HEAPF32[$28>>2] = $12;
 return;
}
function __ZN12ComputeBound6vertexERKN3osg5Vec2dE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0.0, $12 = 0, $13 = 0, $14 = 0.0, $15 = 0, $16 = 0, $17 = 0.0, $18 = 0, $19 = 0, $2 = 0.0, $20 = 0.0, $21 = 0, $22 = 0, $23 = 0.0, $24 = 0, $3 = 0.0, $4 = 0, $5 = 0.0, $6 = 0.0;
 var $7 = 0, $8 = 0.0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = +HEAPF64[$1>>3];
 $3 = $2;
 $4 = ((($1)) + 8|0);
 $5 = +HEAPF64[$4>>3];
 $6 = $5;
 $7 = ((($0)) + 28|0);
 $8 = +HEAPF32[$7>>2];
 $9 = $3 < $8;
 if ($9) {
  HEAPF32[$7>>2] = $3;
 }
 $10 = ((($0)) + 40|0);
 $11 = +HEAPF32[$10>>2];
 $12 = $3 > $11;
 if ($12) {
  HEAPF32[$10>>2] = $3;
 }
 $13 = ((($0)) + 32|0);
 $14 = +HEAPF32[$13>>2];
 $15 = $6 < $14;
 if ($15) {
  HEAPF32[$13>>2] = $6;
 }
 $16 = ((($0)) + 44|0);
 $17 = +HEAPF32[$16>>2];
 $18 = $6 > $17;
 if ($18) {
  HEAPF32[$16>>2] = $6;
 }
 $19 = ((($0)) + 36|0);
 $20 = +HEAPF32[$19>>2];
 $21 = $20 > 0.0;
 if ($21) {
  HEAPF32[$19>>2] = 0.0;
 }
 $22 = ((($0)) + 48|0);
 $23 = +HEAPF32[$22>>2];
 $24 = $23 < 0.0;
 if (!($24)) {
  return;
 }
 HEAPF32[$22>>2] = 0.0;
 return;
}
function __ZN12ComputeBound6vertexERKN3osg5Vec3dE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0.0, $12 = 0, $13 = 0, $14 = 0.0, $15 = 0, $16 = 0, $17 = 0.0, $18 = 0, $19 = 0, $2 = 0.0, $20 = 0.0, $21 = 0, $22 = 0, $23 = 0.0, $24 = 0, $25 = 0, $26 = 0.0, $27 = 0, $3 = 0.0;
 var $4 = 0, $5 = 0.0, $6 = 0.0, $7 = 0, $8 = 0.0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = +HEAPF64[$1>>3];
 $3 = $2;
 $4 = ((($1)) + 8|0);
 $5 = +HEAPF64[$4>>3];
 $6 = $5;
 $7 = ((($1)) + 16|0);
 $8 = +HEAPF64[$7>>3];
 $9 = $8;
 $10 = ((($0)) + 28|0);
 $11 = +HEAPF32[$10>>2];
 $12 = $3 < $11;
 if ($12) {
  HEAPF32[$10>>2] = $3;
 }
 $13 = ((($0)) + 40|0);
 $14 = +HEAPF32[$13>>2];
 $15 = $3 > $14;
 if ($15) {
  HEAPF32[$13>>2] = $3;
 }
 $16 = ((($0)) + 32|0);
 $17 = +HEAPF32[$16>>2];
 $18 = $6 < $17;
 if ($18) {
  HEAPF32[$16>>2] = $6;
 }
 $19 = ((($0)) + 44|0);
 $20 = +HEAPF32[$19>>2];
 $21 = $6 > $20;
 if ($21) {
  HEAPF32[$19>>2] = $6;
 }
 $22 = ((($0)) + 36|0);
 $23 = +HEAPF32[$22>>2];
 $24 = $9 < $23;
 if ($24) {
  HEAPF32[$22>>2] = $9;
 }
 $25 = ((($0)) + 48|0);
 $26 = +HEAPF32[$25>>2];
 $27 = $9 > $26;
 if (!($27)) {
  return;
 }
 HEAPF32[$25>>2] = $9;
 return;
}
function __ZN12ComputeBound6vertexERKN3osg5Vec4dE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0.0, $12 = 0.0, $13 = 0.0, $14 = 0.0, $15 = 0.0, $16 = 0.0, $17 = 0, $18 = 0.0, $19 = 0, $2 = 0, $20 = 0, $21 = 0.0, $22 = 0, $23 = 0, $24 = 0.0, $25 = 0, $26 = 0, $27 = 0.0, $28 = 0;
 var $29 = 0, $3 = 0.0, $30 = 0.0, $31 = 0, $32 = 0, $33 = 0.0, $34 = 0, $4 = 0, $5 = 0.0, $6 = 0.0, $7 = 0, $8 = 0.0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 24|0);
 $3 = +HEAPF64[$2>>3];
 $4 = $3 != 0.0;
 if (!($4)) {
  return;
 }
 $5 = +HEAPF64[$1>>3];
 $6 = $5;
 $7 = ((($1)) + 8|0);
 $8 = +HEAPF64[$7>>3];
 $9 = $8;
 $10 = ((($1)) + 16|0);
 $11 = +HEAPF64[$10>>3];
 $12 = $11;
 $13 = $3;
 $14 = $6 / $13;
 $15 = $9 / $13;
 $16 = $12 / $13;
 $17 = ((($0)) + 28|0);
 $18 = +HEAPF32[$17>>2];
 $19 = $14 < $18;
 if ($19) {
  HEAPF32[$17>>2] = $14;
 }
 $20 = ((($0)) + 40|0);
 $21 = +HEAPF32[$20>>2];
 $22 = $14 > $21;
 if ($22) {
  HEAPF32[$20>>2] = $14;
 }
 $23 = ((($0)) + 32|0);
 $24 = +HEAPF32[$23>>2];
 $25 = $15 < $24;
 if ($25) {
  HEAPF32[$23>>2] = $15;
 }
 $26 = ((($0)) + 44|0);
 $27 = +HEAPF32[$26>>2];
 $28 = $15 > $27;
 if ($28) {
  HEAPF32[$26>>2] = $15;
 }
 $29 = ((($0)) + 36|0);
 $30 = +HEAPF32[$29>>2];
 $31 = $16 < $30;
 if ($31) {
  HEAPF32[$29>>2] = $16;
 }
 $32 = ((($0)) + 48|0);
 $33 = +HEAPF32[$32>>2];
 $34 = $16 > $33;
 if (!($34)) {
  return;
 }
 HEAPF32[$32>>2] = $16;
 return;
}
function __ZN12ComputeBound6vertexEff($0,$1,$2) {
 $0 = $0|0;
 $1 = +$1;
 $2 = +$2;
 var $10 = 0.0, $11 = 0, $12 = 0, $13 = 0.0, $14 = 0, $15 = 0, $16 = 0.0, $17 = 0, $18 = 0, $19 = 0.0, $20 = 0, $3 = 0, $4 = 0.0, $5 = 0, $6 = 0, $7 = 0.0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 28|0);
 $4 = +HEAPF32[$3>>2];
 $5 = $4 > $1;
 if ($5) {
  HEAPF32[$3>>2] = $1;
 }
 $6 = ((($0)) + 40|0);
 $7 = +HEAPF32[$6>>2];
 $8 = $7 < $1;
 if ($8) {
  HEAPF32[$6>>2] = $1;
 }
 $9 = ((($0)) + 32|0);
 $10 = +HEAPF32[$9>>2];
 $11 = $10 > $2;
 if ($11) {
  HEAPF32[$9>>2] = $2;
 }
 $12 = ((($0)) + 44|0);
 $13 = +HEAPF32[$12>>2];
 $14 = $13 < $2;
 if ($14) {
  HEAPF32[$12>>2] = $2;
 }
 $15 = ((($0)) + 36|0);
 $16 = +HEAPF32[$15>>2];
 $17 = $16 > 1.0;
 if ($17) {
  HEAPF32[$15>>2] = 1.0;
 }
 $18 = ((($0)) + 48|0);
 $19 = +HEAPF32[$18>>2];
 $20 = $19 < 1.0;
 if (!($20)) {
  return;
 }
 HEAPF32[$18>>2] = 1.0;
 return;
}
function __ZN12ComputeBound6vertexEfff($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = +$1;
 $2 = +$2;
 $3 = +$3;
 var $10 = 0, $11 = 0.0, $12 = 0, $13 = 0, $14 = 0.0, $15 = 0, $16 = 0, $17 = 0.0, $18 = 0, $19 = 0, $20 = 0.0, $21 = 0, $4 = 0, $5 = 0.0, $6 = 0, $7 = 0, $8 = 0.0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ((($0)) + 28|0);
 $5 = +HEAPF32[$4>>2];
 $6 = $5 > $1;
 if ($6) {
  HEAPF32[$4>>2] = $1;
 }
 $7 = ((($0)) + 40|0);
 $8 = +HEAPF32[$7>>2];
 $9 = $8 < $1;
 if ($9) {
  HEAPF32[$7>>2] = $1;
 }
 $10 = ((($0)) + 32|0);
 $11 = +HEAPF32[$10>>2];
 $12 = $11 > $2;
 if ($12) {
  HEAPF32[$10>>2] = $2;
 }
 $13 = ((($0)) + 44|0);
 $14 = +HEAPF32[$13>>2];
 $15 = $14 < $2;
 if ($15) {
  HEAPF32[$13>>2] = $2;
 }
 $16 = ((($0)) + 36|0);
 $17 = +HEAPF32[$16>>2];
 $18 = $17 > $3;
 if ($18) {
  HEAPF32[$16>>2] = $3;
 }
 $19 = ((($0)) + 48|0);
 $20 = +HEAPF32[$19>>2];
 $21 = $20 < $3;
 if (!($21)) {
  return;
 }
 HEAPF32[$19>>2] = $3;
 return;
}
function __ZN12ComputeBound6vertexEffff($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = +$1;
 $2 = +$2;
 $3 = +$3;
 $4 = +$4;
 var $10 = 0.0, $11 = 0, $12 = 0, $13 = 0.0, $14 = 0, $15 = 0, $16 = 0.0, $17 = 0, $18 = 0, $19 = 0.0, $20 = 0, $21 = 0, $22 = 0.0, $23 = 0, $24 = 0, $25 = 0.0, $26 = 0, $5 = 0, $6 = 0.0, $7 = 0.0;
 var $8 = 0.0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = $4 != 0.0;
 if (!($5)) {
  return;
 }
 $6 = $1 / $4;
 $7 = $2 / $4;
 $8 = $3 / $4;
 $9 = ((($0)) + 28|0);
 $10 = +HEAPF32[$9>>2];
 $11 = $10 > $6;
 if ($11) {
  HEAPF32[$9>>2] = $6;
 }
 $12 = ((($0)) + 40|0);
 $13 = +HEAPF32[$12>>2];
 $14 = $13 < $6;
 if ($14) {
  HEAPF32[$12>>2] = $6;
 }
 $15 = ((($0)) + 32|0);
 $16 = +HEAPF32[$15>>2];
 $17 = $16 > $7;
 if ($17) {
  HEAPF32[$15>>2] = $7;
 }
 $18 = ((($0)) + 44|0);
 $19 = +HEAPF32[$18>>2];
 $20 = $19 < $7;
 if ($20) {
  HEAPF32[$18>>2] = $7;
 }
 $21 = ((($0)) + 36|0);
 $22 = +HEAPF32[$21>>2];
 $23 = $22 > $8;
 if ($23) {
  HEAPF32[$21>>2] = $8;
 }
 $24 = ((($0)) + 48|0);
 $25 = +HEAPF32[$24>>2];
 $26 = $25 < $8;
 if (!($26)) {
  return;
 }
 HEAPF32[$24>>2] = $8;
 return;
}
function __ZN12ComputeBound6vertexEdd($0,$1,$2) {
 $0 = $0|0;
 $1 = +$1;
 $2 = +$2;
 var $10 = 0, $11 = 0, $12 = 0.0, $13 = 0, $14 = 0, $15 = 0.0, $16 = 0, $17 = 0, $18 = 0.0, $19 = 0, $20 = 0, $21 = 0.0, $22 = 0, $3 = 0.0, $4 = 0.0, $5 = 0, $6 = 0.0, $7 = 0, $8 = 0, $9 = 0.0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $3 = $1;
 $4 = $2;
 $5 = ((($0)) + 28|0);
 $6 = +HEAPF32[$5>>2];
 $7 = $6 > $3;
 if ($7) {
  HEAPF32[$5>>2] = $3;
 }
 $8 = ((($0)) + 40|0);
 $9 = +HEAPF32[$8>>2];
 $10 = $9 < $3;
 if ($10) {
  HEAPF32[$8>>2] = $3;
 }
 $11 = ((($0)) + 32|0);
 $12 = +HEAPF32[$11>>2];
 $13 = $12 > $4;
 if ($13) {
  HEAPF32[$11>>2] = $4;
 }
 $14 = ((($0)) + 44|0);
 $15 = +HEAPF32[$14>>2];
 $16 = $15 < $4;
 if ($16) {
  HEAPF32[$14>>2] = $4;
 }
 $17 = ((($0)) + 36|0);
 $18 = +HEAPF32[$17>>2];
 $19 = $18 > 1.0;
 if ($19) {
  HEAPF32[$17>>2] = 1.0;
 }
 $20 = ((($0)) + 48|0);
 $21 = +HEAPF32[$20>>2];
 $22 = $21 < 1.0;
 if (!($22)) {
  return;
 }
 HEAPF32[$20>>2] = 1.0;
 return;
}
function __ZN12ComputeBound6vertexEddd($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = +$1;
 $2 = +$2;
 $3 = +$3;
 var $10 = 0, $11 = 0.0, $12 = 0, $13 = 0, $14 = 0.0, $15 = 0, $16 = 0, $17 = 0.0, $18 = 0, $19 = 0, $20 = 0.0, $21 = 0, $22 = 0, $23 = 0.0, $24 = 0, $4 = 0.0, $5 = 0.0, $6 = 0.0, $7 = 0, $8 = 0.0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = $1;
 $5 = $2;
 $6 = $3;
 $7 = ((($0)) + 28|0);
 $8 = +HEAPF32[$7>>2];
 $9 = $8 > $4;
 if ($9) {
  HEAPF32[$7>>2] = $4;
 }
 $10 = ((($0)) + 40|0);
 $11 = +HEAPF32[$10>>2];
 $12 = $11 < $4;
 if ($12) {
  HEAPF32[$10>>2] = $4;
 }
 $13 = ((($0)) + 32|0);
 $14 = +HEAPF32[$13>>2];
 $15 = $14 > $5;
 if ($15) {
  HEAPF32[$13>>2] = $5;
 }
 $16 = ((($0)) + 44|0);
 $17 = +HEAPF32[$16>>2];
 $18 = $17 < $5;
 if ($18) {
  HEAPF32[$16>>2] = $5;
 }
 $19 = ((($0)) + 36|0);
 $20 = +HEAPF32[$19>>2];
 $21 = $20 > $6;
 if ($21) {
  HEAPF32[$19>>2] = $6;
 }
 $22 = ((($0)) + 48|0);
 $23 = +HEAPF32[$22>>2];
 $24 = $23 < $6;
 if (!($24)) {
  return;
 }
 HEAPF32[$22>>2] = $6;
 return;
}
function __ZN12ComputeBound6vertexEdddd($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = +$1;
 $2 = +$2;
 $3 = +$3;
 $4 = +$4;
 var $10 = 0.0, $11 = 0.0, $12 = 0, $13 = 0.0, $14 = 0, $15 = 0, $16 = 0.0, $17 = 0, $18 = 0, $19 = 0.0, $20 = 0, $21 = 0, $22 = 0.0, $23 = 0, $24 = 0, $25 = 0.0, $26 = 0, $27 = 0, $28 = 0.0, $29 = 0;
 var $5 = 0, $6 = 0.0, $7 = 0.0, $8 = 0.0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = $4 != 0.0;
 if (!($5)) {
  return;
 }
 $6 = $1 / $4;
 $7 = $6;
 $8 = $2 / $4;
 $9 = $8;
 $10 = $3 / $4;
 $11 = $10;
 $12 = ((($0)) + 28|0);
 $13 = +HEAPF32[$12>>2];
 $14 = $13 > $7;
 if ($14) {
  HEAPF32[$12>>2] = $7;
 }
 $15 = ((($0)) + 40|0);
 $16 = +HEAPF32[$15>>2];
 $17 = $16 < $7;
 if ($17) {
  HEAPF32[$15>>2] = $7;
 }
 $18 = ((($0)) + 32|0);
 $19 = +HEAPF32[$18>>2];
 $20 = $19 > $9;
 if ($20) {
  HEAPF32[$18>>2] = $9;
 }
 $21 = ((($0)) + 44|0);
 $22 = +HEAPF32[$21>>2];
 $23 = $22 < $9;
 if ($23) {
  HEAPF32[$21>>2] = $9;
 }
 $24 = ((($0)) + 36|0);
 $25 = +HEAPF32[$24>>2];
 $26 = $25 > $11;
 if ($26) {
  HEAPF32[$24>>2] = $11;
 }
 $27 = ((($0)) + 48|0);
 $28 = +HEAPF32[$27>>2];
 $29 = $28 < $11;
 if (!($29)) {
  return;
 }
 HEAPF32[$27>>2] = $11;
 return;
}
function __ZN12ComputeBound3endEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN3osg11ContextData3getI18DisplayListManagerEEPT_v($0) {
 $0 = $0|0;
 var $$0$i$i = 0, $$0$ph$i$i = 0, $$014$i = 0, $$024$i$i = 0, $$025$i$i = 0, $$025$i53$i = 0, $$037$i = 0, $$03752$i = 0, $$in$i$i = 0, $$pre$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 36|0);
 $2 = ((($0)) + 40|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 do {
  if ($4) {
   $$025$i$i = $2;$$037$i = $2;$15 = $3;
   label = 12;
  } else {
   $5 = ((($0)) + 40|0);
   $$0$i$i = $5;$$024$i$i = $3;$51 = $3;
   while(1) {
    $6 = ((($$024$i$i)) + 16|0);
    $7 = HEAP32[$6>>2]|0;
    $8 = ($7>>>0)>(24504>>>0);
    if ($8) {
     $9 = HEAP32[$$024$i$i>>2]|0;
     $10 = ($9|0)==(0|0);
     if ($10) {
      label = 6;
      break;
     } else {
      $$0$ph$i$i = $$024$i$i;$$in$i$i = $9;
     }
    } else {
     $11 = ($7>>>0)<(24504>>>0);
     if (!($11)) {
      label = 10;
      break;
     }
     $12 = ((($$024$i$i)) + 4|0);
     $13 = HEAP32[$12>>2]|0;
     $14 = ($13|0)==(0|0);
     if ($14) {
      label = 9;
      break;
     } else {
      $$0$ph$i$i = $12;$$in$i$i = $13;
     }
    }
    $$0$i$i = $$0$ph$i$i;$$024$i$i = $$in$i$i;$51 = $$in$i$i;
   }
   if ((label|0) == 6) {
    $$025$i53$i = $$024$i$i;$$03752$i = $$024$i$i;
    label = 13;
    break;
   }
   else if ((label|0) == 9) {
    $$025$i53$i = $12;$$03752$i = $$024$i$i;
    label = 13;
    break;
   }
   else if ((label|0) == 10) {
    $$025$i$i = $$0$i$i;$$037$i = $$024$i$i;$15 = $51;
    label = 12;
    break;
   }
  }
 } while(0);
 if ((label|0) == 12) {
  $16 = ($15|0)==(0|0);
  if ($16) {
   $$025$i53$i = $$025$i$i;$$03752$i = $$037$i;
   label = 13;
  } else {
   $$014$i = $15;
  }
 }
 if ((label|0) == 13) {
  $17 = (__Znwj(24)|0);
  $18 = ((($17)) + 16|0);
  HEAP32[$18>>2] = (24504);
  $19 = ((($17)) + 20|0);
  HEAP32[$19>>2] = 0;
  HEAP32[$17>>2] = 0;
  $20 = ((($17)) + 4|0);
  HEAP32[$20>>2] = 0;
  $21 = ((($17)) + 8|0);
  HEAP32[$21>>2] = $$03752$i;
  HEAP32[$$025$i53$i>>2] = $17;
  $22 = HEAP32[$1>>2]|0;
  $23 = HEAP32[$22>>2]|0;
  $24 = ($23|0)==(0|0);
  if ($24) {
   $28 = $17;
  } else {
   $25 = $23;
   HEAP32[$1>>2] = $25;
   $$pre$i$i = HEAP32[$$025$i53$i>>2]|0;
   $28 = $$pre$i$i;
  }
  $26 = ((($0)) + 40|0);
  $27 = HEAP32[$26>>2]|0;
  __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($27,$28);
  $29 = ((($0)) + 44|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (($30) + 1)|0;
  HEAP32[$29>>2] = $31;
  $$014$i = $17;
 }
 $32 = ((($$014$i)) + 20|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ($33|0)==(0|0);
 if (!($34)) {
  $50 = HEAP32[$32>>2]|0;
  return ($50|0);
 }
 $35 = (__Znwj(64)|0);
 $36 = ((($0)) + 24|0);
 $37 = HEAP32[$36>>2]|0;
 __THREW__ = 0;
 invoke_vii(3753,($35|0),($37|0));
 $38 = __THREW__; __THREW__ = 0;
 $39 = $38&1;
 if ($39) {
  $48 = ___cxa_find_matching_catch_2()|0;
  $49 = tempRet0;
  __ZdlPv($35);
  ___resumeException($48|0);
  // unreachable;
 }
 $40 = HEAP32[$32>>2]|0;
 $41 = ($40|0)==($35|0);
 if ($41) {
  $50 = HEAP32[$32>>2]|0;
  return ($50|0);
 }
 HEAP32[$32>>2] = $35;
 $42 = ((($35)) + 8|0);
 $43 = HEAP32[$42>>2]|0;HEAP32[$42>>2] = (($43+1)|0);
 $44 = ($40|0)==(0|0);
 if ($44) {
  $50 = HEAP32[$32>>2]|0;
  return ($50|0);
 }
 $45 = ((($40)) + 8|0);
 $46 = HEAP32[$45>>2]|0;HEAP32[$45>>2] = (($46-1)|0);
 $47 = ($46|0)==(1);
 if (!($47)) {
  $50 = HEAP32[$32>>2]|0;
  return ($50|0);
 }
 __ZNK3osg10Referenced24signalObserversAndDeleteEbb($40,1,1);
 $50 = HEAP32[$32>>2]|0;
 return ($50|0);
}
function __ZN18DisplayListManager17deleteDisplayListEjj($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
 if (!($4)) {
  STACKTOP = sp;return;
 }
 $5 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
 $6 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($5,126476,57)|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($7)) + -12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($6) + ($9)|0);
 __ZNKSt3__28ios_base6getlocEv($3,$10);
 __THREW__ = 0;
 $11 = (invoke_iii(3255,($3|0),(215188|0))|0);
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if (!($13)) {
  $14 = HEAP32[$11>>2]|0;
  $15 = ((($14)) + 28|0);
  $16 = HEAP32[$15>>2]|0;
  __THREW__ = 0;
  $17 = (invoke_iii($16|0,($11|0),10)|0);
  $18 = __THREW__; __THREW__ = 0;
  $19 = $18&1;
  if (!($19)) {
   __ZNSt3__26localeD2Ev($3);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($6,$17)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($6)|0);
   STACKTOP = sp;return;
  }
 }
 $20 = ___cxa_find_matching_catch_2()|0;
 $21 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($3|0));
 $22 = __THREW__; __THREW__ = 0;
 $23 = $22&1;
 if ($23) {
  $24 = ___cxa_find_matching_catch_3(0|0)|0;
  $25 = tempRet0;
  ___clang_call_terminate($24);
  // unreachable;
 } else {
  ___resumeException($20|0);
  // unreachable;
 }
}
function __ZNSt3__26vectorIN3osg7ref_ptrINS1_16VertexArrayStateEEENS_9allocatorIS4_EEE8__appendEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$06$i$i = 0, $$pre = 0, $$pre$i = 0, $$promoted4$i = 0, $$sroa$7$0 = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i = 0, $scevgep$i15 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) - ($5))|0;
 $7 = $6 >> 2;
 $8 = ($7>>>0)<($1>>>0);
 $9 = $5;
 if (!($8)) {
  $$promoted4$i = $5;
  $10 = $1 << 2;
  _memset(($$promoted4$i|0),0,($10|0))|0;
  $scevgep$i = (($9) + ($1<<2)|0);
  HEAP32[$4>>2] = $scevgep$i;
  return;
 }
 $11 = HEAP32[$0>>2]|0;
 $12 = (($5) - ($11))|0;
 $13 = $12 >> 2;
 $14 = (($13) + ($1))|0;
 $15 = ($14>>>0)>(1073741823);
 $16 = $11;
 if ($15) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $17 = (($3) - ($11))|0;
 $18 = $17 >> 2;
 $19 = ($18>>>0)<(536870911);
 $20 = $17 >> 1;
 $21 = ($20>>>0)<($14>>>0);
 $$sroa$speculated$i = $21 ? $14 : $20;
 $$sroa$speculated$$i = $19 ? $$sroa$speculated$i : 1073741823;
 $22 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($22) {
   $32 = 0;
  } else {
   $23 = ($$sroa$speculated$$i>>>0)>(1073741823);
   if (!($23)) {
    $29 = $$sroa$speculated$$i << 2;
    $30 = (__Znwj($29)|0);
    $32 = $30;
    break;
   }
   $24 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($24|0),(204840|0));
   $25 = __THREW__; __THREW__ = 0;
   $26 = $25&1;
   if ($26) {
    $27 = ___cxa_find_matching_catch_2()|0;
    $28 = tempRet0;
    ___cxa_free_exception(($24|0));
    ___resumeException($27|0);
    // unreachable;
   } else {
    HEAP32[$24>>2] = (99824);
    ___cxa_throw(($24|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $31 = (($32) + ($13<<2)|0);
 $33 = $31;
 $34 = (($32) + ($$sroa$speculated$$i<<2)|0);
 $35 = $34;
 $36 = $1 << 2;
 _memset(($31|0),0,($36|0))|0;
 $scevgep$i15 = (($31) + ($1<<2)|0);
 $37 = $scevgep$i15;
 $38 = ($9|0)==($16|0);
 if ($38) {
  $50 = $33;$51 = $5;$53 = $9;
 } else {
  $$06$i$i = $9;$$sroa$7$0 = $33;$41 = $31;
  while(1) {
   $39 = ((($$06$i$i)) + -4|0);
   $40 = ((($41)) + -4|0);
   $42 = HEAP32[$39>>2]|0;
   HEAP32[$40>>2] = $42;
   $43 = ($42|0)==(0|0);
   if (!($43)) {
    $44 = ((($42)) + 8|0);
    $45 = HEAP32[$44>>2]|0;HEAP32[$44>>2] = (($45+1)|0);
   }
   $46 = $$sroa$7$0;
   $47 = ((($46)) + -4|0);
   $48 = $47;
   $49 = ($39|0)==($16|0);
   if ($49) {
    break;
   } else {
    $$06$i$i = $39;$$sroa$7$0 = $48;$41 = $47;
   }
  }
  $$pre$i = HEAP32[$0>>2]|0;
  $$pre = HEAP32[$4>>2]|0;
  $50 = $48;$51 = $$pre$i;$53 = $$pre;
 }
 HEAP32[$0>>2] = $50;
 HEAP32[$4>>2] = $37;
 HEAP32[$2>>2] = $35;
 $52 = $51;
 $54 = ($53|0)==($52|0);
 L25: do {
  if (!($54)) {
   $56 = $53;
   while(1) {
    $55 = ((($56)) + -4|0);
    $57 = HEAP32[$55>>2]|0;
    $58 = ($57|0)==(0|0);
    if (!($58)) {
     $59 = ((($57)) + 8|0);
     $60 = HEAP32[$59>>2]|0;HEAP32[$59>>2] = (($60-1)|0);
     $61 = ($60|0)==(1);
     if ($61) {
      __THREW__ = 0;
      invoke_viii(3262,($57|0),1,1);
      $62 = __THREW__; __THREW__ = 0;
      $63 = $62&1;
      if ($63) {
       break;
      }
     }
    }
    HEAP32[$55>>2] = 0;
    $64 = ($55|0)==($52|0);
    if ($64) {
     break L25;
    } else {
     $56 = $55;
    }
   }
   $65 = ___cxa_find_matching_catch_2()|0;
   $66 = tempRet0;
   ___cxa_call_unexpected(($65|0));
   // unreachable;
  }
 } while(0);
 $67 = ($51|0)==(0);
 if ($67) {
  return;
 }
 $68 = $51;
 __ZdlPv($68);
 return;
}
function __ZN18DisplayListManagerC2Ej($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$1 = 0, $$14 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = (__Znwj(32)|0);
 HEAP32[$2>>2] = $3;
 $4 = ((($2)) + 8|0);
 HEAP32[$4>>2] = -2147483616;
 $5 = ((($2)) + 4|0);
 HEAP32[$5>>2] = 18;
 dest=$3; src=126534; stop=dest+18|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $6 = ((($3)) + 18|0);
 HEAP8[$6>>0] = 0;
 __THREW__ = 0;
 invoke_viii(3719,($0|0),($2|0),($1|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $23 = ___cxa_find_matching_catch_2()|0;
  $24 = tempRet0;
  $25 = ((($2)) + 11|0);
  $26 = HEAP8[$25>>0]|0;
  $27 = ($26<<24>>24)<(0);
  if ($27) {
   $28 = HEAP32[$2>>2]|0;
   __ZdlPv($28);
  }
  $$1 = $24;$$14 = $23;
  ___resumeException($$14|0);
  // unreachable;
 }
 $9 = ((($2)) + 11|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = ($10<<24>>24)<(0);
 if ($11) {
  $12 = HEAP32[$2>>2]|0;
  __ZdlPv($12);
 }
 HEAP32[$0>>2] = (58732);
 $13 = ((($0)) + 28|0);
 HEAP32[$13>>2] = 0;
 $14 = ((($0)) + 32|0);
 HEAP32[$14>>2] = 0;
 $15 = ((($0)) + 36|0);
 HEAP32[$15>>2] = 0;
 $16 = ((($0)) + 40|0);
 __THREW__ = 0;
 invoke_vii(3507,($16|0),0);
 $17 = __THREW__; __THREW__ = 0;
 $18 = $17&1;
 if (!($18)) {
  $19 = ((($0)) + 56|0);
  HEAP32[$19>>2] = 0;
  $20 = ((($0)) + 60|0);
  HEAP32[$20>>2] = 0;
  $21 = ((($0)) + 56|0);
  $22 = ((($0)) + 52|0);
  HEAP32[$22>>2] = $21;
  STACKTOP = sp;return;
 }
 $29 = ___cxa_find_matching_catch_2()|0;
 $30 = tempRet0;
 __THREW__ = 0;
 invoke_vi(1861,($0|0));
 $31 = __THREW__; __THREW__ = 0;
 $32 = $31&1;
 if ($32) {
  $33 = ___cxa_find_matching_catch_3(0|0)|0;
  $34 = tempRet0;
  ___clang_call_terminate($33);
  // unreachable;
 } else {
  $$1 = $30;$$14 = $29;
  ___resumeException($$14|0);
  // unreachable;
 }
}
function __ZN18DisplayListManagerD2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (58732);
 $1 = ((($0)) + 52|0);
 $2 = ((($0)) + 56|0);
 $3 = HEAP32[$2>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIjjEENS_19__map_value_compareIjS2_NS_4lessIjEELb1EEENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($1,$3);
 $4 = ((($0)) + 40|0);
 __THREW__ = 0;
 invoke_vi(707,($4|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if (!($6)) {
  __ZN3osg21GraphicsObjectManagerD2Ev($0);
  return;
 }
 $7 = ___cxa_find_matching_catch_2()|0;
 $8 = tempRet0;
 __THREW__ = 0;
 invoke_vi(1861,($0|0));
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if ($10) {
  $11 = ___cxa_find_matching_catch_3(0|0)|0;
  $12 = tempRet0;
  ___clang_call_terminate($11);
  // unreachable;
 } else {
  ___resumeException($7|0);
  // unreachable;
 }
}
function __ZN18DisplayListManagerD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (58732);
 $1 = ((($0)) + 52|0);
 $2 = ((($0)) + 56|0);
 $3 = HEAP32[$2>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIjjEENS_19__map_value_compareIjS2_NS_4lessIjEELb1EEENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($1,$3);
 $4 = ((($0)) + 40|0);
 __THREW__ = 0;
 invoke_vi(707,($4|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $9 = ___cxa_find_matching_catch_2()|0;
  $10 = tempRet0;
  __THREW__ = 0;
  invoke_vi(1861,($0|0));
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if ($12) {
   $13 = ___cxa_find_matching_catch_3(0|0)|0;
   $14 = tempRet0;
   ___clang_call_terminate($13);
   // unreachable;
  } else {
   $eh$lpad$body$index2Z2D = $10;$eh$lpad$body$indexZ2D = $9;
   __ZdlPv($0);
   ___resumeException($eh$lpad$body$indexZ2D|0);
   // unreachable;
  }
 }
 __THREW__ = 0;
 invoke_vi(1861,($0|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if (!($8)) {
  __ZdlPv($0);
  return;
 }
 $15 = ___cxa_find_matching_catch_2()|0;
 $16 = tempRet0;
 $eh$lpad$body$index2Z2D = $16;$eh$lpad$body$indexZ2D = $15;
 __ZdlPv($0);
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
}
function __ZN3osg21GraphicsObjectManager8newFrameEPNS_10FrameStampE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN3osg21GraphicsObjectManager10resetStatsEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN3osg21GraphicsObjectManager11reportStatsERNSt3__213basic_ostreamIcNS1_11char_traitsIcEEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZNK3osg21GraphicsObjectManager14recomputeStatsERNSt3__213basic_ostreamIcNS1_11char_traitsIcEEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN18DisplayListManager21flushDeletedGLObjectsEdRd($0,$1,$2) {
 $0 = $0|0;
 $1 = +$1;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
 if (!($4)) {
  STACKTOP = sp;return;
 }
 $5 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
 $6 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($5,126622,64)|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($7)) + -12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($6) + ($9)|0);
 __ZNKSt3__28ios_base6getlocEv($3,$10);
 __THREW__ = 0;
 $11 = (invoke_iii(3255,($3|0),(215188|0))|0);
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if (!($13)) {
  $14 = HEAP32[$11>>2]|0;
  $15 = ((($14)) + 28|0);
  $16 = HEAP32[$15>>2]|0;
  __THREW__ = 0;
  $17 = (invoke_iii($16|0,($11|0),10)|0);
  $18 = __THREW__; __THREW__ = 0;
  $19 = $18&1;
  if (!($19)) {
   __ZNSt3__26localeD2Ev($3);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($6,$17)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($6)|0);
   STACKTOP = sp;return;
  }
 }
 $20 = ___cxa_find_matching_catch_2()|0;
 $21 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($3|0));
 $22 = __THREW__; __THREW__ = 0;
 $23 = $22&1;
 if ($23) {
  $24 = ___cxa_find_matching_catch_3(0|0)|0;
  $25 = tempRet0;
  ___clang_call_terminate($24);
  // unreachable;
 } else {
  ___resumeException($20|0);
  // unreachable;
 }
}
function __ZN18DisplayListManager24flushAllDeletedGLObjectsEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $2 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 $3 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
 $4 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($3,126476,57)|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($5)) + -12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($4) + ($7)|0);
 __ZNKSt3__28ios_base6getlocEv($1,$8);
 __THREW__ = 0;
 $9 = (invoke_iii(3255,($1|0),(215188|0))|0);
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if (!($11)) {
  $12 = HEAP32[$9>>2]|0;
  $13 = ((($12)) + 28|0);
  $14 = HEAP32[$13>>2]|0;
  __THREW__ = 0;
  $15 = (invoke_iii($14|0,($9|0),10)|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __ZNSt3__26localeD2Ev($1);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($4,$15)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($4)|0);
   STACKTOP = sp;return;
  }
 }
 $18 = ___cxa_find_matching_catch_2()|0;
 $19 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($1|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if ($21) {
  $22 = ___cxa_find_matching_catch_3(0|0)|0;
  $23 = tempRet0;
  ___clang_call_terminate($22);
  // unreachable;
 } else {
  ___resumeException($18|0);
  // unreachable;
 }
}
function __ZN18DisplayListManager18deleteAllGLObjectsEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $2 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 $3 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
 $4 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($3,126553,68)|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($5)) + -12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($4) + ($7)|0);
 __ZNKSt3__28ios_base6getlocEv($1,$8);
 __THREW__ = 0;
 $9 = (invoke_iii(3255,($1|0),(215188|0))|0);
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if (!($11)) {
  $12 = HEAP32[$9>>2]|0;
  $13 = ((($12)) + 28|0);
  $14 = HEAP32[$13>>2]|0;
  __THREW__ = 0;
  $15 = (invoke_iii($14|0,($9|0),10)|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __ZNSt3__26localeD2Ev($1);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($4,$15)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($4)|0);
   STACKTOP = sp;return;
  }
 }
 $18 = ___cxa_find_matching_catch_2()|0;
 $19 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($1|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if ($21) {
  $22 = ___cxa_find_matching_catch_3(0|0)|0;
  $23 = tempRet0;
  ___clang_call_terminate($22);
  // unreachable;
 } else {
  ___resumeException($18|0);
  // unreachable;
 }
}
function __ZN18DisplayListManager19discardAllGLObjectsEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 40|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 (FUNCTION_TABLE_ii[$4 & 8191]($1)|0);
 $5 = ((($0)) + 52|0);
 $6 = ((($0)) + 56|0);
 $7 = HEAP32[$6>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIjjEENS_19__map_value_compareIjS2_NS_4lessIjEELb1EEENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($5,$7);
 $8 = ((($0)) + 60|0);
 HEAP32[$8>>2] = 0;
 HEAP32[$5>>2] = $6;
 HEAP32[$6>>2] = 0;
 $9 = HEAP32[$1>>2]|0;
 $10 = ((($9)) + 12|0);
 $11 = HEAP32[$10>>2]|0;
 (FUNCTION_TABLE_ii[$11 & 8191]($1)|0);
 return;
}
function __ZN3osg8DrawableC2ERKS0_RKNS_6CopyOpE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$1 = 0, $$118 = 0, $$2 = 0, $$219 = 0, $$3 = 0, $$320 = 0, $$pre$i$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index3Z2D = 0, $eh$lpad$body$indexZ2D = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i$i$i$i = 0, $scevgep5$i$i$i$i = 0, $scevgep5$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg4NodeC2ERKS0_RKNS_6CopyOpE($0,$1,$2);
 HEAP32[$0>>2] = (58336);
 $3 = ((($0)) + 124|0);
 $4 = ((($1)) + 124|0);
 ;HEAP32[$3>>2]=HEAP32[$4>>2]|0;HEAP32[$3+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$4+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$4+12>>2]|0;HEAP32[$3+16>>2]=HEAP32[$4+16>>2]|0;HEAP32[$3+20>>2]=HEAP32[$4+20>>2]|0;
 $5 = ((($0)) + 148|0);
 $6 = ((($1)) + 148|0);
 $7 = HEAP32[$6>>2]|0;
 HEAP32[$5>>2] = $7;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = ((($7)) + 8|0);
  $10 = HEAP32[$9>>2]|0;HEAP32[$9>>2] = (($10+1)|0);
 }
 $11 = ((($0)) + 152|0);
 $12 = ((($1)) + 152|0);
 ;HEAP32[$11>>2]=HEAP32[$12>>2]|0;HEAP32[$11+4>>2]=HEAP32[$12+4>>2]|0;HEAP32[$11+8>>2]=HEAP32[$12+8>>2]|0;HEAP32[$11+12>>2]=HEAP32[$12+12>>2]|0;HEAP32[$11+16>>2]=HEAP32[$12+16>>2]|0;HEAP32[$11+20>>2]=HEAP32[$12+20>>2]|0;
 $13 = HEAP32[$2>>2]|0;
 $14 = ((($13)) + 48|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ((($1)) + 176|0);
 $17 = HEAP32[$16>>2]|0;
 __THREW__ = 0;
 $18 = (invoke_iii($15|0,($2|0),($17|0))|0);
 $19 = __THREW__; __THREW__ = 0;
 $20 = $19&1;
 if ($20) {
  $100 = ___cxa_find_matching_catch_2()|0;
  $101 = tempRet0;
  $$3 = $101;$$320 = $100;
 } else {
  $21 = ((($0)) + 176|0);
  HEAP32[$21>>2] = $18;
  $22 = ($18|0)==(0|0);
  if (!($22)) {
   $23 = ((($18)) + 8|0);
   $24 = HEAP32[$23>>2]|0;HEAP32[$23>>2] = (($24+1)|0);
  }
  $25 = ((($0)) + 180|0);
  $26 = ((($1)) + 180|0);
  $27 = HEAP8[$26>>0]|0;
  HEAP8[$25>>0] = $27;
  $28 = ((($0)) + 181|0);
  $29 = ((($1)) + 181|0);
  $30 = HEAP8[$29>>0]|0;
  HEAP8[$28>>0] = $30;
  $31 = ((($0)) + 182|0);
  $32 = ((($1)) + 182|0);
  $33 = HEAP8[$32>>0]|0;
  HEAP8[$31>>0] = $33;
  $34 = ((($0)) + 183|0);
  $35 = ((($1)) + 183|0);
  $36 = HEAP8[$35>>0]|0;
  HEAP8[$34>>0] = $36;
  $37 = ((($0)) + 184|0);
  $38 = ((($1)) + 184|0);
  $39 = HEAP8[$38>>0]|0;
  HEAP8[$37>>0] = $39;
  $40 = ((($0)) + 188|0);
  __THREW__ = 0;
  $41 = (invoke_i(3285)|0);
  $42 = __THREW__; __THREW__ = 0;
  $43 = $42&1;
  L10: do {
   if ($43) {
    label = 26;
   } else {
    $44 = HEAP32[$41>>2]|0;
    __THREW__ = 0;
    $45 = (invoke_ii(3286,($44|0))|0);
    $46 = __THREW__; __THREW__ = 0;
    $47 = $46&1;
    if ($47) {
     label = 26;
    } else {
     HEAP32[$40>>2] = 0;
     $48 = ((($0)) + 192|0);
     HEAP32[$48>>2] = 0;
     $49 = ((($0)) + 196|0);
     HEAP32[$49>>2] = 0;
     $50 = ($45|0)==(0);
     do {
      if (!($50)) {
       $51 = ($45>>>0)>(1073741823);
       if ($51) {
        __THREW__ = 0;
        invoke_vi(3307,($40|0));
        $52 = __THREW__; __THREW__ = 0;
       } else {
        $53 = $45 << 2;
        __THREW__ = 0;
        $54 = (invoke_ii(3276,($53|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if (!($56)) {
         HEAP32[$40>>2] = $54;
         $57 = (($54) + ($45<<2)|0);
         $58 = ((($0)) + 196|0);
         HEAP32[$58>>2] = $57;
         _memset(($54|0),0,($53|0))|0;
         HEAP32[$48>>2] = $57;
         break;
        }
       }
       $59 = ___cxa_find_matching_catch_2()|0;
       $60 = tempRet0;
       $61 = HEAP32[$40>>2]|0;
       $62 = ($61|0)==(0|0);
       if ($62) {
        $eh$lpad$body$index3Z2D = $60;$eh$lpad$body$indexZ2D = $59;
        label = 27;
        break L10;
       }
       $63 = HEAP32[$48>>2]|0;
       $64 = ($63|0)==($61|0);
       if (!($64)) {
        $scevgep$i$i$i$i$i = ((($63)) + -4|0);
        $65 = $scevgep$i$i$i$i$i;
        $66 = $61;
        $67 = (($65) - ($66))|0;
        $68 = $67 >>> 2;
        $69 = $68 ^ -1;
        $scevgep5$i$i$i$i$i = (($63) + ($69<<2)|0);
        HEAP32[$48>>2] = $scevgep5$i$i$i$i$i;
       }
       __ZdlPv($61);
       $eh$lpad$body$index3Z2D = $60;$eh$lpad$body$indexZ2D = $59;
       label = 27;
       break L10;
      }
     } while(0);
     $70 = ((($0)) + 200|0);
     __THREW__ = 0;
     $71 = (invoke_i(3285)|0);
     $72 = __THREW__; __THREW__ = 0;
     $73 = $72&1;
     if ($73) {
      label = 28;
     } else {
      $74 = HEAP32[$71>>2]|0;
      __THREW__ = 0;
      $75 = (invoke_ii(3286,($74|0))|0);
      $76 = __THREW__; __THREW__ = 0;
      $77 = $76&1;
      if ($77) {
       label = 28;
      } else {
       __THREW__ = 0;
       invoke_vii(3754,($70|0),($75|0));
       $78 = __THREW__; __THREW__ = 0;
       $79 = $78&1;
       if ($79) {
        label = 28;
       } else {
        $80 = ((($0)) + 212|0);
        $81 = ((($1)) + 212|0);
        $82 = HEAP32[$81>>2]|0;
        HEAP32[$80>>2] = $82;
        $83 = ($82|0)==(0|0);
        if (!($83)) {
         $84 = HEAP32[$82>>2]|0;
         $85 = ((($84)) + -12|0);
         $86 = HEAP32[$85>>2]|0;
         $87 = (($82) + ($86)|0);
         $88 = ((($87)) + 8|0);
         $89 = HEAP32[$88>>2]|0;HEAP32[$88>>2] = (($89+1)|0);
        }
        $90 = HEAP32[$2>>2]|0;
        $91 = ((($90)) + 24|0);
        $92 = HEAP32[$91>>2]|0;
        $93 = ((($1)) + 120|0);
        $94 = HEAP32[$93>>2]|0;
        __THREW__ = 0;
        $95 = (invoke_iii($92|0,($2|0),($94|0))|0);
        $96 = __THREW__; __THREW__ = 0;
        $97 = $96&1;
        if (!($97)) {
         __THREW__ = 0;
         invoke_vii(3726,($0|0),($95|0));
         $98 = __THREW__; __THREW__ = 0;
         $99 = $98&1;
         if (!($99)) {
          return;
         }
        }
        $106 = ___cxa_find_matching_catch_2()|0;
        $107 = tempRet0;
        $108 = HEAP32[$80>>2]|0;
        $109 = ($108|0)==(0|0);
        if (!($109)) {
         $110 = HEAP32[$108>>2]|0;
         $111 = ((($110)) + -12|0);
         $112 = HEAP32[$111>>2]|0;
         $113 = (($108) + ($112)|0);
         $114 = ((($113)) + 8|0);
         $115 = HEAP32[$114>>2]|0;HEAP32[$114>>2] = (($115-1)|0);
         $116 = ($115|0)==(1);
         if ($116) {
          __THREW__ = 0;
          invoke_viii(3262,($113|0),1,1);
          $117 = __THREW__; __THREW__ = 0;
          $118 = $117&1;
          if ($118) {
           $163 = ___cxa_find_matching_catch_3(0|0)|0;
           $164 = tempRet0;
           ___clang_call_terminate($163);
           // unreachable;
          }
         }
        }
        HEAP32[$80>>2] = 0;
        $119 = HEAP32[$70>>2]|0;
        $120 = ($119|0)==(0|0);
        if ($120) {
         $$1 = $107;$$118 = $106;
        } else {
         $121 = ((($0)) + 204|0);
         $122 = HEAP32[$121>>2]|0;
         $123 = ($122|0)==($119|0);
         do {
          if ($123) {
           $137 = $119;
          } else {
           $125 = $122;
           L43: while(1) {
            $124 = ((($125)) + -4|0);
            HEAP32[$121>>2] = $124;
            $126 = HEAP32[$124>>2]|0;
            $127 = ($126|0)==(0|0);
            do {
             if (!($127)) {
              $128 = ((($126)) + 8|0);
              $129 = HEAP32[$128>>2]|0;HEAP32[$128>>2] = (($129-1)|0);
              $130 = ($129|0)==(1);
              if (!($130)) {
               break;
              }
              __THREW__ = 0;
              invoke_viii(3262,($126|0),1,1);
              $131 = __THREW__; __THREW__ = 0;
              $132 = $131&1;
              if ($132) {
               label = 38;
               break L43;
              }
             }
            } while(0);
            HEAP32[$124>>2] = 0;
            $133 = HEAP32[$121>>2]|0;
            $134 = ($133|0)==($119|0);
            if ($134) {
             label = 39;
             break;
            } else {
             $125 = $133;
            }
           }
           if ((label|0) == 38) {
            $135 = ___cxa_find_matching_catch_2()|0;
            $136 = tempRet0;
            ___cxa_call_unexpected(($135|0));
            // unreachable;
           }
           else if ((label|0) == 39) {
            $$pre$i$i = HEAP32[$70>>2]|0;
            $137 = $$pre$i$i;
            break;
           }
          }
         } while(0);
         __ZdlPv($137);
         $$1 = $107;$$118 = $106;
        }
       }
      }
     }
     if ((label|0) == 28) {
      $104 = ___cxa_find_matching_catch_2()|0;
      $105 = tempRet0;
      $$1 = $105;$$118 = $104;
     }
     $138 = HEAP32[$40>>2]|0;
     $139 = ($138|0)==(0|0);
     if ($139) {
      $$2 = $$1;$$219 = $$118;
     } else {
      $140 = HEAP32[$48>>2]|0;
      $141 = ($140|0)==($138|0);
      if (!($141)) {
       $scevgep$i$i$i$i = ((($140)) + -4|0);
       $142 = $scevgep$i$i$i$i;
       $143 = $138;
       $144 = (($142) - ($143))|0;
       $145 = $144 >>> 2;
       $146 = $145 ^ -1;
       $scevgep5$i$i$i$i = (($140) + ($146<<2)|0);
       HEAP32[$48>>2] = $scevgep5$i$i$i$i;
      }
      __ZdlPv($138);
      $$2 = $$1;$$219 = $$118;
     }
    }
   }
  } while(0);
  if ((label|0) == 26) {
   $102 = ___cxa_find_matching_catch_2()|0;
   $103 = tempRet0;
   $eh$lpad$body$index3Z2D = $103;$eh$lpad$body$indexZ2D = $102;
   label = 27;
  }
  if ((label|0) == 27) {
   $$2 = $eh$lpad$body$index3Z2D;$$219 = $eh$lpad$body$indexZ2D;
  }
  $147 = HEAP32[$21>>2]|0;
  $148 = ($147|0)==(0|0);
  if (!($148)) {
   $149 = ((($147)) + 8|0);
   $150 = HEAP32[$149>>2]|0;HEAP32[$149>>2] = (($150-1)|0);
   $151 = ($150|0)==(1);
   if ($151) {
    __THREW__ = 0;
    invoke_viii(3262,($147|0),1,1);
    $152 = __THREW__; __THREW__ = 0;
    $153 = $152&1;
    if ($153) {
     $163 = ___cxa_find_matching_catch_3(0|0)|0;
     $164 = tempRet0;
     ___clang_call_terminate($163);
     // unreachable;
    }
   }
  }
  HEAP32[$21>>2] = 0;
  $$3 = $$2;$$320 = $$219;
 }
 $154 = HEAP32[$5>>2]|0;
 $155 = ($154|0)==(0|0);
 if (!($155)) {
  $156 = ((($154)) + 8|0);
  $157 = HEAP32[$156>>2]|0;HEAP32[$156>>2] = (($157-1)|0);
  $158 = ($157|0)==(1);
  if ($158) {
   __THREW__ = 0;
   invoke_viii(3262,($154|0),1,1);
   $159 = __THREW__; __THREW__ = 0;
   $160 = $159&1;
   if ($160) {
    $163 = ___cxa_find_matching_catch_3(0|0)|0;
    $164 = tempRet0;
    ___clang_call_terminate($163);
    // unreachable;
   }
  }
 }
 HEAP32[$5>>2] = 0;
 __THREW__ = 0;
 invoke_vi(2026,($0|0));
 $161 = __THREW__; __THREW__ = 0;
 $162 = $161&1;
 if ($162) {
  $163 = ___cxa_find_matching_catch_3(0|0)|0;
  $164 = tempRet0;
  ___clang_call_terminate($163);
  // unreachable;
 } else {
  ___resumeException($$320|0);
  // unreachable;
 }
}
function __ZNSt3__26vectorIN3osg7ref_ptrINS1_16VertexArrayStateEEENS_9allocatorIS4_EEEC2Ej($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$pre$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = 0;
 $2 = ((($0)) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = ((($0)) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = ($1|0)==(0);
 if ($4) {
  return;
 }
 $5 = ($1>>>0)>(1073741823);
 if ($5) {
  __THREW__ = 0;
  invoke_vi(3307,($0|0));
  $6 = __THREW__; __THREW__ = 0;
 } else {
  $7 = $1 << 2;
  __THREW__ = 0;
  $8 = (invoke_ii(3276,($7|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   HEAP32[$0>>2] = $8;
   $11 = (($8) + ($1<<2)|0);
   $12 = ((($0)) + 8|0);
   HEAP32[$12>>2] = $11;
   _memset(($8|0),0,($7|0))|0;
   HEAP32[$2>>2] = $11;
   return;
  }
 }
 $13 = ___cxa_find_matching_catch_2()|0;
 $14 = tempRet0;
 $15 = HEAP32[$0>>2]|0;
 $16 = ($15|0)==(0|0);
 if ($16) {
  ___resumeException($13|0);
  // unreachable;
 }
 $17 = HEAP32[$2>>2]|0;
 $18 = ($17|0)==($15|0);
 do {
  if ($18) {
   $32 = $15;
  } else {
   $20 = $17;
   while(1) {
    $19 = ((($20)) + -4|0);
    HEAP32[$2>>2] = $19;
    $21 = HEAP32[$19>>2]|0;
    $22 = ($21|0)==(0|0);
    if (!($22)) {
     $23 = ((($21)) + 8|0);
     $24 = HEAP32[$23>>2]|0;HEAP32[$23>>2] = (($24-1)|0);
     $25 = ($24|0)==(1);
     if ($25) {
      __THREW__ = 0;
      invoke_viii(3262,($21|0),1,1);
      $26 = __THREW__; __THREW__ = 0;
      $27 = $26&1;
      if ($27) {
       label = 12;
       break;
      }
     }
    }
    HEAP32[$19>>2] = 0;
    $28 = HEAP32[$2>>2]|0;
    $29 = ($28|0)==($15|0);
    if ($29) {
     label = 13;
     break;
    } else {
     $20 = $28;
    }
   }
   if ((label|0) == 12) {
    $30 = ___cxa_find_matching_catch_2()|0;
    $31 = tempRet0;
    ___cxa_call_unexpected(($30|0));
    // unreachable;
   }
   else if ((label|0) == 13) {
    $$pre$i = HEAP32[$0>>2]|0;
    $32 = $$pre$i;
    break;
   }
  }
 } while(0);
 __ZdlPv($32);
 ___resumeException($13|0);
 // unreachable;
}
function __ZN3osg8DrawableC2Ev($0) {
 $0 = $0|0;
 var $$0 = 0, $$02 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $eh$lpad$body$index3Z2D = 0, $eh$lpad$body$indexZ2D = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i$i$i$i = 0, $scevgep5$i$i$i$i = 0, $scevgep5$i$i$i$i$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 __ZN3osg4NodeC2Ev($0);
 HEAP32[$0>>2] = (58336);
 $1 = ((($0)) + 124|0);
 HEAPF32[$1>>2] = 3.4028234663852886E+38;
 $2 = ((($0)) + 128|0);
 HEAPF32[$2>>2] = 3.4028234663852886E+38;
 $3 = ((($0)) + 132|0);
 HEAPF32[$3>>2] = 3.4028234663852886E+38;
 $4 = ((($0)) + 136|0);
 HEAPF32[$4>>2] = -3.4028234663852886E+38;
 $5 = ((($0)) + 140|0);
 HEAPF32[$5>>2] = -3.4028234663852886E+38;
 $6 = ((($0)) + 144|0);
 HEAPF32[$6>>2] = -3.4028234663852886E+38;
 $7 = ((($0)) + 148|0);
 HEAP32[$7>>2] = 0;
 $8 = ((($0)) + 152|0);
 HEAPF32[$8>>2] = 3.4028234663852886E+38;
 $9 = ((($0)) + 156|0);
 HEAPF32[$9>>2] = 3.4028234663852886E+38;
 $10 = ((($0)) + 160|0);
 HEAPF32[$10>>2] = 3.4028234663852886E+38;
 $11 = ((($0)) + 164|0);
 HEAPF32[$11>>2] = -3.4028234663852886E+38;
 $12 = ((($0)) + 168|0);
 HEAPF32[$12>>2] = -3.4028234663852886E+38;
 $13 = ((($0)) + 172|0);
 HEAPF32[$13>>2] = -3.4028234663852886E+38;
 $14 = ((($0)) + 176|0);
 HEAP32[$14>>2] = 0;
 $15 = ((($0)) + 188|0);
 __THREW__ = 0;
 $16 = (invoke_i(3285)|0);
 $17 = __THREW__; __THREW__ = 0;
 $18 = $17&1;
 L1: do {
  if ($18) {
   label = 16;
  } else {
   $19 = HEAP32[$16>>2]|0;
   __THREW__ = 0;
   $20 = (invoke_ii(3286,($19|0))|0);
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if ($22) {
    label = 16;
   } else {
    HEAP32[$15>>2] = 0;
    $23 = ((($0)) + 192|0);
    HEAP32[$23>>2] = 0;
    $24 = ((($0)) + 196|0);
    HEAP32[$24>>2] = 0;
    $25 = ($20|0)==(0);
    do {
     if (!($25)) {
      $26 = ($20>>>0)>(1073741823);
      if ($26) {
       __THREW__ = 0;
       invoke_vi(3307,($15|0));
       $27 = __THREW__; __THREW__ = 0;
      } else {
       $28 = $20 << 2;
       __THREW__ = 0;
       $29 = (invoke_ii(3276,($28|0))|0);
       $30 = __THREW__; __THREW__ = 0;
       $31 = $30&1;
       if (!($31)) {
        HEAP32[$15>>2] = $29;
        $32 = (($29) + ($20<<2)|0);
        $33 = ((($0)) + 196|0);
        HEAP32[$33>>2] = $32;
        _memset(($29|0),0,($28|0))|0;
        HEAP32[$23>>2] = $32;
        break;
       }
      }
      $34 = ___cxa_find_matching_catch_2()|0;
      $35 = tempRet0;
      $36 = HEAP32[$15>>2]|0;
      $37 = ($36|0)==(0|0);
      if ($37) {
       $eh$lpad$body$index3Z2D = $35;$eh$lpad$body$indexZ2D = $34;
       label = 17;
       break L1;
      }
      $38 = HEAP32[$23>>2]|0;
      $39 = ($38|0)==($36|0);
      if (!($39)) {
       $scevgep$i$i$i$i$i = ((($38)) + -4|0);
       $40 = $scevgep$i$i$i$i$i;
       $41 = $36;
       $42 = (($40) - ($41))|0;
       $43 = $42 >>> 2;
       $44 = $43 ^ -1;
       $scevgep5$i$i$i$i$i = (($38) + ($44<<2)|0);
       HEAP32[$23>>2] = $scevgep5$i$i$i$i$i;
      }
      __ZdlPv($36);
      $eh$lpad$body$index3Z2D = $35;$eh$lpad$body$indexZ2D = $34;
      label = 17;
      break L1;
     }
    } while(0);
    $45 = ((($0)) + 200|0);
    __THREW__ = 0;
    $46 = (invoke_i(3285)|0);
    $47 = __THREW__; __THREW__ = 0;
    $48 = $47&1;
    if (!($48)) {
     $49 = HEAP32[$46>>2]|0;
     __THREW__ = 0;
     $50 = (invoke_ii(3286,($49|0))|0);
     $51 = __THREW__; __THREW__ = 0;
     $52 = $51&1;
     if (!($52)) {
      __THREW__ = 0;
      invoke_vii(3754,($45|0),($50|0));
      $53 = __THREW__; __THREW__ = 0;
      $54 = $53&1;
      if (!($54)) {
       $55 = ((($0)) + 212|0);
       HEAP32[$55>>2] = 0;
       $56 = ((($0)) + 180|0);
       HEAP8[$56>>0] = 0;
       $57 = ((($0)) + 181|0);
       HEAP8[$57>>0] = 0;
       $58 = ((($0)) + 182|0);
       HEAP8[$58>>0] = 1;
       $59 = ((($0)) + 183|0);
       HEAP8[$59>>0] = 1;
       $60 = ((($0)) + 184|0);
       HEAP8[$60>>0] = 0;
       return;
      }
     }
    }
    $63 = ___cxa_find_matching_catch_2()|0;
    $64 = tempRet0;
    $65 = HEAP32[$15>>2]|0;
    $66 = ($65|0)==(0|0);
    if ($66) {
     $$0 = $64;$$02 = $63;
    } else {
     $67 = HEAP32[$23>>2]|0;
     $68 = ($67|0)==($65|0);
     if (!($68)) {
      $scevgep$i$i$i$i = ((($67)) + -4|0);
      $69 = $scevgep$i$i$i$i;
      $70 = $65;
      $71 = (($69) - ($70))|0;
      $72 = $71 >>> 2;
      $73 = $72 ^ -1;
      $scevgep5$i$i$i$i = (($67) + ($73<<2)|0);
      HEAP32[$23>>2] = $scevgep5$i$i$i$i;
     }
     __ZdlPv($65);
     $$0 = $64;$$02 = $63;
    }
   }
  }
 } while(0);
 if ((label|0) == 16) {
  $61 = ___cxa_find_matching_catch_2()|0;
  $62 = tempRet0;
  $eh$lpad$body$index3Z2D = $62;$eh$lpad$body$indexZ2D = $61;
  label = 17;
 }
 if ((label|0) == 17) {
  $$0 = $eh$lpad$body$index3Z2D;$$02 = $eh$lpad$body$indexZ2D;
 }
 $74 = HEAP32[$14>>2]|0;
 $75 = ($74|0)==(0|0);
 if (!($75)) {
  $76 = ((($74)) + 8|0);
  $77 = HEAP32[$76>>2]|0;HEAP32[$76>>2] = (($77-1)|0);
  $78 = ($77|0)==(1);
  if ($78) {
   __THREW__ = 0;
   invoke_viii(3262,($74|0),1,1);
   $79 = __THREW__; __THREW__ = 0;
   $80 = $79&1;
   if ($80) {
    $90 = ___cxa_find_matching_catch_3(0|0)|0;
    $91 = tempRet0;
    ___clang_call_terminate($90);
    // unreachable;
   }
  }
 }
 HEAP32[$14>>2] = 0;
 $81 = HEAP32[$7>>2]|0;
 $82 = ($81|0)==(0|0);
 if (!($82)) {
  $83 = ((($81)) + 8|0);
  $84 = HEAP32[$83>>2]|0;HEAP32[$83>>2] = (($84-1)|0);
  $85 = ($84|0)==(1);
  if ($85) {
   __THREW__ = 0;
   invoke_viii(3262,($81|0),1,1);
   $86 = __THREW__; __THREW__ = 0;
   $87 = $86&1;
   if ($87) {
    $90 = ___cxa_find_matching_catch_3(0|0)|0;
    $91 = tempRet0;
    ___clang_call_terminate($90);
    // unreachable;
   }
  }
 }
 HEAP32[$7>>2] = 0;
 __THREW__ = 0;
 invoke_vi(2026,($0|0));
 $88 = __THREW__; __THREW__ = 0;
 $89 = $88&1;
 if ($89) {
  $90 = ___cxa_find_matching_catch_3(0|0)|0;
  $91 = tempRet0;
  ___clang_call_terminate($90);
  // unreachable;
 } else {
  ___resumeException($$02|0);
  // unreachable;
 }
}
function __ZN3osg8Drawable45setMinimumNumberOfDisplayListsToRetainInCacheEj($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[52054] = $0;
 return;
}
function __ZN3osg8Drawable17setUseDisplayListEb($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 181|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = $3&255;
 $5 = $1&1;
 $6 = ($4|0)==($5|0);
 if ($6) {
  return;
 }
 HEAP8[$2>>0] = 0;
 return;
}
function __ZNK3osg8Drawable4drawERNS_10RenderInfoE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0;
 var $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0;
 var $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 713|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)==(0);
 if ($5) {
  $6 = ((($0)) + 184|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = ($7<<24>>24)!=(0);
  $9 = ((($2)) + 711|0);
  $10 = HEAP8[$9>>0]|0;
  $11 = ($10<<24>>24)!=(0);
  $12 = $8 & $11;
  if ($12) {
   label = 4;
  } else {
   $126 = ((($2)) + 132|0);
   $127 = HEAP32[$126>>2]|0;
   $128 = ($127|0)==(0|0);
   if (!($128)) {
    $129 = ((($127)) + 24|0);
    $130 = HEAP32[$129>>2]|0;
    $131 = ((($2)) + 704|0);
    $132 = HEAP32[$131>>2]|0;
    $133 = ($132|0)==($130|0);
    if (!($133)) {
     $134 = ((($2)) + 784|0);
     $135 = HEAP32[$134>>2]|0;
     $136 = ((($135)) + 1500|0);
     $137 = HEAP32[$136>>2]|0;
     FUNCTION_TABLE_vi[$137 & 8191]($130);
     HEAP32[$131>>2] = $130;
    }
   }
   $138 = ((($0)) + 212|0);
   $139 = HEAP32[$138>>2]|0;
   $140 = ($139|0)==(0|0);
   if ($140) {
    $144 = HEAP32[$0>>2]|0;
    $145 = ((($144)) + 240|0);
    $146 = HEAP32[$145>>2]|0;
    FUNCTION_TABLE_vii[$146 & 8191]($0,$1);
    return;
   } else {
    $141 = HEAP32[$139>>2]|0;
    $142 = ((($141)) + 20|0);
    $143 = HEAP32[$142>>2]|0;
    FUNCTION_TABLE_viii[$143 & 8191]($139,$1,$0);
    return;
   }
  }
 } else {
  $13 = ($2|0)==(0|0);
  if ($13) {
   $23 = 0;
  } else {
   label = 4;
  }
 }
 if ((label|0) == 4) {
  $14 = ((($2)) + 124|0);
  $15 = HEAP32[$14>>2]|0;
  $23 = $15;
 }
 $16 = ((($0)) + 200|0);
 $17 = ((($0)) + 204|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = HEAP32[$16>>2]|0;
 $20 = (($18) - ($19))|0;
 $21 = $20 >> 2;
 $22 = ($21>>>0)>($23>>>0);
 L17: do {
  if (!($22)) {
   $24 = (($23) + 1)|0;
   $25 = ($24>>>0)>($21>>>0);
   $26 = $19;
   $27 = $18;
   if ($25) {
    $28 = (($24) - ($21))|0;
    __ZNSt3__26vectorIN3osg7ref_ptrINS1_16VertexArrayStateEEENS_9allocatorIS4_EEE8__appendEj($16,$28);
    break;
   }
   $29 = ($24>>>0)<($21>>>0);
   if ($29) {
    $30 = (($26) + ($24<<2)|0);
    $31 = ($27|0)==($30|0);
    if (!($31)) {
     $33 = $27;
     while(1) {
      $32 = ((($33)) + -4|0);
      HEAP32[$17>>2] = $32;
      $34 = HEAP32[$32>>2]|0;
      $35 = ($34|0)==(0|0);
      if (!($35)) {
       $36 = ((($34)) + 8|0);
       $37 = HEAP32[$36>>2]|0;HEAP32[$36>>2] = (($37-1)|0);
       $38 = ($37|0)==(1);
       if ($38) {
        __THREW__ = 0;
        invoke_viii(3262,($34|0),1,1);
        $39 = __THREW__; __THREW__ = 0;
        $40 = $39&1;
        if ($40) {
         break;
        }
       }
      }
      HEAP32[$32>>2] = 0;
      $41 = HEAP32[$17>>2]|0;
      $42 = ($41|0)==($30|0);
      if ($42) {
       break L17;
      } else {
       $33 = $41;
      }
     }
     $43 = ___cxa_find_matching_catch_2()|0;
     $44 = tempRet0;
     ___cxa_call_unexpected(($43|0));
     // unreachable;
    }
   }
  }
 } while(0);
 $45 = HEAP32[$16>>2]|0;
 $46 = (($45) + ($23<<2)|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = ($47|0)==(0|0);
 if ($48) {
  $49 = HEAP32[$0>>2]|0;
  $50 = ((($49)) + 232|0);
  $51 = HEAP32[$50>>2]|0;
  $52 = (FUNCTION_TABLE_iii[$51 & 8191]($0,$1)|0);
  $53 = HEAP32[$17>>2]|0;
  $54 = HEAP32[$16>>2]|0;
  $55 = (($53) - ($54))|0;
  $56 = $55 >> 2;
  $57 = ($56>>>0)>($23>>>0);
  L33: do {
   if (!($57)) {
    $58 = (($23) + 1)|0;
    $59 = ($58>>>0)>($56>>>0);
    $60 = $54;
    $61 = $53;
    if ($59) {
     $62 = (($58) - ($56))|0;
     __ZNSt3__26vectorIN3osg7ref_ptrINS1_16VertexArrayStateEEENS_9allocatorIS4_EEE8__appendEj($16,$62);
     break;
    }
    $63 = ($58>>>0)<($56>>>0);
    if ($63) {
     $64 = (($60) + ($58<<2)|0);
     $65 = ($61|0)==($64|0);
     if (!($65)) {
      $67 = $61;
      while(1) {
       $66 = ((($67)) + -4|0);
       HEAP32[$17>>2] = $66;
       $68 = HEAP32[$66>>2]|0;
       $69 = ($68|0)==(0|0);
       if (!($69)) {
        $70 = ((($68)) + 8|0);
        $71 = HEAP32[$70>>2]|0;HEAP32[$70>>2] = (($71-1)|0);
        $72 = ($71|0)==(1);
        if ($72) {
         __THREW__ = 0;
         invoke_viii(3262,($68|0),1,1);
         $73 = __THREW__; __THREW__ = 0;
         $74 = $73&1;
         if ($74) {
          break;
         }
        }
       }
       HEAP32[$66>>2] = 0;
       $75 = HEAP32[$17>>2]|0;
       $76 = ($75|0)==($64|0);
       if ($76) {
        break L33;
       } else {
        $67 = $75;
       }
      }
      $77 = ___cxa_find_matching_catch_2()|0;
      $78 = tempRet0;
      ___cxa_call_unexpected(($77|0));
      // unreachable;
     }
    }
   }
  } while(0);
  $79 = HEAP32[$16>>2]|0;
  $80 = (($79) + ($23<<2)|0);
  $81 = HEAP32[$80>>2]|0;
  $82 = ($81|0)==($52|0);
  if ($82) {
   $$0 = $52;
  } else {
   HEAP32[$80>>2] = $52;
   $83 = ($52|0)==(0|0);
   if (!($83)) {
    $84 = ((($52)) + 8|0);
    $85 = HEAP32[$84>>2]|0;HEAP32[$84>>2] = (($85+1)|0);
   }
   $86 = ($81|0)==(0|0);
   if ($86) {
    $$0 = $52;
   } else {
    $87 = ((($81)) + 8|0);
    $88 = HEAP32[$87>>2]|0;HEAP32[$87>>2] = (($88-1)|0);
    $89 = ($88|0)==(1);
    if ($89) {
     __ZNK3osg10Referenced24signalObserversAndDeleteEbb($81,1,1);
     $$0 = $52;
    } else {
     $$0 = $52;
    }
   }
  }
 } else {
  $$0 = $47;
 }
 $90 = ((($2)) + 132|0);
 HEAP32[$90>>2] = $$0;
 $91 = ((($$0)) + 24|0);
 $92 = HEAP32[$91>>2]|0;
 $93 = ((($2)) + 704|0);
 $94 = HEAP32[$93>>2]|0;
 $95 = ($94|0)==($92|0);
 do {
  if (!($95)) {
   $96 = ((($2)) + 784|0);
   $97 = HEAP32[$96>>2]|0;
   $98 = ((($97)) + 1500|0);
   $99 = HEAP32[$98>>2]|0;
   __THREW__ = 0;
   invoke_vi($99|0,($92|0));
   $100 = __THREW__; __THREW__ = 0;
   $101 = $100&1;
   if ($101) {
    $122 = ___cxa_find_matching_catch_2()|0;
    $123 = tempRet0;
    $124 = ((($2)) + 128|0);
    $125 = HEAP32[$124>>2]|0;
    HEAP32[$90>>2] = $125;
    ___resumeException($122|0);
    // unreachable;
   } else {
    HEAP32[$93>>2] = $92;
    break;
   }
  }
 } while(0);
 $102 = ((($0)) + 212|0);
 $103 = HEAP32[$102>>2]|0;
 $104 = ($103|0)==(0|0);
 if ($104) {
  $110 = HEAP32[$0>>2]|0;
  $111 = ((($110)) + 240|0);
  $112 = HEAP32[$111>>2]|0;
  __THREW__ = 0;
  invoke_vii($112|0,($0|0),($1|0));
  $113 = __THREW__; __THREW__ = 0;
  $114 = $113&1;
  if ($114) {
   $122 = ___cxa_find_matching_catch_2()|0;
   $123 = tempRet0;
   $124 = ((($2)) + 128|0);
   $125 = HEAP32[$124>>2]|0;
   HEAP32[$90>>2] = $125;
   ___resumeException($122|0);
   // unreachable;
  }
 } else {
  $105 = HEAP32[$103>>2]|0;
  $106 = ((($105)) + 20|0);
  $107 = HEAP32[$106>>2]|0;
  __THREW__ = 0;
  invoke_viii($107|0,($103|0),($1|0),($0|0));
  $108 = __THREW__; __THREW__ = 0;
  $109 = $108&1;
  if ($109) {
   $122 = ___cxa_find_matching_catch_2()|0;
   $123 = tempRet0;
   $124 = ((($2)) + 128|0);
   $125 = HEAP32[$124>>2]|0;
   HEAP32[$90>>2] = $125;
   ___resumeException($122|0);
   // unreachable;
  }
 }
 $115 = ((($0)) + 24|0);
 $116 = HEAP32[$115>>2]|0;
 $117 = ($116|0)==(0);
 $118 = $117&1;
 $119 = ((($$0)) + 104|0);
 HEAP8[$119>>0] = $118;
 $120 = ((($2)) + 128|0);
 $121 = HEAP32[$120>>2]|0;
 HEAP32[$90>>2] = $121;
 return;
}
function __ZN3osg21GLRenderBufferManagerD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1702,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZN3osg21GLRenderBufferManager14deleteGLObjectEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 HEAP32[$2>>2] = $1;
 $3 = ((($0)) + 24|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (__ZN3osg12GLExtensions3GetEjb($4,1)|0);
 $6 = ((($5)) + 24|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = ($7<<24>>24)==(0);
 if ($8) {
  STACKTOP = sp;return;
 }
 $9 = ((($5)) + 1260|0);
 $10 = HEAP32[$9>>2]|0;
 FUNCTION_TABLE_vii[$10 & 8191](1,$2);
 STACKTOP = sp;return;
}
function __ZN3osg26GLFrameBufferObjectManagerD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1702,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZN3osg26GLFrameBufferObjectManager14deleteGLObjectEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 HEAP32[$2>>2] = $1;
 $3 = ((($0)) + 24|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (__ZN3osg12GLExtensions3GetEjb($4,1)|0);
 $6 = ((($5)) + 24|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = ($7<<24>>24)==(0);
 if ($8) {
  STACKTOP = sp;return;
 }
 $9 = ((($5)) + 1284|0);
 $10 = HEAP32[$9>>2]|0;
 FUNCTION_TABLE_vii[$10 & 8191](1,$2);
 STACKTOP = sp;return;
}
function __ZN3osg12RenderBufferD2Ev($0) {
 $0 = $0|0;
 var $$01142 = 0, $$pre = 0, $$pre$i27 = 0, $$pre$pre$i23 = 0, $$pre46 = 0, $$pre47 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i$i$i12 = 0, $scevgep$i$i$i$i24 = 0, $scevgep$i$i$i$i31 = 0, $scevgep$i$i$i$i34 = 0, $scevgep5$i$i$i$i = 0, $scevgep5$i$i$i$i13 = 0, $scevgep5$i$i$i$i25 = 0, $scevgep5$i$i$i$i32 = 0, $scevgep5$i$i$i$i35 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 HEAP32[$0>>2] = (58912);
 $2 = ((($0)) + 32|0);
 $3 = ((($0)) + 36|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$2>>2]|0;
 $6 = ($4|0)==($5|0);
 $7 = $5;
 L1: do {
  if ($6) {
   $100 = $7;
  } else {
   $$01142 = 0;$101 = $7;$102 = $4;$32 = $5;
   while(1) {
    $33 = $32;
    $34 = (($33) + ($$01142<<2)|0);
    $35 = HEAP32[$34>>2]|0;
    $36 = ($35|0)==(0);
    if ($36) {
     $103 = $101;$74 = $32;$75 = $102;
    } else {
     __THREW__ = 0;
     $37 = (invoke_ii(3683,($$01142|0))|0);
     $38 = __THREW__; __THREW__ = 0;
     $39 = $38&1;
     if ($39) {
      break;
     }
     __THREW__ = 0;
     $40 = (invoke_ii(3684,($37|0))|0);
     $41 = __THREW__; __THREW__ = 0;
     $42 = $41&1;
     if ($42) {
      break;
     }
     $43 = HEAP32[$40>>2]|0;
     $44 = ((($43)) + 44|0);
     $45 = HEAP32[$44>>2]|0;
     $46 = HEAP32[$3>>2]|0;
     $47 = HEAP32[$2>>2]|0;
     $48 = (($46) - ($47))|0;
     $49 = $48 >> 2;
     $50 = ($49>>>0)>($$01142>>>0);
     $51 = $47;
     if ($50) {
      $67 = $51;
     } else {
      $52 = (($$01142) + 1)|0;
      HEAP32[$1>>2] = 0;
      $53 = ($52>>>0)>($49>>>0);
      $54 = $46;
      if ($53) {
       $55 = (($52) - ($49))|0;
       __THREW__ = 0;
       invoke_viii(3755,($2|0),($55|0),($1|0));
       $56 = __THREW__; __THREW__ = 0;
       $57 = $56&1;
       if ($57) {
        break;
       }
       $$pre$pre$i23 = HEAP32[$2>>2]|0;
       $$pre$i27 = $$pre$pre$i23;
      } else {
       $58 = ($52>>>0)<($49>>>0);
       if ($58) {
        $59 = (($51) + ($52<<2)|0);
        $60 = ($54|0)==($59|0);
        if ($60) {
         $$pre$i27 = $51;
        } else {
         $scevgep$i$i$i$i24 = ((($54)) + -4|0);
         $61 = $scevgep$i$i$i$i24;
         $62 = $59;
         $63 = (($61) - ($62))|0;
         $64 = $63 >>> 2;
         $65 = $64 ^ -1;
         $scevgep5$i$i$i$i25 = (($54) + ($65<<2)|0);
         HEAP32[$3>>2] = $scevgep5$i$i$i$i25;
         $$pre$i27 = $51;
        }
       } else {
        $$pre$i27 = $51;
       }
      }
      $67 = $$pre$i27;
     }
     $66 = (($67) + ($$01142<<2)|0);
     $68 = HEAP32[$66>>2]|0;
     __THREW__ = 0;
     invoke_vii($45|0,($40|0),($68|0));
     $69 = __THREW__; __THREW__ = 0;
     $70 = $69&1;
     if ($70) {
      break;
     }
     $$pre = HEAP32[$3>>2]|0;
     $$pre46 = HEAP32[$2>>2]|0;
     $71 = $$pre46;
     $103 = $71;$74 = $$pre46;$75 = $$pre;
    }
    $72 = (($$01142) + 1)|0;
    $73 = (($75) - ($74))|0;
    $76 = $73 >> 2;
    $77 = ($72>>>0)<($76>>>0);
    if ($77) {
     $$01142 = $72;$101 = $103;$102 = $75;$32 = $74;
    } else {
     $100 = $103;
     break L1;
    }
   }
   $19 = ___cxa_find_matching_catch_2()|0;
   $20 = tempRet0;
   $21 = ((($0)) + 44|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = ($22|0)==(0|0);
   if (!($23)) {
    $24 = ((($0)) + 48|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = ($25|0)==($22|0);
    if (!($26)) {
     $scevgep$i$i$i$i12 = ((($25)) + -4|0);
     $27 = $scevgep$i$i$i$i12;
     $28 = $22;
     $29 = (($27) - ($28))|0;
     $30 = $29 >>> 2;
     $31 = $30 ^ -1;
     $scevgep5$i$i$i$i13 = (($25) + ($31<<2)|0);
     HEAP32[$24>>2] = $scevgep5$i$i$i$i13;
    }
    __ZdlPv($22);
   }
   $87 = HEAP32[$2>>2]|0;
   $88 = ($87|0)==(0|0);
   if (!($88)) {
    $89 = HEAP32[$3>>2]|0;
    $90 = ($89|0)==($87|0);
    if (!($90)) {
     $scevgep$i$i$i$i34 = ((($89)) + -4|0);
     $91 = $scevgep$i$i$i$i34;
     $92 = $87;
     $93 = (($91) - ($92))|0;
     $94 = $93 >>> 2;
     $95 = $94 ^ -1;
     $scevgep5$i$i$i$i35 = (($89) + ($95<<2)|0);
     HEAP32[$3>>2] = $scevgep5$i$i$i$i35;
    }
    __ZdlPv($87);
   }
   __THREW__ = 0;
   invoke_vi(388,($0|0));
   $96 = __THREW__; __THREW__ = 0;
   $97 = $96&1;
   if ($97) {
    $98 = ___cxa_find_matching_catch_3(0|0)|0;
    $99 = tempRet0;
    ___clang_call_terminate($98);
    // unreachable;
   } else {
    ___resumeException($19|0);
    // unreachable;
   }
  }
 } while(0);
 $8 = ((($0)) + 44|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if ($10) {
  $78 = $100;
 } else {
  $11 = ((($0)) + 48|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($12|0)==($9|0);
  if (!($13)) {
   $scevgep$i$i$i$i = ((($12)) + -4|0);
   $14 = $scevgep$i$i$i$i;
   $15 = $9;
   $16 = (($14) - ($15))|0;
   $17 = $16 >>> 2;
   $18 = $17 ^ -1;
   $scevgep5$i$i$i$i = (($12) + ($18<<2)|0);
   HEAP32[$11>>2] = $scevgep5$i$i$i$i;
  }
  __ZdlPv($9);
  $$pre47 = HEAP32[$2>>2]|0;
  $78 = $$pre47;
 }
 $79 = ($78|0)==(0|0);
 if ($79) {
  __ZN3osg6ObjectD2Ev($0);
  STACKTOP = sp;return;
 }
 $80 = HEAP32[$3>>2]|0;
 $81 = ($80|0)==($78|0);
 if (!($81)) {
  $scevgep$i$i$i$i31 = ((($80)) + -4|0);
  $82 = $scevgep$i$i$i$i31;
  $83 = $78;
  $84 = (($82) - ($83))|0;
  $85 = $84 >>> 2;
  $86 = $85 ^ -1;
  $scevgep5$i$i$i$i32 = (($80) + ($86<<2)|0);
  HEAP32[$3>>2] = $scevgep5$i$i$i$i32;
 }
 __ZdlPv($78);
 __ZN3osg6ObjectD2Ev($0);
 STACKTOP = sp;return;
}
function __ZN3osg12RenderBufferD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1713,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK3osg12RenderBuffer9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(76)|0);
 __THREW__ = 0;
 invoke_vi(3756,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch_2()|0;
  $5 = tempRet0;
  __ZdlPv($1);
  ___resumeException($4|0);
  // unreachable;
 } else {
  return ($1|0);
 }
 return (0)|0;
}
function __ZNK3osg12RenderBuffer5cloneERKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(76)|0);
 __THREW__ = 0;
 invoke_viii(3757,($2|0),($0|0),($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch_2()|0;
  $6 = tempRet0;
  __ZdlPv($2);
  ___resumeException($5|0);
  // unreachable;
 } else {
  return ($2|0);
 }
 return (0)|0;
}
function __ZNK3osg12RenderBuffer12isSameKindAsEPKNS_6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,24552,0)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK3osg12RenderBuffer11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175113|0);
}
function __ZNK3osg12RenderBuffer9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (126798|0);
}
function __ZN3osg12RenderBuffer21resizeGLObjectBuffersEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i$i$i2 = 0;
 var $scevgep5$i$i$i$i = 0, $scevgep5$i$i$i$i3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp + 4|0;
 $3 = sp;
 $4 = ((($0)) + 32|0);
 HEAP32[$3>>2] = 0;
 $5 = ((($0)) + 36|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$4>>2]|0;
 $8 = (($6) - ($7))|0;
 $9 = $8 >> 2;
 $10 = ($9>>>0)<($1>>>0);
 $11 = $7;
 $12 = $6;
 if ($10) {
  $13 = (($1) - ($9))|0;
  __ZNSt3__26vectorIjNS_9allocatorIjEEE8__appendEjRKj($4,$13,$3);
 } else {
  $14 = ($9>>>0)>($1>>>0);
  if ($14) {
   $15 = (($11) + ($1<<2)|0);
   $16 = ($12|0)==($15|0);
   if (!($16)) {
    $scevgep$i$i$i$i = ((($12)) + -4|0);
    $17 = $scevgep$i$i$i$i;
    $18 = $15;
    $19 = (($17) - ($18))|0;
    $20 = $19 >>> 2;
    $21 = $20 ^ -1;
    $scevgep5$i$i$i$i = (($12) + ($21<<2)|0);
    HEAP32[$5>>2] = $scevgep5$i$i$i$i;
   }
  }
 }
 $22 = ((($0)) + 44|0);
 HEAP32[$2>>2] = 0;
 $23 = ((($0)) + 48|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = HEAP32[$22>>2]|0;
 $26 = (($24) - ($25))|0;
 $27 = $26 >> 2;
 $28 = ($27>>>0)<($1>>>0);
 $29 = $25;
 $30 = $24;
 if ($28) {
  $31 = (($1) - ($27))|0;
  __ZNSt3__26vectorIiNS_9allocatorIiEEE8__appendEjRKi($22,$31,$2);
  STACKTOP = sp;return;
 }
 $32 = ($27>>>0)>($1>>>0);
 if (!($32)) {
  STACKTOP = sp;return;
 }
 $33 = (($29) + ($1<<2)|0);
 $34 = ($30|0)==($33|0);
 if ($34) {
  STACKTOP = sp;return;
 }
 $scevgep$i$i$i$i2 = ((($30)) + -4|0);
 $35 = $scevgep$i$i$i$i2;
 $36 = $33;
 $37 = (($35) - ($36))|0;
 $38 = $37 >>> 2;
 $39 = $38 ^ -1;
 $scevgep5$i$i$i$i3 = (($30) + ($39<<2)|0);
 HEAP32[$23>>2] = $scevgep5$i$i$i$i3;
 STACKTOP = sp;return;
}
function __ZNK3osg12RenderBuffer16releaseGLObjectsEPNS_5StateE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$055 = 0, $$pre = 0, $$pre$i = 0, $$pre$i20 = 0, $$pre$i28 = 0, $$pre$i36 = 0, $$pre$i52 = 0, $$pre$pre = 0, $$pre$pre$i = 0, $$pre$pre$i16 = 0, $$pre$pre$i24 = 0, $$pre$pre$i32 = 0, $$pre$pre$i48 = 0, $$pre$pre$pre = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0;
 var $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $scevgep$i$i$i$i = 0;
 var $scevgep$i$i$i$i17 = 0, $scevgep$i$i$i$i25 = 0, $scevgep$i$i$i$i33 = 0, $scevgep$i$i$i$i49 = 0, $scevgep5$i$i$i$i = 0, $scevgep5$i$i$i$i18 = 0, $scevgep5$i$i$i$i26 = 0, $scevgep5$i$i$i$i34 = 0, $scevgep5$i$i$i$i50 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $2 = sp + 16|0;
 $3 = sp + 12|0;
 $4 = sp + 8|0;
 $5 = sp + 4|0;
 $6 = sp;
 $7 = ($1|0)==(0|0);
 if ($7) {
  $8 = ((($0)) + 32|0);
  $9 = ((($0)) + 36|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = HEAP32[$8>>2]|0;
  $12 = ($10|0)==($11|0);
  if ($12) {
   STACKTOP = sp;return;
  }
  $$055 = 0;$144 = $10;$85 = $11;
  while(1) {
   $86 = $85;
   $87 = (($86) + ($$055<<2)|0);
   $88 = HEAP32[$87>>2]|0;
   $89 = ($88|0)==(0);
   if ($89) {
    $140 = $85;$141 = $144;
   } else {
    $90 = (__ZN3osg22getOrCreateContextDataEj($$055)|0);
    $91 = (__ZN3osg11ContextData3getINS_21GLRenderBufferManagerEEEPT_v($90)|0);
    $92 = HEAP32[$91>>2]|0;
    $93 = ((($92)) + 44|0);
    $94 = HEAP32[$93>>2]|0;
    $95 = HEAP32[$9>>2]|0;
    $96 = HEAP32[$8>>2]|0;
    $97 = (($95) - ($96))|0;
    $98 = $97 >> 2;
    $99 = ($98>>>0)>($$055>>>0);
    $100 = $96;
    if ($99) {
     $114 = $100;
    } else {
     $101 = (($$055) + 1)|0;
     HEAP32[$2>>2] = 0;
     $102 = ($101>>>0)>($98>>>0);
     $103 = $95;
     if ($102) {
      $104 = (($101) - ($98))|0;
      __ZNSt3__26vectorIjNS_9allocatorIjEEE8__appendEjRKj($8,$104,$2);
      $$pre$pre$i48 = HEAP32[$8>>2]|0;
      $$pre$i52 = $$pre$pre$i48;
     } else {
      $105 = ($101>>>0)<($98>>>0);
      if ($105) {
       $106 = (($100) + ($101<<2)|0);
       $107 = ($103|0)==($106|0);
       if ($107) {
        $$pre$i52 = $100;
       } else {
        $scevgep$i$i$i$i49 = ((($103)) + -4|0);
        $108 = $scevgep$i$i$i$i49;
        $109 = $106;
        $110 = (($108) - ($109))|0;
        $111 = $110 >>> 2;
        $112 = $111 ^ -1;
        $scevgep5$i$i$i$i50 = (($103) + ($112<<2)|0);
        HEAP32[$9>>2] = $scevgep5$i$i$i$i50;
        $$pre$i52 = $100;
       }
      } else {
       $$pre$i52 = $100;
      }
     }
     $114 = $$pre$i52;
    }
    $113 = (($114) + ($$055<<2)|0);
    $115 = HEAP32[$113>>2]|0;
    FUNCTION_TABLE_vii[$94 & 8191]($91,$115);
    $116 = HEAP32[$9>>2]|0;
    $117 = HEAP32[$8>>2]|0;
    $118 = (($116) - ($117))|0;
    $119 = $118 >> 2;
    $120 = ($119>>>0)>($$055>>>0);
    $121 = $117;
    if ($120) {
     $$pre = $116;$137 = $121;$145 = $117;
    } else {
     $122 = (($$055) + 1)|0;
     HEAP32[$6>>2] = 0;
     $123 = ($122>>>0)>($119>>>0);
     $124 = $116;
     if ($123) {
      $125 = (($122) - ($119))|0;
      __ZNSt3__26vectorIjNS_9allocatorIjEEE8__appendEjRKj($8,$125,$6);
      $$pre$pre$i = HEAP32[$8>>2]|0;
      $126 = $$pre$pre$i;
      $$pre$pre$pre = HEAP32[$9>>2]|0;
      $$pre$i = $$pre$pre$i;$$pre$pre = $$pre$pre$pre;$146 = $126;
     } else {
      $127 = ($122>>>0)<($119>>>0);
      if ($127) {
       $128 = (($121) + ($122<<2)|0);
       $129 = ($124|0)==($128|0);
       if ($129) {
        $$pre$i = $121;$$pre$pre = $116;$146 = $117;
       } else {
        $scevgep$i$i$i$i = ((($124)) + -4|0);
        $130 = $scevgep$i$i$i$i;
        $131 = $128;
        $132 = (($130) - ($131))|0;
        $133 = $132 >>> 2;
        $134 = $133 ^ -1;
        $scevgep5$i$i$i$i = (($124) + ($134<<2)|0);
        HEAP32[$9>>2] = $scevgep5$i$i$i$i;
        $135 = $scevgep5$i$i$i$i;
        $$pre$i = $121;$$pre$pre = $135;$146 = $117;
       }
      } else {
       $$pre$i = $121;$$pre$pre = $116;$146 = $117;
      }
     }
     $$pre = $$pre$pre;$137 = $$pre$i;$145 = $146;
    }
    $136 = (($137) + ($$055<<2)|0);
    HEAP32[$136>>2] = 0;
    $140 = $145;$141 = $$pre;
   }
   $138 = (($$055) + 1)|0;
   $139 = (($141) - ($140))|0;
   $142 = $139 >> 2;
   $143 = ($138>>>0)<($142>>>0);
   if ($143) {
    $$055 = $138;$144 = $141;$85 = $140;
   } else {
    break;
   }
  }
  STACKTOP = sp;return;
 }
 $13 = ((($1)) + 124|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ((($0)) + 32|0);
 $16 = ((($0)) + 36|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = HEAP32[$15>>2]|0;
 $19 = (($17) - ($18))|0;
 $20 = $19 >> 2;
 $21 = ($20>>>0)>($14>>>0);
 $22 = $18;
 if ($21) {
  $36 = $22;
 } else {
  $23 = (($14) + 1)|0;
  HEAP32[$5>>2] = 0;
  $24 = ($23>>>0)>($20>>>0);
  $25 = $17;
  if ($24) {
   $26 = (($23) - ($20))|0;
   __ZNSt3__26vectorIjNS_9allocatorIjEEE8__appendEjRKj($15,$26,$5);
   $$pre$pre$i16 = HEAP32[$15>>2]|0;
   $$pre$i20 = $$pre$pre$i16;
  } else {
   $27 = ($23>>>0)<($20>>>0);
   if ($27) {
    $28 = (($22) + ($23<<2)|0);
    $29 = ($25|0)==($28|0);
    if ($29) {
     $$pre$i20 = $22;
    } else {
     $scevgep$i$i$i$i17 = ((($25)) + -4|0);
     $30 = $scevgep$i$i$i$i17;
     $31 = $28;
     $32 = (($30) - ($31))|0;
     $33 = $32 >>> 2;
     $34 = $33 ^ -1;
     $scevgep5$i$i$i$i18 = (($25) + ($34<<2)|0);
     HEAP32[$16>>2] = $scevgep5$i$i$i$i18;
     $$pre$i20 = $22;
    }
   } else {
    $$pre$i20 = $22;
   }
  }
  $36 = $$pre$i20;
 }
 $35 = (($36) + ($14<<2)|0);
 $37 = HEAP32[$35>>2]|0;
 $38 = ($37|0)==(0);
 if ($38) {
  STACKTOP = sp;return;
 }
 $39 = (__ZN3osg22getOrCreateContextDataEj($14)|0);
 $40 = (__ZN3osg11ContextData3getINS_21GLRenderBufferManagerEEEPT_v($39)|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = ((($41)) + 44|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = HEAP32[$16>>2]|0;
 $45 = HEAP32[$15>>2]|0;
 $46 = (($44) - ($45))|0;
 $47 = $46 >> 2;
 $48 = ($47>>>0)>($14>>>0);
 $49 = $45;
 if ($48) {
  $63 = $49;
 } else {
  $50 = (($14) + 1)|0;
  HEAP32[$4>>2] = 0;
  $51 = ($50>>>0)>($47>>>0);
  $52 = $44;
  if ($51) {
   $53 = (($50) - ($47))|0;
   __ZNSt3__26vectorIjNS_9allocatorIjEEE8__appendEjRKj($15,$53,$4);
   $$pre$pre$i24 = HEAP32[$15>>2]|0;
   $$pre$i28 = $$pre$pre$i24;
  } else {
   $54 = ($50>>>0)<($47>>>0);
   if ($54) {
    $55 = (($49) + ($50<<2)|0);
    $56 = ($52|0)==($55|0);
    if ($56) {
     $$pre$i28 = $49;
    } else {
     $scevgep$i$i$i$i25 = ((($52)) + -4|0);
     $57 = $scevgep$i$i$i$i25;
     $58 = $55;
     $59 = (($57) - ($58))|0;
     $60 = $59 >>> 2;
     $61 = $60 ^ -1;
     $scevgep5$i$i$i$i26 = (($52) + ($61<<2)|0);
     HEAP32[$16>>2] = $scevgep5$i$i$i$i26;
     $$pre$i28 = $49;
    }
   } else {
    $$pre$i28 = $49;
   }
  }
  $63 = $$pre$i28;
 }
 $62 = (($63) + ($14<<2)|0);
 $64 = HEAP32[$62>>2]|0;
 FUNCTION_TABLE_vii[$43 & 8191]($40,$64);
 $65 = HEAP32[$16>>2]|0;
 $66 = HEAP32[$15>>2]|0;
 $67 = (($65) - ($66))|0;
 $68 = $67 >> 2;
 $69 = ($68>>>0)>($14>>>0);
 $70 = $66;
 if ($69) {
  $84 = $70;
 } else {
  $71 = (($14) + 1)|0;
  HEAP32[$3>>2] = 0;
  $72 = ($71>>>0)>($68>>>0);
  $73 = $65;
  if ($72) {
   $74 = (($71) - ($68))|0;
   __ZNSt3__26vectorIjNS_9allocatorIjEEE8__appendEjRKj($15,$74,$3);
   $$pre$pre$i32 = HEAP32[$15>>2]|0;
   $$pre$i36 = $$pre$pre$i32;
  } else {
   $75 = ($71>>>0)<($68>>>0);
   if ($75) {
    $76 = (($70) + ($71<<2)|0);
    $77 = ($73|0)==($76|0);
    if ($77) {
     $$pre$i36 = $70;
    } else {
     $scevgep$i$i$i$i33 = ((($73)) + -4|0);
     $78 = $scevgep$i$i$i$i33;
     $79 = $76;
     $80 = (($78) - ($79))|0;
     $81 = $80 >>> 2;
     $82 = $81 ^ -1;
     $scevgep5$i$i$i$i34 = (($73) + ($82<<2)|0);
     HEAP32[$16>>2] = $scevgep5$i$i$i$i34;
     $$pre$i36 = $70;
    }
   } else {
    $$pre$i36 = $70;
   }
  }
  $84 = $$pre$i36;
 }
 $83 = (($84) + ($14<<2)|0);
 HEAP32[$83>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN3osg12RenderBufferC2ERKS0_RKNS_6CopyOpE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$09 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $eh$lpad$body$index3Z2D = 0, $eh$lpad$body$indexZ2D = 0, $eh$lpad$body18$index10Z2D = 0, $eh$lpad$body18$indexZ2D = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i$i$i$i = 0;
 var $scevgep$i$i$i$i$i12 = 0, $scevgep5$i$i$i$i = 0, $scevgep5$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i13 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg6ObjectC2ERKS0_RKNS_6CopyOpE($0,$1,$2);
 HEAP32[$0>>2] = (58912);
 $3 = ((($0)) + 32|0);
 __THREW__ = 0;
 $4 = (invoke_i(3285)|0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 L1: do {
  if ($6) {
   label = 24;
  } else {
   $7 = HEAP32[$4>>2]|0;
   __THREW__ = 0;
   $8 = (invoke_ii(3286,($7|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if ($10) {
    label = 24;
   } else {
    HEAP32[$3>>2] = 0;
    $11 = ((($0)) + 36|0);
    HEAP32[$11>>2] = 0;
    $12 = ((($0)) + 40|0);
    HEAP32[$12>>2] = 0;
    $13 = ($8|0)==(0);
    do {
     if (!($13)) {
      $14 = ($8>>>0)>(1073741823);
      if ($14) {
       __THREW__ = 0;
       invoke_vi(3307,($3|0));
       $15 = __THREW__; __THREW__ = 0;
      } else {
       $16 = $8 << 2;
       __THREW__ = 0;
       $17 = (invoke_ii(3276,($16|0))|0);
       $18 = __THREW__; __THREW__ = 0;
       $19 = $18&1;
       if (!($19)) {
        HEAP32[$3>>2] = $17;
        $20 = (($17) + ($8<<2)|0);
        $21 = ((($0)) + 40|0);
        HEAP32[$21>>2] = $20;
        _memset(($17|0),0,($16|0))|0;
        HEAP32[$11>>2] = $20;
        break;
       }
      }
      $22 = ___cxa_find_matching_catch_2()|0;
      $23 = tempRet0;
      $24 = HEAP32[$3>>2]|0;
      $25 = ($24|0)==(0|0);
      if ($25) {
       $eh$lpad$body$index3Z2D = $23;$eh$lpad$body$indexZ2D = $22;
       label = 25;
       break L1;
      }
      $26 = HEAP32[$11>>2]|0;
      $27 = ($26|0)==($24|0);
      if (!($27)) {
       $scevgep$i$i$i$i$i = ((($26)) + -4|0);
       $28 = $scevgep$i$i$i$i$i;
       $29 = $24;
       $30 = (($28) - ($29))|0;
       $31 = $30 >>> 2;
       $32 = $31 ^ -1;
       $scevgep5$i$i$i$i$i = (($26) + ($32<<2)|0);
       HEAP32[$11>>2] = $scevgep5$i$i$i$i$i;
      }
      __ZdlPv($24);
      $eh$lpad$body$index3Z2D = $23;$eh$lpad$body$indexZ2D = $22;
      label = 25;
      break L1;
     }
    } while(0);
    $33 = ((($0)) + 44|0);
    __THREW__ = 0;
    $34 = (invoke_i(3285)|0);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     label = 26;
    } else {
     $37 = HEAP32[$34>>2]|0;
     __THREW__ = 0;
     $38 = (invoke_ii(3286,($37|0))|0);
     $39 = __THREW__; __THREW__ = 0;
     $40 = $39&1;
     if ($40) {
      label = 26;
     } else {
      HEAP32[$33>>2] = 0;
      $41 = ((($0)) + 48|0);
      HEAP32[$41>>2] = 0;
      $42 = ((($0)) + 52|0);
      HEAP32[$42>>2] = 0;
      $43 = ($38|0)==(0);
      if ($43) {
       $63 = ((($0)) + 56|0);
       $64 = ((($1)) + 56|0);
       $65 = HEAP32[$64>>2]|0;
       HEAP32[$63>>2] = $65;
       $66 = ((($0)) + 60|0);
       $67 = ((($1)) + 60|0);
       $68 = HEAP32[$67>>2]|0;
       HEAP32[$66>>2] = $68;
       $69 = ((($0)) + 64|0);
       $70 = ((($1)) + 64|0);
       $71 = HEAP32[$70>>2]|0;
       HEAP32[$69>>2] = $71;
       $72 = ((($0)) + 68|0);
       $73 = ((($1)) + 68|0);
       $74 = HEAP32[$73>>2]|0;
       HEAP32[$72>>2] = $74;
       $75 = ((($0)) + 72|0);
       $76 = ((($1)) + 72|0);
       $77 = HEAP32[$76>>2]|0;
       HEAP32[$75>>2] = $77;
       return;
      }
      $44 = ($38>>>0)>(1073741823);
      if ($44) {
       __THREW__ = 0;
       invoke_vi(3307,($33|0));
       $45 = __THREW__; __THREW__ = 0;
      } else {
       $46 = $38 << 2;
       __THREW__ = 0;
       $47 = (invoke_ii(3276,($46|0))|0);
       $48 = __THREW__; __THREW__ = 0;
       $49 = $48&1;
       if (!($49)) {
        HEAP32[$33>>2] = $47;
        $50 = (($47) + ($38<<2)|0);
        $51 = ((($0)) + 52|0);
        HEAP32[$51>>2] = $50;
        _memset(($47|0),0,($46|0))|0;
        HEAP32[$41>>2] = $50;
        $63 = ((($0)) + 56|0);
        $64 = ((($1)) + 56|0);
        $65 = HEAP32[$64>>2]|0;
        HEAP32[$63>>2] = $65;
        $66 = ((($0)) + 60|0);
        $67 = ((($1)) + 60|0);
        $68 = HEAP32[$67>>2]|0;
        HEAP32[$66>>2] = $68;
        $69 = ((($0)) + 64|0);
        $70 = ((($1)) + 64|0);
        $71 = HEAP32[$70>>2]|0;
        HEAP32[$69>>2] = $71;
        $72 = ((($0)) + 68|0);
        $73 = ((($1)) + 68|0);
        $74 = HEAP32[$73>>2]|0;
        HEAP32[$72>>2] = $74;
        $75 = ((($0)) + 72|0);
        $76 = ((($1)) + 72|0);
        $77 = HEAP32[$76>>2]|0;
        HEAP32[$75>>2] = $77;
        return;
       }
      }
      $52 = ___cxa_find_matching_catch_2()|0;
      $53 = tempRet0;
      $54 = HEAP32[$33>>2]|0;
      $55 = ($54|0)==(0|0);
      if ($55) {
       $eh$lpad$body18$index10Z2D = $53;$eh$lpad$body18$indexZ2D = $52;
      } else {
       $56 = HEAP32[$41>>2]|0;
       $57 = ($56|0)==($54|0);
       if (!($57)) {
        $scevgep$i$i$i$i$i12 = ((($56)) + -4|0);
        $58 = $scevgep$i$i$i$i$i12;
        $59 = $54;
        $60 = (($58) - ($59))|0;
        $61 = $60 >>> 2;
        $62 = $61 ^ -1;
        $scevgep5$i$i$i$i$i13 = (($56) + ($62<<2)|0);
        HEAP32[$41>>2] = $scevgep5$i$i$i$i$i13;
       }
       __ZdlPv($54);
       $eh$lpad$body18$index10Z2D = $53;$eh$lpad$body18$indexZ2D = $52;
      }
     }
    }
    if ((label|0) == 26) {
     $80 = ___cxa_find_matching_catch_2()|0;
     $81 = tempRet0;
     $eh$lpad$body18$index10Z2D = $81;$eh$lpad$body18$indexZ2D = $80;
    }
    $82 = HEAP32[$3>>2]|0;
    $83 = ($82|0)==(0|0);
    if ($83) {
     $$0 = $eh$lpad$body18$index10Z2D;$$09 = $eh$lpad$body18$indexZ2D;
    } else {
     $84 = HEAP32[$11>>2]|0;
     $85 = ($84|0)==($82|0);
     if (!($85)) {
      $scevgep$i$i$i$i = ((($84)) + -4|0);
      $86 = $scevgep$i$i$i$i;
      $87 = $82;
      $88 = (($86) - ($87))|0;
      $89 = $88 >>> 2;
      $90 = $89 ^ -1;
      $scevgep5$i$i$i$i = (($84) + ($90<<2)|0);
      HEAP32[$11>>2] = $scevgep5$i$i$i$i;
     }
     __ZdlPv($82);
     $$0 = $eh$lpad$body18$index10Z2D;$$09 = $eh$lpad$body18$indexZ2D;
    }
   }
  }
 } while(0);
 if ((label|0) == 24) {
  $78 = ___cxa_find_matching_catch_2()|0;
  $79 = tempRet0;
  $eh$lpad$body$index3Z2D = $79;$eh$lpad$body$indexZ2D = $78;
  label = 25;
 }
 if ((label|0) == 25) {
  $$0 = $eh$lpad$body$index3Z2D;$$09 = $eh$lpad$body$indexZ2D;
 }
 __THREW__ = 0;
 invoke_vi(388,($0|0));
 $91 = __THREW__; __THREW__ = 0;
 $92 = $91&1;
 if ($92) {
  $93 = ___cxa_find_matching_catch_3(0|0)|0;
  $94 = tempRet0;
  ___clang_call_terminate($93);
  // unreachable;
 } else {
  ___resumeException($$09|0);
  // unreachable;
 }
}
function __ZN3osg12RenderBufferC2Ev($0) {
 $0 = $0|0;
 var $$0 = 0, $$02 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $eh$lpad$body$index3Z2D = 0, $eh$lpad$body$indexZ2D = 0, $eh$lpad$body11$index10Z2D = 0, $eh$lpad$body11$indexZ2D = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i5 = 0, $scevgep5$i$i$i$i = 0, $scevgep5$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg10ReferencedC2Ev($0);
 $1 = ((($0)) + 12|0);
 ;HEAP32[$1>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;
 $2 = ((($0)) + 24|0);
 HEAP32[$2>>2] = 2;
 $3 = ((($0)) + 28|0);
 HEAP32[$3>>2] = 0;
 HEAP32[$0>>2] = (58912);
 $4 = ((($0)) + 32|0);
 __THREW__ = 0;
 $5 = (invoke_i(3285)|0);
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 L1: do {
  if ($7) {
   label = 24;
  } else {
   $8 = HEAP32[$5>>2]|0;
   __THREW__ = 0;
   $9 = (invoke_ii(3286,($8|0))|0);
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if ($11) {
    label = 24;
   } else {
    HEAP32[$4>>2] = 0;
    $12 = ((($0)) + 36|0);
    HEAP32[$12>>2] = 0;
    $13 = ((($0)) + 40|0);
    HEAP32[$13>>2] = 0;
    $14 = ($9|0)==(0);
    do {
     if (!($14)) {
      $15 = ($9>>>0)>(1073741823);
      if ($15) {
       __THREW__ = 0;
       invoke_vi(3307,($4|0));
       $16 = __THREW__; __THREW__ = 0;
      } else {
       $17 = $9 << 2;
       __THREW__ = 0;
       $18 = (invoke_ii(3276,($17|0))|0);
       $19 = __THREW__; __THREW__ = 0;
       $20 = $19&1;
       if (!($20)) {
        HEAP32[$4>>2] = $18;
        $21 = (($18) + ($9<<2)|0);
        $22 = ((($0)) + 40|0);
        HEAP32[$22>>2] = $21;
        _memset(($18|0),0,($17|0))|0;
        HEAP32[$12>>2] = $21;
        break;
       }
      }
      $23 = ___cxa_find_matching_catch_2()|0;
      $24 = tempRet0;
      $25 = HEAP32[$4>>2]|0;
      $26 = ($25|0)==(0|0);
      if ($26) {
       $eh$lpad$body$index3Z2D = $24;$eh$lpad$body$indexZ2D = $23;
       label = 25;
       break L1;
      }
      $27 = HEAP32[$12>>2]|0;
      $28 = ($27|0)==($25|0);
      if (!($28)) {
       $scevgep$i$i$i$i$i = ((($27)) + -4|0);
       $29 = $scevgep$i$i$i$i$i;
       $30 = $25;
       $31 = (($29) - ($30))|0;
       $32 = $31 >>> 2;
       $33 = $32 ^ -1;
       $scevgep5$i$i$i$i$i = (($27) + ($33<<2)|0);
       HEAP32[$12>>2] = $scevgep5$i$i$i$i$i;
      }
      __ZdlPv($25);
      $eh$lpad$body$index3Z2D = $24;$eh$lpad$body$indexZ2D = $23;
      label = 25;
      break L1;
     }
    } while(0);
    $34 = ((($0)) + 44|0);
    __THREW__ = 0;
    $35 = (invoke_i(3285)|0);
    $36 = __THREW__; __THREW__ = 0;
    $37 = $36&1;
    if ($37) {
     label = 26;
    } else {
     $38 = HEAP32[$35>>2]|0;
     __THREW__ = 0;
     $39 = (invoke_ii(3286,($38|0))|0);
     $40 = __THREW__; __THREW__ = 0;
     $41 = $40&1;
     if ($41) {
      label = 26;
     } else {
      HEAP32[$34>>2] = 0;
      $42 = ((($0)) + 48|0);
      HEAP32[$42>>2] = 0;
      $43 = ((($0)) + 52|0);
      HEAP32[$43>>2] = 0;
      $44 = ($39|0)==(0);
      if ($44) {
       $64 = ((($0)) + 56|0);
       HEAP32[$64>>2] = 33190;
       $65 = ((($0)) + 60|0);
       HEAP32[$65>>2] = 512;
       $66 = ((($0)) + 64|0);
       HEAP32[$66>>2] = 512;
       $67 = ((($0)) + 68|0);
       HEAP32[$67>>2] = 0;
       $68 = ((($0)) + 72|0);
       HEAP32[$68>>2] = 0;
       return;
      }
      $45 = ($39>>>0)>(1073741823);
      if ($45) {
       __THREW__ = 0;
       invoke_vi(3307,($34|0));
       $46 = __THREW__; __THREW__ = 0;
      } else {
       $47 = $39 << 2;
       __THREW__ = 0;
       $48 = (invoke_ii(3276,($47|0))|0);
       $49 = __THREW__; __THREW__ = 0;
       $50 = $49&1;
       if (!($50)) {
        HEAP32[$34>>2] = $48;
        $51 = (($48) + ($39<<2)|0);
        $52 = ((($0)) + 52|0);
        HEAP32[$52>>2] = $51;
        _memset(($48|0),0,($47|0))|0;
        HEAP32[$42>>2] = $51;
        $64 = ((($0)) + 56|0);
        HEAP32[$64>>2] = 33190;
        $65 = ((($0)) + 60|0);
        HEAP32[$65>>2] = 512;
        $66 = ((($0)) + 64|0);
        HEAP32[$66>>2] = 512;
        $67 = ((($0)) + 68|0);
        HEAP32[$67>>2] = 0;
        $68 = ((($0)) + 72|0);
        HEAP32[$68>>2] = 0;
        return;
       }
      }
      $53 = ___cxa_find_matching_catch_2()|0;
      $54 = tempRet0;
      $55 = HEAP32[$34>>2]|0;
      $56 = ($55|0)==(0|0);
      if ($56) {
       $eh$lpad$body11$index10Z2D = $54;$eh$lpad$body11$indexZ2D = $53;
      } else {
       $57 = HEAP32[$42>>2]|0;
       $58 = ($57|0)==($55|0);
       if (!($58)) {
        $scevgep$i$i$i$i$i5 = ((($57)) + -4|0);
        $59 = $scevgep$i$i$i$i$i5;
        $60 = $55;
        $61 = (($59) - ($60))|0;
        $62 = $61 >>> 2;
        $63 = $62 ^ -1;
        $scevgep5$i$i$i$i$i6 = (($57) + ($63<<2)|0);
        HEAP32[$42>>2] = $scevgep5$i$i$i$i$i6;
       }
       __ZdlPv($55);
       $eh$lpad$body11$index10Z2D = $54;$eh$lpad$body11$indexZ2D = $53;
      }
     }
    }
    if ((label|0) == 26) {
     $71 = ___cxa_find_matching_catch_2()|0;
     $72 = tempRet0;
     $eh$lpad$body11$index10Z2D = $72;$eh$lpad$body11$indexZ2D = $71;
    }
    $73 = HEAP32[$4>>2]|0;
    $74 = ($73|0)==(0|0);
    if ($74) {
     $$0 = $eh$lpad$body11$index10Z2D;$$02 = $eh$lpad$body11$indexZ2D;
    } else {
     $75 = HEAP32[$12>>2]|0;
     $76 = ($75|0)==($73|0);
     if (!($76)) {
      $scevgep$i$i$i$i = ((($75)) + -4|0);
      $77 = $scevgep$i$i$i$i;
      $78 = $73;
      $79 = (($77) - ($78))|0;
      $80 = $79 >>> 2;
      $81 = $80 ^ -1;
      $scevgep5$i$i$i$i = (($75) + ($81<<2)|0);
      HEAP32[$12>>2] = $scevgep5$i$i$i$i;
     }
     __ZdlPv($73);
     $$0 = $eh$lpad$body11$index10Z2D;$$02 = $eh$lpad$body11$indexZ2D;
    }
   }
  }
 } while(0);
 if ((label|0) == 24) {
  $69 = ___cxa_find_matching_catch_2()|0;
  $70 = tempRet0;
  $eh$lpad$body$index3Z2D = $70;$eh$lpad$body$indexZ2D = $69;
  label = 25;
 }
 if ((label|0) == 25) {
  $$0 = $eh$lpad$body$index3Z2D;$$02 = $eh$lpad$body$indexZ2D;
 }
 __THREW__ = 0;
 invoke_vi(388,($0|0));
 $82 = __THREW__; __THREW__ = 0;
 $83 = $82&1;
 if ($83) {
  $84 = ___cxa_find_matching_catch_3(0|0)|0;
  $85 = tempRet0;
  ___clang_call_terminate($84);
  // unreachable;
 } else {
  ___resumeException($$02|0);
  // unreachable;
 }
}
function __ZN3osg17FrameBufferObjectD2Ev($0) {
 $0 = $0|0;
 var $$01460 = 0, $$pre = 0, $$pre$i30 = 0, $$pre$pre$i26 = 0, $$pre64 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i$i$i15 = 0, $scevgep$i$i$i$i27 = 0, $scevgep$i$i$i$i34 = 0, $scevgep$i$i$i$i37 = 0, $scevgep$i$i$i$i42 = 0, $scevgep$i$i$i$i47 = 0, $scevgep$i$i$i52 = 0, $scevgep5$i$i$i = 0, $scevgep5$i$i$i$i = 0, $scevgep5$i$i$i$i16 = 0, $scevgep5$i$i$i$i28 = 0, $scevgep5$i$i$i$i35 = 0, $scevgep5$i$i$i$i38 = 0, $scevgep5$i$i$i$i43 = 0, $scevgep5$i$i$i$i48 = 0, $scevgep5$i$i$i53 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 HEAP32[$0>>2] = (59060);
 $2 = ((($0)) + 104|0);
 $3 = ((($0)) + 108|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$2>>2]|0;
 $6 = ($4|0)==($5|0);
 $7 = $5;
 $8 = $4;
 L1: do {
  if ($6) {
   $11 = $8;$9 = $7;
  } else {
   $$01460 = 0;$152 = $8;$153 = $7;$154 = $4;$29 = $5;
   while(1) {
    $30 = $29;
    $31 = (($30) + ($$01460<<2)|0);
    $32 = HEAP32[$31>>2]|0;
    $33 = ($32|0)==(0);
    if ($33) {
     $155 = $152;$156 = $153;$72 = $29;$73 = $154;
    } else {
     __THREW__ = 0;
     $34 = (invoke_ii(3683,($$01460|0))|0);
     $35 = __THREW__; __THREW__ = 0;
     $36 = $35&1;
     if ($36) {
      break;
     }
     __THREW__ = 0;
     $37 = (invoke_ii(3685,($34|0))|0);
     $38 = __THREW__; __THREW__ = 0;
     $39 = $38&1;
     if ($39) {
      break;
     }
     $40 = HEAP32[$37>>2]|0;
     $41 = ((($40)) + 44|0);
     $42 = HEAP32[$41>>2]|0;
     $43 = HEAP32[$3>>2]|0;
     $44 = HEAP32[$2>>2]|0;
     $45 = (($43) - ($44))|0;
     $46 = $45 >> 2;
     $47 = ($46>>>0)>($$01460>>>0);
     $48 = $44;
     if ($47) {
      $64 = $48;
     } else {
      $49 = (($$01460) + 1)|0;
      HEAP32[$1>>2] = 0;
      $50 = ($49>>>0)>($46>>>0);
      $51 = $43;
      if ($50) {
       $52 = (($49) - ($46))|0;
       __THREW__ = 0;
       invoke_viii(3755,($2|0),($52|0),($1|0));
       $53 = __THREW__; __THREW__ = 0;
       $54 = $53&1;
       if ($54) {
        break;
       }
       $$pre$pre$i26 = HEAP32[$2>>2]|0;
       $$pre$i30 = $$pre$pre$i26;
      } else {
       $55 = ($49>>>0)<($46>>>0);
       if ($55) {
        $56 = (($48) + ($49<<2)|0);
        $57 = ($51|0)==($56|0);
        if ($57) {
         $$pre$i30 = $48;
        } else {
         $scevgep$i$i$i$i27 = ((($51)) + -4|0);
         $58 = $scevgep$i$i$i$i27;
         $59 = $56;
         $60 = (($58) - ($59))|0;
         $61 = $60 >>> 2;
         $62 = $61 ^ -1;
         $scevgep5$i$i$i$i28 = (($51) + ($62<<2)|0);
         HEAP32[$3>>2] = $scevgep5$i$i$i$i28;
         $$pre$i30 = $48;
        }
       } else {
        $$pre$i30 = $48;
       }
      }
      $64 = $$pre$i30;
     }
     $63 = (($64) + ($$01460<<2)|0);
     $65 = HEAP32[$63>>2]|0;
     __THREW__ = 0;
     invoke_vii($42|0,($37|0),($65|0));
     $66 = __THREW__; __THREW__ = 0;
     $67 = $66&1;
     if ($67) {
      break;
     }
     $$pre = HEAP32[$3>>2]|0;
     $$pre64 = HEAP32[$2>>2]|0;
     $68 = $$pre64;
     $69 = $$pre;
     $155 = $69;$156 = $68;$72 = $$pre64;$73 = $$pre;
    }
    $70 = (($$01460) + 1)|0;
    $71 = (($73) - ($72))|0;
    $74 = $71 >> 2;
    $75 = ($70>>>0)<($74>>>0);
    if ($75) {
     $$01460 = $70;$152 = $155;$153 = $156;$154 = $73;$29 = $72;
    } else {
     $11 = $155;$9 = $156;
     break L1;
    }
   }
   $18 = ___cxa_find_matching_catch_2()|0;
   $19 = tempRet0;
   $20 = HEAP32[$2>>2]|0;
   $21 = ($20|0)==(0|0);
   if (!($21)) {
    $22 = HEAP32[$3>>2]|0;
    $23 = ($22|0)==($20|0);
    if (!($23)) {
     $scevgep$i$i$i$i15 = ((($22)) + -4|0);
     $24 = $scevgep$i$i$i$i15;
     $25 = $20;
     $26 = (($24) - ($25))|0;
     $27 = $26 >>> 2;
     $28 = $27 ^ -1;
     $scevgep5$i$i$i$i16 = (($22) + ($28<<2)|0);
     HEAP32[$3>>2] = $scevgep5$i$i$i$i16;
    }
    __ZdlPv($20);
   }
   $112 = ((($0)) + 92|0);
   $113 = HEAP32[$112>>2]|0;
   $114 = ($113|0)==(0|0);
   if (!($114)) {
    $115 = ((($0)) + 96|0);
    $116 = HEAP32[$115>>2]|0;
    $117 = ($116|0)==($113|0);
    if (!($117)) {
     $scevgep$i$i$i$i42 = ((($116)) + -4|0);
     $118 = $scevgep$i$i$i$i42;
     $119 = $113;
     $120 = (($118) - ($119))|0;
     $121 = $120 >>> 2;
     $122 = $121 ^ -1;
     $scevgep5$i$i$i$i43 = (($116) + ($122<<2)|0);
     HEAP32[$115>>2] = $scevgep5$i$i$i$i43;
    }
    __ZdlPv($113);
   }
   $123 = ((($0)) + 80|0);
   $124 = HEAP32[$123>>2]|0;
   $125 = ($124|0)==(0|0);
   if (!($125)) {
    $126 = ((($0)) + 84|0);
    $127 = HEAP32[$126>>2]|0;
    $128 = ($127|0)==($124|0);
    if (!($128)) {
     $scevgep$i$i$i$i47 = ((($127)) + -4|0);
     $129 = $scevgep$i$i$i$i47;
     $130 = $124;
     $131 = (($129) - ($130))|0;
     $132 = $131 >>> 2;
     $133 = $132 ^ -1;
     $scevgep5$i$i$i$i48 = (($127) + ($133<<2)|0);
     HEAP32[$126>>2] = $scevgep5$i$i$i$i48;
    }
    __ZdlPv($124);
   }
   $134 = ((($0)) + 68|0);
   $135 = HEAP32[$134>>2]|0;
   $136 = ($135|0)==(0|0);
   if (!($136)) {
    $137 = ((($0)) + 72|0);
    $138 = HEAP32[$137>>2]|0;
    $139 = ($138|0)==($135|0);
    if (!($139)) {
     $scevgep$i$i$i52 = ((($138)) + -4|0);
     $140 = $scevgep$i$i$i52;
     $141 = $135;
     $142 = (($140) - ($141))|0;
     $143 = $142 >>> 2;
     $144 = $143 ^ -1;
     $scevgep5$i$i$i53 = (($138) + ($144<<2)|0);
     HEAP32[$137>>2] = $scevgep5$i$i$i53;
    }
    __ZdlPv($135);
   }
   $145 = ((($0)) + 56|0);
   $146 = ((($0)) + 60|0);
   $147 = HEAP32[$146>>2]|0;
   __ZNSt3__26__treeINS_12__value_typeIN3osg6Camera15BufferComponentENS2_21FrameBufferAttachmentEEENS_19__map_value_compareIS4_S6_NS_4lessIS4_EELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($145,$147);
   __THREW__ = 0;
   invoke_vi(1573,($0|0));
   $148 = __THREW__; __THREW__ = 0;
   $149 = $148&1;
   if ($149) {
    $150 = ___cxa_find_matching_catch_3(0|0)|0;
    $151 = tempRet0;
    ___clang_call_terminate($150);
    // unreachable;
   } else {
    ___resumeException($18|0);
    // unreachable;
   }
  }
 } while(0);
 $10 = ($9|0)==(0|0);
 if (!($10)) {
  $12 = ($11|0)==($9|0);
  if (!($12)) {
   $scevgep$i$i$i$i = ((($11)) + -4|0);
   $13 = $scevgep$i$i$i$i;
   $14 = $9;
   $15 = (($13) - ($14))|0;
   $16 = $15 >>> 2;
   $17 = $16 ^ -1;
   $scevgep5$i$i$i$i = (($11) + ($17<<2)|0);
   HEAP32[$3>>2] = $scevgep5$i$i$i$i;
  }
  __ZdlPv($9);
 }
 $76 = ((($0)) + 92|0);
 $77 = HEAP32[$76>>2]|0;
 $78 = ($77|0)==(0|0);
 if (!($78)) {
  $79 = ((($0)) + 96|0);
  $80 = HEAP32[$79>>2]|0;
  $81 = ($80|0)==($77|0);
  if (!($81)) {
   $scevgep$i$i$i$i34 = ((($80)) + -4|0);
   $82 = $scevgep$i$i$i$i34;
   $83 = $77;
   $84 = (($82) - ($83))|0;
   $85 = $84 >>> 2;
   $86 = $85 ^ -1;
   $scevgep5$i$i$i$i35 = (($80) + ($86<<2)|0);
   HEAP32[$79>>2] = $scevgep5$i$i$i$i35;
  }
  __ZdlPv($77);
 }
 $87 = ((($0)) + 80|0);
 $88 = HEAP32[$87>>2]|0;
 $89 = ($88|0)==(0|0);
 if (!($89)) {
  $90 = ((($0)) + 84|0);
  $91 = HEAP32[$90>>2]|0;
  $92 = ($91|0)==($88|0);
  if (!($92)) {
   $scevgep$i$i$i$i37 = ((($91)) + -4|0);
   $93 = $scevgep$i$i$i$i37;
   $94 = $88;
   $95 = (($93) - ($94))|0;
   $96 = $95 >>> 2;
   $97 = $96 ^ -1;
   $scevgep5$i$i$i$i38 = (($91) + ($97<<2)|0);
   HEAP32[$90>>2] = $scevgep5$i$i$i$i38;
  }
  __ZdlPv($88);
 }
 $98 = ((($0)) + 68|0);
 $99 = HEAP32[$98>>2]|0;
 $100 = ($99|0)==(0|0);
 if ($100) {
  $109 = ((($0)) + 56|0);
  $110 = ((($0)) + 60|0);
  $111 = HEAP32[$110>>2]|0;
  __ZNSt3__26__treeINS_12__value_typeIN3osg6Camera15BufferComponentENS2_21FrameBufferAttachmentEEENS_19__map_value_compareIS4_S6_NS_4lessIS4_EELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($109,$111);
  __ZN3osg14StateAttributeD2Ev($0);
  STACKTOP = sp;return;
 }
 $101 = ((($0)) + 72|0);
 $102 = HEAP32[$101>>2]|0;
 $103 = ($102|0)==($99|0);
 if (!($103)) {
  $scevgep$i$i$i = ((($102)) + -4|0);
  $104 = $scevgep$i$i$i;
  $105 = $99;
  $106 = (($104) - ($105))|0;
  $107 = $106 >>> 2;
  $108 = $107 ^ -1;
  $scevgep5$i$i$i = (($102) + ($108<<2)|0);
  HEAP32[$101>>2] = $scevgep5$i$i$i;
 }
 __ZdlPv($99);
 $109 = ((($0)) + 56|0);
 $110 = ((($0)) + 60|0);
 $111 = HEAP32[$110>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIN3osg6Camera15BufferComponentENS2_21FrameBufferAttachmentEEENS_19__map_value_compareIS4_S6_NS_4lessIS4_EELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($109,$111);
 __ZN3osg14StateAttributeD2Ev($0);
 STACKTOP = sp;return;
}
function __ZN3osg17FrameBufferObjectD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1722,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK3osg17FrameBufferObject9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(116)|0);
 __THREW__ = 0;
 invoke_vi(3677,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch_2()|0;
  $5 = tempRet0;
  __ZdlPv($1);
  ___resumeException($4|0);
  // unreachable;
 } else {
  return ($1|0);
 }
 return (0)|0;
}
function __ZNK3osg17FrameBufferObject5cloneERKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(116)|0);
 __THREW__ = 0;
 invoke_viii(3758,($2|0),($0|0),($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch_2()|0;
  $6 = tempRet0;
  __ZdlPv($2);
  ___resumeException($5|0);
  // unreachable;
 } else {
  return ($2|0);
 }
 return (0)|0;
}
function __ZNK3osg17FrameBufferObject12isSameKindAsEPKNS_6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,24568,0)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK3osg17FrameBufferObject11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175113|0);
}
function __ZNK3osg17FrameBufferObject9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (127253|0);
}
function __ZN3osg17FrameBufferObject21resizeGLObjectBuffersEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i$i$i3 = 0, $scevgep$i$i$i$i6 = 0, $scevgep5$i$i$i$i = 0, $scevgep5$i$i$i$i4 = 0;
 var $scevgep5$i$i$i$i7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp + 8|0;
 $3 = sp + 4|0;
 $4 = sp;
 $5 = ((($0)) + 104|0);
 HEAP32[$4>>2] = 0;
 $6 = ((($0)) + 108|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$5>>2]|0;
 $9 = (($7) - ($8))|0;
 $10 = $9 >> 2;
 $11 = ($10>>>0)<($1>>>0);
 $12 = $8;
 $13 = $7;
 if ($11) {
  $14 = (($1) - ($10))|0;
  __ZNSt3__26vectorIjNS_9allocatorIjEEE8__appendEjRKj($5,$14,$4);
 } else {
  $15 = ($10>>>0)>($1>>>0);
  if ($15) {
   $16 = (($12) + ($1<<2)|0);
   $17 = ($13|0)==($16|0);
   if (!($17)) {
    $scevgep$i$i$i$i = ((($13)) + -4|0);
    $18 = $scevgep$i$i$i$i;
    $19 = $16;
    $20 = (($18) - ($19))|0;
    $21 = $20 >>> 2;
    $22 = $21 ^ -1;
    $scevgep5$i$i$i$i = (($13) + ($22<<2)|0);
    HEAP32[$6>>2] = $scevgep5$i$i$i$i;
   }
  }
 }
 $23 = ((($0)) + 92|0);
 HEAP32[$3>>2] = 0;
 $24 = ((($0)) + 96|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = HEAP32[$23>>2]|0;
 $27 = (($25) - ($26))|0;
 $28 = $27 >> 2;
 $29 = ($28>>>0)<($1>>>0);
 $30 = $26;
 $31 = $25;
 if ($29) {
  $32 = (($1) - ($28))|0;
  __ZNSt3__26vectorIiNS_9allocatorIiEEE8__appendEjRKi($23,$32,$3);
 } else {
  $33 = ($28>>>0)>($1>>>0);
  if ($33) {
   $34 = (($30) + ($1<<2)|0);
   $35 = ($31|0)==($34|0);
   if (!($35)) {
    $scevgep$i$i$i$i3 = ((($31)) + -4|0);
    $36 = $scevgep$i$i$i$i3;
    $37 = $34;
    $38 = (($36) - ($37))|0;
    $39 = $38 >>> 2;
    $40 = $39 ^ -1;
    $scevgep5$i$i$i$i4 = (($31) + ($40<<2)|0);
    HEAP32[$24>>2] = $scevgep5$i$i$i$i4;
   }
  }
 }
 HEAP32[$2>>2] = 0;
 $41 = HEAP32[$6>>2]|0;
 $42 = HEAP32[$5>>2]|0;
 $43 = (($41) - ($42))|0;
 $44 = $43 >> 2;
 $45 = ($44>>>0)<($1>>>0);
 $46 = $42;
 $47 = $41;
 if ($45) {
  $48 = (($1) - ($44))|0;
  __ZNSt3__26vectorIjNS_9allocatorIjEEE8__appendEjRKj($5,$48,$2);
  STACKTOP = sp;return;
 }
 $49 = ($44>>>0)>($1>>>0);
 if (!($49)) {
  STACKTOP = sp;return;
 }
 $50 = (($46) + ($1<<2)|0);
 $51 = ($47|0)==($50|0);
 if ($51) {
  STACKTOP = sp;return;
 }
 $scevgep$i$i$i$i6 = ((($47)) + -4|0);
 $52 = $scevgep$i$i$i$i6;
 $53 = $50;
 $54 = (($52) - ($53))|0;
 $55 = $54 >>> 2;
 $56 = $55 ^ -1;
 $scevgep5$i$i$i$i7 = (($47) + ($56<<2)|0);
 HEAP32[$6>>2] = $scevgep5$i$i$i$i7;
 STACKTOP = sp;return;
}
function __ZNK3osg17FrameBufferObject16releaseGLObjectsEPNS_5StateE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$055 = 0, $$pre = 0, $$pre$i = 0, $$pre$i20 = 0, $$pre$i28 = 0, $$pre$i36 = 0, $$pre$i52 = 0, $$pre$pre = 0, $$pre$pre$i = 0, $$pre$pre$i16 = 0, $$pre$pre$i24 = 0, $$pre$pre$i32 = 0, $$pre$pre$i48 = 0, $$pre$pre$pre = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0;
 var $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $scevgep$i$i$i$i = 0;
 var $scevgep$i$i$i$i17 = 0, $scevgep$i$i$i$i25 = 0, $scevgep$i$i$i$i33 = 0, $scevgep$i$i$i$i49 = 0, $scevgep5$i$i$i$i = 0, $scevgep5$i$i$i$i18 = 0, $scevgep5$i$i$i$i26 = 0, $scevgep5$i$i$i$i34 = 0, $scevgep5$i$i$i$i50 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $2 = sp + 16|0;
 $3 = sp + 12|0;
 $4 = sp + 8|0;
 $5 = sp + 4|0;
 $6 = sp;
 $7 = ($1|0)==(0|0);
 if ($7) {
  $8 = ((($0)) + 104|0);
  $9 = ((($0)) + 108|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = HEAP32[$8>>2]|0;
  $12 = ($10|0)==($11|0);
  if ($12) {
   STACKTOP = sp;return;
  }
  $$055 = 0;$144 = $10;$85 = $11;
  while(1) {
   $86 = $85;
   $87 = (($86) + ($$055<<2)|0);
   $88 = HEAP32[$87>>2]|0;
   $89 = ($88|0)==(0);
   if ($89) {
    $140 = $85;$141 = $144;
   } else {
    $90 = (__ZN3osg22getOrCreateContextDataEj($$055)|0);
    $91 = (__ZN3osg11ContextData3getINS_26GLFrameBufferObjectManagerEEEPT_v($90)|0);
    $92 = HEAP32[$91>>2]|0;
    $93 = ((($92)) + 44|0);
    $94 = HEAP32[$93>>2]|0;
    $95 = HEAP32[$9>>2]|0;
    $96 = HEAP32[$8>>2]|0;
    $97 = (($95) - ($96))|0;
    $98 = $97 >> 2;
    $99 = ($98>>>0)>($$055>>>0);
    $100 = $96;
    if ($99) {
     $114 = $100;
    } else {
     $101 = (($$055) + 1)|0;
     HEAP32[$2>>2] = 0;
     $102 = ($101>>>0)>($98>>>0);
     $103 = $95;
     if ($102) {
      $104 = (($101) - ($98))|0;
      __ZNSt3__26vectorIjNS_9allocatorIjEEE8__appendEjRKj($8,$104,$2);
      $$pre$pre$i48 = HEAP32[$8>>2]|0;
      $$pre$i52 = $$pre$pre$i48;
     } else {
      $105 = ($101>>>0)<($98>>>0);
      if ($105) {
       $106 = (($100) + ($101<<2)|0);
       $107 = ($103|0)==($106|0);
       if ($107) {
        $$pre$i52 = $100;
       } else {
        $scevgep$i$i$i$i49 = ((($103)) + -4|0);
        $108 = $scevgep$i$i$i$i49;
        $109 = $106;
        $110 = (($108) - ($109))|0;
        $111 = $110 >>> 2;
        $112 = $111 ^ -1;
        $scevgep5$i$i$i$i50 = (($103) + ($112<<2)|0);
        HEAP32[$9>>2] = $scevgep5$i$i$i$i50;
        $$pre$i52 = $100;
       }
      } else {
       $$pre$i52 = $100;
      }
     }
     $114 = $$pre$i52;
    }
    $113 = (($114) + ($$055<<2)|0);
    $115 = HEAP32[$113>>2]|0;
    FUNCTION_TABLE_vii[$94 & 8191]($91,$115);
    $116 = HEAP32[$9>>2]|0;
    $117 = HEAP32[$8>>2]|0;
    $118 = (($116) - ($117))|0;
    $119 = $118 >> 2;
    $120 = ($119>>>0)>($$055>>>0);
    $121 = $117;
    if ($120) {
     $$pre = $116;$137 = $121;$145 = $117;
    } else {
     $122 = (($$055) + 1)|0;
     HEAP32[$6>>2] = 0;
     $123 = ($122>>>0)>($119>>>0);
     $124 = $116;
     if ($123) {
      $125 = (($122) - ($119))|0;
      __ZNSt3__26vectorIjNS_9allocatorIjEEE8__appendEjRKj($8,$125,$6);
      $$pre$pre$i = HEAP32[$8>>2]|0;
      $126 = $$pre$pre$i;
      $$pre$pre$pre = HEAP32[$9>>2]|0;
      $$pre$i = $$pre$pre$i;$$pre$pre = $$pre$pre$pre;$146 = $126;
     } else {
      $127 = ($122>>>0)<($119>>>0);
      if ($127) {
       $128 = (($121) + ($122<<2)|0);
       $129 = ($124|0)==($128|0);
       if ($129) {
        $$pre$i = $121;$$pre$pre = $116;$146 = $117;
       } else {
        $scevgep$i$i$i$i = ((($124)) + -4|0);
        $130 = $scevgep$i$i$i$i;
        $131 = $128;
        $132 = (($130) - ($131))|0;
        $133 = $132 >>> 2;
        $134 = $133 ^ -1;
        $scevgep5$i$i$i$i = (($124) + ($134<<2)|0);
        HEAP32[$9>>2] = $scevgep5$i$i$i$i;
        $135 = $scevgep5$i$i$i$i;
        $$pre$i = $121;$$pre$pre = $135;$146 = $117;
       }
      } else {
       $$pre$i = $121;$$pre$pre = $116;$146 = $117;
      }
     }
     $$pre = $$pre$pre;$137 = $$pre$i;$145 = $146;
    }
    $136 = (($137) + ($$055<<2)|0);
    HEAP32[$136>>2] = 0;
    $140 = $145;$141 = $$pre;
   }
   $138 = (($$055) + 1)|0;
   $139 = (($141) - ($140))|0;
   $142 = $139 >> 2;
   $143 = ($138>>>0)<($142>>>0);
   if ($143) {
    $$055 = $138;$144 = $141;$85 = $140;
   } else {
    break;
   }
  }
  STACKTOP = sp;return;
 }
 $13 = ((($1)) + 124|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ((($0)) + 104|0);
 $16 = ((($0)) + 108|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = HEAP32[$15>>2]|0;
 $19 = (($17) - ($18))|0;
 $20 = $19 >> 2;
 $21 = ($20>>>0)>($14>>>0);
 $22 = $18;
 if ($21) {
  $36 = $22;
 } else {
  $23 = (($14) + 1)|0;
  HEAP32[$5>>2] = 0;
  $24 = ($23>>>0)>($20>>>0);
  $25 = $17;
  if ($24) {
   $26 = (($23) - ($20))|0;
   __ZNSt3__26vectorIjNS_9allocatorIjEEE8__appendEjRKj($15,$26,$5);
   $$pre$pre$i16 = HEAP32[$15>>2]|0;
   $$pre$i20 = $$pre$pre$i16;
  } else {
   $27 = ($23>>>0)<($20>>>0);
   if ($27) {
    $28 = (($22) + ($23<<2)|0);
    $29 = ($25|0)==($28|0);
    if ($29) {
     $$pre$i20 = $22;
    } else {
     $scevgep$i$i$i$i17 = ((($25)) + -4|0);
     $30 = $scevgep$i$i$i$i17;
     $31 = $28;
     $32 = (($30) - ($31))|0;
     $33 = $32 >>> 2;
     $34 = $33 ^ -1;
     $scevgep5$i$i$i$i18 = (($25) + ($34<<2)|0);
     HEAP32[$16>>2] = $scevgep5$i$i$i$i18;
     $$pre$i20 = $22;
    }
   } else {
    $$pre$i20 = $22;
   }
  }
  $36 = $$pre$i20;
 }
 $35 = (($36) + ($14<<2)|0);
 $37 = HEAP32[$35>>2]|0;
 $38 = ($37|0)==(0);
 if ($38) {
  STACKTOP = sp;return;
 }
 $39 = (__ZN3osg22getOrCreateContextDataEj($14)|0);
 $40 = (__ZN3osg11ContextData3getINS_26GLFrameBufferObjectManagerEEEPT_v($39)|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = ((($41)) + 44|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = HEAP32[$16>>2]|0;
 $45 = HEAP32[$15>>2]|0;
 $46 = (($44) - ($45))|0;
 $47 = $46 >> 2;
 $48 = ($47>>>0)>($14>>>0);
 $49 = $45;
 if ($48) {
  $63 = $49;
 } else {
  $50 = (($14) + 1)|0;
  HEAP32[$4>>2] = 0;
  $51 = ($50>>>0)>($47>>>0);
  $52 = $44;
  if ($51) {
   $53 = (($50) - ($47))|0;
   __ZNSt3__26vectorIjNS_9allocatorIjEEE8__appendEjRKj($15,$53,$4);
   $$pre$pre$i24 = HEAP32[$15>>2]|0;
   $$pre$i28 = $$pre$pre$i24;
  } else {
   $54 = ($50>>>0)<($47>>>0);
   if ($54) {
    $55 = (($49) + ($50<<2)|0);
    $56 = ($52|0)==($55|0);
    if ($56) {
     $$pre$i28 = $49;
    } else {
     $scevgep$i$i$i$i25 = ((($52)) + -4|0);
     $57 = $scevgep$i$i$i$i25;
     $58 = $55;
     $59 = (($57) - ($58))|0;
     $60 = $59 >>> 2;
     $61 = $60 ^ -1;
     $scevgep5$i$i$i$i26 = (($52) + ($61<<2)|0);
     HEAP32[$16>>2] = $scevgep5$i$i$i$i26;
     $$pre$i28 = $49;
    }
   } else {
    $$pre$i28 = $49;
   }
  }
  $63 = $$pre$i28;
 }
 $62 = (($63) + ($14<<2)|0);
 $64 = HEAP32[$62>>2]|0;
 FUNCTION_TABLE_vii[$43 & 8191]($40,$64);
 $65 = HEAP32[$16>>2]|0;
 $66 = HEAP32[$15>>2]|0;
 $67 = (($65) - ($66))|0;
 $68 = $67 >> 2;
 $69 = ($68>>>0)>($14>>>0);
 $70 = $66;
 if ($69) {
  $84 = $70;
 } else {
  $71 = (($14) + 1)|0;
  HEAP32[$3>>2] = 0;
  $72 = ($71>>>0)>($68>>>0);
  $73 = $65;
  if ($72) {
   $74 = (($71) - ($68))|0;
   __ZNSt3__26vectorIjNS_9allocatorIjEEE8__appendEjRKj($15,$74,$3);
   $$pre$pre$i32 = HEAP32[$15>>2]|0;
   $$pre$i36 = $$pre$pre$i32;
  } else {
   $75 = ($71>>>0)<($68>>>0);
   if ($75) {
    $76 = (($70) + ($71<<2)|0);
    $77 = ($73|0)==($76|0);
    if ($77) {
     $$pre$i36 = $70;
    } else {
     $scevgep$i$i$i$i33 = ((($73)) + -4|0);
     $78 = $scevgep$i$i$i$i33;
     $79 = $76;
     $80 = (($78) - ($79))|0;
     $81 = $80 >>> 2;
     $82 = $81 ^ -1;
     $scevgep5$i$i$i$i34 = (($73) + ($82<<2)|0);
     HEAP32[$16>>2] = $scevgep5$i$i$i$i34;
     $$pre$i36 = $70;
    }
   } else {
    $$pre$i36 = $70;
   }
  }
  $84 = $$pre$i36;
 }
 $83 = (($84) + ($14<<2)|0);
 HEAP32[$83>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNK3osg17FrameBufferObject7getTypeEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 55;
}
function __ZNK3osg17FrameBufferObject7compareERKNS_14StateAttributeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$$$i = 0, $$$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i23 = 0, $$0$i$i$i27 = 0, $$5 = 0, $$sroa$030$0$be = 0, $$sroa$030$044 = 0, $$sroa$033$045 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($0|0)==($1|0);
 if ($2) {
  $$5 = 0;
  return ($$5|0);
 }
 $3 = ($0|0)==(0|0);
 if ($3) {
  ___cxa_bad_typeid();
  // unreachable;
 }
 $4 = HEAP32[$0>>2]|0;
 $5 = ((($4)) + -4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$1>>2]|0;
 $8 = ((($7)) + -4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($6)) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($9)) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($11>>>0)<($13>>>0);
 if ($14) {
  $$5 = -1;
  return ($$5|0);
 }
 $15 = ($11|0)==($13|0);
 if (!($15)) {
  $$5 = 1;
  return ($$5|0);
 }
 $16 = ((($0)) + 64|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ((($1)) + 56|0);
 $19 = ((($1)) + 64|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($17>>>0)<($20>>>0);
 if ($21) {
  $$5 = -1;
  return ($$5|0);
 }
 $22 = ($20>>>0)<($17>>>0);
 if ($22) {
  $$5 = 1;
  return ($$5|0);
 }
 $23 = ((($0)) + 56|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ((($0)) + 60|0);
 $26 = ($24|0)==($25|0);
 if ($26) {
  $$5 = 0;
  return ($$5|0);
 }
 $27 = HEAP32[$18>>2]|0;
 $$sroa$030$044 = $27;$$sroa$033$045 = $24;
 while(1) {
  $28 = ($$sroa$030$044|0)==($$sroa$033$045|0);
  if (!($28)) {
   $29 = ((($$sroa$030$044)) + 20|0);
   $30 = ((($$sroa$033$045)) + 20|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = HEAP32[$31>>2]|0;
   $33 = HEAP32[$29>>2]|0;
   $34 = HEAP32[$33>>2]|0;
   $35 = ($32|0)<($34|0);
   if ($35) {
    $$5 = -1;
    label = 33;
    break;
   }
   $36 = ($32|0)>($34|0);
   if ($36) {
    $$5 = 1;
    label = 33;
    break;
   }
   $37 = ((($31)) + 4|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = ((($33)) + 4|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = ($38>>>0)<($40>>>0);
   if ($41) {
    $$5 = -1;
    label = 33;
    break;
   }
   $42 = ($38>>>0)>($40>>>0);
   if ($42) {
    $$5 = 1;
    label = 33;
    break;
   }
   $43 = ((($31)) + 8|0);
   $44 = HEAP32[$43>>2]|0;
   $45 = ((($33)) + 8|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = ($44>>>0)<($46>>>0);
   if ($47) {
    $$5 = -1;
    label = 33;
    break;
   }
   $48 = ($44>>>0)>($46>>>0);
   if ($48) {
    $$5 = 1;
    label = 33;
    break;
   }
   $49 = ((($31)) + 12|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = ((($33)) + 12|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = ($50>>>0)<($52>>>0);
   if ($53) {
    $$5 = -1;
    label = 33;
    break;
   }
   $54 = ($50>>>0)>($52>>>0);
   if ($54) {
    $$5 = 1;
    label = 33;
    break;
   }
   $55 = ((($31)) + 16|0);
   $56 = HEAP32[$55>>2]|0;
   $57 = ((($33)) + 16|0);
   $58 = HEAP32[$57>>2]|0;
   $59 = ($56>>>0)<($58>>>0);
   if ($59) {
    $$5 = -1;
    label = 33;
    break;
   }
   $60 = ($56>>>0)>($58>>>0);
   if ($60) {
    $$5 = 1;
    label = 33;
    break;
   }
   $61 = ((($31)) + 20|0);
   $62 = HEAP32[$61>>2]|0;
   $63 = ((($33)) + 20|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = ($62>>>0)<($64>>>0);
   $66 = ($62>>>0)>($64>>>0);
   $$$i = $66&1;
   $$$$i = $65 ? -1 : $$$i;
   $67 = ($$$$i|0)==(0);
   if (!($67)) {
    $$5 = $$$$i;
    label = 33;
    break;
   }
  }
  $68 = ((($$sroa$033$045)) + 4|0);
  $69 = HEAP32[$68>>2]|0;
  $70 = ($69|0)==(0|0);
  if ($70) {
   $71 = ((($$sroa$033$045)) + 8|0);
   $72 = HEAP32[$71>>2]|0;
   $73 = HEAP32[$72>>2]|0;
   $74 = ($73|0)==($$sroa$033$045|0);
   if ($74) {
    $$0$i$i$i27 = $72;
   } else {
    $78 = $71;
    while(1) {
     $77 = HEAP32[$78>>2]|0;
     $79 = ((($77)) + 8|0);
     $80 = HEAP32[$79>>2]|0;
     $81 = HEAP32[$80>>2]|0;
     $82 = ($81|0)==($77|0);
     if ($82) {
      $$0$i$i$i27 = $80;
      break;
     } else {
      $78 = $79;
     }
    }
   }
  } else {
   $$0$i$i$i$i23 = $69;
   while(1) {
    $75 = HEAP32[$$0$i$i$i$i23>>2]|0;
    $76 = ($75|0)==(0|0);
    if ($76) {
     break;
    } else {
     $$0$i$i$i$i23 = $75;
    }
   }
   $$0$i$i$i27 = $$0$i$i$i$i23;
  }
  $83 = ((($$sroa$030$044)) + 4|0);
  $84 = HEAP32[$83>>2]|0;
  $85 = ($84|0)==(0|0);
  if ($85) {
   $86 = ((($$sroa$030$044)) + 8|0);
   $87 = HEAP32[$86>>2]|0;
   $88 = HEAP32[$87>>2]|0;
   $89 = ($88|0)==($$sroa$030$044|0);
   if ($89) {
    $$sroa$030$0$be = $87;
   } else {
    $94 = $86;
    while(1) {
     $93 = HEAP32[$94>>2]|0;
     $95 = ((($93)) + 8|0);
     $96 = HEAP32[$95>>2]|0;
     $97 = HEAP32[$96>>2]|0;
     $98 = ($97|0)==($93|0);
     if ($98) {
      $$sroa$030$0$be = $96;
      break;
     } else {
      $94 = $95;
     }
    }
   }
  } else {
   $$0$i$i$i$i = $84;
   while(1) {
    $91 = HEAP32[$$0$i$i$i$i>>2]|0;
    $92 = ($91|0)==(0|0);
    if ($92) {
     break;
    } else {
     $$0$i$i$i$i = $91;
    }
   }
   $$sroa$030$0$be = $$0$i$i$i$i;
  }
  $90 = ($$0$i$i$i27|0)==($25|0);
  if ($90) {
   $$5 = 0;
   label = 33;
   break;
  } else {
   $$sroa$030$044 = $$sroa$030$0$be;$$sroa$033$045 = $$0$i$i$i27;
  }
 }
 if ((label|0) == 33) {
  return ($$5|0);
 }
 return (0)|0;
}
function __ZNK3osg17FrameBufferObject5applyERNS_5StateE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNK3osg17FrameBufferObject5applyERNS_5StateENS0_10BindTargetE($0,$1,36160);
 return;
}
function __ZNK3osg17FrameBufferObject5applyERNS_5StateENS0_10BindTargetE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i89 = 0, $$1 = 0, $$164 = 0, $$pr = 0, $$pre = 0, $$pre$i = 0, $$pre$i70 = 0, $$pre$i78 = 0, $$pre$i86 = 0, $$pre$pre$i = 0, $$pre$pre$i66 = 0, $$pre$pre$i74 = 0, $$pre$pre$i82 = 0, $$sroa$0107$0$be = 0, $$sroa$0107$0119 = 0, $$sroa$098$0$be = 0, $$sroa$098$0118 = 0, $10 = 0;
 var $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0;
 var $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0;
 var $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0;
 var $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0;
 var $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0;
 var $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0;
 var $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0;
 var $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0;
 var $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0;
 var $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0;
 var $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i$i$i67 = 0, $scevgep$i$i$i$i75 = 0, $scevgep$i$i$i$i83 = 0, $scevgep5$i$i$i$i = 0, $scevgep5$i$i$i$i68 = 0;
 var $scevgep5$i$i$i$i76 = 0, $scevgep5$i$i$i$i84 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $3 = sp + 28|0;
 $4 = sp + 24|0;
 $5 = sp + 20|0;
 $6 = sp + 16|0;
 $7 = sp + 12|0;
 $8 = sp + 8|0;
 $9 = sp + 4|0;
 $10 = sp;
 $11 = ((($1)) + 124|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ((($0)) + 92|0);
 $14 = ((($0)) + 96|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP32[$13>>2]|0;
 $17 = (($15) - ($16))|0;
 $18 = $17 >> 2;
 $19 = ($18>>>0)>($12>>>0);
 $20 = $16;
 if ($19) {
  $35 = $20;$45 = $16;
 } else {
  $21 = (($12) + 1)|0;
  HEAP32[$10>>2] = 0;
  $22 = ($21>>>0)>($18>>>0);
  $23 = $15;
  if ($22) {
   $24 = (($21) - ($18))|0;
   __ZNSt3__26vectorIiNS_9allocatorIiEEE8__appendEjRKi($13,$24,$10);
   $$pre$pre$i = HEAP32[$13>>2]|0;
   $25 = $$pre$pre$i;
   $$pre$i = $$pre$pre$i;$297 = $25;
  } else {
   $26 = ($21>>>0)<($18>>>0);
   if ($26) {
    $27 = (($20) + ($21<<2)|0);
    $28 = ($23|0)==($27|0);
    if ($28) {
     $$pre$i = $20;$297 = $16;
    } else {
     $scevgep$i$i$i$i = ((($23)) + -4|0);
     $29 = $scevgep$i$i$i$i;
     $30 = $27;
     $31 = (($29) - ($30))|0;
     $32 = $31 >>> 2;
     $33 = $32 ^ -1;
     $scevgep5$i$i$i$i = (($23) + ($33<<2)|0);
     HEAP32[$14>>2] = $scevgep5$i$i$i$i;
     $$pre$i = $20;$297 = $16;
    }
   } else {
    $$pre$i = $20;$297 = $16;
   }
  }
  $35 = $$pre$i;$45 = $297;
 }
 $34 = (($35) + ($12<<2)|0);
 $36 = HEAP32[$34>>2]|0;
 $37 = ($36|0)==(0);
 if (!($37)) {
  STACKTOP = sp;return;
 }
 $38 = ((($1)) + 784|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = ((($39)) + 1252|0);
 $41 = HEAP8[$40>>0]|0;
 $42 = ($41<<24>>24)==(0);
 if ($42) {
  $43 = HEAP32[$14>>2]|0;
  $44 = (($43) - ($45))|0;
  $46 = $44 >> 2;
  $47 = ($46>>>0)>($12>>>0);
  $48 = $45;
  if ($47) {
   $62 = $48;
  } else {
   $49 = (($12) + 1)|0;
   HEAP32[$9>>2] = 0;
   $50 = ($49>>>0)>($46>>>0);
   $51 = $43;
   if ($50) {
    $52 = (($49) - ($46))|0;
    __ZNSt3__26vectorIiNS_9allocatorIiEEE8__appendEjRKi($13,$52,$9);
    $$pre$pre$i66 = HEAP32[$13>>2]|0;
    $$pre$i70 = $$pre$pre$i66;
   } else {
    $53 = ($49>>>0)<($46>>>0);
    if ($53) {
     $54 = (($48) + ($49<<2)|0);
     $55 = ($51|0)==($54|0);
     if ($55) {
      $$pre$i70 = $48;
     } else {
      $scevgep$i$i$i$i67 = ((($51)) + -4|0);
      $56 = $scevgep$i$i$i$i67;
      $57 = $54;
      $58 = (($56) - ($57))|0;
      $59 = $58 >>> 2;
      $60 = $59 ^ -1;
      $scevgep5$i$i$i$i68 = (($51) + ($60<<2)|0);
      HEAP32[$14>>2] = $scevgep5$i$i$i$i68;
      $$pre$i70 = $48;
     }
    } else {
     $$pre$i70 = $48;
    }
   }
   $62 = $$pre$i70;
  }
  $61 = (($62) + ($12<<2)|0);
  HEAP32[$61>>2] = 1;
  $63 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
  if (!($63)) {
   STACKTOP = sp;return;
  }
  $64 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
  $65 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($64,126832,48)|0);
  $66 = HEAP32[$65>>2]|0;
  $67 = ((($66)) + -12|0);
  $68 = HEAP32[$67>>2]|0;
  $69 = (($65) + ($68)|0);
  __ZNKSt3__28ios_base6getlocEv($8,$69);
  __THREW__ = 0;
  $70 = (invoke_iii(3255,($8|0),(215188|0))|0);
  $71 = __THREW__; __THREW__ = 0;
  $72 = $71&1;
  if (!($72)) {
   $73 = HEAP32[$70>>2]|0;
   $74 = ((($73)) + 28|0);
   $75 = HEAP32[$74>>2]|0;
   __THREW__ = 0;
   $76 = (invoke_iii($75|0,($70|0),10)|0);
   $77 = __THREW__; __THREW__ = 0;
   $78 = $77&1;
   if (!($78)) {
    __ZNSt3__26localeD2Ev($8);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($65,$76)|0);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($65)|0);
    STACKTOP = sp;return;
   }
  }
  $79 = ___cxa_find_matching_catch_2()|0;
  $80 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3263,($8|0));
  $81 = __THREW__; __THREW__ = 0;
  $82 = $81&1;
  if ($82) {
   $83 = ___cxa_find_matching_catch_3(0|0)|0;
   $84 = tempRet0;
   ___clang_call_terminate($83);
   // unreachable;
  } else {
   ___resumeException($79|0);
   // unreachable;
  }
 }
 $85 = ((($0)) + 56|0);
 $86 = ((($0)) + 64|0);
 $87 = HEAP32[$86>>2]|0;
 $88 = ($87|0)==(0);
 if ($88) {
  $89 = ((($39)) + 1280|0);
  $90 = HEAP32[$89>>2]|0;
  FUNCTION_TABLE_vii[$90 & 8191]($2,0);
  STACKTOP = sp;return;
 }
 $91 = ((($0)) + 80|0);
 $92 = ((($0)) + 84|0);
 $93 = HEAP32[$92>>2]|0;
 $94 = HEAP32[$91>>2]|0;
 $95 = (($93) - ($94))|0;
 $96 = $95 >> 2;
 $97 = ($96>>>0)>($12>>>0);
 $98 = $94;
 if ($97) {
  $112 = $98;
 } else {
  $99 = (($12) + 1)|0;
  HEAP32[$7>>2] = 0;
  $100 = ($99>>>0)>($96>>>0);
  $101 = $93;
  if ($100) {
   $102 = (($99) - ($96))|0;
   __ZNSt3__26vectorIiNS_9allocatorIiEEE8__appendEjRKi($91,$102,$7);
   $$pre$pre$i74 = HEAP32[$91>>2]|0;
   $$pre$i78 = $$pre$pre$i74;
  } else {
   $103 = ($99>>>0)<($96>>>0);
   if ($103) {
    $104 = (($98) + ($99<<2)|0);
    $105 = ($101|0)==($104|0);
    if ($105) {
     $$pre$i78 = $98;
    } else {
     $scevgep$i$i$i$i75 = ((($101)) + -4|0);
     $106 = $scevgep$i$i$i$i75;
     $107 = $104;
     $108 = (($106) - ($107))|0;
     $109 = $108 >>> 2;
     $110 = $109 ^ -1;
     $scevgep5$i$i$i$i76 = (($101) + ($110<<2)|0);
     HEAP32[$92>>2] = $scevgep5$i$i$i$i76;
     $$pre$i78 = $98;
    }
   } else {
    $$pre$i78 = $98;
   }
  }
  $112 = $$pre$i78;
 }
 $111 = (($112) + ($12<<2)|0);
 $113 = ((($0)) + 104|0);
 $114 = ((($0)) + 108|0);
 $115 = HEAP32[$114>>2]|0;
 $116 = HEAP32[$113>>2]|0;
 $117 = (($115) - ($116))|0;
 $118 = $117 >> 2;
 $119 = ($118>>>0)>($12>>>0);
 $120 = $116;
 if ($119) {
  $134 = $120;
 } else {
  $121 = (($12) + 1)|0;
  HEAP32[$6>>2] = 0;
  $122 = ($121>>>0)>($118>>>0);
  $123 = $115;
  if ($122) {
   $124 = (($121) - ($118))|0;
   __ZNSt3__26vectorIjNS_9allocatorIjEEE8__appendEjRKj($113,$124,$6);
   $$pre$pre$i82 = HEAP32[$113>>2]|0;
   $$pre$i86 = $$pre$pre$i82;
  } else {
   $125 = ($121>>>0)<($118>>>0);
   if ($125) {
    $126 = (($120) + ($121<<2)|0);
    $127 = ($123|0)==($126|0);
    if ($127) {
     $$pre$i86 = $120;
    } else {
     $scevgep$i$i$i$i83 = ((($123)) + -4|0);
     $128 = $scevgep$i$i$i$i83;
     $129 = $126;
     $130 = (($128) - ($129))|0;
     $131 = $130 >>> 2;
     $132 = $131 ^ -1;
     $scevgep5$i$i$i$i84 = (($123) + ($132<<2)|0);
     HEAP32[$114>>2] = $scevgep5$i$i$i$i84;
     $$pre$i86 = $120;
    }
   } else {
    $$pre$i86 = $120;
   }
  }
  $134 = $$pre$i86;
 }
 $133 = (($134) + ($12<<2)|0);
 $135 = HEAP32[$133>>2]|0;
 $136 = ($135|0)==(0);
 do {
  if ($136) {
   $137 = ((($39)) + 1288|0);
   $138 = HEAP32[$137>>2]|0;
   FUNCTION_TABLE_vii[$138 & 8191](1,$133);
   $139 = HEAP32[$133>>2]|0;
   $140 = ($139|0)==(0);
   if (!($140)) {
    HEAP32[$111>>2] = 1;
    label = 51;
    break;
   }
   $141 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
   if (!($141)) {
    STACKTOP = sp;return;
   }
   $142 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
   $143 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($142,126881,52)|0);
   $144 = HEAP32[$143>>2]|0;
   $145 = ((($144)) + -12|0);
   $146 = HEAP32[$145>>2]|0;
   $147 = (($143) + ($146)|0);
   __ZNKSt3__28ios_base6getlocEv($5,$147);
   __THREW__ = 0;
   $148 = (invoke_iii(3255,($5|0),(215188|0))|0);
   $149 = __THREW__; __THREW__ = 0;
   $150 = $149&1;
   if (!($150)) {
    $151 = HEAP32[$148>>2]|0;
    $152 = ((($151)) + 28|0);
    $153 = HEAP32[$152>>2]|0;
    __THREW__ = 0;
    $154 = (invoke_iii($153|0,($148|0),10)|0);
    $155 = __THREW__; __THREW__ = 0;
    $156 = $155&1;
    if (!($156)) {
     __ZNSt3__26localeD2Ev($5);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($143,$154)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($143)|0);
     STACKTOP = sp;return;
    }
   }
   $157 = ___cxa_find_matching_catch_2()|0;
   $158 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($5|0));
   $159 = __THREW__; __THREW__ = 0;
   $160 = $159&1;
   if ($160) {
    $161 = ___cxa_find_matching_catch_3(0|0)|0;
    $162 = tempRet0;
    ___clang_call_terminate($161);
    // unreachable;
   } else {
    ___resumeException($157|0);
    // unreachable;
   }
  } else {
   $$pr = HEAP32[$111>>2]|0;
   $163 = ($$pr|0)==(0);
   if ($163) {
    $209 = $135;
   } else {
    label = 51;
   }
  }
 } while(0);
 if ((label|0) == 51) {
  $164 = HEAP8[206032]|0;
  $165 = ($164<<24>>24)==(0);
  do {
   if ($165) {
    $166 = (___cxa_guard_acquire(206032)|0);
    $167 = ($166|0)==(0);
    if (!($167)) {
     __THREW__ = 0;
     invoke_vii(3507,(208220|0),0);
     $168 = __THREW__; __THREW__ = 0;
     $169 = $168&1;
     if (!($169)) {
      (___cxa_atexit((707|0),(208220|0),(___dso_handle|0))|0);
      break;
     }
     $179 = ___cxa_find_matching_catch_2()|0;
     $180 = tempRet0;
     $$1 = $179;$$164 = $180;
     ___resumeException($$1|0);
     // unreachable;
    }
   }
  } while(0);
  $170 = HEAP32[52055]|0;
  $171 = ((($170)) + 8|0);
  $172 = HEAP32[$171>>2]|0;
  (FUNCTION_TABLE_ii[$172 & 8191](208220)|0);
  $173 = HEAP32[$85>>2]|0;
  $174 = ((($0)) + 60|0);
  $175 = ($173|0)==($174|0);
  L85: do {
   if (!($175)) {
    $$sroa$0107$0119 = $173;
    while(1) {
     $181 = ((($$sroa$0107$0119)) + 20|0);
     __THREW__ = 0;
     invoke_viii(3759,($181|0),($1|0),($39|0));
     $182 = __THREW__; __THREW__ = 0;
     $183 = $182&1;
     if ($183) {
      break;
     }
     $184 = ((($$sroa$0107$0119)) + 4|0);
     $185 = HEAP32[$184>>2]|0;
     $186 = ($185|0)==(0|0);
     if ($186) {
      $187 = ((($$sroa$0107$0119)) + 8|0);
      $188 = HEAP32[$187>>2]|0;
      $189 = HEAP32[$188>>2]|0;
      $190 = ($189|0)==($$sroa$0107$0119|0);
      if ($190) {
       $$sroa$0107$0$be = $188;
      } else {
       $195 = $187;
       while(1) {
        $194 = HEAP32[$195>>2]|0;
        $196 = ((($194)) + 8|0);
        $197 = HEAP32[$196>>2]|0;
        $198 = HEAP32[$197>>2]|0;
        $199 = ($198|0)==($194|0);
        if ($199) {
         $$sroa$0107$0$be = $197;
         break;
        } else {
         $195 = $196;
        }
       }
      }
     } else {
      $$0$i$i$i$i89 = $185;
      while(1) {
       $192 = HEAP32[$$0$i$i$i$i89>>2]|0;
       $193 = ($192|0)==(0|0);
       if ($193) {
        break;
       } else {
        $$0$i$i$i$i89 = $192;
       }
      }
      $$sroa$0107$0$be = $$0$i$i$i$i89;
     }
     $191 = ($$sroa$0107$0$be|0)==($174|0);
     if ($191) {
      break L85;
     } else {
      $$sroa$0107$0119 = $$sroa$0107$0$be;
     }
    }
    $200 = ___cxa_find_matching_catch_2()|0;
    $201 = tempRet0;
    $202 = HEAP32[52055]|0;
    $203 = ((($202)) + 12|0);
    $204 = HEAP32[$203>>2]|0;
    __THREW__ = 0;
    (invoke_ii($204|0,(208220|0))|0);
    $205 = __THREW__; __THREW__ = 0;
    $206 = $205&1;
    if ($206) {
     $295 = ___cxa_find_matching_catch_3(0|0)|0;
     $296 = tempRet0;
     ___clang_call_terminate($295);
     // unreachable;
    } else {
     $$1 = $200;$$164 = $201;
     ___resumeException($$1|0);
     // unreachable;
    }
   }
  } while(0);
  $176 = HEAP32[52055]|0;
  $177 = ((($176)) + 12|0);
  $178 = HEAP32[$177>>2]|0;
  (FUNCTION_TABLE_ii[$178 & 8191](208220)|0);
  $$pre = HEAP32[$133>>2]|0;
  $209 = $$pre;
 }
 $207 = ((($39)) + 1280|0);
 $208 = HEAP32[$207>>2]|0;
 FUNCTION_TABLE_vii[$208 & 8191]($2,$209);
 L103: do {
  switch ($2|0) {
  case 36009: case 36160:  {
   $210 = ((($0)) + 68|0);
   $211 = ((($0)) + 72|0);
   $212 = HEAP32[$211>>2]|0;
   $213 = HEAP32[$210>>2]|0;
   $214 = (($212) - ($213))|0;
   $215 = $214 >> 2;
   $216 = ($215|0)==(0);
   $217 = $213;
   if (!($216)) {
    $218 = HEAP32[$38>>2]|0;
    $219 = ($218|0)==(0|0);
    if (!($219)) {
     $220 = ((($218)) + 40|0);
     $221 = HEAP32[$220>>2]|0;
     $222 = ($221|0)==(0|0);
     if (!($222)) {
      FUNCTION_TABLE_vii[$221 & 8191]($215,$217);
      break L103;
     }
    }
    $223 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
    if ($223) {
     $224 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
     $225 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($224,126934,87)|0);
     $226 = HEAP32[$225>>2]|0;
     $227 = ((($226)) + -12|0);
     $228 = HEAP32[$227>>2]|0;
     $229 = (($225) + ($228)|0);
     __ZNKSt3__28ios_base6getlocEv($4,$229);
     __THREW__ = 0;
     $230 = (invoke_iii(3255,($4|0),(215188|0))|0);
     $231 = __THREW__; __THREW__ = 0;
     $232 = $231&1;
     if (!($232)) {
      $233 = HEAP32[$230>>2]|0;
      $234 = ((($233)) + 28|0);
      $235 = HEAP32[$234>>2]|0;
      __THREW__ = 0;
      $236 = (invoke_iii($235|0,($230|0),10)|0);
      $237 = __THREW__; __THREW__ = 0;
      $238 = $237&1;
      if (!($238)) {
       __ZNSt3__26localeD2Ev($4);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($225,$236)|0);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($225)|0);
       break L103;
      }
     }
     $239 = ___cxa_find_matching_catch_2()|0;
     $240 = tempRet0;
     __THREW__ = 0;
     invoke_vi(3263,($4|0));
     $241 = __THREW__; __THREW__ = 0;
     $242 = $241&1;
     if ($242) {
      $243 = ___cxa_find_matching_catch_3(0|0)|0;
      $244 = tempRet0;
      ___clang_call_terminate($243);
      // unreachable;
     } else {
      ___resumeException($239|0);
      // unreachable;
     }
    }
   }
   break;
  }
  default: {
  }
  }
 } while(0);
 $245 = HEAP32[$111>>2]|0;
 $246 = ($245|0)==(0);
 if ($246) {
  STACKTOP = sp;return;
 }
 $247 = HEAP32[$85>>2]|0;
 $248 = ((($0)) + 60|0);
 $249 = ($247|0)==($248|0);
 L122: do {
  if (!($249)) {
   $250 = ((($39)) + 1253|0);
   $$sroa$098$0118 = $247;
   L124: while(1) {
    $251 = ((($$sroa$098$0118)) + 16|0);
    $252 = ((($$sroa$098$0118)) + 20|0);
    $253 = HEAP32[$251>>2]|0;
    L126: do {
     switch ($253|0) {
     case 2:  {
      $254 = HEAP8[$250>>0]|0;
      $255 = ($254<<24>>24)==(0);
      if (!($255)) {
       __ZNK3osg21FrameBufferAttachment6attachERNS_5StateEjjPKNS_12GLExtensionsE($252,$1,$2,36096,$39);
       __ZNK3osg21FrameBufferAttachment6attachERNS_5StateEjjPKNS_12GLExtensionsE($252,$1,$2,36128,$39);
       break L126;
      }
      $256 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
      if ($256) {
       $257 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
       $258 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($257,127022,116)|0);
       $259 = HEAP32[$258>>2]|0;
       $260 = ((($259)) + -12|0);
       $261 = HEAP32[$260>>2]|0;
       $262 = (($258) + ($261)|0);
       __ZNKSt3__28ios_base6getlocEv($3,$262);
       __THREW__ = 0;
       $263 = (invoke_iii(3255,($3|0),(215188|0))|0);
       $264 = __THREW__; __THREW__ = 0;
       $265 = $264&1;
       if ($265) {
        break L124;
       }
       $266 = HEAP32[$263>>2]|0;
       $267 = ((($266)) + 28|0);
       $268 = HEAP32[$267>>2]|0;
       __THREW__ = 0;
       $269 = (invoke_iii($268|0,($263|0),10)|0);
       $270 = __THREW__; __THREW__ = 0;
       $271 = $270&1;
       if ($271) {
        break L124;
       }
       __ZNSt3__26localeD2Ev($3);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($258,$269)|0);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($258)|0);
      }
      break;
     }
     case 0:  {
      $$0$i = 36096;
      label = 95;
      break;
     }
     case 1:  {
      $$0$i = 36128;
      label = 95;
      break;
     }
     case 3:  {
      $$0$i = 36064;
      label = 95;
      break;
     }
     default: {
      $278 = (($253) + 36060)|0;
      $$0$i = $278;
      label = 95;
     }
     }
    } while(0);
    if ((label|0) == 95) {
     label = 0;
     __ZNK3osg21FrameBufferAttachment6attachERNS_5StateEjjPKNS_12GLExtensionsE($252,$1,$2,$$0$i,$39);
    }
    $279 = ((($$sroa$098$0118)) + 4|0);
    $280 = HEAP32[$279>>2]|0;
    $281 = ($280|0)==(0|0);
    if ($281) {
     $282 = ((($$sroa$098$0118)) + 8|0);
     $283 = HEAP32[$282>>2]|0;
     $284 = HEAP32[$283>>2]|0;
     $285 = ($284|0)==($$sroa$098$0118|0);
     if ($285) {
      $$sroa$098$0$be = $283;
     } else {
      $290 = $282;
      while(1) {
       $289 = HEAP32[$290>>2]|0;
       $291 = ((($289)) + 8|0);
       $292 = HEAP32[$291>>2]|0;
       $293 = HEAP32[$292>>2]|0;
       $294 = ($293|0)==($289|0);
       if ($294) {
        $$sroa$098$0$be = $292;
        break;
       } else {
        $290 = $291;
       }
      }
     }
    } else {
     $$0$i$i$i$i = $280;
     while(1) {
      $287 = HEAP32[$$0$i$i$i$i>>2]|0;
      $288 = ($287|0)==(0|0);
      if ($288) {
       break;
      } else {
       $$0$i$i$i$i = $287;
      }
     }
     $$sroa$098$0$be = $$0$i$i$i$i;
    }
    $286 = ($$sroa$098$0$be|0)==($248|0);
    if ($286) {
     break L122;
    } else {
     $$sroa$098$0118 = $$sroa$098$0$be;
    }
   }
   $272 = ___cxa_find_matching_catch_2()|0;
   $273 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($3|0));
   $274 = __THREW__; __THREW__ = 0;
   $275 = $274&1;
   if ($275) {
    $276 = ___cxa_find_matching_catch_3(0|0)|0;
    $277 = tempRet0;
    ___clang_call_terminate($276);
    // unreachable;
   } else {
    ___resumeException($272|0);
    // unreachable;
   }
  }
 } while(0);
 HEAP32[$111>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNK3osg21FrameBufferAttachment44createRequiredTexturesAndApplyGenerateMipMapERNS_5StateEPKNS_12GLExtensionsE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$phi$trans$insert = 0, $$pre = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $switch = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($1)) + 124|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$0>>2]|0;
 $6 = ((($5)) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if ($8) {
  return;
 }
 $9 = ((($7)) + 224|0);
 $10 = ((($7)) + 228|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = HEAP32[$9>>2]|0;
 $13 = (($11) - ($12))|0;
 $14 = $13 >> 2;
 $15 = ($14>>>0)>($4>>>0);
 L4: do {
  if (!($15)) {
   $16 = (($4) + 1)|0;
   $17 = ($16>>>0)>($14>>>0);
   $18 = $12;
   $19 = $11;
   if ($17) {
    $20 = (($16) - ($14))|0;
    __ZNSt3__26vectorIN3osg7ref_ptrINS1_7Texture13TextureObjectEEENS_9allocatorIS5_EEE8__appendEj($9,$20);
    break;
   }
   $21 = ($16>>>0)<($14>>>0);
   if ($21) {
    $22 = (($18) + ($16<<2)|0);
    $23 = ($19|0)==($22|0);
    if (!($23)) {
     $25 = $19;
     while(1) {
      $24 = ((($25)) + -4|0);
      HEAP32[$10>>2] = $24;
      $26 = HEAP32[$24>>2]|0;
      $27 = ($26|0)==(0|0);
      if (!($27)) {
       $28 = ((($26)) + 8|0);
       $29 = HEAP32[$28>>2]|0;HEAP32[$28>>2] = (($29-1)|0);
       $30 = ($29|0)==(1);
       if ($30) {
        __THREW__ = 0;
        invoke_viii(3262,($26|0),1,1);
        $31 = __THREW__; __THREW__ = 0;
        $32 = $31&1;
        if ($32) {
         break;
        }
       }
      }
      HEAP32[$24>>2] = 0;
      $33 = HEAP32[$10>>2]|0;
      $34 = ($33|0)==($22|0);
      if ($34) {
       break L4;
      } else {
       $25 = $33;
      }
     }
     $35 = ___cxa_find_matching_catch_2()|0;
     $36 = tempRet0;
     ___cxa_call_unexpected(($35|0));
     // unreachable;
    }
   }
  }
 } while(0);
 $37 = HEAP32[$9>>2]|0;
 $38 = (($37) + ($4<<2)|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = ($39|0)==(0|0);
 if ($40) {
  label = 14;
 } else {
  $41 = ((($39)) + 12|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = ($42|0)==(0);
  if ($43) {
   label = 14;
  }
 }
 if ((label|0) == 14) {
  $44 = HEAP32[$0>>2]|0;
  $45 = ((($44)) + 8|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = HEAP32[$46>>2]|0;
  $48 = ((($47)) + 176|0);
  $49 = HEAP32[$48>>2]|0;
  FUNCTION_TABLE_vii[$49 & 8191]($46,$1);
  $50 = HEAP32[$0>>2]|0;
  $51 = ((($50)) + 8|0);
  $52 = HEAP32[$51>>2]|0;
  $53 = ((($52)) + 224|0);
  $54 = ((($52)) + 228|0);
  $55 = HEAP32[$54>>2]|0;
  $56 = HEAP32[$53>>2]|0;
  $57 = (($55) - ($56))|0;
  $58 = $57 >> 2;
  $59 = ($58>>>0)>($4>>>0);
  L22: do {
   if (!($59)) {
    $60 = (($4) + 1)|0;
    $61 = ($60>>>0)>($58>>>0);
    $62 = $56;
    $63 = $55;
    if ($61) {
     $64 = (($60) - ($58))|0;
     __ZNSt3__26vectorIN3osg7ref_ptrINS1_7Texture13TextureObjectEEENS_9allocatorIS5_EEE8__appendEj($53,$64);
     break;
    }
    $65 = ($60>>>0)<($58>>>0);
    if ($65) {
     $66 = (($62) + ($60<<2)|0);
     $67 = ($63|0)==($66|0);
     if (!($67)) {
      $69 = $63;
      while(1) {
       $68 = ((($69)) + -4|0);
       HEAP32[$54>>2] = $68;
       $70 = HEAP32[$68>>2]|0;
       $71 = ($70|0)==(0|0);
       if (!($71)) {
        $72 = ((($70)) + 8|0);
        $73 = HEAP32[$72>>2]|0;HEAP32[$72>>2] = (($73-1)|0);
        $74 = ($73|0)==(1);
        if ($74) {
         __THREW__ = 0;
         invoke_viii(3262,($70|0),1,1);
         $75 = __THREW__; __THREW__ = 0;
         $76 = $75&1;
         if ($76) {
          break;
         }
        }
       }
       HEAP32[$68>>2] = 0;
       $77 = HEAP32[$54>>2]|0;
       $78 = ($77|0)==($66|0);
       if ($78) {
        break L22;
       } else {
        $69 = $77;
       }
      }
      $79 = ___cxa_find_matching_catch_2()|0;
      $80 = tempRet0;
      ___cxa_call_unexpected(($79|0));
      // unreachable;
     }
    }
   }
  } while(0);
  $81 = HEAP32[$53>>2]|0;
  $82 = (($81) + ($4<<2)|0);
  $83 = HEAP32[$82>>2]|0;
  $84 = ($83|0)==(0|0);
  if ($84) {
   return;
  }
  $$phi$trans$insert = ((($83)) + 12|0);
  $$pre = HEAP32[$$phi$trans$insert>>2]|0;
  $85 = ($$pre|0)==(0);
  if ($85) {
   return;
  }
 }
 $86 = HEAP32[$0>>2]|0;
 $87 = ((($86)) + 8|0);
 $88 = HEAP32[$87>>2]|0;
 $89 = (__ZNK3osg7Texture9getFilterENS0_15FilterParameterE($88,0)|0);
 $90 = $89 & -4;
 $switch = ($90|0)==(9984);
 if (!($switch)) {
  return;
 }
 $91 = ((($1)) + 688|0);
 $92 = HEAP32[$91>>2]|0;
 $93 = ($92|0)==(0);
 if (!($93)) {
  $94 = ((($1)) + 728|0);
  $95 = HEAP32[$94>>2]|0;
  $96 = ($95|0)==(0|0);
  if (!($96)) {
   $97 = ((($1)) + 716|0);
   $98 = HEAP32[$97>>2]|0;
   $99 = ((($1)) + 720|0);
   $100 = HEAP32[$99>>2]|0;
   $101 = ($98|0)>($100|0);
   $102 = $101 ? $98 : $100;
   $103 = ($102|0)==(0);
   if (!($103)) {
    FUNCTION_TABLE_vi[$95 & 8191](33984);
    HEAP32[$91>>2] = 0;
   }
  }
 }
 $104 = HEAP32[$0>>2]|0;
 $105 = ((($104)) + 8|0);
 $106 = HEAP32[$105>>2]|0;
 (__ZN3osg5State21applyTextureAttributeEjPKNS_14StateAttributeE($1,0,$106)|0);
 $107 = ((($2)) + 1324|0);
 $108 = HEAP32[$107>>2]|0;
 $109 = HEAP32[$0>>2]|0;
 $110 = ((($109)) + 8|0);
 $111 = HEAP32[$110>>2]|0;
 $112 = HEAP32[$111>>2]|0;
 $113 = ((($112)) + 180|0);
 $114 = HEAP32[$113>>2]|0;
 $115 = (FUNCTION_TABLE_ii[$114 & 8191]($111)|0);
 FUNCTION_TABLE_vi[$108 & 8191]($115);
 return;
}
function __ZNK3osg21FrameBufferAttachment6attachERNS_5StateEjjPKNS_12GLExtensionsE($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$phi$trans$insert = 0, $$pre = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $5 = ((($1)) + 124|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$0>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0);
 if ($9) {
  $10 = ((($4)) + 1320|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ((($7)) + 4|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (__ZNK3osg12RenderBuffer11getObjectIDEjPKNS_12GLExtensionsE($13,$6,$4)|0);
  FUNCTION_TABLE_viiii[$11 & 8191]($2,$3,36161,$14);
  return;
 }
 $15 = ((($7)) + 8|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==(0|0);
 if ($17) {
  return;
 }
 $18 = ((($16)) + 224|0);
 $19 = ((($16)) + 228|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = HEAP32[$18>>2]|0;
 $22 = (($20) - ($21))|0;
 $23 = $22 >> 2;
 $24 = ($23>>>0)>($6>>>0);
 L8: do {
  if (!($24)) {
   $25 = (($6) + 1)|0;
   $26 = ($25>>>0)>($23>>>0);
   $27 = $21;
   $28 = $20;
   if ($26) {
    $29 = (($25) - ($23))|0;
    __ZNSt3__26vectorIN3osg7ref_ptrINS1_7Texture13TextureObjectEEENS_9allocatorIS5_EEE8__appendEj($18,$29);
    break;
   }
   $30 = ($25>>>0)<($23>>>0);
   if ($30) {
    $31 = (($27) + ($25<<2)|0);
    $32 = ($28|0)==($31|0);
    if (!($32)) {
     $34 = $28;
     while(1) {
      $33 = ((($34)) + -4|0);
      HEAP32[$19>>2] = $33;
      $35 = HEAP32[$33>>2]|0;
      $36 = ($35|0)==(0|0);
      if (!($36)) {
       $37 = ((($35)) + 8|0);
       $38 = HEAP32[$37>>2]|0;HEAP32[$37>>2] = (($38-1)|0);
       $39 = ($38|0)==(1);
       if ($39) {
        __THREW__ = 0;
        invoke_viii(3262,($35|0),1,1);
        $40 = __THREW__; __THREW__ = 0;
        $41 = $40&1;
        if ($41) {
         break;
        }
       }
      }
      HEAP32[$33>>2] = 0;
      $42 = HEAP32[$19>>2]|0;
      $43 = ($42|0)==($31|0);
      if ($43) {
       break L8;
      } else {
       $34 = $42;
      }
     }
     $44 = ___cxa_find_matching_catch_2()|0;
     $45 = tempRet0;
     ___cxa_call_unexpected(($44|0));
     // unreachable;
    }
   }
  }
 } while(0);
 $46 = HEAP32[$18>>2]|0;
 $47 = (($46) + ($6<<2)|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = ($48|0)==(0|0);
 if ($49) {
  label = 16;
 } else {
  $50 = ((($48)) + 12|0);
  $51 = HEAP32[$50>>2]|0;
  $52 = ($51|0)==(0);
  if ($52) {
   label = 16;
  } else {
   $101 = $51;
  }
 }
 if ((label|0) == 16) {
  $53 = HEAP32[$0>>2]|0;
  $54 = ((($53)) + 8|0);
  $55 = HEAP32[$54>>2]|0;
  $56 = HEAP32[$55>>2]|0;
  $57 = ((($56)) + 176|0);
  $58 = HEAP32[$57>>2]|0;
  FUNCTION_TABLE_vii[$58 & 8191]($55,$1);
  $59 = HEAP32[$0>>2]|0;
  $60 = ((($59)) + 8|0);
  $61 = HEAP32[$60>>2]|0;
  $62 = ((($61)) + 224|0);
  $63 = ((($61)) + 228|0);
  $64 = HEAP32[$63>>2]|0;
  $65 = HEAP32[$62>>2]|0;
  $66 = (($64) - ($65))|0;
  $67 = $66 >> 2;
  $68 = ($67>>>0)>($6>>>0);
  L26: do {
   if (!($68)) {
    $69 = (($6) + 1)|0;
    $70 = ($69>>>0)>($67>>>0);
    $71 = $65;
    $72 = $64;
    if ($70) {
     $73 = (($69) - ($67))|0;
     __ZNSt3__26vectorIN3osg7ref_ptrINS1_7Texture13TextureObjectEEENS_9allocatorIS5_EEE8__appendEj($62,$73);
     break;
    }
    $74 = ($69>>>0)<($67>>>0);
    if ($74) {
     $75 = (($71) + ($69<<2)|0);
     $76 = ($72|0)==($75|0);
     if (!($76)) {
      $78 = $72;
      while(1) {
       $77 = ((($78)) + -4|0);
       HEAP32[$63>>2] = $77;
       $79 = HEAP32[$77>>2]|0;
       $80 = ($79|0)==(0|0);
       if (!($80)) {
        $81 = ((($79)) + 8|0);
        $82 = HEAP32[$81>>2]|0;HEAP32[$81>>2] = (($82-1)|0);
        $83 = ($82|0)==(1);
        if ($83) {
         __THREW__ = 0;
         invoke_viii(3262,($79|0),1,1);
         $84 = __THREW__; __THREW__ = 0;
         $85 = $84&1;
         if ($85) {
          break;
         }
        }
       }
       HEAP32[$77>>2] = 0;
       $86 = HEAP32[$63>>2]|0;
       $87 = ($86|0)==($75|0);
       if ($87) {
        break L26;
       } else {
        $78 = $86;
       }
      }
      $88 = ___cxa_find_matching_catch_2()|0;
      $89 = tempRet0;
      ___cxa_call_unexpected(($88|0));
      // unreachable;
     }
    }
   }
  } while(0);
  $90 = HEAP32[$62>>2]|0;
  $91 = (($90) + ($6<<2)|0);
  $92 = HEAP32[$91>>2]|0;
  $93 = ($92|0)==(0|0);
  if ($93) {
   return;
  }
  $$phi$trans$insert = ((($92)) + 12|0);
  $$pre = HEAP32[$$phi$trans$insert>>2]|0;
  $94 = ($$pre|0)==(0);
  if ($94) {
   return;
  } else {
   $101 = $$pre;
  }
 }
 $95 = HEAP32[$0>>2]|0;
 $96 = HEAP32[$95>>2]|0;
 switch ($96|0) {
 case 4:  {
  $132 = ((($95)) + 12|0);
  $133 = HEAP32[$132>>2]|0;
  $134 = HEAP32[14083]|0;
  $135 = ($133|0)==($134|0);
  $136 = ((($95)) + 16|0);
  $137 = HEAP32[$136>>2]|0;
  if ($135) {
   $138 = ((($4)) + 1308|0);
   $139 = HEAP32[$138>>2]|0;
   FUNCTION_TABLE_viiii[$139 & 8191]($2,$3,$101,$137);
   return;
  } else {
   $140 = ((($4)) + 1300|0);
   $141 = HEAP32[$140>>2]|0;
   $142 = (($133) + 34069)|0;
   FUNCTION_TABLE_viiiii[$141 & 8191]($2,$3,$142,$101,$137);
   return;
  }
  break;
 }
 case 1:  {
  $97 = ((($4)) + 1296|0);
  $98 = HEAP32[$97>>2]|0;
  $99 = ((($95)) + 16|0);
  $100 = HEAP32[$99>>2]|0;
  FUNCTION_TABLE_viiiii[$98 & 8191]($2,$3,3552,$101,$100);
  return;
  break;
 }
 case 2:  {
  $102 = ((($4)) + 1300|0);
  $103 = HEAP32[$102>>2]|0;
  $104 = ((($95)) + 16|0);
  $105 = HEAP32[$104>>2]|0;
  FUNCTION_TABLE_viiiii[$103 & 8191]($2,$3,3553,$101,$105);
  return;
  break;
 }
 case 7:  {
  $106 = ((($4)) + 1300|0);
  $107 = HEAP32[$106>>2]|0;
  $108 = ((($95)) + 16|0);
  $109 = HEAP32[$108>>2]|0;
  FUNCTION_TABLE_viiiii[$107 & 8191]($2,$3,37120,$101,$109);
  return;
  break;
 }
 case 3:  {
  $110 = ((($95)) + 20|0);
  $111 = HEAP32[$110>>2]|0;
  $112 = HEAP32[14083]|0;
  $113 = ($111|0)==($112|0);
  $114 = ((($95)) + 16|0);
  $115 = HEAP32[$114>>2]|0;
  if ($113) {
   $116 = ((($4)) + 1308|0);
   $117 = HEAP32[$116>>2]|0;
   FUNCTION_TABLE_viiii[$117 & 8191]($2,$3,$101,$115);
   return;
  } else {
   $118 = ((($4)) + 1304|0);
   $119 = HEAP32[$118>>2]|0;
   FUNCTION_TABLE_viiiiii[$119 & 8191]($2,$3,32879,$101,$115,$111);
   return;
  }
  break;
 }
 case 6:  {
  $120 = ((($95)) + 20|0);
  $121 = HEAP32[$120>>2]|0;
  $122 = HEAP32[14083]|0;
  $123 = ($121|0)==($122|0);
  $124 = ((($95)) + 16|0);
  $125 = HEAP32[$124>>2]|0;
  if ($123) {
   $126 = ((($4)) + 1308|0);
   $127 = HEAP32[$126>>2]|0;
   FUNCTION_TABLE_viiii[$127 & 8191]($2,$3,$101,$125);
   return;
  } else {
   $128 = ((($4)) + 1312|0);
   $129 = HEAP32[$128>>2]|0;
   FUNCTION_TABLE_viiiii[$129 & 8191]($2,$3,$101,$125,$121);
   return;
  }
  break;
 }
 case 5:  {
  $130 = ((($4)) + 1300|0);
  $131 = HEAP32[$130>>2]|0;
  FUNCTION_TABLE_viiiii[$131 & 8191]($2,$3,34037,$101,0);
  return;
  break;
 }
 default: {
  return;
 }
 }
}
function __ZNK3osg12RenderBuffer11getObjectIDEjPKNS_12GLExtensionsE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$02$i$i$i$i$i$i$i = 0, $$pr = 0, $$pr41$pre = 0, $$pre = 0, $$pre$i = 0, $$pre$i40 = 0, $$pre$pre$i = 0, $$pre$pre$i36 = 0, $$pre43 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i$i$i37 = 0, $scevgep5$i$i$i$i = 0, $scevgep5$i$i$i$i38 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp + 8|0;
 $4 = sp + 4|0;
 $5 = sp;
 $6 = ((($0)) + 32|0);
 $7 = ((($0)) + 36|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$6>>2]|0;
 $10 = (($8) - ($9))|0;
 $11 = $10 >> 2;
 $12 = ($11>>>0)>($1>>>0);
 $13 = $9;
 if ($12) {
  $27 = $13;
 } else {
  $14 = (($1) + 1)|0;
  HEAP32[$5>>2] = 0;
  $15 = ($14>>>0)>($11>>>0);
  $16 = $8;
  if ($15) {
   $17 = (($14) - ($11))|0;
   __ZNSt3__26vectorIjNS_9allocatorIjEEE8__appendEjRKj($6,$17,$5);
   $$pre$pre$i = HEAP32[$6>>2]|0;
   $$pre$i = $$pre$pre$i;
  } else {
   $18 = ($14>>>0)<($11>>>0);
   if ($18) {
    $19 = (($13) + ($14<<2)|0);
    $20 = ($16|0)==($19|0);
    if ($20) {
     $$pre$i = $13;
    } else {
     $scevgep$i$i$i$i = ((($16)) + -4|0);
     $21 = $scevgep$i$i$i$i;
     $22 = $19;
     $23 = (($21) - ($22))|0;
     $24 = $23 >>> 2;
     $25 = $24 ^ -1;
     $scevgep5$i$i$i$i = (($16) + ($25<<2)|0);
     HEAP32[$7>>2] = $scevgep5$i$i$i$i;
     $$pre$i = $13;
    }
   } else {
    $$pre$i = $13;
   }
  }
  $27 = $$pre$i;
 }
 $26 = (($27) + ($1<<2)|0);
 $28 = ((($0)) + 44|0);
 $29 = ((($0)) + 48|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = HEAP32[$28>>2]|0;
 $32 = (($30) - ($31))|0;
 $33 = $32 >> 2;
 $34 = ($33>>>0)>($1>>>0);
 $35 = $31;
 if ($34) {
  $49 = $35;
 } else {
  $36 = (($1) + 1)|0;
  HEAP32[$4>>2] = 0;
  $37 = ($36>>>0)>($33>>>0);
  $38 = $30;
  if ($37) {
   $39 = (($36) - ($33))|0;
   __ZNSt3__26vectorIiNS_9allocatorIiEEE8__appendEjRKi($28,$39,$4);
   $$pre$pre$i36 = HEAP32[$28>>2]|0;
   $$pre$i40 = $$pre$pre$i36;
  } else {
   $40 = ($36>>>0)<($33>>>0);
   if ($40) {
    $41 = (($35) + ($36<<2)|0);
    $42 = ($38|0)==($41|0);
    if ($42) {
     $$pre$i40 = $35;
    } else {
     $scevgep$i$i$i$i37 = ((($38)) + -4|0);
     $43 = $scevgep$i$i$i$i37;
     $44 = $41;
     $45 = (($43) - ($44))|0;
     $46 = $45 >>> 2;
     $47 = $46 ^ -1;
     $scevgep5$i$i$i$i38 = (($38) + ($47<<2)|0);
     HEAP32[$29>>2] = $scevgep5$i$i$i$i38;
     $$pre$i40 = $35;
    }
   } else {
    $$pre$i40 = $35;
   }
  }
  $49 = $$pre$i40;
 }
 $48 = (($49) + ($1<<2)|0);
 $50 = HEAP32[$26>>2]|0;
 $51 = ($50|0)==(0);
 do {
  if ($51) {
   $52 = ((($2)) + 1264|0);
   $53 = HEAP32[$52>>2]|0;
   FUNCTION_TABLE_vii[$53 & 8191](1,$26);
   $54 = HEAP32[$26>>2]|0;
   $55 = ($54|0)==(0);
   if ($55) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   } else {
    HEAP32[$48>>2] = 1;
    $$pre = HEAP32[$26>>2]|0;
    $59 = $$pre;
    break;
   }
  } else {
   $$pr = HEAP32[$48>>2]|0;
   $56 = ($$pr|0)==(0);
   if ($56) {
    $$0 = $50;
    STACKTOP = sp;return ($$0|0);
   } else {
    $59 = $50;
   }
  }
 } while(0);
 $57 = ((($2)) + 1256|0);
 $58 = HEAP32[$57>>2]|0;
 FUNCTION_TABLE_vii[$58 & 8191](36161,$59);
 $60 = ((($0)) + 68|0);
 $61 = HEAP32[$60>>2]|0;
 $62 = ((($0)) + 72|0);
 $63 = HEAP32[$62>>2]|0;
 $64 = ($61|0)<($63|0);
 if ($64) {
  $65 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
  do {
   if ($65) {
    $66 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
    $67 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($66,127139,113)|0);
    $68 = HEAP32[$67>>2]|0;
    $69 = ((($68)) + -12|0);
    $70 = HEAP32[$69>>2]|0;
    $71 = (($67) + ($70)|0);
    __ZNKSt3__28ios_base6getlocEv($3,$71);
    __THREW__ = 0;
    $72 = (invoke_iii(3255,($3|0),(215188|0))|0);
    $73 = __THREW__; __THREW__ = 0;
    $74 = $73&1;
    if (!($74)) {
     $75 = HEAP32[$72>>2]|0;
     $76 = ((($75)) + 28|0);
     $77 = HEAP32[$76>>2]|0;
     __THREW__ = 0;
     $78 = (invoke_iii($77|0,($72|0),10)|0);
     $79 = __THREW__; __THREW__ = 0;
     $80 = $79&1;
     if (!($80)) {
      __ZNSt3__26localeD2Ev($3);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($67,$78)|0);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($67)|0);
      break;
     }
    }
    $81 = ___cxa_find_matching_catch_2()|0;
    $82 = tempRet0;
    __THREW__ = 0;
    invoke_vi(3263,($3|0));
    $83 = __THREW__; __THREW__ = 0;
    $84 = $83&1;
    if ($84) {
     $85 = ___cxa_find_matching_catch_3(0|0)|0;
     $86 = tempRet0;
     ___clang_call_terminate($85);
     // unreachable;
    } else {
     ___resumeException($81|0);
     // unreachable;
    }
   }
  } while(0);
  $87 = HEAP32[$62>>2]|0;
  HEAP32[$60>>2] = $87;
  $88 = ((($0)) + 44|0);
  $89 = HEAP32[$88>>2]|0;
  $90 = HEAP32[$29>>2]|0;
  $91 = $89;
  $92 = (($90) - ($91))|0;
  $93 = ($92|0)>(0);
  if ($93) {
   $94 = $92 >>> 2;
   $$02$i$i$i$i$i$i$i = $94;$95 = $89;
   while(1) {
    HEAP32[$95>>2] = 1;
    $96 = ((($95)) + 4|0);
    $97 = (($$02$i$i$i$i$i$i$i) + -1)|0;
    $98 = ($$02$i$i$i$i$i$i$i|0)>(1);
    if ($98) {
     $$02$i$i$i$i$i$i$i = $97;$95 = $96;
    } else {
     break;
    }
   }
   $$pr41$pre = HEAP32[$60>>2]|0;
   $99 = $$pr41$pre;
  } else {
   $99 = $87;
  }
 } else {
  $99 = $61;
 }
 $100 = ($99|0)>(0);
 do {
  if ($100) {
   $101 = ((($2)) + 1276|0);
   $102 = HEAP32[$101>>2]|0;
   $103 = ($102|0)==(0|0);
   if (!($103)) {
    $104 = (__ZN3osg12RenderBuffer13getMaxSamplesEjPKNS_12GLExtensionsE($1,$2)|0);
    $105 = ($99|0)<($104|0);
    $106 = $105 ? $99 : $104;
    $107 = HEAP32[$62>>2]|0;
    $108 = ($107|0)<($106|0);
    $109 = $108 ? $107 : $106;
    $110 = HEAP32[$101>>2]|0;
    $111 = ((($0)) + 56|0);
    $112 = HEAP32[$111>>2]|0;
    $113 = ((($0)) + 60|0);
    $114 = HEAP32[$113>>2]|0;
    $115 = ((($0)) + 64|0);
    $116 = HEAP32[$115>>2]|0;
    FUNCTION_TABLE_viiiiii[$110 & 8191](36161,$106,$109,$112,$114,$116);
    break;
   }
   $117 = ((($2)) + 1272|0);
   $118 = HEAP32[$117>>2]|0;
   $119 = ($118|0)==(0|0);
   if ($119) {
    label = 36;
   } else {
    $120 = (__ZN3osg12RenderBuffer13getMaxSamplesEjPKNS_12GLExtensionsE($1,$2)|0);
    $121 = ($99|0)<($120|0);
    $122 = $121 ? $99 : $120;
    $123 = HEAP32[$117>>2]|0;
    $124 = ((($0)) + 56|0);
    $125 = HEAP32[$124>>2]|0;
    $126 = ((($0)) + 60|0);
    $127 = HEAP32[$126>>2]|0;
    $128 = ((($0)) + 64|0);
    $129 = HEAP32[$128>>2]|0;
    FUNCTION_TABLE_viiiii[$123 & 8191](36161,$122,$125,$127,$129);
   }
  } else {
   label = 36;
  }
 } while(0);
 if ((label|0) == 36) {
  $130 = ((($2)) + 1268|0);
  $131 = HEAP32[$130>>2]|0;
  $132 = ((($0)) + 56|0);
  $133 = HEAP32[$132>>2]|0;
  $134 = ((($0)) + 60|0);
  $135 = HEAP32[$134>>2]|0;
  $136 = ((($0)) + 64|0);
  $137 = HEAP32[$136>>2]|0;
  FUNCTION_TABLE_viiii[$131 & 8191](36161,$133,$135,$137);
 }
 HEAP32[$48>>2] = 0;
 $$pre43 = HEAP32[$26>>2]|0;
 $$0 = $$pre43;
 STACKTOP = sp;return ($$0|0);
}
function __ZNSt3__26vectorIN3osg7ref_ptrINS1_7Texture13TextureObjectEEENS_9allocatorIS5_EEE8__appendEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$06$i$i = 0, $$pre = 0, $$pre$i = 0, $$promoted4$i = 0, $$sroa$7$0 = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i = 0, $scevgep$i15 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) - ($5))|0;
 $7 = $6 >> 2;
 $8 = ($7>>>0)<($1>>>0);
 $9 = $5;
 if (!($8)) {
  $$promoted4$i = $5;
  $10 = $1 << 2;
  _memset(($$promoted4$i|0),0,($10|0))|0;
  $scevgep$i = (($9) + ($1<<2)|0);
  HEAP32[$4>>2] = $scevgep$i;
  return;
 }
 $11 = HEAP32[$0>>2]|0;
 $12 = (($5) - ($11))|0;
 $13 = $12 >> 2;
 $14 = (($13) + ($1))|0;
 $15 = ($14>>>0)>(1073741823);
 $16 = $11;
 if ($15) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $17 = (($3) - ($11))|0;
 $18 = $17 >> 2;
 $19 = ($18>>>0)<(536870911);
 $20 = $17 >> 1;
 $21 = ($20>>>0)<($14>>>0);
 $$sroa$speculated$i = $21 ? $14 : $20;
 $$sroa$speculated$$i = $19 ? $$sroa$speculated$i : 1073741823;
 $22 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($22) {
   $32 = 0;
  } else {
   $23 = ($$sroa$speculated$$i>>>0)>(1073741823);
   if (!($23)) {
    $29 = $$sroa$speculated$$i << 2;
    $30 = (__Znwj($29)|0);
    $32 = $30;
    break;
   }
   $24 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($24|0),(204840|0));
   $25 = __THREW__; __THREW__ = 0;
   $26 = $25&1;
   if ($26) {
    $27 = ___cxa_find_matching_catch_2()|0;
    $28 = tempRet0;
    ___cxa_free_exception(($24|0));
    ___resumeException($27|0);
    // unreachable;
   } else {
    HEAP32[$24>>2] = (99824);
    ___cxa_throw(($24|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $31 = (($32) + ($13<<2)|0);
 $33 = $31;
 $34 = (($32) + ($$sroa$speculated$$i<<2)|0);
 $35 = $34;
 $36 = $1 << 2;
 _memset(($31|0),0,($36|0))|0;
 $scevgep$i15 = (($31) + ($1<<2)|0);
 $37 = $scevgep$i15;
 $38 = ($9|0)==($16|0);
 if ($38) {
  $50 = $33;$51 = $5;$53 = $9;
 } else {
  $$06$i$i = $9;$$sroa$7$0 = $33;$41 = $31;
  while(1) {
   $39 = ((($$06$i$i)) + -4|0);
   $40 = ((($41)) + -4|0);
   $42 = HEAP32[$39>>2]|0;
   HEAP32[$40>>2] = $42;
   $43 = ($42|0)==(0|0);
   if (!($43)) {
    $44 = ((($42)) + 8|0);
    $45 = HEAP32[$44>>2]|0;HEAP32[$44>>2] = (($45+1)|0);
   }
   $46 = $$sroa$7$0;
   $47 = ((($46)) + -4|0);
   $48 = $47;
   $49 = ($39|0)==($16|0);
   if ($49) {
    break;
   } else {
    $$06$i$i = $39;$$sroa$7$0 = $48;$41 = $47;
   }
  }
  $$pre$i = HEAP32[$0>>2]|0;
  $$pre = HEAP32[$4>>2]|0;
  $50 = $48;$51 = $$pre$i;$53 = $$pre;
 }
 HEAP32[$0>>2] = $50;
 HEAP32[$4>>2] = $37;
 HEAP32[$2>>2] = $35;
 $52 = $51;
 $54 = ($53|0)==($52|0);
 L25: do {
  if (!($54)) {
   $56 = $53;
   while(1) {
    $55 = ((($56)) + -4|0);
    $57 = HEAP32[$55>>2]|0;
    $58 = ($57|0)==(0|0);
    if (!($58)) {
     $59 = ((($57)) + 8|0);
     $60 = HEAP32[$59>>2]|0;HEAP32[$59>>2] = (($60-1)|0);
     $61 = ($60|0)==(1);
     if ($61) {
      __THREW__ = 0;
      invoke_viii(3262,($57|0),1,1);
      $62 = __THREW__; __THREW__ = 0;
      $63 = $62&1;
      if ($63) {
       break;
      }
     }
    }
    HEAP32[$55>>2] = 0;
    $64 = ($55|0)==($52|0);
    if ($64) {
     break L25;
    } else {
     $56 = $55;
    }
   }
   $65 = ___cxa_find_matching_catch_2()|0;
   $66 = tempRet0;
   ___cxa_call_unexpected(($65|0));
   // unreachable;
  }
 } while(0);
 $67 = ($51|0)==(0);
 if ($67) {
  return;
 }
 $68 = $51;
 __ZdlPv($68);
 return;
}
function __ZN3osg12RenderBuffer13getMaxSamplesEjPKNS_12GLExtensionsE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$pre = 0, $$pre$i = 0, $$pre$pre$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $eh$lpad$body$index3Z2D = 0, $eh$lpad$body$indexZ2D = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i$i$i$i = 0, $scevgep5$i$i$i$i = 0, $scevgep5$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = HEAP8[206040]|0;
 $4 = ($3<<24>>24)==(0);
 do {
  if ($4) {
   $5 = (___cxa_guard_acquire(206040)|0);
   $6 = ($5|0)==(0);
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_i(3285)|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = HEAP32[$7>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_ii(3286,($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if (!($13)) {
      HEAP32[52058] = 0;
      HEAP32[(208236)>>2] = 0;
      HEAP32[(208240)>>2] = 0;
      $14 = ($11|0)==(0);
      do {
       if (!($14)) {
        $15 = ($11>>>0)>(1073741823);
        if ($15) {
         __THREW__ = 0;
         invoke_vi(3307,(208232|0));
         $16 = __THREW__; __THREW__ = 0;
        } else {
         $17 = $11 << 2;
         __THREW__ = 0;
         $18 = (invoke_ii(3276,($17|0))|0);
         $19 = __THREW__; __THREW__ = 0;
         $20 = $19&1;
         if (!($20)) {
          HEAP32[52058] = $18;
          $21 = (($18) + ($11<<2)|0);
          HEAP32[(208240)>>2] = $21;
          _memset(($18|0),0,($17|0))|0;
          HEAP32[(208236)>>2] = $21;
          break;
         }
        }
        $22 = ___cxa_find_matching_catch_2()|0;
        $23 = tempRet0;
        $24 = HEAP32[52058]|0;
        $25 = ($24|0)==(0|0);
        if ($25) {
         $eh$lpad$body$index3Z2D = $23;$eh$lpad$body$indexZ2D = $22;
         ___resumeException($eh$lpad$body$indexZ2D|0);
         // unreachable;
        }
        $26 = HEAP32[(208236)>>2]|0;
        $27 = ($26|0)==($24|0);
        if (!($27)) {
         $scevgep$i$i$i$i$i = ((($26)) + -4|0);
         $28 = $scevgep$i$i$i$i$i;
         $29 = $24;
         $30 = (($28) - ($29))|0;
         $31 = $30 >>> 2;
         $32 = $31 ^ -1;
         $scevgep5$i$i$i$i$i = (($26) + ($32<<2)|0);
         HEAP32[(208236)>>2] = $scevgep5$i$i$i$i$i;
        }
        __ZdlPv($24);
        $eh$lpad$body$index3Z2D = $23;$eh$lpad$body$indexZ2D = $22;
        ___resumeException($eh$lpad$body$indexZ2D|0);
        // unreachable;
       }
      } while(0);
      (___cxa_atexit((3760|0),(208232|0),(___dso_handle|0))|0);
      break;
     }
    }
    $58 = ___cxa_find_matching_catch_2()|0;
    $59 = tempRet0;
    $eh$lpad$body$index3Z2D = $59;$eh$lpad$body$indexZ2D = $58;
    ___resumeException($eh$lpad$body$indexZ2D|0);
    // unreachable;
   }
  }
 } while(0);
 $33 = HEAP32[(208236)>>2]|0;
 $34 = HEAP32[52058]|0;
 $35 = (($33) - ($34))|0;
 $36 = $35 >> 2;
 $37 = ($36>>>0)>($0>>>0);
 $38 = $34;
 if ($37) {
  $52 = $38;
 } else {
  $39 = (($0) + 1)|0;
  HEAP32[$2>>2] = 0;
  $40 = ($39>>>0)>($36>>>0);
  $41 = $33;
  if ($40) {
   $42 = (($39) - ($36))|0;
   __ZNSt3__26vectorIiNS_9allocatorIiEEE8__appendEjRKi(208232,$42,$2);
   $$pre$pre$i = HEAP32[52058]|0;
   $$pre$i = $$pre$pre$i;
  } else {
   $43 = ($39>>>0)<($36>>>0);
   if ($43) {
    $44 = (($38) + ($39<<2)|0);
    $45 = ($41|0)==($44|0);
    if ($45) {
     $$pre$i = $38;
    } else {
     $scevgep$i$i$i$i = ((($41)) + -4|0);
     $46 = $scevgep$i$i$i$i;
     $47 = $44;
     $48 = (($46) - ($47))|0;
     $49 = $48 >>> 2;
     $50 = $49 ^ -1;
     $scevgep5$i$i$i$i = (($41) + ($50<<2)|0);
     HEAP32[(208236)>>2] = $scevgep5$i$i$i$i;
     $$pre$i = $38;
    }
   } else {
    $$pre$i = $38;
   }
  }
  $52 = $$pre$i;
 }
 $51 = (($52) + ($0<<2)|0);
 $53 = HEAP32[$51>>2]|0;
 $54 = ($53|0)==(0);
 if (!($54)) {
  $60 = $53;
  STACKTOP = sp;return ($60|0);
 }
 $55 = ((($1)) + 1228|0);
 $56 = HEAP8[$55>>0]|0;
 $57 = ($56<<24>>24)==(0);
 if ($57) {
  $60 = 0;
  STACKTOP = sp;return ($60|0);
 }
 _glGetIntegerv(36183,($51|0));
 $$pre = HEAP32[$51>>2]|0;
 $60 = $$pre;
 STACKTOP = sp;return ($60|0);
}
function __ZN3osg14buffered_valueIiED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i = 0, $scevgep5$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 }
 $3 = ((($0)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==($1|0);
 if (!($5)) {
  $scevgep$i$i$i = ((($4)) + -4|0);
  $6 = $scevgep$i$i$i;
  $7 = $1;
  $8 = (($6) - ($7))|0;
  $9 = $8 >>> 2;
  $10 = $9 ^ -1;
  $scevgep5$i$i$i = (($4) + ($10<<2)|0);
  HEAP32[$3>>2] = $scevgep5$i$i$i;
 }
 __ZdlPv($1);
 return;
}
function __ZN3osg17FrameBufferObjectC2ERKS0_RKNS_6CopyOpE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i$i = 0, $$06 = 0, $$1 = 0, $$17 = 0, $$2 = 0, $$28 = 0, $$3 = 0, $$39 = 0, $$byval_copy = 0, $$pre$i$i$i$i$i$i = 0, $$sroa$07$0$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0;
 var $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0;
 var $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0;
 var $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0;
 var $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$i$index2Z2D = 0, $eh$lpad$body$i$indexZ2D = 0, $eh$lpad$body12$index8Z2D = 0, $eh$lpad$body12$indexZ2D = 0, $eh$lpad$body24$index15Z2D = 0, $eh$lpad$body24$indexZ2D = 0, $eh$lpad$body33$index22Z2D = 0, $eh$lpad$body33$indexZ2D = 0, $scevgep$i$i$i = 0;
 var $scevgep$i$i$i$i = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i16 = 0, $scevgep$i$i$i$i$i27 = 0, $scevgep$i$i$i$i34 = 0, $scevgep5$i$i$i = 0, $scevgep5$i$i$i$i = 0, $scevgep5$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i17 = 0, $scevgep5$i$i$i$i$i28 = 0, $scevgep5$i$i$i$i35 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy = sp + 12|0;
 $3 = sp + 8|0;
 $4 = sp + 4|0;
 $5 = sp;
 __ZN3osg14StateAttributeC2ERKS0_RKNS_6CopyOpE($0,$1,$2);
 HEAP32[$0>>2] = (59060);
 $6 = ((($0)) + 56|0);
 $7 = ((($0)) + 60|0);
 HEAP32[$7>>2] = 0;
 $8 = ((($0)) + 64|0);
 HEAP32[$8>>2] = 0;
 $9 = ((($0)) + 60|0);
 HEAP32[$6>>2] = $9;
 $10 = ((($1)) + 56|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($1)) + 60|0);
 $13 = ($11|0)==($12|0);
 L1: do {
  if ($13) {
   label = 22;
  } else {
   $14 = $9;
   $$sroa$07$0$i = $11;
   while(1) {
    $15 = ((($$sroa$07$0$i)) + 16|0);
    HEAP32[$5>>2] = $14;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy>>2]=HEAP32[$5>>2]|0;
    $16 = (invoke_iiiiii(3761,($6|0),($$byval_copy|0),($3|0),($4|0),($15|0))|0);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     label = 21;
     break;
    }
    $19 = HEAP32[$16>>2]|0;
    $20 = ($19|0)==(0|0);
    if ($20) {
     __THREW__ = 0;
     $21 = (invoke_ii(3276,24)|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      label = 21;
      break;
     }
     $24 = ((($21)) + 16|0);
     $25 = HEAP32[$15>>2]|0;
     HEAP32[$24>>2] = $25;
     $26 = ((($21)) + 20|0);
     __THREW__ = 0;
     $27 = (invoke_ii(3276,24)|0);
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      label = 11;
      break;
     }
     $30 = ((($$sroa$07$0$i)) + 20|0);
     $31 = HEAP32[$30>>2]|0;
     $32 = HEAP32[$31>>2]|0;
     HEAP32[$27>>2] = $32;
     $33 = ((($27)) + 4|0);
     $34 = ((($31)) + 4|0);
     $35 = HEAP32[$34>>2]|0;
     HEAP32[$33>>2] = $35;
     $36 = ($35|0)==(0|0);
     if (!($36)) {
      $37 = ((($35)) + 8|0);
      $38 = HEAP32[$37>>2]|0;HEAP32[$37>>2] = (($38+1)|0);
     }
     $39 = ((($27)) + 8|0);
     $40 = ((($31)) + 8|0);
     $41 = HEAP32[$40>>2]|0;
     HEAP32[$39>>2] = $41;
     $42 = ($41|0)==(0|0);
     if (!($42)) {
      $43 = ((($41)) + 8|0);
      $44 = HEAP32[$43>>2]|0;HEAP32[$43>>2] = (($44+1)|0);
     }
     $47 = ((($27)) + 12|0);
     $48 = ((($31)) + 12|0);
     $49 = HEAP32[$48>>2]|0;
     HEAP32[$47>>2] = $49;
     $50 = ((($27)) + 16|0);
     $51 = ((($31)) + 16|0);
     $52 = HEAP32[$51>>2]|0;
     HEAP32[$50>>2] = $52;
     $53 = ((($27)) + 20|0);
     $54 = ((($31)) + 20|0);
     $55 = HEAP32[$54>>2]|0;
     HEAP32[$53>>2] = $55;
     HEAP32[$26>>2] = $27;
     $56 = HEAP32[$3>>2]|0;
     HEAP32[$21>>2] = 0;
     $57 = ((($21)) + 4|0);
     HEAP32[$57>>2] = 0;
     $58 = ((($21)) + 8|0);
     HEAP32[$58>>2] = $56;
     HEAP32[$16>>2] = $21;
     $59 = HEAP32[$6>>2]|0;
     $60 = HEAP32[$59>>2]|0;
     $61 = ($60|0)==(0|0);
     if ($61) {
      $64 = $21;
     } else {
      $62 = $60;
      HEAP32[$6>>2] = $62;
      $$pre$i$i$i$i$i$i = HEAP32[$16>>2]|0;
      $64 = $$pre$i$i$i$i$i$i;
     }
     $63 = HEAP32[$7>>2]|0;
     __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($63,$64);
     $65 = HEAP32[$8>>2]|0;
     $66 = (($65) + 1)|0;
     HEAP32[$8>>2] = $66;
    }
    $67 = ((($$sroa$07$0$i)) + 4|0);
    $68 = HEAP32[$67>>2]|0;
    $69 = ($68|0)==(0|0);
    if ($69) {
     $70 = ((($$sroa$07$0$i)) + 8|0);
     $71 = HEAP32[$70>>2]|0;
     $72 = HEAP32[$71>>2]|0;
     $73 = ($72|0)==($$sroa$07$0$i|0);
     if ($73) {
      $$0$i$i$i$i$i = $71;
     } else {
      $77 = $70;
      while(1) {
       $76 = HEAP32[$77>>2]|0;
       $78 = ((($76)) + 8|0);
       $79 = HEAP32[$78>>2]|0;
       $80 = HEAP32[$79>>2]|0;
       $81 = ($80|0)==($76|0);
       if ($81) {
        $$0$i$i$i$i$i = $79;
        break;
       } else {
        $77 = $78;
       }
      }
     }
    } else {
     $$0$i$i$i$i$i$i = $68;
     while(1) {
      $74 = HEAP32[$$0$i$i$i$i$i$i>>2]|0;
      $75 = ($74|0)==(0|0);
      if ($75) {
       break;
      } else {
       $$0$i$i$i$i$i$i = $74;
      }
     }
     $$0$i$i$i$i$i = $$0$i$i$i$i$i$i;
    }
    $82 = ($$0$i$i$i$i$i|0)==($12|0);
    if ($82) {
     label = 22;
     break L1;
    } else {
     $$sroa$07$0$i = $$0$i$i$i$i$i;
    }
   }
   if ((label|0) == 11) {
    $45 = ___cxa_find_matching_catch_2()|0;
    $46 = tempRet0;
    __ZdlPv($21);
    $eh$lpad$body$i$index2Z2D = $46;$eh$lpad$body$i$indexZ2D = $45;
   }
   else if ((label|0) == 21) {
    $83 = ___cxa_find_matching_catch_2()|0;
    $84 = tempRet0;
    $eh$lpad$body$i$index2Z2D = $84;$eh$lpad$body$i$indexZ2D = $83;
   }
   $179 = HEAP32[$9>>2]|0;
   __ZNSt3__26__treeINS_12__value_typeIN3osg6Camera15BufferComponentENS2_21FrameBufferAttachmentEEENS_19__map_value_compareIS4_S6_NS_4lessIS4_EELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($6,$179);
   $$3 = $eh$lpad$body$i$index2Z2D;$$39 = $eh$lpad$body$i$indexZ2D;
  }
 } while(0);
 if ((label|0) == 22) {
  $85 = ((($0)) + 68|0);
  $86 = ((($1)) + 68|0);
  __THREW__ = 0;
  invoke_vii(3317,($85|0),($86|0));
  $87 = __THREW__; __THREW__ = 0;
  $88 = $87&1;
  if ($88) {
   $180 = ___cxa_find_matching_catch_2()|0;
   $181 = tempRet0;
   $$2 = $181;$$28 = $180;
  } else {
   $89 = ((($0)) + 80|0);
   __THREW__ = 0;
   $90 = (invoke_i(3285)|0);
   $91 = __THREW__; __THREW__ = 0;
   $92 = $91&1;
   L37: do {
    if ($92) {
     label = 59;
    } else {
     $93 = HEAP32[$90>>2]|0;
     __THREW__ = 0;
     $94 = (invoke_ii(3286,($93|0))|0);
     $95 = __THREW__; __THREW__ = 0;
     $96 = $95&1;
     if ($96) {
      label = 59;
     } else {
      HEAP32[$89>>2] = 0;
      $97 = ((($0)) + 84|0);
      HEAP32[$97>>2] = 0;
      $98 = ((($0)) + 88|0);
      HEAP32[$98>>2] = 0;
      $99 = ($94|0)==(0);
      do {
       if (!($99)) {
        $100 = ($94>>>0)>(1073741823);
        if ($100) {
         __THREW__ = 0;
         invoke_vi(3307,($89|0));
         $101 = __THREW__; __THREW__ = 0;
        } else {
         $102 = $94 << 2;
         __THREW__ = 0;
         $103 = (invoke_ii(3276,($102|0))|0);
         $104 = __THREW__; __THREW__ = 0;
         $105 = $104&1;
         if (!($105)) {
          HEAP32[$89>>2] = $103;
          $106 = (($103) + ($94<<2)|0);
          $107 = ((($0)) + 88|0);
          HEAP32[$107>>2] = $106;
          _memset(($103|0),0,($102|0))|0;
          HEAP32[$97>>2] = $106;
          break;
         }
        }
        $108 = ___cxa_find_matching_catch_2()|0;
        $109 = tempRet0;
        $110 = HEAP32[$89>>2]|0;
        $111 = ($110|0)==(0|0);
        if ($111) {
         $eh$lpad$body12$index8Z2D = $109;$eh$lpad$body12$indexZ2D = $108;
         label = 60;
         break L37;
        }
        $112 = HEAP32[$97>>2]|0;
        $113 = ($112|0)==($110|0);
        if (!($113)) {
         $scevgep$i$i$i$i$i = ((($112)) + -4|0);
         $114 = $scevgep$i$i$i$i$i;
         $115 = $110;
         $116 = (($114) - ($115))|0;
         $117 = $116 >>> 2;
         $118 = $117 ^ -1;
         $scevgep5$i$i$i$i$i = (($112) + ($118<<2)|0);
         HEAP32[$97>>2] = $scevgep5$i$i$i$i$i;
        }
        __ZdlPv($110);
        $eh$lpad$body12$index8Z2D = $109;$eh$lpad$body12$indexZ2D = $108;
        label = 60;
        break L37;
       }
      } while(0);
      $119 = ((($0)) + 92|0);
      __THREW__ = 0;
      $120 = (invoke_i(3285)|0);
      $121 = __THREW__; __THREW__ = 0;
      $122 = $121&1;
      L52: do {
       if ($122) {
        label = 61;
       } else {
        $123 = HEAP32[$120>>2]|0;
        __THREW__ = 0;
        $124 = (invoke_ii(3286,($123|0))|0);
        $125 = __THREW__; __THREW__ = 0;
        $126 = $125&1;
        if ($126) {
         label = 61;
        } else {
         HEAP32[$119>>2] = 0;
         $127 = ((($0)) + 96|0);
         HEAP32[$127>>2] = 0;
         $128 = ((($0)) + 100|0);
         HEAP32[$128>>2] = 0;
         $129 = ($124|0)==(0);
         do {
          if (!($129)) {
           $130 = ($124>>>0)>(1073741823);
           if ($130) {
            __THREW__ = 0;
            invoke_vi(3307,($119|0));
            $131 = __THREW__; __THREW__ = 0;
           } else {
            $132 = $124 << 2;
            __THREW__ = 0;
            $133 = (invoke_ii(3276,($132|0))|0);
            $134 = __THREW__; __THREW__ = 0;
            $135 = $134&1;
            if (!($135)) {
             HEAP32[$119>>2] = $133;
             $136 = (($133) + ($124<<2)|0);
             $137 = ((($0)) + 100|0);
             HEAP32[$137>>2] = $136;
             _memset(($133|0),0,($132|0))|0;
             HEAP32[$127>>2] = $136;
             break;
            }
           }
           $138 = ___cxa_find_matching_catch_2()|0;
           $139 = tempRet0;
           $140 = HEAP32[$119>>2]|0;
           $141 = ($140|0)==(0|0);
           if ($141) {
            $eh$lpad$body24$index15Z2D = $139;$eh$lpad$body24$indexZ2D = $138;
            label = 62;
            break L52;
           }
           $142 = HEAP32[$127>>2]|0;
           $143 = ($142|0)==($140|0);
           if (!($143)) {
            $scevgep$i$i$i$i$i16 = ((($142)) + -4|0);
            $144 = $scevgep$i$i$i$i$i16;
            $145 = $140;
            $146 = (($144) - ($145))|0;
            $147 = $146 >>> 2;
            $148 = $147 ^ -1;
            $scevgep5$i$i$i$i$i17 = (($142) + ($148<<2)|0);
            HEAP32[$127>>2] = $scevgep5$i$i$i$i$i17;
           }
           __ZdlPv($140);
           $eh$lpad$body24$index15Z2D = $139;$eh$lpad$body24$indexZ2D = $138;
           label = 62;
           break L52;
          }
         } while(0);
         $149 = ((($0)) + 104|0);
         __THREW__ = 0;
         $150 = (invoke_i(3285)|0);
         $151 = __THREW__; __THREW__ = 0;
         $152 = $151&1;
         if ($152) {
          label = 63;
         } else {
          $153 = HEAP32[$150>>2]|0;
          __THREW__ = 0;
          $154 = (invoke_ii(3286,($153|0))|0);
          $155 = __THREW__; __THREW__ = 0;
          $156 = $155&1;
          if ($156) {
           label = 63;
          } else {
           HEAP32[$149>>2] = 0;
           $157 = ((($0)) + 108|0);
           HEAP32[$157>>2] = 0;
           $158 = ((($0)) + 112|0);
           HEAP32[$158>>2] = 0;
           $159 = ($154|0)==(0);
           if ($159) {
            STACKTOP = sp;return;
           }
           $160 = ($154>>>0)>(1073741823);
           if ($160) {
            __THREW__ = 0;
            invoke_vi(3307,($149|0));
            $161 = __THREW__; __THREW__ = 0;
           } else {
            $162 = $154 << 2;
            __THREW__ = 0;
            $163 = (invoke_ii(3276,($162|0))|0);
            $164 = __THREW__; __THREW__ = 0;
            $165 = $164&1;
            if (!($165)) {
             HEAP32[$149>>2] = $163;
             $166 = (($163) + ($154<<2)|0);
             $167 = ((($0)) + 112|0);
             HEAP32[$167>>2] = $166;
             _memset(($163|0),0,($162|0))|0;
             HEAP32[$157>>2] = $166;
             STACKTOP = sp;return;
            }
           }
           $168 = ___cxa_find_matching_catch_2()|0;
           $169 = tempRet0;
           $170 = HEAP32[$149>>2]|0;
           $171 = ($170|0)==(0|0);
           if ($171) {
            $eh$lpad$body33$index22Z2D = $169;$eh$lpad$body33$indexZ2D = $168;
           } else {
            $172 = HEAP32[$157>>2]|0;
            $173 = ($172|0)==($170|0);
            if (!($173)) {
             $scevgep$i$i$i$i$i27 = ((($172)) + -4|0);
             $174 = $scevgep$i$i$i$i$i27;
             $175 = $170;
             $176 = (($174) - ($175))|0;
             $177 = $176 >>> 2;
             $178 = $177 ^ -1;
             $scevgep5$i$i$i$i$i28 = (($172) + ($178<<2)|0);
             HEAP32[$157>>2] = $scevgep5$i$i$i$i$i28;
            }
            __ZdlPv($170);
            $eh$lpad$body33$index22Z2D = $169;$eh$lpad$body33$indexZ2D = $168;
           }
          }
         }
         if ((label|0) == 63) {
          $186 = ___cxa_find_matching_catch_2()|0;
          $187 = tempRet0;
          $eh$lpad$body33$index22Z2D = $187;$eh$lpad$body33$indexZ2D = $186;
         }
         $188 = HEAP32[$119>>2]|0;
         $189 = ($188|0)==(0|0);
         if ($189) {
          $$0 = $eh$lpad$body33$index22Z2D;$$06 = $eh$lpad$body33$indexZ2D;
         } else {
          $190 = HEAP32[$127>>2]|0;
          $191 = ($190|0)==($188|0);
          if (!($191)) {
           $scevgep$i$i$i$i = ((($190)) + -4|0);
           $192 = $scevgep$i$i$i$i;
           $193 = $188;
           $194 = (($192) - ($193))|0;
           $195 = $194 >>> 2;
           $196 = $195 ^ -1;
           $scevgep5$i$i$i$i = (($190) + ($196<<2)|0);
           HEAP32[$127>>2] = $scevgep5$i$i$i$i;
          }
          __ZdlPv($188);
          $$0 = $eh$lpad$body33$index22Z2D;$$06 = $eh$lpad$body33$indexZ2D;
         }
        }
       }
      } while(0);
      if ((label|0) == 61) {
       $184 = ___cxa_find_matching_catch_2()|0;
       $185 = tempRet0;
       $eh$lpad$body24$index15Z2D = $185;$eh$lpad$body24$indexZ2D = $184;
       label = 62;
      }
      if ((label|0) == 62) {
       $$0 = $eh$lpad$body24$index15Z2D;$$06 = $eh$lpad$body24$indexZ2D;
      }
      $197 = HEAP32[$89>>2]|0;
      $198 = ($197|0)==(0|0);
      if ($198) {
       $$1 = $$0;$$17 = $$06;
      } else {
       $199 = HEAP32[$97>>2]|0;
       $200 = ($199|0)==($197|0);
       if (!($200)) {
        $scevgep$i$i$i$i34 = ((($199)) + -4|0);
        $201 = $scevgep$i$i$i$i34;
        $202 = $197;
        $203 = (($201) - ($202))|0;
        $204 = $203 >>> 2;
        $205 = $204 ^ -1;
        $scevgep5$i$i$i$i35 = (($199) + ($205<<2)|0);
        HEAP32[$97>>2] = $scevgep5$i$i$i$i35;
       }
       __ZdlPv($197);
       $$1 = $$0;$$17 = $$06;
      }
     }
    }
   } while(0);
   if ((label|0) == 59) {
    $182 = ___cxa_find_matching_catch_2()|0;
    $183 = tempRet0;
    $eh$lpad$body12$index8Z2D = $183;$eh$lpad$body12$indexZ2D = $182;
    label = 60;
   }
   if ((label|0) == 60) {
    $$1 = $eh$lpad$body12$index8Z2D;$$17 = $eh$lpad$body12$indexZ2D;
   }
   $206 = HEAP32[$85>>2]|0;
   $207 = ($206|0)==(0|0);
   if ($207) {
    $$2 = $$1;$$28 = $$17;
   } else {
    $208 = ((($0)) + 72|0);
    $209 = HEAP32[$208>>2]|0;
    $210 = ($209|0)==($206|0);
    if (!($210)) {
     $scevgep$i$i$i = ((($209)) + -4|0);
     $211 = $scevgep$i$i$i;
     $212 = $206;
     $213 = (($211) - ($212))|0;
     $214 = $213 >>> 2;
     $215 = $214 ^ -1;
     $scevgep5$i$i$i = (($209) + ($215<<2)|0);
     HEAP32[$208>>2] = $scevgep5$i$i$i;
    }
    __ZdlPv($206);
    $$2 = $$1;$$28 = $$17;
   }
  }
  $216 = HEAP32[$9>>2]|0;
  __ZNSt3__26__treeINS_12__value_typeIN3osg6Camera15BufferComponentENS2_21FrameBufferAttachmentEEENS_19__map_value_compareIS4_S6_NS_4lessIS4_EELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($6,$216);
  $$3 = $$2;$$39 = $$28;
 }
 __THREW__ = 0;
 invoke_vi(1573,($0|0));
 $217 = __THREW__; __THREW__ = 0;
 $218 = $217&1;
 if ($218) {
  $219 = ___cxa_find_matching_catch_3(0|0)|0;
  $220 = tempRet0;
  ___clang_call_terminate($219);
  // unreachable;
 } else {
  ___resumeException($$39|0);
  // unreachable;
 }
}
function __ZNSt3__26__treeINS_12__value_typeIN3osg6Camera15BufferComponentENS2_21FrameBufferAttachmentEEENS_19__map_value_compareIS4_S6_NS_4lessIS4_EELb1EEENS_9allocatorIS6_EEE12__find_equalIS4_EERPNS_16__tree_node_baseIPvEENS_21__tree_const_iteratorIS6_PNS_11__tree_nodeIS6_SG_EEiEERPNS_15__tree_end_nodeISI_EESJ_RKT_($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0$i = 0, $$0$i$i = 0, $$0$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i$i = 0, $$0$i26 = 0, $$0$ph$i = 0, $$0$ph$i23 = 0, $$024$i = 0, $$024$i25 = 0, $$08$i$i = 0, $$2 = 0, $$in$i = 0, $$in$i22 = 0, $$pre = 0, $$sroa$043$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = ((($0)) + 4|0);
 $6 = HEAP32[$1>>2]|0;
 $7 = ($6|0)==($5|0);
 $8 = $6;
 if (!($7)) {
  $9 = ((($6)) + 16|0);
  $10 = HEAP32[$4>>2]|0;
  $11 = HEAP32[$9>>2]|0;
  $12 = ($10|0)<($11|0);
  if (!($12)) {
   $43 = ($11|0)<($10|0);
   if (!($43)) {
    HEAP32[$2>>2] = $8;
    HEAP32[$3>>2] = $8;
    $$2 = $3;
    return ($$2|0);
   }
   $44 = ((($6)) + 4|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = ($45|0)==(0|0);
   if ($46) {
    $47 = ((($6)) + 8|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = HEAP32[$48>>2]|0;
    $50 = ($49|0)==($6|0);
    if ($50) {
     $$0$i$i$i$i$i = $48;
    } else {
     $54 = $47;
     while(1) {
      $53 = HEAP32[$54>>2]|0;
      $55 = ((($53)) + 8|0);
      $56 = HEAP32[$55>>2]|0;
      $57 = HEAP32[$56>>2]|0;
      $58 = ($57|0)==($53|0);
      if ($58) {
       $$0$i$i$i$i$i = $56;
       break;
      } else {
       $54 = $55;
      }
     }
    }
   } else {
    $$0$i$i$i$i$i$i = $45;
    while(1) {
     $51 = HEAP32[$$0$i$i$i$i$i$i>>2]|0;
     $52 = ($51|0)==(0|0);
     if ($52) {
      break;
     } else {
      $$0$i$i$i$i$i$i = $51;
     }
    }
    $$0$i$i$i$i$i = $$0$i$i$i$i$i$i;
   }
   $59 = ($$0$i$i$i$i$i|0)==($5|0);
   if (!($59)) {
    $60 = ((($$0$i$i$i$i$i)) + 16|0);
    $61 = HEAP32[$60>>2]|0;
    $62 = ($10|0)<($61|0);
    if (!($62)) {
     $66 = HEAP32[$5>>2]|0;
     $67 = ($66|0)==(0|0);
     if ($67) {
      HEAP32[$2>>2] = $5;
      $$2 = $5;
      return ($$2|0);
     }
     $68 = ((($0)) + 4|0);
     $$0$i = $68;$$024$i = $66;
     while(1) {
      $69 = ((($$024$i)) + 16|0);
      $70 = HEAP32[$69>>2]|0;
      $71 = ($10|0)<($70|0);
      if ($71) {
       $72 = HEAP32[$$024$i>>2]|0;
       $73 = ($72|0)==(0|0);
       if ($73) {
        label = 39;
        break;
       } else {
        $$0$ph$i = $$024$i;$$in$i = $72;
       }
      } else {
       $74 = ($70|0)<($10|0);
       if (!($74)) {
        label = 43;
        break;
       }
       $75 = ((($$024$i)) + 4|0);
       $76 = HEAP32[$75>>2]|0;
       $77 = ($76|0)==(0|0);
       if ($77) {
        label = 42;
        break;
       } else {
        $$0$ph$i = $75;$$in$i = $76;
       }
      }
      $$0$i = $$0$ph$i;$$024$i = $$in$i;
     }
     if ((label|0) == 39) {
      HEAP32[$2>>2] = $$024$i;
      $$2 = $$024$i;
      return ($$2|0);
     }
     else if ((label|0) == 42) {
      HEAP32[$2>>2] = $$024$i;
      $$2 = $75;
      return ($$2|0);
     }
     else if ((label|0) == 43) {
      HEAP32[$2>>2] = $$024$i;
      $$2 = $$0$i;
      return ($$2|0);
     }
    }
   }
   $63 = ((($6)) + 4|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = ($64|0)==(0|0);
   if ($65) {
    HEAP32[$2>>2] = $8;
    $$2 = $44;
    return ($$2|0);
   } else {
    HEAP32[$2>>2] = $$0$i$i$i$i$i;
    $$2 = $$0$i$i$i$i$i;
    return ($$2|0);
   }
  }
 }
 $13 = HEAP32[$0>>2]|0;
 $14 = ($6|0)==($13|0);
 $$pre = HEAP32[$6>>2]|0;
 if ($14) {
  $$sroa$043$0 = $8;
 } else {
  $15 = ($$pre|0)==(0|0);
  if ($15) {
   $$0$i$i = $6;
   while(1) {
    $19 = ((($$0$i$i)) + 8|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = HEAP32[$20>>2]|0;
    $22 = ($21|0)==($$0$i$i|0);
    if ($22) {
     $$0$i$i = $20;
    } else {
     $$08$i$i = $20;
     break;
    }
   }
  } else {
   $$0$i$i$i = $$pre;
   while(1) {
    $16 = ((($$0$i$i$i)) + 4|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = ($17|0)==(0|0);
    if ($18) {
     $$08$i$i = $$0$i$i$i;
     break;
    } else {
     $$0$i$i$i = $17;
    }
   }
  }
  $23 = $$08$i$i;
  $24 = ((($$08$i$i)) + 16|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = HEAP32[$4>>2]|0;
  $27 = ($25|0)<($26|0);
  if ($27) {
   $$sroa$043$0 = $23;
  } else {
   $31 = HEAP32[$5>>2]|0;
   $32 = ($31|0)==(0|0);
   if ($32) {
    HEAP32[$2>>2] = $5;
    $$2 = $5;
    return ($$2|0);
   }
   $33 = ((($0)) + 4|0);
   $$0$i26 = $33;$$024$i25 = $31;
   while(1) {
    $34 = ((($$024$i25)) + 16|0);
    $35 = HEAP32[$34>>2]|0;
    $36 = ($26|0)<($35|0);
    if ($36) {
     $37 = HEAP32[$$024$i25>>2]|0;
     $38 = ($37|0)==(0|0);
     if ($38) {
      label = 17;
      break;
     } else {
      $$0$ph$i23 = $$024$i25;$$in$i22 = $37;
     }
    } else {
     $39 = ($35|0)<($26|0);
     if (!($39)) {
      label = 21;
      break;
     }
     $40 = ((($$024$i25)) + 4|0);
     $41 = HEAP32[$40>>2]|0;
     $42 = ($41|0)==(0|0);
     if ($42) {
      label = 20;
      break;
     } else {
      $$0$ph$i23 = $40;$$in$i22 = $41;
     }
    }
    $$0$i26 = $$0$ph$i23;$$024$i25 = $$in$i22;
   }
   if ((label|0) == 17) {
    HEAP32[$2>>2] = $$024$i25;
    $$2 = $$024$i25;
    return ($$2|0);
   }
   else if ((label|0) == 20) {
    HEAP32[$2>>2] = $$024$i25;
    $$2 = $40;
    return ($$2|0);
   }
   else if ((label|0) == 21) {
    HEAP32[$2>>2] = $$024$i25;
    $$2 = $$0$i26;
    return ($$2|0);
   }
  }
 }
 $28 = ($$pre|0)==(0|0);
 if ($28) {
  HEAP32[$2>>2] = $6;
  $$2 = $6;
  return ($$2|0);
 } else {
  $29 = $$sroa$043$0;
  HEAP32[$2>>2] = $29;
  $30 = ((($29)) + 4|0);
  $$2 = $30;
  return ($$2|0);
 }
 return (0)|0;
}
function __ZNSt3__26__treeINS_12__value_typeIN3osg6Camera15BufferComponentENS2_21FrameBufferAttachmentEEENS_19__map_value_compareIS4_S6_NS_4lessIS4_EELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 }
 $3 = HEAP32[$1>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIN3osg6Camera15BufferComponentENS2_21FrameBufferAttachmentEEENS_19__map_value_compareIS4_S6_NS_4lessIS4_EELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($0,$3);
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIN3osg6Camera15BufferComponentENS2_21FrameBufferAttachmentEEENS_19__map_value_compareIS4_S6_NS_4lessIS4_EELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($0,$5);
 $6 = ((($1)) + 20|0);
 __THREW__ = 0;
 invoke_vi(3680,($6|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch_2()|0;
  $10 = tempRet0;
  ___cxa_call_unexpected(($9|0));
  // unreachable;
 }
 __ZdlPv($1);
 return;
}
function __ZN3osg21FrameBufferAttachmentD2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index4Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 }
 $3 = ((($1)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  label = 5;
 } else {
  $6 = ((($4)) + 8|0);
  $7 = HEAP32[$6>>2]|0;HEAP32[$6>>2] = (($7-1)|0);
  $8 = ($7|0)==(1);
  if ($8) {
   __THREW__ = 0;
   invoke_viii(3262,($4|0),1,1);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if ($10) {
    $19 = ___cxa_find_matching_catch_2()|0;
    $20 = tempRet0;
    $21 = ((($1)) + 4|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = ($22|0)==(0|0);
    if ($23) {
     $eh$lpad$body$index4Z2D = $20;$eh$lpad$body$indexZ2D = $19;
    } else {
     $24 = ((($22)) + 8|0);
     $25 = HEAP32[$24>>2]|0;HEAP32[$24>>2] = (($25-1)|0);
     $26 = ($25|0)==(1);
     if ($26) {
      __THREW__ = 0;
      invoke_viii(3262,($22|0),1,1);
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       $29 = ___cxa_find_matching_catch_3(0|0)|0;
       $30 = tempRet0;
       ___clang_call_terminate($29);
       // unreachable;
      } else {
       $eh$lpad$body$index4Z2D = $20;$eh$lpad$body$indexZ2D = $19;
      }
     } else {
      $eh$lpad$body$index4Z2D = $20;$eh$lpad$body$indexZ2D = $19;
     }
    }
   } else {
    label = 5;
   }
  } else {
   label = 5;
  }
 }
 do {
  if ((label|0) == 5) {
   HEAP32[$3>>2] = 0;
   $11 = ((($1)) + 4|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = ($12|0)==(0|0);
   if (!($13)) {
    $14 = ((($12)) + 8|0);
    $15 = HEAP32[$14>>2]|0;HEAP32[$14>>2] = (($15-1)|0);
    $16 = ($15|0)==(1);
    if ($16) {
     __THREW__ = 0;
     invoke_viii(3262,($12|0),1,1);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      $31 = ___cxa_find_matching_catch_2()|0;
      $32 = tempRet0;
      $eh$lpad$body$index4Z2D = $32;$eh$lpad$body$indexZ2D = $31;
      break;
     }
    }
   }
   __ZdlPv($1);
   return;
  }
 } while(0);
 __ZdlPv($1);
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
}
function __ZN3osg17FrameBufferObjectC2Ev($0) {
 $0 = $0|0;
 var $$0 = 0, $$02 = 0, $$1 = 0, $$13 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index3Z2D = 0;
 var $eh$lpad$body$indexZ2D = 0, $eh$lpad$body18$index10Z2D = 0, $eh$lpad$body18$indexZ2D = 0, $eh$lpad$body27$index17Z2D = 0, $eh$lpad$body27$indexZ2D = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i10 = 0, $scevgep$i$i$i$i$i21 = 0, $scevgep$i$i$i$i28 = 0, $scevgep5$i$i$i = 0, $scevgep5$i$i$i$i = 0, $scevgep5$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i11 = 0, $scevgep5$i$i$i$i$i22 = 0, $scevgep5$i$i$i$i29 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg14StateAttributeC2Ev($0);
 HEAP32[$0>>2] = (59060);
 $1 = ((($0)) + 56|0);
 $2 = ((($0)) + 60|0);
 HEAP32[$2>>2] = 0;
 $3 = ((($0)) + 64|0);
 HEAP32[$3>>2] = 0;
 $4 = ((($0)) + 60|0);
 HEAP32[$1>>2] = $4;
 $5 = ((($0)) + 68|0);
 HEAP32[$5>>2] = 0;
 $6 = ((($0)) + 72|0);
 HEAP32[$6>>2] = 0;
 $7 = ((($0)) + 76|0);
 HEAP32[$7>>2] = 0;
 $8 = ((($0)) + 80|0);
 __THREW__ = 0;
 $9 = (invoke_i(3285)|0);
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 L1: do {
  if ($11) {
   label = 35;
  } else {
   $12 = HEAP32[$9>>2]|0;
   __THREW__ = 0;
   $13 = (invoke_ii(3286,($12|0))|0);
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if ($15) {
    label = 35;
   } else {
    HEAP32[$8>>2] = 0;
    $16 = ((($0)) + 84|0);
    HEAP32[$16>>2] = 0;
    $17 = ((($0)) + 88|0);
    HEAP32[$17>>2] = 0;
    $18 = ($13|0)==(0);
    do {
     if (!($18)) {
      $19 = ($13>>>0)>(1073741823);
      if ($19) {
       __THREW__ = 0;
       invoke_vi(3307,($8|0));
       $20 = __THREW__; __THREW__ = 0;
      } else {
       $21 = $13 << 2;
       __THREW__ = 0;
       $22 = (invoke_ii(3276,($21|0))|0);
       $23 = __THREW__; __THREW__ = 0;
       $24 = $23&1;
       if (!($24)) {
        HEAP32[$8>>2] = $22;
        $25 = (($22) + ($13<<2)|0);
        $26 = ((($0)) + 88|0);
        HEAP32[$26>>2] = $25;
        _memset(($22|0),0,($21|0))|0;
        HEAP32[$16>>2] = $25;
        break;
       }
      }
      $27 = ___cxa_find_matching_catch_2()|0;
      $28 = tempRet0;
      $29 = HEAP32[$8>>2]|0;
      $30 = ($29|0)==(0|0);
      if ($30) {
       $eh$lpad$body$index3Z2D = $28;$eh$lpad$body$indexZ2D = $27;
       label = 36;
       break L1;
      }
      $31 = HEAP32[$16>>2]|0;
      $32 = ($31|0)==($29|0);
      if (!($32)) {
       $scevgep$i$i$i$i$i = ((($31)) + -4|0);
       $33 = $scevgep$i$i$i$i$i;
       $34 = $29;
       $35 = (($33) - ($34))|0;
       $36 = $35 >>> 2;
       $37 = $36 ^ -1;
       $scevgep5$i$i$i$i$i = (($31) + ($37<<2)|0);
       HEAP32[$16>>2] = $scevgep5$i$i$i$i$i;
      }
      __ZdlPv($29);
      $eh$lpad$body$index3Z2D = $28;$eh$lpad$body$indexZ2D = $27;
      label = 36;
      break L1;
     }
    } while(0);
    $38 = ((($0)) + 92|0);
    __THREW__ = 0;
    $39 = (invoke_i(3285)|0);
    $40 = __THREW__; __THREW__ = 0;
    $41 = $40&1;
    L16: do {
     if ($41) {
      label = 37;
     } else {
      $42 = HEAP32[$39>>2]|0;
      __THREW__ = 0;
      $43 = (invoke_ii(3286,($42|0))|0);
      $44 = __THREW__; __THREW__ = 0;
      $45 = $44&1;
      if ($45) {
       label = 37;
      } else {
       HEAP32[$38>>2] = 0;
       $46 = ((($0)) + 96|0);
       HEAP32[$46>>2] = 0;
       $47 = ((($0)) + 100|0);
       HEAP32[$47>>2] = 0;
       $48 = ($43|0)==(0);
       do {
        if (!($48)) {
         $49 = ($43>>>0)>(1073741823);
         if ($49) {
          __THREW__ = 0;
          invoke_vi(3307,($38|0));
          $50 = __THREW__; __THREW__ = 0;
         } else {
          $51 = $43 << 2;
          __THREW__ = 0;
          $52 = (invoke_ii(3276,($51|0))|0);
          $53 = __THREW__; __THREW__ = 0;
          $54 = $53&1;
          if (!($54)) {
           HEAP32[$38>>2] = $52;
           $55 = (($52) + ($43<<2)|0);
           $56 = ((($0)) + 100|0);
           HEAP32[$56>>2] = $55;
           _memset(($52|0),0,($51|0))|0;
           HEAP32[$46>>2] = $55;
           break;
          }
         }
         $57 = ___cxa_find_matching_catch_2()|0;
         $58 = tempRet0;
         $59 = HEAP32[$38>>2]|0;
         $60 = ($59|0)==(0|0);
         if ($60) {
          $eh$lpad$body18$index10Z2D = $58;$eh$lpad$body18$indexZ2D = $57;
          label = 38;
          break L16;
         }
         $61 = HEAP32[$46>>2]|0;
         $62 = ($61|0)==($59|0);
         if (!($62)) {
          $scevgep$i$i$i$i$i10 = ((($61)) + -4|0);
          $63 = $scevgep$i$i$i$i$i10;
          $64 = $59;
          $65 = (($63) - ($64))|0;
          $66 = $65 >>> 2;
          $67 = $66 ^ -1;
          $scevgep5$i$i$i$i$i11 = (($61) + ($67<<2)|0);
          HEAP32[$46>>2] = $scevgep5$i$i$i$i$i11;
         }
         __ZdlPv($59);
         $eh$lpad$body18$index10Z2D = $58;$eh$lpad$body18$indexZ2D = $57;
         label = 38;
         break L16;
        }
       } while(0);
       $68 = ((($0)) + 104|0);
       __THREW__ = 0;
       $69 = (invoke_i(3285)|0);
       $70 = __THREW__; __THREW__ = 0;
       $71 = $70&1;
       if ($71) {
        label = 39;
       } else {
        $72 = HEAP32[$69>>2]|0;
        __THREW__ = 0;
        $73 = (invoke_ii(3286,($72|0))|0);
        $74 = __THREW__; __THREW__ = 0;
        $75 = $74&1;
        if ($75) {
         label = 39;
        } else {
         HEAP32[$68>>2] = 0;
         $76 = ((($0)) + 108|0);
         HEAP32[$76>>2] = 0;
         $77 = ((($0)) + 112|0);
         HEAP32[$77>>2] = 0;
         $78 = ($73|0)==(0);
         if ($78) {
          return;
         }
         $79 = ($73>>>0)>(1073741823);
         if ($79) {
          __THREW__ = 0;
          invoke_vi(3307,($68|0));
          $80 = __THREW__; __THREW__ = 0;
         } else {
          $81 = $73 << 2;
          __THREW__ = 0;
          $82 = (invoke_ii(3276,($81|0))|0);
          $83 = __THREW__; __THREW__ = 0;
          $84 = $83&1;
          if (!($84)) {
           HEAP32[$68>>2] = $82;
           $85 = (($82) + ($73<<2)|0);
           $86 = ((($0)) + 112|0);
           HEAP32[$86>>2] = $85;
           _memset(($82|0),0,($81|0))|0;
           HEAP32[$76>>2] = $85;
           return;
          }
         }
         $87 = ___cxa_find_matching_catch_2()|0;
         $88 = tempRet0;
         $89 = HEAP32[$68>>2]|0;
         $90 = ($89|0)==(0|0);
         if ($90) {
          $eh$lpad$body27$index17Z2D = $88;$eh$lpad$body27$indexZ2D = $87;
         } else {
          $91 = HEAP32[$76>>2]|0;
          $92 = ($91|0)==($89|0);
          if (!($92)) {
           $scevgep$i$i$i$i$i21 = ((($91)) + -4|0);
           $93 = $scevgep$i$i$i$i$i21;
           $94 = $89;
           $95 = (($93) - ($94))|0;
           $96 = $95 >>> 2;
           $97 = $96 ^ -1;
           $scevgep5$i$i$i$i$i22 = (($91) + ($97<<2)|0);
           HEAP32[$76>>2] = $scevgep5$i$i$i$i$i22;
          }
          __ZdlPv($89);
          $eh$lpad$body27$index17Z2D = $88;$eh$lpad$body27$indexZ2D = $87;
         }
        }
       }
       if ((label|0) == 39) {
        $102 = ___cxa_find_matching_catch_2()|0;
        $103 = tempRet0;
        $eh$lpad$body27$index17Z2D = $103;$eh$lpad$body27$indexZ2D = $102;
       }
       $104 = HEAP32[$38>>2]|0;
       $105 = ($104|0)==(0|0);
       if ($105) {
        $$0 = $eh$lpad$body27$index17Z2D;$$02 = $eh$lpad$body27$indexZ2D;
       } else {
        $106 = HEAP32[$46>>2]|0;
        $107 = ($106|0)==($104|0);
        if (!($107)) {
         $scevgep$i$i$i$i = ((($106)) + -4|0);
         $108 = $scevgep$i$i$i$i;
         $109 = $104;
         $110 = (($108) - ($109))|0;
         $111 = $110 >>> 2;
         $112 = $111 ^ -1;
         $scevgep5$i$i$i$i = (($106) + ($112<<2)|0);
         HEAP32[$46>>2] = $scevgep5$i$i$i$i;
        }
        __ZdlPv($104);
        $$0 = $eh$lpad$body27$index17Z2D;$$02 = $eh$lpad$body27$indexZ2D;
       }
      }
     }
    } while(0);
    if ((label|0) == 37) {
     $100 = ___cxa_find_matching_catch_2()|0;
     $101 = tempRet0;
     $eh$lpad$body18$index10Z2D = $101;$eh$lpad$body18$indexZ2D = $100;
     label = 38;
    }
    if ((label|0) == 38) {
     $$0 = $eh$lpad$body18$index10Z2D;$$02 = $eh$lpad$body18$indexZ2D;
    }
    $113 = HEAP32[$8>>2]|0;
    $114 = ($113|0)==(0|0);
    if ($114) {
     $$1 = $$0;$$13 = $$02;
    } else {
     $115 = HEAP32[$16>>2]|0;
     $116 = ($115|0)==($113|0);
     if (!($116)) {
      $scevgep$i$i$i$i28 = ((($115)) + -4|0);
      $117 = $scevgep$i$i$i$i28;
      $118 = $113;
      $119 = (($117) - ($118))|0;
      $120 = $119 >>> 2;
      $121 = $120 ^ -1;
      $scevgep5$i$i$i$i29 = (($115) + ($121<<2)|0);
      HEAP32[$16>>2] = $scevgep5$i$i$i$i29;
     }
     __ZdlPv($113);
     $$1 = $$0;$$13 = $$02;
    }
   }
  }
 } while(0);
 if ((label|0) == 35) {
  $98 = ___cxa_find_matching_catch_2()|0;
  $99 = tempRet0;
  $eh$lpad$body$index3Z2D = $99;$eh$lpad$body$indexZ2D = $98;
  label = 36;
 }
 if ((label|0) == 36) {
  $$1 = $eh$lpad$body$index3Z2D;$$13 = $eh$lpad$body$indexZ2D;
 }
 $122 = HEAP32[$5>>2]|0;
 $123 = ($122|0)==(0|0);
 if (!($123)) {
  $124 = HEAP32[$6>>2]|0;
  $125 = ($124|0)==($122|0);
  if (!($125)) {
   $scevgep$i$i$i = ((($124)) + -4|0);
   $126 = $scevgep$i$i$i;
   $127 = $122;
   $128 = (($126) - ($127))|0;
   $129 = $128 >>> 2;
   $130 = $129 ^ -1;
   $scevgep5$i$i$i = (($124) + ($130<<2)|0);
   HEAP32[$6>>2] = $scevgep5$i$i$i;
  }
  __ZdlPv($122);
 }
 $131 = HEAP32[$4>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIN3osg6Camera15BufferComponentENS2_21FrameBufferAttachmentEEENS_19__map_value_compareIS4_S6_NS_4lessIS4_EELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($1,$131);
 __THREW__ = 0;
 invoke_vi(1573,($0|0));
 $132 = __THREW__; __THREW__ = 0;
 $133 = $132&1;
 if ($133) {
  $134 = ___cxa_find_matching_catch_3(0|0)|0;
  $135 = tempRet0;
  ___clang_call_terminate($134);
  // unreachable;
 } else {
  ___resumeException($$13|0);
  // unreachable;
 }
}
function __ZN3osg21GLRenderBufferManagerC2Ej($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0;
 var src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = (__Znwj(32)|0);
 HEAP32[$2>>2] = $3;
 $4 = ((($2)) + 8|0);
 HEAP32[$4>>2] = -2147483616;
 $5 = ((($2)) + 4|0);
 HEAP32[$5>>2] = 21;
 dest=$3; src=127297; stop=dest+21|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $6 = ((($3)) + 21|0);
 HEAP8[$6>>0] = 0;
 __THREW__ = 0;
 invoke_viii(3762,($0|0),($2|0),($1|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $13 = ___cxa_find_matching_catch_2()|0;
  $14 = tempRet0;
  $15 = ((($2)) + 11|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = ($16<<24>>24)<(0);
  if (!($17)) {
   ___resumeException($13|0);
   // unreachable;
  }
  $18 = HEAP32[$2>>2]|0;
  __ZdlPv($18);
  ___resumeException($13|0);
  // unreachable;
 } else {
  $9 = ((($2)) + 11|0);
  $10 = HEAP8[$9>>0]|0;
  $11 = ($10<<24>>24)<(0);
  if (!($11)) {
   HEAP32[$0>>2] = (58784);
   STACKTOP = sp;return;
  }
  $12 = HEAP32[$2>>2]|0;
  __ZdlPv($12);
  HEAP32[$0>>2] = (58784);
  STACKTOP = sp;return;
 }
}
function __ZN3osg26GLFrameBufferObjectManagerC2Ej($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0;
 var src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = (__Znwj(32)|0);
 HEAP32[$2>>2] = $3;
 $4 = ((($2)) + 8|0);
 HEAP32[$4>>2] = -2147483616;
 $5 = ((($2)) + 4|0);
 HEAP32[$5>>2] = 26;
 dest=$3; src=127319; stop=dest+26|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $6 = ((($3)) + 26|0);
 HEAP8[$6>>0] = 0;
 __THREW__ = 0;
 invoke_viii(3762,($0|0),($2|0),($1|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $13 = ___cxa_find_matching_catch_2()|0;
  $14 = tempRet0;
  $15 = ((($2)) + 11|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = ($16<<24>>24)<(0);
  if (!($17)) {
   ___resumeException($13|0);
   // unreachable;
  }
  $18 = HEAP32[$2>>2]|0;
  __ZdlPv($18);
  ___resumeException($13|0);
  // unreachable;
 } else {
  $9 = ((($2)) + 11|0);
  $10 = HEAP8[$9>>0]|0;
  $11 = ($10<<24>>24)<(0);
  if (!($11)) {
   HEAP32[$0>>2] = (58848);
   STACKTOP = sp;return;
  }
  $12 = HEAP32[$2>>2]|0;
  __ZdlPv($12);
  HEAP32[$0>>2] = (58848);
  STACKTOP = sp;return;
 }
}
function __ZN3osg12RenderBufferC2Eiijii($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$0 = 0, $$07 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $eh$lpad$body$index3Z2D = 0, $eh$lpad$body$indexZ2D = 0, $eh$lpad$body16$index10Z2D = 0, $eh$lpad$body16$indexZ2D = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i10 = 0, $scevgep5$i$i$i$i = 0, $scevgep5$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i11 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg10ReferencedC2Ev($0);
 $6 = ((($0)) + 12|0);
 ;HEAP32[$6>>2]=0|0;HEAP32[$6+4>>2]=0|0;HEAP32[$6+8>>2]=0|0;
 $7 = ((($0)) + 24|0);
 HEAP32[$7>>2] = 2;
 $8 = ((($0)) + 28|0);
 HEAP32[$8>>2] = 0;
 HEAP32[$0>>2] = (58912);
 $9 = ((($0)) + 32|0);
 __THREW__ = 0;
 $10 = (invoke_i(3285)|0);
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 L1: do {
  if ($12) {
   label = 24;
  } else {
   $13 = HEAP32[$10>>2]|0;
   __THREW__ = 0;
   $14 = (invoke_ii(3286,($13|0))|0);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if ($16) {
    label = 24;
   } else {
    HEAP32[$9>>2] = 0;
    $17 = ((($0)) + 36|0);
    HEAP32[$17>>2] = 0;
    $18 = ((($0)) + 40|0);
    HEAP32[$18>>2] = 0;
    $19 = ($14|0)==(0);
    do {
     if (!($19)) {
      $20 = ($14>>>0)>(1073741823);
      if ($20) {
       __THREW__ = 0;
       invoke_vi(3307,($9|0));
       $21 = __THREW__; __THREW__ = 0;
      } else {
       $22 = $14 << 2;
       __THREW__ = 0;
       $23 = (invoke_ii(3276,($22|0))|0);
       $24 = __THREW__; __THREW__ = 0;
       $25 = $24&1;
       if (!($25)) {
        HEAP32[$9>>2] = $23;
        $26 = (($23) + ($14<<2)|0);
        $27 = ((($0)) + 40|0);
        HEAP32[$27>>2] = $26;
        _memset(($23|0),0,($22|0))|0;
        HEAP32[$17>>2] = $26;
        break;
       }
      }
      $28 = ___cxa_find_matching_catch_2()|0;
      $29 = tempRet0;
      $30 = HEAP32[$9>>2]|0;
      $31 = ($30|0)==(0|0);
      if ($31) {
       $eh$lpad$body$index3Z2D = $29;$eh$lpad$body$indexZ2D = $28;
       label = 25;
       break L1;
      }
      $32 = HEAP32[$17>>2]|0;
      $33 = ($32|0)==($30|0);
      if (!($33)) {
       $scevgep$i$i$i$i$i = ((($32)) + -4|0);
       $34 = $scevgep$i$i$i$i$i;
       $35 = $30;
       $36 = (($34) - ($35))|0;
       $37 = $36 >>> 2;
       $38 = $37 ^ -1;
       $scevgep5$i$i$i$i$i = (($32) + ($38<<2)|0);
       HEAP32[$17>>2] = $scevgep5$i$i$i$i$i;
      }
      __ZdlPv($30);
      $eh$lpad$body$index3Z2D = $29;$eh$lpad$body$indexZ2D = $28;
      label = 25;
      break L1;
     }
    } while(0);
    $39 = ((($0)) + 44|0);
    __THREW__ = 0;
    $40 = (invoke_i(3285)|0);
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     label = 26;
    } else {
     $43 = HEAP32[$40>>2]|0;
     __THREW__ = 0;
     $44 = (invoke_ii(3286,($43|0))|0);
     $45 = __THREW__; __THREW__ = 0;
     $46 = $45&1;
     if ($46) {
      label = 26;
     } else {
      HEAP32[$39>>2] = 0;
      $47 = ((($0)) + 48|0);
      HEAP32[$47>>2] = 0;
      $48 = ((($0)) + 52|0);
      HEAP32[$48>>2] = 0;
      $49 = ($44|0)==(0);
      if ($49) {
       $69 = ((($0)) + 56|0);
       HEAP32[$69>>2] = $3;
       $70 = ((($0)) + 60|0);
       HEAP32[$70>>2] = $1;
       $71 = ((($0)) + 64|0);
       HEAP32[$71>>2] = $2;
       $72 = ((($0)) + 68|0);
       HEAP32[$72>>2] = $4;
       $73 = ((($0)) + 72|0);
       HEAP32[$73>>2] = $5;
       return;
      }
      $50 = ($44>>>0)>(1073741823);
      if ($50) {
       __THREW__ = 0;
       invoke_vi(3307,($39|0));
       $51 = __THREW__; __THREW__ = 0;
      } else {
       $52 = $44 << 2;
       __THREW__ = 0;
       $53 = (invoke_ii(3276,($52|0))|0);
       $54 = __THREW__; __THREW__ = 0;
       $55 = $54&1;
       if (!($55)) {
        HEAP32[$39>>2] = $53;
        $56 = (($53) + ($44<<2)|0);
        $57 = ((($0)) + 52|0);
        HEAP32[$57>>2] = $56;
        _memset(($53|0),0,($52|0))|0;
        HEAP32[$47>>2] = $56;
        $69 = ((($0)) + 56|0);
        HEAP32[$69>>2] = $3;
        $70 = ((($0)) + 60|0);
        HEAP32[$70>>2] = $1;
        $71 = ((($0)) + 64|0);
        HEAP32[$71>>2] = $2;
        $72 = ((($0)) + 68|0);
        HEAP32[$72>>2] = $4;
        $73 = ((($0)) + 72|0);
        HEAP32[$73>>2] = $5;
        return;
       }
      }
      $58 = ___cxa_find_matching_catch_2()|0;
      $59 = tempRet0;
      $60 = HEAP32[$39>>2]|0;
      $61 = ($60|0)==(0|0);
      if ($61) {
       $eh$lpad$body16$index10Z2D = $59;$eh$lpad$body16$indexZ2D = $58;
      } else {
       $62 = HEAP32[$47>>2]|0;
       $63 = ($62|0)==($60|0);
       if (!($63)) {
        $scevgep$i$i$i$i$i10 = ((($62)) + -4|0);
        $64 = $scevgep$i$i$i$i$i10;
        $65 = $60;
        $66 = (($64) - ($65))|0;
        $67 = $66 >>> 2;
        $68 = $67 ^ -1;
        $scevgep5$i$i$i$i$i11 = (($62) + ($68<<2)|0);
        HEAP32[$47>>2] = $scevgep5$i$i$i$i$i11;
       }
       __ZdlPv($60);
       $eh$lpad$body16$index10Z2D = $59;$eh$lpad$body16$indexZ2D = $58;
      }
     }
    }
    if ((label|0) == 26) {
     $76 = ___cxa_find_matching_catch_2()|0;
     $77 = tempRet0;
     $eh$lpad$body16$index10Z2D = $77;$eh$lpad$body16$indexZ2D = $76;
    }
    $78 = HEAP32[$9>>2]|0;
    $79 = ($78|0)==(0|0);
    if ($79) {
     $$0 = $eh$lpad$body16$index10Z2D;$$07 = $eh$lpad$body16$indexZ2D;
    } else {
     $80 = HEAP32[$17>>2]|0;
     $81 = ($80|0)==($78|0);
     if (!($81)) {
      $scevgep$i$i$i$i = ((($80)) + -4|0);
      $82 = $scevgep$i$i$i$i;
      $83 = $78;
      $84 = (($82) - ($83))|0;
      $85 = $84 >>> 2;
      $86 = $85 ^ -1;
      $scevgep5$i$i$i$i = (($80) + ($86<<2)|0);
      HEAP32[$17>>2] = $scevgep5$i$i$i$i;
     }
     __ZdlPv($78);
     $$0 = $eh$lpad$body16$index10Z2D;$$07 = $eh$lpad$body16$indexZ2D;
    }
   }
  }
 } while(0);
 if ((label|0) == 24) {
  $74 = ___cxa_find_matching_catch_2()|0;
  $75 = tempRet0;
  $eh$lpad$body$index3Z2D = $75;$eh$lpad$body$indexZ2D = $74;
  label = 25;
 }
 if ((label|0) == 25) {
  $$0 = $eh$lpad$body$index3Z2D;$$07 = $eh$lpad$body$indexZ2D;
 }
 __THREW__ = 0;
 invoke_vi(388,($0|0));
 $87 = __THREW__; __THREW__ = 0;
 $88 = $87&1;
 if ($88) {
  $89 = ___cxa_find_matching_catch_3(0|0)|0;
  $90 = tempRet0;
  ___clang_call_terminate($89);
  // unreachable;
 } else {
  ___resumeException($$07|0);
  // unreachable;
 }
}
function __ZN3osg21FrameBufferAttachmentC2EPNS_12RenderBufferE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(24)|0);
 ;HEAP32[$2>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;HEAP32[$2+12>>2]=0|0;HEAP32[$2+16>>2]=0|0;HEAP32[$2+20>>2]=0|0;
 HEAP32[$0>>2] = $2;
 $3 = ($1|0)==(0|0);
 if ($3) {
  return;
 }
 $4 = ((($2)) + 4|0);
 HEAP32[$4>>2] = $1;
 $5 = ((($1)) + 8|0);
 $6 = HEAP32[$5>>2]|0;HEAP32[$5>>2] = (($6+1)|0);
 return;
}
function __ZN3osg21FrameBufferAttachmentC2ERNS_6Camera10AttachmentE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$pre = 0, $$pre107 = 0, $$pre110 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp + 4|0;
 $3 = sp;
 $4 = ((($1)) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = (___dynamic_cast($5,26864,26752,0)|0);
  $8 = ($7|0)==(0|0);
  if (!($8)) {
   $9 = (__Znwj(24)|0);
   $10 = ((($1)) + 12|0);
   $11 = HEAP32[$10>>2]|0;
   HEAP32[$9>>2] = 1;
   $12 = ((($9)) + 4|0);
   HEAP32[$12>>2] = 0;
   $13 = ((($9)) + 8|0);
   $14 = ((($9)) + 12|0);
   HEAP32[$14>>2] = 0;
   $15 = ((($9)) + 16|0);
   HEAP32[$15>>2] = $11;
   $16 = ((($9)) + 20|0);
   HEAP32[$16>>2] = 0;
   HEAP32[$0>>2] = $9;
   HEAP32[$13>>2] = $7;
   $17 = ((($7)) + 8|0);
   $18 = HEAP32[$17>>2]|0;HEAP32[$17>>2] = (($18+1)|0);
   STACKTOP = sp;return;
  }
  $19 = (___dynamic_cast($5,26864,26784,0)|0);
  $20 = ($19|0)==(0|0);
  if (!($20)) {
   $21 = (__Znwj(24)|0);
   $22 = ((($1)) + 12|0);
   $23 = HEAP32[$22>>2]|0;
   HEAP32[$21>>2] = 2;
   $24 = ((($21)) + 4|0);
   HEAP32[$24>>2] = 0;
   $25 = ((($21)) + 8|0);
   $26 = ((($21)) + 12|0);
   HEAP32[$26>>2] = 0;
   $27 = ((($21)) + 16|0);
   HEAP32[$27>>2] = $23;
   $28 = ((($21)) + 20|0);
   HEAP32[$28>>2] = 0;
   HEAP32[$0>>2] = $21;
   HEAP32[$25>>2] = $19;
   $29 = ((($19)) + 8|0);
   $30 = HEAP32[$29>>2]|0;HEAP32[$29>>2] = (($30+1)|0);
   STACKTOP = sp;return;
  }
  $31 = (___dynamic_cast($5,26864,26800,0)|0);
  $32 = ($31|0)==(0|0);
  if (!($32)) {
   $33 = (__Znwj(24)|0);
   $34 = ((($1)) + 12|0);
   $35 = HEAP32[$34>>2]|0;
   HEAP32[$33>>2] = 7;
   $36 = ((($33)) + 4|0);
   HEAP32[$36>>2] = 0;
   $37 = ((($33)) + 8|0);
   $38 = ((($33)) + 12|0);
   HEAP32[$38>>2] = 0;
   $39 = ((($33)) + 16|0);
   HEAP32[$39>>2] = $35;
   $40 = ((($33)) + 20|0);
   HEAP32[$40>>2] = 0;
   HEAP32[$0>>2] = $33;
   HEAP32[$37>>2] = $31;
   $41 = ((($31)) + 8|0);
   $42 = HEAP32[$41>>2]|0;HEAP32[$41>>2] = (($42+1)|0);
   STACKTOP = sp;return;
  }
  $43 = (___dynamic_cast($5,26864,26816,0)|0);
  $44 = ($43|0)==(0|0);
  if (!($44)) {
   $45 = (__Znwj(24)|0);
   $46 = ((($1)) + 12|0);
   $47 = HEAP32[$46>>2]|0;
   HEAP32[$45>>2] = 3;
   $48 = ((($45)) + 4|0);
   HEAP32[$48>>2] = 0;
   $49 = ((($45)) + 8|0);
   $50 = ((($45)) + 12|0);
   HEAP32[$50>>2] = 0;
   $51 = ((($45)) + 16|0);
   HEAP32[$51>>2] = $47;
   $52 = ((($45)) + 20|0);
   HEAP32[$52>>2] = 0;
   HEAP32[$0>>2] = $45;
   HEAP32[$49>>2] = $43;
   $53 = ((($43)) + 8|0);
   $54 = HEAP32[$53>>2]|0;HEAP32[$53>>2] = (($54+1)|0);
   $$pre = HEAP32[$0>>2]|0;
   $55 = ((($1)) + 16|0);
   $56 = HEAP32[$55>>2]|0;
   $57 = ((($$pre)) + 20|0);
   HEAP32[$57>>2] = $56;
   STACKTOP = sp;return;
  }
  $58 = (___dynamic_cast($5,26864,26768,0)|0);
  $59 = ($58|0)==(0|0);
  if (!($59)) {
   $60 = (__Znwj(24)|0);
   $61 = ((($1)) + 12|0);
   $62 = HEAP32[$61>>2]|0;
   HEAP32[$60>>2] = 6;
   $63 = ((($60)) + 4|0);
   HEAP32[$63>>2] = 0;
   $64 = ((($60)) + 8|0);
   $65 = ((($60)) + 12|0);
   HEAP32[$65>>2] = 0;
   $66 = ((($60)) + 16|0);
   HEAP32[$66>>2] = $62;
   $67 = ((($60)) + 20|0);
   HEAP32[$67>>2] = 0;
   HEAP32[$0>>2] = $60;
   HEAP32[$64>>2] = $58;
   $68 = ((($58)) + 8|0);
   $69 = HEAP32[$68>>2]|0;HEAP32[$68>>2] = (($69+1)|0);
   $$pre107 = HEAP32[$0>>2]|0;
   $70 = ((($1)) + 16|0);
   $71 = HEAP32[$70>>2]|0;
   $72 = ((($$pre107)) + 20|0);
   HEAP32[$72>>2] = $71;
   STACKTOP = sp;return;
  }
  $73 = (___dynamic_cast($5,26864,26896,0)|0);
  $74 = ($73|0)==(0|0);
  if (!($74)) {
   $75 = (__Znwj(24)|0);
   $76 = ((($1)) + 12|0);
   $77 = HEAP32[$76>>2]|0;
   HEAP32[$75>>2] = 4;
   $78 = ((($75)) + 4|0);
   HEAP32[$78>>2] = 0;
   $79 = ((($75)) + 8|0);
   $80 = ((($75)) + 12|0);
   HEAP32[$80>>2] = 0;
   $81 = ((($75)) + 16|0);
   HEAP32[$81>>2] = $77;
   $82 = ((($75)) + 20|0);
   HEAP32[$82>>2] = 0;
   HEAP32[$0>>2] = $75;
   HEAP32[$79>>2] = $73;
   $83 = ((($73)) + 8|0);
   $84 = HEAP32[$83>>2]|0;HEAP32[$83>>2] = (($84+1)|0);
   $$pre110 = HEAP32[$0>>2]|0;
   $85 = ((($1)) + 16|0);
   $86 = HEAP32[$85>>2]|0;
   $87 = ((($$pre110)) + 12|0);
   HEAP32[$87>>2] = $86;
   STACKTOP = sp;return;
  }
  $88 = (___dynamic_cast($5,26864,26912,0)|0);
  $89 = ($88|0)==(0|0);
  if (!($89)) {
   $90 = (__Znwj(24)|0);
   HEAP32[$90>>2] = 5;
   $91 = ((($90)) + 4|0);
   ;HEAP32[$91>>2]=0|0;HEAP32[$91+4>>2]=0|0;HEAP32[$91+8>>2]=0|0;HEAP32[$91+12>>2]=0|0;HEAP32[$91+16>>2]=0|0;
   HEAP32[$0>>2] = $90;
   $92 = ((($90)) + 8|0);
   HEAP32[$92>>2] = $88;
   $93 = ((($88)) + 8|0);
   $94 = HEAP32[$93>>2]|0;HEAP32[$93>>2] = (($94+1)|0);
   STACKTOP = sp;return;
  }
 }
 $95 = ((($1)) + 4|0);
 $96 = HEAP32[$95>>2]|0;
 $97 = ($96|0)==(0|0);
 do {
  if ($97) {
   $146 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
   if ($146) {
    $147 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
    $148 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($147,127478,109)|0);
    $149 = HEAP32[$148>>2]|0;
    $150 = ((($149)) + -12|0);
    $151 = HEAP32[$150>>2]|0;
    $152 = (($148) + ($151)|0);
    __ZNKSt3__28ios_base6getlocEv($3,$152);
    __THREW__ = 0;
    $153 = (invoke_iii(3255,($3|0),(215188|0))|0);
    $154 = __THREW__; __THREW__ = 0;
    $155 = $154&1;
    if (!($155)) {
     $156 = HEAP32[$153>>2]|0;
     $157 = ((($156)) + 28|0);
     $158 = HEAP32[$157>>2]|0;
     __THREW__ = 0;
     $159 = (invoke_iii($158|0,($153|0),10)|0);
     $160 = __THREW__; __THREW__ = 0;
     $161 = $160&1;
     if (!($161)) {
      __ZNSt3__26localeD2Ev($3);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($148,$159)|0);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($148)|0);
      break;
     }
    }
    $162 = ___cxa_find_matching_catch_2()|0;
    $163 = tempRet0;
    __THREW__ = 0;
    invoke_vi(3263,($3|0));
    $164 = __THREW__; __THREW__ = 0;
    $165 = $164&1;
    if ($165) {
     $166 = ___cxa_find_matching_catch_3(0|0)|0;
     $167 = tempRet0;
     ___clang_call_terminate($166);
     // unreachable;
    } else {
     ___resumeException($162|0);
     // unreachable;
    }
   }
  } else {
   $98 = ((($96)) + 72|0);
   $99 = HEAP32[$98>>2]|0;
   $100 = ($99|0)>(0);
   if ($100) {
    $101 = ((($96)) + 76|0);
    $102 = HEAP32[$101>>2]|0;
    $103 = ($102|0)>(0);
    if ($103) {
     $104 = ((($96)) + 88|0);
     $105 = HEAP32[$104>>2]|0;
     $106 = ($105|0)==(0);
     $107 = HEAP32[$1>>2]|0;
     $$0 = $106 ? $107 : $105;
     $108 = (__Znwj(24)|0);
     ;HEAP32[$108>>2]=0|0;HEAP32[$108+4>>2]=0|0;HEAP32[$108+8>>2]=0|0;HEAP32[$108+12>>2]=0|0;HEAP32[$108+16>>2]=0|0;HEAP32[$108+20>>2]=0|0;
     HEAP32[$0>>2] = $108;
     $109 = (__Znwj(76)|0);
     $110 = HEAP32[$98>>2]|0;
     $111 = HEAP32[$101>>2]|0;
     __THREW__ = 0;
     invoke_viiiiii(3681,($109|0),($110|0),($111|0),($$0|0),0,0);
     $112 = __THREW__; __THREW__ = 0;
     $113 = $112&1;
     if ($113) {
      $169 = ___cxa_find_matching_catch_2()|0;
      $170 = tempRet0;
      __ZdlPv($109);
      ___resumeException($169|0);
      // unreachable;
     }
     $114 = HEAP32[$0>>2]|0;
     $115 = ((($114)) + 4|0);
     $116 = HEAP32[$115>>2]|0;
     $117 = ($116|0)==($109|0);
     if ($117) {
      STACKTOP = sp;return;
     }
     HEAP32[$115>>2] = $109;
     $118 = ((($109)) + 8|0);
     $119 = HEAP32[$118>>2]|0;HEAP32[$118>>2] = (($119+1)|0);
     $120 = ($116|0)==(0|0);
     if ($120) {
      STACKTOP = sp;return;
     }
     $121 = ((($116)) + 8|0);
     $122 = HEAP32[$121>>2]|0;HEAP32[$121>>2] = (($122-1)|0);
     $123 = ($122|0)==(1);
     if (!($123)) {
      STACKTOP = sp;return;
     }
     __ZNK3osg10Referenced24signalObserversAndDeleteEbb($116,1,1);
     STACKTOP = sp;return;
    }
   }
   $124 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
   if ($124) {
    $125 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
    $126 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($125,127346,131)|0);
    $127 = HEAP32[$126>>2]|0;
    $128 = ((($127)) + -12|0);
    $129 = HEAP32[$128>>2]|0;
    $130 = (($126) + ($129)|0);
    __ZNKSt3__28ios_base6getlocEv($2,$130);
    __THREW__ = 0;
    $131 = (invoke_iii(3255,($2|0),(215188|0))|0);
    $132 = __THREW__; __THREW__ = 0;
    $133 = $132&1;
    if (!($133)) {
     $134 = HEAP32[$131>>2]|0;
     $135 = ((($134)) + 28|0);
     $136 = HEAP32[$135>>2]|0;
     __THREW__ = 0;
     $137 = (invoke_iii($136|0,($131|0),10)|0);
     $138 = __THREW__; __THREW__ = 0;
     $139 = $138&1;
     if (!($139)) {
      __ZNSt3__26localeD2Ev($2);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($126,$137)|0);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($126)|0);
      break;
     }
    }
    $140 = ___cxa_find_matching_catch_2()|0;
    $141 = tempRet0;
    __THREW__ = 0;
    invoke_vi(3263,($2|0));
    $142 = __THREW__; __THREW__ = 0;
    $143 = $142&1;
    if ($143) {
     $144 = ___cxa_find_matching_catch_3(0|0)|0;
     $145 = tempRet0;
     ___clang_call_terminate($144);
     // unreachable;
    } else {
     ___resumeException($140|0);
     // unreachable;
    }
   }
  }
 } while(0);
 $168 = (__Znwj(24)|0);
 ;HEAP32[$168>>2]=0|0;HEAP32[$168+4>>2]=0|0;HEAP32[$168+8>>2]=0|0;HEAP32[$168+12>>2]=0|0;HEAP32[$168+16>>2]=0|0;HEAP32[$168+20>>2]=0|0;
 HEAP32[$0>>2] = $168;
 STACKTOP = sp;return;
}
function __ZN3osg21FrameBufferAttachmentaSERKS0_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index4Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = ((($2)) + 8|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0|0);
  if (!($6)) {
   $7 = ((($5)) + 8|0);
   $8 = HEAP32[$7>>2]|0;HEAP32[$7>>2] = (($8-1)|0);
   $9 = ($8|0)==(1);
   if ($9) {
    __THREW__ = 0;
    invoke_viii(3262,($5|0),1,1);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     $20 = ___cxa_find_matching_catch_2()|0;
     $21 = tempRet0;
     $22 = ((($2)) + 4|0);
     $23 = HEAP32[$22>>2]|0;
     $24 = ($23|0)==(0|0);
     if ($24) {
      $eh$lpad$body$index4Z2D = $21;$eh$lpad$body$indexZ2D = $20;
      __ZdlPv($2);
      ___resumeException($eh$lpad$body$indexZ2D|0);
      // unreachable;
     }
     $25 = ((($23)) + 8|0);
     $26 = HEAP32[$25>>2]|0;HEAP32[$25>>2] = (($26-1)|0);
     $27 = ($26|0)==(1);
     if (!($27)) {
      $eh$lpad$body$index4Z2D = $21;$eh$lpad$body$indexZ2D = $20;
      __ZdlPv($2);
      ___resumeException($eh$lpad$body$indexZ2D|0);
      // unreachable;
     }
     __THREW__ = 0;
     invoke_viii(3262,($23|0),1,1);
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      $30 = ___cxa_find_matching_catch_3(0|0)|0;
      $31 = tempRet0;
      ___clang_call_terminate($30);
      // unreachable;
     } else {
      $eh$lpad$body$index4Z2D = $21;$eh$lpad$body$indexZ2D = $20;
      __ZdlPv($2);
      ___resumeException($eh$lpad$body$indexZ2D|0);
      // unreachable;
     }
    }
   }
  }
  HEAP32[$4>>2] = 0;
  $12 = ((($2)) + 4|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($13|0)==(0|0);
  if (!($14)) {
   $15 = ((($13)) + 8|0);
   $16 = HEAP32[$15>>2]|0;HEAP32[$15>>2] = (($16-1)|0);
   $17 = ($16|0)==(1);
   if ($17) {
    __THREW__ = 0;
    invoke_viii(3262,($13|0),1,1);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     $56 = ___cxa_find_matching_catch_2()|0;
     $57 = tempRet0;
     $eh$lpad$body$index4Z2D = $57;$eh$lpad$body$indexZ2D = $56;
     __ZdlPv($2);
     ___resumeException($eh$lpad$body$indexZ2D|0);
     // unreachable;
    }
   }
  }
  __ZdlPv($2);
 }
 $32 = (__Znwj(24)|0);
 $33 = HEAP32[$1>>2]|0;
 $34 = HEAP32[$33>>2]|0;
 HEAP32[$32>>2] = $34;
 $35 = ((($32)) + 4|0);
 $36 = ((($33)) + 4|0);
 $37 = HEAP32[$36>>2]|0;
 HEAP32[$35>>2] = $37;
 $38 = ($37|0)==(0|0);
 if (!($38)) {
  $39 = ((($37)) + 8|0);
  $40 = HEAP32[$39>>2]|0;HEAP32[$39>>2] = (($40+1)|0);
 }
 $41 = ((($32)) + 8|0);
 $42 = ((($33)) + 8|0);
 $43 = HEAP32[$42>>2]|0;
 HEAP32[$41>>2] = $43;
 $44 = ($43|0)==(0|0);
 if ($44) {
  $47 = ((($32)) + 12|0);
  $48 = ((($33)) + 12|0);
  $49 = HEAP32[$48>>2]|0;
  HEAP32[$47>>2] = $49;
  $50 = ((($32)) + 16|0);
  $51 = ((($33)) + 16|0);
  $52 = HEAP32[$51>>2]|0;
  HEAP32[$50>>2] = $52;
  $53 = ((($32)) + 20|0);
  $54 = ((($33)) + 20|0);
  $55 = HEAP32[$54>>2]|0;
  HEAP32[$53>>2] = $55;
  HEAP32[$0>>2] = $32;
  return ($0|0);
 }
 $45 = ((($43)) + 8|0);
 $46 = HEAP32[$45>>2]|0;HEAP32[$45>>2] = (($46+1)|0);
 $47 = ((($32)) + 12|0);
 $48 = ((($33)) + 12|0);
 $49 = HEAP32[$48>>2]|0;
 HEAP32[$47>>2] = $49;
 $50 = ((($32)) + 16|0);
 $51 = ((($33)) + 16|0);
 $52 = HEAP32[$51>>2]|0;
 HEAP32[$50>>2] = $52;
 $53 = ((($32)) + 20|0);
 $54 = ((($33)) + 20|0);
 $55 = HEAP32[$54>>2]|0;
 HEAP32[$53>>2] = $55;
 HEAP32[$0>>2] = $32;
 return ($0|0);
}
function __ZN3osg17FrameBufferObject13setAttachmentENS_6Camera15BufferComponentERKNS_21FrameBufferAttachmentE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$i$i$i$i$i = 0, $$0$i$i$i$sink$be$i = 0, $$0$i$i$i$sink14$i = 0, $$02$i$i$i$i$i$i = 0, $$off$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $scevgep$i$i$i$i = 0, $scevgep5$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp + 4|0;
 $4 = sp;
 HEAP32[$4>>2] = $1;
 $5 = ((($0)) + 56|0);
 $6 = (__ZNSt3__23mapIN3osg6Camera15BufferComponentENS1_21FrameBufferAttachmentENS_4lessIS3_EENS_9allocatorINS_4pairIKS3_S4_EEEEEixERS9_($5,$4)|0);
 (__ZN3osg21FrameBufferAttachmentaSERKS0_($6,$2)|0);
 $7 = ((($0)) + 68|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($0)) + 72|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==($8|0);
 if (!($11)) {
  $scevgep$i$i$i$i = ((($10)) + -4|0);
  $12 = $scevgep$i$i$i$i;
  $13 = $8;
  $14 = (($12) - ($13))|0;
  $15 = $14 >>> 2;
  $16 = $15 ^ -1;
  $scevgep5$i$i$i$i = (($10) + ($16<<2)|0);
  HEAP32[$9>>2] = $scevgep5$i$i$i$i;
 }
 $17 = ((($0)) + 56|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ((($0)) + 60|0);
 $20 = ($18|0)==($19|0);
 if (!($20)) {
  $21 = ((($0)) + 76|0);
  $$0$i$i$i$sink14$i = $18;
  while(1) {
   $22 = ((($$0$i$i$i$sink14$i)) + 16|0);
   $23 = HEAP32[$22>>2]|0;
   $$off$i = (($23) + -4)|0;
   $24 = ($$off$i>>>0)<(16);
   if ($24) {
    $25 = (($23) + 36060)|0;
    HEAP32[$3>>2] = $25;
    $26 = HEAP32[$9>>2]|0;
    $27 = HEAP32[$21>>2]|0;
    $28 = ($26|0)==($27|0);
    if ($28) {
     __ZNSt3__26vectorIjNS_9allocatorIjEEE21__push_back_slow_pathIKjEEvRT_($7,$3);
    } else {
     HEAP32[$26>>2] = $25;
     $29 = ((($26)) + 4|0);
     HEAP32[$9>>2] = $29;
    }
   }
   $30 = ((($$0$i$i$i$sink14$i)) + 4|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = ($31|0)==(0|0);
   if ($32) {
    $33 = ((($$0$i$i$i$sink14$i)) + 8|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = HEAP32[$34>>2]|0;
    $36 = ($35|0)==($$0$i$i$i$sink14$i|0);
    if ($36) {
     $$0$i$i$i$sink$be$i = $34;
    } else {
     $41 = $33;
     while(1) {
      $40 = HEAP32[$41>>2]|0;
      $42 = ((($40)) + 8|0);
      $43 = HEAP32[$42>>2]|0;
      $44 = HEAP32[$43>>2]|0;
      $45 = ($44|0)==($40|0);
      if ($45) {
       $$0$i$i$i$sink$be$i = $43;
       break;
      } else {
       $41 = $42;
      }
     }
    }
   } else {
    $$0$i$i$i$i$i = $31;
    while(1) {
     $38 = HEAP32[$$0$i$i$i$i$i>>2]|0;
     $39 = ($38|0)==(0|0);
     if ($39) {
      break;
     } else {
      $$0$i$i$i$i$i = $38;
     }
    }
    $$0$i$i$i$sink$be$i = $$0$i$i$i$i$i;
   }
   $37 = ($$0$i$i$i$sink$be$i|0)==($19|0);
   if ($37) {
    break;
   } else {
    $$0$i$i$i$sink14$i = $$0$i$i$i$sink$be$i;
   }
  }
 }
 $46 = ((($0)) + 80|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = ((($0)) + 84|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = $47;
 $51 = (($49) - ($50))|0;
 $52 = ($51|0)>(0);
 if (!($52)) {
  STACKTOP = sp;return;
 }
 $53 = $51 >>> 2;
 $$02$i$i$i$i$i$i = $53;$54 = $47;
 while(1) {
  HEAP32[$54>>2] = 1;
  $55 = ((($54)) + 4|0);
  $56 = (($$02$i$i$i$i$i$i) + -1)|0;
  $57 = ($$02$i$i$i$i$i$i|0)>(1);
  if ($57) {
   $$02$i$i$i$i$i$i = $56;$54 = $55;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__23mapIN3osg6Camera15BufferComponentENS1_21FrameBufferAttachmentENS_4lessIS3_EENS_9allocatorINS_4pairIKS3_S4_EEEEEixERS9_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i = 0, $$0$ph$i = 0, $$014 = 0, $$024$i = 0, $$025$i = 0, $$025$i53 = 0, $$037 = 0, $$03752 = 0, $$in$i = 0, $$pre$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 do {
  if ($4) {
   $$025$i = $2;$$037 = $2;$16 = $3;
   label = 12;
  } else {
   $5 = ((($0)) + 4|0);
   $6 = HEAP32[$1>>2]|0;
   $$0$i = $5;$$024$i = $3;$40 = $3;
   while(1) {
    $7 = ((($$024$i)) + 16|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = ($6|0)<($8|0);
    if ($9) {
     $10 = HEAP32[$$024$i>>2]|0;
     $11 = ($10|0)==(0|0);
     if ($11) {
      label = 6;
      break;
     } else {
      $$0$ph$i = $$024$i;$$in$i = $10;
     }
    } else {
     $12 = ($8|0)<($6|0);
     if (!($12)) {
      label = 10;
      break;
     }
     $13 = ((($$024$i)) + 4|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = ($14|0)==(0|0);
     if ($15) {
      label = 9;
      break;
     } else {
      $$0$ph$i = $13;$$in$i = $14;
     }
    }
    $$0$i = $$0$ph$i;$$024$i = $$in$i;$40 = $$in$i;
   }
   if ((label|0) == 6) {
    $$025$i53 = $$024$i;$$03752 = $$024$i;
    break;
   }
   else if ((label|0) == 9) {
    $$025$i53 = $13;$$03752 = $$024$i;
    break;
   }
   else if ((label|0) == 10) {
    $$025$i = $$0$i;$$037 = $$024$i;$16 = $40;
    label = 12;
    break;
   }
  }
 } while(0);
 if ((label|0) == 12) {
  $17 = ($16|0)==(0|0);
  if ($17) {
   $$025$i53 = $$025$i;$$03752 = $$037;
  } else {
   $$014 = $16;
   $39 = ((($$014)) + 20|0);
   return ($39|0);
  }
 }
 $18 = (__Znwj(24)|0);
 $19 = ((($18)) + 16|0);
 $20 = HEAP32[$1>>2]|0;
 HEAP32[$19>>2] = $20;
 __THREW__ = 0;
 $21 = (invoke_ii(3276,24)|0);
 $22 = __THREW__; __THREW__ = 0;
 $23 = $22&1;
 if ($23) {
  $24 = ___cxa_find_matching_catch_2()|0;
  $25 = tempRet0;
  __ZdlPv($18);
  ___resumeException($24|0);
  // unreachable;
 }
 $26 = ((($18)) + 20|0);
 ;HEAP32[$21>>2]=0|0;HEAP32[$21+4>>2]=0|0;HEAP32[$21+8>>2]=0|0;HEAP32[$21+12>>2]=0|0;HEAP32[$21+16>>2]=0|0;HEAP32[$21+20>>2]=0|0;
 HEAP32[$26>>2] = $21;
 HEAP32[$18>>2] = 0;
 $27 = ((($18)) + 4|0);
 HEAP32[$27>>2] = 0;
 $28 = ((($18)) + 8|0);
 HEAP32[$28>>2] = $$03752;
 HEAP32[$$025$i53>>2] = $18;
 $29 = HEAP32[$0>>2]|0;
 $30 = HEAP32[$29>>2]|0;
 $31 = ($30|0)==(0|0);
 if ($31) {
  $35 = $18;
 } else {
  $32 = $30;
  HEAP32[$0>>2] = $32;
  $$pre$i = HEAP32[$$025$i53>>2]|0;
  $35 = $$pre$i;
 }
 $33 = ((($0)) + 4|0);
 $34 = HEAP32[$33>>2]|0;
 __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($34,$35);
 $36 = ((($0)) + 8|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (($37) + 1)|0;
 HEAP32[$36>>2] = $38;
 $$014 = $18;
 $39 = ((($$014)) + 20|0);
 return ($39|0);
}
function __ZNK3osg17FrameBufferObject13isMultisampleEv($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 64|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  $$0 = 0;
  return ($$0|0);
 }
 $4 = ((($0)) + 56|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($5)) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($7)) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if ($10) {
  $$0 = 0;
  return ($$0|0);
 }
 $11 = ((($9)) + 68|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)>(0);
 $$0 = $13;
 return ($$0|0);
}
function __ZN3osg10FrameStampD2Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg10ReferencedD2Ev($0);
 return;
}
function __ZN3osg10FrameStampD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZN3osg10FrameStampC2Ev($0) {
 $0 = $0|0;
 var $1 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 __ZN3osg10ReferencedC2Eb($0,1);
 HEAP32[$0>>2] = (59248);
 $1 = ((($0)) + 12|0);
 dest=$1; stop=dest+56|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 return;
}
function __ZN3osg10FrameStampaSERKS0_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0.0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0.0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($0|0)==($1|0);
 if ($2) {
  return ($0|0);
 }
 $3 = ((($1)) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 12|0);
 HEAP32[$5>>2] = $4;
 $6 = ((($1)) + 16|0);
 $7 = +HEAPF64[$6>>3];
 $8 = ((($0)) + 16|0);
 HEAPF64[$8>>3] = $7;
 $9 = ((($1)) + 24|0);
 $10 = +HEAPF64[$9>>3];
 $11 = ((($0)) + 24|0);
 HEAPF64[$11>>3] = $10;
 $12 = ((($1)) + 32|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($0)) + 32|0);
 HEAP32[$14>>2] = $13;
 $15 = ((($1)) + 36|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ((($0)) + 36|0);
 HEAP32[$17>>2] = $16;
 $18 = ((($1)) + 40|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ((($0)) + 40|0);
 HEAP32[$20>>2] = $19;
 $21 = ((($1)) + 44|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ((($0)) + 44|0);
 HEAP32[$23>>2] = $22;
 $24 = ((($1)) + 48|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ((($0)) + 48|0);
 HEAP32[$26>>2] = $25;
 $27 = ((($1)) + 52|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = ((($0)) + 52|0);
 HEAP32[$29>>2] = $28;
 $30 = ((($1)) + 56|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ((($0)) + 56|0);
 HEAP32[$32>>2] = $31;
 $33 = ((($1)) + 60|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ((($0)) + 60|0);
 HEAP32[$35>>2] = $34;
 $36 = ((($1)) + 64|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = ((($0)) + 64|0);
 HEAP32[$38>>2] = $37;
 return ($0|0);
}
function __ZN3osg5GeodeD2Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg5GroupD2Ev($0);
 return;
}
function __ZN3osg5GeodeD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1924,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK3osg5Geode9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(160)|0);
 __THREW__ = 0;
 invoke_vi(3763,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $10 = ___cxa_find_matching_catch_2()|0;
  $11 = tempRet0;
  __ZdlPv($1);
  ___resumeException($10|0);
  // unreachable;
 } else {
  HEAP32[$1>>2] = (59268);
  $4 = ((($1)) + 136|0);
  HEAPF32[$4>>2] = 3.4028234663852886E+38;
  $5 = ((($1)) + 140|0);
  HEAPF32[$5>>2] = 3.4028234663852886E+38;
  $6 = ((($1)) + 144|0);
  HEAPF32[$6>>2] = 3.4028234663852886E+38;
  $7 = ((($1)) + 148|0);
  HEAPF32[$7>>2] = -3.4028234663852886E+38;
  $8 = ((($1)) + 152|0);
  HEAPF32[$8>>2] = -3.4028234663852886E+38;
  $9 = ((($1)) + 156|0);
  HEAPF32[$9>>2] = -3.4028234663852886E+38;
  return ($1|0);
 }
 return (0)|0;
}
function __ZNK3osg5Geode5cloneERKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(160)|0);
 __THREW__ = 0;
 invoke_viii(3764,($2|0),($0|0),($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $11 = ___cxa_find_matching_catch_2()|0;
  $12 = tempRet0;
  __ZdlPv($2);
  ___resumeException($11|0);
  // unreachable;
 } else {
  HEAP32[$2>>2] = (59268);
  $5 = ((($2)) + 136|0);
  HEAPF32[$5>>2] = 3.4028234663852886E+38;
  $6 = ((($2)) + 140|0);
  HEAPF32[$6>>2] = 3.4028234663852886E+38;
  $7 = ((($2)) + 144|0);
  HEAPF32[$7>>2] = 3.4028234663852886E+38;
  $8 = ((($2)) + 148|0);
  HEAPF32[$8>>2] = -3.4028234663852886E+38;
  $9 = ((($2)) + 152|0);
  HEAPF32[$9>>2] = -3.4028234663852886E+38;
  $10 = ((($2)) + 156|0);
  HEAPF32[$10>>2] = -3.4028234663852886E+38;
  return ($2|0);
 }
 return (0)|0;
}
function __ZNK3osg5Geode12isSameKindAsEPKNS_6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,24600,0)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK3osg5Geode11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175113|0);
}
function __ZNK3osg5Geode9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (127607|0);
}
function __ZN3osg5Geode6acceptERNS_11NodeVisitorE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$byval_copy = 0, $$pre$i$i = 0, $$sink$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i = 0, $scevgep5$i$i$i$i = 0, $scevgep5$i$i$i$sink$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy = sp + 8|0;
 $2 = sp + 4|0;
 $3 = sp;
 $4 = ((($1)) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($1)) + 24|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($0)) + 116|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $9 | $7;
 $11 = $10 & $5;
 $12 = ($11|0)==(0);
 if ($12) {
  STACKTOP = sp;return;
 }
 HEAP32[$2>>2] = $0;
 $13 = ((($1)) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(1);
 $16 = ((($1)) + 28|0);
 $17 = $0;
 do {
  if ($15) {
   $25 = HEAP32[$16>>2]|0;
   HEAP32[$3>>2] = $25;
   ;HEAP32[$$byval_copy>>2]=HEAP32[$3>>2]|0;
   (__ZNSt3__26vectorIPN3osg4NodeENS_9allocatorIS3_EEE6insertENS_11__wrap_iterIPKS3_EERS8_($16,$$byval_copy,$2)|0);
  } else {
   $18 = ((($1)) + 32|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ((($1)) + 36|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = ($19|0)==($21|0);
   if ($22) {
    __ZNSt3__26vectorIPN3osg4NodeENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_($16,$2);
    break;
   } else {
    HEAP32[$19>>2] = $17;
    $23 = HEAP32[$18>>2]|0;
    $24 = ((($23)) + 4|0);
    HEAP32[$18>>2] = $24;
    break;
   }
  }
 } while(0);
 $26 = HEAP32[$1>>2]|0;
 $27 = ((($26)) + 112|0);
 $28 = HEAP32[$27>>2]|0;
 FUNCTION_TABLE_vii[$28 & 8191]($1,$0);
 $29 = HEAP32[$13>>2]|0;
 $30 = ($29|0)==(1);
 do {
  if ($30) {
   $34 = ((($1)) + 28|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ((($35)) + 4|0);
   $37 = ((($1)) + 32|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = $36;
   $40 = (($38) - ($39))|0;
   $41 = $40 >> 2;
   $42 = ($41|0)==(0);
   $43 = $38;
   if ($42) {
    $45 = $43;
   } else {
    _memmove(($35|0),($36|0),($40|0))|0;
    $$pre$i$i = HEAP32[$37>>2]|0;
    $45 = $$pre$i$i;
   }
   $44 = (($35) + ($41<<2)|0);
   $46 = ($45|0)==($44|0);
   if ($46) {
    STACKTOP = sp;return;
   } else {
    $scevgep$i$i$i$i = ((($45)) + -4|0);
    $47 = $scevgep$i$i$i$i;
    $48 = $44;
    $49 = (($47) - ($48))|0;
    $50 = $49 >>> 2;
    $51 = $50 ^ -1;
    $scevgep5$i$i$i$i = (($45) + ($51<<2)|0);
    $$sink$i = $37;$scevgep5$i$i$i$sink$i = $scevgep5$i$i$i$i;
    break;
   }
  } else {
   $31 = ((($1)) + 32|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ((($32)) + -4|0);
   $$sink$i = $31;$scevgep5$i$i$i$sink$i = $33;
  }
 } while(0);
 HEAP32[$$sink$i>>2] = $scevgep5$i$i$i$sink$i;
 STACKTOP = sp;return;
}
function __ZNK3osg5Geode12computeBoundEv($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$pre = 0.0, $$pre$i = 0.0, $$pre$i6 = 0.0, $$pre15 = 0.0, $$pre26$i = 0.0, $$pre27$i = 0.0, $$pre28$i = 0.0, $$pre29$i = 0.0, $$pre30$i = 0.0, $$pre31$i = 0.0, $$pre32$i = 0.0, $$sroa$08$014 = 0, $10 = 0, $100 = 0.0, $101 = 0.0, $102 = 0.0, $103 = 0.0, $104 = 0.0, $105 = 0.0, $106 = 0.0;
 var $107 = 0.0, $108 = 0, $109 = 0.0, $11 = 0, $110 = 0, $111 = 0.0, $112 = 0.0, $113 = 0.0, $114 = 0.0, $115 = 0.0, $116 = 0.0, $117 = 0.0, $118 = 0.0, $119 = 0.0, $12 = 0, $120 = 0.0, $121 = 0.0, $122 = 0.0, $123 = 0.0, $124 = 0.0;
 var $125 = 0.0, $126 = 0.0, $127 = 0.0, $128 = 0.0, $129 = 0.0, $13 = 0, $130 = 0.0, $131 = 0.0, $132 = 0.0, $133 = 0.0, $134 = 0, $135 = 0, $136 = 0, $137 = 0.0, $138 = 0, $139 = 0, $14 = 0, $140 = 0.0, $141 = 0, $142 = 0.0;
 var $143 = 0.0, $144 = 0.0, $145 = 0, $146 = 0.0, $147 = 0.0, $148 = 0.0, $149 = 0, $15 = 0, $150 = 0.0, $151 = 0.0, $152 = 0.0, $153 = 0.0, $154 = 0.0, $155 = 0.0, $156 = 0.0, $157 = 0.0, $158 = 0.0, $159 = 0.0, $16 = 0, $160 = 0.0;
 var $161 = 0.0, $162 = 0.0, $163 = 0, $164 = 0.0, $165 = 0, $166 = 0.0, $167 = 0.0, $168 = 0.0, $169 = 0.0, $17 = 0, $170 = 0.0, $171 = 0.0, $172 = 0.0, $173 = 0.0, $174 = 0.0, $175 = 0.0, $176 = 0.0, $177 = 0.0, $178 = 0.0, $179 = 0.0;
 var $18 = 0, $180 = 0.0, $181 = 0.0, $182 = 0.0, $183 = 0.0, $184 = 0.0, $185 = 0.0, $186 = 0.0, $187 = 0.0, $188 = 0.0, $189 = 0, $19 = 0, $190 = 0.0, $191 = 0, $192 = 0, $193 = 0.0, $194 = 0.0, $195 = 0.0, $196 = 0, $197 = 0.0;
 var $198 = 0.0, $199 = 0.0, $2 = 0, $20 = 0, $200 = 0.0, $201 = 0, $202 = 0, $203 = 0.0, $204 = 0.0, $205 = 0.0, $206 = 0.0, $207 = 0, $208 = 0.0, $209 = 0.0, $21 = 0, $210 = 0.0, $211 = 0.0, $212 = 0, $213 = 0, $214 = 0.0;
 var $215 = 0.0, $216 = 0.0, $217 = 0.0, $218 = 0, $219 = 0.0, $22 = 0, $220 = 0.0, $221 = 0.0, $222 = 0.0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $23 = 0, $24 = 0, $25 = 0.0, $26 = 0.0, $27 = 0, $28 = 0.0, $29 = 0.0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0.0, $41 = 0.0, $42 = 0, $43 = 0, $44 = 0.0, $45 = 0, $46 = 0.0, $47 = 0;
 var $48 = 0, $49 = 0.0, $5 = 0, $50 = 0, $51 = 0.0, $52 = 0, $53 = 0.0, $54 = 0, $55 = 0.0, $56 = 0, $57 = 0.0, $58 = 0.0, $59 = 0.0, $6 = 0, $60 = 0, $61 = 0.0, $62 = 0.0, $63 = 0, $64 = 0.0, $65 = 0.0;
 var $66 = 0, $67 = 0.0, $68 = 0.0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0.0, $83 = 0;
 var $84 = 0, $85 = 0.0, $86 = 0, $87 = 0.0, $88 = 0.0, $89 = 0.0, $9 = 0, $90 = 0, $91 = 0.0, $92 = 0.0, $93 = 0.0, $94 = 0, $95 = 0.0, $96 = 0.0, $97 = 0.0, $98 = 0.0, $99 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $2 = sp + 16|0;
 $3 = sp;
 HEAPF32[$0>>2] = 0.0;
 $4 = ((($0)) + 4|0);
 HEAPF32[$4>>2] = 0.0;
 $5 = ((($0)) + 8|0);
 HEAPF32[$5>>2] = 0.0;
 $6 = ((($0)) + 12|0);
 HEAPF32[$6>>2] = -1.0;
 $7 = ((($1)) + 136|0);
 HEAPF32[$7>>2] = 3.4028234663852886E+38;
 $8 = ((($1)) + 140|0);
 HEAPF32[$8>>2] = 3.4028234663852886E+38;
 $9 = ((($1)) + 144|0);
 HEAPF32[$9>>2] = 3.4028234663852886E+38;
 $10 = ((($1)) + 148|0);
 HEAPF32[$10>>2] = -3.4028234663852886E+38;
 $11 = ((($1)) + 152|0);
 HEAPF32[$11>>2] = -3.4028234663852886E+38;
 $12 = ((($1)) + 156|0);
 HEAPF32[$12>>2] = -3.4028234663852886E+38;
 $13 = ((($1)) + 124|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ((($1)) + 128|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($14|0)==($16|0);
 if ($17) {
  STACKTOP = sp;return;
 }
 $18 = ((($3)) + 12|0);
 $19 = ((($3)) + 4|0);
 $20 = ((($3)) + 8|0);
 $21 = ((($2)) + 12|0);
 $22 = ((($2)) + 4|0);
 $23 = ((($2)) + 8|0);
 $$sroa$08$014 = $14;
 while(1) {
  $31 = HEAP32[$$sroa$08$014>>2]|0;
  $32 = ($31|0)==(0|0);
  do {
   if (!($32)) {
    $33 = HEAP32[$31>>2]|0;
    $34 = ((($33)) + 80|0);
    $35 = HEAP32[$34>>2]|0;
    $36 = (FUNCTION_TABLE_ii[$35 & 8191]($31)|0);
    $37 = ($36|0)==(0|0);
    if (!($37)) {
     $38 = (__ZNK3osg8Drawable14getBoundingBoxEv($36)|0);
     $39 = ((($38)) + 12|0);
     $40 = +HEAPF32[$39>>2];
     $41 = +HEAPF32[$38>>2];
     $42 = !($40 >= $41);
     if ($42) {
      break;
     }
     $43 = ((($38)) + 16|0);
     $44 = +HEAPF32[$43>>2];
     $45 = ((($38)) + 4|0);
     $46 = +HEAPF32[$45>>2];
     $47 = !($44 >= $46);
     if ($47) {
      break;
     }
     $48 = ((($38)) + 20|0);
     $49 = +HEAPF32[$48>>2];
     $50 = ((($38)) + 8|0);
     $51 = +HEAPF32[$50>>2];
     $52 = !($49 >= $51);
     if ($52) {
      break;
     }
     $53 = +HEAPF32[$7>>2];
     $54 = $41 < $53;
     if ($54) {
      HEAPF32[$7>>2] = $41;
      $$pre$i6 = +HEAPF32[$39>>2];
      $57 = $$pre$i6;
     } else {
      $57 = $40;
     }
     $55 = +HEAPF32[$10>>2];
     $56 = $57 > $55;
     if ($56) {
      HEAPF32[$10>>2] = $57;
     }
     $58 = +HEAPF32[$45>>2];
     $59 = +HEAPF32[$8>>2];
     $60 = $58 < $59;
     if ($60) {
      HEAPF32[$8>>2] = $58;
     }
     $61 = +HEAPF32[$43>>2];
     $62 = +HEAPF32[$11>>2];
     $63 = $61 > $62;
     if ($63) {
      HEAPF32[$11>>2] = $61;
     }
     $64 = +HEAPF32[$50>>2];
     $65 = +HEAPF32[$9>>2];
     $66 = $64 < $65;
     if ($66) {
      HEAPF32[$9>>2] = $64;
     }
     $67 = +HEAPF32[$48>>2];
     $68 = +HEAPF32[$12>>2];
     $69 = $67 > $68;
     if (!($69)) {
      break;
     }
     HEAPF32[$12>>2] = $67;
     break;
    }
    $70 = HEAP32[$$sroa$08$014>>2]|0;
    $71 = ((($70)) + 68|0);
    $72 = HEAP8[$71>>0]|0;
    $73 = ($72<<24>>24)==(0);
    if ($73) {
     $74 = ((($70)) + 32|0);
     $75 = ((($70)) + 52|0);
     ;HEAP32[$75>>2]=HEAP32[$74>>2]|0;HEAP32[$75+4>>2]=HEAP32[$74+4>>2]|0;HEAP32[$75+8>>2]=HEAP32[$74+8>>2]|0;HEAP32[$75+12>>2]=HEAP32[$74+12>>2]|0;
     $76 = ((($70)) + 48|0);
     $77 = HEAP32[$76>>2]|0;
     $78 = ($77|0)==(0|0);
     if ($78) {
      $134 = HEAP32[$70>>2]|0;
      $135 = ((($134)) + 200|0);
      $136 = HEAP32[$135>>2]|0;
      FUNCTION_TABLE_vii[$136 & 8191]($3,$70);
      $137 = +HEAPF32[$18>>2];
      $138 = !($137 >= 0.0);
      do {
       if (!($138)) {
        $139 = ((($70)) + 64|0);
        $140 = +HEAPF32[$139>>2];
        $141 = !($140 >= 0.0);
        if ($141) {
         ;HEAP32[$75>>2]=HEAP32[$3>>2]|0;HEAP32[$75+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$75+8>>2]=HEAP32[$3+8>>2]|0;
         HEAPF32[$139>>2] = $137;
         break;
        }
        $142 = +HEAPF32[$75>>2];
        $143 = +HEAPF32[$3>>2];
        $144 = $142 - $143;
        $145 = ((($70)) + 56|0);
        $146 = +HEAPF32[$145>>2];
        $147 = +HEAPF32[$19>>2];
        $148 = $146 - $147;
        $149 = ((($70)) + 60|0);
        $150 = +HEAPF32[$149>>2];
        $151 = +HEAPF32[$20>>2];
        $152 = $150 - $151;
        $153 = $144 * $144;
        $154 = $148 * $148;
        $155 = $153 + $154;
        $156 = $152 * $152;
        $157 = $155 + $156;
        $158 = (+Math_sqrt((+$157)));
        $159 = $158;
        $160 = $137;
        $161 = $160 + $159;
        $162 = $140;
        $163 = !($161 <= $162);
        if ($163) {
         $164 = $162 + $159;
         $165 = !($164 <= $160);
         if ($165) {
          $166 = $160 + $164;
          $167 = $166 * 0.5;
          $168 = $167 - $162;
          $169 = $168 / $159;
          $170 = $143 - $142;
          $171 = $170;
          $172 = $171 * $169;
          $173 = $142;
          $174 = $173 + $172;
          $175 = $174;
          HEAPF32[$75>>2] = $175;
          $176 = $147 - $146;
          $177 = $176;
          $178 = $169 * $177;
          $179 = $146;
          $180 = $179 + $178;
          $181 = $180;
          HEAPF32[$145>>2] = $181;
          $182 = $151 - $150;
          $183 = $182;
          $184 = $169 * $183;
          $185 = $150;
          $186 = $185 + $184;
          $187 = $186;
          HEAPF32[$149>>2] = $187;
          $188 = $167;
          HEAPF32[$139>>2] = $188;
          break;
         } else {
          ;HEAP32[$75>>2]=HEAP32[$3>>2]|0;HEAP32[$75+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$75+8>>2]=HEAP32[$3+8>>2]|0;
          HEAPF32[$139>>2] = $137;
          break;
         }
        }
       }
      } while(0);
     } else {
      $79 = HEAP32[$77>>2]|0;
      $80 = ((($79)) + 140|0);
      $81 = HEAP32[$80>>2]|0;
      FUNCTION_TABLE_viii[$81 & 8191]($2,$77,$70);
      $82 = +HEAPF32[$21>>2];
      $83 = !($82 >= 0.0);
      do {
       if (!($83)) {
        $84 = ((($70)) + 64|0);
        $85 = +HEAPF32[$84>>2];
        $86 = !($85 >= 0.0);
        if ($86) {
         ;HEAP32[$75>>2]=HEAP32[$2>>2]|0;HEAP32[$75+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$75+8>>2]=HEAP32[$2+8>>2]|0;
         HEAPF32[$84>>2] = $82;
         break;
        }
        $87 = +HEAPF32[$75>>2];
        $88 = +HEAPF32[$2>>2];
        $89 = $87 - $88;
        $90 = ((($70)) + 56|0);
        $91 = +HEAPF32[$90>>2];
        $92 = +HEAPF32[$22>>2];
        $93 = $91 - $92;
        $94 = ((($70)) + 60|0);
        $95 = +HEAPF32[$94>>2];
        $96 = +HEAPF32[$23>>2];
        $97 = $95 - $96;
        $98 = $89 * $89;
        $99 = $93 * $93;
        $100 = $98 + $99;
        $101 = $97 * $97;
        $102 = $100 + $101;
        $103 = (+Math_sqrt((+$102)));
        $104 = $103;
        $105 = $82;
        $106 = $105 + $104;
        $107 = $85;
        $108 = !($106 <= $107);
        if ($108) {
         $109 = $107 + $104;
         $110 = !($109 <= $105);
         if ($110) {
          $111 = $105 + $109;
          $112 = $111 * 0.5;
          $113 = $112 - $107;
          $114 = $113 / $104;
          $115 = $88 - $87;
          $116 = $115;
          $117 = $116 * $114;
          $118 = $87;
          $119 = $118 + $117;
          $120 = $119;
          HEAPF32[$75>>2] = $120;
          $121 = $92 - $91;
          $122 = $121;
          $123 = $114 * $122;
          $124 = $91;
          $125 = $124 + $123;
          $126 = $125;
          HEAPF32[$90>>2] = $126;
          $127 = $96 - $95;
          $128 = $127;
          $129 = $114 * $128;
          $130 = $95;
          $131 = $130 + $129;
          $132 = $131;
          HEAPF32[$94>>2] = $132;
          $133 = $112;
          HEAPF32[$84>>2] = $133;
          break;
         } else {
          ;HEAP32[$75>>2]=HEAP32[$2>>2]|0;HEAP32[$75+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$75+8>>2]=HEAP32[$2+8>>2]|0;
          HEAPF32[$84>>2] = $82;
          break;
         }
        }
       }
      } while(0);
     }
     HEAP8[$71>>0] = 1;
    }
    $189 = ((($70)) + 64|0);
    $190 = +HEAPF32[$189>>2];
    $191 = !($190 >= 0.0);
    if (!($191)) {
     $192 = ((($70)) + 52|0);
     $193 = +HEAPF32[$192>>2];
     $194 = $193 - $190;
     $195 = +HEAPF32[$7>>2];
     $196 = $194 < $195;
     if ($196) {
      HEAPF32[$7>>2] = $194;
      $$pre$i = +HEAPF32[$192>>2];
      $$pre26$i = +HEAPF32[$189>>2];
      $198 = $$pre$i;$199 = $$pre26$i;
     } else {
      $198 = $193;$199 = $190;
     }
     $197 = $199 + $198;
     $200 = +HEAPF32[$10>>2];
     $201 = $197 > $200;
     if ($201) {
      HEAPF32[$10>>2] = $197;
      $$pre27$i = +HEAPF32[$189>>2];
      $205 = $$pre27$i;
     } else {
      $205 = $199;
     }
     $202 = ((($70)) + 56|0);
     $203 = +HEAPF32[$202>>2];
     $204 = $203 - $205;
     $206 = +HEAPF32[$8>>2];
     $207 = $204 < $206;
     if ($207) {
      HEAPF32[$8>>2] = $204;
      $$pre28$i = +HEAPF32[$202>>2];
      $$pre29$i = +HEAPF32[$189>>2];
      $209 = $$pre28$i;$210 = $$pre29$i;
     } else {
      $209 = $203;$210 = $205;
     }
     $208 = $210 + $209;
     $211 = +HEAPF32[$11>>2];
     $212 = $208 > $211;
     if ($212) {
      HEAPF32[$11>>2] = $208;
      $$pre30$i = +HEAPF32[$189>>2];
      $216 = $$pre30$i;
     } else {
      $216 = $210;
     }
     $213 = ((($70)) + 60|0);
     $214 = +HEAPF32[$213>>2];
     $215 = $214 - $216;
     $217 = +HEAPF32[$9>>2];
     $218 = $215 < $217;
     if ($218) {
      HEAPF32[$9>>2] = $215;
      $$pre31$i = +HEAPF32[$213>>2];
      $$pre32$i = +HEAPF32[$189>>2];
      $220 = $$pre31$i;$221 = $$pre32$i;
     } else {
      $220 = $214;$221 = $216;
     }
     $219 = $221 + $220;
     $222 = +HEAPF32[$12>>2];
     $223 = $219 > $222;
     if ($223) {
      HEAPF32[$12>>2] = $219;
     }
    }
   }
  } while(0);
  $224 = ((($$sroa$08$014)) + 4|0);
  $225 = HEAP32[$15>>2]|0;
  $226 = ($224|0)==($225|0);
  if ($226) {
   break;
  } else {
   $$sroa$08$014 = $224;
  }
 }
 $$pre = +HEAPF32[$10>>2];
 $$pre15 = +HEAPF32[$7>>2];
 $24 = !($$pre >= $$pre15);
 if ($24) {
  STACKTOP = sp;return;
 }
 $25 = +HEAPF32[$11>>2];
 $26 = +HEAPF32[$8>>2];
 $27 = !($25 >= $26);
 if ($27) {
  STACKTOP = sp;return;
 }
 $28 = +HEAPF32[$12>>2];
 $29 = +HEAPF32[$9>>2];
 $30 = !($28 >= $29);
 if ($30) {
  STACKTOP = sp;return;
 }
 __ZN3osg18BoundingSphereImplINS_5Vec3fEE8expandByIS1_EEvRKNS_15BoundingBoxImplIT_EE($0,$7);
 STACKTOP = sp;return;
}
function __ZN3osg5Geode11addDrawableEPNS_8DrawableE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $3 = ((($2)) + 204|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_iii[$4 & 8191]($0,$1)|0);
 return ($5|0);
}
function __ZN3osg5Geode14removeDrawableEPNS_8DrawableE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$079$i$i = 0, $$1$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $3 = ((($2)) + 248|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 124|0);
 $6 = ((($0)) + 128|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$5>>2]|0;
 $9 = (($7) - ($8))|0;
 $10 = $9 >> 2;
 $11 = ($10|0)==(0);
 $12 = $8;
 L1: do {
  if ($11) {
   $$1$i$i = 0;
  } else {
   $$079$i$i = 0;
   while(1) {
    $13 = (($12) + ($$079$i$i<<2)|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ($14|0)==($1|0);
    if ($15) {
     $$1$i$i = $$079$i$i;
     break L1;
    }
    $16 = (($$079$i$i) + 1)|0;
    $17 = ($16>>>0)<($10>>>0);
    if ($17) {
     $$079$i$i = $16;
    } else {
     $$1$i$i = $10;
     break;
    }
   }
  }
 } while(0);
 $18 = (FUNCTION_TABLE_iiii[$4 & 8191]($0,$$1$i$i,1)|0);
 return ($18|0);
}
function __ZN3osg5Geode15removeDrawablesEjj($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = HEAP32[$0>>2]|0;
 $4 = ((($3)) + 216|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_iiii[$5 & 8191]($0,$1,$2)|0);
 return ($6|0);
}
function __ZN3osg5Geode15replaceDrawableEPNS_8DrawableES2_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = HEAP32[$0>>2]|0;
 $4 = ((($3)) + 220|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_iiii[$5 & 8191]($0,$1,$2)|0);
 return ($6|0);
}
function __ZN3osg5Geode11setDrawableEjPNS_8DrawableE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = HEAP32[$0>>2]|0;
 $4 = ((($3)) + 228|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_iiii[$5 & 8191]($0,$1,$2)|0);
 return ($6|0);
}
function __ZN3osg5GeodeC2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg5GroupC2Ev($0);
 HEAP32[$0>>2] = (59268);
 $1 = ((($0)) + 136|0);
 HEAPF32[$1>>2] = 3.4028234663852886E+38;
 $2 = ((($0)) + 140|0);
 HEAPF32[$2>>2] = 3.4028234663852886E+38;
 $3 = ((($0)) + 144|0);
 HEAPF32[$3>>2] = 3.4028234663852886E+38;
 $4 = ((($0)) + 148|0);
 HEAPF32[$4>>2] = -3.4028234663852886E+38;
 $5 = ((($0)) + 152|0);
 HEAPF32[$5>>2] = -3.4028234663852886E+38;
 $6 = ((($0)) + 156|0);
 HEAPF32[$6>>2] = -3.4028234663852886E+38;
 return;
}
function __ZN3osg8GeometryD2Ev($0) {
 $0 = $0|0;
 var $$2 = 0, $$24 = 0, $$3 = 0, $$35 = 0, $$4 = 0, $$46 = 0, $$5 = 0, $$57 = 0, $$6 = 0, $$68 = 0, $$pre$i = 0, $$pre$i13 = 0, $$pre$i27 = 0, $$pre$i31 = 0, $$pre$i38 = 0, $$pre$i55 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0;
 var $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0;
 var $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0;
 var $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0;
 var $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0;
 var $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0;
 var $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0;
 var $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (59536);
 __THREW__ = 0;
 invoke_vi(1652,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if ($2) {
   $103 = ___cxa_find_matching_catch_2()|0;
   $104 = tempRet0;
   $105 = ((($0)) + 260|0);
   $106 = HEAP32[$105>>2]|0;
   $107 = ($106|0)==(0|0);
   if (!($107)) {
    $108 = ((($0)) + 264|0);
    $109 = HEAP32[$108>>2]|0;
    $110 = ($109|0)==($106|0);
    do {
     if ($110) {
      $124 = $106;
     } else {
      $112 = $109;
      while(1) {
       $111 = ((($112)) + -4|0);
       HEAP32[$108>>2] = $111;
       $113 = HEAP32[$111>>2]|0;
       $114 = ($113|0)==(0|0);
       if (!($114)) {
        $115 = ((($113)) + 8|0);
        $116 = HEAP32[$115>>2]|0;HEAP32[$115>>2] = (($116-1)|0);
        $117 = ($116|0)==(1);
        if ($117) {
         __THREW__ = 0;
         invoke_viii(3262,($113|0),1,1);
         $118 = __THREW__; __THREW__ = 0;
         $119 = $118&1;
         if ($119) {
          label = 51;
          break;
         }
        }
       }
       HEAP32[$111>>2] = 0;
       $120 = HEAP32[$108>>2]|0;
       $121 = ($120|0)==($106|0);
       if ($121) {
        label = 52;
        break;
       } else {
        $112 = $120;
       }
      }
      if ((label|0) == 51) {
       $122 = ___cxa_find_matching_catch_2()|0;
       $123 = tempRet0;
       ___cxa_call_unexpected(($122|0));
       // unreachable;
      }
      else if ((label|0) == 52) {
       $$pre$i31 = HEAP32[$105>>2]|0;
       $124 = $$pre$i31;
       break;
      }
     }
    } while(0);
    __ZdlPv($124);
   }
   $125 = ((($0)) + 248|0);
   $126 = HEAP32[$125>>2]|0;
   $127 = ($126|0)==(0|0);
   if (!($127)) {
    $128 = ((($0)) + 252|0);
    $129 = HEAP32[$128>>2]|0;
    $130 = ($129|0)==($126|0);
    do {
     if ($130) {
      $144 = $126;
     } else {
      $132 = $129;
      while(1) {
       $131 = ((($132)) + -4|0);
       HEAP32[$128>>2] = $131;
       $133 = HEAP32[$131>>2]|0;
       $134 = ($133|0)==(0|0);
       if (!($134)) {
        $135 = ((($133)) + 8|0);
        $136 = HEAP32[$135>>2]|0;HEAP32[$135>>2] = (($136-1)|0);
        $137 = ($136|0)==(1);
        if ($137) {
         __THREW__ = 0;
         invoke_viii(3262,($133|0),1,1);
         $138 = __THREW__; __THREW__ = 0;
         $139 = $138&1;
         if ($139) {
          label = 60;
          break;
         }
        }
       }
       HEAP32[$131>>2] = 0;
       $140 = HEAP32[$128>>2]|0;
       $141 = ($140|0)==($126|0);
       if ($141) {
        label = 61;
        break;
       } else {
        $132 = $140;
       }
      }
      if ((label|0) == 60) {
       $142 = ___cxa_find_matching_catch_2()|0;
       $143 = tempRet0;
       ___cxa_call_unexpected(($142|0));
       // unreachable;
      }
      else if ((label|0) == 61) {
       $$pre$i38 = HEAP32[$125>>2]|0;
       $144 = $$pre$i38;
       break;
      }
     }
    } while(0);
    __ZdlPv($144);
   }
   $147 = ((($0)) + 244|0);
   $148 = HEAP32[$147>>2]|0;
   $149 = ($148|0)==(0|0);
   if (!($149)) {
    $150 = ((($148)) + 8|0);
    $151 = HEAP32[$150>>2]|0;HEAP32[$150>>2] = (($151-1)|0);
    $152 = ($151|0)==(1);
    if ($152) {
     __THREW__ = 0;
     invoke_viii(3262,($148|0),1,1);
     $153 = __THREW__; __THREW__ = 0;
     $154 = $153&1;
     if ($154) {
      $217 = ___cxa_find_matching_catch_3(0|0)|0;
      $218 = tempRet0;
      ___clang_call_terminate($217);
      // unreachable;
     }
    }
   }
   HEAP32[$147>>2] = 0;
   $$2 = $104;$$24 = $103;
   label = 69;
  } else {
   $3 = ((($0)) + 260|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = ($4|0)==(0|0);
   if (!($5)) {
    $6 = ((($0)) + 264|0);
    $7 = HEAP32[$6>>2]|0;
    $8 = ($7|0)==($4|0);
    do {
     if ($8) {
      $22 = $4;
     } else {
      $10 = $7;
      while(1) {
       $9 = ((($10)) + -4|0);
       HEAP32[$6>>2] = $9;
       $11 = HEAP32[$9>>2]|0;
       $12 = ($11|0)==(0|0);
       if (!($12)) {
        $13 = ((($11)) + 8|0);
        $14 = HEAP32[$13>>2]|0;HEAP32[$13>>2] = (($14-1)|0);
        $15 = ($14|0)==(1);
        if ($15) {
         __THREW__ = 0;
         invoke_viii(3262,($11|0),1,1);
         $16 = __THREW__; __THREW__ = 0;
         $17 = $16&1;
         if ($17) {
          label = 8;
          break;
         }
        }
       }
       HEAP32[$9>>2] = 0;
       $18 = HEAP32[$6>>2]|0;
       $19 = ($18|0)==($4|0);
       if ($19) {
        label = 9;
        break;
       } else {
        $10 = $18;
       }
      }
      if ((label|0) == 8) {
       $20 = ___cxa_find_matching_catch_2()|0;
       $21 = tempRet0;
       ___cxa_call_unexpected(($20|0));
       // unreachable;
      }
      else if ((label|0) == 9) {
       $$pre$i = HEAP32[$3>>2]|0;
       $22 = $$pre$i;
       break;
      }
     }
    } while(0);
    __ZdlPv($22);
   }
   $23 = ((($0)) + 248|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = ($24|0)==(0|0);
   if (!($25)) {
    $26 = ((($0)) + 252|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = ($27|0)==($24|0);
    do {
     if ($28) {
      $42 = $24;
     } else {
      $30 = $27;
      while(1) {
       $29 = ((($30)) + -4|0);
       HEAP32[$26>>2] = $29;
       $31 = HEAP32[$29>>2]|0;
       $32 = ($31|0)==(0|0);
       if (!($32)) {
        $33 = ((($31)) + 8|0);
        $34 = HEAP32[$33>>2]|0;HEAP32[$33>>2] = (($34-1)|0);
        $35 = ($34|0)==(1);
        if ($35) {
         __THREW__ = 0;
         invoke_viii(3262,($31|0),1,1);
         $36 = __THREW__; __THREW__ = 0;
         $37 = $36&1;
         if ($37) {
          label = 17;
          break;
         }
        }
       }
       HEAP32[$29>>2] = 0;
       $38 = HEAP32[$26>>2]|0;
       $39 = ($38|0)==($24|0);
       if ($39) {
        label = 18;
        break;
       } else {
        $30 = $38;
       }
      }
      if ((label|0) == 17) {
       $40 = ___cxa_find_matching_catch_2()|0;
       $41 = tempRet0;
       ___cxa_call_unexpected(($40|0));
       // unreachable;
      }
      else if ((label|0) == 18) {
       $$pre$i13 = HEAP32[$23>>2]|0;
       $42 = $$pre$i13;
       break;
      }
     }
    } while(0);
    __ZdlPv($42);
   }
   $43 = ((($0)) + 244|0);
   $44 = HEAP32[$43>>2]|0;
   $45 = ($44|0)==(0|0);
   if (!($45)) {
    $46 = ((($44)) + 8|0);
    $47 = HEAP32[$46>>2]|0;HEAP32[$46>>2] = (($47-1)|0);
    $48 = ($47|0)==(1);
    if ($48) {
     __THREW__ = 0;
     invoke_viii(3262,($44|0),1,1);
     $49 = __THREW__; __THREW__ = 0;
     $50 = $49&1;
     if ($50) {
      $145 = ___cxa_find_matching_catch_2()|0;
      $146 = tempRet0;
      $$2 = $146;$$24 = $145;
      label = 69;
      break;
     }
    }
   }
   HEAP32[$43>>2] = 0;
   $51 = ((($0)) + 240|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = ($52|0)==(0|0);
   if (!($53)) {
    $54 = ((($52)) + 8|0);
    $55 = HEAP32[$54>>2]|0;HEAP32[$54>>2] = (($55-1)|0);
    $56 = ($55|0)==(1);
    if ($56) {
     __THREW__ = 0;
     invoke_viii(3262,($52|0),1,1);
     $57 = __THREW__; __THREW__ = 0;
     $58 = $57&1;
     if ($58) {
      $155 = ___cxa_find_matching_catch_2()|0;
      $156 = tempRet0;
      $$3 = $156;$$35 = $155;
      label = 74;
      break;
     }
    }
   }
   HEAP32[$51>>2] = 0;
   $59 = ((($0)) + 236|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = ($60|0)==(0|0);
   if (!($61)) {
    $62 = ((($60)) + 8|0);
    $63 = HEAP32[$62>>2]|0;HEAP32[$62>>2] = (($63-1)|0);
    $64 = ($63|0)==(1);
    if ($64) {
     __THREW__ = 0;
     invoke_viii(3262,($60|0),1,1);
     $65 = __THREW__; __THREW__ = 0;
     $66 = $65&1;
     if ($66) {
      $165 = ___cxa_find_matching_catch_2()|0;
      $166 = tempRet0;
      $$4 = $166;$$46 = $165;
      label = 79;
      break;
     }
    }
   }
   HEAP32[$59>>2] = 0;
   $67 = ((($0)) + 232|0);
   $68 = HEAP32[$67>>2]|0;
   $69 = ($68|0)==(0|0);
   if (!($69)) {
    $70 = ((($68)) + 8|0);
    $71 = HEAP32[$70>>2]|0;HEAP32[$70>>2] = (($71-1)|0);
    $72 = ($71|0)==(1);
    if ($72) {
     __THREW__ = 0;
     invoke_viii(3262,($68|0),1,1);
     $73 = __THREW__; __THREW__ = 0;
     $74 = $73&1;
     if ($74) {
      $175 = ___cxa_find_matching_catch_2()|0;
      $176 = tempRet0;
      $$5 = $176;$$57 = $175;
      label = 84;
      break;
     }
    }
   }
   HEAP32[$67>>2] = 0;
   $75 = ((($0)) + 228|0);
   $76 = HEAP32[$75>>2]|0;
   $77 = ($76|0)==(0|0);
   if (!($77)) {
    $78 = ((($76)) + 8|0);
    $79 = HEAP32[$78>>2]|0;HEAP32[$78>>2] = (($79-1)|0);
    $80 = ($79|0)==(1);
    if ($80) {
     __THREW__ = 0;
     invoke_viii(3262,($76|0),1,1);
     $81 = __THREW__; __THREW__ = 0;
     $82 = $81&1;
     if ($82) {
      $185 = ___cxa_find_matching_catch_2()|0;
      $186 = tempRet0;
      $$6 = $186;$$68 = $185;
      break;
     }
    }
   }
   HEAP32[$75>>2] = 0;
   $83 = ((($0)) + 216|0);
   $84 = HEAP32[$83>>2]|0;
   $85 = ($84|0)==(0|0);
   if ($85) {
    __ZN3osg8DrawableD2Ev($0);
    return;
   }
   $86 = ((($0)) + 220|0);
   $87 = HEAP32[$86>>2]|0;
   $88 = ($87|0)==($84|0);
   do {
    if ($88) {
     $102 = $84;
    } else {
     $90 = $87;
     while(1) {
      $89 = ((($90)) + -4|0);
      HEAP32[$86>>2] = $89;
      $91 = HEAP32[$89>>2]|0;
      $92 = ($91|0)==(0|0);
      if (!($92)) {
       $93 = ((($91)) + 8|0);
       $94 = HEAP32[$93>>2]|0;HEAP32[$93>>2] = (($94-1)|0);
       $95 = ($94|0)==(1);
       if ($95) {
        __THREW__ = 0;
        invoke_viii(3262,($91|0),1,1);
        $96 = __THREW__; __THREW__ = 0;
        $97 = $96&1;
        if ($97) {
         label = 41;
         break;
        }
       }
      }
      HEAP32[$89>>2] = 0;
      $98 = HEAP32[$86>>2]|0;
      $99 = ($98|0)==($84|0);
      if ($99) {
       label = 42;
       break;
      } else {
       $90 = $98;
      }
     }
     if ((label|0) == 41) {
      $100 = ___cxa_find_matching_catch_2()|0;
      $101 = tempRet0;
      ___cxa_call_unexpected(($100|0));
      // unreachable;
     }
     else if ((label|0) == 42) {
      $$pre$i27 = HEAP32[$83>>2]|0;
      $102 = $$pre$i27;
      break;
     }
    }
   } while(0);
   __ZdlPv($102);
   __ZN3osg8DrawableD2Ev($0);
   return;
  }
 } while(0);
 if ((label|0) == 69) {
  $157 = ((($0)) + 240|0);
  $158 = HEAP32[$157>>2]|0;
  $159 = ($158|0)==(0|0);
  if (!($159)) {
   $160 = ((($158)) + 8|0);
   $161 = HEAP32[$160>>2]|0;HEAP32[$160>>2] = (($161-1)|0);
   $162 = ($161|0)==(1);
   if ($162) {
    __THREW__ = 0;
    invoke_viii(3262,($158|0),1,1);
    $163 = __THREW__; __THREW__ = 0;
    $164 = $163&1;
    if ($164) {
     $217 = ___cxa_find_matching_catch_3(0|0)|0;
     $218 = tempRet0;
     ___clang_call_terminate($217);
     // unreachable;
    }
   }
  }
  HEAP32[$157>>2] = 0;
  $$3 = $$2;$$35 = $$24;
  label = 74;
 }
 if ((label|0) == 74) {
  $167 = ((($0)) + 236|0);
  $168 = HEAP32[$167>>2]|0;
  $169 = ($168|0)==(0|0);
  if (!($169)) {
   $170 = ((($168)) + 8|0);
   $171 = HEAP32[$170>>2]|0;HEAP32[$170>>2] = (($171-1)|0);
   $172 = ($171|0)==(1);
   if ($172) {
    __THREW__ = 0;
    invoke_viii(3262,($168|0),1,1);
    $173 = __THREW__; __THREW__ = 0;
    $174 = $173&1;
    if ($174) {
     $217 = ___cxa_find_matching_catch_3(0|0)|0;
     $218 = tempRet0;
     ___clang_call_terminate($217);
     // unreachable;
    }
   }
  }
  HEAP32[$167>>2] = 0;
  $$4 = $$3;$$46 = $$35;
  label = 79;
 }
 if ((label|0) == 79) {
  $177 = ((($0)) + 232|0);
  $178 = HEAP32[$177>>2]|0;
  $179 = ($178|0)==(0|0);
  if (!($179)) {
   $180 = ((($178)) + 8|0);
   $181 = HEAP32[$180>>2]|0;HEAP32[$180>>2] = (($181-1)|0);
   $182 = ($181|0)==(1);
   if ($182) {
    __THREW__ = 0;
    invoke_viii(3262,($178|0),1,1);
    $183 = __THREW__; __THREW__ = 0;
    $184 = $183&1;
    if ($184) {
     $217 = ___cxa_find_matching_catch_3(0|0)|0;
     $218 = tempRet0;
     ___clang_call_terminate($217);
     // unreachable;
    }
   }
  }
  HEAP32[$177>>2] = 0;
  $$5 = $$4;$$57 = $$46;
  label = 84;
 }
 if ((label|0) == 84) {
  $187 = ((($0)) + 228|0);
  $188 = HEAP32[$187>>2]|0;
  $189 = ($188|0)==(0|0);
  if (!($189)) {
   $190 = ((($188)) + 8|0);
   $191 = HEAP32[$190>>2]|0;HEAP32[$190>>2] = (($191-1)|0);
   $192 = ($191|0)==(1);
   if ($192) {
    __THREW__ = 0;
    invoke_viii(3262,($188|0),1,1);
    $193 = __THREW__; __THREW__ = 0;
    $194 = $193&1;
    if ($194) {
     $217 = ___cxa_find_matching_catch_3(0|0)|0;
     $218 = tempRet0;
     ___clang_call_terminate($217);
     // unreachable;
    }
   }
  }
  HEAP32[$187>>2] = 0;
  $$6 = $$5;$$68 = $$57;
 }
 $195 = ((($0)) + 216|0);
 $196 = HEAP32[$195>>2]|0;
 $197 = ($196|0)==(0|0);
 if (!($197)) {
  $198 = ((($0)) + 220|0);
  $199 = HEAP32[$198>>2]|0;
  $200 = ($199|0)==($196|0);
  do {
   if ($200) {
    $214 = $196;
   } else {
    $202 = $199;
    while(1) {
     $201 = ((($202)) + -4|0);
     HEAP32[$198>>2] = $201;
     $203 = HEAP32[$201>>2]|0;
     $204 = ($203|0)==(0|0);
     if (!($204)) {
      $205 = ((($203)) + 8|0);
      $206 = HEAP32[$205>>2]|0;HEAP32[$205>>2] = (($206-1)|0);
      $207 = ($206|0)==(1);
      if ($207) {
       __THREW__ = 0;
       invoke_viii(3262,($203|0),1,1);
       $208 = __THREW__; __THREW__ = 0;
       $209 = $208&1;
       if ($209) {
        label = 94;
        break;
       }
      }
     }
     HEAP32[$201>>2] = 0;
     $210 = HEAP32[$198>>2]|0;
     $211 = ($210|0)==($196|0);
     if ($211) {
      label = 95;
      break;
     } else {
      $202 = $210;
     }
    }
    if ((label|0) == 94) {
     $212 = ___cxa_find_matching_catch_2()|0;
     $213 = tempRet0;
     ___cxa_call_unexpected(($212|0));
     // unreachable;
    }
    else if ((label|0) == 95) {
     $$pre$i55 = HEAP32[$195>>2]|0;
     $214 = $$pre$i55;
     break;
    }
   }
  } while(0);
  __ZdlPv($214);
 }
 __THREW__ = 0;
 invoke_vi(1630,($0|0));
 $215 = __THREW__; __THREW__ = 0;
 $216 = $215&1;
 if ($216) {
  $217 = ___cxa_find_matching_catch_3(0|0)|0;
  $218 = tempRet0;
  ___clang_call_terminate($217);
  // unreachable;
 } else {
  ___resumeException($$68|0);
  // unreachable;
 }
}
function __ZN3osg8GeometryD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1754,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK3osg8Geometry9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $1 = (__Znwj(276)|0);
 __THREW__ = 0;
 invoke_vi(3750,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $7 = ___cxa_find_matching_catch_2()|0;
  $8 = tempRet0;
  __ZdlPv($1);
  ___resumeException($7|0);
  // unreachable;
 } else {
  HEAP32[$1>>2] = (59536);
  $4 = ((($1)) + 216|0);
  $5 = ((($1)) + 182|0);
  dest=$4; stop=dest+56|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));HEAP8[$4+56>>0]=0|0;
  HEAP8[$5>>0] = 1;
  $6 = ((($1)) + 183|0);
  HEAP8[$6>>0] = 0;
  return ($1|0);
 }
 return (0)|0;
}
function __ZNK3osg8Geometry5cloneERKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(276)|0);
 __THREW__ = 0;
 invoke_viii(3765,($2|0),($0|0),($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch_2()|0;
  $6 = tempRet0;
  __ZdlPv($2);
  ___resumeException($5|0);
  // unreachable;
 } else {
  return ($2|0);
 }
 return (0)|0;
}
function __ZNK3osg8Geometry12isSameKindAsEPKNS_6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,24616,0)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK3osg8Geometry11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175113|0);
}
function __ZNK3osg8Geometry9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (128637|0);
}
function __ZN3osg8Geometry21resizeGLObjectBuffersEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$2 = 0, $$27 = 0, $$pre = 0, $$pre$i = 0, $$pre$i11 = 0, $$pre$i15 = 0, $$pre11$i = 0, $$sroa$023$037 = 0, $$sroa$030$038 = 0, $$sroa$06$010$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i17 = 0, $scevgep5$i$i$i = 0, $scevgep5$i$i$i18 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $2 = sp + 24|0;
 $3 = sp + 12|0;
 $4 = sp;
 __ZN3osg8Drawable21resizeGLObjectBuffersEj($0,$1);
 HEAP32[$3>>2] = 0;
 $5 = ((($3)) + 4|0);
 HEAP32[$5>>2] = 0;
 $6 = ((($3)) + 8|0);
 HEAP32[$6>>2] = 0;
 __THREW__ = 0;
 $7 = (invoke_iii(3766,($0|0),($3|0))|0);
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 L1: do {
  if ($9) {
   $13 = ___cxa_find_matching_catch_2()|0;
   $14 = tempRet0;
   $$2 = $14;$$27 = $13;
  } else {
   L4: do {
    if ($7) {
     $10 = HEAP32[$3>>2]|0;
     $11 = HEAP32[$5>>2]|0;
     $12 = ($10|0)==($11|0);
     if (!($12)) {
      $$sroa$030$038 = $10;
      while(1) {
       $15 = HEAP32[$$sroa$030$038>>2]|0;
       $16 = HEAP32[$15>>2]|0;
       $17 = ((($16)) + 132|0);
       $18 = HEAP32[$17>>2]|0;
       __THREW__ = 0;
       invoke_vii($18|0,($15|0),($1|0));
       $19 = __THREW__; __THREW__ = 0;
       $20 = $19&1;
       if ($20) {
        break;
       }
       $21 = ((($$sroa$030$038)) + 4|0);
       $22 = HEAP32[$5>>2]|0;
       $23 = ($21|0)==($22|0);
       if ($23) {
        break L4;
       } else {
        $$sroa$030$038 = $21;
       }
      }
      $24 = ___cxa_find_matching_catch_2()|0;
      $25 = tempRet0;
      $$2 = $25;$$27 = $24;
      break L1;
     }
    }
   } while(0);
   HEAP32[$4>>2] = 0;
   $26 = ((($4)) + 4|0);
   HEAP32[$26>>2] = 0;
   $27 = ((($4)) + 8|0);
   HEAP32[$27>>2] = 0;
   $28 = ((($0)) + 216|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = ((($0)) + 220|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = ($29|0)==($31|0);
   L11: do {
    if (!($32)) {
     $33 = ((($4)) + 8|0);
     $$sroa$06$010$i = $29;
     L13: while(1) {
      $34 = HEAP32[$$sroa$06$010$i>>2]|0;
      $35 = HEAP32[$34>>2]|0;
      $36 = ((($35)) + 176|0);
      $37 = HEAP32[$36>>2]|0;
      __THREW__ = 0;
      $38 = (invoke_ii($37|0,($34|0))|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if ($40) {
       break;
      }
      HEAP32[$2>>2] = $38;
      $41 = ($38|0)==(0|0);
      $42 = $38;
      do {
       if (!($41)) {
        $43 = HEAP32[$26>>2]|0;
        $44 = HEAP32[$33>>2]|0;
        $45 = ($43|0)==($44|0);
        if ($45) {
         __THREW__ = 0;
         invoke_vii(3767,($4|0),($2|0));
         $48 = __THREW__; __THREW__ = 0;
         $49 = $48&1;
         if ($49) {
          break L13;
         } else {
          break;
         }
        } else {
         HEAP32[$43>>2] = $42;
         $46 = HEAP32[$26>>2]|0;
         $47 = ((($46)) + 4|0);
         HEAP32[$26>>2] = $47;
         break;
        }
       }
      } while(0);
      $50 = ((($$sroa$06$010$i)) + 4|0);
      $51 = HEAP32[$30>>2]|0;
      $52 = ($50|0)==($51|0);
      if ($52) {
       label = 16;
       break;
      } else {
       $$sroa$06$010$i = $50;
      }
     }
     L22: do {
      if ((label|0) == 16) {
       $$pre$i15 = HEAP32[$26>>2]|0;
       $$pre11$i = HEAP32[$4>>2]|0;
       $53 = $$pre11$i;
       $54 = $$pre$i15;
       $55 = ($$pre$i15|0)==($$pre11$i|0);
       $56 = ($53|0)==($54|0);
       $or$cond = $55 | $56;
       if ($or$cond) {
        $66 = $53;$68 = $54;
       } else {
        $$sroa$023$037 = $53;
        while(1) {
         $57 = HEAP32[$$sroa$023$037>>2]|0;
         $58 = HEAP32[$57>>2]|0;
         $59 = ((($58)) + 132|0);
         $60 = HEAP32[$59>>2]|0;
         __THREW__ = 0;
         invoke_vii($60|0,($57|0),($1|0));
         $61 = __THREW__; __THREW__ = 0;
         $62 = $61&1;
         if ($62) {
          break L22;
         }
         $63 = ((($$sroa$023$037)) + 4|0);
         $64 = HEAP32[$26>>2]|0;
         $65 = ($63|0)==($64|0);
         if ($65) {
          break;
         } else {
          $$sroa$023$037 = $63;
         }
        }
        $$pre = HEAP32[$4>>2]|0;
        $66 = $$pre;$68 = $63;
       }
       $67 = ($66|0)==(0|0);
       if ($67) {
        break L11;
       }
       $69 = ($68|0)==($66|0);
       if (!($69)) {
        $scevgep$i$i$i17 = ((($68)) + -4|0);
        $70 = $scevgep$i$i$i17;
        $71 = $66;
        $72 = (($70) - ($71))|0;
        $73 = $72 >>> 2;
        $74 = $73 ^ -1;
        $scevgep5$i$i$i18 = (($68) + ($74<<2)|0);
        HEAP32[$26>>2] = $scevgep5$i$i$i18;
       }
       __ZdlPv($66);
       break L11;
      }
     } while(0);
     $93 = ___cxa_find_matching_catch_2()|0;
     $94 = tempRet0;
     $95 = HEAP32[$4>>2]|0;
     $96 = ($95|0)==(0|0);
     if (!($96)) {
      $97 = HEAP32[$26>>2]|0;
      $98 = ($97|0)==($95|0);
      if (!($98)) {
       $scevgep$i$i$i = ((($97)) + -4|0);
       $99 = $scevgep$i$i$i;
       $100 = $95;
       $101 = (($99) - ($100))|0;
       $102 = $101 >>> 2;
       $103 = $102 ^ -1;
       $scevgep5$i$i$i = (($97) + ($103<<2)|0);
       HEAP32[$26>>2] = $scevgep5$i$i$i;
      }
      __ZdlPv($95);
     }
     $$2 = $94;$$27 = $93;
     break L1;
    }
   } while(0);
   $75 = HEAP32[$3>>2]|0;
   $76 = ($75|0)==(0|0);
   if ($76) {
    STACKTOP = sp;return;
   }
   $77 = HEAP32[$5>>2]|0;
   $78 = ($77|0)==($75|0);
   do {
    if ($78) {
     $92 = $75;
    } else {
     $80 = $77;
     while(1) {
      $79 = ((($80)) + -4|0);
      HEAP32[$5>>2] = $79;
      $81 = HEAP32[$79>>2]|0;
      $82 = ($81|0)==(0|0);
      if (!($82)) {
       $83 = ((($81)) + 8|0);
       $84 = HEAP32[$83>>2]|0;HEAP32[$83>>2] = (($84-1)|0);
       $85 = ($84|0)==(1);
       if ($85) {
        __THREW__ = 0;
        invoke_viii(3262,($81|0),1,1);
        $86 = __THREW__; __THREW__ = 0;
        $87 = $86&1;
        if ($87) {
         label = 30;
         break;
        }
       }
      }
      HEAP32[$79>>2] = 0;
      $88 = HEAP32[$5>>2]|0;
      $89 = ($88|0)==($75|0);
      if ($89) {
       label = 31;
       break;
      } else {
       $80 = $88;
      }
     }
     if ((label|0) == 30) {
      $90 = ___cxa_find_matching_catch_2()|0;
      $91 = tempRet0;
      ___cxa_call_unexpected(($90|0));
      // unreachable;
     }
     else if ((label|0) == 31) {
      $$pre$i11 = HEAP32[$3>>2]|0;
      $92 = $$pre$i11;
      break;
     }
    }
   } while(0);
   __ZdlPv($92);
   STACKTOP = sp;return;
  }
 } while(0);
 $104 = HEAP32[$3>>2]|0;
 $105 = ($104|0)==(0|0);
 if ($105) {
  ___resumeException($$27|0);
  // unreachable;
 }
 $106 = HEAP32[$5>>2]|0;
 $107 = ($106|0)==($104|0);
 do {
  if ($107) {
   $121 = $104;
  } else {
   $109 = $106;
   while(1) {
    $108 = ((($109)) + -4|0);
    HEAP32[$5>>2] = $108;
    $110 = HEAP32[$108>>2]|0;
    $111 = ($110|0)==(0|0);
    if (!($111)) {
     $112 = ((($110)) + 8|0);
     $113 = HEAP32[$112>>2]|0;HEAP32[$112>>2] = (($113-1)|0);
     $114 = ($113|0)==(1);
     if ($114) {
      __THREW__ = 0;
      invoke_viii(3262,($110|0),1,1);
      $115 = __THREW__; __THREW__ = 0;
      $116 = $115&1;
      if ($116) {
       label = 45;
       break;
      }
     }
    }
    HEAP32[$108>>2] = 0;
    $117 = HEAP32[$5>>2]|0;
    $118 = ($117|0)==($104|0);
    if ($118) {
     label = 46;
     break;
    } else {
     $109 = $117;
    }
   }
   if ((label|0) == 45) {
    $119 = ___cxa_find_matching_catch_2()|0;
    $120 = tempRet0;
    ___cxa_call_unexpected(($119|0));
    // unreachable;
   }
   else if ((label|0) == 46) {
    $$pre$i = HEAP32[$3>>2]|0;
    $121 = $$pre$i;
    break;
   }
  }
 } while(0);
 __ZdlPv($121);
 ___resumeException($$27|0);
 // unreachable;
}
function __ZNK3osg8Geometry16releaseGLObjectsEPNS_5StateE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$2 = 0, $$211 = 0, $$pre = 0, $$pre$i = 0, $$pre$i23 = 0, $$pre$i27 = 0, $$pre11$i = 0, $$sroa$035$049 = 0, $$sroa$042$050 = 0, $$sroa$06$010$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0;
 var $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0;
 var $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0;
 var $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0;
 var $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0;
 var $235 = 0, $236 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i29 = 0, $scevgep5$i$i$i = 0, $scevgep5$i$i$i30 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $2 = sp + 24|0;
 $3 = sp + 12|0;
 $4 = sp;
 __ZNK3osg8Drawable16releaseGLObjectsEPNS_5StateE($0,$1);
 $5 = ($1|0)==(0|0);
 $6 = ((($0)) + 200|0);
 L1: do {
  if ($5) {
   $103 = HEAP32[$6>>2]|0;
   $104 = ((($0)) + 204|0);
   $105 = HEAP32[$104>>2]|0;
   $106 = ($105|0)==($103|0);
   if (!($106)) {
    $108 = $105;
    while(1) {
     $107 = ((($108)) + -4|0);
     HEAP32[$104>>2] = $107;
     $109 = HEAP32[$107>>2]|0;
     $110 = ($109|0)==(0|0);
     if (!($110)) {
      $111 = ((($109)) + 8|0);
      $112 = HEAP32[$111>>2]|0;HEAP32[$111>>2] = (($112-1)|0);
      $113 = ($112|0)==(1);
      if ($113) {
       __THREW__ = 0;
       invoke_viii(3262,($109|0),1,1);
       $114 = __THREW__; __THREW__ = 0;
       $115 = $114&1;
       if ($115) {
        break;
       }
      }
     }
     HEAP32[$107>>2] = 0;
     $116 = HEAP32[$104>>2]|0;
     $117 = ($116|0)==($103|0);
     if ($117) {
      break L1;
     } else {
      $108 = $116;
     }
    }
    $118 = ___cxa_find_matching_catch_2()|0;
    $119 = tempRet0;
    ___cxa_call_unexpected(($118|0));
    // unreachable;
   }
  } else {
   $7 = ((($1)) + 124|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ((($0)) + 204|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = HEAP32[$6>>2]|0;
   $12 = (($10) - ($11))|0;
   $13 = $12 >> 2;
   $14 = ($13>>>0)>($8>>>0);
   L11: do {
    if (!($14)) {
     $15 = (($8) + 1)|0;
     $16 = ($15>>>0)>($13>>>0);
     $17 = $11;
     $18 = $10;
     if ($16) {
      $19 = (($15) - ($13))|0;
      __ZNSt3__26vectorIN3osg7ref_ptrINS1_16VertexArrayStateEEENS_9allocatorIS4_EEE8__appendEj($6,$19);
      break;
     }
     $20 = ($15>>>0)<($13>>>0);
     if ($20) {
      $21 = (($17) + ($15<<2)|0);
      $22 = ($18|0)==($21|0);
      if (!($22)) {
       $24 = $18;
       while(1) {
        $23 = ((($24)) + -4|0);
        HEAP32[$9>>2] = $23;
        $25 = HEAP32[$23>>2]|0;
        $26 = ($25|0)==(0|0);
        if (!($26)) {
         $27 = ((($25)) + 8|0);
         $28 = HEAP32[$27>>2]|0;HEAP32[$27>>2] = (($28-1)|0);
         $29 = ($28|0)==(1);
         if ($29) {
          __THREW__ = 0;
          invoke_viii(3262,($25|0),1,1);
          $30 = __THREW__; __THREW__ = 0;
          $31 = $30&1;
          if ($31) {
           break;
          }
         }
        }
        HEAP32[$23>>2] = 0;
        $32 = HEAP32[$9>>2]|0;
        $33 = ($32|0)==($21|0);
        if ($33) {
         break L11;
        } else {
         $24 = $32;
        }
       }
       $34 = ___cxa_find_matching_catch_2()|0;
       $35 = tempRet0;
       ___cxa_call_unexpected(($34|0));
       // unreachable;
      }
     }
    }
   } while(0);
   $36 = HEAP32[$6>>2]|0;
   $37 = (($36) + ($8<<2)|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = ($38|0)==(0|0);
   if (!($39)) {
    $40 = $36;
    $41 = HEAP32[$7>>2]|0;
    $42 = HEAP32[$9>>2]|0;
    $43 = (($42) - ($40))|0;
    $44 = $43 >> 2;
    $45 = ($44>>>0)>($41>>>0);
    L26: do {
     if (!($45)) {
      $46 = (($41) + 1)|0;
      $47 = ($46>>>0)>($44>>>0);
      $48 = $42;
      if ($47) {
       $49 = (($46) - ($44))|0;
       __ZNSt3__26vectorIN3osg7ref_ptrINS1_16VertexArrayStateEEENS_9allocatorIS4_EEE8__appendEj($6,$49);
       break;
      }
      $50 = ($46>>>0)<($44>>>0);
      if ($50) {
       $51 = (($36) + ($46<<2)|0);
       $52 = ($48|0)==($51|0);
       if (!($52)) {
        $54 = $48;
        while(1) {
         $53 = ((($54)) + -4|0);
         HEAP32[$9>>2] = $53;
         $55 = HEAP32[$53>>2]|0;
         $56 = ($55|0)==(0|0);
         if (!($56)) {
          $57 = ((($55)) + 8|0);
          $58 = HEAP32[$57>>2]|0;HEAP32[$57>>2] = (($58-1)|0);
          $59 = ($58|0)==(1);
          if ($59) {
           __THREW__ = 0;
           invoke_viii(3262,($55|0),1,1);
           $60 = __THREW__; __THREW__ = 0;
           $61 = $60&1;
           if ($61) {
            break;
           }
          }
         }
         HEAP32[$53>>2] = 0;
         $62 = HEAP32[$9>>2]|0;
         $63 = ($62|0)==($51|0);
         if ($63) {
          break L26;
         } else {
          $54 = $62;
         }
        }
        $64 = ___cxa_find_matching_catch_2()|0;
        $65 = tempRet0;
        ___cxa_call_unexpected(($64|0));
        // unreachable;
       }
      }
     }
    } while(0);
    $66 = HEAP32[$6>>2]|0;
    $67 = (($66) + ($41<<2)|0);
    $68 = HEAP32[$67>>2]|0;
    __ZN3osg16VertexArrayState7releaseEv($68);
    $69 = HEAP32[$7>>2]|0;
    $70 = HEAP32[$9>>2]|0;
    $71 = HEAP32[$6>>2]|0;
    $72 = (($70) - ($71))|0;
    $73 = $72 >> 2;
    $74 = ($73>>>0)>($69>>>0);
    L40: do {
     if (!($74)) {
      $75 = (($69) + 1)|0;
      $76 = ($75>>>0)>($73>>>0);
      $77 = $71;
      $78 = $70;
      if ($76) {
       $79 = (($75) - ($73))|0;
       __ZNSt3__26vectorIN3osg7ref_ptrINS1_16VertexArrayStateEEENS_9allocatorIS4_EEE8__appendEj($6,$79);
       break;
      }
      $80 = ($75>>>0)<($73>>>0);
      if ($80) {
       $81 = (($77) + ($75<<2)|0);
       $82 = ($78|0)==($81|0);
       if (!($82)) {
        $84 = $78;
        while(1) {
         $83 = ((($84)) + -4|0);
         HEAP32[$9>>2] = $83;
         $85 = HEAP32[$83>>2]|0;
         $86 = ($85|0)==(0|0);
         if (!($86)) {
          $87 = ((($85)) + 8|0);
          $88 = HEAP32[$87>>2]|0;HEAP32[$87>>2] = (($88-1)|0);
          $89 = ($88|0)==(1);
          if ($89) {
           __THREW__ = 0;
           invoke_viii(3262,($85|0),1,1);
           $90 = __THREW__; __THREW__ = 0;
           $91 = $90&1;
           if ($91) {
            break;
           }
          }
         }
         HEAP32[$83>>2] = 0;
         $92 = HEAP32[$9>>2]|0;
         $93 = ($92|0)==($81|0);
         if ($93) {
          break L40;
         } else {
          $84 = $92;
         }
        }
        $94 = ___cxa_find_matching_catch_2()|0;
        $95 = tempRet0;
        ___cxa_call_unexpected(($94|0));
        // unreachable;
       }
      }
     }
    } while(0);
    $96 = HEAP32[$6>>2]|0;
    $97 = (($96) + ($69<<2)|0);
    $98 = HEAP32[$97>>2]|0;
    $99 = ($98|0)==(0|0);
    if (!($99)) {
     HEAP32[$97>>2] = 0;
     $100 = ((($98)) + 8|0);
     $101 = HEAP32[$100>>2]|0;HEAP32[$100>>2] = (($101-1)|0);
     $102 = ($101|0)==(1);
     if ($102) {
      __ZNK3osg10Referenced24signalObserversAndDeleteEbb($98,1,1);
     }
    }
   }
  }
 } while(0);
 HEAP32[$3>>2] = 0;
 $120 = ((($3)) + 4|0);
 HEAP32[$120>>2] = 0;
 $121 = ((($3)) + 8|0);
 HEAP32[$121>>2] = 0;
 __THREW__ = 0;
 $122 = (invoke_iii(3766,($0|0),($3|0))|0);
 $123 = __THREW__; __THREW__ = 0;
 $124 = $123&1;
 L57: do {
  if ($124) {
   $128 = ___cxa_find_matching_catch_2()|0;
   $129 = tempRet0;
   $$2 = $129;$$211 = $128;
  } else {
   L60: do {
    if ($122) {
     $125 = HEAP32[$3>>2]|0;
     $126 = HEAP32[$120>>2]|0;
     $127 = ($125|0)==($126|0);
     if (!($127)) {
      $$sroa$042$050 = $125;
      while(1) {
       $130 = HEAP32[$$sroa$042$050>>2]|0;
       $131 = HEAP32[$130>>2]|0;
       $132 = ((($131)) + 136|0);
       $133 = HEAP32[$132>>2]|0;
       __THREW__ = 0;
       invoke_vii($133|0,($130|0),($1|0));
       $134 = __THREW__; __THREW__ = 0;
       $135 = $134&1;
       if ($135) {
        break;
       }
       $136 = ((($$sroa$042$050)) + 4|0);
       $137 = HEAP32[$120>>2]|0;
       $138 = ($136|0)==($137|0);
       if ($138) {
        break L60;
       } else {
        $$sroa$042$050 = $136;
       }
      }
      $139 = ___cxa_find_matching_catch_2()|0;
      $140 = tempRet0;
      $$2 = $140;$$211 = $139;
      break L57;
     }
    }
   } while(0);
   HEAP32[$4>>2] = 0;
   $141 = ((($4)) + 4|0);
   HEAP32[$141>>2] = 0;
   $142 = ((($4)) + 8|0);
   HEAP32[$142>>2] = 0;
   $143 = ((($0)) + 216|0);
   $144 = HEAP32[$143>>2]|0;
   $145 = ((($0)) + 220|0);
   $146 = HEAP32[$145>>2]|0;
   $147 = ($144|0)==($146|0);
   L67: do {
    if (!($147)) {
     $148 = ((($4)) + 8|0);
     $$sroa$06$010$i = $144;
     L69: while(1) {
      $149 = HEAP32[$$sroa$06$010$i>>2]|0;
      $150 = HEAP32[$149>>2]|0;
      $151 = ((($150)) + 176|0);
      $152 = HEAP32[$151>>2]|0;
      __THREW__ = 0;
      $153 = (invoke_ii($152|0,($149|0))|0);
      $154 = __THREW__; __THREW__ = 0;
      $155 = $154&1;
      if ($155) {
       break;
      }
      HEAP32[$2>>2] = $153;
      $156 = ($153|0)==(0|0);
      $157 = $153;
      do {
       if (!($156)) {
        $158 = HEAP32[$141>>2]|0;
        $159 = HEAP32[$148>>2]|0;
        $160 = ($158|0)==($159|0);
        if ($160) {
         __THREW__ = 0;
         invoke_vii(3767,($4|0),($2|0));
         $163 = __THREW__; __THREW__ = 0;
         $164 = $163&1;
         if ($164) {
          break L69;
         } else {
          break;
         }
        } else {
         HEAP32[$158>>2] = $157;
         $161 = HEAP32[$141>>2]|0;
         $162 = ((($161)) + 4|0);
         HEAP32[$141>>2] = $162;
         break;
        }
       }
      } while(0);
      $165 = ((($$sroa$06$010$i)) + 4|0);
      $166 = HEAP32[$145>>2]|0;
      $167 = ($165|0)==($166|0);
      if ($167) {
       label = 57;
       break;
      } else {
       $$sroa$06$010$i = $165;
      }
     }
     L78: do {
      if ((label|0) == 57) {
       $$pre$i27 = HEAP32[$141>>2]|0;
       $$pre11$i = HEAP32[$4>>2]|0;
       $168 = $$pre11$i;
       $169 = $$pre$i27;
       $170 = ($$pre$i27|0)==($$pre11$i|0);
       $171 = ($168|0)==($169|0);
       $or$cond = $170 | $171;
       if ($or$cond) {
        $181 = $168;$183 = $169;
       } else {
        $$sroa$035$049 = $168;
        while(1) {
         $172 = HEAP32[$$sroa$035$049>>2]|0;
         $173 = HEAP32[$172>>2]|0;
         $174 = ((($173)) + 136|0);
         $175 = HEAP32[$174>>2]|0;
         __THREW__ = 0;
         invoke_vii($175|0,($172|0),($1|0));
         $176 = __THREW__; __THREW__ = 0;
         $177 = $176&1;
         if ($177) {
          break L78;
         }
         $178 = ((($$sroa$035$049)) + 4|0);
         $179 = HEAP32[$141>>2]|0;
         $180 = ($178|0)==($179|0);
         if ($180) {
          break;
         } else {
          $$sroa$035$049 = $178;
         }
        }
        $$pre = HEAP32[$4>>2]|0;
        $181 = $$pre;$183 = $178;
       }
       $182 = ($181|0)==(0|0);
       if ($182) {
        break L67;
       }
       $184 = ($183|0)==($181|0);
       if (!($184)) {
        $scevgep$i$i$i29 = ((($183)) + -4|0);
        $185 = $scevgep$i$i$i29;
        $186 = $181;
        $187 = (($185) - ($186))|0;
        $188 = $187 >>> 2;
        $189 = $188 ^ -1;
        $scevgep5$i$i$i30 = (($183) + ($189<<2)|0);
        HEAP32[$141>>2] = $scevgep5$i$i$i30;
       }
       __ZdlPv($181);
       break L67;
      }
     } while(0);
     $208 = ___cxa_find_matching_catch_2()|0;
     $209 = tempRet0;
     $210 = HEAP32[$4>>2]|0;
     $211 = ($210|0)==(0|0);
     if (!($211)) {
      $212 = HEAP32[$141>>2]|0;
      $213 = ($212|0)==($210|0);
      if (!($213)) {
       $scevgep$i$i$i = ((($212)) + -4|0);
       $214 = $scevgep$i$i$i;
       $215 = $210;
       $216 = (($214) - ($215))|0;
       $217 = $216 >>> 2;
       $218 = $217 ^ -1;
       $scevgep5$i$i$i = (($212) + ($218<<2)|0);
       HEAP32[$141>>2] = $scevgep5$i$i$i;
      }
      __ZdlPv($210);
     }
     $$2 = $209;$$211 = $208;
     break L57;
    }
   } while(0);
   $190 = HEAP32[$3>>2]|0;
   $191 = ($190|0)==(0|0);
   if ($191) {
    STACKTOP = sp;return;
   }
   $192 = HEAP32[$120>>2]|0;
   $193 = ($192|0)==($190|0);
   do {
    if ($193) {
     $207 = $190;
    } else {
     $195 = $192;
     while(1) {
      $194 = ((($195)) + -4|0);
      HEAP32[$120>>2] = $194;
      $196 = HEAP32[$194>>2]|0;
      $197 = ($196|0)==(0|0);
      if (!($197)) {
       $198 = ((($196)) + 8|0);
       $199 = HEAP32[$198>>2]|0;HEAP32[$198>>2] = (($199-1)|0);
       $200 = ($199|0)==(1);
       if ($200) {
        __THREW__ = 0;
        invoke_viii(3262,($196|0),1,1);
        $201 = __THREW__; __THREW__ = 0;
        $202 = $201&1;
        if ($202) {
         label = 71;
         break;
        }
       }
      }
      HEAP32[$194>>2] = 0;
      $203 = HEAP32[$120>>2]|0;
      $204 = ($203|0)==($190|0);
      if ($204) {
       label = 72;
       break;
      } else {
       $195 = $203;
      }
     }
     if ((label|0) == 71) {
      $205 = ___cxa_find_matching_catch_2()|0;
      $206 = tempRet0;
      ___cxa_call_unexpected(($205|0));
      // unreachable;
     }
     else if ((label|0) == 72) {
      $$pre$i23 = HEAP32[$3>>2]|0;
      $207 = $$pre$i23;
      break;
     }
    }
   } while(0);
   __ZdlPv($207);
   STACKTOP = sp;return;
  }
 } while(0);
 $219 = HEAP32[$3>>2]|0;
 $220 = ($219|0)==(0|0);
 if ($220) {
  ___resumeException($$211|0);
  // unreachable;
 }
 $221 = HEAP32[$120>>2]|0;
 $222 = ($221|0)==($219|0);
 do {
  if ($222) {
   $236 = $219;
  } else {
   $224 = $221;
   while(1) {
    $223 = ((($224)) + -4|0);
    HEAP32[$120>>2] = $223;
    $225 = HEAP32[$223>>2]|0;
    $226 = ($225|0)==(0|0);
    if (!($226)) {
     $227 = ((($225)) + 8|0);
     $228 = HEAP32[$227>>2]|0;HEAP32[$227>>2] = (($228-1)|0);
     $229 = ($228|0)==(1);
     if ($229) {
      __THREW__ = 0;
      invoke_viii(3262,($225|0),1,1);
      $230 = __THREW__; __THREW__ = 0;
      $231 = $230&1;
      if ($231) {
       label = 86;
       break;
      }
     }
    }
    HEAP32[$223>>2] = 0;
    $232 = HEAP32[$120>>2]|0;
    $233 = ($232|0)==($219|0);
    if ($233) {
     label = 87;
     break;
    } else {
     $224 = $232;
    }
   }
   if ((label|0) == 86) {
    $234 = ___cxa_find_matching_catch_2()|0;
    $235 = tempRet0;
    ___cxa_call_unexpected(($234|0));
    // unreachable;
   }
   else if ((label|0) == 87) {
    $$pre$i = HEAP32[$3>>2]|0;
    $236 = $$pre$i;
    break;
   }
  }
 } while(0);
 __ZdlPv($236);
 ___resumeException($$211|0);
 // unreachable;
}
function __ZN3osg8Geometry10asGeometryEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ($0|0);
}
function __ZNK3osg8Geometry10asGeometryEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ($0|0);
}
function __ZN3osg8Geometry6acceptERNS_11NodeVisitorE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$byval_copy = 0, $$pre$i$i = 0, $$sink$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i = 0, $scevgep5$i$i$i$i = 0, $scevgep5$i$i$i$sink$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy = sp + 8|0;
 $2 = sp + 4|0;
 $3 = sp;
 $4 = ((($1)) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($1)) + 24|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($0)) + 116|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $9 | $7;
 $11 = $10 & $5;
 $12 = ($11|0)==(0);
 if ($12) {
  STACKTOP = sp;return;
 }
 HEAP32[$2>>2] = $0;
 $13 = ((($1)) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(1);
 $16 = ((($1)) + 28|0);
 $17 = $0;
 do {
  if ($15) {
   $25 = HEAP32[$16>>2]|0;
   HEAP32[$3>>2] = $25;
   ;HEAP32[$$byval_copy>>2]=HEAP32[$3>>2]|0;
   (__ZNSt3__26vectorIPN3osg4NodeENS_9allocatorIS3_EEE6insertENS_11__wrap_iterIPKS3_EERS8_($16,$$byval_copy,$2)|0);
  } else {
   $18 = ((($1)) + 32|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ((($1)) + 36|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = ($19|0)==($21|0);
   if ($22) {
    __ZNSt3__26vectorIPN3osg4NodeENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_($16,$2);
    break;
   } else {
    HEAP32[$19>>2] = $17;
    $23 = HEAP32[$18>>2]|0;
    $24 = ((($23)) + 4|0);
    HEAP32[$18>>2] = $24;
    break;
   }
  }
 } while(0);
 $26 = HEAP32[$1>>2]|0;
 $27 = ((($26)) + 104|0);
 $28 = HEAP32[$27>>2]|0;
 FUNCTION_TABLE_vii[$28 & 8191]($1,$0);
 $29 = HEAP32[$13>>2]|0;
 $30 = ($29|0)==(1);
 do {
  if ($30) {
   $34 = ((($1)) + 28|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ((($35)) + 4|0);
   $37 = ((($1)) + 32|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = $36;
   $40 = (($38) - ($39))|0;
   $41 = $40 >> 2;
   $42 = ($41|0)==(0);
   $43 = $38;
   if ($42) {
    $45 = $43;
   } else {
    _memmove(($35|0),($36|0),($40|0))|0;
    $$pre$i$i = HEAP32[$37>>2]|0;
    $45 = $$pre$i$i;
   }
   $44 = (($35) + ($41<<2)|0);
   $46 = ($45|0)==($44|0);
   if ($46) {
    STACKTOP = sp;return;
   } else {
    $scevgep$i$i$i$i = ((($45)) + -4|0);
    $47 = $scevgep$i$i$i$i;
    $48 = $44;
    $49 = (($47) - ($48))|0;
    $50 = $49 >>> 2;
    $51 = $50 ^ -1;
    $scevgep5$i$i$i$i = (($45) + ($51<<2)|0);
    $$sink$i = $37;$scevgep5$i$i$i$sink$i = $scevgep5$i$i$i$i;
    break;
   }
  } else {
   $31 = ((($1)) + 32|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ((($32)) + -4|0);
   $$sink$i = $31;$scevgep5$i$i$i$sink$i = $33;
  }
 } while(0);
 HEAP32[$$sink$i>>2] = $scevgep5$i$i$i$sink$i;
 STACKTOP = sp;return;
}
function __ZN3osg8Geometry25setUseVertexBufferObjectsEb($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$6 = 0, $$636 = 0, $$8 = 0, $$838 = 0, $$pr = 0, $$pre = 0, $$pre$i = 0, $$pre$i44 = 0, $$pre175 = 0, $$pre176 = 0, $$sroa$0120$0168 = 0, $$sroa$0120$1165 = 0, $$sroa$0128$0169 = 0, $$sroa$0128$3 = 0, $$sroa$0128$5 = 0, $$sroa$06$010$i = 0, $$sroa$090$0162 = 0, $$sroa$090$1160 = 0, $$sroa$098$0161 = 0, $$sroa$098$2 = 0;
 var $$sroa$098$5 = 0, $$sroa$098$6 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0;
 var $224 = 0, $225 = 0, $226 = 0, $227 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i48 = 0, $scevgep5$i$i$i = 0, $scevgep5$i$i$i49 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $2 = sp + 24|0;
 $3 = sp + 12|0;
 $4 = sp;
 $5 = ((($0)) + 183|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = $6&255;
 $8 = $1&1;
 $9 = ($7|0)==($8|0);
 if ($9) {
  STACKTOP = sp;return;
 }
 __ZN3osg8Drawable25setUseVertexBufferObjectsEb($0,$1);
 HEAP32[$3>>2] = 0;
 $10 = ((($3)) + 4|0);
 HEAP32[$10>>2] = 0;
 $11 = ((($3)) + 8|0);
 HEAP32[$11>>2] = 0;
 __THREW__ = 0;
 (invoke_iii(3766,($0|0),($3|0))|0);
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $54 = ___cxa_find_matching_catch_2()|0;
  $55 = tempRet0;
  $$8 = $54;$$838 = $55;
 } else {
  HEAP32[$4>>2] = 0;
  $14 = ((($4)) + 4|0);
  HEAP32[$14>>2] = 0;
  $15 = ((($4)) + 8|0);
  HEAP32[$15>>2] = 0;
  $16 = ((($0)) + 216|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = ((($0)) + 220|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = ($17|0)==($19|0);
  L7: do {
   if ($20) {
    label = 11;
   } else {
    $21 = ((($4)) + 8|0);
    $$sroa$06$010$i = $17;
    L9: while(1) {
     $22 = HEAP32[$$sroa$06$010$i>>2]|0;
     $23 = HEAP32[$22>>2]|0;
     $24 = ((($23)) + 176|0);
     $25 = HEAP32[$24>>2]|0;
     __THREW__ = 0;
     $26 = (invoke_ii($25|0,($22|0))|0);
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     if ($28) {
      break;
     }
     HEAP32[$2>>2] = $26;
     $29 = ($26|0)==(0|0);
     $30 = $26;
     do {
      if (!($29)) {
       $31 = HEAP32[$14>>2]|0;
       $32 = HEAP32[$21>>2]|0;
       $33 = ($31|0)==($32|0);
       if ($33) {
        __THREW__ = 0;
        invoke_vii(3767,($4|0),($2|0));
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L9;
        } else {
         break;
        }
       } else {
        HEAP32[$31>>2] = $30;
        $34 = HEAP32[$14>>2]|0;
        $35 = ((($34)) + 4|0);
        HEAP32[$14>>2] = $35;
        break;
       }
      }
     } while(0);
     $38 = ((($$sroa$06$010$i)) + 4|0);
     $39 = HEAP32[$18>>2]|0;
     $40 = ($38|0)==($39|0);
     if ($40) {
      label = 11;
      break L7;
     } else {
      $$sroa$06$010$i = $38;
     }
    }
    $56 = ___cxa_find_matching_catch_2()|0;
    $57 = tempRet0;
    $$6 = $56;$$636 = $57;
   }
  } while(0);
  L19: do {
   if ((label|0) == 11) {
    $41 = HEAP32[$3>>2]|0;
    $42 = HEAP32[$10>>2]|0;
    $43 = ($41|0)==($42|0);
    if (!($43)) {
     $$sroa$0120$0168 = $41;$$sroa$0128$0169 = 0;$224 = $42;$225 = 1;
     while(1) {
      if (!($225)) {
       $$sroa$0128$5 = $$sroa$0128$0169;
       break;
      }
      $44 = HEAP32[$$sroa$0120$0168>>2]|0;
      $45 = ((($44)) + 40|0);
      $46 = HEAP32[$45>>2]|0;
      $47 = ($46|0)==(0|0);
      if ($47) {
       $$sroa$0128$3 = 0;$62 = $224;
      } else {
       $48 = (___dynamic_cast($46,23080,23112,0)|0);
       $49 = ($48|0)==(0|0);
       if ($49) {
        $$sroa$0128$3 = 0;$62 = $224;
       } else {
        $50 = ($$sroa$0128$0169|0)==($48|0);
        if ($50) {
         $$sroa$0128$3 = $$sroa$0128$0169;$62 = $224;
        } else {
         $51 = ($48|0)==(0|0);
         if ($51) {
          $$sroa$0128$3 = 0;$62 = $224;
         } else {
          $52 = ((($48)) + 8|0);
          $53 = HEAP32[$52>>2]|0;HEAP32[$52>>2] = (($53+1)|0);
          $$pre = HEAP32[$10>>2]|0;
          $$sroa$0128$3 = $48;$62 = $$pre;
         }
        }
       }
      }
      $60 = ((($$sroa$0120$0168)) + 4|0);
      $61 = ($60|0)==($62|0);
      $63 = ($$sroa$0128$3|0)==(0|0);
      if ($61) {
       label = 22;
       break;
      } else {
       $$sroa$0120$0168 = $60;$$sroa$0128$0169 = $$sroa$0128$3;$224 = $62;$225 = $63;
      }
     }
     if ((label|0) == 22) {
      if ($63) {
       __THREW__ = 0;
       $64 = (invoke_ii(3276,72)|0);
       $65 = __THREW__; __THREW__ = 0;
       $66 = $65&1;
       if ($66) {
        $58 = ___cxa_find_matching_catch_2()|0;
        $59 = tempRet0;
        $$6 = $58;$$636 = $59;
        break;
       }
       __THREW__ = 0;
       invoke_vi(3768,($64|0));
       $67 = __THREW__; __THREW__ = 0;
       $68 = $67&1;
       if ($68) {
        $72 = ___cxa_find_matching_catch_2()|0;
        $73 = tempRet0;
        __ZdlPv($64);
        $$6 = $72;$$636 = $73;
        break;
       }
       $69 = ($$sroa$0128$3|0)==($64|0);
       if ($69) {
        $$sroa$0128$5 = 0;
       } else {
        $70 = ((($64)) + 8|0);
        $71 = HEAP32[$70>>2]|0;HEAP32[$70>>2] = (($71+1)|0);
        $$sroa$0128$5 = $64;
       }
      } else {
       $$sroa$0128$5 = $$sroa$0128$3;
      }
     }
     $74 = HEAP32[$3>>2]|0;
     $75 = HEAP32[$10>>2]|0;
     $76 = ($74|0)==($75|0);
     L42: do {
      if (!($76)) {
       $$sroa$0120$1165 = $74;$226 = $75;
       while(1) {
        $77 = HEAP32[$$sroa$0120$1165>>2]|0;
        $78 = ((($77)) + 40|0);
        $79 = HEAP32[$78>>2]|0;
        $80 = ($79|0)==(0|0);
        if ($80) {
         label = 32;
        } else {
         $81 = (___dynamic_cast($79,23080,23112,0)|0);
         $82 = ($81|0)==(0|0);
         if ($82) {
          label = 32;
         } else {
          $87 = $226;
         }
        }
        if ((label|0) == 32) {
         label = 0;
         __THREW__ = 0;
         invoke_vii(3554,($77|0),($$sroa$0128$5|0));
         $83 = __THREW__; __THREW__ = 0;
         $84 = $83&1;
         if ($84) {
          break;
         }
         $$pre175 = HEAP32[$10>>2]|0;
         $87 = $$pre175;
        }
        $85 = ((($$sroa$0120$1165)) + 4|0);
        $86 = ($85|0)==($87|0);
        if ($86) {
         break L42;
        } else {
         $$sroa$0120$1165 = $85;$226 = $87;
        }
       }
       $94 = ___cxa_find_matching_catch_2()|0;
       $95 = tempRet0;
       $96 = ($$sroa$0128$5|0)==(0|0);
       if ($96) {
        $$6 = $94;$$636 = $95;
        break L19;
       }
       $97 = ((($$sroa$0128$5)) + 8|0);
       $98 = HEAP32[$97>>2]|0;HEAP32[$97>>2] = (($98-1)|0);
       $99 = ($98|0)==(1);
       if (!($99)) {
        $$6 = $94;$$636 = $95;
        break L19;
       }
       __THREW__ = 0;
       invoke_viii(3262,($$sroa$0128$5|0),1,1);
       $100 = __THREW__; __THREW__ = 0;
       $101 = $100&1;
       if (!($101)) {
        $$6 = $94;$$636 = $95;
        break L19;
       }
       $222 = ___cxa_find_matching_catch_3(0|0)|0;
       $223 = tempRet0;
       ___clang_call_terminate($222);
       // unreachable;
      }
     } while(0);
     $88 = ($$sroa$0128$5|0)==(0|0);
     if (!($88)) {
      $89 = ((($$sroa$0128$5)) + 8|0);
      $90 = HEAP32[$89>>2]|0;HEAP32[$89>>2] = (($90-1)|0);
      $91 = ($90|0)==(1);
      if ($91) {
       __THREW__ = 0;
       invoke_viii(3262,($$sroa$0128$5|0),1,1);
       $92 = __THREW__; __THREW__ = 0;
       $93 = $92&1;
       if ($93) {
        $102 = ___cxa_find_matching_catch_2()|0;
        $103 = tempRet0;
        $$6 = $102;$$636 = $103;
        break;
       }
      }
     }
    }
    $104 = HEAP32[$4>>2]|0;
    $105 = HEAP32[$14>>2]|0;
    $106 = ($104|0)==($105|0);
    L61: do {
     if ($106) {
      $168 = $104;
     } else {
      $$sroa$090$0162 = $104;$$sroa$098$0161 = 0;
      while(1) {
       $107 = HEAP32[$$sroa$090$0162>>2]|0;
       $108 = ((($107)) + 40|0);
       $109 = HEAP32[$108>>2]|0;
       $110 = ($109|0)==(0|0);
       if ($110) {
        $$sroa$098$2 = $$sroa$098$0161;
       } else {
        $111 = (___dynamic_cast($109,23080,23128,0)|0);
        $112 = ($111|0)==(0|0);
        if ($112) {
         $$sroa$098$2 = $$sroa$098$0161;
        } else {
         $113 = ($$sroa$098$0161|0)==($111|0);
         if ($113) {
          $$sroa$098$2 = $$sroa$098$0161;
         } else {
          $114 = ($111|0)==(0|0);
          if (!($114)) {
           $115 = ((($111)) + 8|0);
           $116 = HEAP32[$115>>2]|0;HEAP32[$115>>2] = (($116+1)|0);
          }
          $117 = ($$sroa$098$0161|0)==(0|0);
          if ($117) {
           $$sroa$098$2 = $111;
          } else {
           $118 = ((($$sroa$098$0161)) + 8|0);
           $119 = HEAP32[$118>>2]|0;HEAP32[$118>>2] = (($119-1)|0);
           $120 = ($119|0)==(1);
           if ($120) {
            __THREW__ = 0;
            invoke_viii(3262,($$sroa$098$0161|0),1,1);
            $121 = __THREW__; __THREW__ = 0;
            $122 = $121&1;
            if ($122) {
             $$sroa$098$6 = $111;
             break;
            } else {
             $$sroa$098$2 = $111;
            }
           } else {
            $$sroa$098$2 = $111;
           }
          }
         }
        }
       }
       $123 = ((($$sroa$090$0162)) + 4|0);
       $124 = HEAP32[$14>>2]|0;
       $125 = ($123|0)==($124|0);
       if ($125) {
        label = 52;
        break;
       } else {
        $$sroa$090$0162 = $123;$$sroa$098$0161 = $$sroa$098$2;
       }
      }
      L74: do {
       if ((label|0) == 52) {
        $126 = ($$sroa$098$2|0)==(0|0);
        do {
         if ($126) {
          __THREW__ = 0;
          $127 = (invoke_ii(3276,72)|0);
          $128 = __THREW__; __THREW__ = 0;
          $129 = $128&1;
          if ($129) {
           $134 = ___cxa_find_matching_catch_2()|0;
           $135 = tempRet0;
           $$6 = $134;$$636 = $135;
           break L19;
          }
          __THREW__ = 0;
          invoke_vi(3769,($127|0));
          $130 = __THREW__; __THREW__ = 0;
          $131 = $130&1;
          if ($131) {
           $136 = ___cxa_find_matching_catch_2()|0;
           $137 = tempRet0;
           __ZdlPv($127);
           $$6 = $136;$$636 = $137;
           break L19;
          } else {
           $132 = ((($127)) + 8|0);
           $133 = HEAP32[$132>>2]|0;HEAP32[$132>>2] = (($133+1)|0);
           $$sroa$098$5 = $127;
           break;
          }
         } else {
          $$sroa$098$5 = $$sroa$098$2;
         }
        } while(0);
        $138 = HEAP32[$4>>2]|0;
        $139 = HEAP32[$14>>2]|0;
        $140 = ($138|0)==($139|0);
        if (!($140)) {
         $$sroa$090$1160 = $138;$227 = $139;
         while(1) {
          $141 = HEAP32[$$sroa$090$1160>>2]|0;
          $142 = ((($141)) + 40|0);
          $143 = HEAP32[$142>>2]|0;
          $144 = ($143|0)==(0|0);
          if ($144) {
           label = 62;
          } else {
           $145 = (___dynamic_cast($143,23080,23128,0)|0);
           $146 = ($145|0)==(0|0);
           if ($146) {
            label = 62;
           } else {
            $151 = $227;
           }
          }
          if ((label|0) == 62) {
           label = 0;
           __THREW__ = 0;
           invoke_vii(3554,($141|0),($$sroa$098$5|0));
           $147 = __THREW__; __THREW__ = 0;
           $148 = $147&1;
           if ($148) {
            $$sroa$098$6 = $$sroa$098$5;
            break L74;
           }
           $$pre176 = HEAP32[$14>>2]|0;
           $151 = $$pre176;
          }
          $149 = ((($$sroa$090$1160)) + 4|0);
          $150 = ($149|0)==($151|0);
          if ($150) {
           break;
          } else {
           $$sroa$090$1160 = $149;$227 = $151;
          }
         }
        }
        $152 = ($$sroa$098$5|0)==(0|0);
        if (!($152)) {
         $153 = ((($$sroa$098$5)) + 8|0);
         $154 = HEAP32[$153>>2]|0;HEAP32[$153>>2] = (($154-1)|0);
         $155 = ($154|0)==(1);
         if ($155) {
          __THREW__ = 0;
          invoke_viii(3262,($$sroa$098$5|0),1,1);
          $156 = __THREW__; __THREW__ = 0;
          $157 = $156&1;
          if ($157) {
           $166 = ___cxa_find_matching_catch_2()|0;
           $167 = tempRet0;
           $$6 = $166;$$636 = $167;
           break L19;
          }
         }
        }
        $$pr = HEAP32[$4>>2]|0;
        $168 = $$pr;
        break L61;
       }
      } while(0);
      $158 = ___cxa_find_matching_catch_2()|0;
      $159 = tempRet0;
      $160 = ($$sroa$098$6|0)==(0|0);
      if ($160) {
       $$6 = $158;$$636 = $159;
       break L19;
      }
      $161 = ((($$sroa$098$6)) + 8|0);
      $162 = HEAP32[$161>>2]|0;HEAP32[$161>>2] = (($162-1)|0);
      $163 = ($162|0)==(1);
      if (!($163)) {
       $$6 = $158;$$636 = $159;
       break L19;
      }
      __THREW__ = 0;
      invoke_viii(3262,($$sroa$098$6|0),1,1);
      $164 = __THREW__; __THREW__ = 0;
      $165 = $164&1;
      if (!($165)) {
       $$6 = $158;$$636 = $159;
       break L19;
      }
      $222 = ___cxa_find_matching_catch_3(0|0)|0;
      $223 = tempRet0;
      ___clang_call_terminate($222);
      // unreachable;
     }
    } while(0);
    $169 = ($168|0)==(0|0);
    if (!($169)) {
     $170 = HEAP32[$14>>2]|0;
     $171 = ($170|0)==($168|0);
     if (!($171)) {
      $scevgep$i$i$i48 = ((($170)) + -4|0);
      $172 = $scevgep$i$i$i48;
      $173 = $168;
      $174 = (($172) - ($173))|0;
      $175 = $174 >>> 2;
      $176 = $175 ^ -1;
      $scevgep5$i$i$i49 = (($170) + ($176<<2)|0);
      HEAP32[$14>>2] = $scevgep5$i$i$i49;
     }
     __ZdlPv($168);
    }
    $177 = HEAP32[$3>>2]|0;
    $178 = ($177|0)==(0|0);
    if (!($178)) {
     $179 = HEAP32[$10>>2]|0;
     $180 = ($179|0)==($177|0);
     do {
      if ($180) {
       $194 = $177;
      } else {
       $182 = $179;
       while(1) {
        $181 = ((($182)) + -4|0);
        HEAP32[$10>>2] = $181;
        $183 = HEAP32[$181>>2]|0;
        $184 = ($183|0)==(0|0);
        if (!($184)) {
         $185 = ((($183)) + 8|0);
         $186 = HEAP32[$185>>2]|0;HEAP32[$185>>2] = (($186-1)|0);
         $187 = ($186|0)==(1);
         if ($187) {
          __THREW__ = 0;
          invoke_viii(3262,($183|0),1,1);
          $188 = __THREW__; __THREW__ = 0;
          $189 = $188&1;
          if ($189) {
           label = 83;
           break;
          }
         }
        }
        HEAP32[$181>>2] = 0;
        $190 = HEAP32[$10>>2]|0;
        $191 = ($190|0)==($177|0);
        if ($191) {
         label = 84;
         break;
        } else {
         $182 = $190;
        }
       }
       if ((label|0) == 83) {
        $192 = ___cxa_find_matching_catch_2()|0;
        $193 = tempRet0;
        ___cxa_call_unexpected(($192|0));
        // unreachable;
       }
       else if ((label|0) == 84) {
        $$pre$i44 = HEAP32[$3>>2]|0;
        $194 = $$pre$i44;
        break;
       }
      }
     } while(0);
     __ZdlPv($194);
    }
    STACKTOP = sp;return;
   }
  } while(0);
  $195 = HEAP32[$4>>2]|0;
  $196 = ($195|0)==(0|0);
  if (!($196)) {
   $197 = HEAP32[$14>>2]|0;
   $198 = ($197|0)==($195|0);
   if (!($198)) {
    $scevgep$i$i$i = ((($197)) + -4|0);
    $199 = $scevgep$i$i$i;
    $200 = $195;
    $201 = (($199) - ($200))|0;
    $202 = $201 >>> 2;
    $203 = $202 ^ -1;
    $scevgep5$i$i$i = (($197) + ($203<<2)|0);
    HEAP32[$14>>2] = $scevgep5$i$i$i;
   }
   __ZdlPv($195);
  }
  $$8 = $$6;$$838 = $$636;
 }
 $204 = HEAP32[$3>>2]|0;
 $205 = ($204|0)==(0|0);
 if ($205) {
  ___resumeException($$8|0);
  // unreachable;
 }
 $206 = HEAP32[$10>>2]|0;
 $207 = ($206|0)==($204|0);
 do {
  if ($207) {
   $221 = $204;
  } else {
   $209 = $206;
   while(1) {
    $208 = ((($209)) + -4|0);
    HEAP32[$10>>2] = $208;
    $210 = HEAP32[$208>>2]|0;
    $211 = ($210|0)==(0|0);
    if (!($211)) {
     $212 = ((($210)) + 8|0);
     $213 = HEAP32[$212>>2]|0;HEAP32[$212>>2] = (($213-1)|0);
     $214 = ($213|0)==(1);
     if ($214) {
      __THREW__ = 0;
      invoke_viii(3262,($210|0),1,1);
      $215 = __THREW__; __THREW__ = 0;
      $216 = $215&1;
      if ($216) {
       label = 99;
       break;
      }
     }
    }
    HEAP32[$208>>2] = 0;
    $217 = HEAP32[$10>>2]|0;
    $218 = ($217|0)==($204|0);
    if ($218) {
     label = 100;
     break;
    } else {
     $209 = $217;
    }
   }
   if ((label|0) == 99) {
    $219 = ___cxa_find_matching_catch_2()|0;
    $220 = tempRet0;
    ___cxa_call_unexpected(($219|0));
    // unreachable;
   }
   else if ((label|0) == 100) {
    $$pre$i = HEAP32[$3>>2]|0;
    $221 = $$pre$i;
    break;
   }
  }
 } while(0);
 __ZdlPv($221);
 ___resumeException($$8|0);
 // unreachable;
}
function __ZN3osg8Geometry14dirtyGLObjectsEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg8Drawable14dirtyGLObjectsEv($0);
 return;
}
function __ZNK3osg8Geometry19getGLObjectSizeHintEv($0) {
 $0 = $0|0;
 var $$0 = 0, $$02939 = 0, $$03044 = 0, $$1 = 0, $$10$lcssa = 0, $$1038 = 0, $$2 = 0, $$3 = 0, $$5$lcssa = 0, $$5$ph = 0, $$545 = 0, $$6 = 0, $$7$lcssa = 0, $$740 = 0, $$8 = 0, $$pre = 0, $$pre48 = 0, $$pre49 = 0, $$pre50 = 0, $$sroa$032$037 = 0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 228|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  $$0 = 0;
 } else {
  $4 = HEAP32[$2>>2]|0;
  $5 = ((($4)) + 144|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (FUNCTION_TABLE_ii[$6 & 8191]($2)|0);
  $$0 = $7;
 }
 $8 = ((($0)) + 232|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if ($10) {
  $$1 = $$0;
 } else {
  $11 = HEAP32[$9>>2]|0;
  $12 = ((($11)) + 144|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (FUNCTION_TABLE_ii[$13 & 8191]($9)|0);
  $15 = (($14) + ($$0))|0;
  $$1 = $15;
 }
 $16 = ((($0)) + 236|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==(0|0);
 if ($18) {
  $$2 = $$1;
 } else {
  $19 = HEAP32[$17>>2]|0;
  $20 = ((($19)) + 144|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = (FUNCTION_TABLE_ii[$21 & 8191]($17)|0);
  $23 = (($22) + ($$1))|0;
  $$2 = $23;
 }
 $24 = ((($0)) + 240|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)==(0|0);
 if ($26) {
  $$3 = $$2;
 } else {
  $27 = HEAP32[$25>>2]|0;
  $28 = ((($27)) + 144|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = (FUNCTION_TABLE_ii[$29 & 8191]($25)|0);
  $31 = (($30) + ($$2))|0;
  $$3 = $31;
 }
 $32 = ((($0)) + 244|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ($33|0)==(0|0);
 if ($34) {
  $$5$ph = $$3;
 } else {
  $35 = HEAP32[$33>>2]|0;
  $36 = ((($35)) + 144|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = (FUNCTION_TABLE_ii[$37 & 8191]($33)|0);
  $39 = (($38) + ($$3))|0;
  $$5$ph = $39;
 }
 $40 = ((($0)) + 248|0);
 $41 = ((($0)) + 252|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = HEAP32[$40>>2]|0;
 $44 = ($42|0)==($43|0);
 if ($44) {
  $$5$lcssa = $$5$ph;
 } else {
  $$03044 = 0;$$545 = $$5$ph;$50 = $43;$97 = $42;
  while(1) {
   $51 = $50;
   $52 = (($51) + ($$03044<<2)|0);
   $53 = HEAP32[$52>>2]|0;
   $54 = ($53|0)==(0|0);
   if ($54) {
    $$6 = $$545;$62 = $50;$63 = $97;
   } else {
    $55 = HEAP32[$53>>2]|0;
    $56 = ((($55)) + 144|0);
    $57 = HEAP32[$56>>2]|0;
    $58 = (FUNCTION_TABLE_ii[$57 & 8191]($53)|0);
    $59 = (($58) + ($$545))|0;
    $$pre = HEAP32[$41>>2]|0;
    $$pre48 = HEAP32[$40>>2]|0;
    $$6 = $59;$62 = $$pre48;$63 = $$pre;
   }
   $60 = (($$03044) + 1)|0;
   $61 = (($63) - ($62))|0;
   $64 = $61 >> 2;
   $65 = ($60>>>0)<($64>>>0);
   if ($65) {
    $$03044 = $60;$$545 = $$6;$50 = $62;$97 = $63;
   } else {
    $$5$lcssa = $$6;
    break;
   }
  }
 }
 $45 = ((($0)) + 260|0);
 $46 = ((($0)) + 264|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = HEAP32[$45>>2]|0;
 $49 = ($47|0)==($48|0);
 if ($49) {
  $$7$lcssa = $$5$lcssa;
 } else {
  $$02939 = 0;$$740 = $$5$lcssa;$66 = $48;$98 = $47;
  while(1) {
   $67 = $66;
   $68 = (($67) + ($$02939<<2)|0);
   $69 = HEAP32[$68>>2]|0;
   $70 = ($69|0)==(0|0);
   if ($70) {
    $$8 = $$740;$78 = $66;$79 = $98;
   } else {
    $71 = HEAP32[$69>>2]|0;
    $72 = ((($71)) + 144|0);
    $73 = HEAP32[$72>>2]|0;
    $74 = (FUNCTION_TABLE_ii[$73 & 8191]($69)|0);
    $75 = (($74) + ($$740))|0;
    $$pre49 = HEAP32[$46>>2]|0;
    $$pre50 = HEAP32[$45>>2]|0;
    $$8 = $75;$78 = $$pre50;$79 = $$pre49;
   }
   $76 = (($$02939) + 1)|0;
   $77 = (($79) - ($78))|0;
   $80 = $77 >> 2;
   $81 = ($76>>>0)<($80>>>0);
   if ($81) {
    $$02939 = $76;$$740 = $$8;$66 = $78;$98 = $79;
   } else {
    $$7$lcssa = $$8;
    break;
   }
  }
 }
 $82 = ((($0)) + 216|0);
 $83 = HEAP32[$82>>2]|0;
 $84 = ((($0)) + 220|0);
 $85 = HEAP32[$84>>2]|0;
 $86 = ($83|0)==($85|0);
 if ($86) {
  $$10$lcssa = $$7$lcssa;
  return ($$10$lcssa|0);
 } else {
  $$1038 = $$7$lcssa;$$sroa$032$037 = $83;
 }
 while(1) {
  $87 = HEAP32[$$sroa$032$037>>2]|0;
  $88 = HEAP32[$87>>2]|0;
  $89 = ((($88)) + 200|0);
  $90 = HEAP32[$89>>2]|0;
  $91 = (FUNCTION_TABLE_ii[$90 & 8191]($87)|0);
  $92 = $91 << 2;
  $93 = (($92) + ($$1038))|0;
  $94 = ((($$sroa$032$037)) + 4|0);
  $95 = HEAP32[$84>>2]|0;
  $96 = ($94|0)==($95|0);
  if ($96) {
   $$10$lcssa = $93;
   break;
  } else {
   $$1038 = $93;$$sroa$032$037 = $94;
  }
 }
 return ($$10$lcssa|0);
}
function __ZNK3osg8Geometry16compileGLObjectsERNS_10RenderInfoE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i$i = 0, $$0$i$i$i$i104 = 0, $$0$i$i$i$i120 = 0, $$0$i$i$i$i136 = 0, $$0$i$i$i$i152 = 0, $$0$i$i$i$i56 = 0, $$0$i$i$i$i72 = 0, $$0$i$i$i$i88 = 0, $$0$ph$i$i$i$i101 = 0, $$0$ph$i$i$i$i117 = 0, $$0$ph$i$i$i$i133 = 0, $$0$ph$i$i$i$i149 = 0, $$0$ph$i$i$i$i53 = 0, $$0$ph$i$i$i$i69 = 0, $$0$ph$i$i$i$i85 = 0, $$024$i$i$i$i103 = 0, $$024$i$i$i$i119 = 0, $$024$i$i$i$i135 = 0, $$024$i$i$i$i151 = 0, $$024$i$i$i$i55 = 0;
 var $$024$i$i$i$i71 = 0, $$024$i$i$i$i87 = 0, $$025$i$i$i$i106 = 0, $$025$i$i$i$i122 = 0, $$025$i$i$i$i138 = 0, $$025$i$i$i$i154 = 0, $$025$i$i$i$i58 = 0, $$025$i$i$i$i74 = 0, $$025$i$i$i$i90 = 0, $$036$i$i$i105 = 0, $$036$i$i$i121 = 0, $$036$i$i$i137 = 0, $$036$i$i$i153 = 0, $$036$i$i$i57 = 0, $$036$i$i$i73 = 0, $$036$i$i$i89 = 0, $$6 = 0, $$646 = 0, $$in$i$i$i$i100 = 0, $$in$i$i$i$i116 = 0;
 var $$in$i$i$i$i132 = 0, $$in$i$i$i$i148 = 0, $$in$i$i$i$i52 = 0, $$in$i$i$i$i68 = 0, $$in$i$i$i$i84 = 0, $$pre = 0, $$pre$i$i$i$i109 = 0, $$pre$i$i$i$i125 = 0, $$pre$i$i$i$i141 = 0, $$pre$i$i$i$i157 = 0, $$pre$i$i$i$i61 = 0, $$pre$i$i$i$i77 = 0, $$pre$i$i$i$i93 = 0, $$pre368 = 0, $$pre369 = 0, $$sroa$0169$0$be = 0, $$sroa$0169$0310 = 0, $$sroa$0182$0311 = 0, $$sroa$0198$0313 = 0, $$sroa$0215$0317 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0;
 var $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0;
 var $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0;
 var $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0;
 var $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0;
 var $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0;
 var $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0;
 var $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0;
 var $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0;
 var $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0;
 var $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0;
 var $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0;
 var $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0;
 var $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0;
 var $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0;
 var $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0;
 var $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0;
 var $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0;
 var $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0;
 var $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = HEAP32[$1>>2]|0;
 $4 = ((($0)) + 182|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)==(0);
 if ($6) {
  $17 = 0;
 } else {
  $7 = ((($0)) + 183|0);
  $8 = HEAP8[$7>>0]|0;
  $9 = ($8<<24>>24)!=(0);
  $17 = $9;
 }
 $10 = ((($3)) + 712|0);
 $11 = HEAP8[$10>>0]|0;
 $12 = ($11<<24>>24)==(0);
 if ($12) {
  $13 = ((($3)) + 710|0);
  $14 = HEAP8[$13>>0]|0;
  $15 = ($14<<24>>24)!=(0);
  $16 = $17 & $15;
  if (!($16)) {
   STACKTOP = sp;return;
  }
 }
 $18 = ((($3)) + 124|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ((($3)) + 784|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0|0);
 if ($22) {
  STACKTOP = sp;return;
 }
 $23 = ((($2)) + 4|0);
 HEAP32[$23>>2] = 0;
 $24 = ((($2)) + 8|0);
 HEAP32[$24>>2] = 0;
 $25 = ((($2)) + 4|0);
 HEAP32[$2>>2] = $25;
 $26 = ((($0)) + 228|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ($27|0)==(0|0);
 do {
  if ($28) {
   $451 = 0;
  } else {
   $29 = ((($27)) + 40|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = ($30|0)==(0|0);
   if ($31) {
    $451 = 0;
   } else {
    $32 = $30;
    $33 = HEAP32[$25>>2]|0;
    $34 = ($33|0)==(0|0);
    if ($34) {
     __THREW__ = 0;
     $35 = (invoke_ii(3276,20)|0);
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      $38 = ((($35)) + 16|0);
      HEAP32[$38>>2] = $32;
      HEAP32[$35>>2] = 0;
      $39 = ((($35)) + 4|0);
      HEAP32[$39>>2] = 0;
      $40 = ((($35)) + 8|0);
      HEAP32[$40>>2] = $25;
      HEAP32[$25>>2] = $35;
      $41 = $35;
      HEAP32[$2>>2] = $41;
      __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($35,$35);
      $42 = HEAP32[$24>>2]|0;
      $43 = (($42) + 1)|0;
      HEAP32[$24>>2] = $43;
      $451 = $43;
      break;
     }
     $46 = ___cxa_find_matching_catch_2()|0;
     $47 = tempRet0;
     $$6 = $47;$$646 = $46;
     $450 = HEAP32[$25>>2]|0;
     __ZNSt3__26__treeIPN3osg12BufferObjectENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($2,$450);
     ___resumeException($$646|0);
     // unreachable;
    } else {
     $451 = 0;
    }
   }
  }
 } while(0);
 $48 = ((($0)) + 232|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = ($49|0)==(0|0);
 if ($50) {
  $452 = $451;
 } else {
  $51 = ((($49)) + 40|0);
  $52 = HEAP32[$51>>2]|0;
  $53 = ($52|0)==(0|0);
  if ($53) {
   $452 = $451;
  } else {
   $54 = $52;
   $55 = HEAP32[$25>>2]|0;
   $56 = ($55|0)==(0|0);
   do {
    if ($56) {
     $$025$i$i$i$i74 = $25;$$036$i$i$i73 = $25;
    } else {
     $$0$i$i$i$i72 = $23;$$024$i$i$i$i71 = $55;
     while(1) {
      $57 = ((($$024$i$i$i$i71)) + 16|0);
      $58 = HEAP32[$57>>2]|0;
      $59 = ($52>>>0)<($58>>>0);
      if ($59) {
       $60 = HEAP32[$$024$i$i$i$i71>>2]|0;
       $61 = ($60|0)==(0|0);
       if ($61) {
        label = 19;
        break;
       } else {
        $$0$ph$i$i$i$i69 = $$024$i$i$i$i71;$$in$i$i$i$i68 = $60;
       }
      } else {
       $62 = ($58>>>0)<($52>>>0);
       if (!($62)) {
        label = 23;
        break;
       }
       $63 = ((($$024$i$i$i$i71)) + 4|0);
       $64 = HEAP32[$63>>2]|0;
       $65 = ($64|0)==(0|0);
       if ($65) {
        label = 22;
        break;
       } else {
        $$0$ph$i$i$i$i69 = $63;$$in$i$i$i$i68 = $64;
       }
      }
      $$0$i$i$i$i72 = $$0$ph$i$i$i$i69;$$024$i$i$i$i71 = $$in$i$i$i$i68;
     }
     if ((label|0) == 19) {
      $$025$i$i$i$i74 = $$024$i$i$i$i71;$$036$i$i$i73 = $$024$i$i$i$i71;
      break;
     }
     else if ((label|0) == 22) {
      $$025$i$i$i$i74 = $63;$$036$i$i$i73 = $$024$i$i$i$i71;
      break;
     }
     else if ((label|0) == 23) {
      $$025$i$i$i$i74 = $$0$i$i$i$i72;$$036$i$i$i73 = $$024$i$i$i$i71;
      break;
     }
    }
   } while(0);
   $66 = HEAP32[$$025$i$i$i$i74>>2]|0;
   $67 = ($66|0)==(0|0);
   if ($67) {
    __THREW__ = 0;
    $68 = (invoke_ii(3276,20)|0);
    $69 = __THREW__; __THREW__ = 0;
    $70 = $69&1;
    if ($70) {
     $82 = ___cxa_find_matching_catch_2()|0;
     $83 = tempRet0;
     $$6 = $83;$$646 = $82;
     $450 = HEAP32[$25>>2]|0;
     __ZNSt3__26__treeIPN3osg12BufferObjectENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($2,$450);
     ___resumeException($$646|0);
     // unreachable;
    }
    $71 = ((($68)) + 16|0);
    HEAP32[$71>>2] = $54;
    HEAP32[$68>>2] = 0;
    $72 = ((($68)) + 4|0);
    HEAP32[$72>>2] = 0;
    $73 = ((($68)) + 8|0);
    HEAP32[$73>>2] = $$036$i$i$i73;
    HEAP32[$$025$i$i$i$i74>>2] = $68;
    $74 = HEAP32[$2>>2]|0;
    $75 = HEAP32[$74>>2]|0;
    $76 = ($75|0)==(0|0);
    if ($76) {
     $79 = $68;
    } else {
     $77 = $75;
     HEAP32[$2>>2] = $77;
     $$pre$i$i$i$i77 = HEAP32[$$025$i$i$i$i74>>2]|0;
     $79 = $$pre$i$i$i$i77;
    }
    $78 = HEAP32[$23>>2]|0;
    __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($78,$79);
    $80 = HEAP32[$24>>2]|0;
    $81 = (($80) + 1)|0;
    HEAP32[$24>>2] = $81;
    $452 = $81;
   } else {
    $452 = $451;
   }
  }
 }
 $84 = ((($0)) + 236|0);
 $85 = HEAP32[$84>>2]|0;
 $86 = ($85|0)==(0|0);
 if ($86) {
  $453 = $452;
 } else {
  $87 = ((($85)) + 40|0);
  $88 = HEAP32[$87>>2]|0;
  $89 = ($88|0)==(0|0);
  if ($89) {
   $453 = $452;
  } else {
   $90 = $88;
   $91 = HEAP32[$25>>2]|0;
   $92 = ($91|0)==(0|0);
   do {
    if ($92) {
     $$025$i$i$i$i122 = $25;$$036$i$i$i121 = $25;
    } else {
     $$0$i$i$i$i120 = $23;$$024$i$i$i$i119 = $91;
     while(1) {
      $93 = ((($$024$i$i$i$i119)) + 16|0);
      $94 = HEAP32[$93>>2]|0;
      $95 = ($88>>>0)<($94>>>0);
      if ($95) {
       $96 = HEAP32[$$024$i$i$i$i119>>2]|0;
       $97 = ($96|0)==(0|0);
       if ($97) {
        label = 37;
        break;
       } else {
        $$0$ph$i$i$i$i117 = $$024$i$i$i$i119;$$in$i$i$i$i116 = $96;
       }
      } else {
       $98 = ($94>>>0)<($88>>>0);
       if (!($98)) {
        label = 41;
        break;
       }
       $99 = ((($$024$i$i$i$i119)) + 4|0);
       $100 = HEAP32[$99>>2]|0;
       $101 = ($100|0)==(0|0);
       if ($101) {
        label = 40;
        break;
       } else {
        $$0$ph$i$i$i$i117 = $99;$$in$i$i$i$i116 = $100;
       }
      }
      $$0$i$i$i$i120 = $$0$ph$i$i$i$i117;$$024$i$i$i$i119 = $$in$i$i$i$i116;
     }
     if ((label|0) == 37) {
      $$025$i$i$i$i122 = $$024$i$i$i$i119;$$036$i$i$i121 = $$024$i$i$i$i119;
      break;
     }
     else if ((label|0) == 40) {
      $$025$i$i$i$i122 = $99;$$036$i$i$i121 = $$024$i$i$i$i119;
      break;
     }
     else if ((label|0) == 41) {
      $$025$i$i$i$i122 = $$0$i$i$i$i120;$$036$i$i$i121 = $$024$i$i$i$i119;
      break;
     }
    }
   } while(0);
   $102 = HEAP32[$$025$i$i$i$i122>>2]|0;
   $103 = ($102|0)==(0|0);
   if ($103) {
    __THREW__ = 0;
    $104 = (invoke_ii(3276,20)|0);
    $105 = __THREW__; __THREW__ = 0;
    $106 = $105&1;
    if ($106) {
     $118 = ___cxa_find_matching_catch_2()|0;
     $119 = tempRet0;
     $$6 = $119;$$646 = $118;
     $450 = HEAP32[$25>>2]|0;
     __ZNSt3__26__treeIPN3osg12BufferObjectENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($2,$450);
     ___resumeException($$646|0);
     // unreachable;
    }
    $107 = ((($104)) + 16|0);
    HEAP32[$107>>2] = $90;
    HEAP32[$104>>2] = 0;
    $108 = ((($104)) + 4|0);
    HEAP32[$108>>2] = 0;
    $109 = ((($104)) + 8|0);
    HEAP32[$109>>2] = $$036$i$i$i121;
    HEAP32[$$025$i$i$i$i122>>2] = $104;
    $110 = HEAP32[$2>>2]|0;
    $111 = HEAP32[$110>>2]|0;
    $112 = ($111|0)==(0|0);
    if ($112) {
     $115 = $104;
    } else {
     $113 = $111;
     HEAP32[$2>>2] = $113;
     $$pre$i$i$i$i125 = HEAP32[$$025$i$i$i$i122>>2]|0;
     $115 = $$pre$i$i$i$i125;
    }
    $114 = HEAP32[$23>>2]|0;
    __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($114,$115);
    $116 = HEAP32[$24>>2]|0;
    $117 = (($116) + 1)|0;
    HEAP32[$24>>2] = $117;
    $453 = $117;
   } else {
    $453 = $452;
   }
  }
 }
 $120 = ((($0)) + 240|0);
 $121 = HEAP32[$120>>2]|0;
 $122 = ($121|0)==(0|0);
 if ($122) {
  $454 = $453;
 } else {
  $123 = ((($121)) + 40|0);
  $124 = HEAP32[$123>>2]|0;
  $125 = ($124|0)==(0|0);
  if ($125) {
   $454 = $453;
  } else {
   $126 = $124;
   $127 = HEAP32[$25>>2]|0;
   $128 = ($127|0)==(0|0);
   do {
    if ($128) {
     $$025$i$i$i$i154 = $25;$$036$i$i$i153 = $25;
    } else {
     $$0$i$i$i$i152 = $23;$$024$i$i$i$i151 = $127;
     while(1) {
      $129 = ((($$024$i$i$i$i151)) + 16|0);
      $130 = HEAP32[$129>>2]|0;
      $131 = ($124>>>0)<($130>>>0);
      if ($131) {
       $132 = HEAP32[$$024$i$i$i$i151>>2]|0;
       $133 = ($132|0)==(0|0);
       if ($133) {
        label = 55;
        break;
       } else {
        $$0$ph$i$i$i$i149 = $$024$i$i$i$i151;$$in$i$i$i$i148 = $132;
       }
      } else {
       $134 = ($130>>>0)<($124>>>0);
       if (!($134)) {
        label = 59;
        break;
       }
       $135 = ((($$024$i$i$i$i151)) + 4|0);
       $136 = HEAP32[$135>>2]|0;
       $137 = ($136|0)==(0|0);
       if ($137) {
        label = 58;
        break;
       } else {
        $$0$ph$i$i$i$i149 = $135;$$in$i$i$i$i148 = $136;
       }
      }
      $$0$i$i$i$i152 = $$0$ph$i$i$i$i149;$$024$i$i$i$i151 = $$in$i$i$i$i148;
     }
     if ((label|0) == 55) {
      $$025$i$i$i$i154 = $$024$i$i$i$i151;$$036$i$i$i153 = $$024$i$i$i$i151;
      break;
     }
     else if ((label|0) == 58) {
      $$025$i$i$i$i154 = $135;$$036$i$i$i153 = $$024$i$i$i$i151;
      break;
     }
     else if ((label|0) == 59) {
      $$025$i$i$i$i154 = $$0$i$i$i$i152;$$036$i$i$i153 = $$024$i$i$i$i151;
      break;
     }
    }
   } while(0);
   $138 = HEAP32[$$025$i$i$i$i154>>2]|0;
   $139 = ($138|0)==(0|0);
   if ($139) {
    __THREW__ = 0;
    $140 = (invoke_ii(3276,20)|0);
    $141 = __THREW__; __THREW__ = 0;
    $142 = $141&1;
    if ($142) {
     $154 = ___cxa_find_matching_catch_2()|0;
     $155 = tempRet0;
     $$6 = $155;$$646 = $154;
     $450 = HEAP32[$25>>2]|0;
     __ZNSt3__26__treeIPN3osg12BufferObjectENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($2,$450);
     ___resumeException($$646|0);
     // unreachable;
    }
    $143 = ((($140)) + 16|0);
    HEAP32[$143>>2] = $126;
    HEAP32[$140>>2] = 0;
    $144 = ((($140)) + 4|0);
    HEAP32[$144>>2] = 0;
    $145 = ((($140)) + 8|0);
    HEAP32[$145>>2] = $$036$i$i$i153;
    HEAP32[$$025$i$i$i$i154>>2] = $140;
    $146 = HEAP32[$2>>2]|0;
    $147 = HEAP32[$146>>2]|0;
    $148 = ($147|0)==(0|0);
    if ($148) {
     $151 = $140;
    } else {
     $149 = $147;
     HEAP32[$2>>2] = $149;
     $$pre$i$i$i$i157 = HEAP32[$$025$i$i$i$i154>>2]|0;
     $151 = $$pre$i$i$i$i157;
    }
    $150 = HEAP32[$23>>2]|0;
    __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($150,$151);
    $152 = HEAP32[$24>>2]|0;
    $153 = (($152) + 1)|0;
    HEAP32[$24>>2] = $153;
    $454 = $153;
   } else {
    $454 = $453;
   }
  }
 }
 $156 = ((($0)) + 244|0);
 $157 = HEAP32[$156>>2]|0;
 $158 = ($157|0)==(0|0);
 if ($158) {
  $455 = $454;
 } else {
  $159 = ((($157)) + 40|0);
  $160 = HEAP32[$159>>2]|0;
  $161 = ($160|0)==(0|0);
  if ($161) {
   $455 = $454;
  } else {
   $162 = $160;
   $163 = HEAP32[$25>>2]|0;
   $164 = ($163|0)==(0|0);
   do {
    if ($164) {
     $$025$i$i$i$i138 = $25;$$036$i$i$i137 = $25;
    } else {
     $$0$i$i$i$i136 = $23;$$024$i$i$i$i135 = $163;
     while(1) {
      $165 = ((($$024$i$i$i$i135)) + 16|0);
      $166 = HEAP32[$165>>2]|0;
      $167 = ($160>>>0)<($166>>>0);
      if ($167) {
       $168 = HEAP32[$$024$i$i$i$i135>>2]|0;
       $169 = ($168|0)==(0|0);
       if ($169) {
        label = 73;
        break;
       } else {
        $$0$ph$i$i$i$i133 = $$024$i$i$i$i135;$$in$i$i$i$i132 = $168;
       }
      } else {
       $170 = ($166>>>0)<($160>>>0);
       if (!($170)) {
        label = 77;
        break;
       }
       $171 = ((($$024$i$i$i$i135)) + 4|0);
       $172 = HEAP32[$171>>2]|0;
       $173 = ($172|0)==(0|0);
       if ($173) {
        label = 76;
        break;
       } else {
        $$0$ph$i$i$i$i133 = $171;$$in$i$i$i$i132 = $172;
       }
      }
      $$0$i$i$i$i136 = $$0$ph$i$i$i$i133;$$024$i$i$i$i135 = $$in$i$i$i$i132;
     }
     if ((label|0) == 73) {
      $$025$i$i$i$i138 = $$024$i$i$i$i135;$$036$i$i$i137 = $$024$i$i$i$i135;
      break;
     }
     else if ((label|0) == 76) {
      $$025$i$i$i$i138 = $171;$$036$i$i$i137 = $$024$i$i$i$i135;
      break;
     }
     else if ((label|0) == 77) {
      $$025$i$i$i$i138 = $$0$i$i$i$i136;$$036$i$i$i137 = $$024$i$i$i$i135;
      break;
     }
    }
   } while(0);
   $174 = HEAP32[$$025$i$i$i$i138>>2]|0;
   $175 = ($174|0)==(0|0);
   if ($175) {
    __THREW__ = 0;
    $176 = (invoke_ii(3276,20)|0);
    $177 = __THREW__; __THREW__ = 0;
    $178 = $177&1;
    if ($178) {
     $190 = ___cxa_find_matching_catch_2()|0;
     $191 = tempRet0;
     $$6 = $191;$$646 = $190;
     $450 = HEAP32[$25>>2]|0;
     __ZNSt3__26__treeIPN3osg12BufferObjectENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($2,$450);
     ___resumeException($$646|0);
     // unreachable;
    }
    $179 = ((($176)) + 16|0);
    HEAP32[$179>>2] = $162;
    HEAP32[$176>>2] = 0;
    $180 = ((($176)) + 4|0);
    HEAP32[$180>>2] = 0;
    $181 = ((($176)) + 8|0);
    HEAP32[$181>>2] = $$036$i$i$i137;
    HEAP32[$$025$i$i$i$i138>>2] = $176;
    $182 = HEAP32[$2>>2]|0;
    $183 = HEAP32[$182>>2]|0;
    $184 = ($183|0)==(0|0);
    if ($184) {
     $187 = $176;
    } else {
     $185 = $183;
     HEAP32[$2>>2] = $185;
     $$pre$i$i$i$i141 = HEAP32[$$025$i$i$i$i138>>2]|0;
     $187 = $$pre$i$i$i$i141;
    }
    $186 = HEAP32[$23>>2]|0;
    __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($186,$187);
    $188 = HEAP32[$24>>2]|0;
    $189 = (($188) + 1)|0;
    HEAP32[$24>>2] = $189;
    $455 = $189;
   } else {
    $455 = $454;
   }
  }
 }
 $192 = ((($0)) + 248|0);
 $193 = HEAP32[$192>>2]|0;
 $194 = ((($0)) + 252|0);
 $195 = HEAP32[$194>>2]|0;
 $196 = ($193|0)==($195|0);
 L124: do {
  if ($196) {
   $456 = $455;
  } else {
   $$sroa$0215$0317 = $193;$457 = $455;$458 = $195;
   while(1) {
    $202 = HEAP32[$$sroa$0215$0317>>2]|0;
    $203 = ($202|0)==(0|0);
    if ($203) {
     $237 = $458;$462 = $457;
    } else {
     $204 = ((($202)) + 40|0);
     $205 = HEAP32[$204>>2]|0;
     $206 = ($205|0)==(0|0);
     if ($206) {
      $237 = $458;$462 = $457;
     } else {
      $207 = $205;
      $208 = HEAP32[$25>>2]|0;
      $209 = ($208|0)==(0|0);
      do {
       if ($209) {
        $$025$i$i$i$i106 = $25;$$036$i$i$i105 = $25;
       } else {
        $$0$i$i$i$i104 = $23;$$024$i$i$i$i103 = $208;
        while(1) {
         $210 = ((($$024$i$i$i$i103)) + 16|0);
         $211 = HEAP32[$210>>2]|0;
         $212 = ($205>>>0)<($211>>>0);
         if ($212) {
          $213 = HEAP32[$$024$i$i$i$i103>>2]|0;
          $214 = ($213|0)==(0|0);
          if ($214) {
           label = 95;
           break;
          } else {
           $$0$ph$i$i$i$i101 = $$024$i$i$i$i103;$$in$i$i$i$i100 = $213;
          }
         } else {
          $215 = ($211>>>0)<($205>>>0);
          if (!($215)) {
           label = 99;
           break;
          }
          $216 = ((($$024$i$i$i$i103)) + 4|0);
          $217 = HEAP32[$216>>2]|0;
          $218 = ($217|0)==(0|0);
          if ($218) {
           label = 98;
           break;
          } else {
           $$0$ph$i$i$i$i101 = $216;$$in$i$i$i$i100 = $217;
          }
         }
         $$0$i$i$i$i104 = $$0$ph$i$i$i$i101;$$024$i$i$i$i103 = $$in$i$i$i$i100;
        }
        if ((label|0) == 95) {
         label = 0;
         $$025$i$i$i$i106 = $$024$i$i$i$i103;$$036$i$i$i105 = $$024$i$i$i$i103;
         break;
        }
        else if ((label|0) == 98) {
         label = 0;
         $$025$i$i$i$i106 = $216;$$036$i$i$i105 = $$024$i$i$i$i103;
         break;
        }
        else if ((label|0) == 99) {
         label = 0;
         $$025$i$i$i$i106 = $$0$i$i$i$i104;$$036$i$i$i105 = $$024$i$i$i$i103;
         break;
        }
       }
      } while(0);
      $219 = HEAP32[$$025$i$i$i$i106>>2]|0;
      $220 = ($219|0)==(0|0);
      if ($220) {
       __THREW__ = 0;
       $221 = (invoke_ii(3276,20)|0);
       $222 = __THREW__; __THREW__ = 0;
       $223 = $222&1;
       if ($223) {
        break;
       }
       $224 = ((($221)) + 16|0);
       HEAP32[$224>>2] = $207;
       HEAP32[$221>>2] = 0;
       $225 = ((($221)) + 4|0);
       HEAP32[$225>>2] = 0;
       $226 = ((($221)) + 8|0);
       HEAP32[$226>>2] = $$036$i$i$i105;
       HEAP32[$$025$i$i$i$i106>>2] = $221;
       $227 = HEAP32[$2>>2]|0;
       $228 = HEAP32[$227>>2]|0;
       $229 = ($228|0)==(0|0);
       if ($229) {
        $232 = $221;
       } else {
        $230 = $228;
        HEAP32[$2>>2] = $230;
        $$pre$i$i$i$i109 = HEAP32[$$025$i$i$i$i106>>2]|0;
        $232 = $$pre$i$i$i$i109;
       }
       $231 = HEAP32[$23>>2]|0;
       __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($231,$232);
       $233 = HEAP32[$24>>2]|0;
       $234 = (($233) + 1)|0;
       HEAP32[$24>>2] = $234;
       $$pre = HEAP32[$194>>2]|0;
       $237 = $$pre;$462 = $234;
      } else {
       $237 = $458;$462 = $457;
      }
     }
    }
    $235 = ((($$sroa$0215$0317)) + 4|0);
    $236 = ($235|0)==($237|0);
    if ($236) {
     $456 = $462;
     break L124;
    } else {
     $$sroa$0215$0317 = $235;$457 = $462;$458 = $237;
    }
   }
   $238 = ___cxa_find_matching_catch_2()|0;
   $239 = tempRet0;
   $$6 = $239;$$646 = $238;
   $450 = HEAP32[$25>>2]|0;
   __ZNSt3__26__treeIPN3osg12BufferObjectENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($2,$450);
   ___resumeException($$646|0);
   // unreachable;
  }
 } while(0);
 $197 = ((($0)) + 260|0);
 $198 = HEAP32[$197>>2]|0;
 $199 = ((($0)) + 264|0);
 $200 = HEAP32[$199>>2]|0;
 $201 = ($198|0)==($200|0);
 L153: do {
  if ($201) {
   $459 = $456;
  } else {
   $$sroa$0198$0313 = $198;$460 = $456;$461 = $200;
   while(1) {
    $245 = HEAP32[$$sroa$0198$0313>>2]|0;
    $246 = ($245|0)==(0|0);
    if ($246) {
     $280 = $461;$465 = $460;
    } else {
     $247 = ((($245)) + 40|0);
     $248 = HEAP32[$247>>2]|0;
     $249 = ($248|0)==(0|0);
     if ($249) {
      $280 = $461;$465 = $460;
     } else {
      $250 = $248;
      $251 = HEAP32[$25>>2]|0;
      $252 = ($251|0)==(0|0);
      do {
       if ($252) {
        $$025$i$i$i$i90 = $25;$$036$i$i$i89 = $25;
       } else {
        $$0$i$i$i$i88 = $23;$$024$i$i$i$i87 = $251;
        while(1) {
         $253 = ((($$024$i$i$i$i87)) + 16|0);
         $254 = HEAP32[$253>>2]|0;
         $255 = ($248>>>0)<($254>>>0);
         if ($255) {
          $256 = HEAP32[$$024$i$i$i$i87>>2]|0;
          $257 = ($256|0)==(0|0);
          if ($257) {
           label = 115;
           break;
          } else {
           $$0$ph$i$i$i$i85 = $$024$i$i$i$i87;$$in$i$i$i$i84 = $256;
          }
         } else {
          $258 = ($254>>>0)<($248>>>0);
          if (!($258)) {
           label = 119;
           break;
          }
          $259 = ((($$024$i$i$i$i87)) + 4|0);
          $260 = HEAP32[$259>>2]|0;
          $261 = ($260|0)==(0|0);
          if ($261) {
           label = 118;
           break;
          } else {
           $$0$ph$i$i$i$i85 = $259;$$in$i$i$i$i84 = $260;
          }
         }
         $$0$i$i$i$i88 = $$0$ph$i$i$i$i85;$$024$i$i$i$i87 = $$in$i$i$i$i84;
        }
        if ((label|0) == 115) {
         label = 0;
         $$025$i$i$i$i90 = $$024$i$i$i$i87;$$036$i$i$i89 = $$024$i$i$i$i87;
         break;
        }
        else if ((label|0) == 118) {
         label = 0;
         $$025$i$i$i$i90 = $259;$$036$i$i$i89 = $$024$i$i$i$i87;
         break;
        }
        else if ((label|0) == 119) {
         label = 0;
         $$025$i$i$i$i90 = $$0$i$i$i$i88;$$036$i$i$i89 = $$024$i$i$i$i87;
         break;
        }
       }
      } while(0);
      $262 = HEAP32[$$025$i$i$i$i90>>2]|0;
      $263 = ($262|0)==(0|0);
      if ($263) {
       __THREW__ = 0;
       $264 = (invoke_ii(3276,20)|0);
       $265 = __THREW__; __THREW__ = 0;
       $266 = $265&1;
       if ($266) {
        break;
       }
       $267 = ((($264)) + 16|0);
       HEAP32[$267>>2] = $250;
       HEAP32[$264>>2] = 0;
       $268 = ((($264)) + 4|0);
       HEAP32[$268>>2] = 0;
       $269 = ((($264)) + 8|0);
       HEAP32[$269>>2] = $$036$i$i$i89;
       HEAP32[$$025$i$i$i$i90>>2] = $264;
       $270 = HEAP32[$2>>2]|0;
       $271 = HEAP32[$270>>2]|0;
       $272 = ($271|0)==(0|0);
       if ($272) {
        $275 = $264;
       } else {
        $273 = $271;
        HEAP32[$2>>2] = $273;
        $$pre$i$i$i$i93 = HEAP32[$$025$i$i$i$i90>>2]|0;
        $275 = $$pre$i$i$i$i93;
       }
       $274 = HEAP32[$23>>2]|0;
       __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($274,$275);
       $276 = HEAP32[$24>>2]|0;
       $277 = (($276) + 1)|0;
       HEAP32[$24>>2] = $277;
       $$pre368 = HEAP32[$199>>2]|0;
       $280 = $$pre368;$465 = $277;
      } else {
       $280 = $461;$465 = $460;
      }
     }
    }
    $278 = ((($$sroa$0198$0313)) + 4|0);
    $279 = ($278|0)==($280|0);
    if ($279) {
     $459 = $465;
     break L153;
    } else {
     $$sroa$0198$0313 = $278;$460 = $465;$461 = $280;
    }
   }
   $281 = ___cxa_find_matching_catch_2()|0;
   $282 = tempRet0;
   $$6 = $282;$$646 = $281;
   $450 = HEAP32[$25>>2]|0;
   __ZNSt3__26__treeIPN3osg12BufferObjectENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($2,$450);
   ___resumeException($$646|0);
   // unreachable;
  }
 } while(0);
 $240 = ((($0)) + 216|0);
 $241 = HEAP32[$240>>2]|0;
 $242 = ((($0)) + 220|0);
 $243 = HEAP32[$242>>2]|0;
 $244 = ($241|0)==($243|0);
 L182: do {
  if ($244) {
   $283 = $459;
  } else {
   $$sroa$0182$0311 = $241;$463 = $459;$464 = $243;
   while(1) {
    $285 = HEAP32[$$sroa$0182$0311>>2]|0;
    $286 = ((($285)) + 40|0);
    $287 = HEAP32[$286>>2]|0;
    $288 = ($287|0)==(0|0);
    if ($288) {
     $319 = $464;$466 = $463;
    } else {
     $289 = $287;
     $290 = HEAP32[$25>>2]|0;
     $291 = ($290|0)==(0|0);
     do {
      if ($291) {
       $$025$i$i$i$i58 = $25;$$036$i$i$i57 = $25;
      } else {
       $$0$i$i$i$i56 = $23;$$024$i$i$i$i55 = $290;
       while(1) {
        $292 = ((($$024$i$i$i$i55)) + 16|0);
        $293 = HEAP32[$292>>2]|0;
        $294 = ($287>>>0)<($293>>>0);
        if ($294) {
         $295 = HEAP32[$$024$i$i$i$i55>>2]|0;
         $296 = ($295|0)==(0|0);
         if ($296) {
          label = 133;
          break;
         } else {
          $$0$ph$i$i$i$i53 = $$024$i$i$i$i55;$$in$i$i$i$i52 = $295;
         }
        } else {
         $297 = ($293>>>0)<($287>>>0);
         if (!($297)) {
          label = 137;
          break;
         }
         $298 = ((($$024$i$i$i$i55)) + 4|0);
         $299 = HEAP32[$298>>2]|0;
         $300 = ($299|0)==(0|0);
         if ($300) {
          label = 136;
          break;
         } else {
          $$0$ph$i$i$i$i53 = $298;$$in$i$i$i$i52 = $299;
         }
        }
        $$0$i$i$i$i56 = $$0$ph$i$i$i$i53;$$024$i$i$i$i55 = $$in$i$i$i$i52;
       }
       if ((label|0) == 133) {
        label = 0;
        $$025$i$i$i$i58 = $$024$i$i$i$i55;$$036$i$i$i57 = $$024$i$i$i$i55;
        break;
       }
       else if ((label|0) == 136) {
        label = 0;
        $$025$i$i$i$i58 = $298;$$036$i$i$i57 = $$024$i$i$i$i55;
        break;
       }
       else if ((label|0) == 137) {
        label = 0;
        $$025$i$i$i$i58 = $$0$i$i$i$i56;$$036$i$i$i57 = $$024$i$i$i$i55;
        break;
       }
      }
     } while(0);
     $301 = HEAP32[$$025$i$i$i$i58>>2]|0;
     $302 = ($301|0)==(0|0);
     if ($302) {
      __THREW__ = 0;
      $303 = (invoke_ii(3276,20)|0);
      $304 = __THREW__; __THREW__ = 0;
      $305 = $304&1;
      if ($305) {
       break;
      }
      $306 = ((($303)) + 16|0);
      HEAP32[$306>>2] = $289;
      HEAP32[$303>>2] = 0;
      $307 = ((($303)) + 4|0);
      HEAP32[$307>>2] = 0;
      $308 = ((($303)) + 8|0);
      HEAP32[$308>>2] = $$036$i$i$i57;
      HEAP32[$$025$i$i$i$i58>>2] = $303;
      $309 = HEAP32[$2>>2]|0;
      $310 = HEAP32[$309>>2]|0;
      $311 = ($310|0)==(0|0);
      if ($311) {
       $314 = $303;
      } else {
       $312 = $310;
       HEAP32[$2>>2] = $312;
       $$pre$i$i$i$i61 = HEAP32[$$025$i$i$i$i58>>2]|0;
       $314 = $$pre$i$i$i$i61;
      }
      $313 = HEAP32[$23>>2]|0;
      __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($313,$314);
      $315 = HEAP32[$24>>2]|0;
      $316 = (($315) + 1)|0;
      HEAP32[$24>>2] = $316;
      $$pre369 = HEAP32[$242>>2]|0;
      $319 = $$pre369;$466 = $316;
     } else {
      $319 = $464;$466 = $463;
     }
    }
    $317 = ((($$sroa$0182$0311)) + 4|0);
    $318 = ($317|0)==($319|0);
    if ($318) {
     $283 = $466;
     break L182;
    } else {
     $$sroa$0182$0311 = $317;$463 = $466;$464 = $319;
    }
   }
   $320 = ___cxa_find_matching_catch_2()|0;
   $321 = tempRet0;
   $$6 = $321;$$646 = $320;
   $450 = HEAP32[$25>>2]|0;
   __ZNSt3__26__treeIPN3osg12BufferObjectENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($2,$450);
   ___resumeException($$646|0);
   // unreachable;
  }
 } while(0);
 $284 = ($283|0)==(0);
 do {
  if (!($284)) {
   $322 = HEAP32[$2>>2]|0;
   $323 = ($322|0)==($25|0);
   L212: do {
    if (!($323)) {
     $$sroa$0169$0310 = $322;
     while(1) {
      $334 = ((($$sroa$0169$0310)) + 16|0);
      $335 = HEAP32[$334>>2]|0;
      __THREW__ = 0;
      $336 = (invoke_iii(3770,($335|0),($19|0))|0);
      $337 = __THREW__; __THREW__ = 0;
      $338 = $337&1;
      if ($338) {
       label = 152;
       break;
      }
      $339 = ($336|0)==(0|0);
      if (!($339)) {
       $340 = ((($336)) + 36|0);
       $341 = HEAP8[$340>>0]|0;
       $342 = ($341<<24>>24)==(0);
       if (!($342)) {
        __THREW__ = 0;
        invoke_vi(3771,($336|0));
        $343 = __THREW__; __THREW__ = 0;
        $344 = $343&1;
        if ($344) {
         label = 153;
         break;
        }
       }
      }
      $349 = ((($$sroa$0169$0310)) + 4|0);
      $350 = HEAP32[$349>>2]|0;
      $351 = ($350|0)==(0|0);
      do {
       if ($351) {
        $352 = ((($$sroa$0169$0310)) + 8|0);
        $353 = HEAP32[$352>>2]|0;
        $354 = HEAP32[$353>>2]|0;
        $355 = ($354|0)==($$sroa$0169$0310|0);
        if ($355) {
         $$sroa$0169$0$be = $353;
         break;
        } else {
         $360 = $352;
        }
        while(1) {
         $359 = HEAP32[$360>>2]|0;
         $361 = ((($359)) + 8|0);
         $362 = HEAP32[$361>>2]|0;
         $363 = HEAP32[$362>>2]|0;
         $364 = ($363|0)==($359|0);
         if ($364) {
          $$sroa$0169$0$be = $362;
          break;
         } else {
          $360 = $361;
         }
        }
       } else {
        $$0$i$i$i = $350;
        while(1) {
         $357 = HEAP32[$$0$i$i$i>>2]|0;
         $358 = ($357|0)==(0|0);
         if ($358) {
          break;
         } else {
          $$0$i$i$i = $357;
         }
        }
        $$sroa$0169$0$be = $$0$i$i$i;
       }
      } while(0);
      $356 = ($$sroa$0169$0$be|0)==($25|0);
      if ($356) {
       break L212;
      } else {
       $$sroa$0169$0310 = $$sroa$0169$0$be;
      }
     }
     if ((label|0) == 152) {
      $345 = ___cxa_find_matching_catch_2()|0;
      $346 = tempRet0;
      $$6 = $346;$$646 = $345;
      $450 = HEAP32[$25>>2]|0;
      __ZNSt3__26__treeIPN3osg12BufferObjectENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($2,$450);
      ___resumeException($$646|0);
      // unreachable;
     }
     else if ((label|0) == 153) {
      $347 = ___cxa_find_matching_catch_2()|0;
      $348 = tempRet0;
      $$6 = $348;$$646 = $347;
      $450 = HEAP32[$25>>2]|0;
      __ZNSt3__26__treeIPN3osg12BufferObjectENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($2,$450);
      ___resumeException($$646|0);
      // unreachable;
     }
    }
   } while(0);
   $324 = ((($3)) + 713|0);
   $325 = HEAP8[$324>>0]|0;
   $326 = ($325<<24>>24)==(0);
   if ($326) {
    $327 = ((($0)) + 184|0);
    $328 = HEAP8[$327>>0]|0;
    $329 = ($328<<24>>24)!=(0);
    $330 = ((($3)) + 711|0);
    $331 = HEAP8[$330>>0]|0;
    $332 = ($331<<24>>24)!=(0);
    $333 = $329 & $332;
    if ($333) {
     label = 160;
    }
   } else {
    label = 160;
   }
   L236: do {
    if ((label|0) == 160) {
     $365 = HEAP32[$0>>2]|0;
     $366 = ((($365)) + 232|0);
     $367 = HEAP32[$366>>2]|0;
     __THREW__ = 0;
     $368 = (invoke_iii($367|0,($0|0),($1|0))|0);
     $369 = __THREW__; __THREW__ = 0;
     $370 = $369&1;
     L238: do {
      if (!($370)) {
       $371 = ((($0)) + 200|0);
       $372 = ((($0)) + 204|0);
       $373 = HEAP32[$372>>2]|0;
       $374 = HEAP32[$371>>2]|0;
       $375 = (($373) - ($374))|0;
       $376 = $375 >> 2;
       $377 = ($376>>>0)>($19>>>0);
       L240: do {
        if (!($377)) {
         $378 = (($19) + 1)|0;
         $379 = ($378>>>0)>($376>>>0);
         $380 = $374;
         $381 = $373;
         if ($379) {
          $382 = (($378) - ($376))|0;
          __THREW__ = 0;
          invoke_vii(3772,($371|0),($382|0));
          $383 = __THREW__; __THREW__ = 0;
          $384 = $383&1;
          if ($384) {
           break L238;
          } else {
           break;
          }
         }
         $385 = ($378>>>0)<($376>>>0);
         if (!($385)) {
          break;
         }
         $386 = (($380) + ($378<<2)|0);
         $387 = ($381|0)==($386|0);
         if ($387) {
          break;
         } else {
          $389 = $381;
         }
         L246: while(1) {
          $388 = ((($389)) + -4|0);
          HEAP32[$372>>2] = $388;
          $390 = HEAP32[$388>>2]|0;
          $391 = ($390|0)==(0|0);
          do {
           if (!($391)) {
            $392 = ((($390)) + 8|0);
            $393 = HEAP32[$392>>2]|0;HEAP32[$392>>2] = (($393-1)|0);
            $394 = ($393|0)==(1);
            if (!($394)) {
             break;
            }
            __THREW__ = 0;
            invoke_viii(3262,($390|0),1,1);
            $395 = __THREW__; __THREW__ = 0;
            $396 = $395&1;
            if ($396) {
             break L246;
            }
           }
          } while(0);
          HEAP32[$388>>2] = 0;
          $397 = HEAP32[$372>>2]|0;
          $398 = ($397|0)==($386|0);
          if ($398) {
           break L240;
          } else {
           $389 = $397;
          }
         }
         $399 = ___cxa_find_matching_catch_2()|0;
         $400 = tempRet0;
         ___cxa_call_unexpected(($399|0));
         // unreachable;
        }
       } while(0);
       $401 = HEAP32[$371>>2]|0;
       $402 = (($401) + ($19<<2)|0);
       $403 = HEAP32[$402>>2]|0;
       $404 = ($403|0)==($368|0);
       do {
        if (!($404)) {
         HEAP32[$402>>2] = $368;
         $405 = ($368|0)==(0|0);
         if (!($405)) {
          $406 = ((($368)) + 8|0);
          $407 = HEAP32[$406>>2]|0;HEAP32[$406>>2] = (($407+1)|0);
         }
         $408 = ($403|0)==(0|0);
         if ($408) {
          break;
         }
         $409 = ((($403)) + 8|0);
         $410 = HEAP32[$409>>2]|0;HEAP32[$409>>2] = (($410-1)|0);
         $411 = ($410|0)==(1);
         if (!($411)) {
          break;
         }
         __THREW__ = 0;
         invoke_viii(3262,($403|0),1,1);
         $412 = __THREW__; __THREW__ = 0;
         $413 = $412&1;
         if ($413) {
          break L238;
         }
        }
       } while(0);
       $414 = ((($3)) + 132|0);
       HEAP32[$414>>2] = $368;
       $415 = ((($368)) + 24|0);
       $416 = HEAP32[$415>>2]|0;
       $417 = ((($3)) + 704|0);
       $418 = HEAP32[$417>>2]|0;
       $419 = ($418|0)==($416|0);
       do {
        if ($419) {
         label = 180;
        } else {
         $420 = HEAP32[$20>>2]|0;
         $421 = ((($420)) + 1500|0);
         $422 = HEAP32[$421>>2]|0;
         __THREW__ = 0;
         invoke_vi($422|0,($416|0));
         $423 = __THREW__; __THREW__ = 0;
         $424 = $423&1;
         if ($424) {
          break;
         }
         HEAP32[$417>>2] = $416;
         label = 180;
        }
       } while(0);
       do {
        if ((label|0) == 180) {
         __THREW__ = 0;
         invoke_vii(3773,($0|0),($1|0));
         $425 = __THREW__; __THREW__ = 0;
         $426 = $425&1;
         if ($426) {
          break;
         }
         $427 = HEAP32[$417>>2]|0;
         $428 = ($427|0)==(0);
         if (!($428)) {
          $429 = HEAP32[$20>>2]|0;
          $430 = ((($429)) + 1500|0);
          $431 = HEAP32[$430>>2]|0;
          __THREW__ = 0;
          invoke_vi($431|0,0);
          $432 = __THREW__; __THREW__ = 0;
          $433 = $432&1;
          if ($433) {
           break;
          }
          HEAP32[$417>>2] = 0;
         }
         $434 = ((($3)) + 128|0);
         $435 = HEAP32[$434>>2]|0;
         HEAP32[$414>>2] = $435;
         break L236;
        }
       } while(0);
       $438 = ___cxa_find_matching_catch_2()|0;
       $439 = tempRet0;
       $440 = ((($3)) + 128|0);
       $441 = HEAP32[$440>>2]|0;
       HEAP32[$414>>2] = $441;
       $$6 = $439;$$646 = $438;
       $450 = HEAP32[$25>>2]|0;
       __ZNSt3__26__treeIPN3osg12BufferObjectENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($2,$450);
       ___resumeException($$646|0);
       // unreachable;
      }
     } while(0);
     $436 = ___cxa_find_matching_catch_2()|0;
     $437 = tempRet0;
     $$6 = $437;$$646 = $436;
     $450 = HEAP32[$25>>2]|0;
     __ZNSt3__26__treeIPN3osg12BufferObjectENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($2,$450);
     ___resumeException($$646|0);
     // unreachable;
    }
   } while(0);
   $442 = ((($21)) + 724|0);
   $443 = HEAP32[$442>>2]|0;
   __THREW__ = 0;
   invoke_vii($443|0,34962,0);
   $444 = __THREW__; __THREW__ = 0;
   $445 = $444&1;
   if (!($445)) {
    $446 = HEAP32[$442>>2]|0;
    __THREW__ = 0;
    invoke_vii($446|0,34963,0);
    $447 = __THREW__; __THREW__ = 0;
    $448 = $447&1;
    if (!($448)) {
     break;
    }
   }
   $44 = ___cxa_find_matching_catch_2()|0;
   $45 = tempRet0;
   $$6 = $45;$$646 = $44;
   $450 = HEAP32[$25>>2]|0;
   __ZNSt3__26__treeIPN3osg12BufferObjectENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($2,$450);
   ___resumeException($$646|0);
   // unreachable;
  }
 } while(0);
 $449 = HEAP32[$25>>2]|0;
 __ZNSt3__26__treeIPN3osg12BufferObjectENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($2,$449);
 STACKTOP = sp;return;
}
function __ZNK3osg8Geometry22createVertexArrayStateERNS_10RenderInfoE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$1>>2]|0;
 $3 = (__Znwj(108)|0);
 __THREW__ = 0;
 invoke_vii(3752,($3|0),($2|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $9 = ___cxa_find_matching_catch_2()|0;
  $10 = tempRet0;
  __ZdlPv($3);
  ___resumeException($9|0);
  // unreachable;
 }
 $6 = ((($0)) + 228|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  __ZN3osg16VertexArrayState27assignVertexArrayDispatcherEv($3);
 }
 $11 = ((($0)) + 236|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0|0);
 if (!($13)) {
  __ZN3osg16VertexArrayState26assignColorArrayDispatcherEv($3);
 }
 $14 = ((($0)) + 232|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0|0);
 if (!($16)) {
  __ZN3osg16VertexArrayState27assignNormalArrayDispatcherEv($3);
 }
 $17 = ((($0)) + 240|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ($18|0)==(0|0);
 if (!($19)) {
  __ZN3osg16VertexArrayState35assignSecondaryColorArrayDispatcherEv($3);
 }
 $20 = ((($0)) + 244|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0|0);
 if (!($22)) {
  __ZN3osg16VertexArrayState29assignFogCoordArrayDispatcherEv($3);
 }
 $23 = ((($0)) + 248|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ((($0)) + 252|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($24|0)==($26|0);
 if (!($27)) {
  $28 = $24;
  $29 = $26;
  $30 = (($29) - ($28))|0;
  $31 = $30 >> 2;
  __ZN3osg16VertexArrayState29assignTexCoordArrayDispatcherEj($3,$31);
 }
 $32 = ((($0)) + 260|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ((($0)) + 264|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = ($33|0)==($35|0);
 if (!($36)) {
  $37 = $33;
  $38 = $35;
  $39 = (($38) - ($37))|0;
  $40 = $39 >> 2;
  __ZN3osg16VertexArrayState33assignVertexAttribArrayDispatcherEj($3,$40);
 }
 $41 = ((($2)) + 713|0);
 $42 = HEAP8[$41>>0]|0;
 $43 = ($42<<24>>24)==(0);
 if ($43) {
  $44 = ((($0)) + 184|0);
  $45 = HEAP8[$44>>0]|0;
  $46 = ($45<<24>>24)!=(0);
  $47 = ((($2)) + 711|0);
  $48 = HEAP8[$47>>0]|0;
  $49 = ($48<<24>>24)!=(0);
  $50 = $46 & $49;
  if (!($50)) {
   return ($3|0);
  }
 }
 __ZN3osg16VertexArrayState25generateVertexArrayObjectEv($3);
 return ($3|0);
}
function __ZNK3osg8Geometry18drawImplementationERNS_10RenderInfoE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = ((($0)) + 272|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)==(0);
 if (!($5)) {
  $6 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
  if (!($6)) {
   STACKTOP = sp;return;
  }
  $7 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
  $8 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($7,128392,107)|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ((($9)) + -12|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (($8) + ($11)|0);
  __ZNKSt3__28ios_base6getlocEv($2,$12);
  __THREW__ = 0;
  $13 = (invoke_iii(3255,($2|0),(215188|0))|0);
  $14 = __THREW__; __THREW__ = 0;
  $15 = $14&1;
  if (!($15)) {
   $16 = HEAP32[$13>>2]|0;
   $17 = ((($16)) + 28|0);
   $18 = HEAP32[$17>>2]|0;
   __THREW__ = 0;
   $19 = (invoke_iii($18|0,($13|0),10)|0);
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if (!($21)) {
    __ZNSt3__26localeD2Ev($2);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($8,$19)|0);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($8)|0);
    STACKTOP = sp;return;
   }
  }
  $22 = ___cxa_find_matching_catch_2()|0;
  $23 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3263,($2|0));
  $24 = __THREW__; __THREW__ = 0;
  $25 = $24&1;
  if ($25) {
   $26 = ___cxa_find_matching_catch_3(0|0)|0;
   $27 = tempRet0;
   ___clang_call_terminate($26);
   // unreachable;
  } else {
   ___resumeException($22|0);
   // unreachable;
  }
 }
 $28 = HEAP32[$1>>2]|0;
 $29 = ((($28)) + 344|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ($30|0)==(2);
 if ($31) {
  (__ZNK3osg5State13checkGLErrorsEPKcS2_($28,128500,0)|0);
  __ZNK3osg8Geometry30drawVertexArraysImplementationERNS_10RenderInfoE($0,$1);
  (__ZNK3osg5State13checkGLErrorsEPKcS2_($28,128540,0)|0);
 } else {
  __ZNK3osg8Geometry30drawVertexArraysImplementationERNS_10RenderInfoE($0,$1);
 }
 __ZNK3osg8Geometry28drawPrimitivesImplementationERNS_10RenderInfoE($0,$1);
 $32 = ((($0)) + 182|0);
 $33 = HEAP8[$32>>0]|0;
 $34 = ($33<<24>>24)==(0);
 if ($34) {
  $45 = 0;
 } else {
  $35 = ((($0)) + 183|0);
  $36 = HEAP8[$35>>0]|0;
  $37 = ($36<<24>>24)!=(0);
  $45 = $37;
 }
 $38 = ((($28)) + 712|0);
 $39 = HEAP8[$38>>0]|0;
 $40 = ($39<<24>>24)==(0);
 if ($40) {
  $41 = ((($28)) + 710|0);
  $42 = HEAP8[$41>>0]|0;
  $43 = ($42<<24>>24)!=(0);
  $44 = $45 & $43;
  if ($44) {
   label = 16;
  }
 } else {
  label = 16;
 }
 if ((label|0) == 16) {
  $46 = ((($28)) + 713|0);
  $47 = HEAP8[$46>>0]|0;
  $48 = ($47<<24>>24)==(0);
  if ($48) {
   $49 = ((($0)) + 184|0);
   $50 = HEAP8[$49>>0]|0;
   $51 = ($50<<24>>24)!=(0);
   $52 = ((($28)) + 711|0);
   $53 = HEAP8[$52>>0]|0;
   $54 = ($53<<24>>24)!=(0);
   $55 = $51 & $54;
   if (!($55)) {
    $56 = ((($28)) + 132|0);
    $57 = HEAP32[$56>>2]|0;
    $58 = ((($57)) + 96|0);
    $59 = HEAP32[$58>>2]|0;
    $60 = ($59|0)==(0|0);
    if (!($60)) {
     $61 = ((($57)) + 16|0);
     $62 = HEAP32[$61>>2]|0;
     $63 = ((($62)) + 724|0);
     $64 = HEAP32[$63>>2]|0;
     FUNCTION_TABLE_vii[$64 & 8191](34962,0);
     HEAP32[$58>>2] = 0;
    }
    $65 = ((($57)) + 100|0);
    $66 = HEAP32[$65>>2]|0;
    $67 = ($66|0)==(0|0);
    if (!($67)) {
     $68 = ((($57)) + 16|0);
     $69 = HEAP32[$68>>2]|0;
     $70 = ((($69)) + 724|0);
     $71 = HEAP32[$70>>2]|0;
     FUNCTION_TABLE_vii[$71 & 8191](34963,0);
     HEAP32[$65>>2] = 0;
    }
   }
  }
 }
 if (!($31)) {
  STACKTOP = sp;return;
 }
 (__ZNK3osg5State13checkGLErrorsEPKcS2_($28,128598,0)|0);
 STACKTOP = sp;return;
}
function __ZNK3osg8Geometry8supportsERKNS_8Drawable16AttributeFunctorE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 1;
}
function __ZN3osg8Geometry6acceptERNS_8Drawable16AttributeFunctorE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$01641 = 0, $$040 = 0, $$pre = 0, $$pre43 = 0, $$pre44 = 0, $$pre45 = 0, $$sink19$index = 0, $$sink19$index4 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp + 12|0;
 $3 = sp;
 HEAP32[$3>>2] = (59984);
 $4 = ((($3)) + 4|0);
 HEAP32[$4>>2] = $1;
 $5 = ((($3)) + 8|0);
 HEAP32[$5>>2] = 0;
 $6 = ((($0)) + 228|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 L1: do {
  if ($8) {
   $16 = ((($0)) + 260|0);
   $17 = ((($0)) + 264|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = HEAP32[$16>>2]|0;
   $20 = ($18|0)==($19|0);
   if ($20) {
    label = 20;
   } else {
    __THREW__ = 0;
    $21 = (invoke_ii(3265,4)|0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if (!($23)) {
     do {
      if ($21) {
       __THREW__ = 0;
       $24 = (invoke_ii(3266,4)|0);
       $25 = __THREW__; __THREW__ = 0;
       $26 = $25&1;
       if ($26) {
        break L1;
       }
       __THREW__ = 0;
       $27 = (invoke_iiii(3267,($24|0),(128284|0),70)|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if ($29) {
        break L1;
       }
       $30 = HEAP32[$27>>2]|0;
       $31 = ((($30)) + -12|0);
       $32 = HEAP32[$31>>2]|0;
       $33 = (($27) + ($32)|0);
       __THREW__ = 0;
       invoke_vii(3257,($2|0),($33|0));
       $34 = __THREW__; __THREW__ = 0;
       $35 = $34&1;
       if ($35) {
        break L1;
       }
       __THREW__ = 0;
       $36 = (invoke_iii(3255,($2|0),(215188|0))|0);
       $37 = __THREW__; __THREW__ = 0;
       $38 = $37&1;
       if (!($38)) {
        $39 = HEAP32[$36>>2]|0;
        $40 = ((($39)) + 28|0);
        $41 = HEAP32[$40>>2]|0;
        __THREW__ = 0;
        $42 = (invoke_iii($41|0,($36|0),10)|0);
        $43 = __THREW__; __THREW__ = 0;
        $44 = $43&1;
        if (!($44)) {
         __THREW__ = 0;
         invoke_vi(3263,($2|0));
         $51 = __THREW__; __THREW__ = 0;
         $52 = $51&1;
         if ($52) {
          break L1;
         }
         __THREW__ = 0;
         (invoke_iii(3268,($27|0),($42|0))|0);
         $53 = __THREW__; __THREW__ = 0;
         $54 = $53&1;
         if ($54) {
          break L1;
         }
         __THREW__ = 0;
         (invoke_ii(3269,($27|0))|0);
         $55 = __THREW__; __THREW__ = 0;
         $56 = $55&1;
         if ($56) {
          break L1;
         } else {
          break;
         }
        }
       }
       $45 = ___cxa_find_matching_catch_2()|0;
       $46 = tempRet0;
       __THREW__ = 0;
       invoke_vi(3263,($2|0));
       $47 = __THREW__; __THREW__ = 0;
       $48 = $47&1;
       if ($48) {
        $49 = ___cxa_find_matching_catch_3(0|0)|0;
        $50 = tempRet0;
        ___clang_call_terminate($49);
        // unreachable;
       }
       $$sink19$index = $45;$$sink19$index4 = $46;
       ___resumeException($$sink19$index|0);
       // unreachable;
      }
     } while(0);
     $57 = HEAP32[$16>>2]|0;
     $58 = HEAP32[$57>>2]|0;
     $59 = ($58|0)==(0|0);
     if ($59) {
      label = 20;
     } else {
      HEAP32[$5>>2] = 0;
      $60 = HEAP32[$58>>2]|0;
      $61 = ((($60)) + 172|0);
      $62 = HEAP32[$61>>2]|0;
      __THREW__ = 0;
      invoke_vii($62|0,($58|0),($3|0));
      $63 = __THREW__; __THREW__ = 0;
      $64 = $63&1;
      if (!($64)) {
       label = 20;
      }
     }
    }
   }
  } else {
   HEAP32[$5>>2] = 0;
   $9 = HEAP32[$7>>2]|0;
   $10 = ((($9)) + 172|0);
   $11 = HEAP32[$10>>2]|0;
   __THREW__ = 0;
   invoke_vii($11|0,($7|0),($3|0));
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    label = 20;
   }
  }
 } while(0);
 do {
  if ((label|0) == 20) {
   $65 = ((($0)) + 232|0);
   $66 = HEAP32[$65>>2]|0;
   $67 = ($66|0)==(0|0);
   if (!($67)) {
    HEAP32[$5>>2] = 2;
    $68 = HEAP32[$66>>2]|0;
    $69 = ((($68)) + 172|0);
    $70 = HEAP32[$69>>2]|0;
    __THREW__ = 0;
    invoke_vii($70|0,($66|0),($3|0));
    $71 = __THREW__; __THREW__ = 0;
    $72 = $71&1;
    if ($72) {
     break;
    }
   }
   $73 = ((($0)) + 236|0);
   $74 = HEAP32[$73>>2]|0;
   $75 = ($74|0)==(0|0);
   if (!($75)) {
    HEAP32[$5>>2] = 3;
    $76 = HEAP32[$74>>2]|0;
    $77 = ((($76)) + 172|0);
    $78 = HEAP32[$77>>2]|0;
    __THREW__ = 0;
    invoke_vii($78|0,($74|0),($3|0));
    $79 = __THREW__; __THREW__ = 0;
    $80 = $79&1;
    if ($80) {
     break;
    }
   }
   $81 = ((($0)) + 240|0);
   $82 = HEAP32[$81>>2]|0;
   $83 = ($82|0)==(0|0);
   if (!($83)) {
    HEAP32[$5>>2] = 4;
    $84 = HEAP32[$82>>2]|0;
    $85 = ((($84)) + 172|0);
    $86 = HEAP32[$85>>2]|0;
    __THREW__ = 0;
    invoke_vii($86|0,($82|0),($3|0));
    $87 = __THREW__; __THREW__ = 0;
    $88 = $87&1;
    if ($88) {
     break;
    }
   }
   $89 = ((($0)) + 244|0);
   $90 = HEAP32[$89>>2]|0;
   $91 = ($90|0)==(0|0);
   if (!($91)) {
    HEAP32[$5>>2] = 5;
    $92 = HEAP32[$90>>2]|0;
    $93 = ((($92)) + 172|0);
    $94 = HEAP32[$93>>2]|0;
    __THREW__ = 0;
    invoke_vii($94|0,($90|0),($3|0));
    $95 = __THREW__; __THREW__ = 0;
    $96 = $95&1;
    if ($96) {
     break;
    }
   }
   $97 = ((($0)) + 248|0);
   $98 = ((($0)) + 252|0);
   $99 = HEAP32[$98>>2]|0;
   $100 = HEAP32[$97>>2]|0;
   $101 = ($99|0)==($100|0);
   L37: do {
    if (!($101)) {
     $$01641 = 0;$107 = $100;$144 = $99;
     while(1) {
      $108 = $107;
      $109 = (($108) + ($$01641<<2)|0);
      $110 = HEAP32[$109>>2]|0;
      $111 = ($110|0)==(0|0);
      if ($111) {
       $120 = $107;$121 = $144;
      } else {
       $112 = (($$01641) + 8)|0;
       HEAP32[$5>>2] = $112;
       $113 = HEAP32[$110>>2]|0;
       $114 = ((($113)) + 172|0);
       $115 = HEAP32[$114>>2]|0;
       __THREW__ = 0;
       invoke_vii($115|0,($110|0),($3|0));
       $116 = __THREW__; __THREW__ = 0;
       $117 = $116&1;
       if ($117) {
        break;
       }
       $$pre = HEAP32[$98>>2]|0;
       $$pre43 = HEAP32[$97>>2]|0;
       $120 = $$pre43;$121 = $$pre;
      }
      $118 = (($$01641) + 1)|0;
      $119 = (($121) - ($120))|0;
      $122 = $119 >> 2;
      $123 = ($118>>>0)<($122>>>0);
      if ($123) {
       $$01641 = $118;$107 = $120;$144 = $121;
      } else {
       break L37;
      }
     }
     $124 = ___cxa_find_matching_catch_2()|0;
     $125 = tempRet0;
     $$sink19$index = $124;$$sink19$index4 = $125;
     ___resumeException($$sink19$index|0);
     // unreachable;
    }
   } while(0);
   $102 = ((($0)) + 260|0);
   $103 = ((($0)) + 264|0);
   $104 = HEAP32[$103>>2]|0;
   $105 = HEAP32[$102>>2]|0;
   $106 = ($104|0)==($105|0);
   if ($106) {
    STACKTOP = sp;return;
   }
   $$040 = 0;$126 = $105;$145 = $104;
   while(1) {
    $127 = $126;
    $128 = (($127) + ($$040<<2)|0);
    $129 = HEAP32[$128>>2]|0;
    $130 = ($129|0)==(0|0);
    if ($130) {
     $138 = $126;$139 = $145;
    } else {
     HEAP32[$5>>2] = $$040;
     $131 = HEAP32[$129>>2]|0;
     $132 = ((($131)) + 172|0);
     $133 = HEAP32[$132>>2]|0;
     __THREW__ = 0;
     invoke_vii($133|0,($129|0),($3|0));
     $134 = __THREW__; __THREW__ = 0;
     $135 = $134&1;
     if ($135) {
      break;
     }
     $$pre44 = HEAP32[$103>>2]|0;
     $$pre45 = HEAP32[$102>>2]|0;
     $138 = $$pre45;$139 = $$pre44;
    }
    $136 = (($$040) + 1)|0;
    $137 = (($139) - ($138))|0;
    $140 = $137 >> 2;
    $141 = ($136>>>0)<($140>>>0);
    if ($141) {
     $$040 = $136;$126 = $138;$145 = $139;
    } else {
     label = 37;
     break;
    }
   }
   if ((label|0) == 37) {
    STACKTOP = sp;return;
   }
   $142 = ___cxa_find_matching_catch_2()|0;
   $143 = tempRet0;
   $$sink19$index = $142;$$sink19$index4 = $143;
   ___resumeException($$sink19$index|0);
   // unreachable;
  }
 } while(0);
 $14 = ___cxa_find_matching_catch_2()|0;
 $15 = tempRet0;
 $$sink19$index = $14;$$sink19$index4 = $15;
 ___resumeException($$sink19$index|0);
 // unreachable;
}
function __ZNK3osg8Geometry8supportsERKNS_8Drawable21ConstAttributeFunctorE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 1;
}
function __ZNK3osg8Geometry6acceptERNS_8Drawable21ConstAttributeFunctorE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$01641 = 0, $$040 = 0, $$pre = 0, $$pre43 = 0, $$pre44 = 0, $$pre45 = 0, $$sink19$index = 0, $$sink19$index4 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp + 12|0;
 $3 = sp;
 HEAP32[$3>>2] = (59820);
 $4 = ((($3)) + 4|0);
 HEAP32[$4>>2] = $1;
 $5 = ((($3)) + 8|0);
 HEAP32[$5>>2] = 0;
 $6 = ((($0)) + 228|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 L1: do {
  if ($8) {
   $16 = ((($0)) + 260|0);
   $17 = ((($0)) + 264|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = HEAP32[$16>>2]|0;
   $20 = ($18|0)==($19|0);
   if ($20) {
    label = 20;
   } else {
    __THREW__ = 0;
    $21 = (invoke_ii(3265,4)|0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if (!($23)) {
     do {
      if ($21) {
       __THREW__ = 0;
       $24 = (invoke_ii(3266,4)|0);
       $25 = __THREW__; __THREW__ = 0;
       $26 = $25&1;
       if ($26) {
        break L1;
       }
       __THREW__ = 0;
       $27 = (invoke_iiii(3267,($24|0),(128140|0),75)|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if ($29) {
        break L1;
       }
       $30 = HEAP32[$27>>2]|0;
       $31 = ((($30)) + -12|0);
       $32 = HEAP32[$31>>2]|0;
       $33 = (($27) + ($32)|0);
       __THREW__ = 0;
       invoke_vii(3257,($2|0),($33|0));
       $34 = __THREW__; __THREW__ = 0;
       $35 = $34&1;
       if ($35) {
        break L1;
       }
       __THREW__ = 0;
       $36 = (invoke_iii(3255,($2|0),(215188|0))|0);
       $37 = __THREW__; __THREW__ = 0;
       $38 = $37&1;
       if (!($38)) {
        $39 = HEAP32[$36>>2]|0;
        $40 = ((($39)) + 28|0);
        $41 = HEAP32[$40>>2]|0;
        __THREW__ = 0;
        $42 = (invoke_iii($41|0,($36|0),10)|0);
        $43 = __THREW__; __THREW__ = 0;
        $44 = $43&1;
        if (!($44)) {
         __THREW__ = 0;
         invoke_vi(3263,($2|0));
         $51 = __THREW__; __THREW__ = 0;
         $52 = $51&1;
         if ($52) {
          break L1;
         }
         __THREW__ = 0;
         (invoke_iii(3268,($27|0),($42|0))|0);
         $53 = __THREW__; __THREW__ = 0;
         $54 = $53&1;
         if ($54) {
          break L1;
         }
         __THREW__ = 0;
         (invoke_ii(3269,($27|0))|0);
         $55 = __THREW__; __THREW__ = 0;
         $56 = $55&1;
         if ($56) {
          break L1;
         } else {
          break;
         }
        }
       }
       $45 = ___cxa_find_matching_catch_2()|0;
       $46 = tempRet0;
       __THREW__ = 0;
       invoke_vi(3263,($2|0));
       $47 = __THREW__; __THREW__ = 0;
       $48 = $47&1;
       if ($48) {
        $49 = ___cxa_find_matching_catch_3(0|0)|0;
        $50 = tempRet0;
        ___clang_call_terminate($49);
        // unreachable;
       }
       $$sink19$index = $45;$$sink19$index4 = $46;
       ___resumeException($$sink19$index|0);
       // unreachable;
      }
     } while(0);
     $57 = HEAP32[$16>>2]|0;
     $58 = HEAP32[$57>>2]|0;
     $59 = ($58|0)==(0|0);
     if ($59) {
      label = 20;
     } else {
      HEAP32[$5>>2] = 0;
      $60 = HEAP32[$58>>2]|0;
      $61 = ((($60)) + 176|0);
      $62 = HEAP32[$61>>2]|0;
      __THREW__ = 0;
      invoke_vii($62|0,($58|0),($3|0));
      $63 = __THREW__; __THREW__ = 0;
      $64 = $63&1;
      if (!($64)) {
       label = 20;
      }
     }
    }
   }
  } else {
   HEAP32[$5>>2] = 0;
   $9 = HEAP32[$7>>2]|0;
   $10 = ((($9)) + 176|0);
   $11 = HEAP32[$10>>2]|0;
   __THREW__ = 0;
   invoke_vii($11|0,($7|0),($3|0));
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    label = 20;
   }
  }
 } while(0);
 do {
  if ((label|0) == 20) {
   $65 = ((($0)) + 232|0);
   $66 = HEAP32[$65>>2]|0;
   $67 = ($66|0)==(0|0);
   if (!($67)) {
    HEAP32[$5>>2] = 2;
    $68 = HEAP32[$66>>2]|0;
    $69 = ((($68)) + 176|0);
    $70 = HEAP32[$69>>2]|0;
    __THREW__ = 0;
    invoke_vii($70|0,($66|0),($3|0));
    $71 = __THREW__; __THREW__ = 0;
    $72 = $71&1;
    if ($72) {
     break;
    }
   }
   $73 = ((($0)) + 236|0);
   $74 = HEAP32[$73>>2]|0;
   $75 = ($74|0)==(0|0);
   if (!($75)) {
    HEAP32[$5>>2] = 3;
    $76 = HEAP32[$74>>2]|0;
    $77 = ((($76)) + 176|0);
    $78 = HEAP32[$77>>2]|0;
    __THREW__ = 0;
    invoke_vii($78|0,($74|0),($3|0));
    $79 = __THREW__; __THREW__ = 0;
    $80 = $79&1;
    if ($80) {
     break;
    }
   }
   $81 = ((($0)) + 240|0);
   $82 = HEAP32[$81>>2]|0;
   $83 = ($82|0)==(0|0);
   if (!($83)) {
    HEAP32[$5>>2] = 4;
    $84 = HEAP32[$82>>2]|0;
    $85 = ((($84)) + 176|0);
    $86 = HEAP32[$85>>2]|0;
    __THREW__ = 0;
    invoke_vii($86|0,($82|0),($3|0));
    $87 = __THREW__; __THREW__ = 0;
    $88 = $87&1;
    if ($88) {
     break;
    }
   }
   $89 = ((($0)) + 244|0);
   $90 = HEAP32[$89>>2]|0;
   $91 = ($90|0)==(0|0);
   if (!($91)) {
    HEAP32[$5>>2] = 5;
    $92 = HEAP32[$90>>2]|0;
    $93 = ((($92)) + 176|0);
    $94 = HEAP32[$93>>2]|0;
    __THREW__ = 0;
    invoke_vii($94|0,($90|0),($3|0));
    $95 = __THREW__; __THREW__ = 0;
    $96 = $95&1;
    if ($96) {
     break;
    }
   }
   $97 = ((($0)) + 248|0);
   $98 = ((($0)) + 252|0);
   $99 = HEAP32[$98>>2]|0;
   $100 = HEAP32[$97>>2]|0;
   $101 = ($99|0)==($100|0);
   L37: do {
    if (!($101)) {
     $$01641 = 0;$107 = $100;$144 = $99;
     while(1) {
      $108 = $107;
      $109 = (($108) + ($$01641<<2)|0);
      $110 = HEAP32[$109>>2]|0;
      $111 = ($110|0)==(0|0);
      if ($111) {
       $120 = $107;$121 = $144;
      } else {
       $112 = (($$01641) + 8)|0;
       HEAP32[$5>>2] = $112;
       $113 = HEAP32[$110>>2]|0;
       $114 = ((($113)) + 176|0);
       $115 = HEAP32[$114>>2]|0;
       __THREW__ = 0;
       invoke_vii($115|0,($110|0),($3|0));
       $116 = __THREW__; __THREW__ = 0;
       $117 = $116&1;
       if ($117) {
        break;
       }
       $$pre = HEAP32[$98>>2]|0;
       $$pre43 = HEAP32[$97>>2]|0;
       $120 = $$pre43;$121 = $$pre;
      }
      $118 = (($$01641) + 1)|0;
      $119 = (($121) - ($120))|0;
      $122 = $119 >> 2;
      $123 = ($118>>>0)<($122>>>0);
      if ($123) {
       $$01641 = $118;$107 = $120;$144 = $121;
      } else {
       break L37;
      }
     }
     $124 = ___cxa_find_matching_catch_2()|0;
     $125 = tempRet0;
     $$sink19$index = $124;$$sink19$index4 = $125;
     ___resumeException($$sink19$index|0);
     // unreachable;
    }
   } while(0);
   $102 = ((($0)) + 260|0);
   $103 = ((($0)) + 264|0);
   $104 = HEAP32[$103>>2]|0;
   $105 = HEAP32[$102>>2]|0;
   $106 = ($104|0)==($105|0);
   if ($106) {
    STACKTOP = sp;return;
   }
   $$040 = 0;$126 = $105;$145 = $104;
   while(1) {
    $127 = $126;
    $128 = (($127) + ($$040<<2)|0);
    $129 = HEAP32[$128>>2]|0;
    $130 = ($129|0)==(0|0);
    if ($130) {
     $138 = $126;$139 = $145;
    } else {
     HEAP32[$5>>2] = $$040;
     $131 = HEAP32[$129>>2]|0;
     $132 = ((($131)) + 176|0);
     $133 = HEAP32[$132>>2]|0;
     __THREW__ = 0;
     invoke_vii($133|0,($129|0),($3|0));
     $134 = __THREW__; __THREW__ = 0;
     $135 = $134&1;
     if ($135) {
      break;
     }
     $$pre44 = HEAP32[$103>>2]|0;
     $$pre45 = HEAP32[$102>>2]|0;
     $138 = $$pre45;$139 = $$pre44;
    }
    $136 = (($$040) + 1)|0;
    $137 = (($139) - ($138))|0;
    $140 = $137 >> 2;
    $141 = ($136>>>0)<($140>>>0);
    if ($141) {
     $$040 = $136;$126 = $138;$145 = $139;
    } else {
     label = 37;
     break;
    }
   }
   if ((label|0) == 37) {
    STACKTOP = sp;return;
   }
   $142 = ___cxa_find_matching_catch_2()|0;
   $143 = tempRet0;
   $$sink19$index = $142;$$sink19$index4 = $143;
   ___resumeException($$sink19$index|0);
   // unreachable;
  }
 } while(0);
 $14 = ___cxa_find_matching_catch_2()|0;
 $15 = tempRet0;
 $$sink19$index = $14;$$sink19$index4 = $15;
 ___resumeException($$sink19$index|0);
 // unreachable;
}
function __ZNK3osg8Geometry8supportsERKNS_16PrimitiveFunctorE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 1;
}
function __ZNK3osg8Geometry6acceptERNS_16PrimitiveFunctorE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$035 = 0, $$sroa$030$036 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $phitmp = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp + 8|0;
 $3 = sp + 4|0;
 $4 = sp;
 $5 = ((($0)) + 228|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $8 = ((($0)) + 260|0);
  $9 = ((($0)) + 264|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = HEAP32[$8>>2]|0;
  $12 = ($10|0)==($11|0);
  if ($12) {
   STACKTOP = sp;return;
  }
  $13 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
  do {
   if ($13) {
    $14 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
    $15 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($14,127913,30)|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = ((($16)) + -12|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = (($15) + ($18)|0);
    __ZNKSt3__28ios_base6getlocEv($3,$19);
    __THREW__ = 0;
    $20 = (invoke_iii(3255,($3|0),(215188|0))|0);
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if (!($22)) {
     $23 = HEAP32[$20>>2]|0;
     $24 = ((($23)) + 28|0);
     $25 = HEAP32[$24>>2]|0;
     __THREW__ = 0;
     $26 = (invoke_iii($25|0,($20|0),10)|0);
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     if (!($28)) {
      __ZNSt3__26localeD2Ev($3);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($15,$26)|0);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($15)|0);
      break;
     }
    }
    $29 = ___cxa_find_matching_catch_2()|0;
    $30 = tempRet0;
    __THREW__ = 0;
    invoke_vi(3263,($3|0));
    $31 = __THREW__; __THREW__ = 0;
    $32 = $31&1;
    if ($32) {
     $33 = ___cxa_find_matching_catch_3(0|0)|0;
     $34 = tempRet0;
     ___clang_call_terminate($33);
     // unreachable;
    } else {
     ___resumeException($29|0);
     // unreachable;
    }
   }
  } while(0);
  $35 = HEAP32[$8>>2]|0;
  $36 = HEAP32[$35>>2]|0;
  $37 = ($36|0)==(0|0);
  if ($37) {
   STACKTOP = sp;return;
  } else {
   $$035 = $36;
  }
 } else {
  $$035 = $6;
 }
 $38 = HEAP32[$$035>>2]|0;
 $39 = ((($38)) + 200|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = (FUNCTION_TABLE_ii[$40 & 8191]($$035)|0);
 $42 = ($41|0)==(0);
 if ($42) {
  STACKTOP = sp;return;
 }
 $43 = ((($0)) + 272|0);
 $44 = HEAP8[$43>>0]|0;
 $45 = ($44<<24>>24)==(0);
 if (!($45)) {
  $46 = HEAP32[$$035>>2]|0;
  $47 = ((($46)) + 128|0);
  $48 = HEAP32[$47>>2]|0;
  $49 = (FUNCTION_TABLE_ii[$48 & 8191]($$035)|0);
  $50 = ($49|0)==(0|0);
  if (!($50)) {
   $51 = (___dynamic_cast($49,26488,22736,0)|0);
   $phitmp = ($51|0)==(0|0);
   if (!($phitmp)) {
    $52 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
    if (!($52)) {
     STACKTOP = sp;return;
    }
    $53 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
    $54 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($53,127944,118)|0);
    $55 = HEAP32[$54>>2]|0;
    $56 = ((($55)) + -12|0);
    $57 = HEAP32[$56>>2]|0;
    $58 = (($54) + ($57)|0);
    __ZNKSt3__28ios_base6getlocEv($2,$58);
    __THREW__ = 0;
    $59 = (invoke_iii(3255,($2|0),(215188|0))|0);
    $60 = __THREW__; __THREW__ = 0;
    $61 = $60&1;
    if (!($61)) {
     $62 = HEAP32[$59>>2]|0;
     $63 = ((($62)) + 28|0);
     $64 = HEAP32[$63>>2]|0;
     __THREW__ = 0;
     $65 = (invoke_iii($64|0,($59|0),10)|0);
     $66 = __THREW__; __THREW__ = 0;
     $67 = $66&1;
     if (!($67)) {
      __ZNSt3__26localeD2Ev($2);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($54,$65)|0);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($54)|0);
      STACKTOP = sp;return;
     }
    }
    $68 = ___cxa_find_matching_catch_2()|0;
    $69 = tempRet0;
    __THREW__ = 0;
    invoke_vi(3263,($2|0));
    $70 = __THREW__; __THREW__ = 0;
    $71 = $70&1;
    if ($71) {
     $72 = ___cxa_find_matching_catch_3(0|0)|0;
     $73 = tempRet0;
     ___clang_call_terminate($72);
     // unreachable;
    } else {
     ___resumeException($68|0);
     // unreachable;
    }
   }
  }
 }
 $74 = ((($$035)) + 52|0);
 $75 = HEAP32[$74>>2]|0;
 switch ($75|0) {
 case 27:  {
  $76 = HEAP32[$1>>2]|0;
  $77 = ((($76)) + 8|0);
  $78 = HEAP32[$77>>2]|0;
  $79 = HEAP32[$$035>>2]|0;
  $80 = ((($79)) + 200|0);
  $81 = HEAP32[$80>>2]|0;
  $82 = (FUNCTION_TABLE_ii[$81 & 8191]($$035)|0);
  $83 = HEAP32[$$035>>2]|0;
  $84 = ((($83)) + 140|0);
  $85 = HEAP32[$84>>2]|0;
  $86 = (FUNCTION_TABLE_ii[$85 & 8191]($$035)|0);
  FUNCTION_TABLE_viii[$78 & 8191]($1,$82,$86);
  break;
 }
 case 28:  {
  $87 = HEAP32[$1>>2]|0;
  $88 = ((($87)) + 12|0);
  $89 = HEAP32[$88>>2]|0;
  $90 = HEAP32[$$035>>2]|0;
  $91 = ((($90)) + 200|0);
  $92 = HEAP32[$91>>2]|0;
  $93 = (FUNCTION_TABLE_ii[$92 & 8191]($$035)|0);
  $94 = HEAP32[$$035>>2]|0;
  $95 = ((($94)) + 140|0);
  $96 = HEAP32[$95>>2]|0;
  $97 = (FUNCTION_TABLE_ii[$96 & 8191]($$035)|0);
  FUNCTION_TABLE_viii[$89 & 8191]($1,$93,$97);
  break;
 }
 case 29:  {
  $98 = HEAP32[$1>>2]|0;
  $99 = ((($98)) + 16|0);
  $100 = HEAP32[$99>>2]|0;
  $101 = HEAP32[$$035>>2]|0;
  $102 = ((($101)) + 200|0);
  $103 = HEAP32[$102>>2]|0;
  $104 = (FUNCTION_TABLE_ii[$103 & 8191]($$035)|0);
  $105 = HEAP32[$$035>>2]|0;
  $106 = ((($105)) + 140|0);
  $107 = HEAP32[$106>>2]|0;
  $108 = (FUNCTION_TABLE_ii[$107 & 8191]($$035)|0);
  FUNCTION_TABLE_viii[$100 & 8191]($1,$104,$108);
  break;
 }
 case 30:  {
  $109 = HEAP32[$1>>2]|0;
  $110 = ((($109)) + 20|0);
  $111 = HEAP32[$110>>2]|0;
  $112 = HEAP32[$$035>>2]|0;
  $113 = ((($112)) + 200|0);
  $114 = HEAP32[$113>>2]|0;
  $115 = (FUNCTION_TABLE_ii[$114 & 8191]($$035)|0);
  $116 = HEAP32[$$035>>2]|0;
  $117 = ((($116)) + 140|0);
  $118 = HEAP32[$117>>2]|0;
  $119 = (FUNCTION_TABLE_ii[$118 & 8191]($$035)|0);
  FUNCTION_TABLE_viii[$111 & 8191]($1,$115,$119);
  break;
 }
 case 31:  {
  $120 = HEAP32[$1>>2]|0;
  $121 = ((($120)) + 24|0);
  $122 = HEAP32[$121>>2]|0;
  $123 = HEAP32[$$035>>2]|0;
  $124 = ((($123)) + 200|0);
  $125 = HEAP32[$124>>2]|0;
  $126 = (FUNCTION_TABLE_ii[$125 & 8191]($$035)|0);
  $127 = HEAP32[$$035>>2]|0;
  $128 = ((($127)) + 140|0);
  $129 = HEAP32[$128>>2]|0;
  $130 = (FUNCTION_TABLE_ii[$129 & 8191]($$035)|0);
  FUNCTION_TABLE_viii[$122 & 8191]($1,$126,$130);
  break;
 }
 case 32:  {
  $131 = HEAP32[$1>>2]|0;
  $132 = ((($131)) + 28|0);
  $133 = HEAP32[$132>>2]|0;
  $134 = HEAP32[$$035>>2]|0;
  $135 = ((($134)) + 200|0);
  $136 = HEAP32[$135>>2]|0;
  $137 = (FUNCTION_TABLE_ii[$136 & 8191]($$035)|0);
  $138 = HEAP32[$$035>>2]|0;
  $139 = ((($138)) + 140|0);
  $140 = HEAP32[$139>>2]|0;
  $141 = (FUNCTION_TABLE_ii[$140 & 8191]($$035)|0);
  FUNCTION_TABLE_viii[$133 & 8191]($1,$137,$141);
  break;
 }
 default: {
  $142 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
  if (!($142)) {
   STACKTOP = sp;return;
  }
  $143 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
  $144 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($143,128063,76)|0);
  $145 = HEAP32[$74>>2]|0;
  $146 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi($144,$145)|0);
  $147 = HEAP32[$146>>2]|0;
  $148 = ((($147)) + -12|0);
  $149 = HEAP32[$148>>2]|0;
  $150 = (($146) + ($149)|0);
  __ZNKSt3__28ios_base6getlocEv($4,$150);
  __THREW__ = 0;
  $151 = (invoke_iii(3255,($4|0),(215188|0))|0);
  $152 = __THREW__; __THREW__ = 0;
  $153 = $152&1;
  if (!($153)) {
   $154 = HEAP32[$151>>2]|0;
   $155 = ((($154)) + 28|0);
   $156 = HEAP32[$155>>2]|0;
   __THREW__ = 0;
   $157 = (invoke_iii($156|0,($151|0),10)|0);
   $158 = __THREW__; __THREW__ = 0;
   $159 = $158&1;
   if (!($159)) {
    __ZNSt3__26localeD2Ev($4);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($146,$157)|0);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($146)|0);
    STACKTOP = sp;return;
   }
  }
  $160 = ___cxa_find_matching_catch_2()|0;
  $161 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3263,($4|0));
  $162 = __THREW__; __THREW__ = 0;
  $163 = $162&1;
  if ($163) {
   $164 = ___cxa_find_matching_catch_3(0|0)|0;
   $165 = tempRet0;
   ___clang_call_terminate($164);
   // unreachable;
  } else {
   ___resumeException($160|0);
   // unreachable;
  }
 }
 }
 $166 = ((($0)) + 216|0);
 $167 = HEAP32[$166>>2]|0;
 $168 = ((($0)) + 220|0);
 $169 = HEAP32[$168>>2]|0;
 $170 = ($167|0)==($169|0);
 if ($170) {
  STACKTOP = sp;return;
 } else {
  $$sroa$030$036 = $167;
 }
 while(1) {
  $171 = HEAP32[$$sroa$030$036>>2]|0;
  $172 = HEAP32[$171>>2]|0;
  $173 = ((($172)) + 188|0);
  $174 = HEAP32[$173>>2]|0;
  FUNCTION_TABLE_vii[$174 & 8191]($171,$1);
  $175 = ((($$sroa$030$036)) + 4|0);
  $176 = HEAP32[$168>>2]|0;
  $177 = ($175|0)==($176|0);
  if ($177) {
   break;
  } else {
   $$sroa$030$036 = $175;
  }
 }
 STACKTOP = sp;return;
}
function __ZNK3osg8Geometry8supportsERKNS_21PrimitiveIndexFunctorE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 1;
}
function __ZNK3osg8Geometry6acceptERNS_21PrimitiveIndexFunctorE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$035 = 0, $$sroa$030$036 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $phitmp = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp + 8|0;
 $3 = sp + 4|0;
 $4 = sp;
 $5 = ((($0)) + 228|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $8 = ((($0)) + 260|0);
  $9 = ((($0)) + 264|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = HEAP32[$8>>2]|0;
  $12 = ($10|0)==($11|0);
  if ($12) {
   STACKTOP = sp;return;
  }
  $13 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
  do {
   if ($13) {
    $14 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
    $15 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($14,127626,80)|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = ((($16)) + -12|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = (($15) + ($18)|0);
    __ZNKSt3__28ios_base6getlocEv($3,$19);
    __THREW__ = 0;
    $20 = (invoke_iii(3255,($3|0),(215188|0))|0);
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if (!($22)) {
     $23 = HEAP32[$20>>2]|0;
     $24 = ((($23)) + 28|0);
     $25 = HEAP32[$24>>2]|0;
     __THREW__ = 0;
     $26 = (invoke_iii($25|0,($20|0),10)|0);
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     if (!($28)) {
      __ZNSt3__26localeD2Ev($3);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($15,$26)|0);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($15)|0);
      break;
     }
    }
    $29 = ___cxa_find_matching_catch_2()|0;
    $30 = tempRet0;
    __THREW__ = 0;
    invoke_vi(3263,($3|0));
    $31 = __THREW__; __THREW__ = 0;
    $32 = $31&1;
    if ($32) {
     $33 = ___cxa_find_matching_catch_3(0|0)|0;
     $34 = tempRet0;
     ___clang_call_terminate($33);
     // unreachable;
    } else {
     ___resumeException($29|0);
     // unreachable;
    }
   }
  } while(0);
  $35 = HEAP32[$8>>2]|0;
  $36 = HEAP32[$35>>2]|0;
  $37 = ($36|0)==(0|0);
  if ($37) {
   STACKTOP = sp;return;
  } else {
   $$035 = $36;
  }
 } else {
  $$035 = $6;
 }
 $38 = HEAP32[$$035>>2]|0;
 $39 = ((($38)) + 200|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = (FUNCTION_TABLE_ii[$40 & 8191]($$035)|0);
 $42 = ($41|0)==(0);
 if ($42) {
  STACKTOP = sp;return;
 }
 $43 = ((($0)) + 272|0);
 $44 = HEAP8[$43>>0]|0;
 $45 = ($44<<24>>24)==(0);
 if (!($45)) {
  $46 = HEAP32[$$035>>2]|0;
  $47 = ((($46)) + 128|0);
  $48 = HEAP32[$47>>2]|0;
  $49 = (FUNCTION_TABLE_ii[$48 & 8191]($$035)|0);
  $50 = ($49|0)==(0|0);
  if (!($50)) {
   $51 = (___dynamic_cast($49,26488,22736,0)|0);
   $phitmp = ($51|0)==(0|0);
   if (!($phitmp)) {
    $52 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
    if (!($52)) {
     STACKTOP = sp;return;
    }
    $53 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
    $54 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($53,127707,123)|0);
    $55 = HEAP32[$54>>2]|0;
    $56 = ((($55)) + -12|0);
    $57 = HEAP32[$56>>2]|0;
    $58 = (($54) + ($57)|0);
    __ZNKSt3__28ios_base6getlocEv($2,$58);
    __THREW__ = 0;
    $59 = (invoke_iii(3255,($2|0),(215188|0))|0);
    $60 = __THREW__; __THREW__ = 0;
    $61 = $60&1;
    if (!($61)) {
     $62 = HEAP32[$59>>2]|0;
     $63 = ((($62)) + 28|0);
     $64 = HEAP32[$63>>2]|0;
     __THREW__ = 0;
     $65 = (invoke_iii($64|0,($59|0),10)|0);
     $66 = __THREW__; __THREW__ = 0;
     $67 = $66&1;
     if (!($67)) {
      __ZNSt3__26localeD2Ev($2);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($54,$65)|0);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($54)|0);
      STACKTOP = sp;return;
     }
    }
    $68 = ___cxa_find_matching_catch_2()|0;
    $69 = tempRet0;
    __THREW__ = 0;
    invoke_vi(3263,($2|0));
    $70 = __THREW__; __THREW__ = 0;
    $71 = $70&1;
    if ($71) {
     $72 = ___cxa_find_matching_catch_3(0|0)|0;
     $73 = tempRet0;
     ___clang_call_terminate($72);
     // unreachable;
    } else {
     ___resumeException($68|0);
     // unreachable;
    }
   }
  }
 }
 $74 = ((($$035)) + 52|0);
 $75 = HEAP32[$74>>2]|0;
 switch ($75|0) {
 case 27:  {
  $76 = HEAP32[$1>>2]|0;
  $77 = ((($76)) + 8|0);
  $78 = HEAP32[$77>>2]|0;
  $79 = HEAP32[$$035>>2]|0;
  $80 = ((($79)) + 200|0);
  $81 = HEAP32[$80>>2]|0;
  $82 = (FUNCTION_TABLE_ii[$81 & 8191]($$035)|0);
  $83 = HEAP32[$$035>>2]|0;
  $84 = ((($83)) + 140|0);
  $85 = HEAP32[$84>>2]|0;
  $86 = (FUNCTION_TABLE_ii[$85 & 8191]($$035)|0);
  FUNCTION_TABLE_viii[$78 & 8191]($1,$82,$86);
  break;
 }
 case 28:  {
  $87 = HEAP32[$1>>2]|0;
  $88 = ((($87)) + 12|0);
  $89 = HEAP32[$88>>2]|0;
  $90 = HEAP32[$$035>>2]|0;
  $91 = ((($90)) + 200|0);
  $92 = HEAP32[$91>>2]|0;
  $93 = (FUNCTION_TABLE_ii[$92 & 8191]($$035)|0);
  $94 = HEAP32[$$035>>2]|0;
  $95 = ((($94)) + 140|0);
  $96 = HEAP32[$95>>2]|0;
  $97 = (FUNCTION_TABLE_ii[$96 & 8191]($$035)|0);
  FUNCTION_TABLE_viii[$89 & 8191]($1,$93,$97);
  break;
 }
 case 29:  {
  $98 = HEAP32[$1>>2]|0;
  $99 = ((($98)) + 16|0);
  $100 = HEAP32[$99>>2]|0;
  $101 = HEAP32[$$035>>2]|0;
  $102 = ((($101)) + 200|0);
  $103 = HEAP32[$102>>2]|0;
  $104 = (FUNCTION_TABLE_ii[$103 & 8191]($$035)|0);
  $105 = HEAP32[$$035>>2]|0;
  $106 = ((($105)) + 140|0);
  $107 = HEAP32[$106>>2]|0;
  $108 = (FUNCTION_TABLE_ii[$107 & 8191]($$035)|0);
  FUNCTION_TABLE_viii[$100 & 8191]($1,$104,$108);
  break;
 }
 case 30:  {
  $109 = HEAP32[$1>>2]|0;
  $110 = ((($109)) + 20|0);
  $111 = HEAP32[$110>>2]|0;
  $112 = HEAP32[$$035>>2]|0;
  $113 = ((($112)) + 200|0);
  $114 = HEAP32[$113>>2]|0;
  $115 = (FUNCTION_TABLE_ii[$114 & 8191]($$035)|0);
  $116 = HEAP32[$$035>>2]|0;
  $117 = ((($116)) + 140|0);
  $118 = HEAP32[$117>>2]|0;
  $119 = (FUNCTION_TABLE_ii[$118 & 8191]($$035)|0);
  FUNCTION_TABLE_viii[$111 & 8191]($1,$115,$119);
  break;
 }
 case 31:  {
  $120 = HEAP32[$1>>2]|0;
  $121 = ((($120)) + 24|0);
  $122 = HEAP32[$121>>2]|0;
  $123 = HEAP32[$$035>>2]|0;
  $124 = ((($123)) + 200|0);
  $125 = HEAP32[$124>>2]|0;
  $126 = (FUNCTION_TABLE_ii[$125 & 8191]($$035)|0);
  $127 = HEAP32[$$035>>2]|0;
  $128 = ((($127)) + 140|0);
  $129 = HEAP32[$128>>2]|0;
  $130 = (FUNCTION_TABLE_ii[$129 & 8191]($$035)|0);
  FUNCTION_TABLE_viii[$122 & 8191]($1,$126,$130);
  break;
 }
 case 32:  {
  $131 = HEAP32[$1>>2]|0;
  $132 = ((($131)) + 28|0);
  $133 = HEAP32[$132>>2]|0;
  $134 = HEAP32[$$035>>2]|0;
  $135 = ((($134)) + 200|0);
  $136 = HEAP32[$135>>2]|0;
  $137 = (FUNCTION_TABLE_ii[$136 & 8191]($$035)|0);
  $138 = HEAP32[$$035>>2]|0;
  $139 = ((($138)) + 140|0);
  $140 = HEAP32[$139>>2]|0;
  $141 = (FUNCTION_TABLE_ii[$140 & 8191]($$035)|0);
  FUNCTION_TABLE_viii[$133 & 8191]($1,$137,$141);
  break;
 }
 default: {
  $142 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
  if (!($142)) {
   STACKTOP = sp;return;
  }
  $143 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
  $144 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($143,127831,81)|0);
  $145 = HEAP32[$74>>2]|0;
  $146 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi($144,$145)|0);
  $147 = HEAP32[$146>>2]|0;
  $148 = ((($147)) + -12|0);
  $149 = HEAP32[$148>>2]|0;
  $150 = (($146) + ($149)|0);
  __ZNKSt3__28ios_base6getlocEv($4,$150);
  __THREW__ = 0;
  $151 = (invoke_iii(3255,($4|0),(215188|0))|0);
  $152 = __THREW__; __THREW__ = 0;
  $153 = $152&1;
  if (!($153)) {
   $154 = HEAP32[$151>>2]|0;
   $155 = ((($154)) + 28|0);
   $156 = HEAP32[$155>>2]|0;
   __THREW__ = 0;
   $157 = (invoke_iii($156|0,($151|0),10)|0);
   $158 = __THREW__; __THREW__ = 0;
   $159 = $158&1;
   if (!($159)) {
    __ZNSt3__26localeD2Ev($4);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($146,$157)|0);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($146)|0);
    STACKTOP = sp;return;
   }
  }
  $160 = ___cxa_find_matching_catch_2()|0;
  $161 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3263,($4|0));
  $162 = __THREW__; __THREW__ = 0;
  $163 = $162&1;
  if ($163) {
   $164 = ___cxa_find_matching_catch_3(0|0)|0;
   $165 = tempRet0;
   ___clang_call_terminate($164);
   // unreachable;
  } else {
   ___resumeException($160|0);
   // unreachable;
  }
 }
 }
 $166 = ((($0)) + 216|0);
 $167 = HEAP32[$166>>2]|0;
 $168 = ((($0)) + 220|0);
 $169 = HEAP32[$168>>2]|0;
 $170 = ($167|0)==($169|0);
 if ($170) {
  STACKTOP = sp;return;
 } else {
  $$sroa$030$036 = $167;
 }
 while(1) {
  $171 = HEAP32[$$sroa$030$036>>2]|0;
  $172 = HEAP32[$171>>2]|0;
  $173 = ((($172)) + 192|0);
  $174 = HEAP32[$173>>2]|0;
  FUNCTION_TABLE_vii[$174 & 8191]($171,$1);
  $175 = ((($$sroa$030$036)) + 4|0);
  $176 = HEAP32[$168>>2]|0;
  $177 = ($175|0)==($176|0);
  if ($177) {
   break;
  } else {
   $$sroa$030$036 = $175;
  }
 }
 STACKTOP = sp;return;
}
function __ZN3osg17ConstArrayVisitorD2Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN3osg33ConstAttributeFunctorArrayVisitorD0Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($0);
 return;
}
function __ZN3osg17ConstArrayVisitor5applyERKNS_5ArrayE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN3osg33ConstAttributeFunctorArrayVisitor5applyERKNS_18TemplateIndexArrayIaLNS_5Array4TypeE1ELi1ELi5120EEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($1)) + 80|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if ($6) {
  return;
 }
 $7 = $3;
 $8 = $5;
 $9 = ((($0)) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11)) + 8|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($0)) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($8) - ($7))|0;
 FUNCTION_TABLE_viiii[$13 & 8191]($10,$15,$16,$3);
 return;
}
function __ZN3osg33ConstAttributeFunctorArrayVisitor5applyERKNS_18TemplateIndexArrayIsLNS_5Array4TypeE2ELi1ELi5122EEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($1)) + 80|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if ($6) {
  return;
 }
 $7 = $3;
 $8 = $5;
 $9 = ((($0)) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11)) + 12|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($0)) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($8) - ($7))|0;
 $17 = $16 >> 1;
 FUNCTION_TABLE_viiii[$13 & 8191]($10,$15,$17,$3);
 return;
}
function __ZN3osg33ConstAttributeFunctorArrayVisitor5applyERKNS_18TemplateIndexArrayIiLNS_5Array4TypeE3ELi1ELi5124EEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($1)) + 80|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if ($6) {
  return;
 }
 $7 = $3;
 $8 = $5;
 $9 = ((($0)) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11)) + 16|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($0)) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($8) - ($7))|0;
 $17 = $16 >> 2;
 FUNCTION_TABLE_viiii[$13 & 8191]($10,$15,$17,$3);
 return;
}
function __ZN3osg33ConstAttributeFunctorArrayVisitor5applyERKNS_18TemplateIndexArrayIhLNS_5Array4TypeE4ELi1ELi5121EEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($1)) + 80|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if ($6) {
  return;
 }
 $7 = $3;
 $8 = $5;
 $9 = ((($0)) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11)) + 20|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($0)) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($8) - ($7))|0;
 FUNCTION_TABLE_viiii[$13 & 8191]($10,$15,$16,$3);
 return;
}
function __ZN3osg33ConstAttributeFunctorArrayVisitor5applyERKNS_18TemplateIndexArrayItLNS_5Array4TypeE5ELi1ELi5123EEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($1)) + 80|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if ($6) {
  return;
 }
 $7 = $3;
 $8 = $5;
 $9 = ((($0)) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11)) + 24|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($0)) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($8) - ($7))|0;
 $17 = $16 >> 1;
 FUNCTION_TABLE_viiii[$13 & 8191]($10,$15,$17,$3);
 return;
}
function __ZN3osg33ConstAttributeFunctorArrayVisitor5applyERKNS_18TemplateIndexArrayIjLNS_5Array4TypeE6ELi1ELi5125EEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($1)) + 80|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if ($6) {
  return;
 }
 $7 = $3;
 $8 = $5;
 $9 = ((($0)) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11)) + 28|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($0)) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($8) - ($7))|0;
 $17 = $16 >> 2;
 FUNCTION_TABLE_viiii[$13 & 8191]($10,$15,$17,$3);
 return;
}
function __ZN3osg33ConstAttributeFunctorArrayVisitor5applyERKNS_13TemplateArrayIfLNS_5Array4TypeE7ELi1ELi5126EEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($1)) + 80|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if ($6) {
  return;
 }
 $7 = $3;
 $8 = $5;
 $9 = ((($0)) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11)) + 32|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($0)) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($8) - ($7))|0;
 $17 = $16 >> 2;
 FUNCTION_TABLE_viiii[$13 & 8191]($10,$15,$17,$3);
 return;
}
function __ZN3osg33ConstAttributeFunctorArrayVisitor5applyERKNS_13TemplateArrayIdLNS_5Array4TypeE8ELi1ELi5130EEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($1)) + 80|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if ($6) {
  return;
 }
 $7 = $3;
 $8 = $5;
 $9 = ((($0)) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11)) + 52|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($0)) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($8) - ($7))|0;
 $17 = $16 >> 3;
 FUNCTION_TABLE_viiii[$13 & 8191]($10,$15,$17,$3);
 return;
}
function __ZN3osg17ConstArrayVisitor5applyERKNS_13TemplateArrayINS_5Vec2bELNS_5Array4TypeE9ELi2ELi5120EEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN3osg17ConstArrayVisitor5applyERKNS_13TemplateArrayINS_5Vec3bELNS_5Array4TypeE10ELi3ELi5120EEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN3osg17ConstArrayVisitor5applyERKNS_13TemplateArrayINS_5Vec4bELNS_5Array4TypeE11ELi4ELi5120EEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN3osg17ConstArrayVisitor5applyERKNS_13TemplateArrayINS_5Vec2sELNS_5Array4TypeE12ELi2ELi5122EEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN3osg17ConstArrayVisitor5applyERKNS_13TemplateArrayINS_5Vec3sELNS_5Array4TypeE13ELi3ELi5122EEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN3osg17ConstArrayVisitor5applyERKNS_13TemplateArrayINS_5Vec4sELNS_5Array4TypeE14ELi4ELi5122EEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN3osg17ConstArrayVisitor5applyERKNS_13TemplateArrayINS_5Vec2iELNS_5Array4TypeE15ELi2ELi5124EEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN3osg17ConstArrayVisitor5applyERKNS_13TemplateArrayINS_5Vec3iELNS_5Array4TypeE16ELi3ELi5124EEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN3osg17ConstArrayVisitor5applyERKNS_13TemplateArrayINS_5Vec4iELNS_5Array4TypeE17ELi4ELi5124EEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN3osg17ConstArrayVisitor5applyERKNS_13TemplateArrayINS_6Vec2ubELNS_5Array4TypeE18ELi2ELi5121EEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN3osg17ConstArrayVisitor5applyERKNS_13TemplateArrayINS_6Vec3ubELNS_5Array4TypeE19ELi3ELi5121EEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN3osg33ConstAttributeFunctorArrayVisitor5applyERKNS_13TemplateArrayINS_6Vec4ubELNS_5Array4TypeE20ELi4ELi5121EEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($1)) + 80|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if ($6) {
  return;
 }
 $7 = $3;
 $8 = $5;
 $9 = ((($0)) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11)) + 48|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($0)) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($8) - ($7))|0;
 $17 = $16 >> 2;
 FUNCTION_TABLE_viiii[$13 & 8191]($10,$15,$17,$3);
 return;
}
function __ZN3osg17ConstArrayVisitor5applyERKNS_13TemplateArrayINS_6Vec2usELNS_5Array4TypeE21ELi2ELi5123EEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN3osg17ConstArrayVisitor5applyERKNS_13TemplateArrayINS_6Vec3usELNS_5Array4TypeE22ELi3ELi5123EEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN3osg17ConstArrayVisitor5applyERKNS_13TemplateArrayINS_6Vec4usELNS_5Array4TypeE23ELi4ELi5123EEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN3osg17ConstArrayVisitor5applyERKNS_13TemplateArrayINS_6Vec2uiELNS_5Array4TypeE24ELi2ELi5125EEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN3osg17ConstArrayVisitor5applyERKNS_13TemplateArrayINS_6Vec3uiELNS_5Array4TypeE25ELi3ELi5125EEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN3osg17ConstArrayVisitor5applyERKNS_13TemplateArrayINS_6Vec4uiELNS_5Array4TypeE26ELi4ELi5125EEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN3osg33ConstAttributeFunctorArrayVisitor5applyERKNS_13TemplateArrayINS_5Vec2fELNS_5Array4TypeE27ELi2ELi5126EEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($1)) + 80|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if ($6) {
  return;
 }
 $7 = $3;
 $8 = $5;
 $9 = ((($0)) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11)) + 36|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($0)) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($8) - ($7))|0;
 $17 = $16 >> 3;
 FUNCTION_TABLE_viiii[$13 & 8191]($10,$15,$17,$3);
 return;
}
function __ZN3osg33ConstAttributeFunctorArrayVisitor5applyERKNS_13TemplateArrayINS_5Vec3fELNS_5Array4TypeE28ELi3ELi5126EEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($1)) + 80|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if ($6) {
  return;
 }
 $7 = $3;
 $8 = $5;
 $9 = ((($0)) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11)) + 40|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($0)) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($8) - ($7))|0;
 $17 = (($16|0) / 12)&-1;
 FUNCTION_TABLE_viiii[$13 & 8191]($10,$15,$17,$3);
 return;
}
function __ZN3osg33ConstAttributeFunctorArrayVisitor5applyERKNS_13TemplateArrayINS_5Vec4fELNS_5Array4TypeE29ELi4ELi5126EEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($1)) + 80|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if ($6) {
  return;
 }
 $7 = $3;
 $8 = $5;
 $9 = ((($0)) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11)) + 44|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($0)) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($8) - ($7))|0;
 $17 = $16 >> 4;
 FUNCTION_TABLE_viiii[$13 & 8191]($10,$15,$17,$3);
 return;
}
function __ZN3osg33ConstAttributeFunctorArrayVisitor5applyERKNS_13TemplateArrayINS_5Vec2dELNS_5Array4TypeE30ELi2ELi5130EEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($1)) + 80|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if ($6) {
  return;
 }
 $7 = $3;
 $8 = $5;
 $9 = ((($0)) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11)) + 56|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($0)) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($8) - ($7))|0;
 $17 = $16 >> 4;
 FUNCTION_TABLE_viiii[$13 & 8191]($10,$15,$17,$3);
 return;
}
function __ZN3osg33ConstAttributeFunctorArrayVisitor5applyERKNS_13TemplateArrayINS_5Vec3dELNS_5Array4TypeE31ELi3ELi5130EEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($1)) + 80|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if ($6) {
  return;
 }
 $7 = $3;
 $8 = $5;
 $9 = ((($0)) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11)) + 60|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($0)) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($8) - ($7))|0;
 $17 = (($16|0) / 24)&-1;
 FUNCTION_TABLE_viiii[$13 & 8191]($10,$15,$17,$3);
 return;
}
function __ZN3osg33ConstAttributeFunctorArrayVisitor5applyERKNS_13TemplateArrayINS_5Vec4dELNS_5Array4TypeE32ELi4ELi5130EEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($1)) + 80|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if ($6) {
  return;
 }
 $7 = $3;
 $8 = $5;
 $9 = ((($0)) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11)) + 64|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($0)) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($8) - ($7))|0;
 $17 = $16 >> 5;
 FUNCTION_TABLE_viiii[$13 & 8191]($10,$15,$17,$3);
 return;
}
function __ZN3osg17ConstArrayVisitor5applyERKNS_13TemplateArrayINS_7MatrixfELNS_5Array4TypeE33ELi16ELi5126EEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN3osg17ConstArrayVisitor5applyERKNS_13TemplateArrayINS_7MatrixdELNS_5Array4TypeE34ELi16ELi5130EEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN3osg17ConstArrayVisitor5applyERKNS_18TemplateIndexArrayIyLNS_5Array4TypeE36ELi1ELi5135EEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN3osg17ConstArrayVisitor5applyERKNS_18TemplateIndexArrayIxLNS_5Array4TypeE37ELi1ELi5134EEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN3osg28AttributeFunctorArrayVisitorD0Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($0);
 return;
}
function __ZN3osg28AttributeFunctorArrayVisitor5applyERNS_18TemplateIndexArrayIaLNS_5Array4TypeE1ELi1ELi5120EEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($1)) + 80|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if ($6) {
  return;
 }
 $7 = $3;
 $8 = $5;
 $9 = ((($0)) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11)) + 8|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($0)) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($8) - ($7))|0;
 FUNCTION_TABLE_viiii[$13 & 8191]($10,$15,$16,$3);
 return;
}
function __ZN3osg28AttributeFunctorArrayVisitor5applyERNS_18TemplateIndexArrayIsLNS_5Array4TypeE2ELi1ELi5122EEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($1)) + 80|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if ($6) {
  return;
 }
 $7 = $3;
 $8 = $5;
 $9 = ((($0)) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11)) + 12|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($0)) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($8) - ($7))|0;
 $17 = $16 >> 1;
 FUNCTION_TABLE_viiii[$13 & 8191]($10,$15,$17,$3);
 return;
}
function __ZN3osg28AttributeFunctorArrayVisitor5applyERNS_18TemplateIndexArrayIiLNS_5Array4TypeE3ELi1ELi5124EEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($1)) + 80|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if ($6) {
  return;
 }
 $7 = $3;
 $8 = $5;
 $9 = ((($0)) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11)) + 16|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($0)) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($8) - ($7))|0;
 $17 = $16 >> 2;
 FUNCTION_TABLE_viiii[$13 & 8191]($10,$15,$17,$3);
 return;
}
function __ZN3osg28AttributeFunctorArrayVisitor5applyERNS_18TemplateIndexArrayIhLNS_5Array4TypeE4ELi1ELi5121EEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($1)) + 80|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if ($6) {
  return;
 }
 $7 = $3;
 $8 = $5;
 $9 = ((($0)) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11)) + 20|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($0)) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($8) - ($7))|0;
 FUNCTION_TABLE_viiii[$13 & 8191]($10,$15,$16,$3);
 return;
}
function __ZN3osg28AttributeFunctorArrayVisitor5applyERNS_18TemplateIndexArrayItLNS_5Array4TypeE5ELi1ELi5123EEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($1)) + 80|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if ($6) {
  return;
 }
 $7 = $3;
 $8 = $5;
 $9 = ((($0)) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11)) + 24|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($0)) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($8) - ($7))|0;
 $17 = $16 >> 1;
 FUNCTION_TABLE_viiii[$13 & 8191]($10,$15,$17,$3);
 return;
}
function __ZN3osg28AttributeFunctorArrayVisitor5applyERNS_18TemplateIndexArrayIjLNS_5Array4TypeE6ELi1ELi5125EEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($1)) + 80|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if ($6) {
  return;
 }
 $7 = $3;
 $8 = $5;
 $9 = ((($0)) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11)) + 28|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($0)) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($8) - ($7))|0;
 $17 = $16 >> 2;
 FUNCTION_TABLE_viiii[$13 & 8191]($10,$15,$17,$3);
 return;
}
function __ZN3osg28AttributeFunctorArrayVisitor5applyERNS_13TemplateArrayIfLNS_5Array4TypeE7ELi1ELi5126EEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($1)) + 80|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if ($6) {
  return;
 }
 $7 = $3;
 $8 = $5;
 $9 = ((($0)) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11)) + 32|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($0)) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($8) - ($7))|0;
 $17 = $16 >> 2;
 FUNCTION_TABLE_viiii[$13 & 8191]($10,$15,$17,$3);
 return;
}
function __ZN3osg28AttributeFunctorArrayVisitor5applyERNS_13TemplateArrayIdLNS_5Array4TypeE8ELi1ELi5130EEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($1)) + 80|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if ($6) {
  return;
 }
 $7 = $3;
 $8 = $5;
 $9 = ((($0)) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11)) + 52|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($0)) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($8) - ($7))|0;
 $17 = $16 >> 3;
 FUNCTION_TABLE_viiii[$13 & 8191]($10,$15,$17,$3);
 return;
}
function __ZN3osg28AttributeFunctorArrayVisitor5applyERNS_13TemplateArrayINS_6Vec4ubELNS_5Array4TypeE20ELi4ELi5121EEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($1)) + 80|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if ($6) {
  return;
 }
 $7 = $3;
 $8 = $5;
 $9 = ((($0)) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11)) + 48|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($0)) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($8) - ($7))|0;
 $17 = $16 >> 2;
 FUNCTION_TABLE_viiii[$13 & 8191]($10,$15,$17,$3);
 return;
}
function __ZN3osg28AttributeFunctorArrayVisitor5applyERNS_13TemplateArrayINS_5Vec2fELNS_5Array4TypeE27ELi2ELi5126EEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($1)) + 80|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if ($6) {
  return;
 }
 $7 = $3;
 $8 = $5;
 $9 = ((($0)) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11)) + 36|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($0)) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($8) - ($7))|0;
 $17 = $16 >> 3;
 FUNCTION_TABLE_viiii[$13 & 8191]($10,$15,$17,$3);
 return;
}
function __ZN3osg28AttributeFunctorArrayVisitor5applyERNS_13TemplateArrayINS_5Vec3fELNS_5Array4TypeE28ELi3ELi5126EEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($1)) + 80|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if ($6) {
  return;
 }
 $7 = $3;
 $8 = $5;
 $9 = ((($0)) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11)) + 40|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($0)) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($8) - ($7))|0;
 $17 = (($16|0) / 12)&-1;
 FUNCTION_TABLE_viiii[$13 & 8191]($10,$15,$17,$3);
 return;
}
function __ZN3osg28AttributeFunctorArrayVisitor5applyERNS_13TemplateArrayINS_5Vec4fELNS_5Array4TypeE29ELi4ELi5126EEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($1)) + 80|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if ($6) {
  return;
 }
 $7 = $3;
 $8 = $5;
 $9 = ((($0)) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11)) + 44|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($0)) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($8) - ($7))|0;
 $17 = $16 >> 4;
 FUNCTION_TABLE_viiii[$13 & 8191]($10,$15,$17,$3);
 return;
}
function __ZN3osg28AttributeFunctorArrayVisitor5applyERNS_13TemplateArrayINS_5Vec2dELNS_5Array4TypeE30ELi2ELi5130EEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($1)) + 80|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if ($6) {
  return;
 }
 $7 = $3;
 $8 = $5;
 $9 = ((($0)) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11)) + 56|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($0)) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($8) - ($7))|0;
 $17 = $16 >> 4;
 FUNCTION_TABLE_viiii[$13 & 8191]($10,$15,$17,$3);
 return;
}
function __ZN3osg28AttributeFunctorArrayVisitor5applyERNS_13TemplateArrayINS_5Vec3dELNS_5Array4TypeE31ELi3ELi5130EEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($1)) + 80|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if ($6) {
  return;
 }
 $7 = $3;
 $8 = $5;
 $9 = ((($0)) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11)) + 60|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($0)) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($8) - ($7))|0;
 $17 = (($16|0) / 24)&-1;
 FUNCTION_TABLE_viiii[$13 & 8191]($10,$15,$17,$3);
 return;
}
function __ZN3osg28AttributeFunctorArrayVisitor5applyERNS_13TemplateArrayINS_5Vec4dELNS_5Array4TypeE32ELi4ELi5130EEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($1)) + 80|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if ($6) {
  return;
 }
 $7 = $3;
 $8 = $5;
 $9 = ((($0)) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11)) + 64|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($0)) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($8) - ($7))|0;
 $17 = $16 >> 5;
 FUNCTION_TABLE_viiii[$13 & 8191]($10,$15,$17,$3);
 return;
}
function __ZNK3osg8Geometry30drawVertexArraysImplementationERNS_10RenderInfoE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$06478 = 0, $$06579 = 0, $$081 = 0, $$in = 0, $$pre = 0, $$pre$i = 0, $$pre16$i = 0, $$pre83 = 0, $$pre84 = 0, $$pre85 = 0, $$sroa$04$08$i = 0, $$sroa$08$013$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0;
 var $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0;
 var $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0;
 var $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0;
 var $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0;
 var $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0;
 var $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0;
 var $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0;
 var $27 = 0, $270 = 0, $271 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i$i$i66 = 0, $scevgep5$i$i$i$i = 0, $scevgep5$i$i$i$i67 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $2 = sp + 16|0;
 $3 = sp + 12|0;
 $4 = sp + 8|0;
 $5 = sp + 4|0;
 $6 = sp;
 $7 = HEAP32[$1>>2]|0;
 $8 = ((($7)) + 132|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($0)) + 260|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($0)) + 264|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($11|0)==($13|0);
 $15 = ((($7)) + 796|0);
 __ZN3osg20AttributeDispatchers5resetEv($15);
 $16 = ((($7)) + 348|0);
 $17 = HEAP8[$16>>0]|0;
 $18 = ((($7)) + 856|0);
 HEAP8[$18>>0] = $17;
 if (!($14)) {
  $19 = HEAP32[$12>>2]|0;
  $20 = HEAP32[$10>>2]|0;
  $21 = ($19|0)==($20|0);
  if (!($21)) {
   $22 = ((($7)) + 848|0);
   $23 = ((($7)) + 852|0);
   $24 = ((($7)) + 844|0);
   $$081 = 0;$$in = $20;
   while(1) {
    $25 = $$in;
    $26 = (($25) + ($$081<<2)|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = ($27|0)==(0|0);
    L6: do {
     if (!($28)) {
      $29 = ((($27)) + 64|0);
      $30 = HEAP32[$29>>2]|0;
      switch ($30|0) {
      case 1:  {
       $31 = (__ZN3osg20AttributeDispatchers22vertexAttribDispatcherEjPNS_5ArrayE($15,$$081,$27)|0);
       $32 = ($31|0)==(0|0);
       if ($32) {
        break L6;
       }
       $33 = HEAP32[$31>>2]|0;
       $34 = ((($33)) + 16|0);
       $35 = HEAP32[$34>>2]|0;
       FUNCTION_TABLE_vii[$35 & 8191]($31,0);
       break L6;
       break;
      }
      case 2:  {
       break;
      }
      default: {
       break L6;
      }
      }
      $36 = (__ZN3osg20AttributeDispatchers22vertexAttribDispatcherEjPNS_5ArrayE($15,$$081,$27)|0);
      HEAP32[$5>>2] = $36;
      $37 = ($36|0)==(0|0);
      $38 = $36;
      do {
       if (!($37)) {
        $39 = HEAP32[$22>>2]|0;
        $40 = HEAP32[$23>>2]|0;
        $41 = ($39|0)==($40|0);
        if ($41) {
         __ZNSt3__26vectorIPN3osg17AttributeDispatchENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_($24,$5);
         break;
        } else {
         HEAP32[$39>>2] = $38;
         $42 = HEAP32[$22>>2]|0;
         $43 = ((($42)) + 4|0);
         HEAP32[$22>>2] = $43;
         break;
        }
       }
      } while(0);
     }
    } while(0);
    $44 = (($$081) + 1)|0;
    $45 = HEAP32[$12>>2]|0;
    $46 = HEAP32[$10>>2]|0;
    $47 = (($45) - ($46))|0;
    $48 = $47 >> 2;
    $49 = ($44>>>0)<($48>>>0);
    if ($49) {
     $$081 = $44;$$in = $46;
    } else {
     break;
    }
   }
  }
 }
 $50 = ((($0)) + 232|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = ($51|0)==(0|0);
 L20: do {
  if (!($52)) {
   $53 = ((($51)) + 64|0);
   $54 = HEAP32[$53>>2]|0;
   switch ($54|0) {
   case 1:  {
    $55 = (__ZN3osg20AttributeDispatchers16normalDispatcherEPNS_5ArrayE($15,$51)|0);
    $56 = ($55|0)==(0|0);
    if ($56) {
     break L20;
    }
    $57 = HEAP32[$55>>2]|0;
    $58 = ((($57)) + 16|0);
    $59 = HEAP32[$58>>2]|0;
    FUNCTION_TABLE_vii[$59 & 8191]($55,0);
    break L20;
    break;
   }
   case 2:  {
    break;
   }
   default: {
    break L20;
   }
   }
   $60 = (__ZN3osg20AttributeDispatchers16normalDispatcherEPNS_5ArrayE($15,$51)|0);
   HEAP32[$4>>2] = $60;
   $61 = ($60|0)==(0|0);
   $62 = $60;
   do {
    if (!($61)) {
     $63 = ((($7)) + 848|0);
     $64 = HEAP32[$63>>2]|0;
     $65 = ((($7)) + 852|0);
     $66 = HEAP32[$65>>2]|0;
     $67 = ($64|0)==($66|0);
     if ($67) {
      $70 = ((($7)) + 844|0);
      __ZNSt3__26vectorIPN3osg17AttributeDispatchENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_($70,$4);
      break;
     } else {
      HEAP32[$64>>2] = $62;
      $68 = HEAP32[$63>>2]|0;
      $69 = ((($68)) + 4|0);
      HEAP32[$63>>2] = $69;
      break;
     }
    }
   } while(0);
  }
 } while(0);
 $71 = ((($0)) + 236|0);
 $72 = HEAP32[$71>>2]|0;
 $73 = ($72|0)==(0|0);
 L33: do {
  if (!($73)) {
   $74 = ((($72)) + 64|0);
   $75 = HEAP32[$74>>2]|0;
   switch ($75|0) {
   case 1:  {
    $76 = (__ZN3osg20AttributeDispatchers15colorDispatcherEPNS_5ArrayE($15,$72)|0);
    $77 = ($76|0)==(0|0);
    if ($77) {
     break L33;
    }
    $78 = HEAP32[$76>>2]|0;
    $79 = ((($78)) + 16|0);
    $80 = HEAP32[$79>>2]|0;
    FUNCTION_TABLE_vii[$80 & 8191]($76,0);
    break L33;
    break;
   }
   case 2:  {
    break;
   }
   default: {
    break L33;
   }
   }
   $81 = (__ZN3osg20AttributeDispatchers15colorDispatcherEPNS_5ArrayE($15,$72)|0);
   HEAP32[$3>>2] = $81;
   $82 = ($81|0)==(0|0);
   $83 = $81;
   do {
    if (!($82)) {
     $84 = ((($7)) + 848|0);
     $85 = HEAP32[$84>>2]|0;
     $86 = ((($7)) + 852|0);
     $87 = HEAP32[$86>>2]|0;
     $88 = ($85|0)==($87|0);
     if ($88) {
      $91 = ((($7)) + 844|0);
      __ZNSt3__26vectorIPN3osg17AttributeDispatchENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_($91,$3);
      break;
     } else {
      HEAP32[$85>>2] = $83;
      $89 = HEAP32[$84>>2]|0;
      $90 = ((($89)) + 4|0);
      HEAP32[$84>>2] = $90;
      break;
     }
    }
   } while(0);
  }
 } while(0);
 $92 = ((($0)) + 240|0);
 $93 = HEAP32[$92>>2]|0;
 $94 = ($93|0)==(0|0);
 L46: do {
  if (!($94)) {
   $95 = ((($93)) + 64|0);
   $96 = HEAP32[$95>>2]|0;
   switch ($96|0) {
   case 1:  {
    $97 = (__ZN3osg20AttributeDispatchers24secondaryColorDispatcherEPNS_5ArrayE($15,$93)|0);
    $98 = ($97|0)==(0|0);
    if ($98) {
     break L46;
    }
    $99 = HEAP32[$97>>2]|0;
    $100 = ((($99)) + 16|0);
    $101 = HEAP32[$100>>2]|0;
    FUNCTION_TABLE_vii[$101 & 8191]($97,0);
    break L46;
    break;
   }
   case 2:  {
    break;
   }
   default: {
    break L46;
   }
   }
   $102 = (__ZN3osg20AttributeDispatchers24secondaryColorDispatcherEPNS_5ArrayE($15,$93)|0);
   HEAP32[$2>>2] = $102;
   $103 = ($102|0)==(0|0);
   $104 = $102;
   do {
    if (!($103)) {
     $105 = ((($7)) + 848|0);
     $106 = HEAP32[$105>>2]|0;
     $107 = ((($7)) + 852|0);
     $108 = HEAP32[$107>>2]|0;
     $109 = ($106|0)==($108|0);
     if ($109) {
      $112 = ((($7)) + 844|0);
      __ZNSt3__26vectorIPN3osg17AttributeDispatchENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_($112,$2);
      break;
     } else {
      HEAP32[$106>>2] = $104;
      $110 = HEAP32[$105>>2]|0;
      $111 = ((($110)) + 4|0);
      HEAP32[$105>>2] = $111;
      break;
     }
    }
   } while(0);
  }
 } while(0);
 $113 = ((($0)) + 244|0);
 $114 = HEAP32[$113>>2]|0;
 $115 = ($114|0)==(0|0);
 L59: do {
  if (!($115)) {
   $116 = ((($114)) + 64|0);
   $117 = HEAP32[$116>>2]|0;
   switch ($117|0) {
   case 1:  {
    $118 = (__ZN3osg20AttributeDispatchers18fogCoordDispatcherEPNS_5ArrayE($15,$114)|0);
    $119 = ($118|0)==(0|0);
    if ($119) {
     break L59;
    }
    $120 = HEAP32[$118>>2]|0;
    $121 = ((($120)) + 16|0);
    $122 = HEAP32[$121>>2]|0;
    FUNCTION_TABLE_vii[$122 & 8191]($118,0);
    break L59;
    break;
   }
   case 2:  {
    break;
   }
   default: {
    break L59;
   }
   }
   $123 = (__ZN3osg20AttributeDispatchers18fogCoordDispatcherEPNS_5ArrayE($15,$114)|0);
   HEAP32[$6>>2] = $123;
   $124 = ($123|0)==(0|0);
   $125 = $123;
   do {
    if (!($124)) {
     $126 = ((($7)) + 848|0);
     $127 = HEAP32[$126>>2]|0;
     $128 = ((($7)) + 852|0);
     $129 = HEAP32[$128>>2]|0;
     $130 = ($127|0)==($129|0);
     if ($130) {
      $133 = ((($7)) + 844|0);
      __ZNSt3__26vectorIPN3osg17AttributeDispatchENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_($133,$6);
      break;
     } else {
      HEAP32[$127>>2] = $125;
      $131 = HEAP32[$126>>2]|0;
      $132 = ((($131)) + 4|0);
      HEAP32[$126>>2] = $132;
      break;
     }
    }
   } while(0);
  }
 } while(0);
 $134 = ((($7)) + 713|0);
 $135 = HEAP8[$134>>0]|0;
 $136 = ($135<<24>>24)==(0);
 if ($136) {
  $137 = ((($0)) + 184|0);
  $138 = HEAP8[$137>>0]|0;
  $139 = ($138<<24>>24)!=(0);
  $140 = ((($7)) + 711|0);
  $141 = HEAP8[$140>>0]|0;
  $142 = ($141<<24>>24)!=(0);
  $143 = $139 & $142;
  if ($143) {
   label = 52;
  }
 } else {
  label = 52;
 }
 if ((label|0) == 52) {
  $144 = ((($9)) + 104|0);
  $145 = HEAP8[$144>>0]|0;
  $146 = ($145<<24>>24)==(0);
  if ($146) {
   STACKTOP = sp;return;
  }
 }
 $147 = ((($9)) + 72|0);
 $148 = ((($9)) + 84|0);
 $149 = HEAP32[$147>>2]|0;
 $150 = HEAP32[$148>>2]|0;
 HEAP32[$147>>2] = $150;
 HEAP32[$148>>2] = $149;
 $151 = ((($9)) + 76|0);
 $152 = ((($9)) + 88|0);
 $153 = HEAP32[$151>>2]|0;
 $154 = HEAP32[$152>>2]|0;
 HEAP32[$151>>2] = $154;
 HEAP32[$152>>2] = $153;
 $155 = ((($9)) + 80|0);
 $156 = ((($9)) + 92|0);
 $157 = HEAP32[$155>>2]|0;
 $158 = HEAP32[$156>>2]|0;
 HEAP32[$155>>2] = $158;
 HEAP32[$156>>2] = $157;
 $159 = $150;
 $160 = $154;
 $161 = ($160|0)==($159|0);
 $162 = $149;
 $163 = $153;
 if (!($161)) {
  $scevgep$i$i$i$i66 = ((($160)) + -4|0);
  $164 = $scevgep$i$i$i$i66;
  $165 = (($164) - ($150))|0;
  $166 = $165 >>> 2;
  $167 = $166 ^ -1;
  $scevgep5$i$i$i$i67 = (($160) + ($167<<2)|0);
  HEAP32[$151>>2] = $scevgep5$i$i$i$i67;
 }
 $168 = ($162|0)==($163|0);
 if (!($168)) {
  $$sroa$04$08$i = $162;
  while(1) {
   $169 = HEAP32[$$sroa$04$08$i>>2]|0;
   $170 = ((($169)) + 20|0);
   HEAP8[$170>>0] = 0;
   $171 = ((($$sroa$04$08$i)) + 4|0);
   $172 = ($171|0)==($163|0);
   if ($172) {
    break;
   } else {
    $$sroa$04$08$i = $171;
   }
  }
 }
 $173 = ((($0)) + 228|0);
 $174 = HEAP32[$173>>2]|0;
 $175 = ($174|0)==(0|0);
 if (!($175)) {
  $176 = ((($9)) + 28|0);
  $177 = HEAP32[$176>>2]|0;
  __ZN3osg16VertexArrayState8setArrayEPNS0_13ArrayDispatchERNS_5StateEPKNS_5ArrayE($9,$177,$7,$174);
 }
 $178 = HEAP32[$50>>2]|0;
 $179 = ($178|0)==(0|0);
 if (!($179)) {
  $180 = ((($178)) + 64|0);
  $181 = HEAP32[$180>>2]|0;
  $182 = ($181|0)==(4);
  if ($182) {
   $183 = ((($9)) + 32|0);
   $184 = HEAP32[$183>>2]|0;
   __ZN3osg16VertexArrayState8setArrayEPNS0_13ArrayDispatchERNS_5StateEPKNS_5ArrayE($9,$184,$7,$178);
  }
 }
 $185 = HEAP32[$71>>2]|0;
 $186 = ($185|0)==(0|0);
 if (!($186)) {
  $187 = ((($185)) + 64|0);
  $188 = HEAP32[$187>>2]|0;
  $189 = ($188|0)==(4);
  if ($189) {
   $190 = ((($9)) + 36|0);
   $191 = HEAP32[$190>>2]|0;
   __ZN3osg16VertexArrayState8setArrayEPNS0_13ArrayDispatchERNS_5StateEPKNS_5ArrayE($9,$191,$7,$185);
  }
 }
 $192 = HEAP32[$92>>2]|0;
 $193 = ($192|0)==(0|0);
 if (!($193)) {
  $194 = ((($192)) + 64|0);
  $195 = HEAP32[$194>>2]|0;
  $196 = ($195|0)==(4);
  if ($196) {
   $197 = ((($9)) + 40|0);
   $198 = HEAP32[$197>>2]|0;
   __ZN3osg16VertexArrayState8setArrayEPNS0_13ArrayDispatchERNS_5StateEPKNS_5ArrayE($9,$198,$7,$192);
  }
 }
 $199 = HEAP32[$113>>2]|0;
 $200 = ($199|0)==(0|0);
 if (!($200)) {
  $201 = ((($199)) + 64|0);
  $202 = HEAP32[$201>>2]|0;
  $203 = ($202|0)==(4);
  if ($203) {
   $204 = ((($9)) + 44|0);
   $205 = HEAP32[$204>>2]|0;
   __ZN3osg16VertexArrayState8setArrayEPNS0_13ArrayDispatchERNS_5StateEPKNS_5ArrayE($9,$205,$7,$199);
  }
 }
 $206 = ((($0)) + 248|0);
 $207 = ((($0)) + 252|0);
 $208 = HEAP32[$207>>2]|0;
 $209 = HEAP32[$206>>2]|0;
 $210 = ($208|0)==($209|0);
 if (!($210)) {
  $211 = ((($9)) + 48|0);
  $$06579 = 0;$216 = $209;$269 = $208;
  while(1) {
   $217 = $216;
   $218 = (($217) + ($$06579<<2)|0);
   $219 = HEAP32[$218>>2]|0;
   $220 = ($219|0)==(0|0);
   if ($220) {
    $226 = $216;$227 = $269;
   } else {
    $221 = HEAP32[$211>>2]|0;
    $222 = (($221) + ($$06579<<2)|0);
    $223 = HEAP32[$222>>2]|0;
    __ZN3osg16VertexArrayState8setArrayEPNS0_13ArrayDispatchERNS_5StateEPKNS_5ArrayE($9,$223,$7,$219);
    $$pre = HEAP32[$207>>2]|0;
    $$pre83 = HEAP32[$206>>2]|0;
    $226 = $$pre83;$227 = $$pre;
   }
   $224 = (($$06579) + 1)|0;
   $225 = (($227) - ($226))|0;
   $228 = $225 >> 2;
   $229 = ($224>>>0)<($228>>>0);
   if ($229) {
    $$06579 = $224;$216 = $226;$269 = $227;
   } else {
    break;
   }
  }
 }
 if (!($14)) {
  $212 = HEAP32[$12>>2]|0;
  $213 = HEAP32[$10>>2]|0;
  $214 = ($212|0)==($213|0);
  if (!($214)) {
   $215 = ((($9)) + 60|0);
   $$06478 = 0;$230 = $213;$270 = $212;
   while(1) {
    $231 = $230;
    $232 = (($231) + ($$06478<<2)|0);
    $233 = HEAP32[$232>>2]|0;
    $234 = ($233|0)==(0|0);
    do {
     if ($234) {
      $243 = $230;$244 = $270;
     } else {
      $235 = ((($233)) + 64|0);
      $236 = HEAP32[$235>>2]|0;
      $237 = ($236|0)==(4);
      if (!($237)) {
       $243 = $230;$244 = $270;
       break;
      }
      $238 = HEAP32[$215>>2]|0;
      $239 = (($238) + ($$06478<<2)|0);
      $240 = HEAP32[$239>>2]|0;
      __ZN3osg16VertexArrayState8setArrayEPNS0_13ArrayDispatchERNS_5StateEPKNS_5ArrayE($9,$240,$7,$233);
      $$pre84 = HEAP32[$12>>2]|0;
      $$pre85 = HEAP32[$10>>2]|0;
      $243 = $$pre85;$244 = $$pre84;
     }
    } while(0);
    $241 = (($$06478) + 1)|0;
    $242 = (($244) - ($243))|0;
    $245 = $242 >> 2;
    $246 = ($241>>>0)<($245>>>0);
    if ($246) {
     $$06478 = $241;$230 = $243;$270 = $244;
    } else {
     break;
    }
   }
  }
 }
 $247 = ((($9)) + 84|0);
 $248 = HEAP32[$247>>2]|0;
 $249 = HEAP32[$152>>2]|0;
 $250 = ($248|0)==($249|0);
 if ($250) {
  STACKTOP = sp;return;
 } else {
  $$sroa$08$013$i = $248;$271 = $249;
 }
 while(1) {
  $258 = HEAP32[$$sroa$08$013$i>>2]|0;
  $259 = ((($258)) + 20|0);
  $260 = HEAP8[$259>>0]|0;
  $261 = ($260<<24>>24)==(0);
  if ($261) {
   $262 = HEAP32[$258>>2]|0;
   $263 = ((($262)) + 36|0);
   $264 = HEAP32[$263>>2]|0;
   FUNCTION_TABLE_vii[$264 & 8191]($258,$7);
   $265 = ((($258)) + 12|0);
   HEAP32[$265>>2] = 0;
   $266 = ((($258)) + 16|0);
   HEAP32[$266>>2] = -1;
   $$pre$i = HEAP32[$152>>2]|0;
   $251 = $$pre$i;
  } else {
   $251 = $271;
  }
  $267 = ((($$sroa$08$013$i)) + 4|0);
  $268 = ($267|0)==($251|0);
  if ($268) {
   break;
  } else {
   $$sroa$08$013$i = $267;$271 = $251;
  }
 }
 $$pre16$i = HEAP32[$247>>2]|0;
 $252 = ($251|0)==($$pre16$i|0);
 if ($252) {
  STACKTOP = sp;return;
 }
 $scevgep$i$i$i$i = ((($251)) + -4|0);
 $253 = $scevgep$i$i$i$i;
 $254 = $$pre16$i;
 $255 = (($253) - ($254))|0;
 $256 = $255 >>> 2;
 $257 = $256 ^ -1;
 $scevgep5$i$i$i$i = (($251) + ($257<<2)|0);
 HEAP32[$152>>2] = $scevgep5$i$i$i$i;
 STACKTOP = sp;return;
}
function __ZNK3osg8Geometry28drawPrimitivesImplementationERNS_10RenderInfoE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$020 = 0, $$020$us = 0, $$pre = 0, $$pre22 = 0, $$pre23 = 0, $$sroa$02$06$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 182|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)==(0);
 if ($5) {
  $16 = 0;
 } else {
  $6 = ((($0)) + 183|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = ($7<<24>>24)!=(0);
  $16 = $8;
 }
 $9 = ((($2)) + 712|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = ($10<<24>>24)==(0);
 if ($11) {
  $12 = ((($2)) + 710|0);
  $13 = HEAP8[$12>>0]|0;
  $14 = ($13<<24>>24)!=(0);
  $15 = $16 & $14;
  $34 = $15;
 } else {
  $34 = 1;
 }
 $17 = ((($2)) + 844|0);
 $18 = ((($2)) + 848|0);
 $19 = ((($0)) + 216|0);
 $20 = ((($0)) + 220|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = HEAP32[$19>>2]|0;
 $23 = ($21|0)==($22|0);
 $24 = $22;
 if ($23) {
  return;
 }
 $25 = HEAP32[$17>>2]|0;
 $26 = HEAP32[$18>>2]|0;
 $27 = ($25|0)==($26|0);
 if ($27) {
  $$020$us = 0;$29 = $24;
  while(1) {
   $28 = (($29) + ($$020$us<<2)|0);
   $30 = HEAP32[$28>>2]|0;
   $31 = HEAP32[$30>>2]|0;
   $32 = ((($31)) + 184|0);
   $33 = HEAP32[$32>>2]|0;
   FUNCTION_TABLE_viii[$33 & 8191]($30,$2,$34);
   $35 = (($$020$us) + 1)|0;
   $36 = HEAP32[$20>>2]|0;
   $37 = HEAP32[$19>>2]|0;
   $38 = (($36) - ($37))|0;
   $39 = $38 >> 2;
   $40 = ($35|0)==($39|0);
   $41 = $37;
   if ($40) {
    break;
   } else {
    $$020$us = $35;$29 = $41;
   }
  }
  return;
 } else {
  $$020 = 0;$42 = $25;$44 = $26;$65 = $24;
 }
 while(1) {
  $43 = ($42|0)==($44|0);
  if ($43) {
   $53 = $65;
  } else {
   $$sroa$02$06$i = $42;
   while(1) {
    $45 = HEAP32[$$sroa$02$06$i>>2]|0;
    $46 = HEAP32[$45>>2]|0;
    $47 = ((($46)) + 16|0);
    $48 = HEAP32[$47>>2]|0;
    FUNCTION_TABLE_vii[$48 & 8191]($45,$$020);
    $49 = ((($$sroa$02$06$i)) + 4|0);
    $50 = HEAP32[$18>>2]|0;
    $51 = ($49|0)==($50|0);
    if ($51) {
     break;
    } else {
     $$sroa$02$06$i = $49;
    }
   }
   $$pre23 = HEAP32[$19>>2]|0;
   $53 = $$pre23;
  }
  $52 = (($53) + ($$020<<2)|0);
  $54 = HEAP32[$52>>2]|0;
  $55 = HEAP32[$54>>2]|0;
  $56 = ((($55)) + 184|0);
  $57 = HEAP32[$56>>2]|0;
  FUNCTION_TABLE_viii[$57 & 8191]($54,$2,$34);
  $58 = (($$020) + 1)|0;
  $59 = HEAP32[$20>>2]|0;
  $60 = HEAP32[$19>>2]|0;
  $61 = (($59) - ($60))|0;
  $62 = $61 >> 2;
  $63 = ($58|0)==($62|0);
  if ($63) {
   break;
  }
  $64 = $60;
  $$pre = HEAP32[$17>>2]|0;
  $$pre22 = HEAP32[$18>>2]|0;
  $$020 = $58;$42 = $$pre;$44 = $$pre22;$65 = $64;
 }
 return;
}
function __ZNSt3__26vectorIPN3osg17AttributeDispatchENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(1073741823);
 if ($8) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $9 = ((($0)) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) - ($4))|0;
 $12 = $11 >> 2;
 $13 = ($12>>>0)<(536870911);
 $14 = $11 >> 1;
 $15 = ($14>>>0)<($7>>>0);
 $$sroa$speculated$i = $15 ? $7 : $14;
 $$sroa$speculated$$i = $13 ? $$sroa$speculated$i : 1073741823;
 $16 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($16) {
   $26 = 0;
  } else {
   $17 = ($$sroa$speculated$$i>>>0)>(1073741823);
   if (!($17)) {
    $23 = $$sroa$speculated$$i << 2;
    $24 = (__Znwj($23)|0);
    $26 = $24;
    break;
   }
   $18 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($18|0),(204840|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if ($20) {
    $21 = ___cxa_find_matching_catch_2()|0;
    $22 = tempRet0;
    ___cxa_free_exception(($18|0));
    ___resumeException($21|0);
    // unreachable;
   } else {
    HEAP32[$18>>2] = (99824);
    ___cxa_throw(($18|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $25 = (($26) + ($6<<2)|0);
 $27 = (($26) + ($$sroa$speculated$$i<<2)|0);
 $28 = $27;
 $29 = HEAP32[$1>>2]|0;
 HEAP32[$25>>2] = $29;
 $30 = ((($25)) + 4|0);
 $31 = $30;
 $32 = (0 - ($6))|0;
 $33 = (($25) + ($32<<2)|0);
 $34 = $33;
 $35 = ($5|0)>(0);
 if ($35) {
  $36 = $4;
  _memcpy(($33|0),($36|0),($5|0))|0;
 }
 HEAP32[$0>>2] = $34;
 HEAP32[$2>>2] = $31;
 HEAP32[$9>>2] = $28;
 $37 = ($4|0)==(0);
 if ($37) {
  return;
 }
 $38 = $4;
 __ZdlPv($38);
 return;
}
function __ZNSt3__26__treeIPN3osg12BufferObjectENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 } else {
  $3 = HEAP32[$1>>2]|0;
  __ZNSt3__26__treeIPN3osg12BufferObjectENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($0,$3);
  $4 = ((($1)) + 4|0);
  $5 = HEAP32[$4>>2]|0;
  __ZNSt3__26__treeIPN3osg12BufferObjectENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($0,$5);
  __ZdlPv($1);
  return;
 }
}
function __ZNK3osg8Geometry12getArrayListERNSt3__26vectorINS_7ref_ptrINS_5ArrayEEENS1_9allocatorIS5_EEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$03693 = 0, $$037 = 0, $$03894 = 0, $$pre = 0, $$pre$i = 0, $$pre$i41 = 0, $$pre$i53 = 0, $$pre$i57 = 0, $$pre$i69 = 0, $$pre$i73 = 0, $$pre$i85 = 0, $$pre96 = 0, $$pre97 = 0, $$pre98 = 0, $$pre99 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0;
 var $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0;
 var $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0;
 var $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0;
 var $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0;
 var $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0;
 var $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0;
 var $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $2 = sp + 24|0;
 $3 = sp + 20|0;
 $4 = sp + 16|0;
 $5 = sp + 12|0;
 $6 = sp + 8|0;
 $7 = sp + 4|0;
 $8 = sp;
 $9 = ((($1)) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$1>>2]|0;
 $12 = (($10) - ($11))|0;
 $13 = ((($0)) + 228|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(0|0);
 if (!($15)) {
  HEAP32[$2>>2] = $14;
  $16 = ((($14)) + 8|0);
  $17 = HEAP32[$16>>2]|0;HEAP32[$16>>2] = (($17+1)|0);
  $$pre = HEAP32[$9>>2]|0;
  $18 = ((($1)) + 8|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = ($$pre|0)==($19|0);
  if ($20) {
   __THREW__ = 0;
   invoke_vii(3774,($1|0),($2|0));
   $27 = __THREW__; __THREW__ = 0;
   $28 = $27&1;
   if ($28) {
    $34 = ___cxa_find_matching_catch_2()|0;
    $35 = tempRet0;
    $36 = HEAP32[$2>>2]|0;
    $37 = ($36|0)==(0|0);
    if (!($37)) {
     $38 = ((($36)) + 8|0);
     $39 = HEAP32[$38>>2]|0;HEAP32[$38>>2] = (($39-1)|0);
     $40 = ($39|0)==(1);
     if ($40) {
      __THREW__ = 0;
      invoke_viii(3262,($36|0),1,1);
      $41 = __THREW__; __THREW__ = 0;
      $42 = $41&1;
      if ($42) {
       $259 = ___cxa_find_matching_catch_3(0|0)|0;
       $260 = tempRet0;
       ___clang_call_terminate($259);
       // unreachable;
      }
     }
    }
    $$0 = $34;$$037 = $35;
    ___resumeException($$0|0);
    // unreachable;
   }
  } else {
   $21 = HEAP32[$2>>2]|0;
   HEAP32[$$pre>>2] = $21;
   $22 = ($21|0)==(0|0);
   if ($22) {
    $26 = $$pre;
   } else {
    $23 = ((($21)) + 8|0);
    $24 = HEAP32[$23>>2]|0;HEAP32[$23>>2] = (($24+1)|0);
    $$pre$i41 = HEAP32[$9>>2]|0;
    $26 = $$pre$i41;
   }
   $25 = ((($26)) + 4|0);
   HEAP32[$9>>2] = $25;
  }
  $29 = HEAP32[$2>>2]|0;
  $30 = ($29|0)==(0|0);
  if (!($30)) {
   $31 = ((($29)) + 8|0);
   $32 = HEAP32[$31>>2]|0;HEAP32[$31>>2] = (($32-1)|0);
   $33 = ($32|0)==(1);
   if ($33) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($29,1,1);
   }
  }
 }
 $43 = ((($0)) + 232|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = ($44|0)==(0|0);
 if (!($45)) {
  HEAP32[$3>>2] = $44;
  $46 = ((($44)) + 8|0);
  $47 = HEAP32[$46>>2]|0;HEAP32[$46>>2] = (($47+1)|0);
  $48 = HEAP32[$9>>2]|0;
  $49 = ((($1)) + 8|0);
  $50 = HEAP32[$49>>2]|0;
  $51 = ($48|0)==($50|0);
  if ($51) {
   __THREW__ = 0;
   invoke_vii(3774,($1|0),($3|0));
   $58 = __THREW__; __THREW__ = 0;
   $59 = $58&1;
   if ($59) {
    $65 = ___cxa_find_matching_catch_2()|0;
    $66 = tempRet0;
    $67 = HEAP32[$3>>2]|0;
    $68 = ($67|0)==(0|0);
    if (!($68)) {
     $69 = ((($67)) + 8|0);
     $70 = HEAP32[$69>>2]|0;HEAP32[$69>>2] = (($70-1)|0);
     $71 = ($70|0)==(1);
     if ($71) {
      __THREW__ = 0;
      invoke_viii(3262,($67|0),1,1);
      $72 = __THREW__; __THREW__ = 0;
      $73 = $72&1;
      if ($73) {
       $259 = ___cxa_find_matching_catch_3(0|0)|0;
       $260 = tempRet0;
       ___clang_call_terminate($259);
       // unreachable;
      }
     }
    }
    $$0 = $65;$$037 = $66;
    ___resumeException($$0|0);
    // unreachable;
   }
  } else {
   $52 = HEAP32[$3>>2]|0;
   HEAP32[$48>>2] = $52;
   $53 = ($52|0)==(0|0);
   if ($53) {
    $57 = $48;
   } else {
    $54 = ((($52)) + 8|0);
    $55 = HEAP32[$54>>2]|0;HEAP32[$54>>2] = (($55+1)|0);
    $$pre$i57 = HEAP32[$9>>2]|0;
    $57 = $$pre$i57;
   }
   $56 = ((($57)) + 4|0);
   HEAP32[$9>>2] = $56;
  }
  $60 = HEAP32[$3>>2]|0;
  $61 = ($60|0)==(0|0);
  if (!($61)) {
   $62 = ((($60)) + 8|0);
   $63 = HEAP32[$62>>2]|0;HEAP32[$62>>2] = (($63-1)|0);
   $64 = ($63|0)==(1);
   if ($64) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($60,1,1);
   }
  }
 }
 $74 = ((($0)) + 236|0);
 $75 = HEAP32[$74>>2]|0;
 $76 = ($75|0)==(0|0);
 if (!($76)) {
  HEAP32[$4>>2] = $75;
  $77 = ((($75)) + 8|0);
  $78 = HEAP32[$77>>2]|0;HEAP32[$77>>2] = (($78+1)|0);
  $79 = HEAP32[$9>>2]|0;
  $80 = ((($1)) + 8|0);
  $81 = HEAP32[$80>>2]|0;
  $82 = ($79|0)==($81|0);
  if ($82) {
   __THREW__ = 0;
   invoke_vii(3774,($1|0),($4|0));
   $89 = __THREW__; __THREW__ = 0;
   $90 = $89&1;
   if ($90) {
    $96 = ___cxa_find_matching_catch_2()|0;
    $97 = tempRet0;
    $98 = HEAP32[$4>>2]|0;
    $99 = ($98|0)==(0|0);
    if (!($99)) {
     $100 = ((($98)) + 8|0);
     $101 = HEAP32[$100>>2]|0;HEAP32[$100>>2] = (($101-1)|0);
     $102 = ($101|0)==(1);
     if ($102) {
      __THREW__ = 0;
      invoke_viii(3262,($98|0),1,1);
      $103 = __THREW__; __THREW__ = 0;
      $104 = $103&1;
      if ($104) {
       $259 = ___cxa_find_matching_catch_3(0|0)|0;
       $260 = tempRet0;
       ___clang_call_terminate($259);
       // unreachable;
      }
     }
    }
    $$0 = $96;$$037 = $97;
    ___resumeException($$0|0);
    // unreachable;
   }
  } else {
   $83 = HEAP32[$4>>2]|0;
   HEAP32[$79>>2] = $83;
   $84 = ($83|0)==(0|0);
   if ($84) {
    $88 = $79;
   } else {
    $85 = ((($83)) + 8|0);
    $86 = HEAP32[$85>>2]|0;HEAP32[$85>>2] = (($86+1)|0);
    $$pre$i73 = HEAP32[$9>>2]|0;
    $88 = $$pre$i73;
   }
   $87 = ((($88)) + 4|0);
   HEAP32[$9>>2] = $87;
  }
  $91 = HEAP32[$4>>2]|0;
  $92 = ($91|0)==(0|0);
  if (!($92)) {
   $93 = ((($91)) + 8|0);
   $94 = HEAP32[$93>>2]|0;HEAP32[$93>>2] = (($94-1)|0);
   $95 = ($94|0)==(1);
   if ($95) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($91,1,1);
   }
  }
 }
 $105 = ((($0)) + 240|0);
 $106 = HEAP32[$105>>2]|0;
 $107 = ($106|0)==(0|0);
 if (!($107)) {
  HEAP32[$5>>2] = $106;
  $108 = ((($106)) + 8|0);
  $109 = HEAP32[$108>>2]|0;HEAP32[$108>>2] = (($109+1)|0);
  $110 = HEAP32[$9>>2]|0;
  $111 = ((($1)) + 8|0);
  $112 = HEAP32[$111>>2]|0;
  $113 = ($110|0)==($112|0);
  if ($113) {
   __THREW__ = 0;
   invoke_vii(3774,($1|0),($5|0));
   $120 = __THREW__; __THREW__ = 0;
   $121 = $120&1;
   if ($121) {
    $127 = ___cxa_find_matching_catch_2()|0;
    $128 = tempRet0;
    $129 = HEAP32[$5>>2]|0;
    $130 = ($129|0)==(0|0);
    if (!($130)) {
     $131 = ((($129)) + 8|0);
     $132 = HEAP32[$131>>2]|0;HEAP32[$131>>2] = (($132-1)|0);
     $133 = ($132|0)==(1);
     if ($133) {
      __THREW__ = 0;
      invoke_viii(3262,($129|0),1,1);
      $134 = __THREW__; __THREW__ = 0;
      $135 = $134&1;
      if ($135) {
       $259 = ___cxa_find_matching_catch_3(0|0)|0;
       $260 = tempRet0;
       ___clang_call_terminate($259);
       // unreachable;
      }
     }
    }
    $$0 = $127;$$037 = $128;
    ___resumeException($$0|0);
    // unreachable;
   }
  } else {
   $114 = HEAP32[$5>>2]|0;
   HEAP32[$110>>2] = $114;
   $115 = ($114|0)==(0|0);
   if ($115) {
    $119 = $110;
   } else {
    $116 = ((($114)) + 8|0);
    $117 = HEAP32[$116>>2]|0;HEAP32[$116>>2] = (($117+1)|0);
    $$pre$i85 = HEAP32[$9>>2]|0;
    $119 = $$pre$i85;
   }
   $118 = ((($119)) + 4|0);
   HEAP32[$9>>2] = $118;
  }
  $122 = HEAP32[$5>>2]|0;
  $123 = ($122|0)==(0|0);
  if (!($123)) {
   $124 = ((($122)) + 8|0);
   $125 = HEAP32[$124>>2]|0;HEAP32[$124>>2] = (($125-1)|0);
   $126 = ($125|0)==(1);
   if ($126) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($122,1,1);
   }
  }
 }
 $136 = ((($0)) + 244|0);
 $137 = HEAP32[$136>>2]|0;
 $138 = ($137|0)==(0|0);
 if (!($138)) {
  HEAP32[$6>>2] = $137;
  $145 = ((($137)) + 8|0);
  $146 = HEAP32[$145>>2]|0;HEAP32[$145>>2] = (($146+1)|0);
  $147 = HEAP32[$9>>2]|0;
  $148 = ((($1)) + 8|0);
  $149 = HEAP32[$148>>2]|0;
  $150 = ($147|0)==($149|0);
  if ($150) {
   __THREW__ = 0;
   invoke_vii(3774,($1|0),($6|0));
   $157 = __THREW__; __THREW__ = 0;
   $158 = $157&1;
   if ($158) {
    $164 = ___cxa_find_matching_catch_2()|0;
    $165 = tempRet0;
    $166 = HEAP32[$6>>2]|0;
    $167 = ($166|0)==(0|0);
    if (!($167)) {
     $168 = ((($166)) + 8|0);
     $169 = HEAP32[$168>>2]|0;HEAP32[$168>>2] = (($169-1)|0);
     $170 = ($169|0)==(1);
     if ($170) {
      __THREW__ = 0;
      invoke_viii(3262,($166|0),1,1);
      $171 = __THREW__; __THREW__ = 0;
      $172 = $171&1;
      if ($172) {
       $259 = ___cxa_find_matching_catch_3(0|0)|0;
       $260 = tempRet0;
       ___clang_call_terminate($259);
       // unreachable;
      }
     }
    }
    $$0 = $164;$$037 = $165;
    ___resumeException($$0|0);
    // unreachable;
   }
  } else {
   $151 = HEAP32[$6>>2]|0;
   HEAP32[$147>>2] = $151;
   $152 = ($151|0)==(0|0);
   if ($152) {
    $156 = $147;
   } else {
    $153 = ((($151)) + 8|0);
    $154 = HEAP32[$153>>2]|0;HEAP32[$153>>2] = (($154+1)|0);
    $$pre$i69 = HEAP32[$9>>2]|0;
    $156 = $$pre$i69;
   }
   $155 = ((($156)) + 4|0);
   HEAP32[$9>>2] = $155;
  }
  $159 = HEAP32[$6>>2]|0;
  $160 = ($159|0)==(0|0);
  if (!($160)) {
   $161 = ((($159)) + 8|0);
   $162 = HEAP32[$161>>2]|0;HEAP32[$161>>2] = (($162-1)|0);
   $163 = ($162|0)==(1);
   if ($163) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($159,1,1);
   }
  }
 }
 $139 = ((($0)) + 248|0);
 $140 = ((($0)) + 252|0);
 $141 = HEAP32[$140>>2]|0;
 $142 = HEAP32[$139>>2]|0;
 $143 = ($141|0)==($142|0);
 L106: do {
  if (!($143)) {
   $144 = ((($1)) + 8|0);
   $$03894 = 0;$179 = $142;$261 = $141;
   while(1) {
    $180 = $179;
    $181 = (($180) + ($$03894<<2)|0);
    $182 = HEAP32[$181>>2]|0;
    $183 = ($182|0)==(0|0);
    if ($183) {
     $213 = $179;$214 = $261;
    } else {
     HEAP32[$7>>2] = $182;
     $184 = ((($182)) + 8|0);
     $185 = HEAP32[$184>>2]|0;HEAP32[$184>>2] = (($185+1)|0);
     $186 = HEAP32[$9>>2]|0;
     $187 = HEAP32[$144>>2]|0;
     $188 = ($186|0)==($187|0);
     if ($188) {
      __THREW__ = 0;
      invoke_vii(3774,($1|0),($7|0));
      $195 = __THREW__; __THREW__ = 0;
      $196 = $195&1;
      if ($196) {
       break;
      }
     } else {
      $189 = HEAP32[$7>>2]|0;
      HEAP32[$186>>2] = $189;
      $190 = ($189|0)==(0|0);
      if ($190) {
       $194 = $186;
      } else {
       $191 = ((($189)) + 8|0);
       $192 = HEAP32[$191>>2]|0;HEAP32[$191>>2] = (($192+1)|0);
       $$pre$i53 = HEAP32[$9>>2]|0;
       $194 = $$pre$i53;
      }
      $193 = ((($194)) + 4|0);
      HEAP32[$9>>2] = $193;
     }
     $197 = HEAP32[$7>>2]|0;
     $198 = ($197|0)==(0|0);
     if (!($198)) {
      $199 = ((($197)) + 8|0);
      $200 = HEAP32[$199>>2]|0;HEAP32[$199>>2] = (($200-1)|0);
      $201 = ($200|0)==(1);
      if ($201) {
       __ZNK3osg10Referenced24signalObserversAndDeleteEbb($197,1,1);
      }
     }
     $$pre96 = HEAP32[$140>>2]|0;
     $$pre97 = HEAP32[$139>>2]|0;
     $213 = $$pre97;$214 = $$pre96;
    }
    $211 = (($$03894) + 1)|0;
    $212 = (($214) - ($213))|0;
    $215 = $212 >> 2;
    $216 = ($211>>>0)<($215>>>0);
    if ($216) {
     $$03894 = $211;$179 = $213;$261 = $214;
    } else {
     break L106;
    }
   }
   $202 = ___cxa_find_matching_catch_2()|0;
   $203 = tempRet0;
   $204 = HEAP32[$7>>2]|0;
   $205 = ($204|0)==(0|0);
   if (!($205)) {
    $206 = ((($204)) + 8|0);
    $207 = HEAP32[$206>>2]|0;HEAP32[$206>>2] = (($207-1)|0);
    $208 = ($207|0)==(1);
    if ($208) {
     __THREW__ = 0;
     invoke_viii(3262,($204|0),1,1);
     $209 = __THREW__; __THREW__ = 0;
     $210 = $209&1;
     if ($210) {
      $259 = ___cxa_find_matching_catch_3(0|0)|0;
      $260 = tempRet0;
      ___clang_call_terminate($259);
      // unreachable;
     }
    }
   }
   $$0 = $202;$$037 = $203;
   ___resumeException($$0|0);
   // unreachable;
  }
 } while(0);
 $173 = ((($0)) + 260|0);
 $174 = ((($0)) + 264|0);
 $175 = HEAP32[$174>>2]|0;
 $176 = HEAP32[$173>>2]|0;
 $177 = ($175|0)==($176|0);
 if ($177) {
  $217 = HEAP32[$9>>2]|0;
  $218 = HEAP32[$1>>2]|0;
  $219 = (($217) - ($218))|0;
  $220 = ($219|0)!=($12|0);
  STACKTOP = sp;return ($220|0);
 }
 $178 = ((($1)) + 8|0);
 $$03693 = 0;$221 = $176;$262 = $175;
 while(1) {
  $222 = $221;
  $223 = (($222) + ($$03693<<2)|0);
  $224 = HEAP32[$223>>2]|0;
  $225 = ($224|0)==(0|0);
  if ($225) {
   $255 = $221;$256 = $262;
  } else {
   HEAP32[$8>>2] = $224;
   $226 = ((($224)) + 8|0);
   $227 = HEAP32[$226>>2]|0;HEAP32[$226>>2] = (($227+1)|0);
   $228 = HEAP32[$9>>2]|0;
   $229 = HEAP32[$178>>2]|0;
   $230 = ($228|0)==($229|0);
   if ($230) {
    __THREW__ = 0;
    invoke_vii(3774,($1|0),($8|0));
    $237 = __THREW__; __THREW__ = 0;
    $238 = $237&1;
    if ($238) {
     break;
    }
   } else {
    $231 = HEAP32[$8>>2]|0;
    HEAP32[$228>>2] = $231;
    $232 = ($231|0)==(0|0);
    if ($232) {
     $236 = $228;
    } else {
     $233 = ((($231)) + 8|0);
     $234 = HEAP32[$233>>2]|0;HEAP32[$233>>2] = (($234+1)|0);
     $$pre$i = HEAP32[$9>>2]|0;
     $236 = $$pre$i;
    }
    $235 = ((($236)) + 4|0);
    HEAP32[$9>>2] = $235;
   }
   $239 = HEAP32[$8>>2]|0;
   $240 = ($239|0)==(0|0);
   if (!($240)) {
    $241 = ((($239)) + 8|0);
    $242 = HEAP32[$241>>2]|0;HEAP32[$241>>2] = (($242-1)|0);
    $243 = ($242|0)==(1);
    if ($243) {
     __ZNK3osg10Referenced24signalObserversAndDeleteEbb($239,1,1);
    }
   }
   $$pre98 = HEAP32[$174>>2]|0;
   $$pre99 = HEAP32[$173>>2]|0;
   $255 = $$pre99;$256 = $$pre98;
  }
  $253 = (($$03693) + 1)|0;
  $254 = (($256) - ($255))|0;
  $257 = $254 >> 2;
  $258 = ($253>>>0)<($257>>>0);
  if ($258) {
   $$03693 = $253;$221 = $255;$262 = $256;
  } else {
   label = 90;
   break;
  }
 }
 if ((label|0) == 90) {
  $217 = HEAP32[$9>>2]|0;
  $218 = HEAP32[$1>>2]|0;
  $219 = (($217) - ($218))|0;
  $220 = ($219|0)!=($12|0);
  STACKTOP = sp;return ($220|0);
 }
 $244 = ___cxa_find_matching_catch_2()|0;
 $245 = tempRet0;
 $246 = HEAP32[$8>>2]|0;
 $247 = ($246|0)==(0|0);
 if (!($247)) {
  $248 = ((($246)) + 8|0);
  $249 = HEAP32[$248>>2]|0;HEAP32[$248>>2] = (($249-1)|0);
  $250 = ($249|0)==(1);
  if ($250) {
   __THREW__ = 0;
   invoke_viii(3262,($246|0),1,1);
   $251 = __THREW__; __THREW__ = 0;
   $252 = $251&1;
   if ($252) {
    $259 = ___cxa_find_matching_catch_3(0|0)|0;
    $260 = tempRet0;
    ___clang_call_terminate($259);
    // unreachable;
   }
  }
 }
 $$0 = $244;$$037 = $245;
 ___resumeException($$0|0);
 // unreachable;
 return (0)|0;
}
function __ZNSt3__26vectorIPN3osg12DrawElementsENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(1073741823);
 if ($8) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $9 = ((($0)) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) - ($4))|0;
 $12 = $11 >> 2;
 $13 = ($12>>>0)<(536870911);
 $14 = $11 >> 1;
 $15 = ($14>>>0)<($7>>>0);
 $$sroa$speculated$i = $15 ? $7 : $14;
 $$sroa$speculated$$i = $13 ? $$sroa$speculated$i : 1073741823;
 $16 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($16) {
   $26 = 0;
  } else {
   $17 = ($$sroa$speculated$$i>>>0)>(1073741823);
   if (!($17)) {
    $23 = $$sroa$speculated$$i << 2;
    $24 = (__Znwj($23)|0);
    $26 = $24;
    break;
   }
   $18 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($18|0),(204840|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if ($20) {
    $21 = ___cxa_find_matching_catch_2()|0;
    $22 = tempRet0;
    ___cxa_free_exception(($18|0));
    ___resumeException($21|0);
    // unreachable;
   } else {
    HEAP32[$18>>2] = (99824);
    ___cxa_throw(($18|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $25 = (($26) + ($6<<2)|0);
 $27 = (($26) + ($$sroa$speculated$$i<<2)|0);
 $28 = $27;
 $29 = HEAP32[$1>>2]|0;
 HEAP32[$25>>2] = $29;
 $30 = ((($25)) + 4|0);
 $31 = $30;
 $32 = (0 - ($6))|0;
 $33 = (($25) + ($32<<2)|0);
 $34 = $33;
 $35 = ($5|0)>(0);
 if ($35) {
  $36 = $4;
  _memcpy(($33|0),($36|0),($5|0))|0;
 }
 HEAP32[$0>>2] = $34;
 HEAP32[$2>>2] = $31;
 HEAP32[$9>>2] = $28;
 $37 = ($4|0)==(0);
 if ($37) {
  return;
 }
 $38 = $4;
 __ZdlPv($38);
 return;
}
function __ZNSt3__26vectorIN3osg7ref_ptrINS1_5ArrayEEENS_9allocatorIS4_EEE21__push_back_slow_pathIKS4_EEvRT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$06$i$i = 0, $$pre = 0, $$pre$i = 0, $$pre38 = 0, $$pre39 = 0, $$sroa$7$0 = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(1073741823);
 $9 = $4;
 $10 = $3;
 if ($8) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $11 = ((($0)) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) - ($4))|0;
 $14 = $13 >> 2;
 $15 = ($14>>>0)<(536870911);
 $16 = $13 >> 1;
 $17 = ($16>>>0)<($7>>>0);
 $$sroa$speculated$i = $17 ? $7 : $16;
 $$sroa$speculated$$i = $15 ? $$sroa$speculated$i : 1073741823;
 $18 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($18) {
   $28 = 0;
  } else {
   $19 = ($$sroa$speculated$$i>>>0)>(1073741823);
   if (!($19)) {
    $25 = $$sroa$speculated$$i << 2;
    $26 = (__Znwj($25)|0);
    $28 = $26;
    break;
   }
   $20 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($20|0),(204840|0));
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if ($22) {
    $23 = ___cxa_find_matching_catch_2()|0;
    $24 = tempRet0;
    ___cxa_free_exception(($20|0));
    ___resumeException($23|0);
    // unreachable;
   } else {
    HEAP32[$20>>2] = (99824);
    ___cxa_throw(($20|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $27 = (($28) + ($6<<2)|0);
 $29 = $27;
 $30 = (($28) + ($$sroa$speculated$$i<<2)|0);
 $31 = $30;
 $32 = HEAP32[$1>>2]|0;
 HEAP32[$27>>2] = $32;
 $33 = ($32|0)==(0|0);
 if ($33) {
  $38 = $10;$40 = $9;
 } else {
  $34 = ((($32)) + 8|0);
  $35 = HEAP32[$34>>2]|0;HEAP32[$34>>2] = (($35+1)|0);
  $$pre = HEAP32[$0>>2]|0;
  $$pre38 = HEAP32[$2>>2]|0;
  $38 = $$pre38;$40 = $$pre;
 }
 $36 = ((($27)) + 4|0);
 $37 = $36;
 $39 = ($38|0)==($40|0);
 if ($39) {
  $41 = $38;
  $53 = $29;$54 = $41;$56 = $38;
 } else {
  $$06$i$i = $38;$$sroa$7$0 = $29;$44 = $27;
  while(1) {
   $42 = ((($$06$i$i)) + -4|0);
   $43 = ((($44)) + -4|0);
   $45 = HEAP32[$42>>2]|0;
   HEAP32[$43>>2] = $45;
   $46 = ($45|0)==(0|0);
   if (!($46)) {
    $47 = ((($45)) + 8|0);
    $48 = HEAP32[$47>>2]|0;HEAP32[$47>>2] = (($48+1)|0);
   }
   $49 = $$sroa$7$0;
   $50 = ((($49)) + -4|0);
   $51 = $50;
   $52 = ($42|0)==($40|0);
   if ($52) {
    break;
   } else {
    $$06$i$i = $42;$$sroa$7$0 = $51;$44 = $50;
   }
  }
  $$pre$i = HEAP32[$0>>2]|0;
  $$pre39 = HEAP32[$2>>2]|0;
  $53 = $51;$54 = $$pre$i;$56 = $$pre39;
 }
 HEAP32[$0>>2] = $53;
 HEAP32[$2>>2] = $37;
 HEAP32[$11>>2] = $31;
 $55 = $54;
 $57 = ($56|0)==($55|0);
 L25: do {
  if (!($57)) {
   $59 = $56;
   while(1) {
    $58 = ((($59)) + -4|0);
    $60 = HEAP32[$58>>2]|0;
    $61 = ($60|0)==(0|0);
    if (!($61)) {
     $62 = ((($60)) + 8|0);
     $63 = HEAP32[$62>>2]|0;HEAP32[$62>>2] = (($63-1)|0);
     $64 = ($63|0)==(1);
     if ($64) {
      __THREW__ = 0;
      invoke_viii(3262,($60|0),1,1);
      $65 = __THREW__; __THREW__ = 0;
      $66 = $65&1;
      if ($66) {
       break;
      }
     }
    }
    HEAP32[$58>>2] = 0;
    $67 = ($58|0)==($55|0);
    if ($67) {
     break L25;
    } else {
     $59 = $58;
    }
   }
   $68 = ___cxa_find_matching_catch_2()|0;
   $69 = tempRet0;
   ___cxa_call_unexpected(($68|0));
   // unreachable;
  }
 } while(0);
 $70 = ($54|0)==(0);
 if ($70) {
  return;
 }
 $71 = $54;
 __ZdlPv($71);
 return;
}
function __ZN3osg8GeometryC2ERKS0_RKNS_6CopyOpE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$030 = 0, $$10 = 0, $$1040 = 0, $$11 = 0, $$1141 = 0, $$2 = 0, $$232 = 0, $$3 = 0, $$333 = 0, $$4 = 0, $$434 = 0, $$7 = 0, $$737 = 0, $$8 = 0, $$838 = 0, $$9 = 0, $$939 = 0, $$pre$i = 0, $$pre$i56 = 0;
 var $$pre$i61 = 0, $$pre$i69 = 0, $$pre$i72 = 0, $$pre$i81 = 0, $$sroa$0101$0121 = 0, $$sroa$087$0116 = 0, $$sroa$094$0117 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0;
 var $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0;
 var $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0;
 var $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0;
 var $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0;
 var $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0;
 var $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0;
 var $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0;
 var $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp + 8|0;
 $4 = sp + 4|0;
 $5 = sp;
 __ZN3osg8DrawableC2ERKS0_RKNS_6CopyOpE($0,$1,$2);
 HEAP32[$0>>2] = (59536);
 $6 = ((($0)) + 216|0);
 HEAP32[$6>>2] = 0;
 $7 = ((($0)) + 220|0);
 HEAP32[$7>>2] = 0;
 $8 = ((($0)) + 224|0);
 HEAP32[$8>>2] = 0;
 $9 = HEAP32[$2>>2]|0;
 $10 = ((($9)) + 40|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($1)) + 228|0);
 $13 = HEAP32[$12>>2]|0;
 __THREW__ = 0;
 $14 = (invoke_iii($11|0,($2|0),($13|0))|0);
 $15 = __THREW__; __THREW__ = 0;
 $16 = $15&1;
 if ($16) {
  $89 = ___cxa_find_matching_catch_2()|0;
  $90 = tempRet0;
  $$11 = $89;$$1141 = $90;
 } else {
  $17 = ((($0)) + 228|0);
  HEAP32[$17>>2] = $14;
  $18 = ($14|0)==(0|0);
  if (!($18)) {
   $19 = ((($14)) + 8|0);
   $20 = HEAP32[$19>>2]|0;HEAP32[$19>>2] = (($20+1)|0);
  }
  $21 = HEAP32[$2>>2]|0;
  $22 = ((($21)) + 40|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = ((($1)) + 232|0);
  $25 = HEAP32[$24>>2]|0;
  __THREW__ = 0;
  $26 = (invoke_iii($23|0,($2|0),($25|0))|0);
  $27 = __THREW__; __THREW__ = 0;
  $28 = $27&1;
  if ($28) {
   $91 = ___cxa_find_matching_catch_2()|0;
   $92 = tempRet0;
   $$10 = $91;$$1040 = $92;
  } else {
   $29 = ((($0)) + 232|0);
   HEAP32[$29>>2] = $26;
   $30 = ($26|0)==(0|0);
   if (!($30)) {
    $31 = ((($26)) + 8|0);
    $32 = HEAP32[$31>>2]|0;HEAP32[$31>>2] = (($32+1)|0);
   }
   $33 = HEAP32[$2>>2]|0;
   $34 = ((($33)) + 40|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ((($1)) + 236|0);
   $37 = HEAP32[$36>>2]|0;
   __THREW__ = 0;
   $38 = (invoke_iii($35|0,($2|0),($37|0))|0);
   $39 = __THREW__; __THREW__ = 0;
   $40 = $39&1;
   if ($40) {
    $93 = ___cxa_find_matching_catch_2()|0;
    $94 = tempRet0;
    $$9 = $93;$$939 = $94;
   } else {
    $41 = ((($0)) + 236|0);
    HEAP32[$41>>2] = $38;
    $42 = ($38|0)==(0|0);
    if (!($42)) {
     $43 = ((($38)) + 8|0);
     $44 = HEAP32[$43>>2]|0;HEAP32[$43>>2] = (($44+1)|0);
    }
    $45 = HEAP32[$2>>2]|0;
    $46 = ((($45)) + 40|0);
    $47 = HEAP32[$46>>2]|0;
    $48 = ((($1)) + 240|0);
    $49 = HEAP32[$48>>2]|0;
    __THREW__ = 0;
    $50 = (invoke_iii($47|0,($2|0),($49|0))|0);
    $51 = __THREW__; __THREW__ = 0;
    $52 = $51&1;
    if ($52) {
     $95 = ___cxa_find_matching_catch_2()|0;
     $96 = tempRet0;
     $$8 = $95;$$838 = $96;
    } else {
     $53 = ((($0)) + 240|0);
     HEAP32[$53>>2] = $50;
     $54 = ($50|0)==(0|0);
     if (!($54)) {
      $55 = ((($50)) + 8|0);
      $56 = HEAP32[$55>>2]|0;HEAP32[$55>>2] = (($56+1)|0);
     }
     $57 = HEAP32[$2>>2]|0;
     $58 = ((($57)) + 40|0);
     $59 = HEAP32[$58>>2]|0;
     $60 = ((($1)) + 244|0);
     $61 = HEAP32[$60>>2]|0;
     __THREW__ = 0;
     $62 = (invoke_iii($59|0,($2|0),($61|0))|0);
     $63 = __THREW__; __THREW__ = 0;
     $64 = $63&1;
     if ($64) {
      $97 = ___cxa_find_matching_catch_2()|0;
      $98 = tempRet0;
      $$7 = $97;$$737 = $98;
     } else {
      $65 = ((($0)) + 244|0);
      HEAP32[$65>>2] = $62;
      $66 = ($62|0)==(0|0);
      if (!($66)) {
       $67 = ((($62)) + 8|0);
       $68 = HEAP32[$67>>2]|0;HEAP32[$67>>2] = (($68+1)|0);
      }
      $69 = ((($0)) + 248|0);
      $70 = ((($0)) + 252|0);
      $71 = ((($0)) + 260|0);
      $72 = ((($0)) + 264|0);
      $73 = ((($0)) + 272|0);
      $74 = ((($1)) + 272|0);
      ;HEAP32[$69>>2]=0|0;HEAP32[$69+4>>2]=0|0;HEAP32[$69+8>>2]=0|0;HEAP32[$69+12>>2]=0|0;HEAP32[$69+16>>2]=0|0;HEAP32[$69+20>>2]=0|0;
      $75 = HEAP8[$74>>0]|0;
      HEAP8[$73>>0] = $75;
      $76 = ((($0)) + 182|0);
      HEAP8[$76>>0] = 1;
      $77 = ((($1)) + 216|0);
      $78 = HEAP32[$77>>2]|0;
      $79 = ((($1)) + 220|0);
      $80 = HEAP32[$79>>2]|0;
      $81 = ($78|0)==($80|0);
      L31: do {
       if ($81) {
        label = 18;
       } else {
        $82 = ((($0)) + 224|0);
        $$sroa$0101$0121 = $78;
        L33: while(1) {
         $99 = HEAP32[$2>>2]|0;
         $100 = ((($99)) + 44|0);
         $101 = HEAP32[$100>>2]|0;
         $102 = HEAP32[$$sroa$0101$0121>>2]|0;
         __THREW__ = 0;
         $103 = (invoke_iii($101|0,($2|0),($102|0))|0);
         $104 = __THREW__; __THREW__ = 0;
         $105 = $104&1;
         if ($105) {
          label = 36;
          break;
         }
         $106 = ($103|0)==(0|0);
         if (!($106)) {
          HEAP32[$3>>2] = $103;
          $107 = ((($103)) + 8|0);
          $108 = HEAP32[$107>>2]|0;HEAP32[$107>>2] = (($108+1)|0);
          $109 = HEAP32[$7>>2]|0;
          $110 = HEAP32[$82>>2]|0;
          $111 = ($109|0)==($110|0);
          if ($111) {
           __THREW__ = 0;
           invoke_vii(3775,($6|0),($3|0));
           $118 = __THREW__; __THREW__ = 0;
           $119 = $118&1;
           if ($119) {
            label = 38;
            break;
           }
          } else {
           $112 = HEAP32[$3>>2]|0;
           HEAP32[$109>>2] = $112;
           $113 = ($112|0)==(0|0);
           if ($113) {
            $117 = $109;
           } else {
            $114 = ((($112)) + 8|0);
            $115 = HEAP32[$114>>2]|0;HEAP32[$114>>2] = (($115+1)|0);
            $$pre$i72 = HEAP32[$7>>2]|0;
            $117 = $$pre$i72;
           }
           $116 = ((($117)) + 4|0);
           HEAP32[$7>>2] = $116;
          }
          $120 = HEAP32[$3>>2]|0;
          $121 = ($120|0)==(0|0);
          do {
           if (!($121)) {
            $122 = ((($120)) + 8|0);
            $123 = HEAP32[$122>>2]|0;HEAP32[$122>>2] = (($123-1)|0);
            $124 = ($123|0)==(1);
            if (!($124)) {
             break;
            }
            __THREW__ = 0;
            invoke_viii(3262,($120|0),1,1);
            $125 = __THREW__; __THREW__ = 0;
            $126 = $125&1;
            if ($126) {
             label = 37;
             break L33;
            }
           }
          } while(0);
         }
         $140 = ((($$sroa$0101$0121)) + 4|0);
         $141 = HEAP32[$79>>2]|0;
         $142 = ($140|0)==($141|0);
         if ($142) {
          label = 18;
          break L31;
         } else {
          $$sroa$0101$0121 = $140;
         }
        }
        if ((label|0) == 36) {
         $127 = ___cxa_find_matching_catch_2()|0;
         $128 = tempRet0;
         $$4 = $127;$$434 = $128;
         break;
        }
        else if ((label|0) == 37) {
         $129 = ___cxa_find_matching_catch_2()|0;
         $130 = tempRet0;
         $$0 = $129;$$030 = $130;
        }
        else if ((label|0) == 38) {
         $131 = ___cxa_find_matching_catch_2()|0;
         $132 = tempRet0;
         $133 = HEAP32[$3>>2]|0;
         $134 = ($133|0)==(0|0);
         do {
          if (!($134)) {
           $135 = ((($133)) + 8|0);
           $136 = HEAP32[$135>>2]|0;HEAP32[$135>>2] = (($136-1)|0);
           $137 = ($136|0)==(1);
           if (!($137)) {
            break;
           }
           __THREW__ = 0;
           invoke_viii(3262,($133|0),1,1);
           $138 = __THREW__; __THREW__ = 0;
           $139 = $138&1;
           if (!($139)) {
            break;
           }
           $336 = ___cxa_find_matching_catch_3(0|0)|0;
           $337 = tempRet0;
           ___clang_call_terminate($336);
           // unreachable;
          }
         } while(0);
         HEAP32[$3>>2] = 0;
         $$0 = $131;$$030 = $132;
        }
        $$4 = $$0;$$434 = $$030;
       }
      } while(0);
      L60: do {
       if ((label|0) == 18) {
        $83 = ((($1)) + 248|0);
        $84 = HEAP32[$83>>2]|0;
        $85 = ((($1)) + 252|0);
        $86 = HEAP32[$85>>2]|0;
        $87 = ($84|0)==($86|0);
        L62: do {
         if (!($87)) {
          $88 = ((($0)) + 256|0);
          $$sroa$094$0117 = $84;
          L64: while(1) {
           $149 = HEAP32[$2>>2]|0;
           $150 = ((($149)) + 40|0);
           $151 = HEAP32[$150>>2]|0;
           $152 = HEAP32[$$sroa$094$0117>>2]|0;
           __THREW__ = 0;
           $153 = (invoke_iii($151|0,($2|0),($152|0))|0);
           $154 = __THREW__; __THREW__ = 0;
           $155 = $154&1;
           if ($155) {
            label = 58;
            break;
           }
           HEAP32[$4>>2] = $153;
           $156 = ($153|0)==(0|0);
           if (!($156)) {
            $157 = ((($153)) + 8|0);
            $158 = HEAP32[$157>>2]|0;HEAP32[$157>>2] = (($158+1)|0);
           }
           $159 = HEAP32[$70>>2]|0;
           $160 = HEAP32[$88>>2]|0;
           $161 = ($159|0)==($160|0);
           if ($161) {
            __THREW__ = 0;
            invoke_vii(3774,($69|0),($4|0));
            $168 = __THREW__; __THREW__ = 0;
            $169 = $168&1;
            if ($169) {
             label = 59;
             break;
            }
           } else {
            $162 = HEAP32[$4>>2]|0;
            HEAP32[$159>>2] = $162;
            $163 = ($162|0)==(0|0);
            if ($163) {
             $167 = $159;
            } else {
             $164 = ((($162)) + 8|0);
             $165 = HEAP32[$164>>2]|0;HEAP32[$164>>2] = (($165+1)|0);
             $$pre$i81 = HEAP32[$70>>2]|0;
             $167 = $$pre$i81;
            }
            $166 = ((($167)) + 4|0);
            HEAP32[$70>>2] = $166;
           }
           $170 = HEAP32[$4>>2]|0;
           $171 = ($170|0)==(0|0);
           do {
            if (!($171)) {
             $172 = ((($170)) + 8|0);
             $173 = HEAP32[$172>>2]|0;HEAP32[$172>>2] = (($173-1)|0);
             $174 = ($173|0)==(1);
             if (!($174)) {
              break;
             }
             __THREW__ = 0;
             invoke_viii(3262,($170|0),1,1);
             $175 = __THREW__; __THREW__ = 0;
             $176 = $175&1;
             if ($176) {
              label = 58;
              break L64;
             }
            }
           } while(0);
           $177 = ((($$sroa$094$0117)) + 4|0);
           $178 = HEAP32[$85>>2]|0;
           $179 = ($177|0)==($178|0);
           if ($179) {
            break L62;
           } else {
            $$sroa$094$0117 = $177;
           }
          }
          if ((label|0) == 58) {
           $180 = ___cxa_find_matching_catch_2()|0;
           $181 = tempRet0;
           $$2 = $180;$$232 = $181;
          }
          else if ((label|0) == 59) {
           $182 = ___cxa_find_matching_catch_2()|0;
           $183 = tempRet0;
           $184 = HEAP32[$4>>2]|0;
           $185 = ($184|0)==(0|0);
           do {
            if (!($185)) {
             $186 = ((($184)) + 8|0);
             $187 = HEAP32[$186>>2]|0;HEAP32[$186>>2] = (($187-1)|0);
             $188 = ($187|0)==(1);
             if (!($188)) {
              break;
             }
             __THREW__ = 0;
             invoke_viii(3262,($184|0),1,1);
             $189 = __THREW__; __THREW__ = 0;
             $190 = $189&1;
             if (!($190)) {
              break;
             }
             $336 = ___cxa_find_matching_catch_3(0|0)|0;
             $337 = tempRet0;
             ___clang_call_terminate($336);
             // unreachable;
            }
           } while(0);
           HEAP32[$4>>2] = 0;
           $$2 = $182;$$232 = $183;
          }
          $$4 = $$2;$$434 = $$232;
          break L60;
         }
        } while(0);
        $143 = ((($1)) + 260|0);
        $144 = HEAP32[$143>>2]|0;
        $145 = ((($1)) + 264|0);
        $146 = HEAP32[$145>>2]|0;
        $147 = ($144|0)==($146|0);
        L91: do {
         if (!($147)) {
          $148 = ((($0)) + 268|0);
          $$sroa$087$0116 = $144;
          L93: while(1) {
           $195 = HEAP32[$2>>2]|0;
           $196 = ((($195)) + 40|0);
           $197 = HEAP32[$196>>2]|0;
           $198 = HEAP32[$$sroa$087$0116>>2]|0;
           __THREW__ = 0;
           $199 = (invoke_iii($197|0,($2|0),($198|0))|0);
           $200 = __THREW__; __THREW__ = 0;
           $201 = $200&1;
           if ($201) {
            label = 77;
            break;
           }
           HEAP32[$5>>2] = $199;
           $202 = ($199|0)==(0|0);
           if (!($202)) {
            $203 = ((($199)) + 8|0);
            $204 = HEAP32[$203>>2]|0;HEAP32[$203>>2] = (($204+1)|0);
           }
           $205 = HEAP32[$72>>2]|0;
           $206 = HEAP32[$148>>2]|0;
           $207 = ($205|0)==($206|0);
           if ($207) {
            __THREW__ = 0;
            invoke_vii(3774,($71|0),($5|0));
            $214 = __THREW__; __THREW__ = 0;
            $215 = $214&1;
            if ($215) {
             label = 78;
             break;
            }
           } else {
            $208 = HEAP32[$5>>2]|0;
            HEAP32[$205>>2] = $208;
            $209 = ($208|0)==(0|0);
            if ($209) {
             $213 = $205;
            } else {
             $210 = ((($208)) + 8|0);
             $211 = HEAP32[$210>>2]|0;HEAP32[$210>>2] = (($211+1)|0);
             $$pre$i69 = HEAP32[$72>>2]|0;
             $213 = $$pre$i69;
            }
            $212 = ((($213)) + 4|0);
            HEAP32[$72>>2] = $212;
           }
           $216 = HEAP32[$5>>2]|0;
           $217 = ($216|0)==(0|0);
           do {
            if (!($217)) {
             $218 = ((($216)) + 8|0);
             $219 = HEAP32[$218>>2]|0;HEAP32[$218>>2] = (($219-1)|0);
             $220 = ($219|0)==(1);
             if (!($220)) {
              break;
             }
             __THREW__ = 0;
             invoke_viii(3262,($216|0),1,1);
             $221 = __THREW__; __THREW__ = 0;
             $222 = $221&1;
             if ($222) {
              label = 77;
              break L93;
             }
            }
           } while(0);
           $223 = ((($$sroa$087$0116)) + 4|0);
           $224 = HEAP32[$145>>2]|0;
           $225 = ($223|0)==($224|0);
           if ($225) {
            break L91;
           } else {
            $$sroa$087$0116 = $223;
           }
          }
          if ((label|0) == 77) {
           $226 = ___cxa_find_matching_catch_2()|0;
           $227 = tempRet0;
           $$3 = $226;$$333 = $227;
          }
          else if ((label|0) == 78) {
           $228 = ___cxa_find_matching_catch_2()|0;
           $229 = tempRet0;
           $230 = HEAP32[$5>>2]|0;
           $231 = ($230|0)==(0|0);
           do {
            if (!($231)) {
             $232 = ((($230)) + 8|0);
             $233 = HEAP32[$232>>2]|0;HEAP32[$232>>2] = (($233-1)|0);
             $234 = ($233|0)==(1);
             if (!($234)) {
              break;
             }
             __THREW__ = 0;
             invoke_viii(3262,($230|0),1,1);
             $235 = __THREW__; __THREW__ = 0;
             $236 = $235&1;
             if (!($236)) {
              break;
             }
             $336 = ___cxa_find_matching_catch_3(0|0)|0;
             $337 = tempRet0;
             ___clang_call_terminate($336);
             // unreachable;
            }
           } while(0);
           HEAP32[$5>>2] = 0;
           $$3 = $228;$$333 = $229;
          }
          $$4 = $$3;$$434 = $$333;
          break L60;
         }
        } while(0);
        $191 = ((($2)) + 4|0);
        $192 = HEAP32[$191>>2]|0;
        $193 = $192 & 384;
        $194 = ($193|0)==(0);
        if ($194) {
         STACKTOP = sp;return;
        }
        $237 = ((($0)) + 183|0);
        HEAP8[$237>>0] = 0;
        $238 = HEAP32[$0>>2]|0;
        $239 = ((($238)) + 212|0);
        $240 = HEAP32[$239>>2]|0;
        __THREW__ = 0;
        invoke_vii($240|0,($0|0),1);
        $241 = __THREW__; __THREW__ = 0;
        $242 = $241&1;
        if ($242) {
         $243 = ___cxa_find_matching_catch_2()|0;
         $244 = tempRet0;
         $$4 = $243;$$434 = $244;
         break;
        } else {
         STACKTOP = sp;return;
        }
       }
      } while(0);
      $245 = HEAP32[$71>>2]|0;
      $246 = ($245|0)==(0|0);
      if (!($246)) {
       $247 = HEAP32[$72>>2]|0;
       $248 = ($247|0)==($245|0);
       do {
        if ($248) {
         $262 = $245;
        } else {
         $250 = $247;
         L130: while(1) {
          $249 = ((($250)) + -4|0);
          HEAP32[$72>>2] = $249;
          $251 = HEAP32[$249>>2]|0;
          $252 = ($251|0)==(0|0);
          do {
           if (!($252)) {
            $253 = ((($251)) + 8|0);
            $254 = HEAP32[$253>>2]|0;HEAP32[$253>>2] = (($254-1)|0);
            $255 = ($254|0)==(1);
            if (!($255)) {
             break;
            }
            __THREW__ = 0;
            invoke_viii(3262,($251|0),1,1);
            $256 = __THREW__; __THREW__ = 0;
            $257 = $256&1;
            if ($257) {
             label = 92;
             break L130;
            }
           }
          } while(0);
          HEAP32[$249>>2] = 0;
          $258 = HEAP32[$72>>2]|0;
          $259 = ($258|0)==($245|0);
          if ($259) {
           label = 93;
           break;
          } else {
           $250 = $258;
          }
         }
         if ((label|0) == 92) {
          $260 = ___cxa_find_matching_catch_2()|0;
          $261 = tempRet0;
          ___cxa_call_unexpected(($260|0));
          // unreachable;
         }
         else if ((label|0) == 93) {
          $$pre$i61 = HEAP32[$71>>2]|0;
          $262 = $$pre$i61;
          break;
         }
        }
       } while(0);
       __ZdlPv($262);
      }
      $263 = HEAP32[$69>>2]|0;
      $264 = ($263|0)==(0|0);
      if (!($264)) {
       $265 = HEAP32[$70>>2]|0;
       $266 = ($265|0)==($263|0);
       do {
        if ($266) {
         $280 = $263;
        } else {
         $268 = $265;
         L144: while(1) {
          $267 = ((($268)) + -4|0);
          HEAP32[$70>>2] = $267;
          $269 = HEAP32[$267>>2]|0;
          $270 = ($269|0)==(0|0);
          do {
           if (!($270)) {
            $271 = ((($269)) + 8|0);
            $272 = HEAP32[$271>>2]|0;HEAP32[$271>>2] = (($272-1)|0);
            $273 = ($272|0)==(1);
            if (!($273)) {
             break;
            }
            __THREW__ = 0;
            invoke_viii(3262,($269|0),1,1);
            $274 = __THREW__; __THREW__ = 0;
            $275 = $274&1;
            if ($275) {
             label = 101;
             break L144;
            }
           }
          } while(0);
          HEAP32[$267>>2] = 0;
          $276 = HEAP32[$70>>2]|0;
          $277 = ($276|0)==($263|0);
          if ($277) {
           label = 102;
           break;
          } else {
           $268 = $276;
          }
         }
         if ((label|0) == 101) {
          $278 = ___cxa_find_matching_catch_2()|0;
          $279 = tempRet0;
          ___cxa_call_unexpected(($278|0));
          // unreachable;
         }
         else if ((label|0) == 102) {
          $$pre$i56 = HEAP32[$69>>2]|0;
          $280 = $$pre$i56;
          break;
         }
        }
       } while(0);
       __ZdlPv($280);
      }
      $281 = HEAP32[$65>>2]|0;
      $282 = ($281|0)==(0|0);
      do {
       if (!($282)) {
        $283 = ((($281)) + 8|0);
        $284 = HEAP32[$283>>2]|0;HEAP32[$283>>2] = (($284-1)|0);
        $285 = ($284|0)==(1);
        if (!($285)) {
         break;
        }
        __THREW__ = 0;
        invoke_viii(3262,($281|0),1,1);
        $286 = __THREW__; __THREW__ = 0;
        $287 = $286&1;
        if (!($287)) {
         break;
        }
        $336 = ___cxa_find_matching_catch_3(0|0)|0;
        $337 = tempRet0;
        ___clang_call_terminate($336);
        // unreachable;
       }
      } while(0);
      HEAP32[$65>>2] = 0;
      $$7 = $$4;$$737 = $$434;
     }
     $288 = HEAP32[$53>>2]|0;
     $289 = ($288|0)==(0|0);
     if (!($289)) {
      $290 = ((($288)) + 8|0);
      $291 = HEAP32[$290>>2]|0;HEAP32[$290>>2] = (($291-1)|0);
      $292 = ($291|0)==(1);
      if ($292) {
       __THREW__ = 0;
       invoke_viii(3262,($288|0),1,1);
       $293 = __THREW__; __THREW__ = 0;
       $294 = $293&1;
       if ($294) {
        $336 = ___cxa_find_matching_catch_3(0|0)|0;
        $337 = tempRet0;
        ___clang_call_terminate($336);
        // unreachable;
       }
      }
     }
     HEAP32[$53>>2] = 0;
     $$8 = $$7;$$838 = $$737;
    }
    $295 = HEAP32[$41>>2]|0;
    $296 = ($295|0)==(0|0);
    if (!($296)) {
     $297 = ((($295)) + 8|0);
     $298 = HEAP32[$297>>2]|0;HEAP32[$297>>2] = (($298-1)|0);
     $299 = ($298|0)==(1);
     if ($299) {
      __THREW__ = 0;
      invoke_viii(3262,($295|0),1,1);
      $300 = __THREW__; __THREW__ = 0;
      $301 = $300&1;
      if ($301) {
       $336 = ___cxa_find_matching_catch_3(0|0)|0;
       $337 = tempRet0;
       ___clang_call_terminate($336);
       // unreachable;
      }
     }
    }
    HEAP32[$41>>2] = 0;
    $$9 = $$8;$$939 = $$838;
   }
   $302 = HEAP32[$29>>2]|0;
   $303 = ($302|0)==(0|0);
   if (!($303)) {
    $304 = ((($302)) + 8|0);
    $305 = HEAP32[$304>>2]|0;HEAP32[$304>>2] = (($305-1)|0);
    $306 = ($305|0)==(1);
    if ($306) {
     __THREW__ = 0;
     invoke_viii(3262,($302|0),1,1);
     $307 = __THREW__; __THREW__ = 0;
     $308 = $307&1;
     if ($308) {
      $336 = ___cxa_find_matching_catch_3(0|0)|0;
      $337 = tempRet0;
      ___clang_call_terminate($336);
      // unreachable;
     }
    }
   }
   HEAP32[$29>>2] = 0;
   $$10 = $$9;$$1040 = $$939;
  }
  $309 = HEAP32[$17>>2]|0;
  $310 = ($309|0)==(0|0);
  if (!($310)) {
   $311 = ((($309)) + 8|0);
   $312 = HEAP32[$311>>2]|0;HEAP32[$311>>2] = (($312-1)|0);
   $313 = ($312|0)==(1);
   if ($313) {
    __THREW__ = 0;
    invoke_viii(3262,($309|0),1,1);
    $314 = __THREW__; __THREW__ = 0;
    $315 = $314&1;
    if ($315) {
     $336 = ___cxa_find_matching_catch_3(0|0)|0;
     $337 = tempRet0;
     ___clang_call_terminate($336);
     // unreachable;
    }
   }
  }
  HEAP32[$17>>2] = 0;
  $$11 = $$10;$$1141 = $$1040;
 }
 $316 = HEAP32[$6>>2]|0;
 $317 = ($316|0)==(0|0);
 if (!($317)) {
  $318 = HEAP32[$7>>2]|0;
  $319 = ($318|0)==($316|0);
  do {
   if ($319) {
    $333 = $316;
   } else {
    $321 = $318;
    while(1) {
     $320 = ((($321)) + -4|0);
     HEAP32[$7>>2] = $320;
     $322 = HEAP32[$320>>2]|0;
     $323 = ($322|0)==(0|0);
     if (!($323)) {
      $324 = ((($322)) + 8|0);
      $325 = HEAP32[$324>>2]|0;HEAP32[$324>>2] = (($325-1)|0);
      $326 = ($325|0)==(1);
      if ($326) {
       __THREW__ = 0;
       invoke_viii(3262,($322|0),1,1);
       $327 = __THREW__; __THREW__ = 0;
       $328 = $327&1;
       if ($328) {
        label = 130;
        break;
       }
      }
     }
     HEAP32[$320>>2] = 0;
     $329 = HEAP32[$7>>2]|0;
     $330 = ($329|0)==($316|0);
     if ($330) {
      label = 131;
      break;
     } else {
      $321 = $329;
     }
    }
    if ((label|0) == 130) {
     $331 = ___cxa_find_matching_catch_2()|0;
     $332 = tempRet0;
     ___cxa_call_unexpected(($331|0));
     // unreachable;
    }
    else if ((label|0) == 131) {
     $$pre$i = HEAP32[$6>>2]|0;
     $333 = $$pre$i;
     break;
    }
   }
  } while(0);
  __ZdlPv($333);
 }
 __THREW__ = 0;
 invoke_vi(1630,($0|0));
 $334 = __THREW__; __THREW__ = 0;
 $335 = $334&1;
 if ($335) {
  $336 = ___cxa_find_matching_catch_3(0|0)|0;
  $337 = tempRet0;
  ___clang_call_terminate($336);
  // unreachable;
 } else {
  ___resumeException($$11|0);
  // unreachable;
 }
}
function __ZN3osg8GeometryC2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 __ZN3osg8DrawableC2Ev($0);
 HEAP32[$0>>2] = (59536);
 $1 = ((($0)) + 216|0);
 $2 = ((($0)) + 182|0);
 dest=$1; stop=dest+56|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));HEAP8[$1+56>>0]=0|0;
 HEAP8[$2>>0] = 1;
 $3 = ((($0)) + 183|0);
 HEAP8[$3>>0] = 0;
 return;
}
function __ZN3osg8Geometry16getTexCoordArrayEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 248|0);
 $3 = ((($0)) + 252|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$2>>2]|0;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 2;
 $8 = ($7>>>0)>($1>>>0);
 if (!($8)) {
  $$0 = 0;
  return ($$0|0);
 }
 $9 = $5;
 $10 = (($9) + ($1<<2)|0);
 $11 = HEAP32[$10>>2]|0;
 $$0 = $11;
 return ($$0|0);
}
function __ZN3osg8Geometry20getVertexAttribArrayEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 260|0);
 $3 = ((($0)) + 264|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$2>>2]|0;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 2;
 $8 = ($7>>>0)>($1>>>0);
 if (!($8)) {
  $$0 = 0;
  return ($$0|0);
 }
 $9 = $5;
 $10 = (($9) + ($1<<2)|0);
 $11 = HEAP32[$10>>2]|0;
 $$0 = $11;
 return ($$0|0);
}
function __ZN3osg8Geometry14setVertexArrayEPNS_5ArrayE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $26 = ((($0)) + 228|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = ($27|0)==(0|0);
  if (!($28)) {
   HEAP32[$26>>2] = 0;
   $29 = ((($27)) + 8|0);
   $30 = HEAP32[$29>>2]|0;HEAP32[$29>>2] = (($30-1)|0);
   $31 = ($30|0)==(1);
   if ($31) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($27,1,1);
   }
  }
  $32 = HEAP32[$0>>2]|0;
  $33 = ((($32)) + 216|0);
  $34 = HEAP32[$33>>2]|0;
  FUNCTION_TABLE_vi[$34 & 8191]($0);
  __ZN3osg4Node10dirtyBoundEv($0);
  return;
 }
 $3 = ((($1)) + 64|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(-1);
 if ($5) {
  HEAP32[$3>>2] = 4;
 }
 $6 = ((($0)) + 228|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==($1|0);
 if (!($8)) {
  HEAP32[$6>>2] = $1;
  $9 = ((($1)) + 8|0);
  $10 = HEAP32[$9>>2]|0;HEAP32[$9>>2] = (($10+1)|0);
  $11 = ($7|0)==(0|0);
  if (!($11)) {
   $12 = ((($7)) + 8|0);
   $13 = HEAP32[$12>>2]|0;HEAP32[$12>>2] = (($13-1)|0);
   $14 = ($13|0)==(1);
   if ($14) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($7,1,1);
   }
  }
 }
 $15 = HEAP32[$0>>2]|0;
 $16 = ((($15)) + 216|0);
 $17 = HEAP32[$16>>2]|0;
 FUNCTION_TABLE_vi[$17 & 8191]($0);
 __ZN3osg4Node10dirtyBoundEv($0);
 $18 = HEAP32[$3>>2]|0;
 $19 = ($18|0)==(4);
 if (!($19)) {
  return;
 }
 $20 = ((($1)) + 40|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0|0);
 if (!($22)) {
  $23 = (___dynamic_cast($21,23080,23112,0)|0);
  $24 = ($23|0)==(0|0);
  if (!($24)) {
   return;
  }
 }
 $25 = (__ZN3osg8Geometry29getOrCreateVertexBufferObjectEv($0)|0);
 __ZN3osg10BufferData15setBufferObjectEPNS_12BufferObjectE($1,$25);
 return;
}
function __ZN3osg8Geometry29getOrCreateVertexBufferObjectEv($0) {
 $0 = $0|0;
 var $$110 = 0, $$112 = 0, $$2 = 0, $$pre = 0, $$pre$i = 0, $$pre$i16 = 0, $$sroa$022$028 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 HEAP32[$1>>2] = 0;
 $2 = ((($1)) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = ((($1)) + 8|0);
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 (invoke_iii(3766,($0|0),($1|0))|0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 L1: do {
  if ($5) {
   $15 = ___cxa_find_matching_catch_2()|0;
   $16 = tempRet0;
   $$110 = $15;$$112 = $16;
  } else {
   $6 = HEAP32[$1>>2]|0;
   $7 = HEAP32[$2>>2]|0;
   $8 = ($6|0)==($7|0);
   L4: do {
    if ($8) {
     label = 9;
    } else {
     $$sroa$022$028 = $6;
     while(1) {
      $9 = HEAP32[$$sroa$022$028>>2]|0;
      $10 = ((($9)) + 40|0);
      $11 = HEAP32[$10>>2]|0;
      $12 = ($11|0)==(0|0);
      if (!($12)) {
       $13 = (___dynamic_cast($11,23080,23112,0)|0);
       $14 = ($13|0)==(0|0);
       if (!($14)) {
        break;
       }
      }
      $19 = ((($$sroa$022$028)) + 4|0);
      $20 = ($19|0)==($7|0);
      if ($20) {
       label = 9;
       break L4;
      } else {
       $$sroa$022$028 = $19;
      }
     }
     $$2 = $13;$28 = $6;
    }
   } while(0);
   do {
    if ((label|0) == 9) {
     __THREW__ = 0;
     $21 = (invoke_ii(3276,72)|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      $17 = ___cxa_find_matching_catch_2()|0;
      $18 = tempRet0;
      $$110 = $17;$$112 = $18;
      break L1;
     }
     __THREW__ = 0;
     invoke_vi(3768,($21|0));
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if ($25) {
      $26 = ___cxa_find_matching_catch_2()|0;
      $27 = tempRet0;
      __ZdlPv($21);
      $$110 = $26;$$112 = $27;
      break L1;
     } else {
      $$pre = HEAP32[$1>>2]|0;
      $$2 = $21;$28 = $$pre;
      break;
     }
    }
   } while(0);
   $29 = ($28|0)==(0|0);
   if ($29) {
    STACKTOP = sp;return ($$2|0);
   }
   $30 = HEAP32[$2>>2]|0;
   $31 = ($30|0)==($28|0);
   do {
    if ($31) {
     $45 = $28;
    } else {
     $33 = $30;
     while(1) {
      $32 = ((($33)) + -4|0);
      HEAP32[$2>>2] = $32;
      $34 = HEAP32[$32>>2]|0;
      $35 = ($34|0)==(0|0);
      if (!($35)) {
       $36 = ((($34)) + 8|0);
       $37 = HEAP32[$36>>2]|0;HEAP32[$36>>2] = (($37-1)|0);
       $38 = ($37|0)==(1);
       if ($38) {
        __THREW__ = 0;
        invoke_viii(3262,($34|0),1,1);
        $39 = __THREW__; __THREW__ = 0;
        $40 = $39&1;
        if ($40) {
         label = 19;
         break;
        }
       }
      }
      HEAP32[$32>>2] = 0;
      $41 = HEAP32[$2>>2]|0;
      $42 = ($41|0)==($28|0);
      if ($42) {
       label = 20;
       break;
      } else {
       $33 = $41;
      }
     }
     if ((label|0) == 19) {
      $43 = ___cxa_find_matching_catch_2()|0;
      $44 = tempRet0;
      ___cxa_call_unexpected(($43|0));
      // unreachable;
     }
     else if ((label|0) == 20) {
      $$pre$i16 = HEAP32[$1>>2]|0;
      $45 = $$pre$i16;
      break;
     }
    }
   } while(0);
   __ZdlPv($45);
   STACKTOP = sp;return ($$2|0);
  }
 } while(0);
 $46 = HEAP32[$1>>2]|0;
 $47 = ($46|0)==(0|0);
 if ($47) {
  ___resumeException($$110|0);
  // unreachable;
 }
 $48 = HEAP32[$2>>2]|0;
 $49 = ($48|0)==($46|0);
 do {
  if ($49) {
   $63 = $46;
  } else {
   $51 = $48;
   while(1) {
    $50 = ((($51)) + -4|0);
    HEAP32[$2>>2] = $50;
    $52 = HEAP32[$50>>2]|0;
    $53 = ($52|0)==(0|0);
    if (!($53)) {
     $54 = ((($52)) + 8|0);
     $55 = HEAP32[$54>>2]|0;HEAP32[$54>>2] = (($55-1)|0);
     $56 = ($55|0)==(1);
     if ($56) {
      __THREW__ = 0;
      invoke_viii(3262,($52|0),1,1);
      $57 = __THREW__; __THREW__ = 0;
      $58 = $57&1;
      if ($58) {
       label = 29;
       break;
      }
     }
    }
    HEAP32[$50>>2] = 0;
    $59 = HEAP32[$2>>2]|0;
    $60 = ($59|0)==($46|0);
    if ($60) {
     label = 30;
     break;
    } else {
     $51 = $59;
    }
   }
   if ((label|0) == 29) {
    $61 = ___cxa_find_matching_catch_2()|0;
    $62 = tempRet0;
    ___cxa_call_unexpected(($61|0));
    // unreachable;
   }
   else if ((label|0) == 30) {
    $$pre$i = HEAP32[$1>>2]|0;
    $63 = $$pre$i;
    break;
   }
  }
 } while(0);
 __ZdlPv($63);
 ___resumeException($$110|0);
 // unreachable;
 return (0)|0;
}
function __ZN3osg8Geometry14setNormalArrayEPNS_5ArrayENS1_7BindingE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($1|0)!=(0|0);
 $4 = ($2|0)!=(-1);
 $or$cond = $3 & $4;
 if ($or$cond) {
  $5 = ((($1)) + 64|0);
  HEAP32[$5>>2] = $2;
 }
 $6 = ((($0)) + 232|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==($1|0);
 if (!($8)) {
  HEAP32[$6>>2] = $1;
  $9 = ($1|0)==(0|0);
  if (!($9)) {
   $10 = ((($1)) + 8|0);
   $11 = HEAP32[$10>>2]|0;HEAP32[$10>>2] = (($11+1)|0);
  }
  $12 = ($7|0)==(0|0);
  if (!($12)) {
   $13 = ((($7)) + 8|0);
   $14 = HEAP32[$13>>2]|0;HEAP32[$13>>2] = (($14-1)|0);
   $15 = ($14|0)==(1);
   if ($15) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($7,1,1);
   }
  }
 }
 $16 = HEAP32[$0>>2]|0;
 $17 = ((($16)) + 216|0);
 $18 = HEAP32[$17>>2]|0;
 FUNCTION_TABLE_vi[$18 & 8191]($0);
 if (!($3)) {
  return;
 }
 $19 = ((($1)) + 64|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)==(4);
 if (!($21)) {
  return;
 }
 $22 = ((($1)) + 40|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)==(0|0);
 if (!($24)) {
  $25 = (___dynamic_cast($23,23080,23112,0)|0);
  $26 = ($25|0)==(0|0);
  if (!($26)) {
   return;
  }
 }
 $27 = (__ZN3osg8Geometry29getOrCreateVertexBufferObjectEv($0)|0);
 __ZN3osg10BufferData15setBufferObjectEPNS_12BufferObjectE($1,$27);
 return;
}
function __ZN3osg8Geometry13setColorArrayEPNS_5ArrayENS1_7BindingE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($1|0)!=(0|0);
 $4 = ($2|0)!=(-1);
 $or$cond = $3 & $4;
 if ($or$cond) {
  $5 = ((($1)) + 64|0);
  HEAP32[$5>>2] = $2;
 }
 $6 = ((($0)) + 236|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==($1|0);
 if (!($8)) {
  HEAP32[$6>>2] = $1;
  $9 = ($1|0)==(0|0);
  if (!($9)) {
   $10 = ((($1)) + 8|0);
   $11 = HEAP32[$10>>2]|0;HEAP32[$10>>2] = (($11+1)|0);
  }
  $12 = ($7|0)==(0|0);
  if (!($12)) {
   $13 = ((($7)) + 8|0);
   $14 = HEAP32[$13>>2]|0;HEAP32[$13>>2] = (($14-1)|0);
   $15 = ($14|0)==(1);
   if ($15) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($7,1,1);
   }
  }
 }
 $16 = HEAP32[$0>>2]|0;
 $17 = ((($16)) + 216|0);
 $18 = HEAP32[$17>>2]|0;
 FUNCTION_TABLE_vi[$18 & 8191]($0);
 if (!($3)) {
  return;
 }
 $19 = ((($1)) + 64|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)==(4);
 if (!($21)) {
  return;
 }
 $22 = ((($1)) + 40|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)==(0|0);
 if (!($24)) {
  $25 = (___dynamic_cast($23,23080,23112,0)|0);
  $26 = ($25|0)==(0|0);
  if (!($26)) {
   return;
  }
 }
 $27 = (__ZN3osg8Geometry29getOrCreateVertexBufferObjectEv($0)|0);
 __ZN3osg10BufferData15setBufferObjectEPNS_12BufferObjectE($1,$27);
 return;
}
function __ZN3osg8Geometry22setSecondaryColorArrayEPNS_5ArrayENS1_7BindingE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($1|0)!=(0|0);
 $4 = ($2|0)!=(-1);
 $or$cond = $3 & $4;
 if ($or$cond) {
  $5 = ((($1)) + 64|0);
  HEAP32[$5>>2] = $2;
 }
 $6 = ((($0)) + 240|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==($1|0);
 if (!($8)) {
  HEAP32[$6>>2] = $1;
  $9 = ($1|0)==(0|0);
  if (!($9)) {
   $10 = ((($1)) + 8|0);
   $11 = HEAP32[$10>>2]|0;HEAP32[$10>>2] = (($11+1)|0);
  }
  $12 = ($7|0)==(0|0);
  if (!($12)) {
   $13 = ((($7)) + 8|0);
   $14 = HEAP32[$13>>2]|0;HEAP32[$13>>2] = (($14-1)|0);
   $15 = ($14|0)==(1);
   if ($15) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($7,1,1);
   }
  }
 }
 $16 = HEAP32[$0>>2]|0;
 $17 = ((($16)) + 216|0);
 $18 = HEAP32[$17>>2]|0;
 FUNCTION_TABLE_vi[$18 & 8191]($0);
 if (!($3)) {
  return;
 }
 $19 = ((($1)) + 64|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)==(4);
 if (!($21)) {
  return;
 }
 $22 = ((($1)) + 40|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)==(0|0);
 if (!($24)) {
  $25 = (___dynamic_cast($23,23080,23112,0)|0);
  $26 = ($25|0)==(0|0);
  if (!($26)) {
   return;
  }
 }
 $27 = (__ZN3osg8Geometry29getOrCreateVertexBufferObjectEv($0)|0);
 __ZN3osg10BufferData15setBufferObjectEPNS_12BufferObjectE($1,$27);
 return;
}
function __ZN3osg8Geometry16setFogCoordArrayEPNS_5ArrayENS1_7BindingE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($1|0)!=(0|0);
 $4 = ($2|0)!=(-1);
 $or$cond = $3 & $4;
 if ($or$cond) {
  $5 = ((($1)) + 64|0);
  HEAP32[$5>>2] = $2;
 }
 $6 = ((($0)) + 244|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==($1|0);
 if (!($8)) {
  HEAP32[$6>>2] = $1;
  $9 = ($1|0)==(0|0);
  if (!($9)) {
   $10 = ((($1)) + 8|0);
   $11 = HEAP32[$10>>2]|0;HEAP32[$10>>2] = (($11+1)|0);
  }
  $12 = ($7|0)==(0|0);
  if (!($12)) {
   $13 = ((($7)) + 8|0);
   $14 = HEAP32[$13>>2]|0;HEAP32[$13>>2] = (($14-1)|0);
   $15 = ($14|0)==(1);
   if ($15) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($7,1,1);
   }
  }
 }
 $16 = HEAP32[$0>>2]|0;
 $17 = ((($16)) + 216|0);
 $18 = HEAP32[$17>>2]|0;
 FUNCTION_TABLE_vi[$18 & 8191]($0);
 if (!($3)) {
  return;
 }
 $19 = ((($1)) + 64|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)==(4);
 if (!($21)) {
  return;
 }
 $22 = ((($1)) + 40|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)==(0|0);
 if (!($24)) {
  $25 = (___dynamic_cast($23,23080,23112,0)|0);
  $26 = ($25|0)==(0|0);
  if (!($26)) {
   return;
  }
 }
 $27 = (__ZN3osg8Geometry29getOrCreateVertexBufferObjectEv($0)|0);
 __ZN3osg10BufferData15setBufferObjectEPNS_12BufferObjectE($1,$27);
 return;
}
function __ZN3osg8Geometry16setTexCoordArrayEjPNS_5ArrayENS1_7BindingE($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$sink = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ((($0)) + 248|0);
 $5 = ((($0)) + 252|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$4>>2]|0;
 $8 = (($6) - ($7))|0;
 $9 = $8 >> 2;
 $10 = ($9>>>0)>($1>>>0);
 L1: do {
  if (!($10)) {
   $11 = (($1) + 1)|0;
   $12 = ($11>>>0)>($9>>>0);
   $13 = $7;
   $14 = $6;
   if ($12) {
    $15 = (($11) - ($9))|0;
    __ZNSt3__26vectorIN3osg7ref_ptrINS1_5ArrayEEENS_9allocatorIS4_EEE8__appendEj($4,$15);
    break;
   }
   $16 = ($11>>>0)<($9>>>0);
   if ($16) {
    $17 = (($13) + ($11<<2)|0);
    $18 = ($14|0)==($17|0);
    if (!($18)) {
     $20 = $14;
     while(1) {
      $19 = ((($20)) + -4|0);
      HEAP32[$5>>2] = $19;
      $21 = HEAP32[$19>>2]|0;
      $22 = ($21|0)==(0|0);
      if (!($22)) {
       $23 = ((($21)) + 8|0);
       $24 = HEAP32[$23>>2]|0;HEAP32[$23>>2] = (($24-1)|0);
       $25 = ($24|0)==(1);
       if ($25) {
        __THREW__ = 0;
        invoke_viii(3262,($21|0),1,1);
        $26 = __THREW__; __THREW__ = 0;
        $27 = $26&1;
        if ($27) {
         break;
        }
       }
      }
      HEAP32[$19>>2] = 0;
      $28 = HEAP32[$5>>2]|0;
      $29 = ($28|0)==($17|0);
      if ($29) {
       break L1;
      } else {
       $20 = $28;
      }
     }
     $30 = ___cxa_find_matching_catch_2()|0;
     $31 = tempRet0;
     ___cxa_call_unexpected(($30|0));
     // unreachable;
    }
   }
  }
 } while(0);
 $32 = ($2|0)==(0|0);
 if ($32) {
  $56 = HEAP32[$4>>2]|0;
  $57 = (($56) + ($1<<2)|0);
  $58 = HEAP32[$57>>2]|0;
  $59 = ($58|0)==(0|0);
  if (!($59)) {
   HEAP32[$57>>2] = 0;
   $60 = ((($58)) + 8|0);
   $61 = HEAP32[$60>>2]|0;HEAP32[$60>>2] = (($61-1)|0);
   $62 = ($61|0)==(1);
   if ($62) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($58,1,1);
   }
  }
  $63 = HEAP32[$0>>2]|0;
  $64 = ((($63)) + 216|0);
  $65 = HEAP32[$64>>2]|0;
  FUNCTION_TABLE_vi[$65 & 8191]($0);
  return;
 }
 $33 = ($3|0)==(-1);
 $34 = ((($2)) + 64|0);
 $$sink = $33 ? 4 : $3;
 HEAP32[$34>>2] = $$sink;
 $35 = HEAP32[$4>>2]|0;
 $36 = (($35) + ($1<<2)|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = ($37|0)==($2|0);
 if (!($38)) {
  HEAP32[$36>>2] = $2;
  $39 = ((($2)) + 8|0);
  $40 = HEAP32[$39>>2]|0;HEAP32[$39>>2] = (($40+1)|0);
  $41 = ($37|0)==(0|0);
  if (!($41)) {
   $42 = ((($37)) + 8|0);
   $43 = HEAP32[$42>>2]|0;HEAP32[$42>>2] = (($43-1)|0);
   $44 = ($43|0)==(1);
   if ($44) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($37,1,1);
   }
  }
 }
 $45 = HEAP32[$0>>2]|0;
 $46 = ((($45)) + 216|0);
 $47 = HEAP32[$46>>2]|0;
 FUNCTION_TABLE_vi[$47 & 8191]($0);
 $48 = HEAP32[$34>>2]|0;
 $49 = ($48|0)==(4);
 if (!($49)) {
  return;
 }
 $50 = ((($2)) + 40|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = ($51|0)==(0|0);
 if (!($52)) {
  $53 = (___dynamic_cast($51,23080,23112,0)|0);
  $54 = ($53|0)==(0|0);
  if (!($54)) {
   return;
  }
 }
 $55 = (__ZN3osg8Geometry29getOrCreateVertexBufferObjectEv($0)|0);
 __ZN3osg10BufferData15setBufferObjectEPNS_12BufferObjectE($2,$55);
 return;
}
function __ZNSt3__26vectorIN3osg7ref_ptrINS1_5ArrayEEENS_9allocatorIS4_EEE8__appendEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$06$i$i = 0, $$pre = 0, $$pre$i = 0, $$promoted4$i = 0, $$sroa$7$0 = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i = 0, $scevgep$i15 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) - ($5))|0;
 $7 = $6 >> 2;
 $8 = ($7>>>0)<($1>>>0);
 $9 = $5;
 if (!($8)) {
  $$promoted4$i = $5;
  $10 = $1 << 2;
  _memset(($$promoted4$i|0),0,($10|0))|0;
  $scevgep$i = (($9) + ($1<<2)|0);
  HEAP32[$4>>2] = $scevgep$i;
  return;
 }
 $11 = HEAP32[$0>>2]|0;
 $12 = (($5) - ($11))|0;
 $13 = $12 >> 2;
 $14 = (($13) + ($1))|0;
 $15 = ($14>>>0)>(1073741823);
 $16 = $11;
 if ($15) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $17 = (($3) - ($11))|0;
 $18 = $17 >> 2;
 $19 = ($18>>>0)<(536870911);
 $20 = $17 >> 1;
 $21 = ($20>>>0)<($14>>>0);
 $$sroa$speculated$i = $21 ? $14 : $20;
 $$sroa$speculated$$i = $19 ? $$sroa$speculated$i : 1073741823;
 $22 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($22) {
   $32 = 0;
  } else {
   $23 = ($$sroa$speculated$$i>>>0)>(1073741823);
   if (!($23)) {
    $29 = $$sroa$speculated$$i << 2;
    $30 = (__Znwj($29)|0);
    $32 = $30;
    break;
   }
   $24 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($24|0),(204840|0));
   $25 = __THREW__; __THREW__ = 0;
   $26 = $25&1;
   if ($26) {
    $27 = ___cxa_find_matching_catch_2()|0;
    $28 = tempRet0;
    ___cxa_free_exception(($24|0));
    ___resumeException($27|0);
    // unreachable;
   } else {
    HEAP32[$24>>2] = (99824);
    ___cxa_throw(($24|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $31 = (($32) + ($13<<2)|0);
 $33 = $31;
 $34 = (($32) + ($$sroa$speculated$$i<<2)|0);
 $35 = $34;
 $36 = $1 << 2;
 _memset(($31|0),0,($36|0))|0;
 $scevgep$i15 = (($31) + ($1<<2)|0);
 $37 = $scevgep$i15;
 $38 = ($9|0)==($16|0);
 if ($38) {
  $50 = $33;$51 = $5;$53 = $9;
 } else {
  $$06$i$i = $9;$$sroa$7$0 = $33;$41 = $31;
  while(1) {
   $39 = ((($$06$i$i)) + -4|0);
   $40 = ((($41)) + -4|0);
   $42 = HEAP32[$39>>2]|0;
   HEAP32[$40>>2] = $42;
   $43 = ($42|0)==(0|0);
   if (!($43)) {
    $44 = ((($42)) + 8|0);
    $45 = HEAP32[$44>>2]|0;HEAP32[$44>>2] = (($45+1)|0);
   }
   $46 = $$sroa$7$0;
   $47 = ((($46)) + -4|0);
   $48 = $47;
   $49 = ($39|0)==($16|0);
   if ($49) {
    break;
   } else {
    $$06$i$i = $39;$$sroa$7$0 = $48;$41 = $47;
   }
  }
  $$pre$i = HEAP32[$0>>2]|0;
  $$pre = HEAP32[$4>>2]|0;
  $50 = $48;$51 = $$pre$i;$53 = $$pre;
 }
 HEAP32[$0>>2] = $50;
 HEAP32[$4>>2] = $37;
 HEAP32[$2>>2] = $35;
 $52 = $51;
 $54 = ($53|0)==($52|0);
 L25: do {
  if (!($54)) {
   $56 = $53;
   while(1) {
    $55 = ((($56)) + -4|0);
    $57 = HEAP32[$55>>2]|0;
    $58 = ($57|0)==(0|0);
    if (!($58)) {
     $59 = ((($57)) + 8|0);
     $60 = HEAP32[$59>>2]|0;HEAP32[$59>>2] = (($60-1)|0);
     $61 = ($60|0)==(1);
     if ($61) {
      __THREW__ = 0;
      invoke_viii(3262,($57|0),1,1);
      $62 = __THREW__; __THREW__ = 0;
      $63 = $62&1;
      if ($63) {
       break;
      }
     }
    }
    HEAP32[$55>>2] = 0;
    $64 = ($55|0)==($52|0);
    if ($64) {
     break L25;
    } else {
     $56 = $55;
    }
   }
   $65 = ___cxa_find_matching_catch_2()|0;
   $66 = tempRet0;
   ___cxa_call_unexpected(($65|0));
   // unreachable;
  }
 } while(0);
 $67 = ($51|0)==(0);
 if ($67) {
  return;
 }
 $68 = $51;
 __ZdlPv($68);
 return;
}
function __ZNK3osg8Geometry16getTexCoordArrayEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 248|0);
 $3 = ((($0)) + 252|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$2>>2]|0;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 2;
 $8 = ($7>>>0)>($1>>>0);
 if (!($8)) {
  $$0 = 0;
  return ($$0|0);
 }
 $9 = $5;
 $10 = (($9) + ($1<<2)|0);
 $11 = HEAP32[$10>>2]|0;
 $$0 = $11;
 return ($$0|0);
}
function __ZN3osg8Geometry20setVertexAttribArrayEjPNS_5ArrayENS1_7BindingE($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ((($0)) + 260|0);
 $5 = ((($0)) + 264|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$4>>2]|0;
 $8 = (($6) - ($7))|0;
 $9 = $8 >> 2;
 $10 = ($9>>>0)>($1>>>0);
 L1: do {
  if (!($10)) {
   $11 = (($1) + 1)|0;
   $12 = ($11>>>0)>($9>>>0);
   $13 = $7;
   $14 = $6;
   if ($12) {
    $15 = (($11) - ($9))|0;
    __ZNSt3__26vectorIN3osg7ref_ptrINS1_5ArrayEEENS_9allocatorIS4_EEE8__appendEj($4,$15);
    break;
   }
   $16 = ($11>>>0)<($9>>>0);
   if ($16) {
    $17 = (($13) + ($11<<2)|0);
    $18 = ($14|0)==($17|0);
    if (!($18)) {
     $20 = $14;
     while(1) {
      $19 = ((($20)) + -4|0);
      HEAP32[$5>>2] = $19;
      $21 = HEAP32[$19>>2]|0;
      $22 = ($21|0)==(0|0);
      if (!($22)) {
       $23 = ((($21)) + 8|0);
       $24 = HEAP32[$23>>2]|0;HEAP32[$23>>2] = (($24-1)|0);
       $25 = ($24|0)==(1);
       if ($25) {
        __THREW__ = 0;
        invoke_viii(3262,($21|0),1,1);
        $26 = __THREW__; __THREW__ = 0;
        $27 = $26&1;
        if ($27) {
         break;
        }
       }
      }
      HEAP32[$19>>2] = 0;
      $28 = HEAP32[$5>>2]|0;
      $29 = ($28|0)==($17|0);
      if ($29) {
       break L1;
      } else {
       $20 = $28;
      }
     }
     $30 = ___cxa_find_matching_catch_2()|0;
     $31 = tempRet0;
     ___cxa_call_unexpected(($30|0));
     // unreachable;
    }
   }
  }
 } while(0);
 $32 = ($2|0)!=(0|0);
 $33 = ($3|0)!=(-1);
 $or$cond = $32 & $33;
 if ($or$cond) {
  $34 = ((($2)) + 64|0);
  HEAP32[$34>>2] = $3;
 }
 $35 = HEAP32[$4>>2]|0;
 $36 = (($35) + ($1<<2)|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = ($37|0)==($2|0);
 if (!($38)) {
  HEAP32[$36>>2] = $2;
  $39 = ($2|0)==(0|0);
  if (!($39)) {
   $40 = ((($2)) + 8|0);
   $41 = HEAP32[$40>>2]|0;HEAP32[$40>>2] = (($41+1)|0);
  }
  $42 = ($37|0)==(0|0);
  if (!($42)) {
   $43 = ((($37)) + 8|0);
   $44 = HEAP32[$43>>2]|0;HEAP32[$43>>2] = (($44-1)|0);
   $45 = ($44|0)==(1);
   if ($45) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($37,1,1);
   }
  }
 }
 $46 = HEAP32[$0>>2]|0;
 $47 = ((($46)) + 216|0);
 $48 = HEAP32[$47>>2]|0;
 FUNCTION_TABLE_vi[$48 & 8191]($0);
 if (!($32)) {
  return;
 }
 $49 = ((($2)) + 64|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = ($50|0)==(4);
 if (!($51)) {
  return;
 }
 $52 = ((($2)) + 40|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = ($53|0)==(0|0);
 if (!($54)) {
  $55 = (___dynamic_cast($53,23080,23112,0)|0);
  $56 = ($55|0)==(0|0);
  if (!($56)) {
   return;
  }
 }
 $57 = (__ZN3osg8Geometry29getOrCreateVertexBufferObjectEv($0)|0);
 __ZN3osg10BufferData15setBufferObjectEPNS_12BufferObjectE($2,$57);
 return;
}
function __ZNK3osg8Geometry20getVertexAttribArrayEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 260|0);
 $3 = ((($0)) + 264|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$2>>2]|0;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 2;
 $8 = ($7>>>0)>($1>>>0);
 if (!($8)) {
  $$0 = 0;
  return ($$0|0);
 }
 $9 = $5;
 $10 = (($9) + ($1<<2)|0);
 $11 = HEAP32[$10>>2]|0;
 $$0 = $11;
 return ($$0|0);
}
function __ZN3osg8Geometry15addPrimitiveSetEPNS_12PrimitiveSetE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$pre$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp + 4|0;
 $3 = sp;
 $4 = ($1|0)==(0|0);
 if ($4) {
  $49 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
  if (!($49)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $50 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
  $51 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($50,128662,103)|0);
  $52 = HEAP32[$51>>2]|0;
  $53 = ((($52)) + -12|0);
  $54 = HEAP32[$53>>2]|0;
  $55 = (($51) + ($54)|0);
  __ZNKSt3__28ios_base6getlocEv($2,$55);
  __THREW__ = 0;
  $56 = (invoke_iii(3255,($2|0),(215188|0))|0);
  $57 = __THREW__; __THREW__ = 0;
  $58 = $57&1;
  if (!($58)) {
   $59 = HEAP32[$56>>2]|0;
   $60 = ((($59)) + 28|0);
   $61 = HEAP32[$60>>2]|0;
   __THREW__ = 0;
   $62 = (invoke_iii($61|0,($56|0),10)|0);
   $63 = __THREW__; __THREW__ = 0;
   $64 = $63&1;
   if (!($64)) {
    __ZNSt3__26localeD2Ev($2);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($51,$62)|0);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($51)|0);
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
  }
  $65 = ___cxa_find_matching_catch_2()|0;
  $66 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3263,($2|0));
  $67 = __THREW__; __THREW__ = 0;
  $68 = $67&1;
  if ($68) {
   $69 = ___cxa_find_matching_catch_3(0|0)|0;
   $70 = tempRet0;
   ___clang_call_terminate($69);
   // unreachable;
  } else {
   ___resumeException($65|0);
   // unreachable;
  }
 }
 $5 = HEAP32[$1>>2]|0;
 $6 = ((($5)) + 176|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_ii[$7 & 8191]($1)|0);
 $9 = ($8|0)==(0|0);
 do {
  if (!($9)) {
   $10 = ((($8)) + 40|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = ($11|0)==(0|0);
   if (!($12)) {
    $13 = (___dynamic_cast($11,23080,23128,0)|0);
    $14 = ($13|0)==(0|0);
    if (!($14)) {
     break;
    }
   }
   $15 = (__ZN3osg8Geometry30getOrCreateElementBufferObjectEv($0)|0);
   __ZN3osg10BufferData15setBufferObjectEPNS_12BufferObjectE($8,$15);
  }
 } while(0);
 HEAP32[$3>>2] = $1;
 $16 = ((($1)) + 8|0);
 $17 = HEAP32[$16>>2]|0;HEAP32[$16>>2] = (($17+1)|0);
 $18 = ((($0)) + 220|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ((($0)) + 224|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($19|0)==($21|0);
 if ($22) {
  $29 = ((($0)) + 216|0);
  __THREW__ = 0;
  invoke_vii(3775,($29|0),($3|0));
  $30 = __THREW__; __THREW__ = 0;
  $31 = $30&1;
  if ($31) {
   $40 = ___cxa_find_matching_catch_2()|0;
   $41 = tempRet0;
   $42 = HEAP32[$3>>2]|0;
   $43 = ($42|0)==(0|0);
   if ($43) {
    ___resumeException($40|0);
    // unreachable;
   }
   $44 = ((($42)) + 8|0);
   $45 = HEAP32[$44>>2]|0;HEAP32[$44>>2] = (($45-1)|0);
   $46 = ($45|0)==(1);
   if (!($46)) {
    ___resumeException($40|0);
    // unreachable;
   }
   __THREW__ = 0;
   invoke_viii(3262,($42|0),1,1);
   $47 = __THREW__; __THREW__ = 0;
   $48 = $47&1;
   if ($48) {
    $71 = ___cxa_find_matching_catch_3(0|0)|0;
    $72 = tempRet0;
    ___clang_call_terminate($71);
    // unreachable;
   } else {
    ___resumeException($40|0);
    // unreachable;
   }
  }
 } else {
  $23 = HEAP32[$3>>2]|0;
  HEAP32[$19>>2] = $23;
  $24 = ($23|0)==(0|0);
  if ($24) {
   $28 = $19;
  } else {
   $25 = ((($23)) + 8|0);
   $26 = HEAP32[$25>>2]|0;HEAP32[$25>>2] = (($26+1)|0);
   $$pre$i = HEAP32[$18>>2]|0;
   $28 = $$pre$i;
  }
  $27 = ((($28)) + 4|0);
  HEAP32[$18>>2] = $27;
 }
 $32 = HEAP32[$3>>2]|0;
 $33 = ($32|0)==(0|0);
 if (!($33)) {
  $34 = ((($32)) + 8|0);
  $35 = HEAP32[$34>>2]|0;HEAP32[$34>>2] = (($35-1)|0);
  $36 = ($35|0)==(1);
  if ($36) {
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($32,1,1);
  }
 }
 $37 = HEAP32[$0>>2]|0;
 $38 = ((($37)) + 216|0);
 $39 = HEAP32[$38>>2]|0;
 FUNCTION_TABLE_vi[$39 & 8191]($0);
 __ZN3osg4Node10dirtyBoundEv($0);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN3osg8Geometry30getOrCreateElementBufferObjectEv($0) {
 $0 = $0|0;
 var $$110 = 0, $$112 = 0, $$2 = 0, $$in = 0, $$pre = 0, $$pre29 = 0, $$pre31 = 0, $$sroa$021$027 = 0, $$sroa$06$010$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i14 = 0, $scevgep5$i$i$i = 0, $scevgep5$i$i$i15 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp + 12|0;
 $2 = sp;
 HEAP32[$2>>2] = 0;
 $3 = ((($2)) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = ((($2)) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = ((($0)) + 216|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($0)) + 220|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6|0)==($8|0);
 L1: do {
  if ($9) {
   label = 15;
  } else {
   $10 = ((($2)) + 8|0);
   $$sroa$06$010$i = $6;
   L3: while(1) {
    $11 = HEAP32[$$sroa$06$010$i>>2]|0;
    $12 = HEAP32[$11>>2]|0;
    $13 = ((($12)) + 176|0);
    $14 = HEAP32[$13>>2]|0;
    __THREW__ = 0;
    $15 = (invoke_ii($14|0,($11|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     label = 13;
     break;
    }
    HEAP32[$1>>2] = $15;
    $18 = ($15|0)==(0|0);
    $19 = $15;
    do {
     if (!($18)) {
      $20 = HEAP32[$3>>2]|0;
      $21 = HEAP32[$10>>2]|0;
      $22 = ($20|0)==($21|0);
      if ($22) {
       __THREW__ = 0;
       invoke_vii(3767,($2|0),($1|0));
       $25 = __THREW__; __THREW__ = 0;
       $26 = $25&1;
       if ($26) {
        label = 13;
        break L3;
       } else {
        break;
       }
      } else {
       HEAP32[$20>>2] = $19;
       $23 = HEAP32[$3>>2]|0;
       $24 = ((($23)) + 4|0);
       HEAP32[$3>>2] = $24;
       break;
      }
     }
    } while(0);
    $27 = ((($$sroa$06$010$i)) + 4|0);
    $28 = HEAP32[$7>>2]|0;
    $29 = ($27|0)==($28|0);
    if ($29) {
     break;
    } else {
     $$sroa$06$010$i = $27;
    }
   }
   if ((label|0) == 13) {
    $37 = ___cxa_find_matching_catch_2()|0;
    $38 = tempRet0;
    $$110 = $37;$$112 = $38;
    label = 25;
    break;
   }
   $$pre = HEAP32[$2>>2]|0;
   $$pre29 = HEAP32[$3>>2]|0;
   $30 = ($$pre|0)==($$pre29|0);
   if ($30) {
    label = 15;
   } else {
    $$sroa$021$027 = $$pre;
    while(1) {
     $31 = HEAP32[$$sroa$021$027>>2]|0;
     $32 = ((($31)) + 40|0);
     $33 = HEAP32[$32>>2]|0;
     $34 = ($33|0)==(0|0);
     if (!($34)) {
      $35 = (___dynamic_cast($33,23080,23128,0)|0);
      $36 = ($35|0)==(0|0);
      if (!($36)) {
       break;
      }
     }
     $39 = ((($$sroa$021$027)) + 4|0);
     $40 = ($39|0)==($$pre29|0);
     if ($40) {
      label = 15;
      break L1;
     } else {
      $$sroa$021$027 = $39;
     }
    }
    $$2 = $35;$$in = $$pre;
    label = 20;
   }
  }
 } while(0);
 do {
  if ((label|0) == 15) {
   __THREW__ = 0;
   $41 = (invoke_ii(3276,72)|0);
   $42 = __THREW__; __THREW__ = 0;
   $43 = $42&1;
   if ($43) {
    $46 = ___cxa_find_matching_catch_2()|0;
    $47 = tempRet0;
    $$110 = $46;$$112 = $47;
    label = 25;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3769,($41|0));
   $44 = __THREW__; __THREW__ = 0;
   $45 = $44&1;
   if ($45) {
    $48 = ___cxa_find_matching_catch_2()|0;
    $49 = tempRet0;
    __ZdlPv($41);
    $$110 = $48;$$112 = $49;
    label = 25;
    break;
   } else {
    $$pre31 = HEAP32[$2>>2]|0;
    $$2 = $41;$$in = $$pre31;
    label = 20;
    break;
   }
  }
 } while(0);
 if ((label|0) == 20) {
  $50 = ($$in|0)==(0|0);
  if ($50) {
   STACKTOP = sp;return ($$2|0);
  }
  $51 = HEAP32[$3>>2]|0;
  $52 = ($51|0)==($$in|0);
  if (!($52)) {
   $scevgep$i$i$i14 = ((($51)) + -4|0);
   $53 = $scevgep$i$i$i14;
   $54 = $$in;
   $55 = (($53) - ($54))|0;
   $56 = $55 >>> 2;
   $57 = $56 ^ -1;
   $scevgep5$i$i$i15 = (($51) + ($57<<2)|0);
   HEAP32[$3>>2] = $scevgep5$i$i$i15;
  }
  __ZdlPv($$in);
  STACKTOP = sp;return ($$2|0);
 }
 else if ((label|0) == 25) {
  $58 = HEAP32[$2>>2]|0;
  $59 = ($58|0)==(0|0);
  if ($59) {
   ___resumeException($$110|0);
   // unreachable;
  }
  $60 = HEAP32[$3>>2]|0;
  $61 = ($60|0)==($58|0);
  if (!($61)) {
   $scevgep$i$i$i = ((($60)) + -4|0);
   $62 = $scevgep$i$i$i;
   $63 = $58;
   $64 = (($62) - ($63))|0;
   $65 = $64 >>> 2;
   $66 = $65 ^ -1;
   $scevgep5$i$i$i = (($60) + ($66<<2)|0);
   HEAP32[$3>>2] = $scevgep5$i$i$i;
  }
  __ZdlPv($58);
  ___resumeException($$110|0);
  // unreachable;
 }
 return (0)|0;
}
function __ZN3osg26createTexturedQuadGeometryERKNS_5Vec3fES2_S2_ffff($0,$1,$2,$3,$4,$5,$6) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = +$3;
 $4 = +$4;
 $5 = +$5;
 $6 = +$6;
 var $$4 = 0, $$467 = 0, $$pre = 0, $$pre170 = 0, $$pre171 = 0, $$pre172 = 0, $$sroa$0128$0$$sroa_idx = 0, $$sroa$0136$0$$sroa_idx = 0, $$sroa$4$0$$sroa_idx122 = 0, $$sroa$4130$0$$sroa_idx131 = 0, $$sroa$4138$0$$sroa_idx139 = 0, $$sroa$4146$0$$sroa_idx147 = 0, $$sroa$5$0$$sroa_idx124 = 0, $$sroa$5133$0$$sroa_idx134 = 0, $$sroa$5141$0$$sroa_idx142 = 0, $$sroa$5149$0$$sroa_idx150 = 0, $$sroa$speculated$$i$i$i$i = 0, $$sroa$speculated$$i$i$i$i69 = 0, $$sroa$speculated$$i$i$i$i75 = 0, $$sroa$speculated$$i$i$i$i83 = 0;
 var $$sroa$speculated$i$i$i$i = 0, $$sroa$speculated$i$i$i$i68 = 0, $$sroa$speculated$i$i$i$i74 = 0, $$sroa$speculated$i$i$i$i82 = 0, $$sroa_raw_idx = 0, $$sroa_raw_idx$1 = 0, $$sroa_raw_idx$2 = 0, $$sroa_raw_idx$3 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0.0, $133 = 0.0, $134 = 0.0, $135 = 0.0, $136 = 0.0, $137 = 0.0, $138 = 0.0, $139 = 0.0, $14 = 0, $140 = 0.0, $141 = 0.0, $142 = 0.0, $143 = 0.0, $144 = 0.0, $145 = 0.0, $146 = 0.0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0.0, $151 = 0.0, $152 = 0, $153 = 0.0, $154 = 0.0, $155 = 0.0, $156 = 0, $157 = 0.0, $158 = 0.0, $159 = 0.0, $16 = 0.0, $160 = 0.0, $161 = 0, $162 = 0.0, $163 = 0.0, $164 = 0.0;
 var $165 = 0.0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0.0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0.0, $180 = 0, $181 = 0, $182 = 0;
 var $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0.0, $200 = 0;
 var $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0;
 var $22 = 0.0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0.0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0;
 var $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0.0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0;
 var $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0.0, $270 = 0, $271 = 0, $272 = 0, $273 = 0;
 var $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0.0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0;
 var $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0;
 var $32 = 0, $33 = 0.0, $34 = 0.0, $35 = 0.0, $36 = 0.0, $37 = 0, $38 = 0.0, $39 = 0.0, $40 = 0.0, $41 = 0, $42 = 0.0, $43 = 0.0, $44 = 0, $45 = 0.0, $46 = 0.0, $47 = 0.0, $48 = 0.0, $49 = 0.0, $50 = 0.0, $51 = 0.0;
 var $52 = 0.0, $53 = 0.0, $54 = 0.0, $55 = 0.0, $56 = 0.0, $57 = 0.0, $58 = 0.0, $59 = 0.0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, $eh$lpad$body90$index7Z2D = 0, $eh$lpad$body90$indexZ2D = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $7 = (__Znwj(276)|0);
 __THREW__ = 0;
 invoke_vi(3750,($7|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $298 = ___cxa_find_matching_catch_2()|0;
  $299 = tempRet0;
  __ZdlPv($7);
  $$4 = $298;$$467 = $299;
  ___resumeException($$4|0);
  // unreachable;
 }
 HEAP32[$7>>2] = (59536);
 $10 = ((($7)) + 216|0);
 $11 = ((($7)) + 182|0);
 dest=$10; stop=dest+56|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));HEAP8[$10+56>>0]=0|0;
 HEAP8[$11>>0] = 1;
 $12 = ((($7)) + 183|0);
 HEAP8[$12>>0] = 0;
 $13 = (__Znwj(88)|0);
 __THREW__ = 0;
 invoke_vii(3776,($13|0),4);
 $14 = __THREW__; __THREW__ = 0;
 $15 = $14&1;
 if ($15) {
  $300 = ___cxa_find_matching_catch_2()|0;
  $301 = tempRet0;
  __ZdlPv($13);
  $$4 = $300;$$467 = $301;
  ___resumeException($$4|0);
  // unreachable;
 }
 $16 = +HEAPF32[$0>>2];
 $17 = +HEAPF32[$2>>2];
 $18 = $16 + $17;
 $19 = ((($0)) + 4|0);
 $20 = +HEAPF32[$19>>2];
 $21 = ((($2)) + 4|0);
 $22 = +HEAPF32[$21>>2];
 $23 = $20 + $22;
 $24 = ((($0)) + 8|0);
 $25 = +HEAPF32[$24>>2];
 $26 = ((($2)) + 8|0);
 $27 = +HEAPF32[$26>>2];
 $28 = $25 + $27;
 $29 = ((($13)) + 76|0);
 $30 = HEAP32[$29>>2]|0;
 HEAPF32[$30>>2] = $18;
 $$sroa$4146$0$$sroa_idx147 = ((($30)) + 4|0);
 HEAPF32[$$sroa$4146$0$$sroa_idx147>>2] = $23;
 $$sroa$5149$0$$sroa_idx150 = ((($30)) + 8|0);
 HEAPF32[$$sroa$5149$0$$sroa_idx150>>2] = $28;
 $31 = HEAP32[$29>>2]|0;
 $32 = ((($31)) + 12|0);
 ;HEAP32[$32>>2]=HEAP32[$0>>2]|0;HEAP32[$32+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$32+8>>2]=HEAP32[$0+8>>2]|0;
 $33 = +HEAPF32[$0>>2];
 $34 = +HEAPF32[$1>>2];
 $35 = $33 + $34;
 $36 = +HEAPF32[$19>>2];
 $37 = ((($1)) + 4|0);
 $38 = +HEAPF32[$37>>2];
 $39 = $36 + $38;
 $40 = +HEAPF32[$24>>2];
 $41 = ((($1)) + 8|0);
 $42 = +HEAPF32[$41>>2];
 $43 = $40 + $42;
 $44 = HEAP32[$29>>2]|0;
 $$sroa$0136$0$$sroa_idx = ((($44)) + 24|0);
 HEAPF32[$$sroa$0136$0$$sroa_idx>>2] = $35;
 $$sroa$4138$0$$sroa_idx139 = ((($44)) + 28|0);
 HEAPF32[$$sroa$4138$0$$sroa_idx139>>2] = $39;
 $$sroa$5141$0$$sroa_idx142 = ((($44)) + 32|0);
 HEAPF32[$$sroa$5141$0$$sroa_idx142>>2] = $43;
 $45 = +HEAPF32[$0>>2];
 $46 = +HEAPF32[$1>>2];
 $47 = $45 + $46;
 $48 = +HEAPF32[$19>>2];
 $49 = +HEAPF32[$37>>2];
 $50 = $48 + $49;
 $51 = +HEAPF32[$24>>2];
 $52 = +HEAPF32[$41>>2];
 $53 = $51 + $52;
 $54 = +HEAPF32[$2>>2];
 $55 = $47 + $54;
 $56 = +HEAPF32[$21>>2];
 $57 = $50 + $56;
 $58 = +HEAPF32[$26>>2];
 $59 = $53 + $58;
 $60 = HEAP32[$29>>2]|0;
 $$sroa$0128$0$$sroa_idx = ((($60)) + 36|0);
 HEAPF32[$$sroa$0128$0$$sroa_idx>>2] = $55;
 $$sroa$4130$0$$sroa_idx131 = ((($60)) + 40|0);
 HEAPF32[$$sroa$4130$0$$sroa_idx131>>2] = $57;
 $$sroa$5133$0$$sroa_idx134 = ((($60)) + 44|0);
 HEAPF32[$$sroa$5133$0$$sroa_idx134>>2] = $59;
 __ZN3osg8Geometry14setVertexArrayEPNS_5ArrayE($7,$13);
 $61 = (__Znwj(88)|0);
 __THREW__ = 0;
 invoke_vii(3435,($61|0),1);
 $62 = __THREW__; __THREW__ = 0;
 $63 = $62&1;
 do {
  if ($63) {
   $302 = ___cxa_find_matching_catch_2()|0;
   $303 = tempRet0;
   $eh$lpad$body$index2Z2D = $303;$eh$lpad$body$indexZ2D = $302;
  } else {
   $64 = ((($61)) + 12|0);
   ;HEAP32[$64>>2]=0|0;HEAP32[$64+4>>2]=0|0;HEAP32[$64+8>>2]=0|0;
   $65 = ((($61)) + 24|0);
   HEAP32[$65>>2] = 2;
   $66 = ((($61)) + 28|0);
   ;HEAP32[$66>>2]=0|0;HEAP32[$66+4>>2]=0|0;HEAP32[$66+8>>2]=0|0;HEAP32[$66+12>>2]=0|0;HEAP32[$66+16>>2]=0|0;HEAP32[$66+20>>2]=0|0;
   HEAP32[$61>>2] = (54500);
   $67 = ((($61)) + 52|0);
   HEAP32[$67>>2] = 27;
   $68 = ((($61)) + 56|0);
   HEAP32[$68>>2] = 2;
   $69 = ((($61)) + 60|0);
   HEAP32[$69>>2] = 5126;
   $70 = ((($61)) + 64|0);
   HEAP32[$70>>2] = -1;
   $71 = ((($61)) + 68|0);
   HEAP8[$71>>0] = 0;
   $72 = ((($61)) + 69|0);
   HEAP8[$72>>0] = 0;
   $73 = ((($61)) + 72|0);
   HEAP32[$73>>2] = (38536);
   $74 = ((($61)) + 76|0);
   HEAP32[$74>>2] = 0;
   $75 = ((($61)) + 80|0);
   HEAP32[$75>>2] = 0;
   $76 = ((($61)) + 84|0);
   HEAP32[$76>>2] = 0;
   __THREW__ = 0;
   $77 = (invoke_ii(3276,32)|0);
   $78 = __THREW__; __THREW__ = 0;
   $79 = $78&1;
   if ($79) {
    $96 = ___cxa_find_matching_catch_2()|0;
    $97 = tempRet0;
    __THREW__ = 0;
    invoke_vi(1265,($61|0));
    $98 = __THREW__; __THREW__ = 0;
    $99 = $98&1;
    if (!($99)) {
     $eh$lpad$body$index2Z2D = $97;$eh$lpad$body$indexZ2D = $96;
     break;
    }
    $100 = ___cxa_find_matching_catch_3(0|0)|0;
    $101 = tempRet0;
    ___clang_call_terminate($100);
    // unreachable;
   }
   HEAP32[$74>>2] = $77;
   $80 = ((($77)) + 32|0);
   HEAP32[$76>>2] = $80;
   HEAP32[$77>>2] = 0;
   $$sroa_raw_idx = ((($77)) + 4|0);
   HEAP32[$$sroa_raw_idx>>2] = 0;
   $81 = ((($77)) + 8|0);
   HEAP32[$81>>2] = 0;
   $$sroa_raw_idx$1 = ((($77)) + 12|0);
   HEAP32[$$sroa_raw_idx$1>>2] = 0;
   $82 = ((($77)) + 16|0);
   HEAP32[$82>>2] = 0;
   $$sroa_raw_idx$2 = ((($77)) + 20|0);
   HEAP32[$$sroa_raw_idx$2>>2] = 0;
   $83 = ((($77)) + 24|0);
   HEAP32[$83>>2] = 0;
   $$sroa_raw_idx$3 = ((($77)) + 28|0);
   HEAP32[$$sroa_raw_idx$3>>2] = 0;
   $84 = ((($77)) + 32|0);
   HEAP32[$75>>2] = $84;
   HEAP32[$61>>2] = (38040);
   HEAP32[$73>>2] = (38264);
   $85 = HEAP32[$74>>2]|0;
   HEAPF32[$85>>2] = $3;
   $86 = ((($85)) + 4|0);
   HEAPF32[$86>>2] = $6;
   $87 = ((($85)) + 8|0);
   HEAPF32[$87>>2] = $3;
   $88 = ((($85)) + 12|0);
   HEAPF32[$88>>2] = $4;
   $89 = ((($85)) + 16|0);
   HEAPF32[$89>>2] = $5;
   $90 = ((($85)) + 20|0);
   HEAPF32[$90>>2] = $4;
   $91 = ((($85)) + 24|0);
   HEAPF32[$91>>2] = $5;
   $92 = ((($85)) + 28|0);
   HEAPF32[$92>>2] = $6;
   __ZN3osg8Geometry16setTexCoordArrayEjPNS_5ArrayENS1_7BindingE($7,0,$61,-1);
   $93 = (__Znwj(88)|0);
   __THREW__ = 0;
   invoke_vii(3435,($93|0),1);
   $94 = __THREW__; __THREW__ = 0;
   $95 = $94&1;
   do {
    if ($95) {
     $304 = ___cxa_find_matching_catch_2()|0;
     $305 = tempRet0;
     $eh$lpad$body90$index7Z2D = $305;$eh$lpad$body90$indexZ2D = $304;
    } else {
     $102 = ((($93)) + 12|0);
     ;HEAP32[$102>>2]=0|0;HEAP32[$102+4>>2]=0|0;HEAP32[$102+8>>2]=0|0;
     $103 = ((($93)) + 24|0);
     HEAP32[$103>>2] = 2;
     $104 = ((($93)) + 28|0);
     ;HEAP32[$104>>2]=0|0;HEAP32[$104+4>>2]=0|0;HEAP32[$104+8>>2]=0|0;HEAP32[$104+12>>2]=0|0;HEAP32[$104+16>>2]=0|0;HEAP32[$104+20>>2]=0|0;
     HEAP32[$93>>2] = (54500);
     $105 = ((($93)) + 52|0);
     HEAP32[$105>>2] = 29;
     $106 = ((($93)) + 56|0);
     HEAP32[$106>>2] = 4;
     $107 = ((($93)) + 60|0);
     HEAP32[$107>>2] = 5126;
     $108 = ((($93)) + 64|0);
     HEAP32[$108>>2] = -1;
     $109 = ((($93)) + 68|0);
     HEAP8[$109>>0] = 0;
     $110 = ((($93)) + 69|0);
     HEAP8[$110>>0] = 0;
     $111 = ((($93)) + 72|0);
     HEAP32[$111>>2] = (38520);
     $112 = ((($93)) + 76|0);
     HEAP32[$112>>2] = 0;
     $113 = ((($93)) + 80|0);
     HEAP32[$113>>2] = 0;
     $114 = ((($93)) + 84|0);
     HEAP32[$114>>2] = 0;
     __THREW__ = 0;
     $115 = (invoke_ii(3276,16)|0);
     $116 = __THREW__; __THREW__ = 0;
     $117 = $116&1;
     if ($117) {
      $126 = ___cxa_find_matching_catch_2()|0;
      $127 = tempRet0;
      __THREW__ = 0;
      invoke_vi(1265,($93|0));
      $128 = __THREW__; __THREW__ = 0;
      $129 = $128&1;
      if (!($129)) {
       $eh$lpad$body90$index7Z2D = $127;$eh$lpad$body90$indexZ2D = $126;
       break;
      }
      $130 = ___cxa_find_matching_catch_3(0|0)|0;
      $131 = tempRet0;
      ___clang_call_terminate($130);
      // unreachable;
     }
     HEAP32[$112>>2] = $115;
     $118 = ((($115)) + 16|0);
     HEAP32[$114>>2] = $118;
     $119 = ((($115)) + 16|0);
     HEAP32[$113>>2] = $119;
     HEAP32[$93>>2] = (38280);
     HEAP32[$111>>2] = (38504);
     HEAPF32[$115>>2] = 1.0;
     $120 = ((($115)) + 4|0);
     HEAPF32[$120>>2] = 1.0;
     $121 = ((($115)) + 8|0);
     HEAPF32[$121>>2] = 1.0;
     $122 = ((($115)) + 12|0);
     HEAPF32[$122>>2] = 1.0;
     __ZN3osg8Geometry13setColorArrayEPNS_5ArrayENS1_7BindingE($7,$93,1);
     $123 = (__Znwj(88)|0);
     __THREW__ = 0;
     invoke_vii(3776,($123|0),1);
     $124 = __THREW__; __THREW__ = 0;
     $125 = $124&1;
     if ($125) {
      $306 = ___cxa_find_matching_catch_2()|0;
      $307 = tempRet0;
      __ZdlPv($123);
      $$4 = $306;$$467 = $307;
      ___resumeException($$4|0);
      // unreachable;
     }
     $132 = +HEAPF32[$37>>2];
     $133 = +HEAPF32[$26>>2];
     $134 = $132 * $133;
     $135 = +HEAPF32[$41>>2];
     $136 = +HEAPF32[$21>>2];
     $137 = $135 * $136;
     $138 = $134 - $137;
     $139 = +HEAPF32[$2>>2];
     $140 = $135 * $139;
     $141 = +HEAPF32[$1>>2];
     $142 = $133 * $141;
     $143 = $140 - $142;
     $144 = $136 * $141;
     $145 = $132 * $139;
     $146 = $144 - $145;
     $147 = ((($123)) + 76|0);
     $148 = HEAP32[$147>>2]|0;
     HEAPF32[$148>>2] = $138;
     $$sroa$4$0$$sroa_idx122 = ((($148)) + 4|0);
     HEAPF32[$$sroa$4$0$$sroa_idx122>>2] = $143;
     $$sroa$5$0$$sroa_idx124 = ((($148)) + 8|0);
     HEAPF32[$$sroa$5$0$$sroa_idx124>>2] = $146;
     $149 = HEAP32[$147>>2]|0;
     $150 = +HEAPF32[$149>>2];
     $151 = $150 * $150;
     $152 = ((($149)) + 4|0);
     $153 = +HEAPF32[$152>>2];
     $154 = $153 * $153;
     $155 = $151 + $154;
     $156 = ((($149)) + 8|0);
     $157 = +HEAPF32[$156>>2];
     $158 = $157 * $157;
     $159 = $155 + $158;
     $160 = (+Math_sqrt((+$159)));
     $161 = $160 > 0.0;
     $162 = 1.0 / $160;
     if ($161) {
      $163 = $157 * $162;
      $164 = $153 * $162;
      $165 = $150 * $162;
      HEAPF32[$149>>2] = $165;
      HEAPF32[$152>>2] = $164;
      HEAPF32[$156>>2] = $163;
     }
     __ZN3osg8Geometry14setNormalArrayEPNS_5ArrayENS1_7BindingE($7,$123,1);
     $166 = (__Znwj(80)|0);
     __THREW__ = 0;
     invoke_vii(3435,($166|0),1);
     $167 = __THREW__; __THREW__ = 0;
     $168 = $167&1;
     if ($168) {
      $308 = ___cxa_find_matching_catch_2()|0;
      $309 = tempRet0;
      __ZdlPv($166);
      $$4 = $308;$$467 = $309;
      ___resumeException($$4|0);
      // unreachable;
     }
     $169 = ((($166)) + 12|0);
     ;HEAP32[$169>>2]=0|0;HEAP32[$169+4>>2]=0|0;HEAP32[$169+8>>2]=0|0;
     $170 = ((($166)) + 24|0);
     HEAP32[$170>>2] = 2;
     $171 = ((($166)) + 28|0);
     ;HEAP32[$171>>2]=0|0;HEAP32[$171+4>>2]=0|0;HEAP32[$171+8>>2]=0|0;HEAP32[$171+12>>2]=0|0;HEAP32[$171+16>>2]=0|0;HEAP32[$171+20>>2]=0|0;
     $172 = ((($166)) + 52|0);
     HEAP32[$172>>2] = 3;
     $173 = ((($166)) + 56|0);
     HEAP32[$173>>2] = 0;
     $174 = ((($166)) + 60|0);
     HEAP32[$174>>2] = 4;
     $175 = ((($166)) + 64|0);
     $176 = ((($166)) + 68|0);
     HEAP32[$176>>2] = 0;
     $177 = ((($166)) + 72|0);
     HEAP32[$177>>2] = 0;
     $178 = ((($166)) + 76|0);
     HEAP32[$178>>2] = 0;
     HEAP32[$166>>2] = (64052);
     HEAP32[$175>>2] = (64300);
     $179 = (__Znwj(1)|0);
     $180 = ((($179)) + 1|0);
     $181 = $180;
     HEAP8[$179>>0] = 0;
     $182 = $179;
     HEAP32[$176>>2] = $182;
     HEAP32[$177>>2] = $181;
     HEAP32[$178>>2] = $181;
     $183 = (__Znwj(2)|0);
     $184 = ((($183)) + 1|0);
     $185 = ((($183)) + 2|0);
     $186 = $185;
     HEAP8[$184>>0] = 1;
     $187 = ((($183)) + 2|0);
     $188 = $187;
     $189 = $183;
     $190 = HEAP8[$179>>0]|0;
     HEAP8[$183>>0] = $190;
     HEAP32[$176>>2] = $189;
     HEAP32[$177>>2] = $188;
     HEAP32[$178>>2] = $186;
     __ZdlPv($179);
     $$pre = HEAP32[$177>>2]|0;
     $191 = HEAP32[$178>>2]|0;
     $192 = ($$pre|0)==($191|0);
     if ($192) {
      $195 = $191;
      $196 = HEAP32[$176>>2]|0;
      $197 = (($195) - ($196))|0;
      $198 = (($197) + 1)|0;
      $199 = ($198|0)<(0);
      $200 = $196;
      if ($199) {
       __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($176);
       // unreachable;
      }
      $201 = ($197>>>0)<(1073741823);
      $202 = $197 << 1;
      $203 = ($202>>>0)<($198>>>0);
      $$sroa$speculated$i$i$i$i82 = $203 ? $198 : $202;
      $$sroa$speculated$$i$i$i$i83 = $201 ? $$sroa$speculated$i$i$i$i82 : 2147483647;
      $204 = ($$sroa$speculated$$i$i$i$i83|0)==(0);
      if ($204) {
       $207 = 0;
      } else {
       $205 = (__Znwj($$sroa$speculated$$i$i$i$i83)|0);
       $207 = $205;
      }
      $206 = (($207) + ($197)|0);
      $208 = (($207) + ($$sroa$speculated$$i$i$i$i83)|0);
      $209 = $208;
      HEAP8[$206>>0] = 2;
      $210 = ((($206)) + 1|0);
      $211 = $210;
      $212 = (0 - ($197))|0;
      $213 = (($206) + ($212)|0);
      $214 = $213;
      $215 = ($197|0)>(0);
      if ($215) {
       _memcpy(($213|0),($200|0),($197|0))|0;
      }
      HEAP32[$176>>2] = $214;
      HEAP32[$177>>2] = $211;
      HEAP32[$178>>2] = $209;
      $216 = ($196|0)==(0);
      if ($216) {
       $218 = $210;
      } else {
       __ZdlPv($200);
       $$pre170 = HEAP32[$177>>2]|0;
       $218 = $$pre170;
      }
     } else {
      HEAP8[$$pre>>0] = 2;
      $193 = HEAP32[$177>>2]|0;
      $194 = ((($193)) + 1|0);
      HEAP32[$177>>2] = $194;
      $218 = $194;
     }
     $217 = HEAP32[$178>>2]|0;
     $219 = ($218|0)==($217|0);
     if ($219) {
      $222 = $217;
      $223 = HEAP32[$176>>2]|0;
      $224 = (($222) - ($223))|0;
      $225 = (($224) + 1)|0;
      $226 = ($225|0)<(0);
      $227 = $223;
      if ($226) {
       __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($176);
       // unreachable;
      }
      $228 = ($224>>>0)<(1073741823);
      $229 = $224 << 1;
      $230 = ($229>>>0)<($225>>>0);
      $$sroa$speculated$i$i$i$i74 = $230 ? $225 : $229;
      $$sroa$speculated$$i$i$i$i75 = $228 ? $$sroa$speculated$i$i$i$i74 : 2147483647;
      $231 = ($$sroa$speculated$$i$i$i$i75|0)==(0);
      if ($231) {
       $234 = 0;
      } else {
       $232 = (__Znwj($$sroa$speculated$$i$i$i$i75)|0);
       $234 = $232;
      }
      $233 = (($234) + ($224)|0);
      $235 = (($234) + ($$sroa$speculated$$i$i$i$i75)|0);
      $236 = $235;
      HEAP8[$233>>0] = 2;
      $237 = ((($233)) + 1|0);
      $238 = $237;
      $239 = (0 - ($224))|0;
      $240 = (($233) + ($239)|0);
      $241 = $240;
      $242 = ($224|0)>(0);
      if ($242) {
       _memcpy(($240|0),($227|0),($224|0))|0;
      }
      HEAP32[$176>>2] = $241;
      HEAP32[$177>>2] = $238;
      HEAP32[$178>>2] = $236;
      $243 = ($223|0)==(0);
      if ($243) {
       $245 = $237;
      } else {
       __ZdlPv($227);
       $$pre171 = HEAP32[$177>>2]|0;
       $245 = $$pre171;
      }
     } else {
      HEAP8[$218>>0] = 2;
      $220 = HEAP32[$177>>2]|0;
      $221 = ((($220)) + 1|0);
      HEAP32[$177>>2] = $221;
      $245 = $221;
     }
     $244 = HEAP32[$178>>2]|0;
     $246 = ($245|0)==($244|0);
     if ($246) {
      $249 = $244;
      $250 = HEAP32[$176>>2]|0;
      $251 = (($249) - ($250))|0;
      $252 = (($251) + 1)|0;
      $253 = ($252|0)<(0);
      $254 = $250;
      if ($253) {
       __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($176);
       // unreachable;
      }
      $255 = ($251>>>0)<(1073741823);
      $256 = $251 << 1;
      $257 = ($256>>>0)<($252>>>0);
      $$sroa$speculated$i$i$i$i68 = $257 ? $252 : $256;
      $$sroa$speculated$$i$i$i$i69 = $255 ? $$sroa$speculated$i$i$i$i68 : 2147483647;
      $258 = ($$sroa$speculated$$i$i$i$i69|0)==(0);
      if ($258) {
       $261 = 0;
      } else {
       $259 = (__Znwj($$sroa$speculated$$i$i$i$i69)|0);
       $261 = $259;
      }
      $260 = (($261) + ($251)|0);
      $262 = (($261) + ($$sroa$speculated$$i$i$i$i69)|0);
      $263 = $262;
      HEAP8[$260>>0] = 3;
      $264 = ((($260)) + 1|0);
      $265 = $264;
      $266 = (0 - ($251))|0;
      $267 = (($260) + ($266)|0);
      $268 = $267;
      $269 = ($251|0)>(0);
      if ($269) {
       _memcpy(($267|0),($254|0),($251|0))|0;
      }
      HEAP32[$176>>2] = $268;
      HEAP32[$177>>2] = $265;
      HEAP32[$178>>2] = $263;
      $270 = ($250|0)==(0);
      if ($270) {
       $272 = $264;
      } else {
       __ZdlPv($254);
       $$pre172 = HEAP32[$177>>2]|0;
       $272 = $$pre172;
      }
     } else {
      HEAP8[$245>>0] = 3;
      $247 = HEAP32[$177>>2]|0;
      $248 = ((($247)) + 1|0);
      HEAP32[$177>>2] = $248;
      $272 = $248;
     }
     $271 = HEAP32[$178>>2]|0;
     $273 = ($272|0)==($271|0);
     if (!($273)) {
      HEAP8[$272>>0] = 0;
      $274 = HEAP32[$177>>2]|0;
      $275 = ((($274)) + 1|0);
      HEAP32[$177>>2] = $275;
      (__ZN3osg8Geometry15addPrimitiveSetEPNS_12PrimitiveSetE($7,$166)|0);
      return ($7|0);
     }
     $276 = $271;
     $277 = HEAP32[$176>>2]|0;
     $278 = (($276) - ($277))|0;
     $279 = (($278) + 1)|0;
     $280 = ($279|0)<(0);
     $281 = $277;
     if ($280) {
      __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($176);
      // unreachable;
     }
     $282 = ($278>>>0)<(1073741823);
     $283 = $278 << 1;
     $284 = ($283>>>0)<($279>>>0);
     $$sroa$speculated$i$i$i$i = $284 ? $279 : $283;
     $$sroa$speculated$$i$i$i$i = $282 ? $$sroa$speculated$i$i$i$i : 2147483647;
     $285 = ($$sroa$speculated$$i$i$i$i|0)==(0);
     if ($285) {
      $288 = 0;
     } else {
      $286 = (__Znwj($$sroa$speculated$$i$i$i$i)|0);
      $288 = $286;
     }
     $287 = (($288) + ($278)|0);
     $289 = (($288) + ($$sroa$speculated$$i$i$i$i)|0);
     $290 = $289;
     HEAP8[$287>>0] = 0;
     $291 = ((($287)) + 1|0);
     $292 = $291;
     $293 = (0 - ($278))|0;
     $294 = (($287) + ($293)|0);
     $295 = $294;
     $296 = ($278|0)>(0);
     if ($296) {
      _memcpy(($294|0),($281|0),($278|0))|0;
     }
     HEAP32[$176>>2] = $295;
     HEAP32[$177>>2] = $292;
     HEAP32[$178>>2] = $290;
     $297 = ($277|0)==(0);
     if ($297) {
      (__ZN3osg8Geometry15addPrimitiveSetEPNS_12PrimitiveSetE($7,$166)|0);
      return ($7|0);
     }
     __ZdlPv($281);
     (__ZN3osg8Geometry15addPrimitiveSetEPNS_12PrimitiveSetE($7,$166)|0);
     return ($7|0);
    }
   } while(0);
   __ZdlPv($93);
   $$4 = $eh$lpad$body90$indexZ2D;$$467 = $eh$lpad$body90$index7Z2D;
   ___resumeException($$4|0);
   // unreachable;
  }
 } while(0);
 __ZdlPv($61);
 $$4 = $eh$lpad$body$indexZ2D;$$467 = $eh$lpad$body$index2Z2D;
 ___resumeException($$4|0);
 // unreachable;
 return (0)|0;
}
function __ZN3osg8Geometry17fixDeprecatedDataEv($0) {
 $0 = $0|0;
 var $$$ = 0, $$$$ = 0, $$$$$ = 0, $$$$$899 = 0, $$$$897 = 0, $$$10 = 0, $$$1439 = 0, $$$4$off0 = 0, $$$4442 = 0, $$$4442$us = 0, $$$6444 = 0, $$$8 = 0, $$$895 = 0, $$0$i = 0, $$0$i511 = 0, $$0393676 = 0, $$0394675 = 0, $$0396670 = 0, $$0397669 = 0, $$0398668 = 0;
 var $$0399863 = 0, $$0400689 = 0, $$0401855 = 0, $$0402705 = 0, $$0403704 = 0, $$0404703 = 0, $$0405695 = 0, $$0406694 = 0, $$0407693 = 0, $$0408$lcssa = 0, $$0408849 = 0, $$0411 = 0, $$0417717 = 0, $$0418 = 0, $$0425734 = 0, $$0426733 = 0, $$0427732 = 0, $$0428823 = 0, $$0435724 = 0, $$0436723 = 0;
 var $$0437722 = 0, $$0438822 = 0, $$0446 = 0, $$0452743 = 0, $$0453813 = 0, $$0454763 = 0, $$0454763$us = 0, $$0455762 = 0, $$0455762$us = 0, $$0456761 = 0, $$0456761$us = 0, $$0457811 = 0, $$0458753 = 0, $$0458753$us = 0, $$0459752 = 0, $$0459752$us = 0, $$0460751 = 0, $$0460751$us = 0, $$0461793 = 0, $$0462773 = 0;
 var $$0462773$us = 0, $$0464784 = 0, $$0464784$us = 0, $$0466792 = 0, $$0467803 = 0, $$0468802 = 0, $$0469801 = 0, $$0470791 = 0, $$0677 = 0, $$10686 = 0, $$12 = 0, $$1409844 = 0, $$1429815 = 0, $$1439814 = 0, $$1465$lcssa = 0, $$1465$lcssa$us = 0, $$1465771 = 0, $$1465771$us = 0, $$2410 = 0, $$2430786 = 0;
 var $$2430786$us = 0, $$2448 = 0, $$3431$lcssa = 0, $$3431$lcssa$us = 0, $$3431775 = 0, $$3431775$us = 0, $$3441785 = 0, $$3441785$us = 0, $$3449 = 0, $$4$off0$lcssa = 0, $$4$off0857 = 0, $$4415 = 0, $$4422 = 0, $$4432745 = 0, $$4442$lcssa = 0, $$4442$lcssa$us = 0, $$4442774 = 0, $$4442774$us = 0, $$4450 = 0, $$5416 = 0;
 var $$5423 = 0, $$5433715 = 0, $$5451 = 0, $$6434687 = 0, $$6444744 = 0, $$656657 = 0, $$7 = 0, $$8714 = 0, $$in = 0, $$in893 = 0, $$pre = 0, $$pre880 = 0, $$pre881 = 0, $$pre882 = 0, $$pre883 = 0, $$pre884 = 0, $$pre885 = 0, $$pre886 = 0, $$pre887 = 0, $$pre888 = 0;
 var $$pre889 = 0, $$pre890 = 0, $$pre891 = 0, $$pre892 = 0, $$sroa$0514$0681 = 0, $$sroa$0520$0671 = 0, $$sroa$0526$0685 = 0, $$sroa$0533$0709 = 0, $$sroa$0539$0699 = 0, $$sroa$0545$0713 = 0, $$sroa$0552$0738 = 0, $$sroa$0558$0728 = 0, $$sroa$0564$0742 = 0, $$sroa$0571$0767 = 0, $$sroa$0571$0767$us = 0, $$sroa$0577$0757 = 0, $$sroa$0577$0757$us = 0, $$sroa$0583$0783 = 0, $$sroa$0583$0783$us = 0, $$sroa$0590$0807 = 0;
 var $$sroa$0596$0797 = 0, $$sroa$0602$0821 = 0, $$sroa$0609$0827 = 0, $$sroa$0617$0831 = 0, $$sroa$0625$0835 = 0, $$sroa$0635$0839 = 0, $$sroa$0645$0843 = 0, $$sroa$0651$0848 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0;
 var $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0;
 var $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0;
 var $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0;
 var $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0;
 var $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0;
 var $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0;
 var $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0;
 var $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0;
 var $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0;
 var $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0;
 var $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0;
 var $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0;
 var $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0;
 var $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0;
 var $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0;
 var $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0;
 var $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0;
 var $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0;
 var $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0;
 var $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0;
 var $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0;
 var $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0;
 var $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0;
 var $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0;
 var $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0;
 var $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0;
 var $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0;
 var $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0;
 var $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0;
 var $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0;
 var $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0;
 var $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0;
 var $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0;
 var $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0;
 var $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0;
 var $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0;
 var $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0;
 var $830 = 0, $831 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0;
 var $scevgep$i$i$i = 0, $scevgep$i$i$i477 = 0, $scevgep$i$i$i484 = 0, $scevgep$i$i$i492 = 0, $scevgep5$i$i$i = 0, $scevgep5$i$i$i478 = 0, $scevgep5$i$i$i485 = 0, $scevgep5$i$i$i493 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(80|0);
 $1 = sp + 60|0;
 $2 = sp + 48|0;
 $3 = sp + 36|0;
 $4 = sp + 24|0;
 $5 = sp + 12|0;
 $6 = sp;
 $7 = ((($0)) + 272|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = ($8<<24>>24)==(0);
 if ($9) {
  STACKTOP = sp;return;
 }
 $10 = ((($0)) + 228|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0|0);
 if (!($12)) {
  $13 = HEAP32[$11>>2]|0;
  $14 = ((($13)) + 124|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (FUNCTION_TABLE_ii[$15 & 8191]($11)|0);
  $17 = ($16|0)==(0|0);
  if (!($17)) {
   $18 = (___dynamic_cast($16,26488,22736,0)|0);
   $19 = ($18|0)==(0|0);
   if (!($19)) {
    $20 = HEAP32[$10>>2]|0;
    $21 = (__ZN21GeometryUtilFunctionsL16expandIndexArrayEPKN3osg5ArrayEPKNS0_10IndexArrayE($20,$18)|0);
    __ZN3osg8Geometry14setVertexArrayEPNS_5ArrayE($0,$21);
   }
  }
 }
 $22 = ((($0)) + 232|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)==(0|0);
 if ($24) {
  $$656657 = 0;
 } else {
  $25 = ((($23)) + 64|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = ($26|0)==(3);
  $28 = HEAP32[$23>>2]|0;
  $29 = ((($28)) + 124|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (FUNCTION_TABLE_ii[$30 & 8191]($23)|0);
  $32 = ($31|0)==(0|0);
  if ($32) {
   $$656657 = $27;
  } else {
   $33 = (___dynamic_cast($31,26488,22736,0)|0);
   $34 = ($33|0)==(0|0);
   if ($34) {
    $$656657 = $27;
   } else {
    $35 = ((($0)) + 232|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = (__ZN21GeometryUtilFunctionsL16expandIndexArrayEPKN3osg5ArrayEPKNS0_10IndexArrayE($36,$33)|0);
    __ZN3osg8Geometry14setNormalArrayEPNS_5ArrayENS1_7BindingE($0,$37,-1);
    $$656657 = $27;
   }
  }
 }
 $38 = ((($0)) + 236|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = ($39|0)==(0|0);
 if ($40) {
  $41 = ((($0)) + 236|0);
  $$$895 = $$656657;$220 = $41;$224 = $41;
 } else {
  $42 = ((($39)) + 64|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = ($43|0)==(3);
  $$$ = $$656657 | $44;
  $45 = ((($0)) + 236|0);
  $46 = HEAP32[$39>>2]|0;
  $47 = ((($46)) + 124|0);
  $48 = HEAP32[$47>>2]|0;
  $49 = (FUNCTION_TABLE_ii[$48 & 8191]($39)|0);
  $50 = ($49|0)==(0|0);
  if ($50) {
   $$$895 = $$$;$220 = $45;$224 = $45;
  } else {
   $51 = (___dynamic_cast($49,26488,22736,0)|0);
   $52 = ($51|0)==(0|0);
   if ($52) {
    $$$895 = $$$;$220 = $45;$224 = $45;
   } else {
    $53 = HEAP32[$38>>2]|0;
    $54 = (__ZN21GeometryUtilFunctionsL16expandIndexArrayEPKN3osg5ArrayEPKNS0_10IndexArrayE($53,$51)|0);
    __ZN3osg8Geometry13setColorArrayEPNS_5ArrayENS1_7BindingE($0,$54,-1);
    $$$895 = $$$;$220 = $45;$224 = $45;
   }
  }
 }
 $55 = ((($0)) + 240|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = ($56|0)==(0|0);
 if ($57) {
  $58 = ((($0)) + 240|0);
  $$$$897 = $$$895;$230 = $58;$234 = $58;
 } else {
  $59 = ((($56)) + 64|0);
  $60 = HEAP32[$59>>2]|0;
  $61 = ($60|0)==(3);
  $$$$ = $$$895 | $61;
  $62 = ((($0)) + 240|0);
  $63 = HEAP32[$56>>2]|0;
  $64 = ((($63)) + 124|0);
  $65 = HEAP32[$64>>2]|0;
  $66 = (FUNCTION_TABLE_ii[$65 & 8191]($56)|0);
  $67 = ($66|0)==(0|0);
  if ($67) {
   $$$$897 = $$$$;$230 = $62;$234 = $62;
  } else {
   $68 = (___dynamic_cast($66,26488,22736,0)|0);
   $69 = ($68|0)==(0|0);
   if ($69) {
    $$$$897 = $$$$;$230 = $62;$234 = $62;
   } else {
    $70 = HEAP32[$55>>2]|0;
    $71 = (__ZN21GeometryUtilFunctionsL16expandIndexArrayEPKN3osg5ArrayEPKNS0_10IndexArrayE($70,$68)|0);
    __ZN3osg8Geometry22setSecondaryColorArrayEPNS_5ArrayENS1_7BindingE($0,$71,-1);
    $$$$897 = $$$$;$230 = $62;$234 = $62;
   }
  }
 }
 $72 = ((($0)) + 244|0);
 $73 = HEAP32[$72>>2]|0;
 $74 = ($73|0)==(0|0);
 if ($74) {
  $75 = ((($0)) + 244|0);
  $$$$$899 = $$$$897;$240 = $75;$244 = $75;
 } else {
  $76 = ((($73)) + 64|0);
  $77 = HEAP32[$76>>2]|0;
  $78 = ($77|0)==(3);
  $$$$$ = $$$$897 | $78;
  $79 = ((($0)) + 244|0);
  $80 = HEAP32[$73>>2]|0;
  $81 = ((($80)) + 124|0);
  $82 = HEAP32[$81>>2]|0;
  $83 = (FUNCTION_TABLE_ii[$82 & 8191]($73)|0);
  $84 = ($83|0)==(0|0);
  if ($84) {
   $$$$$899 = $$$$$;$240 = $79;$244 = $79;
  } else {
   $85 = (___dynamic_cast($83,26488,22736,0)|0);
   $86 = ($85|0)==(0|0);
   if ($86) {
    $$$$$899 = $$$$$;$240 = $79;$244 = $79;
   } else {
    $87 = HEAP32[$72>>2]|0;
    $88 = (__ZN21GeometryUtilFunctionsL16expandIndexArrayEPKN3osg5ArrayEPKNS0_10IndexArrayE($87,$85)|0);
    __ZN3osg8Geometry16setFogCoordArrayEPNS_5ArrayENS1_7BindingE($0,$88,-1);
    $$$$$899 = $$$$$;$240 = $79;$244 = $79;
   }
  }
 }
 $89 = ((($0)) + 248|0);
 $90 = ((($0)) + 252|0);
 $91 = HEAP32[$90>>2]|0;
 $92 = HEAP32[$89>>2]|0;
 $93 = ($91|0)==($92|0);
 if (!($93)) {
  $$0399863 = 0;$$in = $92;
  while(1) {
   $99 = $$in;
   $100 = (($99) + ($$0399863<<2)|0);
   $101 = HEAP32[$100>>2]|0;
   $102 = ($101|0)==(0|0);
   if (!($102)) {
    $103 = HEAP32[$101>>2]|0;
    $104 = ((($103)) + 124|0);
    $105 = HEAP32[$104>>2]|0;
    $106 = (FUNCTION_TABLE_ii[$105 & 8191]($101)|0);
    $107 = ($106|0)==(0|0);
    if (!($107)) {
     $108 = (___dynamic_cast($106,26488,22736,0)|0);
     $109 = ($108|0)==(0|0);
     if (!($109)) {
      $110 = HEAP32[$90>>2]|0;
      $111 = HEAP32[$89>>2]|0;
      $112 = (($110) - ($111))|0;
      $113 = $112 >> 2;
      $114 = ($113>>>0)>($$0399863>>>0);
      if ($114) {
       $115 = $111;
       $116 = (($115) + ($$0399863<<2)|0);
       $117 = HEAP32[$116>>2]|0;
       $$0$i = $117;
      } else {
       $$0$i = 0;
      }
      $118 = (__ZN21GeometryUtilFunctionsL16expandIndexArrayEPKN3osg5ArrayEPKNS0_10IndexArrayE($$0$i,$108)|0);
      __ZN3osg8Geometry16setTexCoordArrayEjPNS_5ArrayENS1_7BindingE($0,$$0399863,$118,-1);
     }
    }
   }
   $119 = (($$0399863) + 1)|0;
   $120 = HEAP32[$90>>2]|0;
   $121 = HEAP32[$89>>2]|0;
   $122 = (($120) - ($121))|0;
   $123 = $122 >> 2;
   $124 = ($119>>>0)<($123>>>0);
   if ($124) {
    $$0399863 = $119;$$in = $121;
   } else {
    break;
   }
  }
 }
 $94 = ((($0)) + 260|0);
 $95 = ((($0)) + 264|0);
 $96 = HEAP32[$95>>2]|0;
 $97 = HEAP32[$94>>2]|0;
 $98 = ($96|0)==($97|0);
 if ($98) {
  $$4$off0$lcssa = $$$$$899;
 } else {
  $$0401855 = 0;$$4$off0857 = $$$$$899;$$in893 = $97;$127 = $96;
  while(1) {
   $125 = $$in893;
   $126 = (($127) - ($$in893))|0;
   $128 = $126 >> 2;
   $129 = ($128>>>0)>($$0401855>>>0);
   if ($129) {
    $130 = $$in893;
    $131 = (($130) + ($$0401855<<2)|0);
    $132 = HEAP32[$131>>2]|0;
    $133 = ($132|0)==(0|0);
    if ($133) {
     $136 = 0;
    } else {
     $134 = ((($132)) + 64|0);
     $135 = HEAP32[$134>>2]|0;
     $136 = $135;
    }
   } else {
    $136 = 0;
   }
   $137 = ($136|0)==(3);
   $$$4$off0 = $$4$off0857 | $137;
   $138 = (($125) + ($$0401855<<2)|0);
   $139 = HEAP32[$138>>2]|0;
   $140 = ($139|0)==(0|0);
   if (!($140)) {
    $141 = HEAP32[$139>>2]|0;
    $142 = ((($141)) + 124|0);
    $143 = HEAP32[$142>>2]|0;
    $144 = (FUNCTION_TABLE_ii[$143 & 8191]($139)|0);
    $145 = ($144|0)==(0|0);
    if (!($145)) {
     $146 = (___dynamic_cast($144,26488,22736,0)|0);
     $147 = ($146|0)==(0|0);
     if (!($147)) {
      $148 = HEAP32[$95>>2]|0;
      $149 = HEAP32[$94>>2]|0;
      $150 = (($148) - ($149))|0;
      $151 = $150 >> 2;
      $152 = ($151>>>0)>($$0401855>>>0);
      if ($152) {
       $153 = $149;
       $154 = (($153) + ($$0401855<<2)|0);
       $155 = HEAP32[$154>>2]|0;
       $$0$i511 = $155;
      } else {
       $$0$i511 = 0;
      }
      $156 = (__ZN21GeometryUtilFunctionsL16expandIndexArrayEPKN3osg5ArrayEPKNS0_10IndexArrayE($$0$i511,$146)|0);
      __ZN3osg8Geometry20setVertexAttribArrayEjPNS_5ArrayENS1_7BindingE($0,$$0401855,$156,-1);
     }
    }
   }
   $157 = (($$0401855) + 1)|0;
   $158 = HEAP32[$95>>2]|0;
   $159 = HEAP32[$94>>2]|0;
   $160 = (($158) - ($159))|0;
   $161 = $160 >> 2;
   $162 = ($157>>>0)<($161>>>0);
   if ($162) {
    $$0401855 = $157;$$4$off0857 = $$$4$off0;$$in893 = $159;$127 = $158;
   } else {
    $$4$off0$lcssa = $$$4$off0;
    break;
   }
  }
 }
 if (!($$4$off0$lcssa)) {
  HEAP8[$7>>0] = 0;
  STACKTOP = sp;return;
 }
 $163 = ((($0)) + 216|0);
 $164 = HEAP32[$163>>2]|0;
 $165 = ((($0)) + 220|0);
 $166 = HEAP32[$165>>2]|0;
 $167 = ($164|0)==($166|0);
 L64: do {
  if ($167) {
   $$0408$lcssa = 0;
  } else {
   $$0408849 = 0;$$sroa$0651$0848 = $164;
   while(1) {
    $168 = HEAP32[$$sroa$0651$0848>>2]|0;
    $169 = ((($168)) + 52|0);
    $170 = HEAP32[$169>>2]|0;
    switch ($170|0) {
    case 1:  {
     $171 = ((($168)) + 68|0);
     $172 = HEAP32[$171>>2]|0;
     $173 = (($172) + ($$0408849))|0;
     $$2410 = $173;
     break;
    }
    case 2:  {
     $174 = ((($168)) + 68|0);
     $175 = HEAP32[$174>>2]|0;
     $176 = ((($168)) + 72|0);
     $177 = HEAP32[$176>>2]|0;
     $178 = ($175|0)==($177|0);
     if ($178) {
      $$2410 = $$0408849;
     } else {
      $$1409844 = $$0408849;$$sroa$0645$0843 = $175;
      while(1) {
       $179 = HEAP32[$$sroa$0645$0843>>2]|0;
       $180 = (($179) + ($$1409844))|0;
       $181 = ((($$sroa$0645$0843)) + 4|0);
       $182 = ($181|0)==($177|0);
       if ($182) {
        $$2410 = $180;
        break;
       } else {
        $$1409844 = $180;$$sroa$0645$0843 = $181;
       }
      }
     }
     break;
    }
    case 3:  {
     $183 = HEAP32[$168>>2]|0;
     $184 = ((($183)) + 200|0);
     $185 = HEAP32[$184>>2]|0;
     $186 = (FUNCTION_TABLE_ii[$185 & 8191]($168)|0);
     $187 = (($186) + ($$0408849))|0;
     $$2410 = $187;
     break;
    }
    case 4:  {
     $188 = HEAP32[$168>>2]|0;
     $189 = ((($188)) + 200|0);
     $190 = HEAP32[$189>>2]|0;
     $191 = (FUNCTION_TABLE_ii[$190 & 8191]($168)|0);
     $192 = (($191) + ($$0408849))|0;
     $$2410 = $192;
     break;
    }
    case 5:  {
     $193 = HEAP32[$168>>2]|0;
     $194 = ((($193)) + 200|0);
     $195 = HEAP32[$194>>2]|0;
     $196 = (FUNCTION_TABLE_ii[$195 & 8191]($168)|0);
     $197 = (($196) + ($$0408849))|0;
     $$2410 = $197;
     break;
    }
    default: {
     $$2410 = $$0408849;
    }
    }
    $198 = ((($$sroa$0651$0848)) + 4|0);
    $199 = HEAP32[$165>>2]|0;
    $200 = ($198|0)==($199|0);
    if ($200) {
     $$0408$lcssa = $$2410;
     break L64;
    } else {
     $$0408849 = $$2410;$$sroa$0651$0848 = $198;
    }
   }
  }
 } while(0);
 HEAP32[$1>>2] = 0;
 $201 = ((($1)) + 4|0);
 HEAP32[$201>>2] = 0;
 $202 = ((($1)) + 8|0);
 HEAP32[$202>>2] = 0;
 HEAP32[$2>>2] = 0;
 $203 = ((($2)) + 4|0);
 HEAP32[$203>>2] = 0;
 $204 = ((($2)) + 8|0);
 HEAP32[$204>>2] = 0;
 $205 = HEAP32[$10>>2]|0;
 $206 = ($205|0)==(0|0);
 if ($206) {
  label = 58;
 } else {
  __THREW__ = 0;
  invoke_viii(3777,($1|0),($10|0),($$0408$lcssa|0));
  $207 = __THREW__; __THREW__ = 0;
  $208 = $207&1;
  if ($208) {
   label = 57;
  } else {
   label = 58;
  }
 }
 L79: do {
  if ((label|0) == 58) {
   $211 = HEAP32[$22>>2]|0;
   $212 = ($211|0)==(0|0);
   L81: do {
    if (!($212)) {
     $213 = ((($211)) + 64|0);
     $214 = HEAP32[$213>>2]|0;
     switch ($214|0) {
     case 4:  {
      __THREW__ = 0;
      invoke_viii(3777,($1|0),($22|0),($$0408$lcssa|0));
      $215 = __THREW__; __THREW__ = 0;
      $216 = $215&1;
      if ($216) {
       label = 57;
       break L79;
      } else {
       break L81;
      }
      break;
     }
     case 3:  {
      __THREW__ = 0;
      invoke_viii(3777,($2|0),($22|0),($$0408$lcssa|0));
      $217 = __THREW__; __THREW__ = 0;
      $218 = $217&1;
      if ($218) {
       label = 57;
       break L79;
      } else {
       break L81;
      }
      break;
     }
     default: {
      break L81;
     }
     }
    }
   } while(0);
   $219 = HEAP32[$220>>2]|0;
   $221 = ($219|0)==(0|0);
   L87: do {
    if (!($221)) {
     $222 = ((($219)) + 64|0);
     $223 = HEAP32[$222>>2]|0;
     switch ($223|0) {
     case 4:  {
      __THREW__ = 0;
      invoke_viii(3777,($1|0),($224|0),($$0408$lcssa|0));
      $225 = __THREW__; __THREW__ = 0;
      $226 = $225&1;
      if ($226) {
       label = 57;
       break L79;
      } else {
       break L87;
      }
      break;
     }
     case 3:  {
      __THREW__ = 0;
      invoke_viii(3777,($2|0),($224|0),($$0408$lcssa|0));
      $227 = __THREW__; __THREW__ = 0;
      $228 = $227&1;
      if ($228) {
       label = 57;
       break L79;
      } else {
       break L87;
      }
      break;
     }
     default: {
      break L87;
     }
     }
    }
   } while(0);
   $229 = HEAP32[$230>>2]|0;
   $231 = ($229|0)==(0|0);
   L93: do {
    if (!($231)) {
     $232 = ((($229)) + 64|0);
     $233 = HEAP32[$232>>2]|0;
     switch ($233|0) {
     case 4:  {
      __THREW__ = 0;
      invoke_viii(3777,($1|0),($234|0),($$0408$lcssa|0));
      $235 = __THREW__; __THREW__ = 0;
      $236 = $235&1;
      if ($236) {
       label = 57;
       break L79;
      } else {
       break L93;
      }
      break;
     }
     case 3:  {
      __THREW__ = 0;
      invoke_viii(3777,($2|0),($234|0),($$0408$lcssa|0));
      $237 = __THREW__; __THREW__ = 0;
      $238 = $237&1;
      if ($238) {
       label = 57;
       break L79;
      } else {
       break L93;
      }
      break;
     }
     default: {
      break L93;
     }
     }
    }
   } while(0);
   $239 = HEAP32[$240>>2]|0;
   $241 = ($239|0)==(0|0);
   L99: do {
    if (!($241)) {
     $242 = ((($239)) + 64|0);
     $243 = HEAP32[$242>>2]|0;
     switch ($243|0) {
     case 4:  {
      __THREW__ = 0;
      invoke_viii(3777,($1|0),($244|0),($$0408$lcssa|0));
      $245 = __THREW__; __THREW__ = 0;
      $246 = $245&1;
      if ($246) {
       label = 57;
       break L79;
      } else {
       break L99;
      }
      break;
     }
     case 3:  {
      __THREW__ = 0;
      invoke_viii(3777,($2|0),($244|0),($$0408$lcssa|0));
      $247 = __THREW__; __THREW__ = 0;
      $248 = $247&1;
      if ($248) {
       label = 57;
       break L79;
      } else {
       break L99;
      }
      break;
     }
     default: {
      break L99;
     }
     }
    }
   } while(0);
   $249 = HEAP32[$89>>2]|0;
   $250 = HEAP32[$90>>2]|0;
   $251 = ($249|0)==($250|0);
   L105: do {
    if (!($251)) {
     $$sroa$0635$0839 = $249;
     L106: while(1) {
      $255 = HEAP32[$$sroa$0635$0839>>2]|0;
      $256 = ($255|0)==(0|0);
      L108: do {
       if (!($256)) {
        $257 = ((($255)) + 64|0);
        $258 = HEAP32[$257>>2]|0;
        switch ($258|0) {
        case 4:  {
         __THREW__ = 0;
         invoke_viii(3777,($1|0),($$sroa$0635$0839|0),($$0408$lcssa|0));
         $259 = __THREW__; __THREW__ = 0;
         $260 = $259&1;
         if ($260) {
          break L106;
         } else {
          break L108;
         }
         break;
        }
        case 3:  {
         __THREW__ = 0;
         invoke_viii(3777,($2|0),($$sroa$0635$0839|0),($$0408$lcssa|0));
         $263 = __THREW__; __THREW__ = 0;
         $264 = $263&1;
         if ($264) {
          break L106;
         } else {
          break L108;
         }
         break;
        }
        default: {
         break L108;
        }
        }
       }
      } while(0);
      $265 = ((($$sroa$0635$0839)) + 4|0);
      $266 = HEAP32[$90>>2]|0;
      $267 = ($265|0)==($266|0);
      if ($267) {
       break L105;
      } else {
       $$sroa$0635$0839 = $265;
      }
     }
     $261 = ___cxa_find_matching_catch_2()|0;
     $262 = tempRet0;
     $$4415 = $261;$$4422 = $262;
     label = 240;
     break L79;
    }
   } while(0);
   $252 = HEAP32[$94>>2]|0;
   $253 = HEAP32[$95>>2]|0;
   $254 = ($252|0)==($253|0);
   L116: do {
    if (!($254)) {
     $$sroa$0625$0835 = $252;
     L117: while(1) {
      $268 = HEAP32[$$sroa$0625$0835>>2]|0;
      $269 = ($268|0)==(0|0);
      L119: do {
       if (!($269)) {
        $270 = ((($268)) + 64|0);
        $271 = HEAP32[$270>>2]|0;
        switch ($271|0) {
        case 4:  {
         __THREW__ = 0;
         invoke_viii(3777,($1|0),($$sroa$0625$0835|0),($$0408$lcssa|0));
         $272 = __THREW__; __THREW__ = 0;
         $273 = $272&1;
         if ($273) {
          break L117;
         } else {
          break L119;
         }
         break;
        }
        case 3:  {
         __THREW__ = 0;
         invoke_viii(3777,($2|0),($$sroa$0625$0835|0),($$0408$lcssa|0));
         $276 = __THREW__; __THREW__ = 0;
         $277 = $276&1;
         if ($277) {
          break L117;
         } else {
          break L119;
         }
         break;
        }
        default: {
         break L119;
        }
        }
       }
      } while(0);
      $278 = ((($$sroa$0625$0835)) + 4|0);
      $279 = HEAP32[$95>>2]|0;
      $280 = ($278|0)==($279|0);
      if ($280) {
       break L116;
      } else {
       $$sroa$0625$0835 = $278;
      }
     }
     $274 = ___cxa_find_matching_catch_2()|0;
     $275 = tempRet0;
     $$4415 = $274;$$4422 = $275;
     label = 240;
     break L79;
    }
   } while(0);
   HEAP32[$3>>2] = 0;
   $281 = ((($3)) + 4|0);
   HEAP32[$281>>2] = 0;
   $282 = ((($3)) + 8|0);
   HEAP32[$282>>2] = 0;
   HEAP32[$4>>2] = 0;
   $283 = ((($4)) + 4|0);
   HEAP32[$283>>2] = 0;
   $284 = ((($4)) + 8|0);
   HEAP32[$284>>2] = 0;
   $285 = HEAP32[$1>>2]|0;
   $286 = HEAP32[$201>>2]|0;
   $287 = ($285|0)==($286|0);
   L127: do {
    if ($287) {
     label = 90;
    } else {
     $288 = ((($5)) + 4|0);
     $289 = ((($5)) + 8|0);
     $290 = ((($3)) + 8|0);
     $$sroa$0617$0831 = $285;
     while(1) {
      $297 = HEAP32[$$sroa$0617$0831>>2]|0;
      $298 = ((($$sroa$0617$0831)) + 4|0);
      $299 = HEAP32[$298>>2]|0;
      $300 = HEAP32[$297>>2]|0;
      $301 = ((($300)) + 140|0);
      $302 = HEAP32[$301>>2]|0;
      __THREW__ = 0;
      $303 = (invoke_ii($302|0,($297|0))|0);
      $304 = __THREW__; __THREW__ = 0;
      $305 = $304&1;
      if ($305) {
       break;
      }
      HEAP32[$5>>2] = $303;
      $306 = HEAP32[$299>>2]|0;
      $307 = ((($306)) + 140|0);
      $308 = HEAP32[$307>>2]|0;
      __THREW__ = 0;
      $309 = (invoke_ii($308|0,($299|0))|0);
      $310 = __THREW__; __THREW__ = 0;
      $311 = $310&1;
      if ($311) {
       break;
      }
      HEAP32[$288>>2] = $309;
      $312 = HEAP32[$297>>2]|0;
      $313 = ((($312)) + 192|0);
      $314 = HEAP32[$313>>2]|0;
      __THREW__ = 0;
      $315 = (invoke_ii($314|0,($297|0))|0);
      $316 = __THREW__; __THREW__ = 0;
      $317 = $316&1;
      if ($317) {
       break;
      }
      HEAP32[$289>>2] = $315;
      $318 = HEAP32[$281>>2]|0;
      $319 = HEAP32[$290>>2]|0;
      $320 = ($318|0)==($319|0);
      if ($320) {
       __THREW__ = 0;
       invoke_vii(3778,($3|0),($5|0));
       $326 = __THREW__; __THREW__ = 0;
       $327 = $326&1;
       if ($327) {
        break;
       }
      } else {
       $321 = HEAP32[$5>>2]|0;
       HEAP32[$318>>2] = $321;
       $322 = ((($318)) + 4|0);
       $323 = HEAP32[$288>>2]|0;
       HEAP32[$322>>2] = $323;
       $324 = ((($318)) + 8|0);
       HEAP32[$324>>2] = $315;
       $325 = ((($318)) + 12|0);
       HEAP32[$281>>2] = $325;
      }
      $328 = ((($$sroa$0617$0831)) + 8|0);
      $329 = HEAP32[$201>>2]|0;
      $330 = ($328|0)==($329|0);
      if ($330) {
       label = 90;
       break L127;
      } else {
       $$sroa$0617$0831 = $328;
      }
     }
     $331 = ___cxa_find_matching_catch_2()|0;
     $332 = tempRet0;
     $$0411 = $331;$$0418 = $332;
    }
   } while(0);
   L139: do {
    if ((label|0) == 90) {
     $291 = HEAP32[$2>>2]|0;
     $292 = HEAP32[$203>>2]|0;
     $293 = ($291|0)==($292|0);
     L141: do {
      if (!($293)) {
       $294 = ((($6)) + 4|0);
       $295 = ((($6)) + 8|0);
       $296 = ((($4)) + 8|0);
       $$sroa$0609$0827 = $291;
       while(1) {
        $336 = HEAP32[$$sroa$0609$0827>>2]|0;
        $337 = ((($$sroa$0609$0827)) + 4|0);
        $338 = HEAP32[$337>>2]|0;
        $339 = HEAP32[$336>>2]|0;
        $340 = ((($339)) + 140|0);
        $341 = HEAP32[$340>>2]|0;
        __THREW__ = 0;
        $342 = (invoke_ii($341|0,($336|0))|0);
        $343 = __THREW__; __THREW__ = 0;
        $344 = $343&1;
        if ($344) {
         break;
        }
        HEAP32[$6>>2] = $342;
        $345 = HEAP32[$338>>2]|0;
        $346 = ((($345)) + 140|0);
        $347 = HEAP32[$346>>2]|0;
        __THREW__ = 0;
        $348 = (invoke_ii($347|0,($338|0))|0);
        $349 = __THREW__; __THREW__ = 0;
        $350 = $349&1;
        if ($350) {
         break;
        }
        HEAP32[$294>>2] = $348;
        $351 = HEAP32[$336>>2]|0;
        $352 = ((($351)) + 192|0);
        $353 = HEAP32[$352>>2]|0;
        __THREW__ = 0;
        $354 = (invoke_ii($353|0,($336|0))|0);
        $355 = __THREW__; __THREW__ = 0;
        $356 = $355&1;
        if ($356) {
         break;
        }
        HEAP32[$295>>2] = $354;
        $357 = HEAP32[$283>>2]|0;
        $358 = HEAP32[$296>>2]|0;
        $359 = ($357|0)==($358|0);
        if ($359) {
         __THREW__ = 0;
         invoke_vii(3778,($4|0),($6|0));
         $365 = __THREW__; __THREW__ = 0;
         $366 = $365&1;
         if ($366) {
          break;
         }
        } else {
         $360 = HEAP32[$6>>2]|0;
         HEAP32[$357>>2] = $360;
         $361 = ((($357)) + 4|0);
         $362 = HEAP32[$294>>2]|0;
         HEAP32[$361>>2] = $362;
         $363 = ((($357)) + 8|0);
         HEAP32[$363>>2] = $354;
         $364 = ((($357)) + 12|0);
         HEAP32[$283>>2] = $364;
        }
        $367 = ((($$sroa$0609$0827)) + 8|0);
        $368 = HEAP32[$203>>2]|0;
        $369 = ($367|0)==($368|0);
        if ($369) {
         break L141;
        } else {
         $$sroa$0609$0827 = $367;
        }
       }
       $370 = ___cxa_find_matching_catch_2()|0;
       $371 = tempRet0;
       $$0411 = $370;$$0418 = $371;
       break L139;
      }
     } while(0);
     $333 = HEAP32[$163>>2]|0;
     $334 = HEAP32[$165>>2]|0;
     $335 = ($333|0)==($334|0);
     L154: do {
      if (!($335)) {
       $$0428823 = 0;$$0438822 = -1;$$sroa$0602$0821 = $333;
       L155: while(1) {
        $381 = HEAP32[$$sroa$0602$0821>>2]|0;
        $382 = ((($381)) + 60|0);
        $383 = HEAP32[$382>>2]|0;
        switch ($383|0) {
        case 0:  {
         $$0446 = 1;
         break;
        }
        case 1:  {
         $$0446 = 2;
         break;
        }
        case 4:  {
         $$0446 = 3;
         break;
        }
        case 7:  {
         $$0446 = 4;
         break;
        }
        default: {
         $$0446 = 0;
        }
        }
        $384 = ((($381)) + 52|0);
        $385 = HEAP32[$384>>2]|0;
        L163: do {
         switch ($385|0) {
         case 1:  {
          $388 = ($$0446|0)==(0);
          do {
           if ($388) {
            $389 = HEAP32[$381>>2]|0;
            $390 = ((($389)) + 200|0);
            $391 = HEAP32[$390>>2]|0;
            __THREW__ = 0;
            $392 = (invoke_ii($391|0,($381|0))|0);
            $393 = __THREW__; __THREW__ = 0;
            $394 = $393&1;
            if ($394) {
             break L155;
            }
            $395 = ($392|0)==(0);
            if (!($395)) {
             $$2448 = $392;$399 = $381;
             break;
            }
            $396 = ((($381)) + 68|0);
            $397 = HEAP32[$396>>2]|0;
            $$2448 = $397;$399 = $381;
           } else {
            $$2448 = $$0446;$399 = $381;
           }
          } while(0);
          $398 = ((($399)) + 64|0);
          $400 = HEAP32[$398>>2]|0;
          HEAP32[$398>>2] = $$0428823;
          $401 = ((($399)) + 68|0);
          $402 = HEAP32[$401>>2]|0;
          $403 = (($402) + ($400))|0;
          $404 = ($400>>>0)<($403>>>0);
          if ($404) {
           $$0453813 = 0;$$0457811 = $400;$$1429815 = $$0428823;$$1439814 = $$0438822;
          } else {
           $$12 = $$0438822;$$7 = $$0428823;
           break L163;
          }
          while(1) {
           $405 = (($$0453813>>>0) % ($$2448>>>0))&-1;
           $406 = ($405|0)==(0);
           $407 = $406&1;
           $$$1439 = (($407) + ($$1439814))|0;
           $408 = HEAP32[$3>>2]|0;
           $409 = HEAP32[$281>>2]|0;
           $410 = ($408|0)==($409|0);
           if (!($410)) {
            $$sroa$0596$0797 = $408;$818 = $409;
            while(1) {
             $414 = ((($$sroa$0596$0797)) + 8|0);
             $415 = HEAP32[$414>>2]|0;
             $416 = ($415|0)==(0);
             if ($416) {
              $426 = $818;
             } else {
              $417 = ((($$sroa$0596$0797)) + 4|0);
              $418 = HEAP32[$417>>2]|0;
              $419 = Math_imul($415, $$1429815)|0;
              $420 = (($418) + ($419)|0);
              $421 = HEAP32[$$sroa$0596$0797>>2]|0;
              $422 = Math_imul($415, $$0457811)|0;
              $423 = (($421) + ($422)|0);
              $$0461793 = $423;$$0466792 = $420;$$0470791 = 0;
              while(1) {
               $427 = ((($$0461793)) + 1|0);
               $428 = HEAP8[$$0461793>>0]|0;
               $429 = ((($$0466792)) + 1|0);
               HEAP8[$$0466792>>0] = $428;
               $430 = (($$0470791) + 1)|0;
               $431 = HEAP32[$414>>2]|0;
               $432 = ($430>>>0)<($431>>>0);
               if ($432) {
                $$0461793 = $427;$$0466792 = $429;$$0470791 = $430;
               } else {
                break;
               }
              }
              $$pre891 = HEAP32[$281>>2]|0;
              $426 = $$pre891;
             }
             $424 = ((($$sroa$0596$0797)) + 12|0);
             $425 = ($424|0)==($426|0);
             if ($425) {
              break;
             } else {
              $$sroa$0596$0797 = $424;$818 = $426;
             }
            }
           }
           $411 = HEAP32[$4>>2]|0;
           $412 = HEAP32[$283>>2]|0;
           $413 = ($411|0)==($412|0);
           if (!($413)) {
            $$sroa$0590$0807 = $411;$819 = $412;
            while(1) {
             $436 = ((($$sroa$0590$0807)) + 8|0);
             $437 = HEAP32[$436>>2]|0;
             $438 = ($437|0)==(0);
             if ($438) {
              $448 = $819;
             } else {
              $439 = ((($$sroa$0590$0807)) + 4|0);
              $440 = HEAP32[$439>>2]|0;
              $441 = Math_imul($437, $$1429815)|0;
              $442 = (($440) + ($441)|0);
              $443 = HEAP32[$$sroa$0590$0807>>2]|0;
              $444 = Math_imul($437, $$$1439)|0;
              $445 = (($443) + ($444)|0);
              $$0467803 = 0;$$0468802 = $442;$$0469801 = $445;
              while(1) {
               $449 = ((($$0469801)) + 1|0);
               $450 = HEAP8[$$0469801>>0]|0;
               $451 = ((($$0468802)) + 1|0);
               HEAP8[$$0468802>>0] = $450;
               $452 = (($$0467803) + 1)|0;
               $453 = HEAP32[$436>>2]|0;
               $454 = ($452>>>0)<($453>>>0);
               if ($454) {
                $$0467803 = $452;$$0468802 = $451;$$0469801 = $449;
               } else {
                break;
               }
              }
              $$pre892 = HEAP32[$283>>2]|0;
              $448 = $$pre892;
             }
             $446 = ((($$sroa$0590$0807)) + 12|0);
             $447 = ($446|0)==($448|0);
             if ($447) {
              break;
             } else {
              $$sroa$0590$0807 = $446;$819 = $448;
             }
            }
           }
           $433 = (($$0457811) + 1)|0;
           $434 = (($$1429815) + 1)|0;
           $435 = (($$0453813) + 1)|0;
           $exitcond = ($435|0)==($402|0);
           if ($exitcond) {
            break;
           } else {
            $$0453813 = $435;$$0457811 = $433;$$1429815 = $434;$$1439814 = $$$1439;
           }
          }
          $777 = (($$0428823) + ($402))|0;
          $$12 = $$$1439;$$7 = $777;
          break;
         }
         case 2:  {
          $455 = ((($381)) + 80|0);
          $456 = HEAP32[$455>>2]|0;
          $457 = ((($381)) + 68|0);
          $458 = HEAP32[$457>>2]|0;
          $459 = ((($381)) + 72|0);
          $460 = HEAP32[$459>>2]|0;
          $461 = ($458|0)==($460|0);
          if ($461) {
           $$12 = $$0438822;$$7 = $$0428823;
           break L163;
          }
          $462 = ($$0446|0)==(0);
          if ($462) {
           $$0464784$us = $456;$$2430786$us = $$0428823;$$3441785$us = $$0438822;$$sroa$0583$0783$us = $458;$820 = $460;
           while(1) {
            $463 = HEAP32[$$sroa$0583$0783$us>>2]|0;
            HEAP32[$455>>2] = $$2430786$us;
            $464 = HEAP32[$$sroa$0583$0783$us>>2]|0;
            $465 = ($464|0)>(0);
            if ($465) {
             $$0462773$us = 0;$$1465771$us = $$0464784$us;$$3431775$us = $$2430786$us;$$4442774$us = $$3441785$us;
             while(1) {
              $469 = (($$0462773$us>>>0) % ($463>>>0))&-1;
              $470 = ($469|0)==(0);
              $471 = $470&1;
              $$$4442$us = (($471) + ($$4442774$us))|0;
              $472 = HEAP32[$3>>2]|0;
              $473 = HEAP32[$281>>2]|0;
              $474 = ($472|0)==($473|0);
              if (!($474)) {
               $$sroa$0577$0757$us = $472;$822 = $473;
               while(1) {
                $475 = ((($$sroa$0577$0757$us)) + 8|0);
                $476 = HEAP32[$475>>2]|0;
                $477 = ($476|0)==(0);
                if ($477) {
                 $487 = $822;
                } else {
                 $478 = ((($$sroa$0577$0757$us)) + 4|0);
                 $479 = HEAP32[$478>>2]|0;
                 $480 = Math_imul($476, $$3431775$us)|0;
                 $481 = (($479) + ($480)|0);
                 $482 = HEAP32[$$sroa$0577$0757$us>>2]|0;
                 $483 = Math_imul($476, $$1465771$us)|0;
                 $484 = (($482) + ($483)|0);
                 $$0458753$us = 0;$$0459752$us = $481;$$0460751$us = $484;
                 while(1) {
                  $488 = ((($$0460751$us)) + 1|0);
                  $489 = HEAP8[$$0460751$us>>0]|0;
                  $490 = ((($$0459752$us)) + 1|0);
                  HEAP8[$$0459752$us>>0] = $489;
                  $491 = (($$0458753$us) + 1)|0;
                  $492 = HEAP32[$475>>2]|0;
                  $493 = ($491>>>0)<($492>>>0);
                  if ($493) {
                   $$0458753$us = $491;$$0459752$us = $490;$$0460751$us = $488;
                  } else {
                   break;
                  }
                 }
                 $$pre888 = HEAP32[$281>>2]|0;
                 $487 = $$pre888;
                }
                $485 = ((($$sroa$0577$0757$us)) + 12|0);
                $486 = ($485|0)==($487|0);
                if ($486) {
                 break;
                } else {
                 $$sroa$0577$0757$us = $485;$822 = $487;
                }
               }
              }
              $494 = HEAP32[$4>>2]|0;
              $495 = HEAP32[$283>>2]|0;
              $496 = ($494|0)==($495|0);
              if (!($496)) {
               $$sroa$0571$0767$us = $494;$823 = $495;
               while(1) {
                $497 = ((($$sroa$0571$0767$us)) + 8|0);
                $498 = HEAP32[$497>>2]|0;
                $499 = ($498|0)==(0);
                if ($499) {
                 $509 = $823;
                } else {
                 $500 = ((($$sroa$0571$0767$us)) + 4|0);
                 $501 = HEAP32[$500>>2]|0;
                 $502 = Math_imul($498, $$3431775$us)|0;
                 $503 = (($501) + ($502)|0);
                 $504 = HEAP32[$$sroa$0571$0767$us>>2]|0;
                 $505 = Math_imul($498, $$$4442$us)|0;
                 $506 = (($504) + ($505)|0);
                 $$0454763$us = 0;$$0455762$us = $503;$$0456761$us = $506;
                 while(1) {
                  $510 = ((($$0456761$us)) + 1|0);
                  $511 = HEAP8[$$0456761$us>>0]|0;
                  $512 = ((($$0455762$us)) + 1|0);
                  HEAP8[$$0455762$us>>0] = $511;
                  $513 = (($$0454763$us) + 1)|0;
                  $514 = HEAP32[$497>>2]|0;
                  $515 = ($513>>>0)<($514>>>0);
                  if ($515) {
                   $$0454763$us = $513;$$0455762$us = $512;$$0456761$us = $510;
                  } else {
                   break;
                  }
                 }
                 $$pre889 = HEAP32[$283>>2]|0;
                 $509 = $$pre889;
                }
                $507 = ((($$sroa$0571$0767$us)) + 12|0);
                $508 = ($507|0)==($509|0);
                if ($508) {
                 break;
                } else {
                 $$sroa$0571$0767$us = $507;$823 = $509;
                }
               }
              }
              $516 = (($$1465771$us) + 1)|0;
              $517 = (($$3431775$us) + 1)|0;
              $518 = (($$0462773$us) + 1)|0;
              $519 = HEAP32[$$sroa$0583$0783$us>>2]|0;
              $520 = ($518|0)<($519|0);
              if ($520) {
               $$0462773$us = $518;$$1465771$us = $516;$$3431775$us = $517;$$4442774$us = $$$4442$us;
              } else {
               break;
              }
             }
             $$pre890 = HEAP32[$459>>2]|0;
             $$1465$lcssa$us = $516;$$3431$lcssa$us = $517;$$4442$lcssa$us = $$$4442$us;$468 = $$pre890;
            } else {
             $$1465$lcssa$us = $$0464784$us;$$3431$lcssa$us = $$2430786$us;$$4442$lcssa$us = $$3441785$us;$468 = $820;
            }
            $466 = ((($$sroa$0583$0783$us)) + 4|0);
            $467 = ($466|0)==($468|0);
            if ($467) {
             $$12 = $$4442$lcssa$us;$$7 = $$3431$lcssa$us;
             break;
            } else {
             $$0464784$us = $$1465$lcssa$us;$$2430786$us = $$3431$lcssa$us;$$3441785$us = $$4442$lcssa$us;$$sroa$0583$0783$us = $466;$820 = $468;
            }
           }
          } else {
           $$0464784 = $456;$$2430786 = $$0428823;$$3441785 = $$0438822;$$sroa$0583$0783 = $458;$821 = $460;
           while(1) {
            HEAP32[$455>>2] = $$2430786;
            $521 = HEAP32[$$sroa$0583$0783>>2]|0;
            $522 = ($521|0)>(0);
            if ($522) {
             $$0462773 = 0;$$1465771 = $$0464784;$$3431775 = $$2430786;$$4442774 = $$3441785;
             while(1) {
              $526 = (($$0462773>>>0) % ($$0446>>>0))&-1;
              $527 = ($526|0)==(0);
              $528 = $527&1;
              $$$4442 = (($528) + ($$4442774))|0;
              $529 = HEAP32[$3>>2]|0;
              $530 = HEAP32[$281>>2]|0;
              $531 = ($529|0)==($530|0);
              if (!($531)) {
               $$sroa$0577$0757 = $529;$824 = $530;
               while(1) {
                $535 = ((($$sroa$0577$0757)) + 8|0);
                $536 = HEAP32[$535>>2]|0;
                $537 = ($536|0)==(0);
                if ($537) {
                 $547 = $824;
                } else {
                 $538 = ((($$sroa$0577$0757)) + 4|0);
                 $539 = HEAP32[$538>>2]|0;
                 $540 = Math_imul($536, $$3431775)|0;
                 $541 = (($539) + ($540)|0);
                 $542 = HEAP32[$$sroa$0577$0757>>2]|0;
                 $543 = Math_imul($536, $$1465771)|0;
                 $544 = (($542) + ($543)|0);
                 $$0458753 = 0;$$0459752 = $541;$$0460751 = $544;
                 while(1) {
                  $548 = ((($$0460751)) + 1|0);
                  $549 = HEAP8[$$0460751>>0]|0;
                  $550 = ((($$0459752)) + 1|0);
                  HEAP8[$$0459752>>0] = $549;
                  $551 = (($$0458753) + 1)|0;
                  $552 = HEAP32[$535>>2]|0;
                  $553 = ($551>>>0)<($552>>>0);
                  if ($553) {
                   $$0458753 = $551;$$0459752 = $550;$$0460751 = $548;
                  } else {
                   break;
                  }
                 }
                 $$pre885 = HEAP32[$281>>2]|0;
                 $547 = $$pre885;
                }
                $545 = ((($$sroa$0577$0757)) + 12|0);
                $546 = ($545|0)==($547|0);
                if ($546) {
                 break;
                } else {
                 $$sroa$0577$0757 = $545;$824 = $547;
                }
               }
              }
              $532 = HEAP32[$4>>2]|0;
              $533 = HEAP32[$283>>2]|0;
              $534 = ($532|0)==($533|0);
              if (!($534)) {
               $$sroa$0571$0767 = $532;$825 = $533;
               while(1) {
                $559 = ((($$sroa$0571$0767)) + 8|0);
                $560 = HEAP32[$559>>2]|0;
                $561 = ($560|0)==(0);
                if ($561) {
                 $571 = $825;
                } else {
                 $562 = ((($$sroa$0571$0767)) + 4|0);
                 $563 = HEAP32[$562>>2]|0;
                 $564 = Math_imul($560, $$3431775)|0;
                 $565 = (($563) + ($564)|0);
                 $566 = HEAP32[$$sroa$0571$0767>>2]|0;
                 $567 = Math_imul($560, $$$4442)|0;
                 $568 = (($566) + ($567)|0);
                 $$0454763 = 0;$$0455762 = $565;$$0456761 = $568;
                 while(1) {
                  $572 = ((($$0456761)) + 1|0);
                  $573 = HEAP8[$$0456761>>0]|0;
                  $574 = ((($$0455762)) + 1|0);
                  HEAP8[$$0455762>>0] = $573;
                  $575 = (($$0454763) + 1)|0;
                  $576 = HEAP32[$559>>2]|0;
                  $577 = ($575>>>0)<($576>>>0);
                  if ($577) {
                   $$0454763 = $575;$$0455762 = $574;$$0456761 = $572;
                  } else {
                   break;
                  }
                 }
                 $$pre886 = HEAP32[$283>>2]|0;
                 $571 = $$pre886;
                }
                $569 = ((($$sroa$0571$0767)) + 12|0);
                $570 = ($569|0)==($571|0);
                if ($570) {
                 break;
                } else {
                 $$sroa$0571$0767 = $569;$825 = $571;
                }
               }
              }
              $554 = (($$1465771) + 1)|0;
              $555 = (($$3431775) + 1)|0;
              $556 = (($$0462773) + 1)|0;
              $557 = HEAP32[$$sroa$0583$0783>>2]|0;
              $558 = ($556|0)<($557|0);
              if ($558) {
               $$0462773 = $556;$$1465771 = $554;$$3431775 = $555;$$4442774 = $$$4442;
              } else {
               break;
              }
             }
             $$pre887 = HEAP32[$459>>2]|0;
             $$1465$lcssa = $554;$$3431$lcssa = $555;$$4442$lcssa = $$$4442;$525 = $$pre887;
            } else {
             $$1465$lcssa = $$0464784;$$3431$lcssa = $$2430786;$$4442$lcssa = $$3441785;$525 = $821;
            }
            $523 = ((($$sroa$0583$0783)) + 4|0);
            $524 = ($523|0)==($525|0);
            if ($524) {
             $$12 = $$4442$lcssa;$$7 = $$3431$lcssa;
             break;
            } else {
             $$0464784 = $$1465$lcssa;$$2430786 = $$3431$lcssa;$$3441785 = $$4442$lcssa;$$sroa$0583$0783 = $523;$821 = $525;
            }
           }
          }
          break;
         }
         case 3:  {
          $578 = ($$0446|0)==(0);
          if ($578) {
           $579 = HEAP32[$381>>2]|0;
           $580 = ((($579)) + 200|0);
           $581 = HEAP32[$580>>2]|0;
           __THREW__ = 0;
           $582 = (invoke_ii($581|0,($381|0))|0);
           $583 = __THREW__; __THREW__ = 0;
           $584 = $583&1;
           if ($584) {
            break L155;
           } else {
            $$3449 = $582;
           }
          } else {
           $$3449 = $$0446;
          }
          $585 = ((($381)) + 68|0);
          $586 = HEAP32[$585>>2]|0;
          $587 = ((($381)) + 72|0);
          $588 = HEAP32[$587>>2]|0;
          $589 = ($586|0)==($588|0);
          if ($589) {
           $$12 = $$0438822;$$7 = $$0428823;
           break L163;
          } else {
           $$0452743 = 0;$$4432745 = $$0428823;$$6444744 = $$0438822;$$sroa$0564$0742 = $586;
          }
          while(1) {
           $590 = (($$0452743>>>0) % ($$3449>>>0))&-1;
           $591 = ($590|0)==(0);
           $592 = $591&1;
           $$$6444 = (($592) + ($$6444744))|0;
           $593 = HEAP8[$$sroa$0564$0742>>0]|0;
           $594 = $593&255;
           $595 = $$4432745&255;
           HEAP8[$$sroa$0564$0742>>0] = $595;
           $596 = HEAP32[$3>>2]|0;
           $597 = HEAP32[$281>>2]|0;
           $598 = ($596|0)==($597|0);
           if (!($598)) {
            $$sroa$0558$0728 = $596;$826 = $597;
            while(1) {
             $602 = ((($$sroa$0558$0728)) + 8|0);
             $603 = HEAP32[$602>>2]|0;
             $604 = ($603|0)==(0);
             if ($604) {
              $614 = $826;
             } else {
              $605 = ((($$sroa$0558$0728)) + 4|0);
              $606 = HEAP32[$605>>2]|0;
              $607 = Math_imul($603, $$4432745)|0;
              $608 = (($606) + ($607)|0);
              $609 = HEAP32[$$sroa$0558$0728>>2]|0;
              $610 = Math_imul($603, $594)|0;
              $611 = (($609) + ($610)|0);
              $$0435724 = 0;$$0436723 = $608;$$0437722 = $611;
              while(1) {
               $615 = ((($$0437722)) + 1|0);
               $616 = HEAP8[$$0437722>>0]|0;
               $617 = ((($$0436723)) + 1|0);
               HEAP8[$$0436723>>0] = $616;
               $618 = (($$0435724) + 1)|0;
               $619 = HEAP32[$602>>2]|0;
               $620 = ($618>>>0)<($619>>>0);
               if ($620) {
                $$0435724 = $618;$$0436723 = $617;$$0437722 = $615;
               } else {
                break;
               }
              }
              $$pre883 = HEAP32[$281>>2]|0;
              $614 = $$pre883;
             }
             $612 = ((($$sroa$0558$0728)) + 12|0);
             $613 = ($612|0)==($614|0);
             if ($613) {
              break;
             } else {
              $$sroa$0558$0728 = $612;$826 = $614;
             }
            }
           }
           $599 = HEAP32[$4>>2]|0;
           $600 = HEAP32[$283>>2]|0;
           $601 = ($599|0)==($600|0);
           if (!($601)) {
            $$sroa$0552$0738 = $599;$827 = $600;
            while(1) {
             $626 = ((($$sroa$0552$0738)) + 8|0);
             $627 = HEAP32[$626>>2]|0;
             $628 = ($627|0)==(0);
             if ($628) {
              $638 = $827;
             } else {
              $629 = ((($$sroa$0552$0738)) + 4|0);
              $630 = HEAP32[$629>>2]|0;
              $631 = Math_imul($627, $$4432745)|0;
              $632 = (($630) + ($631)|0);
              $633 = HEAP32[$$sroa$0552$0738>>2]|0;
              $634 = Math_imul($627, $$$6444)|0;
              $635 = (($633) + ($634)|0);
              $$0425734 = 0;$$0426733 = $632;$$0427732 = $635;
              while(1) {
               $639 = ((($$0427732)) + 1|0);
               $640 = HEAP8[$$0427732>>0]|0;
               $641 = ((($$0426733)) + 1|0);
               HEAP8[$$0426733>>0] = $640;
               $642 = (($$0425734) + 1)|0;
               $643 = HEAP32[$626>>2]|0;
               $644 = ($642>>>0)<($643>>>0);
               if ($644) {
                $$0425734 = $642;$$0426733 = $641;$$0427732 = $639;
               } else {
                break;
               }
              }
              $$pre884 = HEAP32[$283>>2]|0;
              $638 = $$pre884;
             }
             $636 = ((($$sroa$0552$0738)) + 12|0);
             $637 = ($636|0)==($638|0);
             if ($637) {
              break;
             } else {
              $$sroa$0552$0738 = $636;$827 = $638;
             }
            }
           }
           $621 = (($$0452743) + 1)|0;
           $622 = (($$4432745) + 1)|0;
           $623 = ((($$sroa$0564$0742)) + 1|0);
           $624 = HEAP32[$587>>2]|0;
           $625 = ($623|0)==($624|0);
           if ($625) {
            $$12 = $$$6444;$$7 = $622;
            break;
           } else {
            $$0452743 = $621;$$4432745 = $622;$$6444744 = $$$6444;$$sroa$0564$0742 = $623;
           }
          }
          break;
         }
         case 4:  {
          $645 = ($$0446|0)==(0);
          if ($645) {
           $646 = HEAP32[$381>>2]|0;
           $647 = ((($646)) + 200|0);
           $648 = HEAP32[$647>>2]|0;
           __THREW__ = 0;
           $649 = (invoke_ii($648|0,($381|0))|0);
           $650 = __THREW__; __THREW__ = 0;
           $651 = $650&1;
           if ($651) {
            break L155;
           } else {
            $$4450 = $649;
           }
          } else {
           $$4450 = $$0446;
          }
          $652 = ((($381)) + 68|0);
          $653 = HEAP32[$652>>2]|0;
          $654 = ((($381)) + 72|0);
          $655 = HEAP32[$654>>2]|0;
          $656 = ($653|0)==($655|0);
          if ($656) {
           $$12 = $$0438822;$$7 = $$0428823;
           break L163;
          } else {
           $$0417717 = 0;$$5433715 = $$0428823;$$8714 = $$0438822;$$sroa$0545$0713 = $653;
          }
          while(1) {
           $657 = (($$0417717>>>0) % ($$4450>>>0))&-1;
           $658 = ($657|0)==(0);
           $659 = $658&1;
           $$$8 = (($659) + ($$8714))|0;
           $660 = HEAP16[$$sroa$0545$0713>>1]|0;
           $661 = $660&65535;
           $662 = $$5433715&65535;
           HEAP16[$$sroa$0545$0713>>1] = $662;
           $663 = HEAP32[$3>>2]|0;
           $664 = HEAP32[$281>>2]|0;
           $665 = ($663|0)==($664|0);
           if (!($665)) {
            $$sroa$0539$0699 = $663;$828 = $664;
            while(1) {
             $669 = ((($$sroa$0539$0699)) + 8|0);
             $670 = HEAP32[$669>>2]|0;
             $671 = ($670|0)==(0);
             if ($671) {
              $681 = $828;
             } else {
              $672 = ((($$sroa$0539$0699)) + 4|0);
              $673 = HEAP32[$672>>2]|0;
              $674 = Math_imul($670, $$5433715)|0;
              $675 = (($673) + ($674)|0);
              $676 = HEAP32[$$sroa$0539$0699>>2]|0;
              $677 = Math_imul($670, $661)|0;
              $678 = (($676) + ($677)|0);
              $$0405695 = 0;$$0406694 = $675;$$0407693 = $678;
              while(1) {
               $682 = ((($$0407693)) + 1|0);
               $683 = HEAP8[$$0407693>>0]|0;
               $684 = ((($$0406694)) + 1|0);
               HEAP8[$$0406694>>0] = $683;
               $685 = (($$0405695) + 1)|0;
               $686 = HEAP32[$669>>2]|0;
               $687 = ($685>>>0)<($686>>>0);
               if ($687) {
                $$0405695 = $685;$$0406694 = $684;$$0407693 = $682;
               } else {
                break;
               }
              }
              $$pre881 = HEAP32[$281>>2]|0;
              $681 = $$pre881;
             }
             $679 = ((($$sroa$0539$0699)) + 12|0);
             $680 = ($679|0)==($681|0);
             if ($680) {
              break;
             } else {
              $$sroa$0539$0699 = $679;$828 = $681;
             }
            }
           }
           $666 = HEAP32[$4>>2]|0;
           $667 = HEAP32[$283>>2]|0;
           $668 = ($666|0)==($667|0);
           if (!($668)) {
            $$sroa$0533$0709 = $666;$829 = $667;
            while(1) {
             $693 = ((($$sroa$0533$0709)) + 8|0);
             $694 = HEAP32[$693>>2]|0;
             $695 = ($694|0)==(0);
             if ($695) {
              $705 = $829;
             } else {
              $696 = ((($$sroa$0533$0709)) + 4|0);
              $697 = HEAP32[$696>>2]|0;
              $698 = Math_imul($694, $$5433715)|0;
              $699 = (($697) + ($698)|0);
              $700 = HEAP32[$$sroa$0533$0709>>2]|0;
              $701 = Math_imul($694, $$$8)|0;
              $702 = (($700) + ($701)|0);
              $$0402705 = 0;$$0403704 = $699;$$0404703 = $702;
              while(1) {
               $706 = ((($$0404703)) + 1|0);
               $707 = HEAP8[$$0404703>>0]|0;
               $708 = ((($$0403704)) + 1|0);
               HEAP8[$$0403704>>0] = $707;
               $709 = (($$0402705) + 1)|0;
               $710 = HEAP32[$693>>2]|0;
               $711 = ($709>>>0)<($710>>>0);
               if ($711) {
                $$0402705 = $709;$$0403704 = $708;$$0404703 = $706;
               } else {
                break;
               }
              }
              $$pre882 = HEAP32[$283>>2]|0;
              $705 = $$pre882;
             }
             $703 = ((($$sroa$0533$0709)) + 12|0);
             $704 = ($703|0)==($705|0);
             if ($704) {
              break;
             } else {
              $$sroa$0533$0709 = $703;$829 = $705;
             }
            }
           }
           $688 = (($$0417717) + 1)|0;
           $689 = (($$5433715) + 1)|0;
           $690 = ((($$sroa$0545$0713)) + 2|0);
           $691 = HEAP32[$654>>2]|0;
           $692 = ($690|0)==($691|0);
           if ($692) {
            $$12 = $$$8;$$7 = $689;
            break;
           } else {
            $$0417717 = $688;$$5433715 = $689;$$8714 = $$$8;$$sroa$0545$0713 = $690;
           }
          }
          break;
         }
         case 5:  {
          $712 = ($$0446|0)==(0);
          if ($712) {
           $713 = HEAP32[$381>>2]|0;
           $714 = ((($713)) + 200|0);
           $715 = HEAP32[$714>>2]|0;
           __THREW__ = 0;
           $716 = (invoke_ii($715|0,($381|0))|0);
           $717 = __THREW__; __THREW__ = 0;
           $718 = $717&1;
           if ($718) {
            break L155;
           } else {
            $$5451 = $716;
           }
          } else {
           $$5451 = $$0446;
          }
          $719 = ((($381)) + 68|0);
          $720 = HEAP32[$719>>2]|0;
          $721 = ((($381)) + 72|0);
          $722 = HEAP32[$721>>2]|0;
          $723 = ($720|0)==($722|0);
          if ($723) {
           $$12 = $$0438822;$$7 = $$0428823;
           break L163;
          } else {
           $$0400689 = 0;$$10686 = $$0438822;$$6434687 = $$0428823;$$sroa$0526$0685 = $720;
          }
          while(1) {
           $724 = (($$0400689>>>0) % ($$5451>>>0))&-1;
           $725 = ($724|0)==(0);
           $726 = $725&1;
           $$$10 = (($726) + ($$10686))|0;
           $727 = HEAP32[$$sroa$0526$0685>>2]|0;
           HEAP32[$$sroa$0526$0685>>2] = $$6434687;
           $728 = HEAP32[$3>>2]|0;
           $729 = HEAP32[$281>>2]|0;
           $730 = ($728|0)==($729|0);
           if (!($730)) {
            $$sroa$0520$0671 = $728;$830 = $729;
            while(1) {
             $734 = ((($$sroa$0520$0671)) + 8|0);
             $735 = HEAP32[$734>>2]|0;
             $736 = ($735|0)==(0);
             if ($736) {
              $746 = $830;
             } else {
              $737 = ((($$sroa$0520$0671)) + 4|0);
              $738 = HEAP32[$737>>2]|0;
              $739 = Math_imul($735, $$6434687)|0;
              $740 = (($738) + ($739)|0);
              $741 = HEAP32[$$sroa$0520$0671>>2]|0;
              $742 = Math_imul($735, $727)|0;
              $743 = (($741) + ($742)|0);
              $$0396670 = 0;$$0397669 = $740;$$0398668 = $743;
              while(1) {
               $747 = ((($$0398668)) + 1|0);
               $748 = HEAP8[$$0398668>>0]|0;
               $749 = ((($$0397669)) + 1|0);
               HEAP8[$$0397669>>0] = $748;
               $750 = (($$0396670) + 1)|0;
               $751 = HEAP32[$734>>2]|0;
               $752 = ($750>>>0)<($751>>>0);
               if ($752) {
                $$0396670 = $750;$$0397669 = $749;$$0398668 = $747;
               } else {
                break;
               }
              }
              $$pre = HEAP32[$281>>2]|0;
              $746 = $$pre;
             }
             $744 = ((($$sroa$0520$0671)) + 12|0);
             $745 = ($744|0)==($746|0);
             if ($745) {
              break;
             } else {
              $$sroa$0520$0671 = $744;$830 = $746;
             }
            }
           }
           $731 = HEAP32[$4>>2]|0;
           $732 = HEAP32[$283>>2]|0;
           $733 = ($731|0)==($732|0);
           if (!($733)) {
            $$sroa$0514$0681 = $731;$831 = $732;
            while(1) {
             $758 = ((($$sroa$0514$0681)) + 8|0);
             $759 = HEAP32[$758>>2]|0;
             $760 = ($759|0)==(0);
             if ($760) {
              $770 = $831;
             } else {
              $761 = ((($$sroa$0514$0681)) + 4|0);
              $762 = HEAP32[$761>>2]|0;
              $763 = Math_imul($759, $$6434687)|0;
              $764 = (($762) + ($763)|0);
              $765 = HEAP32[$$sroa$0514$0681>>2]|0;
              $766 = Math_imul($759, $$$10)|0;
              $767 = (($765) + ($766)|0);
              $$0393676 = $764;$$0394675 = $767;$$0677 = 0;
              while(1) {
               $771 = ((($$0394675)) + 1|0);
               $772 = HEAP8[$$0394675>>0]|0;
               $773 = ((($$0393676)) + 1|0);
               HEAP8[$$0393676>>0] = $772;
               $774 = (($$0677) + 1)|0;
               $775 = HEAP32[$758>>2]|0;
               $776 = ($774>>>0)<($775>>>0);
               if ($776) {
                $$0393676 = $773;$$0394675 = $771;$$0677 = $774;
               } else {
                break;
               }
              }
              $$pre880 = HEAP32[$283>>2]|0;
              $770 = $$pre880;
             }
             $768 = ((($$sroa$0514$0681)) + 12|0);
             $769 = ($768|0)==($770|0);
             if ($769) {
              break;
             } else {
              $$sroa$0514$0681 = $768;$831 = $770;
             }
            }
           }
           $753 = (($$0400689) + 1)|0;
           $754 = (($$6434687) + 1)|0;
           $755 = ((($$sroa$0526$0685)) + 4|0);
           $756 = HEAP32[$721>>2]|0;
           $757 = ($755|0)==($756|0);
           if ($757) {
            $$12 = $$$10;$$7 = $754;
            break;
           } else {
            $$0400689 = $753;$$10686 = $$$10;$$6434687 = $754;$$sroa$0526$0685 = $755;
           }
          }
          break;
         }
         default: {
          $$12 = $$0438822;$$7 = $$0428823;
         }
         }
        } while(0);
        $778 = ((($$sroa$0602$0821)) + 4|0);
        $779 = HEAP32[$165>>2]|0;
        $780 = ($778|0)==($779|0);
        if ($780) {
         break L154;
        } else {
         $$0428823 = $$7;$$0438822 = $$12;$$sroa$0602$0821 = $778;
        }
       }
       $386 = ___cxa_find_matching_catch_2()|0;
       $387 = tempRet0;
       $$0411 = $386;$$0418 = $387;
       break L139;
      }
     } while(0);
     HEAP8[$7>>0] = 0;
     $372 = HEAP32[$4>>2]|0;
     $373 = ($372|0)==(0|0);
     if (!($373)) {
      $374 = HEAP32[$283>>2]|0;
      $375 = ($374|0)==($372|0);
      if (!($375)) {
       $scevgep$i$i$i492 = ((($374)) + -12|0);
       $376 = $scevgep$i$i$i492;
       $377 = $372;
       $378 = (($376) - ($377))|0;
       $379 = (($378>>>0) / 12)&-1;
       $380 = $379 ^ -1;
       $scevgep5$i$i$i493 = (($374) + (($380*12)|0)|0);
       HEAP32[$283>>2] = $scevgep5$i$i$i493;
      }
      __ZdlPv($372);
     }
     $781 = HEAP32[$3>>2]|0;
     $782 = ($781|0)==(0|0);
     if (!($782)) {
      $783 = HEAP32[$281>>2]|0;
      $784 = ($783|0)==($781|0);
      if (!($784)) {
       $scevgep$i$i$i484 = ((($783)) + -12|0);
       $785 = $scevgep$i$i$i484;
       $786 = $781;
       $787 = (($785) - ($786))|0;
       $788 = (($787>>>0) / 12)&-1;
       $789 = $788 ^ -1;
       $scevgep5$i$i$i485 = (($783) + (($789*12)|0)|0);
       HEAP32[$281>>2] = $scevgep5$i$i$i485;
      }
      __ZdlPv($781);
     }
     __THREW__ = 0;
     invoke_vi(3779,($2|0));
     $790 = __THREW__; __THREW__ = 0;
     $791 = $790&1;
     if ($791) {
      $810 = ___cxa_find_matching_catch_2()|0;
      $811 = tempRet0;
      $$5416 = $810;$$5423 = $811;
      break L79;
     }
     __ZNSt3__213__vector_baseINS_4pairIN3osg7ref_ptrINS2_5ArrayEEES5_EENS_9allocatorIS6_EEED2Ev($1);
     STACKTOP = sp;return;
    }
   } while(0);
   $792 = HEAP32[$4>>2]|0;
   $793 = ($792|0)==(0|0);
   if (!($793)) {
    $794 = HEAP32[$283>>2]|0;
    $795 = ($794|0)==($792|0);
    if (!($795)) {
     $scevgep$i$i$i477 = ((($794)) + -12|0);
     $796 = $scevgep$i$i$i477;
     $797 = $792;
     $798 = (($796) - ($797))|0;
     $799 = (($798>>>0) / 12)&-1;
     $800 = $799 ^ -1;
     $scevgep5$i$i$i478 = (($794) + (($800*12)|0)|0);
     HEAP32[$283>>2] = $scevgep5$i$i$i478;
    }
    __ZdlPv($792);
   }
   $801 = HEAP32[$3>>2]|0;
   $802 = ($801|0)==(0|0);
   if (!($802)) {
    $803 = HEAP32[$281>>2]|0;
    $804 = ($803|0)==($801|0);
    if (!($804)) {
     $scevgep$i$i$i = ((($803)) + -12|0);
     $805 = $scevgep$i$i$i;
     $806 = $801;
     $807 = (($805) - ($806))|0;
     $808 = (($807>>>0) / 12)&-1;
     $809 = $808 ^ -1;
     $scevgep5$i$i$i = (($803) + (($809*12)|0)|0);
     HEAP32[$281>>2] = $scevgep5$i$i$i;
    }
    __ZdlPv($801);
   }
   $$4415 = $$0411;$$4422 = $$0418;
   label = 240;
  }
 } while(0);
 if ((label|0) == 57) {
  $209 = ___cxa_find_matching_catch_2()|0;
  $210 = tempRet0;
  $$4415 = $209;$$4422 = $210;
  label = 240;
 }
 if ((label|0) == 240) {
  __THREW__ = 0;
  invoke_vi(3779,($2|0));
  $812 = __THREW__; __THREW__ = 0;
  $813 = $812&1;
  if ($813) {
   $816 = ___cxa_find_matching_catch_3(0|0)|0;
   $817 = tempRet0;
   ___clang_call_terminate($816);
   // unreachable;
  } else {
   $$5416 = $$4415;$$5423 = $$4422;
  }
 }
 __THREW__ = 0;
 invoke_vi(3779,($1|0));
 $814 = __THREW__; __THREW__ = 0;
 $815 = $814&1;
 if ($815) {
  $816 = ___cxa_find_matching_catch_3(0|0)|0;
  $817 = tempRet0;
  ___clang_call_terminate($816);
  // unreachable;
 } else {
  ___resumeException($$5416|0);
  // unreachable;
 }
}
function __ZN21GeometryUtilFunctionsL16expandIndexArrayEPKN3osg5ArrayEPKNS0_10IndexArrayE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$04369$us = 0, $$04468$us = 0, $$046 = 0, $$046$us = 0, $$070$us = 0, $$sink51$sink52$sink53$sink5466$index = 0, $$sink51$sink52$sink53$sink5466$index4 = 0, $$sink51$sink52$sink53$sink5467$index = 0, $$sink51$sink52$sink53$sink5467$index10 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $exitcond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__ZN3osg9cloneTypeINS_5ArrayEEEPT_PKS2_($0)|0);
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = ((($2)) + 8|0);
  $5 = HEAP32[$4>>2]|0;HEAP32[$4>>2] = (($5+1)|0);
 }
 $6 = ((($0)) + 64|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($2)) + 64|0);
 HEAP32[$8>>2] = $7;
 $9 = ((($0)) + 68|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = ((($2)) + 68|0);
 HEAP8[$11>>0] = $10;
 $12 = ((($0)) + 69|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = ((($2)) + 69|0);
 HEAP8[$14>>0] = $13;
 $15 = HEAP32[$2>>2]|0;
 $16 = ((($15)) + 208|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = HEAP32[$1>>2]|0;
 $19 = ((($18)) + 200|0);
 $20 = HEAP32[$19>>2]|0;
 __THREW__ = 0;
 $21 = (invoke_ii($20|0,($1|0))|0);
 $22 = __THREW__; __THREW__ = 0;
 $23 = $22&1;
 L4: do {
  if ($23) {
   label = 23;
  } else {
   __THREW__ = 0;
   invoke_vii($17|0,($2|0),($21|0));
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   if ($25) {
    label = 23;
   } else {
    $26 = HEAP32[$0>>2]|0;
    $27 = ((($26)) + 192|0);
    $28 = HEAP32[$27>>2]|0;
    __THREW__ = 0;
    $29 = (invoke_ii($28|0,($0|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     label = 23;
    } else {
     $32 = HEAP32[$0>>2]|0;
     $33 = ((($32)) + 140|0);
     $34 = HEAP32[$33>>2]|0;
     __THREW__ = 0;
     $35 = (invoke_ii($34|0,($0|0))|0);
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if ($37) {
      label = 23;
     } else {
      $38 = HEAP32[$2>>2]|0;
      $39 = ((($38)) + 140|0);
      $40 = HEAP32[$39>>2]|0;
      __THREW__ = 0;
      $41 = (invoke_ii($40|0,($2|0))|0);
      $42 = __THREW__; __THREW__ = 0;
      $43 = $42&1;
      if ($43) {
       label = 23;
      } else {
       $44 = ($29|0)==(0);
       L10: do {
        if ($44) {
         $$046 = 0;
         while(1) {
          $67 = HEAP32[$1>>2]|0;
          $68 = ((($67)) + 200|0);
          $69 = HEAP32[$68>>2]|0;
          __THREW__ = 0;
          $70 = (invoke_ii($69|0,($1|0))|0);
          $71 = __THREW__; __THREW__ = 0;
          $72 = $71&1;
          if ($72) {
           label = 23;
           break L4;
          }
          $73 = ($$046>>>0)<($70>>>0);
          if (!($73)) {
           break L10;
          }
          $76 = HEAP32[$1>>2]|0;
          $77 = ((($76)) + 216|0);
          $78 = HEAP32[$77>>2]|0;
          __THREW__ = 0;
          (invoke_iii($78|0,($1|0),($$046|0))|0);
          $79 = __THREW__; __THREW__ = 0;
          $80 = $79&1;
          if ($80) {
           label = 23;
           break L4;
          }
          $81 = (($$046) + 1)|0;
          $$046 = $81;
         }
        } else {
         $$046$us = 0;
         while(1) {
          $45 = HEAP32[$1>>2]|0;
          $46 = ((($45)) + 200|0);
          $47 = HEAP32[$46>>2]|0;
          __THREW__ = 0;
          $48 = (invoke_ii($47|0,($1|0))|0);
          $49 = __THREW__; __THREW__ = 0;
          $50 = $49&1;
          if ($50) {
           label = 23;
           break L4;
          }
          $51 = ($$046$us>>>0)<($48>>>0);
          if (!($51)) {
           break L10;
          }
          $52 = HEAP32[$1>>2]|0;
          $53 = ((($52)) + 216|0);
          $54 = HEAP32[$53>>2]|0;
          __THREW__ = 0;
          $55 = (invoke_iii($54|0,($1|0),($$046$us|0))|0);
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           label = 23;
           break L4;
          }
          $58 = Math_imul($55, $29)|0;
          $59 = (($35) + ($58)|0);
          $60 = Math_imul($$046$us, $29)|0;
          $61 = (($41) + ($60)|0);
          $$04369$us = $61;$$04468$us = $59;$$070$us = 0;
          while(1) {
           $62 = ((($$04468$us)) + 1|0);
           $63 = HEAP8[$$04468$us>>0]|0;
           $64 = ((($$04369$us)) + 1|0);
           HEAP8[$$04369$us>>0] = $63;
           $65 = (($$070$us) + 1)|0;
           $exitcond = ($65|0)==($29|0);
           if ($exitcond) {
            break;
           } else {
            $$04369$us = $64;$$04468$us = $62;$$070$us = $65;
           }
          }
          $66 = (($$046$us) + 1)|0;
          $$046$us = $66;
         }
        }
       } while(0);
       if ($3) {
        return ($2|0);
       }
       __THREW__ = 0;
       (invoke_ii(3335,($2|0))|0);
       $74 = __THREW__; __THREW__ = 0;
       $75 = $74&1;
       if ($75) {
        $82 = ___cxa_find_matching_catch_2()|0;
        $83 = tempRet0;
        $$sink51$sink52$sink53$sink5466$index = $82;$$sink51$sink52$sink53$sink5466$index4 = $83;
        break;
       } else {
        return ($2|0);
       }
      }
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 23) {
  $84 = ___cxa_find_matching_catch_2()|0;
  $85 = tempRet0;
  if ($3) {
   $$sink51$sink52$sink53$sink5467$index = $84;$$sink51$sink52$sink53$sink5467$index10 = $85;
   ___resumeException($$sink51$sink52$sink53$sink5467$index|0);
   // unreachable;
  } else {
   $$sink51$sink52$sink53$sink5466$index = $84;$$sink51$sink52$sink53$sink5466$index4 = $85;
  }
 }
 $86 = ((($2)) + 8|0);
 $87 = HEAP32[$86>>2]|0;HEAP32[$86>>2] = (($87-1)|0);
 $88 = ($87|0)==(1);
 if (!($88)) {
  $$sink51$sink52$sink53$sink5467$index = $$sink51$sink52$sink53$sink5466$index;$$sink51$sink52$sink53$sink5467$index10 = $$sink51$sink52$sink53$sink5466$index4;
  ___resumeException($$sink51$sink52$sink53$sink5467$index|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(3262,($2|0),1,1);
 $89 = __THREW__; __THREW__ = 0;
 $90 = $89&1;
 if ($90) {
  $91 = ___cxa_find_matching_catch_3(0|0)|0;
  $92 = tempRet0;
  ___clang_call_terminate($91);
  // unreachable;
 } else {
  $$sink51$sink52$sink53$sink5467$index = $$sink51$sink52$sink53$sink5466$index;$$sink51$sink52$sink53$sink5467$index10 = $$sink51$sink52$sink53$sink5466$index4;
  ___resumeException($$sink51$sink52$sink53$sink5467$index|0);
  // unreachable;
 }
 return (0)|0;
}
function __ZN21GeometryUtilFunctionsL14duplicateArrayERNSt3__26vectorINS0_4pairIN3osg7ref_ptrINS3_5ArrayEEES6_EENS0_9allocatorIS7_EEEERS6_j($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$016 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$indexZ2D = 0, $eh$lpad$body21$index2Z2D = 0, $eh$lpad$body21$indexZ2D = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = HEAP32[$1>>2]|0;
 $5 = (__ZN3osg9cloneTypeINS_5ArrayEEEPT_PKS2_($4)|0);
 $6 = ((($5)) + 64|0);
 HEAP32[$6>>2] = 4;
 $7 = HEAP32[$1>>2]|0;
 $8 = ((($7)) + 68|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = ((($5)) + 68|0);
 HEAP8[$10>>0] = $9;
 $11 = ((($7)) + 69|0);
 $12 = HEAP8[$11>>0]|0;
 $13 = ((($5)) + 69|0);
 HEAP8[$13>>0] = $12;
 $14 = HEAP32[$5>>2]|0;
 $15 = ((($14)) + 208|0);
 $16 = HEAP32[$15>>2]|0;
 FUNCTION_TABLE_vii[$16 & 8191]($5,$2);
 $17 = ($5|0)==(0|0);
 if (!($17)) {
  $18 = ((($5)) + 8|0);
  $19 = HEAP32[$18>>2]|0;HEAP32[$18>>2] = (($19+1)|0);
 }
 $20 = HEAP32[$1>>2]|0;
 HEAP32[$3>>2] = $20;
 $21 = ($20|0)==(0|0);
 if (!($21)) {
  $22 = ((($20)) + 8|0);
  $23 = HEAP32[$22>>2]|0;HEAP32[$22>>2] = (($23+1)|0);
 }
 $24 = ((($3)) + 4|0);
 HEAP32[$24>>2] = $5;
 if (!($17)) {
  $25 = ((($5)) + 8|0);
  $26 = HEAP32[$25>>2]|0;HEAP32[$25>>2] = (($26+1)|0);
 }
 $27 = ((($0)) + 4|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = ((($0)) + 8|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ($28|0)==($30|0);
 do {
  if ($31) {
   __THREW__ = 0;
   invoke_vii(3780,($0|0),($3|0));
   $43 = __THREW__; __THREW__ = 0;
   $44 = $43&1;
   if ($44) {
    $83 = ___cxa_find_matching_catch_2()|0;
    $84 = tempRet0;
    $85 = HEAP32[$24>>2]|0;
    $86 = ($85|0)==(0|0);
    if (!($86)) {
     $87 = ((($85)) + 8|0);
     $88 = HEAP32[$87>>2]|0;HEAP32[$87>>2] = (($88-1)|0);
     $89 = ($88|0)==(1);
     if ($89) {
      __THREW__ = 0;
      invoke_viii(3262,($85|0),1,1);
      $90 = __THREW__; __THREW__ = 0;
      $91 = $90&1;
      if ($91) {
       $99 = ___cxa_find_matching_catch_3(0|0)|0;
       $100 = tempRet0;
       $101 = HEAP32[$3>>2]|0;
       $102 = ($101|0)==(0|0);
       if (!($102)) {
        $103 = ((($101)) + 8|0);
        $104 = HEAP32[$103>>2]|0;HEAP32[$103>>2] = (($104-1)|0);
        $105 = ($104|0)==(1);
        if ($105) {
         __THREW__ = 0;
         invoke_viii(3262,($101|0),1,1);
         $106 = __THREW__; __THREW__ = 0;
         $107 = $106&1;
         if ($107) {
          $108 = ___cxa_find_matching_catch_3(0|0)|0;
          $109 = tempRet0;
          ___clang_call_terminate($108);
          // unreachable;
         }
        }
       }
       HEAP32[$3>>2] = 0;
       $eh$lpad$body$indexZ2D = $99;
       ___clang_call_terminate($eh$lpad$body$indexZ2D);
       // unreachable;
      }
     }
    }
    HEAP32[$24>>2] = 0;
    $92 = HEAP32[$3>>2]|0;
    $93 = ($92|0)==(0|0);
    if (!($93)) {
     $94 = ((($92)) + 8|0);
     $95 = HEAP32[$94>>2]|0;HEAP32[$94>>2] = (($95-1)|0);
     $96 = ($95|0)==(1);
     if ($96) {
      __THREW__ = 0;
      invoke_viii(3262,($92|0),1,1);
      $97 = __THREW__; __THREW__ = 0;
      $98 = $97&1;
      if ($98) {
       break;
      }
     }
    }
    HEAP32[$3>>2] = 0;
    $$0 = $84;$$016 = $83;
    label = 49;
   } else {
    label = 14;
   }
  } else {
   $32 = HEAP32[$3>>2]|0;
   HEAP32[$28>>2] = $32;
   $33 = ($32|0)==(0|0);
   if (!($33)) {
    $34 = ((($32)) + 8|0);
    $35 = HEAP32[$34>>2]|0;HEAP32[$34>>2] = (($35+1)|0);
   }
   $36 = ((($28)) + 4|0);
   $37 = HEAP32[$24>>2]|0;
   HEAP32[$36>>2] = $37;
   $38 = ($37|0)==(0|0);
   if (!($38)) {
    $39 = ((($37)) + 8|0);
    $40 = HEAP32[$39>>2]|0;HEAP32[$39>>2] = (($40+1)|0);
   }
   $41 = HEAP32[$27>>2]|0;
   $42 = ((($41)) + 8|0);
   HEAP32[$27>>2] = $42;
   label = 14;
  }
 } while(0);
 if ((label|0) == 14) {
  $45 = HEAP32[$24>>2]|0;
  $46 = ($45|0)==(0|0);
  if ($46) {
   label = 17;
  } else {
   $47 = ((($45)) + 8|0);
   $48 = HEAP32[$47>>2]|0;HEAP32[$47>>2] = (($48-1)|0);
   $49 = ($48|0)==(1);
   if ($49) {
    __THREW__ = 0;
    invoke_viii(3262,($45|0),1,1);
    $50 = __THREW__; __THREW__ = 0;
    $51 = $50&1;
    if ($51) {
     $59 = ___cxa_find_matching_catch_2()|0;
     $60 = tempRet0;
     $61 = HEAP32[$3>>2]|0;
     $62 = ($61|0)==(0|0);
     if (!($62)) {
      $63 = ((($61)) + 8|0);
      $64 = HEAP32[$63>>2]|0;HEAP32[$63>>2] = (($64-1)|0);
      $65 = ($64|0)==(1);
      if ($65) {
       __THREW__ = 0;
       invoke_viii(3262,($61|0),1,1);
       $66 = __THREW__; __THREW__ = 0;
       $67 = $66&1;
       if ($67) {
        $68 = ___cxa_find_matching_catch_3(0|0)|0;
        $69 = tempRet0;
        ___clang_call_terminate($68);
        // unreachable;
       }
      }
     }
     HEAP32[$3>>2] = 0;
     $eh$lpad$body21$index2Z2D = $60;$eh$lpad$body21$indexZ2D = $59;
    } else {
     label = 17;
    }
   } else {
    label = 17;
   }
  }
  do {
   if ((label|0) == 17) {
    HEAP32[$24>>2] = 0;
    $52 = HEAP32[$3>>2]|0;
    $53 = ($52|0)==(0|0);
    if (!($53)) {
     $54 = ((($52)) + 8|0);
     $55 = HEAP32[$54>>2]|0;HEAP32[$54>>2] = (($55-1)|0);
     $56 = ($55|0)==(1);
     if ($56) {
      __THREW__ = 0;
      invoke_viii(3262,($52|0),1,1);
      $57 = __THREW__; __THREW__ = 0;
      $58 = $57&1;
      if ($58) {
       $81 = ___cxa_find_matching_catch_2()|0;
       $82 = tempRet0;
       $eh$lpad$body21$index2Z2D = $82;$eh$lpad$body21$indexZ2D = $81;
       break;
      }
     }
    }
    HEAP32[$3>>2] = 0;
    if (!($17)) {
     $70 = ((($5)) + 8|0);
     $71 = HEAP32[$70>>2]|0;HEAP32[$70>>2] = (($71-1)|0);
     $72 = ($71|0)==(1);
     if ($72) {
      __ZNK3osg10Referenced24signalObserversAndDeleteEbb($5,1,1);
     }
    }
    $73 = HEAP32[$1>>2]|0;
    $74 = ($73|0)==($5|0);
    if ($74) {
     STACKTOP = sp;return;
    }
    HEAP32[$1>>2] = $5;
    if (!($17)) {
     $75 = ((($5)) + 8|0);
     $76 = HEAP32[$75>>2]|0;HEAP32[$75>>2] = (($76+1)|0);
    }
    $77 = ($73|0)==(0|0);
    if ($77) {
     STACKTOP = sp;return;
    }
    $78 = ((($73)) + 8|0);
    $79 = HEAP32[$78>>2]|0;HEAP32[$78>>2] = (($79-1)|0);
    $80 = ($79|0)==(1);
    if (!($80)) {
     STACKTOP = sp;return;
    }
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($73,1,1);
    STACKTOP = sp;return;
   }
  } while(0);
  $$0 = $eh$lpad$body21$index2Z2D;$$016 = $eh$lpad$body21$indexZ2D;
  label = 49;
 }
 if ((label|0) == 49) {
  if ($17) {
   ___resumeException($$016|0);
   // unreachable;
  }
  $110 = ((($5)) + 8|0);
  $111 = HEAP32[$110>>2]|0;HEAP32[$110>>2] = (($111-1)|0);
  $112 = ($111|0)==(1);
  if (!($112)) {
   ___resumeException($$016|0);
   // unreachable;
  }
  __THREW__ = 0;
  invoke_viii(3262,($5|0),1,1);
  $113 = __THREW__; __THREW__ = 0;
  $114 = $113&1;
  if (!($114)) {
   ___resumeException($$016|0);
   // unreachable;
  }
 }
 $115 = ___cxa_find_matching_catch_3(0|0)|0;
 $116 = tempRet0;
 $eh$lpad$body$indexZ2D = $115;
 ___clang_call_terminate($eh$lpad$body$indexZ2D);
 // unreachable;
}
function __ZNSt3__26vectorIN21GeometryUtilFunctions7PtrDataENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$06$i$i = 0, $$pre$i = 0, $$sroa$7$0 = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = (($5|0) / 12)&-1;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(357913941);
 $9 = $4;
 $10 = $3;
 if ($8) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $11 = ((($0)) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) - ($4))|0;
 $14 = (($13|0) / 12)&-1;
 $15 = ($14>>>0)<(178956970);
 $16 = $14 << 1;
 $17 = ($16>>>0)<($7>>>0);
 $$sroa$speculated$i = $17 ? $7 : $16;
 $$sroa$speculated$$i = $15 ? $$sroa$speculated$i : 357913941;
 $18 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($18) {
   $28 = 0;
  } else {
   $19 = ($$sroa$speculated$$i>>>0)>(357913941);
   if (!($19)) {
    $25 = ($$sroa$speculated$$i*12)|0;
    $26 = (__Znwj($25)|0);
    $28 = $26;
    break;
   }
   $20 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($20|0),(204840|0));
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if ($22) {
    $23 = ___cxa_find_matching_catch_2()|0;
    $24 = tempRet0;
    ___cxa_free_exception(($20|0));
    ___resumeException($23|0);
    // unreachable;
   } else {
    HEAP32[$20>>2] = (99824);
    ___cxa_throw(($20|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $27 = (($28) + (($6*12)|0)|0);
 $29 = $27;
 $30 = (($28) + (($$sroa$speculated$$i*12)|0)|0);
 $31 = $30;
 $32 = HEAP32[$1>>2]|0;
 HEAP32[$27>>2] = $32;
 $33 = (((($28) + (($6*12)|0)|0)) + 4|0);
 $34 = ((($1)) + 4|0);
 $35 = HEAP32[$34>>2]|0;
 HEAP32[$33>>2] = $35;
 $36 = (((($28) + (($6*12)|0)|0)) + 8|0);
 $37 = ((($1)) + 8|0);
 $38 = HEAP32[$37>>2]|0;
 HEAP32[$36>>2] = $38;
 $39 = ((($27)) + 12|0);
 $40 = $39;
 $41 = ($10|0)==($9|0);
 if ($41) {
  $56 = $29;$57 = $3;
 } else {
  $$06$i$i = $10;$$sroa$7$0 = $29;$43 = $27;
  while(1) {
   $42 = ((($43)) + -12|0);
   $44 = ((($$06$i$i)) + -12|0);
   $45 = HEAP32[$44>>2]|0;
   HEAP32[$42>>2] = $45;
   $46 = ((($43)) + -8|0);
   $47 = ((($$06$i$i)) + -8|0);
   $48 = HEAP32[$47>>2]|0;
   HEAP32[$46>>2] = $48;
   $49 = ((($43)) + -4|0);
   $50 = ((($$06$i$i)) + -4|0);
   $51 = HEAP32[$50>>2]|0;
   HEAP32[$49>>2] = $51;
   $52 = $$sroa$7$0;
   $53 = ((($52)) + -12|0);
   $54 = $53;
   $55 = ($44|0)==($9|0);
   if ($55) {
    break;
   } else {
    $$06$i$i = $44;$$sroa$7$0 = $54;$43 = $53;
   }
  }
  $$pre$i = HEAP32[$0>>2]|0;
  $56 = $54;$57 = $$pre$i;
 }
 HEAP32[$0>>2] = $56;
 HEAP32[$2>>2] = $40;
 HEAP32[$11>>2] = $31;
 $58 = ($57|0)==(0);
 if ($58) {
  return;
 }
 $59 = $57;
 __ZdlPv($59);
 return;
}
function __ZNSt3__213__vector_baseINS_4pairIN3osg7ref_ptrINS2_5ArrayEEES5_EENS_9allocatorIS6_EEED2Ev($0) {
 $0 = $0|0;
 var $$pre = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$i$i$indexZ2D = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 }
 $3 = ((($0)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==($1|0);
 do {
  if ($5) {
   $38 = $1;
  } else {
   $7 = $4;
   while(1) {
    $6 = ((($7)) + -8|0);
    HEAP32[$3>>2] = $6;
    $8 = ((($7)) + -4|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = ($9|0)==(0|0);
    if (!($10)) {
     $11 = ((($9)) + 8|0);
     $12 = HEAP32[$11>>2]|0;HEAP32[$11>>2] = (($12-1)|0);
     $13 = ($12|0)==(1);
     if ($13) {
      __THREW__ = 0;
      invoke_viii(3262,($9|0),1,1);
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if ($15) {
       label = 9;
       break;
      }
     }
    }
    HEAP32[$8>>2] = 0;
    $16 = HEAP32[$6>>2]|0;
    $17 = ($16|0)==(0|0);
    if (!($17)) {
     $18 = ((($16)) + 8|0);
     $19 = HEAP32[$18>>2]|0;HEAP32[$18>>2] = (($19-1)|0);
     $20 = ($19|0)==(1);
     if ($20) {
      __THREW__ = 0;
      invoke_viii(3262,($16|0),1,1);
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if ($22) {
       label = 15;
       break;
      }
     }
    }
    HEAP32[$6>>2] = 0;
    $34 = HEAP32[$3>>2]|0;
    $35 = ($34|0)==($1|0);
    if ($35) {
     label = 17;
     break;
    } else {
     $7 = $34;
    }
   }
   if ((label|0) == 9) {
    $23 = ___cxa_find_matching_catch_2()|0;
    $24 = tempRet0;
    $25 = HEAP32[$6>>2]|0;
    $26 = ($25|0)==(0|0);
    if (!($26)) {
     $27 = ((($25)) + 8|0);
     $28 = HEAP32[$27>>2]|0;HEAP32[$27>>2] = (($28-1)|0);
     $29 = ($28|0)==(1);
     if ($29) {
      __THREW__ = 0;
      invoke_viii(3262,($25|0),1,1);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       $32 = ___cxa_find_matching_catch_3(0|0)|0;
       $33 = tempRet0;
       ___clang_call_terminate($32);
       // unreachable;
      }
     }
    }
    HEAP32[$6>>2] = 0;
    $eh$lpad$body$i$i$indexZ2D = $23;
    ___cxa_call_unexpected(($eh$lpad$body$i$i$indexZ2D|0));
    // unreachable;
   }
   else if ((label|0) == 15) {
    $36 = ___cxa_find_matching_catch_2()|0;
    $37 = tempRet0;
    $eh$lpad$body$i$i$indexZ2D = $36;
    ___cxa_call_unexpected(($eh$lpad$body$i$i$indexZ2D|0));
    // unreachable;
   }
   else if ((label|0) == 17) {
    $$pre = HEAP32[$0>>2]|0;
    $38 = $$pre;
    break;
   }
  }
 } while(0);
 __ZdlPv($38);
 return;
}
function __ZN3osg9cloneTypeINS_5ArrayEEEPT_PKS2_($0) {
 $0 = $0|0;
 var $$1 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp + 4|0;
 $2 = sp;
 $3 = ($0|0)==(0|0);
 if ($3) {
  $61 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
  if (!($61)) {
   $$1 = 0;
   STACKTOP = sp;return ($$1|0);
  }
  $62 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
  $63 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($62,128845,78)|0);
  $64 = HEAP32[$63>>2]|0;
  $65 = ((($64)) + -12|0);
  $66 = HEAP32[$65>>2]|0;
  $67 = (($63) + ($66)|0);
  __ZNKSt3__28ios_base6getlocEv($2,$67);
  __THREW__ = 0;
  $68 = (invoke_iii(3255,($2|0),(215188|0))|0);
  $69 = __THREW__; __THREW__ = 0;
  $70 = $69&1;
  if (!($70)) {
   $71 = HEAP32[$68>>2]|0;
   $72 = ((($71)) + 28|0);
   $73 = HEAP32[$72>>2]|0;
   __THREW__ = 0;
   $74 = (invoke_iii($73|0,($68|0),10)|0);
   $75 = __THREW__; __THREW__ = 0;
   $76 = $75&1;
   if (!($76)) {
    __ZNSt3__26localeD2Ev($2);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($63,$74)|0);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($63)|0);
    $$1 = 0;
    STACKTOP = sp;return ($$1|0);
   }
  }
  $77 = ___cxa_find_matching_catch_2()|0;
  $78 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3263,($2|0));
  $79 = __THREW__; __THREW__ = 0;
  $80 = $79&1;
  if ($80) {
   $81 = ___cxa_find_matching_catch_3(0|0)|0;
   $82 = tempRet0;
   ___clang_call_terminate($81);
   // unreachable;
  } else {
   ___resumeException($77|0);
   // unreachable;
  }
 }
 $4 = HEAP32[$0>>2]|0;
 $5 = ((($4)) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_ii[$6 & 8191]($0)|0);
 $8 = ($7|0)==(0|0);
 if ($8) {
  label = 9;
 } else {
  $9 = ((($7)) + 8|0);
  $10 = HEAP32[$9>>2]|0;HEAP32[$9>>2] = (($10+1)|0);
  $11 = (___dynamic_cast($7,26112,23016,0)|0);
  $12 = ($11|0)==(0|0);
  if ($12) {
   label = 9;
  } else {
   __THREW__ = 0;
   (invoke_ii(3335,($7|0))|0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if ($14) {
    label = 5;
   } else {
    $$1 = $11;
    STACKTOP = sp;return ($$1|0);
   }
  }
 }
 L19: do {
  if ((label|0) == 9) {
   __THREW__ = 0;
   $22 = (invoke_ii(3265,2)|0);
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if ($24) {
    label = 5;
   } else {
    do {
     if ($22) {
      __THREW__ = 0;
      $25 = (invoke_ii(3266,2)|0);
      $26 = __THREW__; __THREW__ = 0;
      $27 = $26&1;
      if ($27) {
       label = 5;
       break L19;
      }
      __THREW__ = 0;
      $28 = (invoke_iiii(3267,($25|0),(128766|0),78)|0);
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if ($30) {
       label = 5;
       break L19;
      }
      $31 = HEAP32[$28>>2]|0;
      $32 = ((($31)) + -12|0);
      $33 = HEAP32[$32>>2]|0;
      $34 = (($28) + ($33)|0);
      __THREW__ = 0;
      invoke_vii(3257,($1|0),($34|0));
      $35 = __THREW__; __THREW__ = 0;
      $36 = $35&1;
      if ($36) {
       label = 5;
       break L19;
      }
      __THREW__ = 0;
      $37 = (invoke_iii(3255,($1|0),(215188|0))|0);
      $38 = __THREW__; __THREW__ = 0;
      $39 = $38&1;
      if (!($39)) {
       $40 = HEAP32[$37>>2]|0;
       $41 = ((($40)) + 28|0);
       $42 = HEAP32[$41>>2]|0;
       __THREW__ = 0;
       $43 = (invoke_iii($42|0,($37|0),10)|0);
       $44 = __THREW__; __THREW__ = 0;
       $45 = $44&1;
       if (!($45)) {
        __THREW__ = 0;
        invoke_vi(3263,($1|0));
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 5;
         break L19;
        }
        __THREW__ = 0;
        (invoke_iii(3268,($28|0),($43|0))|0);
        $54 = __THREW__; __THREW__ = 0;
        $55 = $54&1;
        if ($55) {
         label = 5;
         break L19;
        }
        __THREW__ = 0;
        (invoke_ii(3269,($28|0))|0);
        $56 = __THREW__; __THREW__ = 0;
        $57 = $56&1;
        if ($57) {
         label = 5;
         break L19;
        } else {
         break;
        }
       }
      }
      $46 = ___cxa_find_matching_catch_2()|0;
      $47 = tempRet0;
      __THREW__ = 0;
      invoke_vi(3263,($1|0));
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       $50 = ___cxa_find_matching_catch_3(0|0)|0;
       $51 = tempRet0;
       ___clang_call_terminate($50);
       // unreachable;
      } else {
       $eh$lpad$body$index2Z2D = $47;$eh$lpad$body$indexZ2D = $46;
       break L19;
      }
     }
    } while(0);
    if ($8) {
     $$1 = 0;
     STACKTOP = sp;return ($$1|0);
    }
    $58 = ((($7)) + 8|0);
    $59 = HEAP32[$58>>2]|0;HEAP32[$58>>2] = (($59-1)|0);
    $60 = ($59|0)==(1);
    if (!($60)) {
     $$1 = 0;
     STACKTOP = sp;return ($$1|0);
    }
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($7,1,1);
    $$1 = 0;
    STACKTOP = sp;return ($$1|0);
   }
  }
 } while(0);
 if ((label|0) == 5) {
  $15 = ___cxa_find_matching_catch_2()|0;
  $16 = tempRet0;
  $eh$lpad$body$index2Z2D = $16;$eh$lpad$body$indexZ2D = $15;
 }
 if ($8) {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 $17 = ((($7)) + 8|0);
 $18 = HEAP32[$17>>2]|0;HEAP32[$17>>2] = (($18-1)|0);
 $19 = ($18|0)==(1);
 if (!($19)) {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(3262,($7|0),1,1);
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if ($21) {
  $83 = ___cxa_find_matching_catch_3(0|0)|0;
  $84 = tempRet0;
  ___clang_call_terminate($83);
  // unreachable;
 } else {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 return (0)|0;
}
function __ZNSt3__26vectorINS_4pairIN3osg7ref_ptrINS2_5ArrayEEES5_EENS_9allocatorIS6_EEE21__push_back_slow_pathIKS6_EEvRT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$06$i$i = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$phi11$iZ2D = 0, $$pre8$i = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $2 = sp;
 $3 = ((($0)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$0>>2]|0;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 3;
 $8 = (($7) + 1)|0;
 $9 = ($8>>>0)>(536870911);
 if ($9) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $10 = ((($0)) + 8|0);
 $11 = ((($0)) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) - ($5))|0;
 $14 = $13 >> 3;
 $15 = ($14>>>0)<(268435455);
 $16 = $13 >> 2;
 $17 = ($16>>>0)<($8>>>0);
 $$sroa$speculated$i = $17 ? $8 : $16;
 $$sroa$speculated$$i = $15 ? $$sroa$speculated$i : 536870911;
 $18 = ((($2)) + 12|0);
 HEAP32[$18>>2] = 0;
 $19 = ((($2)) + 16|0);
 HEAP32[$19>>2] = $10;
 $20 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($20) {
   $29 = 0;
  } else {
   $21 = ($$sroa$speculated$$i>>>0)>(536870911);
   if (!($21)) {
    $27 = $$sroa$speculated$$i << 3;
    $28 = (__Znwj($27)|0);
    $29 = $28;
    break;
   }
   $22 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($22|0),(204840|0));
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if ($24) {
    $25 = ___cxa_find_matching_catch_2()|0;
    $26 = tempRet0;
    ___cxa_free_exception(($22|0));
    ___resumeException($25|0);
    // unreachable;
   } else {
    HEAP32[$22>>2] = (99824);
    ___cxa_throw(($22|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 HEAP32[$2>>2] = $29;
 $30 = (($29) + ($7<<3)|0);
 $31 = ((($2)) + 8|0);
 HEAP32[$31>>2] = $30;
 $32 = ((($2)) + 4|0);
 HEAP32[$32>>2] = $30;
 $33 = (($29) + ($$sroa$speculated$$i<<3)|0);
 $34 = ((($2)) + 12|0);
 HEAP32[$34>>2] = $33;
 $35 = HEAP32[$1>>2]|0;
 HEAP32[$30>>2] = $35;
 $36 = ($35|0)==(0|0);
 if (!($36)) {
  $37 = ((($35)) + 8|0);
  $38 = HEAP32[$37>>2]|0;HEAP32[$37>>2] = (($38+1)|0);
 }
 $39 = (((($29) + ($7<<3)|0)) + 4|0);
 $40 = ((($1)) + 4|0);
 $41 = HEAP32[$40>>2]|0;
 HEAP32[$39>>2] = $41;
 $42 = ($41|0)==(0|0);
 if (!($42)) {
  $43 = ((($41)) + 8|0);
  $44 = HEAP32[$43>>2]|0;HEAP32[$43>>2] = (($44+1)|0);
 }
 $45 = HEAP32[$31>>2]|0;
 $46 = ((($45)) + 8|0);
 HEAP32[$31>>2] = $46;
 $47 = HEAP32[$0>>2]|0;
 $48 = HEAP32[$3>>2]|0;
 $49 = ($48|0)==($47|0);
 if ($49) {
  $50 = $48;
  $51 = $47;
  $$pre8$i = HEAP32[$32>>2]|0;
  $$pre$phi11$iZ2D = $32;$69 = $$pre8$i;$70 = $51;$72 = $50;
  HEAP32[$0>>2] = $69;
  HEAP32[$$pre$phi11$iZ2D>>2] = $70;
  $71 = HEAP32[$31>>2]|0;
  HEAP32[$3>>2] = $71;
  HEAP32[$31>>2] = $72;
  $73 = HEAP32[$11>>2]|0;
  $74 = HEAP32[$34>>2]|0;
  HEAP32[$11>>2] = $74;
  HEAP32[$34>>2] = $73;
  $75 = HEAP32[$$pre$phi11$iZ2D>>2]|0;
  HEAP32[$2>>2] = $75;
  __ZNSt3__214__split_bufferINS_4pairIN3osg7ref_ptrINS2_5ArrayEEES5_EERNS_9allocatorIS6_EEED2Ev($2);
  STACKTOP = sp;return;
 }
 $$pre$i$i = HEAP32[$32>>2]|0;
 $$06$i$i = $48;$54 = $$pre$i$i;
 while(1) {
  $52 = ((($$06$i$i)) + -8|0);
  $53 = ((($54)) + -8|0);
  $55 = HEAP32[$52>>2]|0;
  HEAP32[$53>>2] = $55;
  $56 = ($55|0)==(0|0);
  if (!($56)) {
   $57 = ((($55)) + 8|0);
   $58 = HEAP32[$57>>2]|0;HEAP32[$57>>2] = (($58+1)|0);
  }
  $59 = ((($54)) + -4|0);
  $60 = ((($$06$i$i)) + -4|0);
  $61 = HEAP32[$60>>2]|0;
  HEAP32[$59>>2] = $61;
  $62 = ($61|0)==(0|0);
  if (!($62)) {
   $63 = ((($61)) + 8|0);
   $64 = HEAP32[$63>>2]|0;HEAP32[$63>>2] = (($64+1)|0);
  }
  $65 = HEAP32[$32>>2]|0;
  $66 = ((($65)) + -8|0);
  HEAP32[$32>>2] = $66;
  $67 = ($52|0)==($47|0);
  if ($67) {
   break;
  } else {
   $$06$i$i = $52;$54 = $66;
  }
 }
 $68 = $66;
 $$pre$i = HEAP32[$0>>2]|0;
 $$pre = HEAP32[$3>>2]|0;
 $$pre$phi11$iZ2D = $32;$69 = $68;$70 = $$pre$i;$72 = $$pre;
 HEAP32[$0>>2] = $69;
 HEAP32[$$pre$phi11$iZ2D>>2] = $70;
 $71 = HEAP32[$31>>2]|0;
 HEAP32[$3>>2] = $71;
 HEAP32[$31>>2] = $72;
 $73 = HEAP32[$11>>2]|0;
 $74 = HEAP32[$34>>2]|0;
 HEAP32[$11>>2] = $74;
 HEAP32[$34>>2] = $73;
 $75 = HEAP32[$$pre$phi11$iZ2D>>2]|0;
 HEAP32[$2>>2] = $75;
 __ZNSt3__214__split_bufferINS_4pairIN3osg7ref_ptrINS2_5ArrayEEES5_EERNS_9allocatorIS6_EEED2Ev($2);
 STACKTOP = sp;return;
}
function __ZNSt3__214__split_bufferINS_4pairIN3osg7ref_ptrINS2_5ArrayEEES5_EERNS_9allocatorIS6_EEED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$i$i$i$indexZ2D = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==($2|0);
 L1: do {
  if (!($5)) {
   $7 = $4;
   while(1) {
    $6 = ((($7)) + -8|0);
    HEAP32[$3>>2] = $6;
    $8 = ((($7)) + -4|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = ($9|0)==(0|0);
    if (!($10)) {
     $11 = ((($9)) + 8|0);
     $12 = HEAP32[$11>>2]|0;HEAP32[$11>>2] = (($12-1)|0);
     $13 = ($12|0)==(1);
     if ($13) {
      __THREW__ = 0;
      invoke_viii(3262,($9|0),1,1);
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if ($15) {
       break;
      }
     }
    }
    HEAP32[$8>>2] = 0;
    $16 = HEAP32[$6>>2]|0;
    $17 = ($16|0)==(0|0);
    if (!($17)) {
     $18 = ((($16)) + 8|0);
     $19 = HEAP32[$18>>2]|0;HEAP32[$18>>2] = (($19-1)|0);
     $20 = ($19|0)==(1);
     if ($20) {
      __THREW__ = 0;
      invoke_viii(3262,($16|0),1,1);
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if ($22) {
       label = 14;
       break;
      }
     }
    }
    HEAP32[$6>>2] = 0;
    $34 = HEAP32[$3>>2]|0;
    $35 = ($34|0)==($2|0);
    if ($35) {
     break L1;
    } else {
     $7 = $34;
    }
   }
   if ((label|0) == 14) {
    $36 = ___cxa_find_matching_catch_2()|0;
    $37 = tempRet0;
    $eh$lpad$body$i$i$i$indexZ2D = $36;
    ___cxa_call_unexpected(($eh$lpad$body$i$i$i$indexZ2D|0));
    // unreachable;
   }
   $23 = ___cxa_find_matching_catch_2()|0;
   $24 = tempRet0;
   $25 = HEAP32[$6>>2]|0;
   $26 = ($25|0)==(0|0);
   if (!($26)) {
    $27 = ((($25)) + 8|0);
    $28 = HEAP32[$27>>2]|0;HEAP32[$27>>2] = (($28-1)|0);
    $29 = ($28|0)==(1);
    if ($29) {
     __THREW__ = 0;
     invoke_viii(3262,($25|0),1,1);
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      $32 = ___cxa_find_matching_catch_3(0|0)|0;
      $33 = tempRet0;
      ___clang_call_terminate($32);
      // unreachable;
     }
    }
   }
   HEAP32[$6>>2] = 0;
   $eh$lpad$body$i$i$i$indexZ2D = $23;
   ___cxa_call_unexpected(($eh$lpad$body$i$i$i$indexZ2D|0));
   // unreachable;
  }
 } while(0);
 $38 = HEAP32[$0>>2]|0;
 $39 = ($38|0)==(0|0);
 if ($39) {
  return;
 }
 __ZdlPv($38);
 return;
}
function __GLOBAL__sub_I_GLExtensions_cpp() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i$i$i = 0;
 var $scevgep$i$i$i$i$i$i4 = 0, $scevgep5$i$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF32[52061] = 1.0;
 HEAPF32[(208248)>>2] = 0.0;
 HEAPF32[(208252)>>2] = 0.0;
 HEAPF32[52064] = 0.0;
 HEAPF32[(208260)>>2] = 1.0;
 HEAPF32[(208264)>>2] = 0.0;
 HEAPF32[52067] = 0.0;
 HEAPF32[(208272)>>2] = 0.0;
 HEAPF32[(208276)>>2] = 1.0;
 $0 = (__ZN3osg15DisplaySettings8instanceEv()|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZNK3osg15DisplaySettings30getMaxNumberOfGraphicsContextsEv($1)|0);
 __ZNSt3__26vectorINS_3setINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS7_EENS5_IS7_EEEENS5_ISB_EEEC2Ej(208280,$2);
 (___cxa_atexit((3781|0),(208280|0),(___dso_handle|0))|0);
 $3 = (__ZN3osg15DisplaySettings8instanceEv()|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (__ZNK3osg15DisplaySettings30getMaxNumberOfGraphicsContextsEv($4)|0);
 __ZNSt3__26vectorINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS4_IS6_EEEC2Ej(208292,$5);
 (___cxa_atexit((3782|0),(208292|0),(___dso_handle|0))|0);
 $6 = (__ZN3osg15DisplaySettings8instanceEv()|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (__ZNK3osg15DisplaySettings30getMaxNumberOfGraphicsContextsEv($7)|0);
 HEAP32[52076] = 0;
 HEAP32[(208308)>>2] = 0;
 HEAP32[(208312)>>2] = 0;
 $9 = ($8|0)==(0);
 do {
  if (!($9)) {
   $10 = ($8>>>0)>(1073741823);
   if ($10) {
    __THREW__ = 0;
    invoke_vi(3307,(208304|0));
    $11 = __THREW__; __THREW__ = 0;
   } else {
    $12 = $8 << 2;
    __THREW__ = 0;
    $13 = (invoke_ii(3276,($12|0))|0);
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if (!($15)) {
     HEAP32[52076] = $13;
     $16 = (($13) + ($8<<2)|0);
     HEAP32[(208312)>>2] = $16;
     _memset(($13|0),0,($12|0))|0;
     HEAP32[(208308)>>2] = $16;
     break;
    }
   }
   $17 = ___cxa_find_matching_catch_2()|0;
   $18 = tempRet0;
   $19 = HEAP32[52076]|0;
   $20 = ($19|0)==(0|0);
   if ($20) {
    ___resumeException($17|0);
    // unreachable;
   }
   $21 = HEAP32[(208308)>>2]|0;
   $22 = ($21|0)==($19|0);
   if (!($22)) {
    $scevgep$i$i$i$i$i$i = ((($21)) + -4|0);
    $23 = $scevgep$i$i$i$i$i$i;
    $24 = $19;
    $25 = (($23) - ($24))|0;
    $26 = $25 >>> 2;
    $27 = $26 ^ -1;
    $scevgep5$i$i$i$i$i$i = (($21) + ($27<<2)|0);
    HEAP32[(208308)>>2] = $scevgep5$i$i$i$i$i$i;
   }
   __ZdlPv($19);
   ___resumeException($17|0);
   // unreachable;
  }
 } while(0);
 (___cxa_atexit((3760|0),(208304|0),(___dso_handle|0))|0);
 $28 = (__ZN3osg15DisplaySettings8instanceEv()|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (__ZNK3osg15DisplaySettings30getMaxNumberOfGraphicsContextsEv($29)|0);
 __ZNSt3__26vectorINS_3setINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS7_EENS5_IS7_EEEENS5_ISB_EEEC2Ej(208316,$30);
 (___cxa_atexit((3781|0),(208316|0),(___dso_handle|0))|0);
 $31 = (__ZN3osg15DisplaySettings8instanceEv()|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (__ZNK3osg15DisplaySettings30getMaxNumberOfGraphicsContextsEv($32)|0);
 __ZNSt3__26vectorINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS4_IS6_EEEC2Ej(208328,$33);
 (___cxa_atexit((3782|0),(208328|0),(___dso_handle|0))|0);
 $34 = (__ZN3osg15DisplaySettings8instanceEv()|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (__ZNK3osg15DisplaySettings30getMaxNumberOfGraphicsContextsEv($35)|0);
 HEAP32[52085] = 0;
 HEAP32[(208344)>>2] = 0;
 HEAP32[(208348)>>2] = 0;
 $37 = ($36|0)==(0);
 if ($37) {
  (___cxa_atexit((3760|0),(208340|0),(___dso_handle|0))|0);
  (__ZN3osg27getGLExtensionDisableStringEv()|0);
  $56 = (__ZN3osg15DisplaySettings8instanceEv()|0);
  $57 = HEAP32[$56>>2]|0;
  $58 = (__ZNK3osg15DisplaySettings30getMaxNumberOfGraphicsContextsEv($57)|0);
  __ZNSt3__26vectorIN3osg7ref_ptrINS1_12GLExtensionsEEENS_9allocatorIS4_EEEC2Ej(208352,$58);
  (___cxa_atexit((3783|0),(208352|0),(___dso_handle|0))|0);
  return;
 }
 $38 = ($36>>>0)>(1073741823);
 if ($38) {
  __THREW__ = 0;
  invoke_vi(3307,(208340|0));
  $39 = __THREW__; __THREW__ = 0;
 } else {
  $40 = $36 << 2;
  __THREW__ = 0;
  $41 = (invoke_ii(3276,($40|0))|0);
  $42 = __THREW__; __THREW__ = 0;
  $43 = $42&1;
  if (!($43)) {
   HEAP32[52085] = $41;
   $44 = (($41) + ($36<<2)|0);
   HEAP32[(208348)>>2] = $44;
   _memset(($41|0),0,($40|0))|0;
   HEAP32[(208344)>>2] = $44;
   (___cxa_atexit((3760|0),(208340|0),(___dso_handle|0))|0);
   (__ZN3osg27getGLExtensionDisableStringEv()|0);
   $56 = (__ZN3osg15DisplaySettings8instanceEv()|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = (__ZNK3osg15DisplaySettings30getMaxNumberOfGraphicsContextsEv($57)|0);
   __ZNSt3__26vectorIN3osg7ref_ptrINS1_12GLExtensionsEEENS_9allocatorIS4_EEEC2Ej(208352,$58);
   (___cxa_atexit((3783|0),(208352|0),(___dso_handle|0))|0);
   return;
  }
 }
 $45 = ___cxa_find_matching_catch_2()|0;
 $46 = tempRet0;
 $47 = HEAP32[52085]|0;
 $48 = ($47|0)==(0|0);
 if ($48) {
  ___resumeException($45|0);
  // unreachable;
 }
 $49 = HEAP32[(208344)>>2]|0;
 $50 = ($49|0)==($47|0);
 if (!($50)) {
  $scevgep$i$i$i$i$i$i4 = ((($49)) + -4|0);
  $51 = $scevgep$i$i$i$i$i$i4;
  $52 = $47;
  $53 = (($51) - ($52))|0;
  $54 = $53 >>> 2;
  $55 = $54 ^ -1;
  $scevgep5$i$i$i$i$i$i5 = (($49) + ($55<<2)|0);
  HEAP32[(208344)>>2] = $scevgep5$i$i$i$i$i$i5;
 }
 __ZdlPv($47);
 ___resumeException($45|0);
 // unreachable;
}
function __ZNSt3__26vectorINS_3setINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS7_EENS5_IS7_EEEENS5_ISB_EEEC2Ej($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i = 0, $$pre$i6 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = 0;
 $2 = ((($0)) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = ((($0)) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = ($1|0)==(0);
 if ($4) {
  return;
 }
 $5 = ($1>>>0)>(357913941);
 if ($5) {
  __THREW__ = 0;
  invoke_vi(3307,($0|0));
  $6 = __THREW__; __THREW__ = 0;
 } else {
  $7 = ($1*12)|0;
  __THREW__ = 0;
  $8 = (invoke_ii(3276,($7|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   HEAP32[$2>>2] = $8;
   HEAP32[$0>>2] = $8;
   $11 = (($8) + (($1*12)|0)|0);
   $12 = ((($0)) + 8|0);
   HEAP32[$12>>2] = $11;
   $$0$i = $1;$14 = $8;
   while(1) {
    $13 = ((($14)) + 4|0);
    HEAP32[$13>>2] = 0;
    $15 = ((($14)) + 8|0);
    HEAP32[$15>>2] = 0;
    $16 = ((($14)) + 4|0);
    HEAP32[$14>>2] = $16;
    $17 = HEAP32[$2>>2]|0;
    $18 = ((($17)) + 12|0);
    HEAP32[$2>>2] = $18;
    $19 = (($$0$i) + -1)|0;
    $20 = ($19|0)==(0);
    if ($20) {
     break;
    } else {
     $$0$i = $19;$14 = $18;
    }
   }
   return;
  }
 }
 $21 = ___cxa_find_matching_catch_2()|0;
 $22 = tempRet0;
 $23 = HEAP32[$0>>2]|0;
 $24 = ($23|0)==(0|0);
 if ($24) {
  ___resumeException($21|0);
  // unreachable;
 }
 $25 = HEAP32[$2>>2]|0;
 $26 = ($25|0)==($23|0);
 if ($26) {
  $33 = $23;
 } else {
  $28 = $25;
  while(1) {
   $27 = ((($28)) + -12|0);
   HEAP32[$2>>2] = $27;
   $29 = ((($28)) + -8|0);
   $30 = HEAP32[$29>>2]|0;
   __ZNSt3__26__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EENS4_IS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($27,$30);
   $31 = HEAP32[$2>>2]|0;
   $32 = ($31|0)==($23|0);
   if ($32) {
    break;
   } else {
    $28 = $31;
   }
  }
  $$pre$i6 = HEAP32[$0>>2]|0;
  $33 = $$pre$i6;
 }
 __ZdlPv($33);
 ___resumeException($21|0);
 // unreachable;
}
function __ZN3osg15buffered_objectINSt3__23setINS1_12basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEENS1_4lessIS8_EENS6_IS8_EEEEED2Ev($0) {
 $0 = $0|0;
 var $$pre$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 }
 $3 = ((($0)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==($1|0);
 if ($5) {
  $12 = $1;
 } else {
  $7 = $4;
  while(1) {
   $6 = ((($7)) + -12|0);
   HEAP32[$3>>2] = $6;
   $8 = ((($7)) + -8|0);
   $9 = HEAP32[$8>>2]|0;
   __ZNSt3__26__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EENS4_IS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($6,$9);
   $10 = HEAP32[$3>>2]|0;
   $11 = ($10|0)==($1|0);
   if ($11) {
    break;
   } else {
    $7 = $10;
   }
  }
  $$pre$i = HEAP32[$0>>2]|0;
  $12 = $$pre$i;
 }
 __ZdlPv($12);
 return;
}
function __ZNSt3__26vectorINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS4_IS6_EEEC2Ej($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i = 0, $$pre$i$i$i = 0, $$pre$i6 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = 0;
 $2 = ((($0)) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = ((($0)) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = ($1|0)==(0);
 if ($4) {
  return;
 }
 $5 = ($1>>>0)>(357913941);
 if ($5) {
  __THREW__ = 0;
  invoke_vi(3307,($0|0));
  $6 = __THREW__; __THREW__ = 0;
 } else {
  $7 = ($1*12)|0;
  __THREW__ = 0;
  $8 = (invoke_ii(3276,($7|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   HEAP32[$2>>2] = $8;
   HEAP32[$0>>2] = $8;
   $11 = (($8) + (($1*12)|0)|0);
   $12 = ((($0)) + 8|0);
   HEAP32[$12>>2] = $11;
   $$0$i = $1;$13 = $8;
   while(1) {
    ;HEAP32[$13>>2]=0|0;HEAP32[$13+4>>2]=0|0;HEAP32[$13+8>>2]=0|0;
    $14 = HEAP32[$2>>2]|0;
    $15 = ((($14)) + 12|0);
    HEAP32[$2>>2] = $15;
    $16 = (($$0$i) + -1)|0;
    $17 = ($16|0)==(0);
    if ($17) {
     break;
    } else {
     $$0$i = $16;$13 = $15;
    }
   }
   return;
  }
 }
 $18 = ___cxa_find_matching_catch_2()|0;
 $19 = tempRet0;
 $20 = HEAP32[$0>>2]|0;
 $21 = ($20|0)==(0|0);
 if ($21) {
  ___resumeException($18|0);
  // unreachable;
 }
 $22 = HEAP32[$2>>2]|0;
 $23 = ($22|0)==($20|0);
 if ($23) {
  $32 = $20;
 } else {
  $25 = $22;
  while(1) {
   $24 = ((($25)) + -12|0);
   HEAP32[$2>>2] = $24;
   $26 = ((($24)) + 11|0);
   $27 = HEAP8[$26>>0]|0;
   $28 = ($27<<24>>24)<(0);
   if ($28) {
    $31 = HEAP32[$24>>2]|0;
    __ZdlPv($31);
    $$pre$i$i$i = HEAP32[$2>>2]|0;
    $29 = $$pre$i$i$i;
   } else {
    $29 = $24;
   }
   $30 = ($29|0)==($20|0);
   if ($30) {
    break;
   } else {
    $25 = $29;
   }
  }
  $$pre$i6 = HEAP32[$0>>2]|0;
  $32 = $$pre$i6;
 }
 __ZdlPv($32);
 ___resumeException($18|0);
 // unreachable;
}
function __ZN3osg15buffered_objectINSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEED2Ev($0) {
 $0 = $0|0;
 var $$pre$i = 0, $$pre$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 }
 $3 = ((($0)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==($1|0);
 if ($5) {
  $14 = $1;
 } else {
  $7 = $4;
  while(1) {
   $6 = ((($7)) + -12|0);
   HEAP32[$3>>2] = $6;
   $8 = ((($6)) + 11|0);
   $9 = HEAP8[$8>>0]|0;
   $10 = ($9<<24>>24)<(0);
   if ($10) {
    $13 = HEAP32[$6>>2]|0;
    __ZdlPv($13);
    $$pre$i$i$i = HEAP32[$3>>2]|0;
    $11 = $$pre$i$i$i;
   } else {
    $11 = $6;
   }
   $12 = ($11|0)==($1|0);
   if ($12) {
    break;
   } else {
    $7 = $11;
   }
  }
  $$pre$i = HEAP32[$0>>2]|0;
  $14 = $$pre$i;
 }
 __ZdlPv($14);
 return;
}
function __ZN3osg27getGLExtensionDisableStringEv() {
 var $$016$i$i = 0, $$017$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[206048]|0;
 $1 = ($0<<24>>24)==(0);
 if ($1) {
  $2 = (___cxa_guard_acquire(206048)|0);
  $3 = ($2|0)==(0);
  if (!($3)) {
   $4 = (_getenv((128924|0))|0);
   HEAP32[52091] = $4;
  }
 }
 $5 = HEAP8[206056]|0;
 $6 = ($5<<24>>24)==(0);
 if (!($6)) {
  return (208368|0);
 }
 $7 = (___cxa_guard_acquire(206056)|0);
 $8 = ($7|0)==(0);
 if ($8) {
  return (208368|0);
 }
 $9 = HEAP32[52091]|0;
 $10 = ($9|0)!=(0|0);
 $11 = $10 ? $9 : 128949;
 ;HEAP32[208368>>2]=0|0;HEAP32[208368+4>>2]=0|0;HEAP32[208368+8>>2]=0|0;
 $12 = (_strlen($11)|0);
 $13 = ($12>>>0)>(4294967279);
 if ($13) {
  __THREW__ = 0;
  invoke_vi(3367,(208368|0));
  $14 = __THREW__; __THREW__ = 0;
  $25 = ___cxa_find_matching_catch_2()|0;
  $26 = tempRet0;
  ___resumeException($25|0);
  // unreachable;
 }
 $15 = ($12>>>0)<(11);
 do {
  if ($15) {
   $22 = $12&255;
   HEAP8[(208379)>>0] = $22;
   $23 = ($12|0)==(0);
   if ($23) {
    $$017$i$i = 208368;
   } else {
    $$016$i$i = 208368;
    label = 12;
   }
  } else {
   $16 = (($12) + 16)|0;
   $17 = $16 & -16;
   __THREW__ = 0;
   $18 = (invoke_ii(3276,($17|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if ($20) {
    $25 = ___cxa_find_matching_catch_2()|0;
    $26 = tempRet0;
    ___resumeException($25|0);
    // unreachable;
   } else {
    HEAP32[52092] = $18;
    $21 = $17 | -2147483648;
    HEAP32[(208376)>>2] = $21;
    HEAP32[(208372)>>2] = $12;
    $$016$i$i = $18;
    label = 12;
    break;
   }
  }
 } while(0);
 if ((label|0) == 12) {
  _memcpy(($$016$i$i|0),($11|0),($12|0))|0;
  $$017$i$i = $$016$i$i;
 }
 $24 = (($$017$i$i) + ($12)|0);
 HEAP8[$24>>0] = 0;
 (___cxa_atexit((3252|0),(208368|0),(___dso_handle|0))|0);
 return (208368|0);
}
function __ZNSt3__26vectorIN3osg7ref_ptrINS1_12GLExtensionsEEENS_9allocatorIS4_EEEC2Ej($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$pre$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = 0;
 $2 = ((($0)) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = ((($0)) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = ($1|0)==(0);
 if ($4) {
  return;
 }
 $5 = ($1>>>0)>(1073741823);
 if ($5) {
  __THREW__ = 0;
  invoke_vi(3307,($0|0));
  $6 = __THREW__; __THREW__ = 0;
 } else {
  $7 = $1 << 2;
  __THREW__ = 0;
  $8 = (invoke_ii(3276,($7|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   HEAP32[$0>>2] = $8;
   $11 = (($8) + ($1<<2)|0);
   $12 = ((($0)) + 8|0);
   HEAP32[$12>>2] = $11;
   _memset(($8|0),0,($7|0))|0;
   HEAP32[$2>>2] = $11;
   return;
  }
 }
 $13 = ___cxa_find_matching_catch_2()|0;
 $14 = tempRet0;
 $15 = HEAP32[$0>>2]|0;
 $16 = ($15|0)==(0|0);
 if ($16) {
  ___resumeException($13|0);
  // unreachable;
 }
 $17 = HEAP32[$2>>2]|0;
 $18 = ($17|0)==($15|0);
 do {
  if ($18) {
   $32 = $15;
  } else {
   $20 = $17;
   while(1) {
    $19 = ((($20)) + -4|0);
    HEAP32[$2>>2] = $19;
    $21 = HEAP32[$19>>2]|0;
    $22 = ($21|0)==(0|0);
    if (!($22)) {
     $23 = ((($21)) + 8|0);
     $24 = HEAP32[$23>>2]|0;HEAP32[$23>>2] = (($24-1)|0);
     $25 = ($24|0)==(1);
     if ($25) {
      __THREW__ = 0;
      invoke_viii(3262,($21|0),1,1);
      $26 = __THREW__; __THREW__ = 0;
      $27 = $26&1;
      if ($27) {
       label = 12;
       break;
      }
     }
    }
    HEAP32[$19>>2] = 0;
    $28 = HEAP32[$2>>2]|0;
    $29 = ($28|0)==($15|0);
    if ($29) {
     label = 13;
     break;
    } else {
     $20 = $28;
    }
   }
   if ((label|0) == 12) {
    $30 = ___cxa_find_matching_catch_2()|0;
    $31 = tempRet0;
    ___cxa_call_unexpected(($30|0));
    // unreachable;
   }
   else if ((label|0) == 13) {
    $$pre$i = HEAP32[$0>>2]|0;
    $32 = $$pre$i;
    break;
   }
  }
 } while(0);
 __ZdlPv($32);
 ___resumeException($13|0);
 // unreachable;
}
function __ZN3osg15buffered_objectINS_7ref_ptrINS_12GLExtensionsEEEED2Ev($0) {
 $0 = $0|0;
 var $$pre$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 }
 $3 = ((($0)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==($1|0);
 do {
  if ($5) {
   $19 = $1;
  } else {
   $7 = $4;
   while(1) {
    $6 = ((($7)) + -4|0);
    HEAP32[$3>>2] = $6;
    $8 = HEAP32[$6>>2]|0;
    $9 = ($8|0)==(0|0);
    if (!($9)) {
     $10 = ((($8)) + 8|0);
     $11 = HEAP32[$10>>2]|0;HEAP32[$10>>2] = (($11-1)|0);
     $12 = ($11|0)==(1);
     if ($12) {
      __THREW__ = 0;
      invoke_viii(3262,($8|0),1,1);
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if ($14) {
       label = 7;
       break;
      }
     }
    }
    HEAP32[$6>>2] = 0;
    $15 = HEAP32[$3>>2]|0;
    $16 = ($15|0)==($1|0);
    if ($16) {
     label = 8;
     break;
    } else {
     $7 = $15;
    }
   }
   if ((label|0) == 7) {
    $17 = ___cxa_find_matching_catch_2()|0;
    $18 = tempRet0;
    ___cxa_call_unexpected(($17|0));
    // unreachable;
   }
   else if ((label|0) == 8) {
    $$pre$i = HEAP32[$0>>2]|0;
    $19 = $$pre$i;
    break;
   }
  }
 } while(0);
 __ZdlPv($19);
 return;
}
function __ZN3osg18getGLVersionNumberEv() {
 var $$0 = 0.0, $0 = 0, $1 = 0, $2 = 0.0, $3 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_glGetString(7938)|0);
 $1 = ($0|0)==(0|0);
 if ($1) {
  $$0 = 0.0;
  return (+$$0);
 }
 $2 = (+__ZN3osg17findAsciiToDoubleEPKc($0));
 $3 = $2;
 $$0 = $3;
 return (+$$0);
}
function __ZN3osg22isGLExtensionSupportedEjPKc($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__ZN3osg31isGLExtensionOrVersionSupportedEjPKcf($0,$1,3.4028234663852886E+38)|0);
 return ($2|0);
}
function __ZN3osg31isGLExtensionOrVersionSupportedEjPKcf($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = +$2;
 var $$ = 0, $$0$i = 0.0, $$0$i$i$i = 0, $$0105$in220225 = 0, $$0109$lcssa = 0, $$0109268 = 0, $$0110314 = 0, $$0116$ = 0, $$0116312 = 0, $$014$i$i = 0, $$016$i$i = 0, $$016$i$i157 = 0, $$017$i$i = 0, $$017$i$i158 = 0, $$01723$i$i = 0, $$021$lcssa$i$i = 0, $$021$ph$i$i = 0, $$02122$i$i = 0, $$023$i$i = 0, $$02729$i$i$i = 0;
 var $$02729$i$i$i186 = 0, $$1$i$i223 = 0, $$1111 = 0, $$1113 = 0, $$1117 = 0, $$1122 = 0, $$128 = 0, $$2$i$i$i190 = 0, $$2108 = 0, $$2114 = 0, $$2123 = 0, $$3 = 0, $$3119 = 0, $$4 = 0, $$4120$off0227 = 0, $$4125 = 0, $$5 = 0, $$5126 = 0, $$pre = 0, $$pre$i = 0;
 var $$pre$i$i$i$i = 0, $$pre$i$i$i$i138 = 0, $$pre$i$i$i$i143 = 0, $$pre$i135 = 0, $$pre$pre$i = 0, $$pre$pre$i131 = 0, $$pre283 = 0, $$pre284 = 0, $$pre285 = 0, $$sroa$0205$0$be = 0, $$sroa$0205$0267 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0;
 var $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0;
 var $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0;
 var $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0;
 var $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0;
 var $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0;
 var $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0;
 var $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0;
 var $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0;
 var $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0;
 var $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0;
 var $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0;
 var $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0;
 var $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0;
 var $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0;
 var $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0;
 var $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0;
 var $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0;
 var $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0;
 var $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0;
 var $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0;
 var $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0;
 var $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0;
 var $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0.0, $65 = 0.0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index4Z2D = 0, $eh$lpad$body$indexZ2D = 0, $eh$lpad$body150$index9Z2D = 0, $eh$lpad$body150$indexZ2D = 0, $extract$t = 0, $or$cond = 0, $or$cond237 = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i$i$i132 = 0, $scevgep25$i$i = 0, $scevgep5$i$i$i$i = 0, $scevgep5$i$i$i$i133 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(112|0);
 $3 = sp + 104|0;
 $4 = sp + 100|0;
 $5 = sp + 96|0;
 $6 = sp + 92|0;
 $7 = sp + 88|0;
 $8 = sp + 84|0;
 $9 = sp + 80|0;
 $10 = sp + 76|0;
 $11 = sp + 72|0;
 $12 = sp + 60|0;
 $13 = sp + 48|0;
 $14 = sp + 36|0;
 $15 = sp + 24|0;
 $16 = sp + 12|0;
 $17 = sp;
 $18 = HEAP32[(208284)>>2]|0;
 $19 = HEAP32[52070]|0;
 $20 = (($18) - ($19))|0;
 $21 = (($20|0) / 12)&-1;
 $22 = ($21>>>0)>($0>>>0);
 do {
  if (!($22)) {
   $23 = (($0) + 1)|0;
   $24 = ($23>>>0)>($21>>>0);
   $25 = $19;
   $26 = $18;
   if ($24) {
    $27 = (($23) - ($21))|0;
    __ZNSt3__26vectorINS_3setINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS7_EENS5_IS7_EEEENS5_ISB_EEE8__appendEj(208280,$27);
    break;
   }
   $28 = ($23>>>0)<($21>>>0);
   if ($28) {
    $29 = (($25) + (($23*12)|0)|0);
    $30 = ($26|0)==($29|0);
    if (!($30)) {
     $32 = $26;
     while(1) {
      $31 = ((($32)) + -12|0);
      HEAP32[(208284)>>2] = $31;
      $33 = ((($32)) + -8|0);
      $34 = HEAP32[$33>>2]|0;
      __ZNSt3__26__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EENS4_IS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($31,$34);
      $35 = HEAP32[(208284)>>2]|0;
      $36 = ($35|0)==($29|0);
      if ($36) {
       break;
      } else {
       $32 = $35;
      }
     }
    }
   }
  }
 } while(0);
 $37 = HEAP32[52070]|0;
 $38 = (($37) + (($0*12)|0)|0);
 $39 = HEAP32[(208296)>>2]|0;
 $40 = HEAP32[52073]|0;
 $41 = (($39) - ($40))|0;
 $42 = (($41|0) / 12)&-1;
 $43 = ($42>>>0)>($0>>>0);
 do {
  if (!($43)) {
   $44 = (($0) + 1)|0;
   $45 = ($44>>>0)>($42>>>0);
   $46 = $40;
   $47 = $39;
   if ($45) {
    $48 = (($44) - ($42))|0;
    __ZNSt3__26vectorINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS4_IS6_EEE8__appendEj(208292,$48);
    break;
   }
   $49 = ($44>>>0)<($42>>>0);
   if ($49) {
    $50 = (($46) + (($44*12)|0)|0);
    $51 = ($47|0)==($50|0);
    if (!($51)) {
     $53 = $47;
     while(1) {
      $52 = ((($53)) + -12|0);
      HEAP32[(208296)>>2] = $52;
      $54 = ((($52)) + 11|0);
      $55 = HEAP8[$54>>0]|0;
      $56 = ($55<<24>>24)<(0);
      if ($56) {
       $59 = HEAP32[$52>>2]|0;
       __ZdlPv($59);
       $$pre$i$i$i$i = HEAP32[(208296)>>2]|0;
       $57 = $$pre$i$i$i$i;
      } else {
       $57 = $52;
      }
      $58 = ($57|0)==($50|0);
      if ($58) {
       break;
      } else {
       $53 = $57;
      }
     }
    }
   }
  }
 } while(0);
 $60 = HEAP32[52073]|0;
 $61 = (($60) + (($0*12)|0)|0);
 $62 = (_glGetString(7938)|0);
 $63 = ($62|0)==(0|0);
 if ($63) {
  $$0$i = 0.0;
 } else {
  $64 = (+__ZN3osg17findAsciiToDoubleEPKc($62));
  $65 = $64;
  $$0$i = $65;
 }
 $66 = !($$0$i >= $2);
 do {
  if ($66) {
   $67 = HEAP32[(208308)>>2]|0;
   $68 = HEAP32[52076]|0;
   $69 = (($67) - ($68))|0;
   $70 = $69 >> 2;
   $71 = ($70>>>0)>($0>>>0);
   $72 = $68;
   if ($71) {
    $87 = $72;$92 = $68;
   } else {
    $73 = (($0) + 1)|0;
    HEAP32[$11>>2] = 0;
    $74 = ($73>>>0)>($70>>>0);
    $75 = $67;
    if ($74) {
     $76 = (($73) - ($70))|0;
     __ZNSt3__26vectorIiNS_9allocatorIiEEE8__appendEjRKi(208304,$76,$11);
     $$pre$pre$i = HEAP32[52076]|0;
     $77 = $$pre$pre$i;
     $$pre$i = $$pre$pre$i;$577 = $77;
    } else {
     $78 = ($73>>>0)<($70>>>0);
     if ($78) {
      $79 = (($72) + ($73<<2)|0);
      $80 = ($75|0)==($79|0);
      if ($80) {
       $$pre$i = $72;$577 = $68;
      } else {
       $scevgep$i$i$i$i = ((($75)) + -4|0);
       $81 = $scevgep$i$i$i$i;
       $82 = $79;
       $83 = (($81) - ($82))|0;
       $84 = $83 >>> 2;
       $85 = $84 ^ -1;
       $scevgep5$i$i$i$i = (($75) + ($85<<2)|0);
       HEAP32[(208308)>>2] = $scevgep5$i$i$i$i;
       $$pre$i = $72;$577 = $68;
      }
     } else {
      $$pre$i = $72;$577 = $68;
     }
    }
    $87 = $$pre$i;$92 = $577;
   }
   $86 = (($87) + ($0<<2)|0);
   $88 = HEAP32[$86>>2]|0;
   $89 = ($88|0)==(0);
   L36: do {
    if ($89) {
     $90 = HEAP32[(208308)>>2]|0;
     $91 = (($90) - ($92))|0;
     $93 = $91 >> 2;
     $94 = ($93>>>0)>($0>>>0);
     $95 = $92;
     if ($94) {
      $109 = $95;
     } else {
      $96 = (($0) + 1)|0;
      HEAP32[$10>>2] = 0;
      $97 = ($96>>>0)>($93>>>0);
      $98 = $90;
      if ($97) {
       $99 = (($96) - ($93))|0;
       __ZNSt3__26vectorIiNS_9allocatorIiEEE8__appendEjRKi(208304,$99,$10);
       $$pre$pre$i131 = HEAP32[52076]|0;
       $$pre$i135 = $$pre$pre$i131;
      } else {
       $100 = ($96>>>0)<($93>>>0);
       if ($100) {
        $101 = (($95) + ($96<<2)|0);
        $102 = ($98|0)==($101|0);
        if ($102) {
         $$pre$i135 = $95;
        } else {
         $scevgep$i$i$i$i132 = ((($98)) + -4|0);
         $103 = $scevgep$i$i$i$i132;
         $104 = $101;
         $105 = (($103) - ($104))|0;
         $106 = $105 >>> 2;
         $107 = $106 ^ -1;
         $scevgep5$i$i$i$i133 = (($98) + ($107<<2)|0);
         HEAP32[(208308)>>2] = $scevgep5$i$i$i$i133;
         $$pre$i135 = $95;
        }
       } else {
        $$pre$i135 = $95;
       }
      }
      $109 = $$pre$i135;
     }
     $108 = (($109) + ($0<<2)|0);
     HEAP32[$108>>2] = 1;
     $110 = (_glGetString(7937)|0);
     $111 = ($110|0)!=(0|0);
     $112 = $111 ? $110 : 221531;
     (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($61,$112)|0);
     $113 = (_glGetString(7939)|0);
     $114 = ($113|0)==(0|0);
     if ($114) {
      $$3 = 0;
      STACKTOP = sp;return ($$3|0);
     }
     $115 = (_strchr($113,32)|0);
     $116 = ($115|0)==(0|0);
     L50: do {
      if ($116) {
       $$0109$lcssa = $113;
      } else {
       $117 = ((($12)) + 11|0);
       $118 = (((($37) + (($0*12)|0)|0)) + 4|0);
       $119 = (((($37) + (($0*12)|0)|0)) + 8|0);
       $120 = ((($12)) + 8|0);
       $121 = ((($12)) + 4|0);
       $$0109268 = $113;$123 = $115;
       while(1) {
        ;HEAP32[$12>>2]=0|0;HEAP32[$12+4>>2]=0|0;HEAP32[$12+8>>2]=0|0;
        $122 = $$0109268;
        $124 = $123;
        $125 = (($124) - ($122))|0;
        $126 = ($125>>>0)>(4294967279);
        if ($126) {
         label = 37;
         break;
        }
        $127 = ($125>>>0)<(11);
        if ($127) {
         $128 = $125&255;
         HEAP8[$117>>0] = $128;
         $$021$ph$i$i = $12;
        } else {
         $129 = (($125) + 16)|0;
         $130 = $129 & -16;
         $131 = (__Znwj($130)|0);
         HEAP32[$12>>2] = $131;
         $132 = $130 | -2147483648;
         HEAP32[$120>>2] = $132;
         HEAP32[$121>>2] = $125;
         $$021$ph$i$i = $131;
        }
        $133 = ($$0109268|0)==($123|0);
        if ($133) {
         $$021$lcssa$i$i = $$021$ph$i$i;
        } else {
         $$02122$i$i = $$021$ph$i$i;$$023$i$i = $$0109268;
         while(1) {
          $134 = HEAP8[$$023$i$i>>0]|0;
          HEAP8[$$02122$i$i>>0] = $134;
          $135 = ((($$023$i$i)) + 1|0);
          $136 = ((($$02122$i$i)) + 1|0);
          $137 = ($135|0)==($123|0);
          if ($137) {
           break;
          } else {
           $$02122$i$i = $136;$$023$i$i = $135;
          }
         }
         $scevgep25$i$i = (($$021$ph$i$i) + ($125)|0);
         $$021$lcssa$i$i = $scevgep25$i$i;
        }
        HEAP8[$$021$lcssa$i$i>>0] = 0;
        __THREW__ = 0;
        $138 = (invoke_iiii(3784,($38|0),($9|0),($12|0))|0);
        $139 = __THREW__; __THREW__ = 0;
        $140 = $139&1;
        if ($140) {
         label = 55;
         break;
        }
        $141 = HEAP32[$138>>2]|0;
        $142 = ($141|0)==(0|0);
        if ($142) {
         __THREW__ = 0;
         $143 = (invoke_ii(3276,28)|0);
         $144 = __THREW__; __THREW__ = 0;
         $145 = $144&1;
         if ($145) {
          label = 55;
          break;
         }
         $146 = ((($143)) + 16|0);
         __THREW__ = 0;
         invoke_vii(3457,($146|0),($12|0));
         $147 = __THREW__; __THREW__ = 0;
         $148 = $147&1;
         if ($148) {
          label = 48;
          break;
         }
         $151 = HEAP32[$9>>2]|0;
         HEAP32[$143>>2] = 0;
         $152 = ((($143)) + 4|0);
         HEAP32[$152>>2] = 0;
         $153 = ((($143)) + 8|0);
         HEAP32[$153>>2] = $151;
         HEAP32[$138>>2] = $143;
         $154 = HEAP32[$38>>2]|0;
         $155 = HEAP32[$154>>2]|0;
         $156 = ($155|0)==(0|0);
         if ($156) {
          $159 = $143;
         } else {
          $157 = $155;
          HEAP32[$38>>2] = $157;
          $$pre$i$i$i$i138 = HEAP32[$138>>2]|0;
          $159 = $$pre$i$i$i$i138;
         }
         $158 = HEAP32[$118>>2]|0;
         __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($158,$159);
         $160 = HEAP32[$119>>2]|0;
         $161 = (($160) + 1)|0;
         HEAP32[$119>>2] = $161;
        }
        $162 = HEAP8[$117>>0]|0;
        $163 = ($162<<24>>24)<(0);
        if ($163) {
         $164 = HEAP32[$12>>2]|0;
         __ZdlPv($164);
        }
        $165 = ((($123)) + 1|0);
        $166 = (_strchr($165,32)|0);
        $167 = ($166|0)==(0|0);
        if ($167) {
         $$0109$lcssa = $165;
         break L50;
        } else {
         $$0109268 = $165;$123 = $166;
        }
       }
       if ((label|0) == 37) {
        __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv($12);
        // unreachable;
       }
       else if ((label|0) == 48) {
        $149 = ___cxa_find_matching_catch_2()|0;
        $150 = tempRet0;
        __ZdlPv($143);
        $eh$lpad$body$index4Z2D = $150;$eh$lpad$body$indexZ2D = $149;
       }
       else if ((label|0) == 55) {
        $168 = ___cxa_find_matching_catch_2()|0;
        $169 = tempRet0;
        $eh$lpad$body$index4Z2D = $169;$eh$lpad$body$indexZ2D = $168;
       }
       $170 = HEAP8[$117>>0]|0;
       $171 = ($170<<24>>24)<(0);
       if ($171) {
        $172 = HEAP32[$12>>2]|0;
        __ZdlPv($172);
       }
       $$5 = $eh$lpad$body$indexZ2D;$$5126 = $eh$lpad$body$index4Z2D;
       ___resumeException($$5|0);
       // unreachable;
      }
     } while(0);
     $173 = HEAP8[$$0109$lcssa>>0]|0;
     $174 = ($173<<24>>24)==(0);
     L86: do {
      if (!($174)) {
       ;HEAP32[$13>>2]=0|0;HEAP32[$13+4>>2]=0|0;HEAP32[$13+8>>2]=0|0;
       $175 = (_strlen($$0109$lcssa)|0);
       $176 = ($175>>>0)>(4294967279);
       if ($176) {
        __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv($13);
        // unreachable;
       }
       $177 = ($175>>>0)<(11);
       if ($177) {
        $184 = $175&255;
        $185 = ((($13)) + 11|0);
        HEAP8[$185>>0] = $184;
        $186 = ($175|0)==(0);
        if ($186) {
         $$017$i$i = $13;
        } else {
         $$016$i$i = $13;
         label = 65;
        }
       } else {
        $178 = (($175) + 16)|0;
        $179 = $178 & -16;
        $180 = (__Znwj($179)|0);
        HEAP32[$13>>2] = $180;
        $181 = $179 | -2147483648;
        $182 = ((($13)) + 8|0);
        HEAP32[$182>>2] = $181;
        $183 = ((($13)) + 4|0);
        HEAP32[$183>>2] = $175;
        $$016$i$i = $180;
        label = 65;
       }
       if ((label|0) == 65) {
        _memcpy(($$016$i$i|0),($$0109$lcssa|0),($175|0))|0;
        $$017$i$i = $$016$i$i;
       }
       $187 = (($$017$i$i) + ($175)|0);
       HEAP8[$187>>0] = 0;
       __THREW__ = 0;
       $188 = (invoke_iiii(3784,($38|0),($8|0),($13|0))|0);
       $189 = __THREW__; __THREW__ = 0;
       $190 = $189&1;
       do {
        if ($190) {
         label = 77;
        } else {
         $191 = HEAP32[$188>>2]|0;
         $192 = ($191|0)==(0|0);
         if ($192) {
          __THREW__ = 0;
          $193 = (invoke_ii(3276,28)|0);
          $194 = __THREW__; __THREW__ = 0;
          $195 = $194&1;
          if ($195) {
           label = 77;
           break;
          }
          $196 = ((($193)) + 16|0);
          __THREW__ = 0;
          invoke_vii(3457,($196|0),($13|0));
          $197 = __THREW__; __THREW__ = 0;
          $198 = $197&1;
          if ($198) {
           $199 = ___cxa_find_matching_catch_2()|0;
           $200 = tempRet0;
           __ZdlPv($193);
           $eh$lpad$body150$index9Z2D = $200;$eh$lpad$body150$indexZ2D = $199;
           break;
          }
          $201 = HEAP32[$8>>2]|0;
          HEAP32[$193>>2] = 0;
          $202 = ((($193)) + 4|0);
          HEAP32[$202>>2] = 0;
          $203 = ((($193)) + 8|0);
          HEAP32[$203>>2] = $201;
          HEAP32[$188>>2] = $193;
          $204 = HEAP32[$38>>2]|0;
          $205 = HEAP32[$204>>2]|0;
          $206 = ($205|0)==(0|0);
          if ($206) {
           $210 = $193;
          } else {
           $207 = $205;
           HEAP32[$38>>2] = $207;
           $$pre$i$i$i$i143 = HEAP32[$188>>2]|0;
           $210 = $$pre$i$i$i$i143;
          }
          $208 = (((($37) + (($0*12)|0)|0)) + 4|0);
          $209 = HEAP32[$208>>2]|0;
          __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($209,$210);
          $211 = (((($37) + (($0*12)|0)|0)) + 8|0);
          $212 = HEAP32[$211>>2]|0;
          $213 = (($212) + 1)|0;
          HEAP32[$211>>2] = $213;
         }
         $214 = ((($13)) + 11|0);
         $215 = HEAP8[$214>>0]|0;
         $216 = ($215<<24>>24)<(0);
         if ($216) {
          $217 = HEAP32[$13>>2]|0;
          __ZdlPv($217);
         }
         break L86;
        }
       } while(0);
       if ((label|0) == 77) {
        $218 = ___cxa_find_matching_catch_2()|0;
        $219 = tempRet0;
        $eh$lpad$body150$index9Z2D = $219;$eh$lpad$body150$indexZ2D = $218;
       }
       $220 = ((($13)) + 11|0);
       $221 = HEAP8[$220>>0]|0;
       $222 = ($221<<24>>24)<(0);
       if ($222) {
        $223 = HEAP32[$13>>2]|0;
        __ZdlPv($223);
       }
       $$5 = $eh$lpad$body150$indexZ2D;$$5126 = $eh$lpad$body150$index9Z2D;
       ___resumeException($$5|0);
       // unreachable;
      }
     } while(0);
     $224 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
     do {
      if ($224) {
       $225 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
       $226 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($225,128965,60)|0);
       $227 = HEAP32[$226>>2]|0;
       $228 = ((($227)) + -12|0);
       $229 = HEAP32[$228>>2]|0;
       $230 = (($226) + ($229)|0);
       __ZNKSt3__28ios_base6getlocEv($7,$230);
       __THREW__ = 0;
       $231 = (invoke_iii(3255,($7|0),(215188|0))|0);
       $232 = __THREW__; __THREW__ = 0;
       $233 = $232&1;
       if (!($233)) {
        $234 = HEAP32[$231>>2]|0;
        $235 = ((($234)) + 28|0);
        $236 = HEAP32[$235>>2]|0;
        __THREW__ = 0;
        $237 = (invoke_iii($236|0,($231|0),10)|0);
        $238 = __THREW__; __THREW__ = 0;
        $239 = $238&1;
        if (!($239)) {
         __ZNSt3__26localeD2Ev($7);
         (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($226,$237)|0);
         (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($226)|0);
         break;
        }
       }
       $240 = ___cxa_find_matching_catch_2()|0;
       $241 = tempRet0;
       __THREW__ = 0;
       invoke_vi(3263,($7|0));
       $242 = __THREW__; __THREW__ = 0;
       $243 = $242&1;
       if ($243) {
        $244 = ___cxa_find_matching_catch_3(0|0)|0;
        $245 = tempRet0;
        ___clang_call_terminate($244);
        // unreachable;
       } else {
        ___resumeException($240|0);
        // unreachable;
       }
      }
     } while(0);
     $246 = HEAP32[$38>>2]|0;
     $247 = (((($37) + (($0*12)|0)|0)) + 4|0);
     $248 = ($246|0)==($247|0);
     if (!($248)) {
      $$sroa$0205$0267 = $246;
      while(1) {
       $249 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
       if ($249) {
        $250 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
        $251 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($250,129026,4)|0);
        $252 = ((($$sroa$0205$0267)) + 16|0);
        $253 = ((($252)) + 11|0);
        $254 = HEAP8[$253>>0]|0;
        $255 = ($254<<24>>24)<(0);
        $256 = HEAP32[$252>>2]|0;
        $257 = $255 ? $256 : $252;
        $258 = ((($$sroa$0205$0267)) + 20|0);
        $259 = HEAP32[$258>>2]|0;
        $260 = $254&255;
        $261 = $255 ? $259 : $260;
        $262 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($251,$257,$261)|0);
        $263 = HEAP32[$262>>2]|0;
        $264 = ((($263)) + -12|0);
        $265 = HEAP32[$264>>2]|0;
        $266 = (($262) + ($265)|0);
        __ZNKSt3__28ios_base6getlocEv($6,$266);
        __THREW__ = 0;
        $267 = (invoke_iii(3255,($6|0),(215188|0))|0);
        $268 = __THREW__; __THREW__ = 0;
        $269 = $268&1;
        if ($269) {
         break;
        }
        $270 = HEAP32[$267>>2]|0;
        $271 = ((($270)) + 28|0);
        $272 = HEAP32[$271>>2]|0;
        __THREW__ = 0;
        $273 = (invoke_iii($272|0,($267|0),10)|0);
        $274 = __THREW__; __THREW__ = 0;
        $275 = $274&1;
        if ($275) {
         break;
        }
        __ZNSt3__26localeD2Ev($6);
        (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($262,$273)|0);
        (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($262)|0);
       }
       $282 = ((($$sroa$0205$0267)) + 4|0);
       $283 = HEAP32[$282>>2]|0;
       $284 = ($283|0)==(0|0);
       if ($284) {
        $285 = ((($$sroa$0205$0267)) + 8|0);
        $286 = HEAP32[$285>>2]|0;
        $287 = HEAP32[$286>>2]|0;
        $288 = ($287|0)==($$sroa$0205$0267|0);
        if ($288) {
         $$sroa$0205$0$be = $286;
        } else {
         $293 = $285;
         while(1) {
          $292 = HEAP32[$293>>2]|0;
          $294 = ((($292)) + 8|0);
          $295 = HEAP32[$294>>2]|0;
          $296 = HEAP32[$295>>2]|0;
          $297 = ($296|0)==($292|0);
          if ($297) {
           $$sroa$0205$0$be = $295;
           break;
          } else {
           $293 = $294;
          }
         }
        }
       } else {
        $$0$i$i$i = $283;
        while(1) {
         $290 = HEAP32[$$0$i$i$i>>2]|0;
         $291 = ($290|0)==(0|0);
         if ($291) {
          break;
         } else {
          $$0$i$i$i = $290;
         }
        }
        $$sroa$0205$0$be = $$0$i$i$i;
       }
       $289 = ($$sroa$0205$0$be|0)==($247|0);
       if ($289) {
        break L36;
       } else {
        $$sroa$0205$0267 = $$sroa$0205$0$be;
       }
      }
      $276 = ___cxa_find_matching_catch_2()|0;
      $277 = tempRet0;
      __THREW__ = 0;
      invoke_vi(3263,($6|0));
      $278 = __THREW__; __THREW__ = 0;
      $279 = $278&1;
      if ($279) {
       $280 = ___cxa_find_matching_catch_3(0|0)|0;
       $281 = tempRet0;
       ___clang_call_terminate($280);
       // unreachable;
      } else {
       ___resumeException($276|0);
       // unreachable;
      }
     }
    }
   } while(0);
   ;HEAP32[$14>>2]=0|0;HEAP32[$14+4>>2]=0|0;HEAP32[$14+8>>2]=0|0;
   $298 = (_strlen($1)|0);
   $299 = ($298>>>0)>(4294967279);
   if ($299) {
    __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv($14);
    // unreachable;
   }
   $300 = ($298>>>0)<(11);
   if ($300) {
    $307 = $298&255;
    $308 = ((($14)) + 11|0);
    HEAP8[$308>>0] = $307;
    $309 = ($298|0)==(0);
    if ($309) {
     $$017$i$i158 = $14;
    } else {
     $$016$i$i157 = $14;
     label = 108;
    }
   } else {
    $301 = (($298) + 16)|0;
    $302 = $301 & -16;
    $303 = (__Znwj($302)|0);
    HEAP32[$14>>2] = $303;
    $304 = $302 | -2147483648;
    $305 = ((($14)) + 8|0);
    HEAP32[$305>>2] = $304;
    $306 = ((($14)) + 4|0);
    HEAP32[$306>>2] = $298;
    $$016$i$i157 = $303;
    label = 108;
   }
   if ((label|0) == 108) {
    _memcpy(($$016$i$i157|0),($1|0),($298|0))|0;
    $$017$i$i158 = $$016$i$i157;
   }
   $310 = (($$017$i$i158) + ($298)|0);
   HEAP8[$310>>0] = 0;
   __THREW__ = 0;
   $311 = (invoke_iii(3785,($38|0),($14|0))|0);
   $312 = __THREW__; __THREW__ = 0;
   $313 = $312&1;
   if ($313) {
    $320 = ___cxa_find_matching_catch_2()|0;
    $321 = tempRet0;
    $322 = ((($14)) + 11|0);
    $323 = HEAP8[$322>>0]|0;
    $324 = ($323<<24>>24)<(0);
    if ($324) {
     $325 = HEAP32[$14>>2]|0;
     __ZdlPv($325);
    }
    $$5 = $320;$$5126 = $321;
    ___resumeException($$5|0);
    // unreachable;
   }
   $314 = (((($37) + (($0*12)|0)|0)) + 4|0);
   $315 = ($311|0)==($314|0);
   $316 = ((($14)) + 11|0);
   $317 = HEAP8[$316>>0]|0;
   $318 = ($317<<24>>24)<(0);
   if ($318) {
    $319 = HEAP32[$14>>2]|0;
    __ZdlPv($319);
   }
   if ($315) {
    $326 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
    if ($326) {
     $553 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
     $554 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($553,129031,18)|0);
     $555 = (_strlen($1)|0);
     $556 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($554,$1,$555)|0);
     $557 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($556,129159,19)|0);
     $558 = HEAP32[$557>>2]|0;
     $559 = ((($558)) + -12|0);
     $560 = HEAP32[$559>>2]|0;
     $561 = (($557) + ($560)|0);
     __ZNKSt3__28ios_base6getlocEv($3,$561);
     __THREW__ = 0;
     $562 = (invoke_iii(3255,($3|0),(215188|0))|0);
     $563 = __THREW__; __THREW__ = 0;
     $564 = $563&1;
     if (!($564)) {
      $565 = HEAP32[$562>>2]|0;
      $566 = ((($565)) + 28|0);
      $567 = HEAP32[$566>>2]|0;
      __THREW__ = 0;
      $568 = (invoke_iii($567|0,($562|0),10)|0);
      $569 = __THREW__; __THREW__ = 0;
      $570 = $569&1;
      if (!($570)) {
       __ZNSt3__26localeD2Ev($3);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($557,$568)|0);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($557)|0);
       $$0105$in220225 = 0;$$4120$off0227 = 1;
       break;
      }
     }
     $571 = ___cxa_find_matching_catch_2()|0;
     $572 = tempRet0;
     __THREW__ = 0;
     invoke_vi(3263,($3|0));
     $573 = __THREW__; __THREW__ = 0;
     $574 = $573&1;
     if ($574) {
      $575 = ___cxa_find_matching_catch_3(0|0)|0;
      $576 = tempRet0;
      ___clang_call_terminate($575);
      // unreachable;
     } else {
      ___resumeException($571|0);
      // unreachable;
     }
    } else {
     $$0105$in220225 = 0;$$4120$off0227 = 1;
    }
   } else {
    label = 117;
   }
  } else {
   label = 117;
  }
 } while(0);
 L179: do {
  if ((label|0) == 117) {
   (__ZN3osg27getGLExtensionDisableStringEv()|0);
   $327 = HEAP8[(208379)>>0]|0;
   $328 = ($327<<24>>24)<(0);
   $329 = HEAP32[(208372)>>2]|0;
   $330 = $327&255;
   $331 = $328 ? $329 : $330;
   $332 = ($331|0)==(0);
   do {
    if ($332) {
     $345 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
     if (!($345)) {
      $$0105$in220225 = 1;$$4120$off0227 = 1;
      break L179;
     }
    } else {
     $333 = ((($15)) + 11|0);
     $334 = ((($15)) + 4|0);
     $335 = ((($61)) + 11|0);
     $336 = (((($60) + (($0*12)|0)|0)) + 4|0);
     $337 = ((($16)) + 11|0);
     $338 = ((($17)) + 11|0);
     $339 = ($327<<24>>24)<(0);
     $340 = HEAP32[52092]|0;
     $341 = $327&255;
     $342 = $339 ? $340 : 208368;
     $343 = $339 ? $329 : $341;
     $344 = (_strlen($1)|0);
     $$0110314 = 0;$$0116312 = 0;$346 = $344;$349 = $342;$351 = $343;
     L184: while(1) {
      $347 = ($346|0)==(0);
      if ($347) {
       $$1$i$i223 = $$0110314;
      } else {
       $348 = (($349) + ($$0110314)|0);
       $350 = (($349) + ($351)|0);
       $352 = $350;
       $353 = $348;
       $354 = (($352) - ($353))|0;
       $355 = ($354|0)<($346|0);
       if ($355) {
        $$3119 = $$0116312;
        label = 181;
        break;
       }
       $356 = HEAP8[$1>>0]|0;
       $357 = $356&255;
       $$02729$i$i$i = $348;$359 = $354;
       while(1) {
        $358 = (($359) - ($346))|0;
        $360 = (($358) + 1)|0;
        $361 = ($360|0)==(0);
        if ($361) {
         $$3119 = $$0116312;
         label = 181;
         break L184;
        }
        $362 = (_memchr($$02729$i$i$i,$357,$360)|0);
        $363 = ($362|0)==(0|0);
        if ($363) {
         $$3119 = $$0116312;
         label = 181;
         break L184;
        }
        $364 = (_memcmp($362,$1,$346)|0);
        $365 = ($364|0)==(0);
        if ($365) {
         break;
        }
        $366 = ((($362)) + 1|0);
        $367 = $366;
        $368 = (($352) - ($367))|0;
        $369 = ($368|0)<($346|0);
        if ($369) {
         $$3119 = $$0116312;
         label = 181;
         break L184;
        } else {
         $$02729$i$i$i = $366;$359 = $368;
        }
       }
       $370 = ($362|0)==($350|0);
       $371 = $362;
       $372 = $349;
       $373 = (($371) - ($372))|0;
       $374 = ($373|0)==(-1);
       $or$cond237 = $370 | $374;
       if ($or$cond237) {
        $$3119 = $$0116312;
        label = 181;
        break;
       } else {
        $$1$i$i223 = $373;
       }
      }
      $375 = (__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5rfindEcj(208368,58,$$1$i$i223)|0);
      $376 = (__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5rfindEcj(208368,59,$$1$i$i223)|0);
      $377 = ($375|0)==(-1);
      ;HEAP32[$15>>2]=0|0;HEAP32[$15+4>>2]=0|0;HEAP32[$15+8>>2]=0|0;
      do {
       if (!($377)) {
        $378 = ($376|0)==(-1);
        if ($378) {
         __THREW__ = 0;
         invoke_viiiii(3746,($16|0),(208368|0),0,($375|0),(208368|0));
         $379 = __THREW__; __THREW__ = 0;
         $380 = $379&1;
         if ($380) {
          label = 135;
          break L184;
         }
         __THREW__ = 0;
         (invoke_iii(3477,($15|0),($16|0))|0);
         $381 = __THREW__; __THREW__ = 0;
         $382 = $381&1;
         if ($382) {
          label = 136;
          break L184;
         }
         $383 = HEAP8[$337>>0]|0;
         $384 = ($383<<24>>24)<(0);
         if ($384) {
          $385 = HEAP32[$16>>2]|0;
          __ZdlPv($385);
         }
         break;
        }
        $393 = ($375>>>0)>($376>>>0);
        if ($393) {
         $394 = (($376) + 1)|0;
         $395 = (($375) + -1)|0;
         $396 = (($395) - ($376))|0;
         __THREW__ = 0;
         invoke_viiiii(3746,($17|0),(208368|0),($394|0),($396|0),(208368|0));
         $397 = __THREW__; __THREW__ = 0;
         $398 = $397&1;
         if ($398) {
          label = 145;
          break L184;
         }
         __THREW__ = 0;
         (invoke_iii(3477,($15|0),($17|0))|0);
         $399 = __THREW__; __THREW__ = 0;
         $400 = $399&1;
         if ($400) {
          label = 146;
          break L184;
         }
         $401 = HEAP8[$338>>0]|0;
         $402 = ($401<<24>>24)<(0);
         if ($402) {
          $403 = HEAP32[$17>>2]|0;
          __ZdlPv($403);
         }
        }
       }
      } while(0);
      $411 = HEAP8[$333>>0]|0;
      $412 = ($411<<24>>24)<(0);
      $413 = HEAP32[$334>>2]|0;
      $414 = $411&255;
      $415 = $412 ? $413 : $414;
      $416 = ($415|0)==(0);
      L213: do {
       if ($416) {
        $452 = $411;$455 = $413;
       } else {
        $417 = HEAP32[$15>>2]|0;
        $418 = $412 ? $417 : $15;
        $419 = (($418) + ($415)|0);
        $$01723$i$i = $418;
        while(1) {
         $420 = HEAP8[$$01723$i$i>>0]|0;
         $421 = ($420<<24>>24)==(32);
         if (!($421)) {
          label = 153;
          break;
         }
         $422 = ((($$01723$i$i)) + 1|0);
         $423 = ($422|0)==($419|0);
         if ($423) {
          label = 154;
          break;
         } else {
          $$01723$i$i = $422;
         }
        }
        L218: do {
         if ((label|0) == 153) {
          label = 0;
          $424 = $$01723$i$i;
          $425 = $418;
          $426 = (($424) - ($425))|0;
          switch ($426|0) {
          case -1:  {
           label = 154;
           break L218;
           break;
          }
          case 0:  {
           break L218;
           break;
          }
          default: {
          }
          }
          __THREW__ = 0;
          (invoke_iiii(3787,($15|0),0,($426|0))|0);
          $429 = __THREW__; __THREW__ = 0;
          $430 = $429&1;
          if ($430) {
           label = 162;
           break L184;
          }
         }
        } while(0);
        if ((label|0) == 154) {
         label = 0;
         __THREW__ = 0;
         (invoke_iii(3786,($15|0),(221531|0))|0);
         $427 = __THREW__; __THREW__ = 0;
         $428 = $427&1;
         if ($428) {
          label = 162;
          break L184;
         }
        }
        $431 = HEAP8[$333>>0]|0;
        $432 = ($431<<24>>24)<(0);
        $433 = HEAP32[$15>>2]|0;
        $434 = HEAP32[$334>>2]|0;
        $435 = $431&255;
        $436 = $432 ? $433 : $15;
        $437 = $432 ? $434 : $435;
        $438 = (($436) + ($437)|0);
        $$014$i$i = $438;
        while(1) {
         $439 = ($$014$i$i|0)==($436|0);
         if ($439) {
          $452 = $431;$455 = $434;
          break L213;
         }
         $440 = ((($$014$i$i)) + -1|0);
         $441 = HEAP8[$440>>0]|0;
         $442 = ($441<<24>>24)==(32);
         if ($442) {
          $$014$i$i = $440;
         } else {
          break;
         }
        }
        $443 = $440;
        $444 = $436;
        $445 = (($443) - ($444))|0;
        $446 = ($445|0)==(-1);
        if ($446) {
         $452 = $431;$455 = $434;
        } else {
         $447 = (($445) + 1)|0;
         __THREW__ = 0;
         (invoke_iiii(3787,($15|0),($447|0),-1)|0);
         $448 = __THREW__; __THREW__ = 0;
         $449 = $448&1;
         if ($449) {
          label = 162;
          break L184;
         }
         $$pre284 = HEAP8[$333>>0]|0;
         $$pre285 = HEAP32[$334>>2]|0;
         $452 = $$pre284;$455 = $$pre285;
        }
       }
      } while(0);
      $453 = ($452<<24>>24)<(0);
      $454 = $452&255;
      $456 = $453 ? $455 : $454;
      $457 = ($456|0)==(0);
      if ($457) {
       $$1111 = $$1$i$i223;$$1117 = 1;$$2108 = 0;
      } else {
       $458 = HEAP8[$335>>0]|0;
       $459 = ($458<<24>>24)<(0);
       if ($459) {
        $460 = HEAP32[$61>>2]|0;
        $461 = HEAP32[$336>>2]|0;
        $466 = $460;$467 = $461;
       } else {
        $462 = $458&255;
        $466 = $61;$467 = $462;
       }
       $463 = HEAP32[$15>>2]|0;
       $464 = $453 ? $463 : $15;
       $465 = (($466) + ($467)|0);
       $468 = $465;
       $469 = $466;
       $470 = ($467|0)<($456|0);
       L237: do {
        if ($470) {
         $$2$i$i$i190 = $465;
        } else {
         $471 = HEAP8[$464>>0]|0;
         $472 = $471&255;
         $$02729$i$i$i186 = $466;$474 = $467;
         while(1) {
          $473 = (($474) - ($456))|0;
          $475 = (($473) + 1)|0;
          $476 = ($475|0)==(0);
          if ($476) {
           $$2$i$i$i190 = $465;
           break L237;
          }
          $477 = (_memchr($$02729$i$i$i186,$472,$475)|0);
          $478 = ($477|0)==(0|0);
          if ($478) {
           $$2$i$i$i190 = $465;
           break L237;
          }
          $479 = (_memcmp($477,$464,$456)|0);
          $480 = ($479|0)==(0);
          if ($480) {
           $$2$i$i$i190 = $477;
           break L237;
          }
          $481 = ((($477)) + 1|0);
          $482 = $481;
          $483 = (($468) - ($482))|0;
          $484 = ($483|0)<($456|0);
          if ($484) {
           $$2$i$i$i190 = $465;
           break;
          } else {
           $$02729$i$i$i186 = $481;$474 = $483;
          }
         }
        }
       } while(0);
       $485 = ($$2$i$i$i190|0)==($465|0);
       $486 = $$2$i$i$i190;
       $487 = (($486) - ($469))|0;
       $488 = ($487|0)==(-1);
       $489 = $485 | $488;
       $$0116$ = $489 ? $$0116312 : 1;
       $490 = $489&1;
       $$128 = (($490) + ($$1$i$i223))|0;
       $$1111 = $$128;$$1117 = $$0116$;$$2108 = $489;
      }
      if ($453) {
       $491 = HEAP32[$15>>2]|0;
       __ZdlPv($491);
      }
      $492 = ($$1111|0)!=(-1);
      $or$cond = $$2108 & $492;
      if (!($or$cond)) {
       $$3119 = $$1117;
       label = 181;
       break;
      }
      $$pre = HEAP8[(208379)>>0]|0;
      $$pre283 = HEAP32[(208372)>>2]|0;
      $493 = ($$pre<<24>>24)<(0);
      $494 = HEAP32[52092]|0;
      $495 = $$pre&255;
      $496 = $493 ? $494 : 208368;
      $497 = $493 ? $$pre283 : $495;
      $498 = (_strlen($1)|0);
      $499 = ($497>>>0)<($$1111>>>0);
      if ($499) {
       $$3119 = $$1117;
       label = 181;
       break;
      } else {
       $$0110314 = $$1111;$$0116312 = $$1117;$346 = $498;$349 = $496;$351 = $497;
      }
     }
     if ((label|0) == 135) {
      $386 = ___cxa_find_matching_catch_2()|0;
      $387 = tempRet0;
      $$1113 = $386;$$1122 = $387;
      label = 138;
     }
     else if ((label|0) == 136) {
      $388 = ___cxa_find_matching_catch_2()|0;
      $389 = tempRet0;
      $390 = HEAP8[$337>>0]|0;
      $391 = ($390<<24>>24)<(0);
      if ($391) {
       $392 = HEAP32[$16>>2]|0;
       __ZdlPv($392);
       $$1113 = $388;$$1122 = $389;
       label = 138;
      } else {
       $$1113 = $388;$$1122 = $389;
       label = 138;
      }
     }
     else if ((label|0) == 145) {
      $404 = ___cxa_find_matching_catch_2()|0;
      $405 = tempRet0;
      $$2114 = $404;$$2123 = $405;
      label = 148;
     }
     else if ((label|0) == 146) {
      $406 = ___cxa_find_matching_catch_2()|0;
      $407 = tempRet0;
      $408 = HEAP8[$338>>0]|0;
      $409 = ($408<<24>>24)<(0);
      if ($409) {
       $410 = HEAP32[$17>>2]|0;
       __ZdlPv($410);
       $$2114 = $406;$$2123 = $407;
       label = 148;
      } else {
       $$2114 = $406;$$2123 = $407;
       label = 148;
      }
     }
     else if ((label|0) == 162) {
      $450 = ___cxa_find_matching_catch_2()|0;
      $451 = tempRet0;
      $$4 = $450;$$4125 = $451;
     }
     else if ((label|0) == 181) {
      $503 = $$3119 & 1;
      $extract$t = ($503<<24>>24)==(0);
      $504 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
      if ($extract$t) {
       if ($504) {
        break;
       } else {
        $$0105$in220225 = 1;$$4120$off0227 = 1;
        break L179;
       }
      }
      if (!($504)) {
       $$0105$in220225 = 1;$$4120$off0227 = 0;
       break L179;
      }
      $529 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
      $530 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($529,129031,18)|0);
      $531 = (_strlen($1)|0);
      $532 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($530,$1,$531)|0);
      $533 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($532,129066,92)|0);
      $534 = HEAP32[$533>>2]|0;
      $535 = ((($534)) + -12|0);
      $536 = HEAP32[$535>>2]|0;
      $537 = (($533) + ($536)|0);
      __ZNKSt3__28ios_base6getlocEv($4,$537);
      __THREW__ = 0;
      $538 = (invoke_iii(3255,($4|0),(215188|0))|0);
      $539 = __THREW__; __THREW__ = 0;
      $540 = $539&1;
      if (!($540)) {
       $541 = HEAP32[$538>>2]|0;
       $542 = ((($541)) + 28|0);
       $543 = HEAP32[$542>>2]|0;
       __THREW__ = 0;
       $544 = (invoke_iii($543|0,($538|0),10)|0);
       $545 = __THREW__; __THREW__ = 0;
       $546 = $545&1;
       if (!($546)) {
        __ZNSt3__26localeD2Ev($4);
        (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($533,$544)|0);
        (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($533)|0);
        $$0105$in220225 = 1;$$4120$off0227 = 0;
        break L179;
       }
      }
      $547 = ___cxa_find_matching_catch_2()|0;
      $548 = tempRet0;
      __THREW__ = 0;
      invoke_vi(3263,($4|0));
      $549 = __THREW__; __THREW__ = 0;
      $550 = $549&1;
      if ($550) {
       $551 = ___cxa_find_matching_catch_3(0|0)|0;
       $552 = tempRet0;
       ___clang_call_terminate($551);
       // unreachable;
      } else {
       ___resumeException($547|0);
       // unreachable;
      }
     }
     if ((label|0) == 138) {
      $$4 = $$1113;$$4125 = $$1122;
     }
     else if ((label|0) == 148) {
      $$4 = $$2114;$$4125 = $$2123;
     }
     $500 = HEAP8[$333>>0]|0;
     $501 = ($500<<24>>24)<(0);
     if ($501) {
      $502 = HEAP32[$15>>2]|0;
      __ZdlPv($502);
     }
     $$5 = $$4;$$5126 = $$4125;
     ___resumeException($$5|0);
     // unreachable;
    }
   } while(0);
   $505 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
   $506 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($505,129031,18)|0);
   $507 = (_strlen($1)|0);
   $508 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($506,$1,$507)|0);
   $509 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($508,129050,15)|0);
   $510 = HEAP32[$509>>2]|0;
   $511 = ((($510)) + -12|0);
   $512 = HEAP32[$511>>2]|0;
   $513 = (($509) + ($512)|0);
   __ZNKSt3__28ios_base6getlocEv($5,$513);
   __THREW__ = 0;
   $514 = (invoke_iii(3255,($5|0),(215188|0))|0);
   $515 = __THREW__; __THREW__ = 0;
   $516 = $515&1;
   if (!($516)) {
    $517 = HEAP32[$514>>2]|0;
    $518 = ((($517)) + 28|0);
    $519 = HEAP32[$518>>2]|0;
    __THREW__ = 0;
    $520 = (invoke_iii($519|0,($514|0),10)|0);
    $521 = __THREW__; __THREW__ = 0;
    $522 = $521&1;
    if (!($522)) {
     __ZNSt3__26localeD2Ev($5);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($509,$520)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($509)|0);
     $$0105$in220225 = 1;$$4120$off0227 = 1;
     break;
    }
   }
   $523 = ___cxa_find_matching_catch_2()|0;
   $524 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($5|0));
   $525 = __THREW__; __THREW__ = 0;
   $526 = $525&1;
   if ($526) {
    $527 = ___cxa_find_matching_catch_3(0|0)|0;
    $528 = tempRet0;
    ___clang_call_terminate($527);
    // unreachable;
   } else {
    ___resumeException($523|0);
    // unreachable;
   }
  }
 } while(0);
 $$ = $$4120$off0227 & $$0105$in220225;
 $$3 = $$;
 STACKTOP = sp;return ($$3|0);
}
function __ZNSt3__26vectorINS_3setINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS7_EENS5_IS7_EEEENS5_ISB_EEE8__appendEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i = 0, $$0$i13 = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $9 = 0, $scevgep = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $2 = sp;
 $3 = ((($0)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) - ($6))|0;
 $8 = (($7|0) / 12)&-1;
 $9 = ($8>>>0)<($1>>>0);
 if (!($9)) {
  $10 = $6;
  $$0$i = $1;$12 = $10;
  while(1) {
   $11 = ((($12)) + 4|0);
   HEAP32[$11>>2] = 0;
   $13 = ((($12)) + 8|0);
   HEAP32[$13>>2] = 0;
   $14 = ((($12)) + 4|0);
   HEAP32[$12>>2] = $14;
   $15 = HEAP32[$5>>2]|0;
   $16 = ((($15)) + 12|0);
   HEAP32[$5>>2] = $16;
   $17 = (($$0$i) + -1)|0;
   $18 = ($17|0)==(0);
   if ($18) {
    break;
   } else {
    $$0$i = $17;$12 = $16;
   }
  }
  STACKTOP = sp;return;
 }
 $19 = HEAP32[$0>>2]|0;
 $20 = (($6) - ($19))|0;
 $21 = (($20|0) / 12)&-1;
 $22 = (($21) + ($1))|0;
 $23 = ($22>>>0)>(357913941);
 if ($23) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $24 = ((($0)) + 8|0);
 $25 = (($4) - ($19))|0;
 $26 = (($25|0) / 12)&-1;
 $27 = ($26>>>0)<(178956970);
 $28 = $26 << 1;
 $29 = ($28>>>0)<($22>>>0);
 $$sroa$speculated$i = $29 ? $22 : $28;
 $$sroa$speculated$$i = $27 ? $$sroa$speculated$i : 357913941;
 $30 = ((($2)) + 12|0);
 HEAP32[$30>>2] = 0;
 $31 = ((($2)) + 16|0);
 HEAP32[$31>>2] = $24;
 $32 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($32) {
   $41 = 0;
  } else {
   $33 = ($$sroa$speculated$$i>>>0)>(357913941);
   if (!($33)) {
    $39 = ($$sroa$speculated$$i*12)|0;
    $40 = (__Znwj($39)|0);
    $41 = $40;
    break;
   }
   $34 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($34|0),(204840|0));
   $35 = __THREW__; __THREW__ = 0;
   $36 = $35&1;
   if ($36) {
    $37 = ___cxa_find_matching_catch_2()|0;
    $38 = tempRet0;
    ___cxa_free_exception(($34|0));
    ___resumeException($37|0);
    // unreachable;
   } else {
    HEAP32[$34>>2] = (99824);
    ___cxa_throw(($34|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 HEAP32[$2>>2] = $41;
 $42 = (($41) + (($21*12)|0)|0);
 $43 = ((($2)) + 8|0);
 HEAP32[$43>>2] = $42;
 $44 = ((($2)) + 4|0);
 HEAP32[$44>>2] = $42;
 $45 = (($41) + (($$sroa$speculated$$i*12)|0)|0);
 $46 = ((($2)) + 12|0);
 HEAP32[$46>>2] = $45;
 $$0$i13 = $1;$48 = $42;
 while(1) {
  $47 = ((($48)) + 4|0);
  HEAP32[$47>>2] = 0;
  $49 = ((($48)) + 8|0);
  HEAP32[$49>>2] = 0;
  $50 = ((($48)) + 4|0);
  HEAP32[$48>>2] = $50;
  $51 = ((($48)) + 12|0);
  $52 = (($$0$i13) + -1)|0;
  $53 = ($52|0)==(0);
  if ($53) {
   break;
  } else {
   $$0$i13 = $52;$48 = $51;
  }
 }
 $scevgep = (($41) + (($22*12)|0)|0);
 HEAP32[$43>>2] = $scevgep;
 __THREW__ = 0;
 invoke_vii(3788,($0|0),($2|0));
 $54 = __THREW__; __THREW__ = 0;
 $55 = $54&1;
 if ($55) {
  $67 = ___cxa_find_matching_catch_2()|0;
  $68 = tempRet0;
  $69 = HEAP32[$44>>2]|0;
  $70 = HEAP32[$43>>2]|0;
  $71 = ($70|0)==($69|0);
  if (!($71)) {
   $73 = $70;
   while(1) {
    $72 = ((($73)) + -12|0);
    HEAP32[$43>>2] = $72;
    $74 = ((($73)) + -8|0);
    $75 = HEAP32[$74>>2]|0;
    __ZNSt3__26__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EENS4_IS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($72,$75);
    $76 = HEAP32[$43>>2]|0;
    $77 = ($76|0)==($69|0);
    if ($77) {
     break;
    } else {
     $73 = $76;
    }
   }
  }
  $78 = HEAP32[$2>>2]|0;
  $79 = ($78|0)==(0|0);
  if ($79) {
   ___resumeException($67|0);
   // unreachable;
  }
  __ZdlPv($78);
  ___resumeException($67|0);
  // unreachable;
 } else {
  $56 = HEAP32[$44>>2]|0;
  $57 = HEAP32[$43>>2]|0;
  $58 = ($57|0)==($56|0);
  if (!($58)) {
   $60 = $57;
   while(1) {
    $59 = ((($60)) + -12|0);
    HEAP32[$43>>2] = $59;
    $61 = ((($60)) + -8|0);
    $62 = HEAP32[$61>>2]|0;
    __ZNSt3__26__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EENS4_IS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($59,$62);
    $63 = HEAP32[$43>>2]|0;
    $64 = ($63|0)==($56|0);
    if ($64) {
     break;
    } else {
     $60 = $63;
    }
   }
  }
  $65 = HEAP32[$2>>2]|0;
  $66 = ($65|0)==(0|0);
  if (!($66)) {
   __ZdlPv($65);
  }
  STACKTOP = sp;return;
 }
}
function __ZNSt3__26vectorINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS4_IS6_EEE8__appendEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i = 0, $$0$i15 = 0, $$06$i$i = 0, $$in = 0, $$pre = 0, $$pre$i16 = 0, $$sroa$16$0 = 0, $$sroa$7$0 = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) - ($5))|0;
 $7 = (($6|0) / 12)&-1;
 $8 = ($7>>>0)<($1>>>0);
 if (!($8)) {
  $9 = $5;
  $$0$i = $1;$10 = $9;
  while(1) {
   ;HEAP32[$10>>2]=0|0;HEAP32[$10+4>>2]=0|0;HEAP32[$10+8>>2]=0|0;
   $11 = HEAP32[$4>>2]|0;
   $12 = ((($11)) + 12|0);
   HEAP32[$4>>2] = $12;
   $13 = (($$0$i) + -1)|0;
   $14 = ($13|0)==(0);
   if ($14) {
    break;
   } else {
    $$0$i = $13;$10 = $12;
   }
  }
  return;
 }
 $15 = HEAP32[$0>>2]|0;
 $16 = (($5) - ($15))|0;
 $17 = (($16|0) / 12)&-1;
 $18 = (($17) + ($1))|0;
 $19 = ($18>>>0)>(357913941);
 if ($19) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $20 = (($3) - ($15))|0;
 $21 = (($20|0) / 12)&-1;
 $22 = ($21>>>0)<(178956970);
 $23 = $21 << 1;
 $24 = ($23>>>0)<($18>>>0);
 $$sroa$speculated$i = $24 ? $18 : $23;
 $$sroa$speculated$$i = $22 ? $$sroa$speculated$i : 357913941;
 $25 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($25) {
   $35 = 0;$83 = 0;
  } else {
   $26 = ($$sroa$speculated$$i>>>0)>(357913941);
   if (!($26)) {
    $32 = ($$sroa$speculated$$i*12)|0;
    $33 = (__Znwj($32)|0);
    $35 = $33;$83 = $33;
    break;
   }
   $27 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($27|0),(204840|0));
   $28 = __THREW__; __THREW__ = 0;
   $29 = $28&1;
   if ($29) {
    $30 = ___cxa_find_matching_catch_2()|0;
    $31 = tempRet0;
    ___cxa_free_exception(($27|0));
    ___resumeException($30|0);
    // unreachable;
   } else {
    HEAP32[$27>>2] = (99824);
    ___cxa_throw(($27|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $34 = (($35) + (($17*12)|0)|0);
 $36 = $34;
 $37 = (($35) + (($$sroa$speculated$$i*12)|0)|0);
 $$0$i15 = $1;$$in = $34;$$sroa$16$0 = $36;
 while(1) {
  ;HEAP32[$$in>>2]=0|0;HEAP32[$$in+4>>2]=0|0;HEAP32[$$in+8>>2]=0|0;
  $38 = $$sroa$16$0;
  $39 = ((($38)) + 12|0);
  $40 = $39;
  $41 = (($$0$i15) + -1)|0;
  $42 = ($41|0)==(0);
  if ($42) {
   break;
  } else {
   $$0$i15 = $41;$$in = $39;$$sroa$16$0 = $40;
  }
 }
 $43 = $37;
 $44 = HEAP32[$0>>2]|0;
 $45 = HEAP32[$4>>2]|0;
 $46 = ($45|0)==($44|0);
 do {
  if ($46) {
   $47 = $44;
   $57 = $36;$58 = $47;$60 = $44;
  } else {
   $$06$i$i = $45;$$sroa$7$0 = $36;$49 = $34;
   while(1) {
    $48 = ((($49)) + -12|0);
    $50 = ((($$06$i$i)) + -12|0);
    __THREW__ = 0;
    invoke_vii(3457,($48|0),($50|0));
    $51 = __THREW__; __THREW__ = 0;
    $52 = $51&1;
    if ($52) {
     break;
    }
    $53 = $$sroa$7$0;
    $54 = ((($53)) + -12|0);
    $55 = $54;
    $56 = ($50|0)==($44|0);
    if ($56) {
     label = 18;
     break;
    } else {
     $$06$i$i = $50;$$sroa$7$0 = $55;$49 = $54;
    }
   }
   if ((label|0) == 18) {
    $$pre$i16 = HEAP32[$0>>2]|0;
    $$pre = HEAP32[$4>>2]|0;
    $57 = $55;$58 = $$pre$i16;$60 = $$pre;
    break;
   }
   $71 = ___cxa_find_matching_catch_2()|0;
   $72 = tempRet0;
   $73 = $$sroa$7$0;
   $74 = ($39|0)==($73|0);
   if (!($74)) {
    $76 = $39;
    while(1) {
     $75 = ((($76)) + -12|0);
     $77 = ((($75)) + 11|0);
     $78 = HEAP8[$77>>0]|0;
     $79 = ($78<<24>>24)<(0);
     if ($79) {
      $81 = HEAP32[$75>>2]|0;
      __ZdlPv($81);
     }
     $80 = ($75|0)==($73|0);
     if ($80) {
      break;
     } else {
      $76 = $75;
     }
    }
   }
   $82 = ($35|0)==(0|0);
   if ($82) {
    ___resumeException($71|0);
    // unreachable;
   }
   __ZdlPv($83);
   ___resumeException($71|0);
   // unreachable;
  }
 } while(0);
 HEAP32[$0>>2] = $57;
 HEAP32[$4>>2] = $40;
 HEAP32[$2>>2] = $43;
 $59 = $58;
 $61 = ($60|0)==($59|0);
 if (!($61)) {
  $63 = $60;
  while(1) {
   $62 = ((($63)) + -12|0);
   $64 = ((($62)) + 11|0);
   $65 = HEAP8[$64>>0]|0;
   $66 = ($65<<24>>24)<(0);
   if ($66) {
    $68 = HEAP32[$62>>2]|0;
    __ZdlPv($68);
   }
   $67 = ($62|0)==($59|0);
   if ($67) {
    break;
   } else {
    $63 = $62;
   }
  }
 }
 $69 = ($58|0)==(0);
 if ($69) {
  return;
 }
 $70 = $58;
 __ZdlPv($70);
 return;
}
function __ZNSt3__26vectorINS_3setINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS7_EENS5_IS7_EEEENS5_ISB_EEE26__swap_out_circular_bufferERNS_14__split_bufferISB_RSC_EE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i$i$i$i$i = 0, $$0$i$i$i$i$i$i$i = 0, $$011$i = 0, $$byval_copy = 0, $$in7$i$i$i$i = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i$i$i$i$i$i = 0, $$pre$phi25Z2D = 0, $$pre$phiZ2D = 0, $$pre22 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $8 = 0, $9 = 0, $eh$lpad$body$i$i$i$index2Z2D = 0, $eh$lpad$body$i$i$i$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy = sp + 12|0;
 $2 = sp + 8|0;
 $3 = sp + 4|0;
 $4 = sp;
 $5 = HEAP32[$0>>2]|0;
 $6 = ((($0)) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($1)) + 4|0);
 $9 = ($7|0)==($5|0);
 if ($9) {
  $10 = $5;
  $$pre22 = HEAP32[$8>>2]|0;
  $$pre$phi25Z2D = $8;$$pre$phiZ2D = $0;$69 = $$pre22;$70 = $10;
  HEAP32[$$pre$phiZ2D>>2] = $69;
  HEAP32[$$pre$phi25Z2D>>2] = $70;
  $71 = ((($1)) + 8|0);
  $72 = HEAP32[$6>>2]|0;
  $73 = HEAP32[$71>>2]|0;
  HEAP32[$6>>2] = $73;
  HEAP32[$71>>2] = $72;
  $74 = ((($0)) + 8|0);
  $75 = ((($1)) + 12|0);
  $76 = HEAP32[$74>>2]|0;
  $77 = HEAP32[$75>>2]|0;
  HEAP32[$74>>2] = $77;
  HEAP32[$75>>2] = $76;
  $78 = HEAP32[$$pre$phi25Z2D>>2]|0;
  HEAP32[$1>>2] = $78;
  STACKTOP = sp;return;
 }
 $$pre$i = HEAP32[$8>>2]|0;
 $$011$i = $7;$12 = $$pre$i;
 L5: while(1) {
  $11 = ((($12)) + -12|0);
  $13 = ((($$011$i)) + -12|0);
  $14 = ((($12)) + -8|0);
  HEAP32[$14>>2] = 0;
  $15 = ((($12)) + -4|0);
  HEAP32[$15>>2] = 0;
  $16 = ((($12)) + -8|0);
  HEAP32[$11>>2] = $16;
  $17 = HEAP32[$13>>2]|0;
  $18 = ((($$011$i)) + -8|0);
  $19 = ($17|0)==($18|0);
  if (!($19)) {
   $20 = $16;
   $$in7$i$i$i$i = $17;
   while(1) {
    $21 = ((($$in7$i$i$i$i)) + 16|0);
    HEAP32[$4>>2] = $20;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy>>2]=HEAP32[$4>>2]|0;
    $22 = (invoke_iiiiii(3789,($11|0),($$byval_copy|0),($2|0),($3|0),($21|0))|0);
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if ($24) {
     label = 20;
     break L5;
    }
    $25 = HEAP32[$22>>2]|0;
    $26 = ($25|0)==(0|0);
    if ($26) {
     __THREW__ = 0;
     $27 = (invoke_ii(3276,28)|0);
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      label = 20;
      break L5;
     }
     $30 = ((($27)) + 16|0);
     __THREW__ = 0;
     invoke_vii(3457,($30|0),($21|0));
     $31 = __THREW__; __THREW__ = 0;
     $32 = $31&1;
     if ($32) {
      label = 10;
      break L5;
     }
     $35 = HEAP32[$2>>2]|0;
     HEAP32[$27>>2] = 0;
     $36 = ((($27)) + 4|0);
     HEAP32[$36>>2] = 0;
     $37 = ((($27)) + 8|0);
     HEAP32[$37>>2] = $35;
     HEAP32[$22>>2] = $27;
     $38 = HEAP32[$11>>2]|0;
     $39 = HEAP32[$38>>2]|0;
     $40 = ($39|0)==(0|0);
     if ($40) {
      $43 = $27;
     } else {
      $41 = $39;
      HEAP32[$11>>2] = $41;
      $$pre$i$i$i$i$i$i$i = HEAP32[$22>>2]|0;
      $43 = $$pre$i$i$i$i$i$i$i;
     }
     $42 = HEAP32[$14>>2]|0;
     __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($42,$43);
     $44 = HEAP32[$15>>2]|0;
     $45 = (($44) + 1)|0;
     HEAP32[$15>>2] = $45;
    }
    $46 = ((($$in7$i$i$i$i)) + 4|0);
    $47 = HEAP32[$46>>2]|0;
    $48 = ($47|0)==(0|0);
    if ($48) {
     $49 = ((($$in7$i$i$i$i)) + 8|0);
     $50 = HEAP32[$49>>2]|0;
     $51 = HEAP32[$50>>2]|0;
     $52 = ($51|0)==($$in7$i$i$i$i|0);
     if ($52) {
      $$0$i$i$i$i$i$i = $50;
     } else {
      $56 = $49;
      while(1) {
       $55 = HEAP32[$56>>2]|0;
       $57 = ((($55)) + 8|0);
       $58 = HEAP32[$57>>2]|0;
       $59 = HEAP32[$58>>2]|0;
       $60 = ($59|0)==($55|0);
       if ($60) {
        $$0$i$i$i$i$i$i = $58;
        break;
       } else {
        $56 = $57;
       }
      }
     }
    } else {
     $$0$i$i$i$i$i$i$i = $47;
     while(1) {
      $53 = HEAP32[$$0$i$i$i$i$i$i$i>>2]|0;
      $54 = ($53|0)==(0|0);
      if ($54) {
       break;
      } else {
       $$0$i$i$i$i$i$i$i = $53;
      }
     }
     $$0$i$i$i$i$i$i = $$0$i$i$i$i$i$i$i;
    }
    $61 = ($$0$i$i$i$i$i$i|0)==($18|0);
    if ($61) {
     break;
    } else {
     $$in7$i$i$i$i = $$0$i$i$i$i$i$i;
    }
   }
  }
  $65 = HEAP32[$8>>2]|0;
  $66 = ((($65)) + -12|0);
  HEAP32[$8>>2] = $66;
  $67 = ($13|0)==($5|0);
  if ($67) {
   label = 23;
   break;
  } else {
   $$011$i = $13;$12 = $66;
  }
 }
 if ((label|0) == 10) {
  $33 = ___cxa_find_matching_catch_2()|0;
  $34 = tempRet0;
  __ZdlPv($27);
  $eh$lpad$body$i$i$i$index2Z2D = $34;$eh$lpad$body$i$i$i$indexZ2D = $33;
  $64 = HEAP32[$16>>2]|0;
  __ZNSt3__26__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EENS4_IS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($11,$64);
  ___resumeException($eh$lpad$body$i$i$i$indexZ2D|0);
  // unreachable;
 }
 else if ((label|0) == 20) {
  $62 = ___cxa_find_matching_catch_2()|0;
  $63 = tempRet0;
  $eh$lpad$body$i$i$i$index2Z2D = $63;$eh$lpad$body$i$i$i$indexZ2D = $62;
  $64 = HEAP32[$16>>2]|0;
  __ZNSt3__26__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EENS4_IS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($11,$64);
  ___resumeException($eh$lpad$body$i$i$i$indexZ2D|0);
  // unreachable;
 }
 else if ((label|0) == 23) {
  $68 = $66;
  $$pre = HEAP32[$0>>2]|0;
  $$pre$phi25Z2D = $8;$$pre$phiZ2D = $0;$69 = $68;$70 = $$pre;
  HEAP32[$$pre$phiZ2D>>2] = $69;
  HEAP32[$$pre$phi25Z2D>>2] = $70;
  $71 = ((($1)) + 8|0);
  $72 = HEAP32[$6>>2]|0;
  $73 = HEAP32[$71>>2]|0;
  HEAP32[$6>>2] = $73;
  HEAP32[$71>>2] = $72;
  $74 = ((($0)) + 8|0);
  $75 = ((($1)) + 12|0);
  $76 = HEAP32[$74>>2]|0;
  $77 = HEAP32[$75>>2]|0;
  HEAP32[$74>>2] = $77;
  HEAP32[$75>>2] = $76;
  $78 = HEAP32[$$pre$phi25Z2D>>2]|0;
  HEAP32[$1>>2] = $78;
  STACKTOP = sp;return;
 }
}
function __ZNSt3__26__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EENS4_IS6_EEE12__find_equalIS6_EERPNS_16__tree_node_baseIPvEENS_21__tree_const_iteratorIS6_PNS_11__tree_nodeIS6_SD_EEiEERPNS_15__tree_end_nodeISF_EESG_RKT_($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0$i$i = 0, $$0$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i$i = 0, $$08$i$i = 0, $$2 = 0, $$pre = 0, $$sroa$053$0 = 0, $$sroa$speculated$i$i$i$i = 0, $$sroa$speculated$i$i$i$i21 = 0, $$sroa$speculated$i$i$i$i27 = 0, $$sroa$speculated$i$i$i$i33 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = ((($0)) + 4|0);
 $6 = HEAP32[$1>>2]|0;
 $7 = ($6|0)==($5|0);
 $8 = $6;
 do {
  if (!($7)) {
   $9 = ((($6)) + 16|0);
   $10 = ((($9)) + 11|0);
   $11 = HEAP8[$10>>0]|0;
   $12 = ($11<<24>>24)<(0);
   $13 = ((($6)) + 20|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = $11&255;
   $16 = $12 ? $14 : $15;
   $17 = ((($4)) + 11|0);
   $18 = HEAP8[$17>>0]|0;
   $19 = ($18<<24>>24)<(0);
   $20 = ((($4)) + 4|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = $18&255;
   $23 = $19 ? $21 : $22;
   $24 = ($16>>>0)<($23>>>0);
   $$sroa$speculated$i$i$i$i33 = $24 ? $16 : $23;
   $25 = ($$sroa$speculated$i$i$i$i33|0)==(0);
   if ($25) {
    label = 4;
   } else {
    $26 = HEAP32[$4>>2]|0;
    $27 = $19 ? $26 : $4;
    $28 = HEAP32[$9>>2]|0;
    $29 = $12 ? $28 : $9;
    $30 = (_memcmp($27,$29,$$sroa$speculated$i$i$i$i33)|0);
    $31 = ($30|0)==(0);
    if ($31) {
     label = 4;
    } else {
     $33 = ($30|0)<(0);
     if ($33) {
      break;
     }
    }
   }
   if ((label|0) == 4) {
    $32 = ($23>>>0)<($16>>>0);
    if ($32) {
     break;
    }
   }
   $74 = ($23>>>0)<($16>>>0);
   $$sroa$speculated$i$i$i$i21 = $74 ? $23 : $16;
   $75 = ($$sroa$speculated$i$i$i$i21|0)==(0);
   if ($75) {
    label = 20;
   } else {
    $76 = HEAP32[$9>>2]|0;
    $77 = $12 ? $76 : $9;
    $78 = HEAP32[$4>>2]|0;
    $79 = $19 ? $78 : $4;
    $80 = (_memcmp($77,$79,$$sroa$speculated$i$i$i$i21)|0);
    $81 = ($80|0)==(0);
    if ($81) {
     label = 20;
    } else {
     $82 = ($80|0)<(0);
     if (!($82)) {
      label = 36;
     }
    }
   }
   if ((label|0) == 20) {
    if (!($24)) {
     label = 36;
    }
   }
   if ((label|0) == 36) {
    HEAP32[$2>>2] = $8;
    HEAP32[$3>>2] = $8;
    $$2 = $3;
    return ($$2|0);
   }
   $83 = ((($6)) + 4|0);
   $84 = HEAP32[$83>>2]|0;
   $85 = ($84|0)==(0|0);
   if ($85) {
    $86 = ((($6)) + 8|0);
    $87 = HEAP32[$86>>2]|0;
    $88 = HEAP32[$87>>2]|0;
    $89 = ($88|0)==($6|0);
    if ($89) {
     $$0$i$i$i$i$i = $87;
    } else {
     $93 = $86;
     while(1) {
      $92 = HEAP32[$93>>2]|0;
      $94 = ((($92)) + 8|0);
      $95 = HEAP32[$94>>2]|0;
      $96 = HEAP32[$95>>2]|0;
      $97 = ($96|0)==($92|0);
      if ($97) {
       $$0$i$i$i$i$i = $95;
       break;
      } else {
       $93 = $94;
      }
     }
    }
   } else {
    $$0$i$i$i$i$i$i = $84;
    while(1) {
     $90 = HEAP32[$$0$i$i$i$i$i$i>>2]|0;
     $91 = ($90|0)==(0|0);
     if ($91) {
      break;
     } else {
      $$0$i$i$i$i$i$i = $90;
     }
    }
    $$0$i$i$i$i$i = $$0$i$i$i$i$i$i;
   }
   $98 = ($$0$i$i$i$i$i|0)==($5|0);
   do {
    if (!($98)) {
     $99 = ((($$0$i$i$i$i$i)) + 16|0);
     $100 = ((($99)) + 11|0);
     $101 = HEAP8[$100>>0]|0;
     $102 = ($101<<24>>24)<(0);
     $103 = ((($$0$i$i$i$i$i)) + 20|0);
     $104 = HEAP32[$103>>2]|0;
     $105 = $101&255;
     $106 = $102 ? $104 : $105;
     $107 = ($106>>>0)<($23>>>0);
     $$sroa$speculated$i$i$i$i = $107 ? $106 : $23;
     $108 = ($$sroa$speculated$i$i$i$i|0)==(0);
     if ($108) {
      label = 30;
     } else {
      $109 = HEAP32[$4>>2]|0;
      $110 = $19 ? $109 : $4;
      $111 = HEAP32[$99>>2]|0;
      $112 = $102 ? $111 : $99;
      $113 = (_memcmp($110,$112,$$sroa$speculated$i$i$i$i)|0);
      $114 = ($113|0)==(0);
      if ($114) {
       label = 30;
      } else {
       $116 = ($113|0)<(0);
       if ($116) {
        break;
       }
      }
     }
     if ((label|0) == 30) {
      $115 = ($23>>>0)<($106>>>0);
      if ($115) {
       break;
      }
     }
     $120 = (__ZNSt3__26__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EENS4_IS6_EEE12__find_equalIS6_EERPNS_16__tree_node_baseIPvEERPNS_15__tree_end_nodeISF_EERKT_($0,$2,$4)|0);
     $$2 = $120;
     return ($$2|0);
    }
   } while(0);
   $117 = ((($6)) + 4|0);
   $118 = HEAP32[$117>>2]|0;
   $119 = ($118|0)==(0|0);
   if ($119) {
    HEAP32[$2>>2] = $8;
    $$2 = $83;
    return ($$2|0);
   } else {
    HEAP32[$2>>2] = $$0$i$i$i$i$i;
    $$2 = $$0$i$i$i$i$i;
    return ($$2|0);
   }
  }
 } while(0);
 $34 = HEAP32[$0>>2]|0;
 $35 = ($6|0)==($34|0);
 $$pre = HEAP32[$6>>2]|0;
 do {
  if ($35) {
   $$sroa$053$0 = $8;
  } else {
   $36 = ($$pre|0)==(0|0);
   if ($36) {
    $$0$i$i = $6;
    while(1) {
     $40 = ((($$0$i$i)) + 8|0);
     $41 = HEAP32[$40>>2]|0;
     $42 = HEAP32[$41>>2]|0;
     $43 = ($42|0)==($$0$i$i|0);
     if ($43) {
      $$0$i$i = $41;
     } else {
      $$08$i$i = $41;
      break;
     }
    }
   } else {
    $$0$i$i$i = $$pre;
    while(1) {
     $37 = ((($$0$i$i$i)) + 4|0);
     $38 = HEAP32[$37>>2]|0;
     $39 = ($38|0)==(0|0);
     if ($39) {
      $$08$i$i = $$0$i$i$i;
      break;
     } else {
      $$0$i$i$i = $38;
     }
    }
   }
   $44 = $$08$i$i;
   $45 = ((($$08$i$i)) + 16|0);
   $46 = ((($4)) + 11|0);
   $47 = HEAP8[$46>>0]|0;
   $48 = ($47<<24>>24)<(0);
   $49 = ((($4)) + 4|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = $47&255;
   $52 = $48 ? $50 : $51;
   $53 = ((($45)) + 11|0);
   $54 = HEAP8[$53>>0]|0;
   $55 = ($54<<24>>24)<(0);
   $56 = ((($$08$i$i)) + 20|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = $54&255;
   $59 = $55 ? $57 : $58;
   $60 = ($52>>>0)<($59>>>0);
   $$sroa$speculated$i$i$i$i27 = $60 ? $52 : $59;
   $61 = ($$sroa$speculated$i$i$i$i27|0)==(0);
   if ($61) {
    label = 12;
   } else {
    $62 = HEAP32[$45>>2]|0;
    $63 = $55 ? $62 : $45;
    $64 = HEAP32[$4>>2]|0;
    $65 = $48 ? $64 : $4;
    $66 = (_memcmp($63,$65,$$sroa$speculated$i$i$i$i27)|0);
    $67 = ($66|0)==(0);
    if ($67) {
     label = 12;
    } else {
     $69 = ($66|0)<(0);
     if ($69) {
      $$sroa$053$0 = $44;
      break;
     }
    }
   }
   if ((label|0) == 12) {
    $68 = ($59>>>0)<($52>>>0);
    if ($68) {
     $$sroa$053$0 = $44;
     break;
    }
   }
   $73 = (__ZNSt3__26__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EENS4_IS6_EEE12__find_equalIS6_EERPNS_16__tree_node_baseIPvEERPNS_15__tree_end_nodeISF_EERKT_($0,$2,$4)|0);
   $$2 = $73;
   return ($$2|0);
  }
 } while(0);
 $70 = ($$pre|0)==(0|0);
 if ($70) {
  HEAP32[$2>>2] = $6;
  $$2 = $6;
  return ($$2|0);
 } else {
  $71 = $$sroa$053$0;
  HEAP32[$2>>2] = $71;
  $72 = ((($71)) + 4|0);
  $$2 = $72;
  return ($$2|0);
 }
 return (0)|0;
}
function __ZN3osg21getGLExtensionFuncPtrEPKc($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (_eglGetProcAddress(($0|0))|0);
 return ($1|0);
}
function __ZN3osg12GLExtensions3GetEjb($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$not = 0, $$not6 = 0, $10 = 0, $100 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $brmerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[(208356)>>2]|0;
 $3 = HEAP32[52088]|0;
 $4 = (($2) - ($3))|0;
 $5 = $4 >> 2;
 $6 = ($5>>>0)>($0>>>0);
 L1: do {
  if (!($6)) {
   $7 = (($0) + 1)|0;
   $8 = ($7>>>0)>($5>>>0);
   $9 = $3;
   $10 = $2;
   if ($8) {
    $11 = (($7) - ($5))|0;
    __ZNSt3__26vectorIN3osg7ref_ptrINS1_12GLExtensionsEEENS_9allocatorIS4_EEE8__appendEj(208352,$11);
    break;
   }
   $12 = ($7>>>0)<($5>>>0);
   if ($12) {
    $13 = (($9) + ($7<<2)|0);
    $14 = ($10|0)==($13|0);
    if (!($14)) {
     $16 = $10;
     while(1) {
      $15 = ((($16)) + -4|0);
      HEAP32[(208356)>>2] = $15;
      $17 = HEAP32[$15>>2]|0;
      $18 = ($17|0)==(0|0);
      if (!($18)) {
       $19 = ((($17)) + 8|0);
       $20 = HEAP32[$19>>2]|0;HEAP32[$19>>2] = (($20-1)|0);
       $21 = ($20|0)==(1);
       if ($21) {
        __THREW__ = 0;
        invoke_viii(3262,($17|0),1,1);
        $22 = __THREW__; __THREW__ = 0;
        $23 = $22&1;
        if ($23) {
         break;
        }
       }
      }
      HEAP32[$15>>2] = 0;
      $24 = HEAP32[(208356)>>2]|0;
      $25 = ($24|0)==($13|0);
      if ($25) {
       break L1;
      } else {
       $16 = $24;
      }
     }
     $26 = ___cxa_find_matching_catch_2()|0;
     $27 = tempRet0;
     ___cxa_call_unexpected(($26|0));
     // unreachable;
    }
   }
  }
 } while(0);
 $28 = HEAP32[52088]|0;
 $29 = (($28) + ($0<<2)|0);
 $30 = HEAP32[$29>>2]|0;
 $$not = ($30|0)!=(0|0);
 $$not6 = $1 ^ 1;
 $brmerge = $$not | $$not6;
 if (!($brmerge)) {
  $31 = (__Znwj(1692)|0);
  __THREW__ = 0;
  invoke_vii(3790,($31|0),($0|0));
  $32 = __THREW__; __THREW__ = 0;
  $33 = $32&1;
  if ($33) {
   $70 = ___cxa_find_matching_catch_2()|0;
   $71 = tempRet0;
   __ZdlPv($31);
   ___resumeException($70|0);
   // unreachable;
  }
  $34 = HEAP32[(208356)>>2]|0;
  $35 = HEAP32[52088]|0;
  $36 = (($34) - ($35))|0;
  $37 = $36 >> 2;
  $38 = ($37>>>0)>($0>>>0);
  L20: do {
   if (!($38)) {
    $39 = (($0) + 1)|0;
    $40 = ($39>>>0)>($37>>>0);
    $41 = $35;
    $42 = $34;
    if ($40) {
     $43 = (($39) - ($37))|0;
     __ZNSt3__26vectorIN3osg7ref_ptrINS1_12GLExtensionsEEENS_9allocatorIS4_EEE8__appendEj(208352,$43);
     break;
    }
    $44 = ($39>>>0)<($37>>>0);
    if ($44) {
     $45 = (($41) + ($39<<2)|0);
     $46 = ($42|0)==($45|0);
     if (!($46)) {
      $48 = $42;
      while(1) {
       $47 = ((($48)) + -4|0);
       HEAP32[(208356)>>2] = $47;
       $49 = HEAP32[$47>>2]|0;
       $50 = ($49|0)==(0|0);
       if (!($50)) {
        $51 = ((($49)) + 8|0);
        $52 = HEAP32[$51>>2]|0;HEAP32[$51>>2] = (($52-1)|0);
        $53 = ($52|0)==(1);
        if ($53) {
         __THREW__ = 0;
         invoke_viii(3262,($49|0),1,1);
         $54 = __THREW__; __THREW__ = 0;
         $55 = $54&1;
         if ($55) {
          break;
         }
        }
       }
       HEAP32[$47>>2] = 0;
       $56 = HEAP32[(208356)>>2]|0;
       $57 = ($56|0)==($45|0);
       if ($57) {
        break L20;
       } else {
        $48 = $56;
       }
      }
      $58 = ___cxa_find_matching_catch_2()|0;
      $59 = tempRet0;
      ___cxa_call_unexpected(($58|0));
      // unreachable;
     }
    }
   }
  } while(0);
  $60 = HEAP32[52088]|0;
  $61 = (($60) + ($0<<2)|0);
  $62 = HEAP32[$61>>2]|0;
  $63 = ($62|0)==($31|0);
  if (!($63)) {
   HEAP32[$61>>2] = $31;
   $64 = ((($31)) + 8|0);
   $65 = HEAP32[$64>>2]|0;HEAP32[$64>>2] = (($65+1)|0);
   $66 = ($62|0)==(0|0);
   if (!($66)) {
    $67 = ((($62)) + 8|0);
    $68 = HEAP32[$67>>2]|0;HEAP32[$67>>2] = (($68-1)|0);
    $69 = ($68|0)==(1);
    if ($69) {
     __ZNK3osg10Referenced24signalObserversAndDeleteEbb($62,1,1);
    }
   }
  }
 }
 $72 = HEAP32[(208356)>>2]|0;
 $73 = HEAP32[52088]|0;
 $74 = (($72) - ($73))|0;
 $75 = $74 >> 2;
 $76 = ($75>>>0)>($0>>>0);
 if ($76) {
  $98 = HEAP32[52088]|0;
  $99 = (($98) + ($0<<2)|0);
  $100 = HEAP32[$99>>2]|0;
  return ($100|0);
 }
 $77 = (($0) + 1)|0;
 $78 = ($77>>>0)>($75>>>0);
 $79 = $73;
 $80 = $72;
 if ($78) {
  $81 = (($77) - ($75))|0;
  __ZNSt3__26vectorIN3osg7ref_ptrINS1_12GLExtensionsEEENS_9allocatorIS4_EEE8__appendEj(208352,$81);
  $98 = HEAP32[52088]|0;
  $99 = (($98) + ($0<<2)|0);
  $100 = HEAP32[$99>>2]|0;
  return ($100|0);
 }
 $82 = ($77>>>0)<($75>>>0);
 if (!($82)) {
  $98 = HEAP32[52088]|0;
  $99 = (($98) + ($0<<2)|0);
  $100 = HEAP32[$99>>2]|0;
  return ($100|0);
 }
 $83 = (($79) + ($77<<2)|0);
 $84 = ($80|0)==($83|0);
 if ($84) {
  $98 = HEAP32[52088]|0;
  $99 = (($98) + ($0<<2)|0);
  $100 = HEAP32[$99>>2]|0;
  return ($100|0);
 } else {
  $86 = $80;
 }
 while(1) {
  $85 = ((($86)) + -4|0);
  HEAP32[(208356)>>2] = $85;
  $87 = HEAP32[$85>>2]|0;
  $88 = ($87|0)==(0|0);
  if (!($88)) {
   $89 = ((($87)) + 8|0);
   $90 = HEAP32[$89>>2]|0;HEAP32[$89>>2] = (($90-1)|0);
   $91 = ($90|0)==(1);
   if ($91) {
    __THREW__ = 0;
    invoke_viii(3262,($87|0),1,1);
    $92 = __THREW__; __THREW__ = 0;
    $93 = $92&1;
    if ($93) {
     label = 37;
     break;
    }
   }
  }
  HEAP32[$85>>2] = 0;
  $94 = HEAP32[(208356)>>2]|0;
  $95 = ($94|0)==($83|0);
  if ($95) {
   label = 38;
   break;
  } else {
   $86 = $94;
  }
 }
 if ((label|0) == 37) {
  $96 = ___cxa_find_matching_catch_2()|0;
  $97 = tempRet0;
  ___cxa_call_unexpected(($96|0));
  // unreachable;
 }
 else if ((label|0) == 38) {
  $98 = HEAP32[52088]|0;
  $99 = (($98) + ($0<<2)|0);
  $100 = HEAP32[$99>>2]|0;
  return ($100|0);
 }
 return (0)|0;
}
function __ZNSt3__26vectorIN3osg7ref_ptrINS1_12GLExtensionsEEENS_9allocatorIS4_EEE8__appendEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$06$i$i = 0, $$pre = 0, $$pre$i = 0, $$promoted4$i = 0, $$sroa$7$0 = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i = 0, $scevgep$i15 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) - ($5))|0;
 $7 = $6 >> 2;
 $8 = ($7>>>0)<($1>>>0);
 $9 = $5;
 if (!($8)) {
  $$promoted4$i = $5;
  $10 = $1 << 2;
  _memset(($$promoted4$i|0),0,($10|0))|0;
  $scevgep$i = (($9) + ($1<<2)|0);
  HEAP32[$4>>2] = $scevgep$i;
  return;
 }
 $11 = HEAP32[$0>>2]|0;
 $12 = (($5) - ($11))|0;
 $13 = $12 >> 2;
 $14 = (($13) + ($1))|0;
 $15 = ($14>>>0)>(1073741823);
 $16 = $11;
 if ($15) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $17 = (($3) - ($11))|0;
 $18 = $17 >> 2;
 $19 = ($18>>>0)<(536870911);
 $20 = $17 >> 1;
 $21 = ($20>>>0)<($14>>>0);
 $$sroa$speculated$i = $21 ? $14 : $20;
 $$sroa$speculated$$i = $19 ? $$sroa$speculated$i : 1073741823;
 $22 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($22) {
   $32 = 0;
  } else {
   $23 = ($$sroa$speculated$$i>>>0)>(1073741823);
   if (!($23)) {
    $29 = $$sroa$speculated$$i << 2;
    $30 = (__Znwj($29)|0);
    $32 = $30;
    break;
   }
   $24 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($24|0),(204840|0));
   $25 = __THREW__; __THREW__ = 0;
   $26 = $25&1;
   if ($26) {
    $27 = ___cxa_find_matching_catch_2()|0;
    $28 = tempRet0;
    ___cxa_free_exception(($24|0));
    ___resumeException($27|0);
    // unreachable;
   } else {
    HEAP32[$24>>2] = (99824);
    ___cxa_throw(($24|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $31 = (($32) + ($13<<2)|0);
 $33 = $31;
 $34 = (($32) + ($$sroa$speculated$$i<<2)|0);
 $35 = $34;
 $36 = $1 << 2;
 _memset(($31|0),0,($36|0))|0;
 $scevgep$i15 = (($31) + ($1<<2)|0);
 $37 = $scevgep$i15;
 $38 = ($9|0)==($16|0);
 if ($38) {
  $50 = $33;$51 = $5;$53 = $9;
 } else {
  $$06$i$i = $9;$$sroa$7$0 = $33;$41 = $31;
  while(1) {
   $39 = ((($$06$i$i)) + -4|0);
   $40 = ((($41)) + -4|0);
   $42 = HEAP32[$39>>2]|0;
   HEAP32[$40>>2] = $42;
   $43 = ($42|0)==(0|0);
   if (!($43)) {
    $44 = ((($42)) + 8|0);
    $45 = HEAP32[$44>>2]|0;HEAP32[$44>>2] = (($45+1)|0);
   }
   $46 = $$sroa$7$0;
   $47 = ((($46)) + -4|0);
   $48 = $47;
   $49 = ($39|0)==($16|0);
   if ($49) {
    break;
   } else {
    $$06$i$i = $39;$$sroa$7$0 = $48;$41 = $47;
   }
  }
  $$pre$i = HEAP32[$0>>2]|0;
  $$pre = HEAP32[$4>>2]|0;
  $50 = $48;$51 = $$pre$i;$53 = $$pre;
 }
 HEAP32[$0>>2] = $50;
 HEAP32[$4>>2] = $37;
 HEAP32[$2>>2] = $35;
 $52 = $51;
 $54 = ($53|0)==($52|0);
 L25: do {
  if (!($54)) {
   $56 = $53;
   while(1) {
    $55 = ((($56)) + -4|0);
    $57 = HEAP32[$55>>2]|0;
    $58 = ($57|0)==(0|0);
    if (!($58)) {
     $59 = ((($57)) + 8|0);
     $60 = HEAP32[$59>>2]|0;HEAP32[$59>>2] = (($60-1)|0);
     $61 = ($60|0)==(1);
     if ($61) {
      __THREW__ = 0;
      invoke_viii(3262,($57|0),1,1);
      $62 = __THREW__; __THREW__ = 0;
      $63 = $62&1;
      if ($63) {
       break;
      }
     }
    }
    HEAP32[$55>>2] = 0;
    $64 = ($55|0)==($52|0);
    if ($64) {
     break L25;
    } else {
     $56 = $55;
    }
   }
   $65 = ___cxa_find_matching_catch_2()|0;
   $66 = tempRet0;
   ___cxa_call_unexpected(($65|0));
   // unreachable;
  }
 } while(0);
 $67 = ($51|0)==(0);
 if ($67) {
  return;
 }
 $68 = $51;
 __ZdlPv($68);
 return;
}
function __ZN3osg12GLExtensionsC2Ej($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$ = 0, $$0$$sroa_cast$i$i197432313233 = 0, $$0$$sroa_cast$i$i198532363238 = 0, $$0$$sroa_cast$i$i199732413243 = 0, $$016$i$i = 0, $$017$i$i = 0, $$02729$i$i$i = 0, $$02729$i$i$i1683 = 0, $$02729$i$i$i1694 = 0, $$02729$i$i$i1705 = 0, $$02729$i$i$i1748 = 0, $$2$i$i$i1687 = 0, $$2$i$i$i1709 = 0, $$3246 = 0, $$5 = 0, $$5514 = 0, $$in$i$i = 0, $$in$i$i1018 = 0, $$in$i$i1027 = 0, $$in$i$i1032 = 0;
 var $$in$i$i1038 = 0, $$in$i$i1043 = 0, $$in$i$i1049 = 0, $$in$i$i1055 = 0, $$in$i$i1060 = 0, $$in$i$i1065 = 0, $$in$i$i1070 = 0, $$in$i$i1075 = 0, $$in$i$i1080 = 0, $$in$i$i1086 = 0, $$in$i$i1092 = 0, $$in$i$i1098 = 0, $$in$i$i1103 = 0, $$in$i$i1108 = 0, $$in$i$i1113 = 0, $$in$i$i1118 = 0, $$in$i$i1123 = 0, $$in$i$i1128 = 0, $$in$i$i1133 = 0, $$in$i$i1138 = 0;
 var $$in$i$i1143 = 0, $$in$i$i1148 = 0, $$in$i$i1154 = 0, $$in$i$i1160 = 0, $$in$i$i1166 = 0, $$in$i$i1172 = 0, $$in$i$i1178 = 0, $$in$i$i1254 = 0, $$in$i$i1260 = 0, $$in$i$i1265 = 0, $$in$i$i1271 = 0, $$in$i$i1276 = 0, $$in$i$i1281 = 0, $$in$i$i1287 = 0, $$in$i$i1292 = 0, $$in$i$i1297 = 0, $$in$i$i1302 = 0, $$in$i$i1307 = 0, $$in$i$i1313 = 0, $$in$i$i1318 = 0;
 var $$in$i$i1325 = 0, $$in$i$i1330 = 0, $$in$i$i1341 = 0, $$in$i$i1346 = 0, $$in$i$i1352 = 0, $$in$i$i1371 = 0, $$in$i$i1377 = 0, $$in$i$i1383 = 0, $$in$i$i1388 = 0, $$in$i$i1393 = 0, $$in$i$i1399 = 0, $$in$i$i1405 = 0, $$in$i$i1410 = 0, $$in$i$i1416 = 0, $$in$i$i1422 = 0, $$in$i$i1428 = 0, $$in$i$i1434 = 0, $$in$i$i1440 = 0, $$in$i$i1446 = 0, $$in$i$i1452 = 0;
 var $$in$i$i1458 = 0, $$in$i$i1464 = 0, $$in$i$i1470 = 0, $$in$i$i1476 = 0, $$in$i$i1482 = 0, $$in$i$i1488 = 0, $$in$i$i1493 = 0, $$in$i$i1499 = 0, $$in$i$i1504 = 0, $$in$i$i1510 = 0, $$in$i$i1516 = 0, $$in$i$i1522 = 0, $$in$i$i1528 = 0, $$in$i$i1534 = 0, $$in$i$i1540 = 0, $$in$i$i1546 = 0, $$in$i$i1552 = 0, $$in$i$i1558 = 0, $$in$i$i1564 = 0, $$in$i$i1597 = 0;
 var $$in$i$i1603 = 0, $$in$i$i1608 = 0, $$in$i$i1614 = 0, $$in$i$i1619 = 0, $$in$i$i1625 = 0, $$in$i$i1631 = 0, $$in$i$i1637 = 0, $$in$i$i1643 = 0, $$in$i$i1649 = 0, $$in$i$i1655 = 0, $$in$i$i1661 = 0, $$in$i$i1667 = 0, $$in$i$i1673 = 0, $$in$i$i1769 = 0, $$in$i$i1774 = 0, $$in$i$i1779 = 0, $$in$i$i1784 = 0, $$in$i$i1789 = 0, $$in$i$i1794 = 0, $$in$i$i1800 = 0;
 var $$in$i$i1806 = 0, $$in$i$i1815 = 0, $$in$i$i1820 = 0, $$in$i$i1825 = 0, $$in$i$i1830 = 0, $$in$i$i1835 = 0, $$in$i$i1840 = 0, $$in$i$i1846 = 0, $$in$i$i1854 = 0, $$in$i$i1860 = 0, $$in$i$i1866 = 0, $$in$i$i1873 = 0, $$in$i$i1879 = 0, $$in$i$i1885 = 0, $$in$i$i1894 = 0, $$in$i$i1900 = 0, $$in$i$i1906 = 0, $$in$i$i1912 = 0, $$in$i$i1931 = 0, $$in$i$i1940 = 0;
 var $$in$i$i1947 = 0, $$in$i$i1954 = 0, $$in$i$i1960 = 0, $$in$i$i1972 = 0, $$in$i$i1977 = 0, $$in$i$i1983 = 0, $$in$i$i1989 = 0, $$in$i$i1995 = 0, $$in$i$i2001 = 0, $$in$i$i2009 = 0, $$in$i$i2014 = 0, $$in$i$i2020 = 0, $$in$i$i2026 = 0, $$in$i$i2032 = 0, $$in$i$i2038 = 0, $$in$i$i2046 = 0, $$in$i$i2053 = 0, $$in$i$i2060 = 0, $$in$i$i2067 = 0, $$in$i$i2073 = 0;
 var $$in$i$i2079 = 0, $$in$i$i2086 = 0, $$in$i$i2092 = 0, $$in$i$i2099 = 0, $$in$i$i2105 = 0, $$in$i$i2111 = 0, $$in$i$i2117 = 0, $$in$i$i2123 = 0, $$in$i$i2129 = 0, $$in$i$i2169 = 0, $$in$i$i2174 = 0, $$in$i$i2179 = 0, $$in$i$i2184 = 0, $$in$i$i2189 = 0, $$in$i$i2195 = 0, $$in$i$i2201 = 0, $$in$i$i2206 = 0, $$in$i$i2254 = 0, $$in$i$i2260 = 0, $$in$i$i2266 = 0;
 var $$in$i$i2272 = 0, $$in$i$i2278 = 0, $$in$i$i2283 = 0, $$in$i$i2288 = 0, $$in$i$i2294 = 0, $$in$i$i2300 = 0, $$in$i$i2305 = 0, $$in$i$i2310 = 0, $$in$i$i2316 = 0, $$in$i$i2321 = 0, $$in$i$i2326 = 0, $$in$i$i2332 = 0, $$in$i$i2337 = 0, $$in$i$i2342 = 0, $$in$i$i2347 = 0, $$in$i$i2352 = 0, $$in$i$i2359 = 0, $$in$i$i2364 = 0, $$in$i$i2369 = 0, $$in$i$i2374 = 0;
 var $$in$i$i2379 = 0, $$in$i$i2385 = 0, $$in$i$i2391 = 0, $$in$i$i2417 = 0, $$in$i$i2439 = 0, $$in$i$i2445 = 0, $$in$i$i2451 = 0, $$in$i$i2456 = 0, $$in$i$i613 = 0, $$in$i$i618 = 0, $$in$i$i623 = 0, $$in$i$i628 = 0, $$in$i$i633 = 0, $$in$i$i643 = 0, $$in$i$i655 = 0, $$in$i$i660 = 0, $$in$i$i666 = 0, $$in$i$i671 = 0, $$in$i$i686 = 0, $$in$i$i691 = 0;
 var $$in$i$i697 = 0, $$in$i$i702 = 0, $$in$i$i721 = 0, $$in$i$i727 = 0, $$in$i$i732 = 0, $$in$i$i738 = 0, $$in$i$i743 = 0, $$in$i$i748 = 0, $$in$i$i753 = 0, $$in$i$i758 = 0, $$in$i$i763 = 0, $$in$i$i768 = 0, $$in$i$i773 = 0, $$in$i$i778 = 0, $$in$i$i783 = 0, $$in$i$i789 = 0, $$in$i$i795 = 0, $$in$i$i801 = 0, $$in$i$i806 = 0, $$in$i$i812 = 0;
 var $$in$i$i818 = 0, $$in$i$i824 = 0, $$in$i$i829 = 0, $$in$i$i835 = 0, $$in$i$i841 = 0, $$in$i$i847 = 0, $$in$i$i854 = 0, $$in$i$i859 = 0, $$in$i$i864 = 0, $$in$i$i873 = 0, $$in$i$i880 = 0, $$in$i$i893 = 0, $$in$i$i901 = 0, $$in$i$i921 = 0, $$in$i$i935 = 0, $$in$i$i943 = 0, $$in$i$i957 = 0, $$in$i$i969 = 0, $$in$i$i974 = 0, $$in$i$i979 = 0;
 var $$ph = 0, $$ph2827 = 0, $$ph3018 = 0, $$ph3065 = 0, $$ph3216 = 0, $$pr = 0, $$pre = 0.0, $$pre$phi3226Z2D = 0, $$pre3225$pre$phiZZ2D = 0, $$pre3228 = 0, $$sink = 0.0, $$sink3223 = 0, $$sink5 = 0, $$sink549$sink556$index = 0, $$sink549$sink556$index16 = 0, $10 = 0, $100 = 0, $1000 = 0, $1001 = 0, $1002 = 0;
 var $1003 = 0, $1004 = 0, $1005 = 0, $1006 = 0, $1007 = 0, $1008 = 0, $1009 = 0, $101 = 0, $1010 = 0, $1011 = 0, $1012 = 0, $1013 = 0, $1014 = 0, $1015 = 0, $1016 = 0, $1017 = 0, $1018 = 0, $1019 = 0, $102 = 0, $1020 = 0;
 var $1021 = 0, $1022 = 0, $1023 = 0, $1024 = 0, $1025 = 0, $1026 = 0, $1027 = 0, $1028 = 0, $1029 = 0, $103 = 0, $1030 = 0, $1031 = 0, $1032 = 0, $1033 = 0, $1034 = 0, $1035 = 0, $1036 = 0, $1037 = 0, $1038 = 0, $1039 = 0;
 var $104 = 0, $1040 = 0, $1041 = 0, $1042 = 0, $1043 = 0, $1044 = 0, $1045 = 0, $1046 = 0, $1047 = 0, $1048 = 0, $1049 = 0, $105 = 0, $1050 = 0, $1051 = 0, $1052 = 0, $1053 = 0, $1054 = 0, $1055 = 0, $1056 = 0, $1057 = 0;
 var $1058 = 0, $1059 = 0, $106 = 0, $1060 = 0, $1061 = 0, $1062 = 0, $1063 = 0, $1064 = 0, $1065 = 0, $1066 = 0, $1067 = 0, $1068 = 0, $1069 = 0, $107 = 0, $1070 = 0, $1071 = 0, $1072 = 0, $1073 = 0, $1074 = 0, $1075 = 0;
 var $1076 = 0, $1077 = 0, $1078 = 0, $1079 = 0, $108 = 0, $1080 = 0, $1081 = 0, $1082 = 0, $1083 = 0, $1084 = 0, $1085 = 0, $1086 = 0, $1087 = 0, $1088 = 0, $1089 = 0, $109 = 0, $1090 = 0, $1091 = 0, $1092 = 0, $1093 = 0;
 var $1094 = 0, $1095 = 0, $1096 = 0, $1097 = 0, $1098 = 0, $1099 = 0, $11 = 0, $110 = 0, $1100 = 0, $1101 = 0, $1102 = 0, $1103 = 0, $1104 = 0, $1105 = 0, $1106 = 0, $1107 = 0, $1108 = 0, $1109 = 0, $111 = 0, $1110 = 0;
 var $1111 = 0, $1112 = 0, $1113 = 0, $1114 = 0, $1115 = 0, $1116 = 0, $1117 = 0, $1118 = 0, $1119 = 0, $112 = 0, $1120 = 0, $1121 = 0, $1122 = 0, $1123 = 0, $1124 = 0, $1125 = 0, $1126 = 0, $1127 = 0, $1128 = 0, $1129 = 0;
 var $113 = 0, $1130 = 0, $1131 = 0, $1132 = 0, $1133 = 0, $1134 = 0, $1135 = 0, $1136 = 0, $1137 = 0, $1138 = 0, $1139 = 0, $114 = 0, $1140 = 0, $1141 = 0, $1142 = 0, $1143 = 0, $1144 = 0, $1145 = 0, $1146 = 0, $1147 = 0;
 var $1148 = 0, $1149 = 0, $115 = 0, $1150 = 0, $1151 = 0, $1152 = 0, $1153 = 0, $1154 = 0, $1155 = 0, $1156 = 0, $1157 = 0, $1158 = 0, $1159 = 0, $116 = 0, $1160 = 0, $1161 = 0, $1162 = 0, $1163 = 0, $1164 = 0, $1165 = 0;
 var $1166 = 0, $1167 = 0, $1168 = 0, $1169 = 0, $117 = 0, $1170 = 0, $1171 = 0, $1172 = 0, $1173 = 0, $1174 = 0, $1175 = 0, $1176 = 0, $1177 = 0, $1178 = 0, $1179 = 0, $118 = 0, $1180 = 0, $1181 = 0, $1182 = 0, $1183 = 0;
 var $1184 = 0, $1185 = 0, $1186 = 0, $1187 = 0, $1188 = 0, $1189 = 0, $119 = 0, $1190 = 0, $1191 = 0, $1192 = 0, $1193 = 0, $1194 = 0, $1195 = 0, $1196 = 0, $1197 = 0, $1198 = 0, $1199 = 0, $12 = 0, $120 = 0, $1200 = 0;
 var $1201 = 0, $1202 = 0, $1203 = 0, $1204 = 0, $1205 = 0, $1206 = 0, $1207 = 0, $1208 = 0, $1209 = 0, $121 = 0, $1210 = 0, $1211 = 0, $1212 = 0, $1213 = 0, $1214 = 0, $1215 = 0, $1216 = 0, $1217 = 0, $1218 = 0, $1219 = 0;
 var $122 = 0, $1220 = 0, $1221 = 0, $1222 = 0, $1223 = 0, $1224 = 0, $1225 = 0, $1226 = 0, $1227 = 0, $1228 = 0, $1229 = 0, $123 = 0, $1230 = 0, $1231 = 0, $1232 = 0, $1233 = 0, $1234 = 0, $1235 = 0, $1236 = 0, $1237 = 0;
 var $1238 = 0, $1239 = 0, $124 = 0, $1240 = 0, $1241 = 0, $1242 = 0, $1243 = 0, $1244 = 0, $1245 = 0, $1246 = 0, $1247 = 0, $1248 = 0, $1249 = 0, $125 = 0, $1250 = 0, $1251 = 0, $1252 = 0, $1253 = 0, $1254 = 0, $1255 = 0;
 var $1256 = 0, $1257 = 0, $1258 = 0, $1259 = 0, $126 = 0, $1260 = 0, $1261 = 0, $1262 = 0, $1263 = 0, $1264 = 0, $1265 = 0, $1266 = 0, $1267 = 0, $1268 = 0, $1269 = 0, $127 = 0, $1270 = 0, $1271 = 0, $1272 = 0, $1273 = 0;
 var $1274 = 0, $1275 = 0, $1276 = 0, $1277 = 0, $1278 = 0, $1279 = 0, $128 = 0, $1280 = 0, $1281 = 0, $1282 = 0, $1283 = 0, $1284 = 0, $1285 = 0, $1286 = 0, $1287 = 0, $1288 = 0, $1289 = 0, $129 = 0, $1290 = 0, $1291 = 0;
 var $1292 = 0, $1293 = 0, $1294 = 0, $1295 = 0, $1296 = 0, $1297 = 0, $1298 = 0, $1299 = 0, $13 = 0, $130 = 0, $1300 = 0, $1301 = 0, $1302 = 0, $1303 = 0, $1304 = 0, $1305 = 0, $1306 = 0, $1307 = 0, $1308 = 0, $1309 = 0;
 var $131 = 0, $1310 = 0, $1311 = 0, $1312 = 0, $1313 = 0, $1314 = 0, $1315 = 0, $1316 = 0, $1317 = 0, $1318 = 0, $1319 = 0, $132 = 0, $1320 = 0, $1321 = 0, $1322 = 0, $1323 = 0, $1324 = 0, $1325 = 0, $1326 = 0, $1327 = 0;
 var $1328 = 0, $1329 = 0, $133 = 0, $1330 = 0, $1331 = 0, $1332 = 0, $1333 = 0, $1334 = 0, $1335 = 0, $1336 = 0, $1337 = 0, $1338 = 0, $1339 = 0, $134 = 0, $1340 = 0, $1341 = 0, $1342 = 0, $1343 = 0, $1344 = 0, $1345 = 0;
 var $1346 = 0, $1347 = 0, $1348 = 0, $1349 = 0, $135 = 0, $1350 = 0, $1351 = 0, $1352 = 0, $1353 = 0, $1354 = 0, $1355 = 0, $1356 = 0, $1357 = 0, $1358 = 0, $1359 = 0, $136 = 0, $1360 = 0, $1361 = 0, $1362 = 0, $1363 = 0;
 var $1364 = 0, $1365 = 0, $1366 = 0, $1367 = 0, $1368 = 0, $1369 = 0, $137 = 0, $1370 = 0, $1371 = 0, $1372 = 0, $1373 = 0, $1374 = 0, $1375 = 0, $1376 = 0, $1377 = 0, $1378 = 0, $1379 = 0, $138 = 0, $1380 = 0, $1381 = 0;
 var $1382 = 0, $1383 = 0, $1384 = 0, $1385 = 0, $1386 = 0, $1387 = 0, $1388 = 0, $1389 = 0, $139 = 0, $1390 = 0, $1391 = 0, $1392 = 0, $1393 = 0, $1394 = 0, $1395 = 0, $1396 = 0, $1397 = 0, $1398 = 0, $1399 = 0, $14 = 0;
 var $140 = 0, $1400 = 0, $1401 = 0, $1402 = 0, $1403 = 0, $1404 = 0, $1405 = 0, $1406 = 0, $1407 = 0, $1408 = 0, $1409 = 0, $141 = 0, $1410 = 0, $1411 = 0, $1412 = 0, $1413 = 0, $1414 = 0, $1415 = 0, $1416 = 0, $1417 = 0;
 var $1418 = 0, $1419 = 0, $142 = 0, $1420 = 0, $1421 = 0, $1422 = 0, $1423 = 0, $1424 = 0, $1425 = 0, $1426 = 0, $1427 = 0, $1428 = 0, $1429 = 0, $143 = 0, $1430 = 0, $1431 = 0, $1432 = 0, $1433 = 0, $1434 = 0, $1435 = 0;
 var $1436 = 0, $1437 = 0, $1438 = 0, $1439 = 0, $144 = 0, $1440 = 0, $1441 = 0, $1442 = 0, $1443 = 0, $1444 = 0, $1445 = 0, $1446 = 0, $1447 = 0, $1448 = 0, $1449 = 0, $145 = 0, $1450 = 0, $1451 = 0, $1452 = 0, $1453 = 0;
 var $1454 = 0, $1455 = 0, $1456 = 0, $1457 = 0, $1458 = 0, $1459 = 0, $146 = 0, $1460 = 0, $1461 = 0, $1462 = 0, $1463 = 0, $1464 = 0, $1465 = 0, $1466 = 0, $1467 = 0, $1468 = 0, $1469 = 0, $147 = 0, $1470 = 0, $1471 = 0;
 var $1472 = 0, $1473 = 0, $1474 = 0, $1475 = 0, $1476 = 0, $1477 = 0, $1478 = 0, $1479 = 0, $148 = 0, $1480 = 0, $1481 = 0, $1482 = 0, $1483 = 0, $1484 = 0, $1485 = 0, $1486 = 0, $1487 = 0, $1488 = 0, $1489 = 0, $149 = 0;
 var $1490 = 0, $1491 = 0, $1492 = 0, $1493 = 0, $1494 = 0, $1495 = 0, $1496 = 0, $1497 = 0, $1498 = 0, $1499 = 0, $15 = 0, $150 = 0, $1500 = 0, $1501 = 0, $1502 = 0, $1503 = 0, $1504 = 0, $1505 = 0, $1506 = 0, $1507 = 0;
 var $1508 = 0, $1509 = 0, $151 = 0, $1510 = 0, $1511 = 0, $1512 = 0, $1513 = 0, $1514 = 0, $1515 = 0, $1516 = 0, $1517 = 0, $1518 = 0, $1519 = 0, $152 = 0, $1520 = 0, $1521 = 0, $1522 = 0, $1523 = 0, $1524 = 0, $1525 = 0;
 var $1526 = 0, $1527 = 0, $1528 = 0, $1529 = 0, $153 = 0, $1530 = 0, $1531 = 0, $1532 = 0, $1533 = 0, $1534 = 0, $1535 = 0, $1536 = 0, $1537 = 0, $1538 = 0, $1539 = 0, $154 = 0, $1540 = 0, $1541 = 0, $1542 = 0, $1543 = 0;
 var $1544 = 0, $1545 = 0, $1546 = 0, $1547 = 0, $1548 = 0, $1549 = 0, $155 = 0, $1550 = 0, $1551 = 0, $1552 = 0, $1553 = 0, $1554 = 0, $1555 = 0, $1556 = 0, $1557 = 0, $1558 = 0, $1559 = 0, $156 = 0, $1560 = 0, $1561 = 0;
 var $1562 = 0, $1563 = 0, $1564 = 0, $1565 = 0, $1566 = 0, $1567 = 0, $1568 = 0, $1569 = 0, $157 = 0, $1570 = 0, $1571 = 0, $1572 = 0, $1573 = 0, $1574 = 0, $1575 = 0, $1576 = 0, $1577 = 0, $1578 = 0, $1579 = 0, $158 = 0;
 var $1580 = 0, $1581 = 0, $1582 = 0, $1583 = 0, $1584 = 0, $1585 = 0, $1586 = 0, $1587 = 0, $1588 = 0, $1589 = 0, $159 = 0, $1590 = 0, $1591 = 0, $1592 = 0, $1593 = 0, $1594 = 0, $1595 = 0, $1596 = 0, $1597 = 0, $1598 = 0;
 var $1599 = 0, $16 = 0, $160 = 0, $1600 = 0, $1601 = 0, $1602 = 0, $1603 = 0, $1604 = 0, $1605 = 0, $1606 = 0, $1607 = 0, $1608 = 0, $1609 = 0, $161 = 0, $1610 = 0, $1611 = 0, $1612 = 0, $1613 = 0, $1614 = 0, $1615 = 0;
 var $1616 = 0, $1617 = 0, $1618 = 0, $1619 = 0, $162 = 0, $1620 = 0, $1621 = 0, $1622 = 0, $1623 = 0, $1624 = 0, $1625 = 0, $1626 = 0, $1627 = 0, $1628 = 0, $1629 = 0, $163 = 0, $1630 = 0, $1631 = 0, $1632 = 0, $1633 = 0;
 var $1634 = 0, $1635 = 0, $1636 = 0, $1637 = 0, $1638 = 0, $1639 = 0, $164 = 0, $1640 = 0, $1641 = 0, $1642 = 0, $1643 = 0, $1644 = 0, $1645 = 0, $1646 = 0, $1647 = 0, $1648 = 0, $1649 = 0, $165 = 0, $1650 = 0, $1651 = 0;
 var $1652 = 0, $1653 = 0, $1654 = 0, $1655 = 0, $1656 = 0, $1657 = 0, $1658 = 0, $1659 = 0, $166 = 0, $1660 = 0, $1661 = 0, $1662 = 0, $1663 = 0, $1664 = 0, $1665 = 0, $1666 = 0, $1667 = 0, $1668 = 0, $1669 = 0, $167 = 0;
 var $1670 = 0, $1671 = 0, $1672 = 0, $1673 = 0, $1674 = 0, $1675 = 0, $1676 = 0, $1677 = 0, $1678 = 0, $1679 = 0, $168 = 0, $1680 = 0, $1681 = 0, $1682 = 0, $1683 = 0, $1684 = 0, $1685 = 0, $1686 = 0, $1687 = 0, $1688 = 0;
 var $1689 = 0, $169 = 0, $1690 = 0, $1691 = 0, $1692 = 0, $1693 = 0, $1694 = 0, $1695 = 0, $1696 = 0, $1697 = 0, $1698 = 0, $1699 = 0, $17 = 0, $170 = 0, $1700 = 0, $1701 = 0, $1702 = 0, $1703 = 0, $1704 = 0, $1705 = 0;
 var $1706 = 0, $1707 = 0, $1708 = 0, $1709 = 0, $171 = 0, $1710 = 0, $1711 = 0, $1712 = 0, $1713 = 0, $1714 = 0, $1715 = 0, $1716 = 0, $1717 = 0, $1718 = 0, $1719 = 0, $172 = 0.0, $1720 = 0, $1721 = 0, $1722 = 0, $1723 = 0;
 var $1724 = 0, $1725 = 0, $1726 = 0, $1727 = 0, $1728 = 0, $1729 = 0, $173 = 0, $1730 = 0, $1731 = 0, $1732 = 0, $1733 = 0, $1734 = 0, $1735 = 0, $1736 = 0, $1737 = 0, $1738 = 0, $1739 = 0, $174 = 0, $1740 = 0, $1741 = 0;
 var $1742 = 0, $1743 = 0, $1744 = 0, $1745 = 0, $1746 = 0, $1747 = 0, $1748 = 0, $1749 = 0, $175 = 0.0, $1750 = 0, $1751 = 0, $1752 = 0, $1753 = 0, $1754 = 0, $1755 = 0, $1756 = 0.0, $1757 = 0, $1758 = 0, $1759 = 0, $176 = 0;
 var $1760 = 0, $1761 = 0, $1762 = 0, $1763 = 0, $1764 = 0, $1765 = 0, $1766 = 0, $1767 = 0, $1768 = 0, $1769 = 0, $177 = 0, $1770 = 0, $1771 = 0, $1772 = 0, $1773 = 0, $1774 = 0, $1775 = 0, $1776 = 0, $1777 = 0, $1778 = 0;
 var $1779 = 0, $178 = 0, $1780 = 0, $1781 = 0, $1782 = 0, $1783 = 0, $1784 = 0, $1785 = 0, $1786 = 0, $1787 = 0, $1788 = 0, $1789 = 0, $179 = 0, $1790 = 0, $1791 = 0, $1792 = 0, $1793 = 0, $1794 = 0, $1795 = 0, $1796 = 0;
 var $1797 = 0, $1798 = 0, $1799 = 0, $18 = 0, $180 = 0, $1800 = 0, $1801 = 0, $1802 = 0, $1803 = 0, $1804 = 0, $1805 = 0, $1806 = 0, $1807 = 0, $1808 = 0, $1809 = 0, $181 = 0, $1810 = 0, $1811 = 0, $1812 = 0, $1813 = 0;
 var $1814 = 0, $1815 = 0, $1816 = 0, $1817 = 0, $1818 = 0, $1819 = 0, $182 = 0, $1820 = 0, $1821 = 0, $1822 = 0, $1823 = 0, $1824 = 0, $1825 = 0, $1826 = 0, $1827 = 0, $1828 = 0, $1829 = 0, $183 = 0, $1830 = 0, $1831 = 0;
 var $1832 = 0, $1833 = 0, $1834 = 0, $1835 = 0, $1836 = 0, $1837 = 0, $1838 = 0, $1839 = 0, $184 = 0, $1840 = 0, $1841 = 0, $1842 = 0, $1843 = 0, $1844 = 0, $1845 = 0, $1846 = 0, $1847 = 0, $1848 = 0, $1849 = 0, $185 = 0;
 var $1850 = 0, $1851 = 0, $1852 = 0, $1853 = 0, $1854 = 0, $1855 = 0, $1856 = 0, $1857 = 0, $1858 = 0, $1859 = 0, $186 = 0, $1860 = 0, $1861 = 0, $1862 = 0, $1863 = 0, $1864 = 0, $1865 = 0, $1866 = 0, $1867 = 0, $1868 = 0;
 var $1869 = 0, $187 = 0.0, $1870 = 0, $1871 = 0, $1872 = 0, $1873 = 0, $1874 = 0, $1875 = 0, $1876 = 0, $1877 = 0, $1878 = 0, $1879 = 0, $188 = 0, $1880 = 0, $1881 = 0, $1882 = 0, $1883 = 0, $1884 = 0, $1885 = 0, $1886 = 0;
 var $1887 = 0, $1888 = 0, $1889 = 0, $189 = 0, $1890 = 0, $1891 = 0, $1892 = 0, $1893 = 0, $1894 = 0, $1895 = 0, $1896 = 0, $1897 = 0, $1898 = 0, $1899 = 0, $19 = 0, $190 = 0, $1900 = 0, $1901 = 0, $1902 = 0, $1903 = 0;
 var $1904 = 0, $1905 = 0, $1906 = 0, $1907 = 0, $1908 = 0, $1909 = 0, $191 = 0, $1910 = 0, $1911 = 0, $1912 = 0, $1913 = 0, $1914 = 0, $1915 = 0, $1916 = 0, $1917 = 0, $1918 = 0, $1919 = 0, $192 = 0, $1920 = 0, $1921 = 0;
 var $1922 = 0, $1923 = 0, $1924 = 0, $1925 = 0, $1926 = 0, $1927 = 0, $1928 = 0, $1929 = 0, $193 = 0, $1930 = 0, $1931 = 0, $1932 = 0, $1933 = 0, $1934 = 0, $1935 = 0, $1936 = 0, $1937 = 0, $1938 = 0, $1939 = 0, $194 = 0;
 var $1940 = 0, $1941 = 0, $1942 = 0, $1943 = 0, $1944 = 0, $1945 = 0, $1946 = 0, $1947 = 0, $1948 = 0, $1949 = 0, $195 = 0, $1950 = 0, $1951 = 0, $1952 = 0, $1953 = 0, $1954 = 0, $1955 = 0, $1956 = 0, $1957 = 0, $1958 = 0;
 var $1959 = 0, $196 = 0, $1960 = 0, $1961 = 0, $1962 = 0, $1963 = 0, $1964 = 0, $1965 = 0, $1966 = 0, $1967 = 0, $1968 = 0, $1969 = 0, $197 = 0, $1970 = 0, $1971 = 0, $1972 = 0, $1973 = 0, $1974 = 0, $1975 = 0, $1976 = 0;
 var $1977 = 0, $1978 = 0, $1979 = 0, $198 = 0, $1980 = 0, $1981 = 0, $1982 = 0, $1983 = 0, $1984 = 0, $1985 = 0, $1986 = 0, $1987 = 0, $1988 = 0, $1989 = 0, $199 = 0, $1990 = 0, $1991 = 0, $1992 = 0, $1993 = 0, $1994 = 0;
 var $1995 = 0, $1996 = 0, $1997 = 0, $1998 = 0, $1999 = 0, $2 = 0, $20 = 0, $200 = 0, $2000 = 0, $2001 = 0, $2002 = 0, $2003 = 0, $2004 = 0, $2005 = 0, $2006 = 0, $2007 = 0, $2008 = 0, $2009 = 0, $201 = 0, $2010 = 0;
 var $2011 = 0, $2012 = 0, $2013 = 0, $2014 = 0, $2015 = 0, $2016 = 0, $2017 = 0, $2018 = 0, $2019 = 0, $202 = 0, $2020 = 0, $2021 = 0, $2022 = 0, $2023 = 0, $2024 = 0, $2025 = 0, $2026 = 0, $2027 = 0, $2028 = 0, $2029 = 0;
 var $203 = 0, $2030 = 0, $2031 = 0, $2032 = 0, $2033 = 0, $2034 = 0, $2035 = 0, $2036 = 0, $2037 = 0, $2038 = 0, $2039 = 0, $204 = 0, $2040 = 0, $2041 = 0, $2042 = 0, $2043 = 0, $2044 = 0, $2045 = 0, $2046 = 0, $2047 = 0;
 var $2048 = 0, $2049 = 0, $205 = 0, $2050 = 0, $2051 = 0, $2052 = 0, $2053 = 0, $2054 = 0, $2055 = 0, $2056 = 0, $2057 = 0, $2058 = 0, $2059 = 0, $206 = 0, $2060 = 0, $2061 = 0, $2062 = 0, $2063 = 0, $2064 = 0, $2065 = 0;
 var $2066 = 0, $2067 = 0, $2068 = 0, $2069 = 0, $207 = 0, $2070 = 0, $2071 = 0, $2072 = 0, $2073 = 0, $2074 = 0, $2075 = 0, $2076 = 0, $2077 = 0, $2078 = 0, $2079 = 0, $208 = 0, $2080 = 0, $2081 = 0, $2082 = 0, $2083 = 0;
 var $2084 = 0, $2085 = 0, $2086 = 0, $2087 = 0, $2088 = 0, $2089 = 0, $209 = 0, $2090 = 0, $2091 = 0, $2092 = 0, $2093 = 0, $2094 = 0, $2095 = 0, $2096 = 0, $2097 = 0, $2098 = 0, $2099 = 0, $21 = 0, $210 = 0, $2100 = 0;
 var $2101 = 0, $2102 = 0, $2103 = 0, $2104 = 0, $2105 = 0, $2106 = 0, $2107 = 0, $2108 = 0, $2109 = 0, $211 = 0.0, $2110 = 0, $2111 = 0, $2112 = 0, $2113 = 0, $2114 = 0, $2115 = 0, $2116 = 0, $2117 = 0, $2118 = 0, $2119 = 0;
 var $212 = 0, $2120 = 0, $2121 = 0, $2122 = 0, $2123 = 0, $2124 = 0, $2125 = 0, $2126 = 0, $2127 = 0, $2128 = 0, $2129 = 0, $213 = 0, $2130 = 0, $2131 = 0, $2132 = 0, $2133 = 0, $2134 = 0, $2135 = 0, $2136 = 0, $2137 = 0;
 var $2138 = 0, $2139 = 0, $214 = 0, $2140 = 0, $2141 = 0, $2142 = 0, $2143 = 0, $2144 = 0, $2145 = 0, $2146 = 0, $2147 = 0, $2148 = 0, $2149 = 0, $215 = 0, $2150 = 0, $2151 = 0, $2152 = 0, $2153 = 0, $2154 = 0, $2155 = 0;
 var $2156 = 0, $2157 = 0, $2158 = 0, $2159 = 0, $216 = 0, $2160 = 0, $2161 = 0, $2162 = 0, $2163 = 0, $2164 = 0, $2165 = 0, $2166 = 0, $2167 = 0, $2168 = 0, $2169 = 0, $217 = 0, $2170 = 0, $2171 = 0, $2172 = 0, $2173 = 0;
 var $2174 = 0, $2175 = 0, $2176 = 0, $2177 = 0, $2178 = 0, $2179 = 0, $218 = 0, $2180 = 0, $2181 = 0, $2182 = 0, $2183 = 0, $2184 = 0, $2185 = 0, $2186 = 0, $2187 = 0, $2188 = 0, $2189 = 0, $219 = 0, $2190 = 0, $2191 = 0;
 var $2192 = 0, $2193 = 0, $2194 = 0, $2195 = 0, $2196 = 0, $2197 = 0, $2198 = 0, $2199 = 0, $22 = 0, $220 = 0, $2200 = 0, $2201 = 0, $2202 = 0, $2203 = 0, $2204 = 0, $2205 = 0, $2206 = 0, $2207 = 0, $2208 = 0, $2209 = 0;
 var $221 = 0, $2210 = 0, $2211 = 0, $2212 = 0, $2213 = 0, $2214 = 0, $2215 = 0, $2216 = 0, $2217 = 0, $2218 = 0, $2219 = 0, $222 = 0, $2220 = 0, $2221 = 0, $2222 = 0, $2223 = 0, $2224 = 0, $2225 = 0, $2226 = 0, $2227 = 0;
 var $2228 = 0, $2229 = 0, $223 = 0, $2230 = 0, $2231 = 0, $2232 = 0, $2233 = 0, $2234 = 0, $2235 = 0, $2236 = 0, $2237 = 0, $2238 = 0, $2239 = 0, $224 = 0, $2240 = 0, $2241 = 0, $2242 = 0, $2243 = 0, $2244 = 0, $2245 = 0;
 var $2246 = 0, $2247 = 0, $2248 = 0, $2249 = 0, $225 = 0, $2250 = 0, $2251 = 0, $2252 = 0, $2253 = 0, $2254 = 0, $2255 = 0, $2256 = 0, $2257 = 0, $2258 = 0, $2259 = 0, $226 = 0, $2260 = 0, $2261 = 0, $2262 = 0, $2263 = 0;
 var $2264 = 0, $2265 = 0, $2266 = 0, $2267 = 0, $2268 = 0, $2269 = 0, $227 = 0, $2270 = 0, $2271 = 0, $2272 = 0, $2273 = 0, $2274 = 0, $2275 = 0, $2276 = 0, $2277 = 0, $2278 = 0, $2279 = 0, $228 = 0, $2280 = 0, $2281 = 0.0;
 var $2282 = 0, $2283 = 0, $2284 = 0, $2285 = 0.0, $2286 = 0, $2287 = 0, $2288 = 0, $2289 = 0, $229 = 0, $2290 = 0, $2291 = 0, $2292 = 0, $2293 = 0, $2294 = 0, $2295 = 0, $2296 = 0, $2297 = 0, $2298 = 0, $2299 = 0, $23 = 0;
 var $230 = 0, $2300 = 0, $2301 = 0, $2302 = 0, $2303 = 0, $2304 = 0, $2305 = 0, $2306 = 0, $2307 = 0, $2308 = 0, $2309 = 0, $231 = 0, $2310 = 0.0, $2311 = 0, $2312 = 0, $2313 = 0, $2314 = 0, $2315 = 0, $2316 = 0, $2317 = 0;
 var $2318 = 0, $2319 = 0, $232 = 0, $2320 = 0, $2321 = 0, $2322 = 0, $2323 = 0, $2324 = 0, $2325 = 0, $2326 = 0, $2327 = 0, $2328 = 0, $2329 = 0, $233 = 0, $2330 = 0, $2331 = 0, $2332 = 0, $2333 = 0, $2334 = 0, $2335 = 0;
 var $2336 = 0, $2337 = 0, $2338 = 0, $2339 = 0, $234 = 0, $2340 = 0, $2341 = 0, $2342 = 0, $2343 = 0, $2344 = 0, $2345 = 0, $2346 = 0, $2347 = 0, $2348 = 0, $2349 = 0, $235 = 0, $2350 = 0, $2351 = 0, $2352 = 0, $2353 = 0;
 var $2354 = 0, $2355 = 0, $2356 = 0, $2357 = 0, $2358 = 0, $2359 = 0, $236 = 0, $2360 = 0, $2361 = 0, $2362 = 0, $2363 = 0, $2364 = 0, $2365 = 0, $2366 = 0, $2367 = 0, $2368 = 0, $2369 = 0, $237 = 0, $2370 = 0, $2371 = 0;
 var $2372 = 0, $2373 = 0, $2374 = 0, $2375 = 0, $2376 = 0, $2377 = 0, $2378 = 0, $2379 = 0, $238 = 0, $2380 = 0, $2381 = 0, $2382 = 0, $2383 = 0, $2384 = 0, $2385 = 0, $2386 = 0, $2387 = 0, $2388 = 0, $2389 = 0, $239 = 0;
 var $2390 = 0, $2391 = 0, $2392 = 0, $2393 = 0, $2394 = 0, $2395 = 0, $2396 = 0, $2397 = 0, $2398 = 0, $2399 = 0, $24 = 0, $240 = 0, $2400 = 0, $2401 = 0, $2402 = 0, $2403 = 0, $2404 = 0, $2405 = 0, $2406 = 0, $2407 = 0;
 var $2408 = 0, $2409 = 0, $241 = 0, $2410 = 0, $2411 = 0, $2412 = 0, $2413 = 0, $2414 = 0, $2415 = 0, $2416 = 0, $2417 = 0, $2418 = 0, $2419 = 0, $242 = 0, $2420 = 0, $2421 = 0, $2422 = 0, $2423 = 0, $2424 = 0, $2425 = 0;
 var $2426 = 0, $2427 = 0, $2428 = 0, $2429 = 0, $243 = 0, $2430 = 0, $2431 = 0, $2432 = 0, $2433 = 0, $2434 = 0, $2435 = 0, $2436 = 0, $2437 = 0, $2438 = 0, $2439 = 0, $244 = 0, $2440 = 0, $2441 = 0, $2442 = 0, $2443 = 0;
 var $2444 = 0, $2445 = 0, $2446 = 0, $2447 = 0, $2448 = 0, $2449 = 0, $245 = 0, $2450 = 0, $2451 = 0, $2452 = 0, $2453 = 0, $2454 = 0, $2455 = 0, $2456 = 0, $2457 = 0, $2458 = 0, $2459 = 0, $246 = 0, $2460 = 0, $2461 = 0;
 var $2462 = 0, $2463 = 0, $2464 = 0, $2465 = 0, $2466 = 0, $2467 = 0, $2468 = 0, $2469 = 0, $247 = 0, $2470 = 0, $2471 = 0, $2472 = 0, $2473 = 0, $2474 = 0, $2475 = 0, $2476 = 0, $2477 = 0, $2478 = 0, $2479 = 0, $248 = 0;
 var $2480 = 0, $2481 = 0, $2482 = 0, $2483 = 0, $2484 = 0, $2485 = 0, $2486 = 0, $2487 = 0, $2488 = 0, $2489 = 0, $249 = 0, $2490 = 0, $2491 = 0, $2492 = 0, $2493 = 0, $2494 = 0, $2495 = 0, $2496 = 0, $2497 = 0, $2498 = 0;
 var $2499 = 0, $25 = 0, $250 = 0, $2500 = 0, $2501 = 0, $2502 = 0, $2503 = 0, $2504 = 0, $2505 = 0, $2506 = 0, $2507 = 0, $2508 = 0, $2509 = 0, $251 = 0, $2510 = 0, $2511 = 0, $2512 = 0, $2513 = 0, $2514 = 0, $2515 = 0;
 var $2516 = 0, $2517 = 0, $2518 = 0, $2519 = 0, $252 = 0, $2520 = 0, $2521 = 0, $2522 = 0, $2523 = 0, $2524 = 0, $2525 = 0, $2526 = 0, $2527 = 0, $2528 = 0.0, $2529 = 0, $253 = 0, $2530 = 0, $2531 = 0, $2532 = 0, $2533 = 0;
 var $2534 = 0, $2535 = 0, $2536 = 0, $2537 = 0, $2538 = 0, $2539 = 0, $254 = 0, $2540 = 0, $2541 = 0, $2542 = 0, $2543 = 0, $2544 = 0, $2545 = 0, $2546 = 0, $2547 = 0, $2548 = 0, $2549 = 0, $255 = 0, $2550 = 0, $2551 = 0;
 var $2552 = 0, $2553 = 0, $2554 = 0, $2555 = 0, $2556 = 0, $2557 = 0, $2558 = 0, $2559 = 0, $256 = 0, $2560 = 0, $2561 = 0, $2562 = 0, $2563 = 0, $2564 = 0, $2565 = 0, $2566 = 0, $2567 = 0, $2568 = 0, $2569 = 0, $257 = 0;
 var $2570 = 0, $2571 = 0, $2572 = 0, $2573 = 0, $2574 = 0, $2575 = 0, $2576 = 0, $2577 = 0, $2578 = 0.0, $2579 = 0, $258 = 0, $2580 = 0, $2581 = 0, $2582 = 0, $2583 = 0, $2584 = 0, $2585 = 0, $2586 = 0, $2587 = 0, $2588 = 0;
 var $2589 = 0, $259 = 0, $2590 = 0, $2591 = 0, $2592 = 0, $2593 = 0, $2594 = 0, $2595 = 0, $2596 = 0, $2597 = 0, $2598 = 0.0, $2599 = 0, $26 = 0, $260 = 0, $2600 = 0, $2601 = 0, $2602 = 0, $2603 = 0, $2604 = 0, $2605 = 0;
 var $2606 = 0, $2607 = 0, $2608 = 0, $2609 = 0, $261 = 0, $2610 = 0, $2611 = 0, $2612 = 0, $2613 = 0, $2614 = 0, $2615 = 0, $2616 = 0, $2617 = 0, $2618 = 0, $2619 = 0, $262 = 0, $2620 = 0, $2621 = 0, $2622 = 0, $2623 = 0;
 var $2624 = 0, $2625 = 0, $2626 = 0, $2627 = 0, $2628 = 0, $2629 = 0, $263 = 0, $2630 = 0, $2631 = 0, $2632 = 0, $2633 = 0.0, $2634 = 0, $2635 = 0, $2636 = 0, $2637 = 0, $2638 = 0, $2639 = 0, $264 = 0, $2640 = 0, $2641 = 0;
 var $2642 = 0, $2643 = 0, $2644 = 0, $2645 = 0, $2646 = 0, $2647 = 0, $2648 = 0, $2649 = 0, $265 = 0, $2650 = 0, $2651 = 0, $2652 = 0, $2653 = 0, $2654 = 0, $2655 = 0, $2656 = 0, $2657 = 0, $2658 = 0, $2659 = 0, $266 = 0;
 var $2660 = 0, $2661 = 0, $2662 = 0, $2663 = 0, $2664 = 0, $2665 = 0, $2666 = 0, $2667 = 0, $2668 = 0, $2669 = 0, $267 = 0, $2670 = 0, $2671 = 0, $2672 = 0, $2673 = 0, $2674 = 0, $2675 = 0, $2676 = 0, $2677 = 0, $2678 = 0;
 var $2679 = 0, $268 = 0, $2680 = 0, $2681 = 0, $2682 = 0, $2683 = 0, $2684 = 0, $2685 = 0, $2686 = 0, $2687 = 0, $2688 = 0, $2689 = 0, $269 = 0, $2690 = 0, $2691 = 0, $2692 = 0, $2693 = 0, $2694 = 0, $2695 = 0, $2696 = 0;
 var $2697 = 0, $2698 = 0, $2699 = 0, $27 = 0, $270 = 0, $2700 = 0, $2701 = 0, $2702 = 0, $2703 = 0, $2704 = 0, $2705 = 0, $2706 = 0, $2707 = 0, $2708 = 0, $2709 = 0, $271 = 0, $2710 = 0, $2711 = 0, $2712 = 0, $2713 = 0;
 var $2714 = 0, $2715 = 0, $2716 = 0, $2717 = 0, $2718 = 0, $2719 = 0, $272 = 0, $2720 = 0, $2721 = 0, $2722 = 0, $2723 = 0, $2724 = 0, $2725 = 0, $2726 = 0, $2727 = 0, $2728 = 0, $2729 = 0, $273 = 0, $2730 = 0, $2731 = 0;
 var $2732 = 0, $2733 = 0, $2734 = 0, $2735 = 0, $2736 = 0, $2737 = 0, $2738 = 0, $2739 = 0, $274 = 0, $2740 = 0, $2741 = 0, $2742 = 0, $2743 = 0, $2744 = 0, $2745 = 0, $2746 = 0, $2747 = 0, $2748 = 0, $2749 = 0, $275 = 0;
 var $2750 = 0, $2751 = 0, $2752 = 0, $2753 = 0, $2754 = 0, $2755 = 0, $2756 = 0, $2757 = 0, $2758 = 0, $2759 = 0, $276 = 0, $2760 = 0, $2761 = 0, $2762 = 0, $2763 = 0, $2764 = 0, $2765 = 0, $2766 = 0, $2767 = 0, $2768 = 0;
 var $2769 = 0, $277 = 0, $2770 = 0, $2771 = 0, $2772 = 0, $2773 = 0, $2774 = 0, $2775 = 0, $2776 = 0, $2777 = 0, $2778 = 0, $2779 = 0, $278 = 0, $2780 = 0, $2781 = 0, $2782 = 0, $2783 = 0, $2784 = 0, $2785 = 0, $2786 = 0;
 var $2787 = 0, $2788 = 0, $2789 = 0, $279 = 0, $2790 = 0, $2791 = 0, $2792 = 0, $2793 = 0, $2794 = 0, $2795 = 0, $2796 = 0, $2797 = 0, $2798 = 0, $2799 = 0, $28 = 0, $280 = 0, $2800 = 0, $2801 = 0, $2802 = 0, $2803 = 0;
 var $2804 = 0, $2805 = 0, $2806 = 0, $2807 = 0, $2808 = 0, $2809 = 0, $281 = 0, $2810 = 0, $2811 = 0, $2812 = 0, $2813 = 0, $2814 = 0, $2815 = 0, $2816 = 0, $2817 = 0, $2818 = 0, $2819 = 0, $282 = 0, $2820 = 0, $2821 = 0;
 var $2822 = 0, $2823 = 0, $2824 = 0, $2825 = 0, $2826 = 0, $2827 = 0, $2828 = 0, $2829 = 0, $283 = 0, $2830 = 0, $2831 = 0, $2832 = 0, $2833 = 0, $2834 = 0, $2835 = 0, $2836 = 0, $2837 = 0, $2838 = 0, $2839 = 0, $284 = 0;
 var $2840 = 0, $2841 = 0, $2842 = 0, $2843 = 0, $2844 = 0, $2845 = 0, $2846 = 0, $2847 = 0, $2848 = 0, $2849 = 0, $285 = 0, $2850 = 0, $2851 = 0, $2852 = 0, $2853 = 0, $2854 = 0, $2855 = 0, $2856 = 0, $2857 = 0, $2858 = 0;
 var $2859 = 0, $286 = 0, $2860 = 0, $2861 = 0, $2862 = 0, $2863 = 0, $2864 = 0, $2865 = 0, $2866 = 0, $2867 = 0, $2868 = 0, $2869 = 0, $287 = 0, $2870 = 0, $2871 = 0, $2872 = 0, $2873 = 0, $2874 = 0, $2875 = 0, $2876 = 0;
 var $2877 = 0, $2878 = 0, $2879 = 0, $288 = 0, $2880 = 0, $2881 = 0, $2882 = 0, $2883 = 0, $2884 = 0, $2885 = 0, $2886 = 0, $2887 = 0, $2888 = 0, $2889 = 0, $289 = 0, $2890 = 0, $2891 = 0, $2892 = 0, $2893 = 0, $2894 = 0;
 var $2895 = 0, $2896 = 0, $2897 = 0, $2898 = 0, $2899 = 0, $29 = 0, $290 = 0, $2900 = 0, $2901 = 0, $2902 = 0, $2903 = 0, $2904 = 0, $2905 = 0, $2906 = 0, $2907 = 0, $2908 = 0, $2909 = 0, $291 = 0, $2910 = 0, $2911 = 0;
 var $2912 = 0, $2913 = 0, $2914 = 0, $2915 = 0, $2916 = 0, $2917 = 0, $2918 = 0, $2919 = 0, $292 = 0, $2920 = 0, $2921 = 0, $2922 = 0, $2923 = 0, $2924 = 0, $2925 = 0, $2926 = 0, $2927 = 0, $2928 = 0, $2929 = 0, $293 = 0;
 var $2930 = 0, $2931 = 0, $2932 = 0, $2933 = 0, $2934 = 0, $2935 = 0, $2936 = 0, $2937 = 0, $2938 = 0, $2939 = 0, $294 = 0, $2940 = 0, $2941 = 0, $2942 = 0, $2943 = 0, $2944 = 0, $2945 = 0, $2946 = 0, $2947 = 0, $2948 = 0;
 var $2949 = 0, $295 = 0, $2950 = 0, $2951 = 0, $2952 = 0, $2953 = 0, $2954 = 0, $2955 = 0, $2956 = 0, $2957 = 0, $2958 = 0, $2959 = 0, $296 = 0, $2960 = 0, $2961 = 0, $2962 = 0, $2963 = 0, $2964 = 0, $2965 = 0, $2966 = 0;
 var $2967 = 0, $2968 = 0, $2969 = 0, $297 = 0, $2970 = 0, $2971 = 0, $2972 = 0, $2973 = 0, $2974 = 0, $2975 = 0, $2976 = 0, $2977 = 0, $2978 = 0, $2979 = 0, $298 = 0, $2980 = 0, $2981 = 0, $2982 = 0, $2983 = 0, $2984 = 0;
 var $2985 = 0, $2986 = 0, $2987 = 0, $2988 = 0, $2989 = 0, $299 = 0, $2990 = 0, $2991 = 0, $2992 = 0, $2993 = 0, $2994 = 0, $2995 = 0, $2996 = 0, $2997 = 0, $2998 = 0, $2999 = 0, $3 = 0, $30 = 0, $300 = 0, $3000 = 0;
 var $3001 = 0, $3002 = 0, $3003 = 0, $3004 = 0, $3005 = 0, $3006 = 0, $3007 = 0, $3008 = 0, $3009 = 0, $301 = 0, $3010 = 0, $3011 = 0, $3012 = 0, $3013 = 0, $3014 = 0, $3015 = 0, $3016 = 0, $3017 = 0, $3018 = 0, $3019 = 0;
 var $302 = 0, $3020 = 0, $3021 = 0, $3022 = 0, $3023 = 0, $3024 = 0, $3025 = 0, $3026 = 0, $3027 = 0, $3028 = 0, $3029 = 0, $303 = 0, $3030 = 0, $3031 = 0, $3032 = 0, $3033 = 0, $3034 = 0, $3035 = 0, $3036 = 0, $3037 = 0;
 var $3038 = 0, $3039 = 0, $304 = 0, $3040 = 0, $3041 = 0, $3042 = 0, $3043 = 0, $3044 = 0, $3045 = 0, $3046 = 0, $3047 = 0, $3048 = 0, $3049 = 0, $305 = 0, $3050 = 0, $3051 = 0, $3052 = 0, $3053 = 0, $3054 = 0, $3055 = 0;
 var $3056 = 0, $3057 = 0, $3058 = 0, $3059 = 0, $306 = 0, $3060 = 0, $3061 = 0, $3062 = 0, $3063 = 0, $3064 = 0, $3065 = 0, $3066 = 0, $3067 = 0, $3068 = 0, $3069 = 0, $307 = 0, $3070 = 0, $3071 = 0, $3072 = 0, $3073 = 0;
 var $3074 = 0, $3075 = 0, $3076 = 0, $3077 = 0, $3078 = 0, $3079 = 0, $308 = 0, $3080 = 0, $3081 = 0, $3082 = 0, $3083 = 0, $3084 = 0, $3085 = 0, $3086 = 0, $3087 = 0, $3088 = 0, $3089 = 0, $309 = 0, $3090 = 0, $3091 = 0;
 var $3092 = 0, $3093 = 0, $3094 = 0, $3095 = 0, $3096 = 0, $3097 = 0, $3098 = 0, $3099 = 0, $31 = 0, $310 = 0, $3100 = 0, $3101 = 0, $3102 = 0, $3103 = 0, $3104 = 0, $3105 = 0, $3106 = 0, $3107 = 0, $3108 = 0, $3109 = 0;
 var $311 = 0, $3110 = 0, $3111 = 0, $3112 = 0, $3113 = 0, $3114 = 0, $3115 = 0, $3116 = 0, $3117 = 0, $3118 = 0, $3119 = 0, $312 = 0, $3120 = 0, $3121 = 0, $3122 = 0, $3123 = 0, $3124 = 0, $3125 = 0, $3126 = 0, $3127 = 0;
 var $3128 = 0, $3129 = 0, $313 = 0, $3130 = 0, $3131 = 0, $3132 = 0, $3133 = 0, $3134 = 0, $3135 = 0, $3136 = 0, $3137 = 0, $3138 = 0, $3139 = 0, $314 = 0, $3140 = 0, $3141 = 0, $3142 = 0, $3143 = 0, $3144 = 0, $3145 = 0;
 var $3146 = 0, $3147 = 0, $3148 = 0, $3149 = 0, $315 = 0, $3150 = 0, $3151 = 0, $3152 = 0, $3153 = 0, $3154 = 0, $3155 = 0, $3156 = 0, $3157 = 0, $3158 = 0, $3159 = 0, $316 = 0, $3160 = 0, $3161 = 0, $3162 = 0, $3163 = 0;
 var $3164 = 0, $3165 = 0, $3166 = 0, $3167 = 0, $3168 = 0, $3169 = 0, $317 = 0, $3170 = 0, $3171 = 0, $3172 = 0, $3173 = 0, $3174 = 0, $3175 = 0, $3176 = 0, $3177 = 0, $3178 = 0, $3179 = 0, $318 = 0, $3180 = 0, $3181 = 0;
 var $3182 = 0, $3183 = 0, $3184 = 0, $3185 = 0, $3186 = 0, $3187 = 0, $3188 = 0, $3189 = 0, $319 = 0, $3190 = 0, $3191 = 0, $3192 = 0, $3193 = 0, $3194 = 0, $3195 = 0, $3196 = 0, $3197 = 0, $3198 = 0, $3199 = 0, $32 = 0;
 var $320 = 0, $3200 = 0, $3201 = 0, $3202 = 0, $3203 = 0, $3204 = 0, $3205 = 0, $3206 = 0, $3207 = 0, $3208 = 0, $3209 = 0, $321 = 0, $3210 = 0, $3211 = 0, $3212 = 0, $3213 = 0, $3214 = 0, $3215 = 0, $3216 = 0, $3217 = 0;
 var $3218 = 0, $3219 = 0, $322 = 0, $3220 = 0, $3221 = 0, $3222 = 0, $3223 = 0, $3224 = 0, $3225 = 0, $3226 = 0, $3227 = 0, $3228 = 0, $3229 = 0, $323 = 0, $3230 = 0, $3231 = 0, $3232 = 0, $3233 = 0, $3234 = 0, $3235 = 0;
 var $3236 = 0, $3237 = 0, $3238 = 0, $3239 = 0, $324 = 0, $3240 = 0, $3241 = 0, $3242 = 0, $3243 = 0, $3244 = 0, $3245 = 0, $3246 = 0, $3247 = 0, $3248 = 0, $3249 = 0, $325 = 0, $3250 = 0, $3251 = 0, $3252 = 0, $3253 = 0;
 var $3254 = 0, $3255 = 0, $3256 = 0, $3257 = 0, $3258 = 0, $3259 = 0, $326 = 0, $3260 = 0, $3261 = 0, $3262 = 0, $3263 = 0, $3264 = 0, $3265 = 0, $3266 = 0, $3267 = 0, $3268 = 0, $3269 = 0, $327 = 0, $3270 = 0, $3271 = 0;
 var $3272 = 0, $3273 = 0, $3274 = 0, $3275 = 0, $3276 = 0, $3277 = 0, $3278 = 0, $3279 = 0, $328 = 0, $3280 = 0, $3281 = 0, $3282 = 0, $3283 = 0, $3284 = 0, $3285 = 0, $3286 = 0, $3287 = 0, $3288 = 0, $3289 = 0, $329 = 0;
 var $3290 = 0, $3291 = 0, $3292 = 0, $3293 = 0, $3294 = 0, $3295 = 0, $3296 = 0, $3297 = 0, $3298 = 0, $3299 = 0, $33 = 0, $330 = 0, $3300 = 0, $3301 = 0, $3302 = 0, $3303 = 0, $3304 = 0, $3305 = 0, $3306 = 0, $3307 = 0;
 var $3308 = 0, $3309 = 0, $331 = 0, $3310 = 0, $3311 = 0, $3312 = 0, $3313 = 0, $3314 = 0, $3315 = 0, $3316 = 0, $3317 = 0, $3318 = 0, $3319 = 0, $332 = 0, $3320 = 0, $3321 = 0, $3322 = 0, $3323 = 0, $3324 = 0, $3325 = 0;
 var $3326 = 0, $3327 = 0, $3328 = 0, $3329 = 0, $333 = 0, $3330 = 0, $3331 = 0, $3332 = 0, $3333 = 0, $3334 = 0, $3335 = 0, $3336 = 0, $3337 = 0, $3338 = 0, $3339 = 0, $334 = 0, $3340 = 0, $3341 = 0, $3342 = 0, $3343 = 0;
 var $3344 = 0, $3345 = 0, $3346 = 0, $3347 = 0, $3348 = 0, $3349 = 0, $335 = 0, $3350 = 0, $3351 = 0, $3352 = 0, $3353 = 0, $3354 = 0, $3355 = 0, $3356 = 0, $3357 = 0, $3358 = 0, $3359 = 0, $336 = 0, $3360 = 0, $3361 = 0;
 var $3362 = 0, $3363 = 0, $3364 = 0, $3365 = 0, $3366 = 0, $3367 = 0, $3368 = 0, $3369 = 0, $337 = 0, $3370 = 0, $3371 = 0, $3372 = 0, $3373 = 0, $3374 = 0, $3375 = 0, $3376 = 0, $3377 = 0, $3378 = 0, $3379 = 0, $338 = 0;
 var $3380 = 0, $3381 = 0, $3382 = 0, $3383 = 0, $3384 = 0, $3385 = 0, $3386 = 0, $3387 = 0, $3388 = 0, $3389 = 0, $339 = 0, $3390 = 0, $3391 = 0, $3392 = 0, $3393 = 0, $3394 = 0, $3395 = 0, $3396 = 0, $3397 = 0, $3398 = 0;
 var $3399 = 0, $34 = 0, $340 = 0, $3400 = 0, $3401 = 0, $3402 = 0, $3403 = 0, $3404 = 0, $3405 = 0, $3406 = 0, $3407 = 0, $3408 = 0, $3409 = 0, $341 = 0, $3410 = 0, $3411 = 0, $3412 = 0, $3413 = 0, $3414 = 0, $3415 = 0;
 var $3416 = 0, $3417 = 0, $3418 = 0, $3419 = 0, $342 = 0, $3420 = 0, $3421 = 0, $3422 = 0, $3423 = 0, $3424 = 0, $3425 = 0, $3426 = 0, $3427 = 0, $3428 = 0, $3429 = 0, $343 = 0, $3430 = 0, $3431 = 0, $3432 = 0, $3433 = 0;
 var $3434 = 0, $3435 = 0, $3436 = 0, $3437 = 0, $3438 = 0, $3439 = 0, $344 = 0, $3440 = 0, $3441 = 0, $3442 = 0, $3443 = 0, $3444 = 0, $3445 = 0, $3446 = 0, $3447 = 0, $3448 = 0, $3449 = 0, $345 = 0, $3450 = 0, $3451 = 0;
 var $3452 = 0, $3453 = 0, $3454 = 0, $3455 = 0, $3456 = 0, $3457 = 0, $3458 = 0, $3459 = 0, $346 = 0, $3460 = 0, $3461 = 0, $3462 = 0, $3463 = 0, $3464 = 0, $3465 = 0, $3466 = 0, $3467 = 0, $3468 = 0, $3469 = 0, $347 = 0;
 var $3470 = 0, $3471 = 0, $3472 = 0, $3473 = 0, $3474 = 0, $3475 = 0, $3476 = 0, $3477 = 0, $3478 = 0, $3479 = 0, $348 = 0, $3480 = 0, $3481 = 0, $3482 = 0, $3483 = 0, $3484 = 0, $3485 = 0, $3486 = 0, $3487 = 0, $3488 = 0;
 var $3489 = 0, $349 = 0, $3490 = 0, $3491 = 0, $3492 = 0, $3493 = 0, $3494 = 0, $3495 = 0, $3496 = 0, $3497 = 0, $3498 = 0, $3499 = 0, $35 = 0, $350 = 0, $3500 = 0, $3501 = 0, $3502 = 0, $3503 = 0, $3504 = 0, $3505 = 0;
 var $3506 = 0, $3507 = 0.0, $3508 = 0, $3509 = 0, $351 = 0, $3510 = 0.0, $3511 = 0, $3512 = 0, $3513 = 0, $3514 = 0, $3515 = 0, $3516 = 0, $3517 = 0, $3518 = 0, $3519 = 0, $352 = 0, $3520 = 0, $3521 = 0, $3522 = 0, $3523 = 0;
 var $3524 = 0, $3525 = 0, $3526 = 0, $3527 = 0, $3528 = 0, $3529 = 0, $353 = 0, $3530 = 0, $3531 = 0, $3532 = 0, $3533 = 0, $3534 = 0, $3535 = 0, $3536 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0;
 var $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0;
 var $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0;
 var $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0;
 var $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0;
 var $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0;
 var $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0;
 var $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0;
 var $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0;
 var $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0.0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0;
 var $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0;
 var $54 = 0.0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0;
 var $558 = 0, $559 = 0, $56 = 0.0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0;
 var $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0;
 var $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0;
 var $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0;
 var $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0;
 var $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0;
 var $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0;
 var $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0;
 var $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0;
 var $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0;
 var $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0;
 var $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0;
 var $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0;
 var $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0;
 var $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0;
 var $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = 0, $834 = 0, $835 = 0, $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0;
 var $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0, $850 = 0, $851 = 0, $852 = 0, $853 = 0, $854 = 0, $855 = 0, $856 = 0, $857 = 0, $858 = 0, $859 = 0, $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0;
 var $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0, $869 = 0, $87 = 0, $870 = 0, $871 = 0, $872 = 0, $873 = 0, $874 = 0, $875 = 0, $876 = 0, $877 = 0, $878 = 0, $879 = 0, $88 = 0, $880 = 0, $881 = 0;
 var $882 = 0, $883 = 0, $884 = 0, $885 = 0, $886 = 0, $887 = 0, $888 = 0, $889 = 0, $89 = 0, $890 = 0, $891 = 0, $892 = 0, $893 = 0, $894 = 0, $895 = 0, $896 = 0, $897 = 0, $898 = 0, $899 = 0, $9 = 0;
 var $90 = 0, $900 = 0, $901 = 0, $902 = 0, $903 = 0, $904 = 0, $905 = 0, $906 = 0, $907 = 0, $908 = 0, $909 = 0, $91 = 0, $910 = 0, $911 = 0, $912 = 0, $913 = 0, $914 = 0, $915 = 0, $916 = 0, $917 = 0;
 var $918 = 0, $919 = 0, $92 = 0, $920 = 0, $921 = 0, $922 = 0, $923 = 0, $924 = 0, $925 = 0, $926 = 0, $927 = 0, $928 = 0, $929 = 0, $93 = 0, $930 = 0, $931 = 0, $932 = 0, $933 = 0, $934 = 0, $935 = 0;
 var $936 = 0, $937 = 0, $938 = 0, $939 = 0, $94 = 0, $940 = 0, $941 = 0, $942 = 0, $943 = 0, $944 = 0, $945 = 0, $946 = 0, $947 = 0, $948 = 0, $949 = 0, $95 = 0, $950 = 0, $951 = 0, $952 = 0, $953 = 0;
 var $954 = 0, $955 = 0, $956 = 0, $957 = 0, $958 = 0, $959 = 0, $96 = 0, $960 = 0, $961 = 0, $962 = 0, $963 = 0, $964 = 0, $965 = 0, $966 = 0, $967 = 0, $968 = 0, $969 = 0, $97 = 0, $970 = 0, $971 = 0;
 var $972 = 0, $973 = 0, $974 = 0, $975 = 0, $976 = 0, $977 = 0, $978 = 0, $979 = 0, $98 = 0, $980 = 0, $981 = 0, $982 = 0, $983 = 0, $984 = 0, $985 = 0, $986 = 0, $987 = 0, $988 = 0, $989 = 0, $99 = 0;
 var $990 = 0, $991 = 0, $992 = 0, $993 = 0, $994 = 0, $995 = 0, $996 = 0, $997 = 0, $998 = 0, $999 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, $eh$lpad$body606$index8Z2D = 0, $eh$lpad$body606$indexZ2D = 0, $not$ = 0, $not$3219 = 0, $not$3220 = 0, $not$3247 = 0, $or$cond = 0, $or$cond3211 = 0;
 var $or$cond3212 = 0, $or$cond3213 = 0, $or$cond3214 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $2 = sp + 20|0;
 $3 = sp + 16|0;
 $4 = sp + 12|0;
 $5 = sp;
 __ZN3osg10ReferencedC2Ev($0);
 HEAP32[$0>>2] = (60148);
 $6 = ((($0)) + 12|0);
 HEAP32[$6>>2] = $1;
 __THREW__ = 0;
 $7 = (invoke_ii(3791,7938)|0);
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 L1: do {
  if ($9) {
   $47 = ___cxa_find_matching_catch_2()|0;
   $48 = tempRet0;
   $$5 = $47;$$5514 = $48;
  } else {
   $10 = ($7|0)!=(0|0);
   do {
    if ($10) {
     __THREW__ = 0;
     $51 = (+invoke_di(3792,($7|0)));
     $52 = __THREW__; __THREW__ = 0;
     $53 = $52&1;
     if ($53) {
      label = 17;
     } else {
      $54 = $51;
      $56 = $54;
      label = 21;
     }
    } else {
     __THREW__ = 0;
     $11 = (invoke_ii(3265,1)|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      label = 17;
     } else {
      if ($11) {
       __THREW__ = 0;
       $14 = (invoke_ii(3266,1)|0);
       $15 = __THREW__; __THREW__ = 0;
       $16 = $15&1;
       if ($16) {
        label = 17;
       } else {
        __THREW__ = 0;
        $17 = (invoke_iiii(3267,($14|0),(129179|0),67)|0);
        $18 = __THREW__; __THREW__ = 0;
        $19 = $18&1;
        if ($19) {
         label = 17;
        } else {
         $20 = HEAP32[$17>>2]|0;
         $21 = ((($20)) + -12|0);
         $22 = HEAP32[$21>>2]|0;
         $23 = (($17) + ($22)|0);
         __THREW__ = 0;
         invoke_vii(3257,($4|0),($23|0));
         $24 = __THREW__; __THREW__ = 0;
         $25 = $24&1;
         if ($25) {
          label = 17;
         } else {
          __THREW__ = 0;
          $26 = (invoke_iii(3255,($4|0),(215188|0))|0);
          $27 = __THREW__; __THREW__ = 0;
          $28 = $27&1;
          if (!($28)) {
           $29 = HEAP32[$26>>2]|0;
           $30 = ((($29)) + 28|0);
           $31 = HEAP32[$30>>2]|0;
           __THREW__ = 0;
           $32 = (invoke_iii($31|0,($26|0),10)|0);
           $33 = __THREW__; __THREW__ = 0;
           $34 = $33&1;
           if (!($34)) {
            __THREW__ = 0;
            invoke_vi(3263,($4|0));
            $41 = __THREW__; __THREW__ = 0;
            $42 = $41&1;
            if ($42) {
             label = 17;
             break;
            }
            __THREW__ = 0;
            (invoke_iii(3268,($17|0),($32|0))|0);
            $43 = __THREW__; __THREW__ = 0;
            $44 = $43&1;
            if ($44) {
             label = 17;
             break;
            }
            __THREW__ = 0;
            (invoke_ii(3269,($17|0))|0);
            $45 = __THREW__; __THREW__ = 0;
            $46 = $45&1;
            if ($46) {
             label = 17;
             break;
            } else {
             $56 = 0.0;
             label = 21;
             break;
            }
           }
          }
          $35 = ___cxa_find_matching_catch_2()|0;
          $36 = tempRet0;
          __THREW__ = 0;
          invoke_vi(3263,($4|0));
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           $39 = ___cxa_find_matching_catch_3(0|0)|0;
           $40 = tempRet0;
           ___clang_call_terminate($39);
           // unreachable;
          } else {
           $eh$lpad$body$index2Z2D = $36;$eh$lpad$body$indexZ2D = $35;
           break;
          }
         }
        }
       }
      } else {
       $56 = 0.0;
       label = 21;
      }
     }
    }
   } while(0);
   if ((label|0) == 17) {
    $49 = ___cxa_find_matching_catch_2()|0;
    $50 = tempRet0;
    $eh$lpad$body$index2Z2D = $50;$eh$lpad$body$indexZ2D = $49;
   }
   else if ((label|0) == 21) {
    $55 = ((($0)) + 16|0);
    HEAPF32[$55>>2] = $56;
    $57 = ((($0)) + 20|0);
    HEAPF32[$57>>2] = 0.0;
    $$ = $10&1;
    $58 = ((($0)) + 25|0);
    $59 = ((($0)) + 26|0);
    $60 = ((($0)) + 27|0);
    $61 = ((($0)) + 28|0);
    _memset(($58|0),($$|0),4)|0;
    L25: do {
     if ($10) {
      $62 = HEAP32[$6>>2]|0;
      __THREW__ = 0;
      $63 = (invoke_iiid(3793,($62|0),(129247|0),3.4028234663852886E+38)|0);
      $64 = __THREW__; __THREW__ = 0;
      $65 = $64&1;
      if ($65) {
       label = 51;
      } else {
       if ($63) {
        $72 = 1;
       } else {
        $66 = HEAP32[$6>>2]|0;
        __THREW__ = 0;
        $67 = (invoke_iiid(3793,($66|0),(129271|0),3.4028234663852886E+38)|0);
        $68 = __THREW__; __THREW__ = 0;
        $69 = $68&1;
        if ($69) {
         label = 51;
         break;
        } else {
         $72 = $67;
        }
       }
       $70 = ((($0)) + 29|0);
       $71 = $72&1;
       HEAP8[$70>>0] = $71;
       $73 = HEAP32[$6>>2]|0;
       __THREW__ = 0;
       $74 = (invoke_iiid(3793,($73|0),(129294|0),3.4028234663852886E+38)|0);
       $75 = __THREW__; __THREW__ = 0;
       $76 = $75&1;
       if ($76) {
        label = 51;
       } else {
        $77 = ((($0)) + 31|0);
        $78 = $74&1;
        HEAP8[$77>>0] = $78;
        $79 = HEAP32[$6>>2]|0;
        __THREW__ = 0;
        $80 = (invoke_iiid(3793,($79|0),(129313|0),3.4028234663852886E+38)|0);
        $81 = __THREW__; __THREW__ = 0;
        $82 = $81&1;
        if ($82) {
         label = 51;
        } else {
         if ($80) {
          $89 = 1;
         } else {
          $83 = HEAP32[$6>>2]|0;
          __THREW__ = 0;
          $84 = (invoke_iiid(3793,($83|0),(129340|0),3.4028234663852886E+38)|0);
          $85 = __THREW__; __THREW__ = 0;
          $86 = $85&1;
          if ($86) {
           label = 51;
           break;
          } else {
           $89 = $84;
          }
         }
         $87 = ((($0)) + 30|0);
         $88 = $89&1;
         HEAP8[$87>>0] = $88;
         $90 = HEAP32[$6>>2]|0;
         __THREW__ = 0;
         $91 = (invoke_iiid(3793,($90|0),(129367|0),3.4028234663852886E+38)|0);
         $92 = __THREW__; __THREW__ = 0;
         $93 = $92&1;
         if ($93) {
          label = 51;
         } else {
          $94 = ((($0)) + 32|0);
          $95 = $91&1;
          HEAP8[$94>>0] = $95;
          $96 = HEAP32[$6>>2]|0;
          __THREW__ = 0;
          $97 = (invoke_iiid(3793,($96|0),(129396|0),3.4028234663852886E+38)|0);
          $98 = __THREW__; __THREW__ = 0;
          $99 = $98&1;
          if ($99) {
           label = 51;
          } else {
           $100 = ((($0)) + 33|0);
           $101 = $97&1;
           HEAP8[$100>>0] = $101;
           $102 = HEAP32[$6>>2]|0;
           __THREW__ = 0;
           $103 = (invoke_iiid(3793,($102|0),(129422|0),3.4028234663852886E+38)|0);
           $104 = __THREW__; __THREW__ = 0;
           $105 = $104&1;
           if ($105) {
            label = 51;
           } else {
            $106 = ((($0)) + 34|0);
            $107 = $103&1;
            HEAP8[$106>>0] = $107;
            $108 = HEAP32[$6>>2]|0;
            __THREW__ = 0;
            $109 = (invoke_iiid(3793,($108|0),(129445|0),3.4028234663852886E+38)|0);
            $110 = __THREW__; __THREW__ = 0;
            $111 = $110&1;
            if ($111) {
             label = 51;
            } else {
             $112 = ((($0)) + 35|0);
             $113 = $109&1;
             HEAP8[$112>>0] = $113;
             $114 = HEAP32[$6>>2]|0;
             __THREW__ = 0;
             $115 = (invoke_iiid(3793,($114|0),(129475|0),3.4028234663852886E+38)|0);
             $116 = __THREW__; __THREW__ = 0;
             $117 = $116&1;
             if ($117) {
              label = 51;
             } else {
              if ($115) {
               $128 = 1;
              } else {
               $118 = HEAP32[$6>>2]|0;
               __THREW__ = 0;
               $119 = (invoke_iiid(3793,($118|0),(129500|0),3.4028234663852886E+38)|0);
               $120 = __THREW__; __THREW__ = 0;
               $121 = $120&1;
               if ($121) {
                label = 51;
                break;
               }
               if ($119) {
                $128 = 1;
               } else {
                $122 = HEAP32[$6>>2]|0;
                __THREW__ = 0;
                $123 = (invoke_iiid(3793,($122|0),(129525|0),3.4028234663852886E+38)|0);
                $124 = __THREW__; __THREW__ = 0;
                $125 = $124&1;
                if ($125) {
                 label = 51;
                 break;
                } else {
                 $128 = $123;
                }
               }
              }
              $126 = ((($0)) + 36|0);
              $127 = $128&1;
              HEAP8[$126>>0] = $127;
              $129 = ((($0)) + 37|0);
              HEAP8[$129>>0] = 1;
              $130 = HEAP32[$6>>2]|0;
              __THREW__ = 0;
              $131 = (invoke_iiid(3793,($130|0),(129549|0),3.4028234663852886E+38)|0);
              $132 = __THREW__; __THREW__ = 0;
              $133 = $132&1;
              if ($133) {
               label = 51;
              } else {
               $$pre = +HEAPF32[$55>>2];
               $134 = $$pre >= 4.5;
               $135 = $131 | $134;
               $136 = ((($0)) + 38|0);
               $137 = $135&1;
               HEAP8[$136>>0] = $137;
               $138 = !($$pre >= 2.0);
               if ($138) {
                $140 = HEAP8[$58>>0]|0;
                $141 = ($140<<24>>24)==(0);
                if ($141) {
                 $$ph = 1;
                 label = 45;
                 break;
                }
                $142 = HEAP8[$59>>0]|0;
                $143 = ($142<<24>>24)==(0);
                if ($143) {
                 $$ph = 1;
                 label = 45;
                 break;
                }
                $144 = HEAP8[$60>>0]|0;
                $145 = ($144<<24>>24)==(0);
                if ($145) {
                 $$ph = 1;
                 label = 45;
                 break;
                }
                $153 = HEAP8[$61>>0]|0;
                $154 = ($153<<24>>24)==(0);
                $155 = ((($0)) + 24|0);
                HEAP8[$155>>0] = $153;
                if ($154) {
                 $1355 = 1;$198 = $155;
                 label = 60;
                 break;
                } else {
                 $$ph3216 = $155;
                }
               } else {
                $139 = ((($0)) + 24|0);
                HEAP8[$139>>0] = 1;
                $$ph3216 = $139;
               }
               while(1) {
                __THREW__ = 0;
                $156 = (invoke_i(3794)|0);
                $157 = __THREW__; __THREW__ = 0;
                $158 = $157&1;
                if ($158) {
                 label = 50;
                 break;
                }
                $159 = ($156|0)==(0);
                if ($159) {
                 break;
                }
               }
               if ((label|0) == 50) {
                $160 = ___cxa_find_matching_catch_2()|0;
                $161 = tempRet0;
                $eh$lpad$body606$index8Z2D = $161;$eh$lpad$body606$indexZ2D = $160;
                break;
               }
               __THREW__ = 0;
               $164 = (invoke_ii(3791,35724)|0);
               $165 = __THREW__; __THREW__ = 0;
               $166 = $165&1;
               if ($166) {
                label = 51;
               } else {
                __THREW__ = 0;
                $167 = (invoke_i(3794)|0);
                $168 = __THREW__; __THREW__ = 0;
                $169 = $168&1;
                do {
                 if (!($169)) {
                  $170 = ($167|0)==(0);
                  $171 = ($164|0)!=(0|0);
                  $or$cond = $171 & $170;
                  if ($or$cond) {
                   __THREW__ = 0;
                   $172 = (+invoke_di(3792,($164|0)));
                   $173 = __THREW__; __THREW__ = 0;
                   $174 = $173&1;
                   if ($174) {
                    break;
                   }
                   $175 = $172;
                   $$sink = $175;
                  } else {
                   $$sink = 1.0;
                  }
                  HEAPF32[$57>>2] = $$sink;
                  $1355 = 1;$198 = $$ph3216;
                  label = 60;
                  break L25;
                 }
                } while(0);
                $176 = ___cxa_find_matching_catch_2()|0;
                $177 = tempRet0;
                $$5 = $176;$$5514 = $177;
                break L1;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     } else {
      $146 = ((($0)) + 29|0);
      HEAP8[$146>>0] = 0;
      $147 = ((($0)) + 31|0);
      HEAP8[$147>>0] = 0;
      $148 = ((($0)) + 30|0);
      HEAP8[$148>>0] = 0;
      $149 = ((($0)) + 32|0);
      $150 = ((($0)) + 37|0);
      ;HEAP32[$149>>2]=0|0;HEAP8[$149+4>>0]=0|0;
      HEAP8[$150>>0] = $$;
      $151 = ((($0)) + 38|0);
      HEAP8[$151>>0] = 0;
      $$ph = 0;
      label = 45;
     }
    } while(0);
    if ((label|0) == 45) {
     $152 = ((($0)) + 24|0);
     HEAP8[$152>>0] = 0;
     $1355 = $$ph;$198 = $152;
     label = 60;
    }
    L71: do {
     if ((label|0) == 60) {
      __THREW__ = 0;
      $178 = (invoke_ii(3265,4)|0);
      $179 = __THREW__; __THREW__ = 0;
      $180 = $179&1;
      if ($180) {
       label = 51;
      } else {
       L74: do {
        if ($178) {
         __THREW__ = 0;
         $181 = (invoke_ii(3266,4)|0);
         $182 = __THREW__; __THREW__ = 0;
         $183 = $182&1;
         if ($183) {
          label = 51;
          break L71;
         }
         __THREW__ = 0;
         $184 = (invoke_iiii(3267,($181|0),(129569|0),10)|0);
         $185 = __THREW__; __THREW__ = 0;
         $186 = $185&1;
         if ($186) {
          label = 51;
          break L71;
         }
         $187 = +HEAPF32[$55>>2];
         __THREW__ = 0;
         $188 = (invoke_iid(3795,($184|0),(+$187))|0);
         $189 = __THREW__; __THREW__ = 0;
         $190 = $189&1;
         if ($190) {
          label = 51;
          break L71;
         }
         __THREW__ = 0;
         $191 = (invoke_iiii(3267,($188|0),(146554|0),2)|0);
         $192 = __THREW__; __THREW__ = 0;
         $193 = $192&1;
         if ($193) {
          label = 51;
          break L71;
         }
         __THREW__ = 0;
         $194 = (invoke_iiii(3267,($191|0),(129580|0),16)|0);
         $195 = __THREW__; __THREW__ = 0;
         $196 = $195&1;
         if ($196) {
          label = 51;
          break L71;
         }
         $197 = HEAP8[$198>>0]|0;
         $199 = ($197<<24>>24)!=(0);
         $200 = $199 ? 165299 : 129597;
         $201 = $199 ? 3 : 2;
         __THREW__ = 0;
         $202 = (invoke_iiii(3267,($194|0),($200|0),($201|0))|0);
         $203 = __THREW__; __THREW__ = 0;
         $204 = $203&1;
         if ($204) {
          label = 51;
          break L71;
         }
         __THREW__ = 0;
         $205 = (invoke_iiii(3267,($202|0),(146554|0),2)|0);
         $206 = __THREW__; __THREW__ = 0;
         $207 = $206&1;
         if ($207) {
          label = 51;
          break L71;
         }
         __THREW__ = 0;
         $208 = (invoke_iiii(3267,($205|0),(129600|0),20)|0);
         $209 = __THREW__; __THREW__ = 0;
         $210 = $209&1;
         if ($210) {
          label = 51;
          break L71;
         }
         $211 = +HEAPF32[$57>>2];
         __THREW__ = 0;
         $212 = (invoke_iid(3795,($208|0),(+$211))|0);
         $213 = __THREW__; __THREW__ = 0;
         $214 = $213&1;
         if ($214) {
          label = 51;
          break L71;
         }
         $215 = HEAP32[$212>>2]|0;
         $216 = ((($215)) + -12|0);
         $217 = HEAP32[$216>>2]|0;
         $218 = (($212) + ($217)|0);
         __THREW__ = 0;
         invoke_vii(3257,($3|0),($218|0));
         $219 = __THREW__; __THREW__ = 0;
         $220 = $219&1;
         if ($220) {
          label = 51;
          break L71;
         }
         __THREW__ = 0;
         $221 = (invoke_iii(3255,($3|0),(215188|0))|0);
         $222 = __THREW__; __THREW__ = 0;
         $223 = $222&1;
         do {
          if (!($223)) {
           $224 = HEAP32[$221>>2]|0;
           $225 = ((($224)) + 28|0);
           $226 = HEAP32[$225>>2]|0;
           __THREW__ = 0;
           $227 = (invoke_iii($226|0,($221|0),10)|0);
           $228 = __THREW__; __THREW__ = 0;
           $229 = $228&1;
           if ($229) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3263,($3|0));
           $236 = __THREW__; __THREW__ = 0;
           $237 = $236&1;
           if ($237) {
            label = 51;
            break L71;
           }
           __THREW__ = 0;
           (invoke_iii(3268,($212|0),($227|0))|0);
           $238 = __THREW__; __THREW__ = 0;
           $239 = $238&1;
           if ($239) {
            label = 51;
            break L71;
           }
           __THREW__ = 0;
           (invoke_ii(3269,($212|0))|0);
           $240 = __THREW__; __THREW__ = 0;
           $241 = $240&1;
           if ($241) {
            label = 51;
            break L71;
           } else {
            break L74;
           }
          }
         } while(0);
         $230 = ___cxa_find_matching_catch_2()|0;
         $231 = tempRet0;
         __THREW__ = 0;
         invoke_vi(3263,($3|0));
         $232 = __THREW__; __THREW__ = 0;
         $233 = $232&1;
         if ($233) {
          $234 = ___cxa_find_matching_catch_3(0|0)|0;
          $235 = tempRet0;
          ___clang_call_terminate($234);
          // unreachable;
         } else {
          $eh$lpad$body606$index8Z2D = $231;$eh$lpad$body606$indexZ2D = $230;
          break L71;
         }
        }
       } while(0);
       $242 = ((($0)) + 40|0);
       if ($10) {
        __THREW__ = 0;
        $243 = (invoke_ii(3796,(198921|0))|0);
        $244 = __THREW__; __THREW__ = 0;
        $245 = $244&1;
        if ($245) {
         label = 51;
         break;
        }
        $246 = ($243|0)==(0|0);
        if ($246) {
         __THREW__ = 0;
         $247 = (invoke_ii(3796,(129621|0))|0);
         $248 = __THREW__; __THREW__ = 0;
         $249 = $248&1;
         if ($249) {
          label = 51;
          break;
         } else {
          $$in$i$i = $247;
         }
        } else {
         $$in$i$i = $243;
        }
        HEAP32[$242>>2] = $$in$i$i;
        $250 = ((($0)) + 44|0);
        __THREW__ = 0;
        $251 = (invoke_ii(3796,(196220|0))|0);
        $252 = __THREW__; __THREW__ = 0;
        $253 = $252&1;
        if ($253) {
         label = 51;
         break;
        }
        $254 = ($251|0)==(0|0);
        if ($254) {
         __THREW__ = 0;
         $255 = (invoke_ii(3796,(129638|0))|0);
         $256 = __THREW__; __THREW__ = 0;
         $257 = $256&1;
         if ($257) {
          label = 51;
          break;
         } else {
          $$in$i$i613 = $255;
         }
        } else {
         $$in$i$i613 = $251;
        }
        HEAP32[$250>>2] = $$in$i$i613;
        $258 = ((($0)) + 48|0);
        __THREW__ = 0;
        $259 = (invoke_ii(3796,(197518|0))|0);
        $260 = __THREW__; __THREW__ = 0;
        $261 = $260&1;
        if ($261) {
         label = 51;
         break;
        }
        $262 = ($259|0)==(0|0);
        if ($262) {
         __THREW__ = 0;
         $263 = (invoke_ii(3796,(129656|0))|0);
         $264 = __THREW__; __THREW__ = 0;
         $265 = $264&1;
         if ($265) {
          label = 51;
          break;
         } else {
          $$in$i$i618 = $263;
         }
        } else {
         $$in$i$i618 = $259;
        }
        HEAP32[$258>>2] = $$in$i$i618;
        $266 = ((($0)) + 52|0);
        __THREW__ = 0;
        $267 = (invoke_ii(3796,(197336|0))|0);
        $268 = __THREW__; __THREW__ = 0;
        $269 = $268&1;
        if ($269) {
         label = 51;
         break;
        }
        $270 = ($267|0)==(0|0);
        if ($270) {
         __THREW__ = 0;
         $271 = (invoke_ii(3796,(129680|0))|0);
         $272 = __THREW__; __THREW__ = 0;
         $273 = $272&1;
         if ($273) {
          label = 51;
          break;
         } else {
          $$in$i$i623 = $271;
         }
        } else {
         $$in$i$i623 = $267;
        }
        HEAP32[$266>>2] = $$in$i$i623;
        $274 = ((($0)) + 56|0);
        __THREW__ = 0;
        $275 = (invoke_ii(3796,(196121|0))|0);
        $276 = __THREW__; __THREW__ = 0;
        $277 = $276&1;
        if ($277) {
         label = 51;
         break;
        }
        $278 = ($275|0)==(0|0);
        if ($278) {
         __THREW__ = 0;
         $279 = (invoke_ii(3796,(129699|0))|0);
         $280 = __THREW__; __THREW__ = 0;
         $281 = $280&1;
         if ($281) {
          label = 51;
          break;
         } else {
          $$in$i$i628 = $279;
         }
        } else {
         $$in$i$i628 = $275;
        }
        HEAP32[$274>>2] = $$in$i$i628;
        $282 = ((($0)) + 60|0);
        __THREW__ = 0;
        $283 = (invoke_ii(3796,(196190|0))|0);
        $284 = __THREW__; __THREW__ = 0;
        $285 = $284&1;
        if ($285) {
         label = 51;
         break;
        }
        $286 = ($283|0)==(0|0);
        if ($286) {
         __THREW__ = 0;
         $287 = (invoke_ii(3796,(129724|0))|0);
         $288 = __THREW__; __THREW__ = 0;
         $289 = $288&1;
         if ($289) {
          label = 51;
          break;
         } else {
          $$in$i$i633 = $287;
         }
        } else {
         $$in$i$i633 = $283;
        }
        HEAP32[$282>>2] = $$in$i$i633;
        __THREW__ = 0;
        $290 = (invoke_ii(3796,(197411|0))|0);
        $291 = __THREW__; __THREW__ = 0;
        $292 = $291&1;
        if ($292) {
         label = 51;
         break;
        }
        $293 = ((($0)) + 64|0);
        HEAP32[$293>>2] = $290;
        __THREW__ = 0;
        $294 = (invoke_ii(3796,(197267|0))|0);
        $295 = __THREW__; __THREW__ = 0;
        $296 = $295&1;
        if ($296) {
         label = 51;
         break;
        }
        $297 = ((($0)) + 72|0);
        HEAP32[$297>>2] = $294;
        $298 = ((($0)) + 76|0);
        __THREW__ = 0;
        $299 = (invoke_ii(3796,(196250|0))|0);
        $300 = __THREW__; __THREW__ = 0;
        $301 = $300&1;
        if ($301) {
         label = 51;
         break;
        }
        $302 = ($299|0)==(0|0);
        if ($302) {
         __THREW__ = 0;
         $303 = (invoke_ii(3796,(129748|0))|0);
         $304 = __THREW__; __THREW__ = 0;
         $305 = $304&1;
         if ($305) {
          label = 51;
          break;
         } else {
          $$in$i$i643 = $303;
         }
        } else {
         $$in$i$i643 = $299;
        }
        HEAP32[$298>>2] = $$in$i$i643;
        __THREW__ = 0;
        $306 = (invoke_ii(3796,(198072|0))|0);
        $307 = __THREW__; __THREW__ = 0;
        $308 = $307&1;
        if ($308) {
         label = 51;
         break;
        }
        $309 = ((($0)) + 80|0);
        HEAP32[$309>>2] = $306;
        __THREW__ = 0;
        $310 = (invoke_ii(3796,(198046|0))|0);
        $311 = __THREW__; __THREW__ = 0;
        $312 = $311&1;
        if ($312) {
         label = 51;
         break;
        }
        $313 = ((($0)) + 84|0);
        HEAP32[$313>>2] = $310;
        $314 = ((($0)) + 88|0);
        __THREW__ = 0;
        $315 = (invoke_ii(3796,(197249|0))|0);
        $316 = __THREW__; __THREW__ = 0;
        $317 = $316&1;
        if ($317) {
         label = 51;
         break;
        }
        $318 = ($315|0)==(0|0);
        if ($318) {
         __THREW__ = 0;
         $319 = (invoke_ii(3796,(129766|0))|0);
         $320 = __THREW__; __THREW__ = 0;
         $321 = $320&1;
         if ($321) {
          label = 51;
          break;
         } else {
          $$in$i$i655 = $319;
         }
        } else {
         $$in$i$i655 = $315;
        }
        HEAP32[$314>>2] = $$in$i$i655;
        $322 = ((($0)) + 92|0);
        __THREW__ = 0;
        $323 = (invoke_ii(3796,(196868|0))|0);
        $324 = __THREW__; __THREW__ = 0;
        $325 = $324&1;
        if ($325) {
         label = 51;
         break;
        }
        $326 = ($323|0)==(0|0);
        if ($326) {
         __THREW__ = 0;
         $327 = (invoke_ii(3796,(129787|0))|0);
         $328 = __THREW__; __THREW__ = 0;
         $329 = $328&1;
         if ($329) {
          label = 51;
          break;
         } else {
          $$in$i$i660 = $327;
         }
        } else {
         $$in$i$i660 = $323;
        }
        HEAP32[$322>>2] = $$in$i$i660;
        $330 = ((($0)) + 96|0);
        __THREW__ = 0;
        $331 = (invoke_ii(3796,(197282|0))|0);
        $332 = __THREW__; __THREW__ = 0;
        $333 = $332&1;
        if ($333) {
         label = 51;
         break;
        }
        $334 = ($331|0)==(0|0);
        if ($334) {
         __THREW__ = 0;
         $335 = (invoke_ii(3796,(129809|0))|0);
         $336 = __THREW__; __THREW__ = 0;
         $337 = $336&1;
         if ($337) {
          label = 51;
          break;
         } else {
          $$in$i$i666 = $335;
         }
        } else {
         $$in$i$i666 = $331;
        }
        HEAP32[$330>>2] = $$in$i$i666;
        $338 = ((($0)) + 100|0);
        __THREW__ = 0;
        $339 = (invoke_ii(3796,(197229|0))|0);
        $340 = __THREW__; __THREW__ = 0;
        $341 = $340&1;
        if ($341) {
         label = 51;
         break;
        }
        $342 = ($339|0)==(0|0);
        if ($342) {
         __THREW__ = 0;
         $343 = (invoke_ii(3796,(129833|0))|0);
         $344 = __THREW__; __THREW__ = 0;
         $345 = $344&1;
         if ($345) {
          label = 51;
          break;
         } else {
          $$in$i$i671 = $343;
         }
        } else {
         $$in$i$i671 = $339;
        }
        HEAP32[$338>>2] = $$in$i$i671;
        __THREW__ = 0;
        $346 = (invoke_ii(3796,(197385|0))|0);
        $347 = __THREW__; __THREW__ = 0;
        $348 = $347&1;
        if ($348) {
         label = 51;
         break;
        }
        $349 = ((($0)) + 104|0);
        HEAP32[$349>>2] = $346;
        __THREW__ = 0;
        $350 = (invoke_ii(3796,(197468|0))|0);
        $351 = __THREW__; __THREW__ = 0;
        $352 = $351&1;
        if ($352) {
         label = 51;
         break;
        }
        $353 = ((($0)) + 112|0);
        HEAP32[$353>>2] = $350;
        __THREW__ = 0;
        $354 = (invoke_ii(3796,(197371|0))|0);
        $355 = __THREW__; __THREW__ = 0;
        $356 = $355&1;
        if ($356) {
         label = 51;
         break;
        }
        $357 = ((($0)) + 120|0);
        HEAP32[$357>>2] = $354;
        __THREW__ = 0;
        $358 = (invoke_ii(3796,(197352|0))|0);
        $359 = __THREW__; __THREW__ = 0;
        $360 = $359&1;
        if ($360) {
         label = 51;
         break;
        }
        $361 = ((($0)) + 124|0);
        HEAP32[$361>>2] = $358;
        $362 = ((($0)) + 128|0);
        __THREW__ = 0;
        $363 = (invoke_ii(3796,(197318|0))|0);
        $364 = __THREW__; __THREW__ = 0;
        $365 = $364&1;
        if ($365) {
         label = 51;
         break;
        }
        $366 = ($363|0)==(0|0);
        if ($366) {
         __THREW__ = 0;
         $367 = (invoke_ii(3796,(129856|0))|0);
         $368 = __THREW__; __THREW__ = 0;
         $369 = $368&1;
         if ($369) {
          label = 51;
          break;
         } else {
          $$in$i$i686 = $367;
         }
        } else {
         $$in$i$i686 = $363;
        }
        HEAP32[$362>>2] = $$in$i$i686;
        $370 = ((($0)) + 132|0);
        __THREW__ = 0;
        $371 = (invoke_ii(3796,(196781|0))|0);
        $372 = __THREW__; __THREW__ = 0;
        $373 = $372&1;
        if ($373) {
         label = 51;
         break;
        }
        $374 = ($371|0)==(0|0);
        if ($374) {
         __THREW__ = 0;
         $375 = (invoke_ii(3796,(129877|0))|0);
         $376 = __THREW__; __THREW__ = 0;
         $377 = $376&1;
         if ($377) {
          label = 51;
          break;
         } else {
          $$in$i$i691 = $375;
         }
        } else {
         $$in$i$i691 = $371;
        }
        HEAP32[$370>>2] = $$in$i$i691;
        $378 = ((($0)) + 136|0);
        __THREW__ = 0;
        $379 = (invoke_ii(3796,(196751|0))|0);
        $380 = __THREW__; __THREW__ = 0;
        $381 = $380&1;
        if ($381) {
         label = 51;
         break;
        }
        $382 = ($379|0)==(0|0);
        if ($382) {
         __THREW__ = 0;
         $383 = (invoke_ii(3796,(129901|0))|0);
         $384 = __THREW__; __THREW__ = 0;
         $385 = $384&1;
         if ($385) {
          label = 51;
          break;
         } else {
          $$in$i$i697 = $383;
         }
        } else {
         $$in$i$i697 = $379;
        }
        HEAP32[$378>>2] = $$in$i$i697;
        $386 = ((($0)) + 140|0);
        __THREW__ = 0;
        $387 = (invoke_ii(3796,(196766|0))|0);
        $388 = __THREW__; __THREW__ = 0;
        $389 = $388&1;
        if ($389) {
         label = 51;
         break;
        }
        $390 = ($387|0)==(0|0);
        if ($390) {
         __THREW__ = 0;
         $391 = (invoke_ii(3796,(129919|0))|0);
         $392 = __THREW__; __THREW__ = 0;
         $393 = $392&1;
         if ($393) {
          label = 51;
          break;
         } else {
          $$in$i$i702 = $391;
         }
        } else {
         $$in$i$i702 = $387;
        }
        HEAP32[$386>>2] = $$in$i$i702;
        __THREW__ = 0;
        $394 = (invoke_ii(3796,(129937|0))|0);
        $395 = __THREW__; __THREW__ = 0;
        $396 = $395&1;
        if ($396) {
         label = 51;
         break;
        }
        $397 = ((($0)) + 144|0);
        HEAP32[$397>>2] = $394;
        __THREW__ = 0;
        $398 = (invoke_ii(3796,(196802|0))|0);
        $399 = __THREW__; __THREW__ = 0;
        $400 = $399&1;
        if ($400) {
         label = 51;
         break;
        }
        $401 = ((($0)) + 148|0);
        HEAP32[$401>>2] = $398;
        __THREW__ = 0;
        $402 = (invoke_ii(3796,(196822|0))|0);
        $403 = __THREW__; __THREW__ = 0;
        $404 = $403&1;
        if ($404) {
         label = 51;
         break;
        }
        $405 = ((($0)) + 152|0);
        HEAP32[$405>>2] = $402;
        __THREW__ = 0;
        $406 = (invoke_ii(3796,(196842|0))|0);
        $407 = __THREW__; __THREW__ = 0;
        $408 = $407&1;
        if ($408) {
         label = 51;
         break;
        }
        $409 = ((($0)) + 156|0);
        HEAP32[$409>>2] = $406;
        __THREW__ = 0;
        $410 = (invoke_ii(3796,(197506|0))|0);
        $411 = __THREW__; __THREW__ = 0;
        $412 = $411&1;
        if ($412) {
         label = 51;
         break;
        }
        $413 = ((($0)) + 160|0);
        HEAP32[$413>>2] = $410;
        __THREW__ = 0;
        $414 = (invoke_ii(3796,(197400|0))|0);
        $415 = __THREW__; __THREW__ = 0;
        $416 = $415&1;
        if ($416) {
         label = 51;
         break;
        }
        $417 = ((($0)) + 164|0);
        HEAP32[$417>>2] = $414;
        $418 = ((($0)) + 168|0);
        __THREW__ = 0;
        $419 = (invoke_ii(3796,(197454|0))|0);
        $420 = __THREW__; __THREW__ = 0;
        $421 = $420&1;
        if ($421) {
         label = 51;
         break;
        }
        $422 = ($419|0)==(0|0);
        if ($422) {
         __THREW__ = 0;
         $423 = (invoke_ii(3796,(129957|0))|0);
         $424 = __THREW__; __THREW__ = 0;
         $425 = $424&1;
         if ($425) {
          label = 51;
          break;
         } else {
          $$in$i$i721 = $423;
         }
        } else {
         $$in$i$i721 = $419;
        }
        HEAP32[$418>>2] = $$in$i$i721;
        $426 = ((($0)) + 172|0);
        __THREW__ = 0;
        $427 = (invoke_ii(3796,(197303|0))|0);
        $428 = __THREW__; __THREW__ = 0;
        $429 = $428&1;
        if ($429) {
         label = 51;
         break;
        }
        $430 = ($427|0)==(0|0);
        if ($430) {
         __THREW__ = 0;
         $431 = (invoke_ii(3796,(129974|0))|0);
         $432 = __THREW__; __THREW__ = 0;
         $433 = $432&1;
         if ($433) {
          label = 51;
          break;
         } else {
          $$in$i$i727 = $431;
         }
        } else {
         $$in$i$i727 = $427;
        }
        HEAP32[$426>>2] = $$in$i$i727;
        $434 = ((($0)) + 176|0);
        __THREW__ = 0;
        $435 = (invoke_ii(3796,(196156|0))|0);
        $436 = __THREW__; __THREW__ = 0;
        $437 = $436&1;
        if ($437) {
         label = 51;
         break;
        }
        $438 = ($435|0)==(0|0);
        if ($438) {
         __THREW__ = 0;
         $439 = (invoke_ii(3796,(129992|0))|0);
         $440 = __THREW__; __THREW__ = 0;
         $441 = $440&1;
         if ($441) {
          label = 51;
          break;
         } else {
          $$in$i$i732 = $439;
         }
        } else {
         $$in$i$i732 = $435;
        }
        HEAP32[$434>>2] = $$in$i$i732;
        $442 = ((($0)) + 180|0);
        __THREW__ = 0;
        $443 = (invoke_ii(3796,(196887|0))|0);
        $444 = __THREW__; __THREW__ = 0;
        $445 = $444&1;
        if ($445) {
         label = 51;
         break;
        }
        $446 = ($443|0)==(0|0);
        if ($446) {
         __THREW__ = 0;
         $447 = (invoke_ii(3796,(130014|0))|0);
         $448 = __THREW__; __THREW__ = 0;
         $449 = $448&1;
         if ($449) {
          label = 51;
          break;
         } else {
          $$in$i$i738 = $447;
         }
        } else {
         $$in$i$i738 = $443;
        }
        HEAP32[$442>>2] = $$in$i$i738;
        $450 = ((($0)) + 184|0);
        __THREW__ = 0;
        $451 = (invoke_ii(3796,(196899|0))|0);
        $452 = __THREW__; __THREW__ = 0;
        $453 = $452&1;
        if ($453) {
         label = 51;
         break;
        }
        $454 = ($451|0)==(0|0);
        if ($454) {
         __THREW__ = 0;
         $455 = (invoke_ii(3796,(130029|0))|0);
         $456 = __THREW__; __THREW__ = 0;
         $457 = $456&1;
         if ($457) {
          label = 51;
          break;
         } else {
          $$in$i$i743 = $455;
         }
        } else {
         $$in$i$i743 = $451;
        }
        HEAP32[$450>>2] = $$in$i$i743;
        $458 = ((($0)) + 188|0);
        __THREW__ = 0;
        $459 = (invoke_ii(3796,(196911|0))|0);
        $460 = __THREW__; __THREW__ = 0;
        $461 = $460&1;
        if ($461) {
         label = 51;
         break;
        }
        $462 = ($459|0)==(0|0);
        if ($462) {
         __THREW__ = 0;
         $463 = (invoke_ii(3796,(130044|0))|0);
         $464 = __THREW__; __THREW__ = 0;
         $465 = $464&1;
         if ($465) {
          label = 51;
          break;
         } else {
          $$in$i$i748 = $463;
         }
        } else {
         $$in$i$i748 = $459;
        }
        HEAP32[$458>>2] = $$in$i$i748;
        $466 = ((($0)) + 192|0);
        __THREW__ = 0;
        $467 = (invoke_ii(3796,(196923|0))|0);
        $468 = __THREW__; __THREW__ = 0;
        $469 = $468&1;
        if ($469) {
         label = 51;
         break;
        }
        $470 = ($467|0)==(0|0);
        if ($470) {
         __THREW__ = 0;
         $471 = (invoke_ii(3796,(130059|0))|0);
         $472 = __THREW__; __THREW__ = 0;
         $473 = $472&1;
         if ($473) {
          label = 51;
          break;
         } else {
          $$in$i$i753 = $471;
         }
        } else {
         $$in$i$i753 = $467;
        }
        HEAP32[$466>>2] = $$in$i$i753;
        $474 = ((($0)) + 196|0);
        __THREW__ = 0;
        $475 = (invoke_ii(3796,(196935|0))|0);
        $476 = __THREW__; __THREW__ = 0;
        $477 = $476&1;
        if ($477) {
         label = 51;
         break;
        }
        $478 = ($475|0)==(0|0);
        if ($478) {
         __THREW__ = 0;
         $479 = (invoke_ii(3796,(130074|0))|0);
         $480 = __THREW__; __THREW__ = 0;
         $481 = $480&1;
         if ($481) {
          label = 51;
          break;
         } else {
          $$in$i$i758 = $479;
         }
        } else {
         $$in$i$i758 = $475;
        }
        HEAP32[$474>>2] = $$in$i$i758;
        $482 = ((($0)) + 200|0);
        __THREW__ = 0;
        $483 = (invoke_ii(3796,(196947|0))|0);
        $484 = __THREW__; __THREW__ = 0;
        $485 = $484&1;
        if ($485) {
         label = 51;
         break;
        }
        $486 = ($483|0)==(0|0);
        if ($486) {
         __THREW__ = 0;
         $487 = (invoke_ii(3796,(130089|0))|0);
         $488 = __THREW__; __THREW__ = 0;
         $489 = $488&1;
         if ($489) {
          label = 51;
          break;
         } else {
          $$in$i$i763 = $487;
         }
        } else {
         $$in$i$i763 = $483;
        }
        HEAP32[$482>>2] = $$in$i$i763;
        $490 = ((($0)) + 204|0);
        __THREW__ = 0;
        $491 = (invoke_ii(3796,(196959|0))|0);
        $492 = __THREW__; __THREW__ = 0;
        $493 = $492&1;
        if ($493) {
         label = 51;
         break;
        }
        $494 = ($491|0)==(0|0);
        if ($494) {
         __THREW__ = 0;
         $495 = (invoke_ii(3796,(130104|0))|0);
         $496 = __THREW__; __THREW__ = 0;
         $497 = $496&1;
         if ($497) {
          label = 51;
          break;
         } else {
          $$in$i$i768 = $495;
         }
        } else {
         $$in$i$i768 = $491;
        }
        HEAP32[$490>>2] = $$in$i$i768;
        $498 = ((($0)) + 208|0);
        __THREW__ = 0;
        $499 = (invoke_ii(3796,(196971|0))|0);
        $500 = __THREW__; __THREW__ = 0;
        $501 = $500&1;
        if ($501) {
         label = 51;
         break;
        }
        $502 = ($499|0)==(0|0);
        if ($502) {
         __THREW__ = 0;
         $503 = (invoke_ii(3796,(130119|0))|0);
         $504 = __THREW__; __THREW__ = 0;
         $505 = $504&1;
         if ($505) {
          label = 51;
          break;
         } else {
          $$in$i$i773 = $503;
         }
        } else {
         $$in$i$i773 = $499;
        }
        HEAP32[$498>>2] = $$in$i$i773;
        $506 = ((($0)) + 212|0);
        __THREW__ = 0;
        $507 = (invoke_ii(3796,(197035|0))|0);
        $508 = __THREW__; __THREW__ = 0;
        $509 = $508&1;
        if ($509) {
         label = 51;
         break;
        }
        $510 = ($507|0)==(0|0);
        if ($510) {
         __THREW__ = 0;
         $511 = (invoke_ii(3796,(130134|0))|0);
         $512 = __THREW__; __THREW__ = 0;
         $513 = $512&1;
         if ($513) {
          label = 51;
          break;
         } else {
          $$in$i$i778 = $511;
         }
        } else {
         $$in$i$i778 = $507;
        }
        HEAP32[$506>>2] = $$in$i$i778;
        $514 = ((($0)) + 216|0);
        __THREW__ = 0;
        $515 = (invoke_ii(3796,(197048|0))|0);
        $516 = __THREW__; __THREW__ = 0;
        $517 = $516&1;
        if ($517) {
         label = 51;
         break;
        }
        $518 = ($515|0)==(0|0);
        if ($518) {
         __THREW__ = 0;
         $519 = (invoke_ii(3796,(130150|0))|0);
         $520 = __THREW__; __THREW__ = 0;
         $521 = $520&1;
         if ($521) {
          label = 51;
          break;
         } else {
          $$in$i$i783 = $519;
         }
        } else {
         $$in$i$i783 = $515;
        }
        HEAP32[$514>>2] = $$in$i$i783;
        $522 = ((($0)) + 220|0);
        __THREW__ = 0;
        $523 = (invoke_ii(3796,(197061|0))|0);
        $524 = __THREW__; __THREW__ = 0;
        $525 = $524&1;
        if ($525) {
         label = 51;
         break;
        }
        $526 = ($523|0)==(0|0);
        if ($526) {
         __THREW__ = 0;
         $527 = (invoke_ii(3796,(130166|0))|0);
         $528 = __THREW__; __THREW__ = 0;
         $529 = $528&1;
         if ($529) {
          label = 51;
          break;
         } else {
          $$in$i$i789 = $527;
         }
        } else {
         $$in$i$i789 = $523;
        }
        HEAP32[$522>>2] = $$in$i$i789;
        $530 = ((($0)) + 224|0);
        __THREW__ = 0;
        $531 = (invoke_ii(3796,(197074|0))|0);
        $532 = __THREW__; __THREW__ = 0;
        $533 = $532&1;
        if ($533) {
         label = 51;
         break;
        }
        $534 = ($531|0)==(0|0);
        if ($534) {
         __THREW__ = 0;
         $535 = (invoke_ii(3796,(130182|0))|0);
         $536 = __THREW__; __THREW__ = 0;
         $537 = $536&1;
         if ($537) {
          label = 51;
          break;
         } else {
          $$in$i$i795 = $535;
         }
        } else {
         $$in$i$i795 = $531;
        }
        HEAP32[$530>>2] = $$in$i$i795;
        $538 = ((($0)) + 228|0);
        __THREW__ = 0;
        $539 = (invoke_ii(3796,(196983|0))|0);
        $540 = __THREW__; __THREW__ = 0;
        $541 = $540&1;
        if ($541) {
         label = 51;
         break;
        }
        $542 = ($539|0)==(0|0);
        if ($542) {
         __THREW__ = 0;
         $543 = (invoke_ii(3796,(130198|0))|0);
         $544 = __THREW__; __THREW__ = 0;
         $545 = $544&1;
         if ($545) {
          label = 51;
          break;
         } else {
          $$in$i$i801 = $543;
         }
        } else {
         $$in$i$i801 = $539;
        }
        HEAP32[$538>>2] = $$in$i$i801;
        $546 = ((($0)) + 232|0);
        __THREW__ = 0;
        $547 = (invoke_ii(3796,(196996|0))|0);
        $548 = __THREW__; __THREW__ = 0;
        $549 = $548&1;
        if ($549) {
         label = 51;
         break;
        }
        $550 = ($547|0)==(0|0);
        if ($550) {
         __THREW__ = 0;
         $551 = (invoke_ii(3796,(130214|0))|0);
         $552 = __THREW__; __THREW__ = 0;
         $553 = $552&1;
         if ($553) {
          label = 51;
          break;
         } else {
          $$in$i$i806 = $551;
         }
        } else {
         $$in$i$i806 = $547;
        }
        HEAP32[$546>>2] = $$in$i$i806;
        $554 = ((($0)) + 236|0);
        __THREW__ = 0;
        $555 = (invoke_ii(3796,(197009|0))|0);
        $556 = __THREW__; __THREW__ = 0;
        $557 = $556&1;
        if ($557) {
         label = 51;
         break;
        }
        $558 = ($555|0)==(0|0);
        if ($558) {
         __THREW__ = 0;
         $559 = (invoke_ii(3796,(130230|0))|0);
         $560 = __THREW__; __THREW__ = 0;
         $561 = $560&1;
         if ($561) {
          label = 51;
          break;
         } else {
          $$in$i$i812 = $559;
         }
        } else {
         $$in$i$i812 = $555;
        }
        HEAP32[$554>>2] = $$in$i$i812;
        $562 = ((($0)) + 240|0);
        __THREW__ = 0;
        $563 = (invoke_ii(3796,(197022|0))|0);
        $564 = __THREW__; __THREW__ = 0;
        $565 = $564&1;
        if ($565) {
         label = 51;
         break;
        }
        $566 = ($563|0)==(0|0);
        if ($566) {
         __THREW__ = 0;
         $567 = (invoke_ii(3796,(130246|0))|0);
         $568 = __THREW__; __THREW__ = 0;
         $569 = $568&1;
         if ($569) {
          label = 51;
          break;
         } else {
          $$in$i$i818 = $567;
         }
        } else {
         $$in$i$i818 = $563;
        }
        HEAP32[$562>>2] = $$in$i$i818;
        $570 = ((($0)) + 244|0);
        __THREW__ = 0;
        $571 = (invoke_ii(3796,(197087|0))|0);
        $572 = __THREW__; __THREW__ = 0;
        $573 = $572&1;
        if ($573) {
         label = 51;
         break;
        }
        $574 = ($571|0)==(0|0);
        if ($574) {
         __THREW__ = 0;
         $575 = (invoke_ii(3796,(130262|0))|0);
         $576 = __THREW__; __THREW__ = 0;
         $577 = $576&1;
         if ($577) {
          label = 51;
          break;
         } else {
          $$in$i$i824 = $575;
         }
        } else {
         $$in$i$i824 = $571;
        }
        HEAP32[$570>>2] = $$in$i$i824;
        $578 = ((($0)) + 248|0);
        __THREW__ = 0;
        $579 = (invoke_ii(3796,(197106|0))|0);
        $580 = __THREW__; __THREW__ = 0;
        $581 = $580&1;
        if ($581) {
         label = 51;
         break;
        }
        $582 = ($579|0)==(0|0);
        if ($582) {
         __THREW__ = 0;
         $583 = (invoke_ii(3796,(130284|0))|0);
         $584 = __THREW__; __THREW__ = 0;
         $585 = $584&1;
         if ($585) {
          label = 51;
          break;
         } else {
          $$in$i$i829 = $583;
         }
        } else {
         $$in$i$i829 = $579;
        }
        HEAP32[$578>>2] = $$in$i$i829;
        $586 = ((($0)) + 252|0);
        __THREW__ = 0;
        $587 = (invoke_ii(3796,(197125|0))|0);
        $588 = __THREW__; __THREW__ = 0;
        $589 = $588&1;
        if ($589) {
         label = 51;
         break;
        }
        $590 = ($587|0)==(0|0);
        if ($590) {
         __THREW__ = 0;
         $591 = (invoke_ii(3796,(130306|0))|0);
         $592 = __THREW__; __THREW__ = 0;
         $593 = $592&1;
         if ($593) {
          label = 51;
          break;
         } else {
          $$in$i$i835 = $591;
         }
        } else {
         $$in$i$i835 = $587;
        }
        HEAP32[$586>>2] = $$in$i$i835;
        $594 = ((($0)) + 256|0);
        __THREW__ = 0;
        $595 = (invoke_ii(3796,(197488|0))|0);
        $596 = __THREW__; __THREW__ = 0;
        $597 = $596&1;
        if ($597) {
         label = 51;
         break;
        }
        $598 = ($595|0)==(0|0);
        if ($598) {
         __THREW__ = 0;
         $599 = (invoke_ii(3796,(130328|0))|0);
         $600 = __THREW__; __THREW__ = 0;
         $601 = $600&1;
         if ($601) {
          label = 51;
          break;
         } else {
          $$in$i$i841 = $599;
         }
        } else {
         $$in$i$i841 = $595;
        }
        HEAP32[$594>>2] = $$in$i$i841;
        $602 = ((($0)) + 260|0);
        __THREW__ = 0;
        $603 = (invoke_ii(3796,(130349|0))|0);
        $604 = __THREW__; __THREW__ = 0;
        $605 = $604&1;
        if ($605) {
         label = 51;
         break;
        }
        $606 = ($603|0)==(0|0);
        if ($606) {
         __THREW__ = 0;
         $607 = (invoke_ii(3796,(130366|0))|0);
         $608 = __THREW__; __THREW__ = 0;
         $609 = $608&1;
         if ($609) {
          label = 51;
          break;
         } else {
          $$in$i$i847 = $607;
         }
        } else {
         $$in$i$i847 = $603;
        }
        HEAP32[$602>>2] = $$in$i$i847;
        __THREW__ = 0;
        $610 = (invoke_ii(3796,(130386|0))|0);
        $611 = __THREW__; __THREW__ = 0;
        $612 = $611&1;
        if ($612) {
         label = 51;
         break;
        }
        $613 = ((($0)) + 264|0);
        HEAP32[$613>>2] = $610;
        $614 = ((($0)) + 268|0);
        __THREW__ = 0;
        $615 = (invoke_ii(3796,(198598|0))|0);
        $616 = __THREW__; __THREW__ = 0;
        $617 = $616&1;
        if ($617) {
         label = 51;
         break;
        }
        $618 = ($615|0)==(0|0);
        if ($618) {
         __THREW__ = 0;
         $619 = (invoke_ii(3796,(130404|0))|0);
         $620 = __THREW__; __THREW__ = 0;
         $621 = $620&1;
         if ($621) {
          label = 51;
          break;
         } else {
          $$in$i$i854 = $619;
         }
        } else {
         $$in$i$i854 = $615;
        }
        HEAP32[$614>>2] = $$in$i$i854;
        $622 = ((($0)) + 272|0);
        __THREW__ = 0;
        $623 = (invoke_ii(3796,(197157|0))|0);
        $624 = __THREW__; __THREW__ = 0;
        $625 = $624&1;
        if ($625) {
         label = 51;
         break;
        }
        $626 = ($623|0)==(0|0);
        if ($626) {
         __THREW__ = 0;
         $627 = (invoke_ii(3796,(130424|0))|0);
         $628 = __THREW__; __THREW__ = 0;
         $629 = $628&1;
         if ($629) {
          label = 51;
          break;
         } else {
          $$in$i$i859 = $627;
         }
        } else {
         $$in$i$i859 = $623;
        }
        HEAP32[$622>>2] = $$in$i$i859;
        $630 = ((($0)) + 276|0);
        __THREW__ = 0;
        $631 = (invoke_ii(3796,(130445|0))|0);
        $632 = __THREW__; __THREW__ = 0;
        $633 = $632&1;
        if ($633) {
         label = 51;
         break;
        }
        $634 = ($631|0)==(0|0);
        if ($634) {
         __THREW__ = 0;
         $635 = (invoke_ii(3796,(130462|0))|0);
         $636 = __THREW__; __THREW__ = 0;
         $637 = $636&1;
         if ($637) {
          label = 51;
          break;
         } else {
          $$in$i$i864 = $635;
         }
        } else {
         $$in$i$i864 = $631;
        }
        HEAP32[$630>>2] = $$in$i$i864;
        __THREW__ = 0;
        $638 = (invoke_ii(3796,(130482|0))|0);
        $639 = __THREW__; __THREW__ = 0;
        $640 = $639&1;
        if ($640) {
         label = 51;
         break;
        }
        $641 = ((($0)) + 280|0);
        HEAP32[$641>>2] = $638;
        __THREW__ = 0;
        $642 = (invoke_ii(3796,(130500|0))|0);
        $643 = __THREW__; __THREW__ = 0;
        $644 = $643&1;
        if ($644) {
         label = 51;
         break;
        }
        $645 = ((($0)) + 284|0);
        HEAP32[$645>>2] = $642;
        $646 = ((($0)) + 288|0);
        __THREW__ = 0;
        $647 = (invoke_ii(3796,(130517|0))|0);
        $648 = __THREW__; __THREW__ = 0;
        $649 = $648&1;
        if ($649) {
         label = 51;
         break;
        }
        $650 = ($647|0)==(0|0);
        if ($650) {
         __THREW__ = 0;
         $651 = (invoke_ii(3796,(130535|0))|0);
         $652 = __THREW__; __THREW__ = 0;
         $653 = $652&1;
         if ($653) {
          label = 51;
          break;
         } else {
          $$in$i$i873 = $651;
         }
        } else {
         $$in$i$i873 = $647;
        }
        HEAP32[$646>>2] = $$in$i$i873;
        __THREW__ = 0;
        $654 = (invoke_ii(3796,(198664|0))|0);
        $655 = __THREW__; __THREW__ = 0;
        $656 = $655&1;
        if ($656) {
         label = 51;
         break;
        }
        $657 = ((($0)) + 292|0);
        HEAP32[$657>>2] = $654;
        $658 = ((($0)) + 296|0);
        __THREW__ = 0;
        $659 = (invoke_ii(3796,(197175|0))|0);
        $660 = __THREW__; __THREW__ = 0;
        $661 = $660&1;
        if ($661) {
         label = 51;
         break;
        }
        $662 = ($659|0)==(0|0);
        if ($662) {
         __THREW__ = 0;
         $663 = (invoke_ii(3796,(130556|0))|0);
         $664 = __THREW__; __THREW__ = 0;
         $665 = $664&1;
         if ($665) {
          label = 51;
          break;
         } else {
          $$in$i$i880 = $663;
         }
        } else {
         $$in$i$i880 = $659;
        }
        HEAP32[$658>>2] = $$in$i$i880;
        __THREW__ = 0;
        $666 = (invoke_ii(3796,(130577|0))|0);
        $667 = __THREW__; __THREW__ = 0;
        $668 = $667&1;
        if ($668) {
         label = 51;
         break;
        }
        $669 = ((($0)) + 300|0);
        HEAP32[$669>>2] = $666;
        __THREW__ = 0;
        $670 = (invoke_ii(3796,(130594|0))|0);
        $671 = __THREW__; __THREW__ = 0;
        $672 = $671&1;
        if ($672) {
         label = 51;
         break;
        }
        $673 = ((($0)) + 304|0);
        HEAP32[$673>>2] = $670;
        __THREW__ = 0;
        $674 = (invoke_ii(3796,(130612|0))|0);
        $675 = __THREW__; __THREW__ = 0;
        $676 = $675&1;
        if ($676) {
         label = 51;
         break;
        }
        $677 = ((($0)) + 308|0);
        HEAP32[$677>>2] = $674;
        $678 = ((($0)) + 312|0);
        __THREW__ = 0;
        $679 = (invoke_ii(3796,(130629|0))|0);
        $680 = __THREW__; __THREW__ = 0;
        $681 = $680&1;
        if ($681) {
         label = 51;
         break;
        }
        $682 = ($679|0)==(0|0);
        if ($682) {
         __THREW__ = 0;
         $683 = (invoke_ii(3796,(130647|0))|0);
         $684 = __THREW__; __THREW__ = 0;
         $685 = $684&1;
         if ($685) {
          label = 51;
          break;
         } else {
          $$in$i$i893 = $683;
         }
        } else {
         $$in$i$i893 = $679;
        }
        HEAP32[$678>>2] = $$in$i$i893;
        __THREW__ = 0;
        $686 = (invoke_ii(3796,(198741|0))|0);
        $687 = __THREW__; __THREW__ = 0;
        $688 = $687&1;
        if ($688) {
         label = 51;
         break;
        }
        $689 = ((($0)) + 316|0);
        HEAP32[$689>>2] = $686;
        $690 = ((($0)) + 320|0);
        __THREW__ = 0;
        $691 = (invoke_ii(3796,(197193|0))|0);
        $692 = __THREW__; __THREW__ = 0;
        $693 = $692&1;
        if ($693) {
         label = 51;
         break;
        }
        $694 = ($691|0)==(0|0);
        if ($694) {
         __THREW__ = 0;
         $695 = (invoke_ii(3796,(130668|0))|0);
         $696 = __THREW__; __THREW__ = 0;
         $697 = $696&1;
         if ($697) {
          label = 51;
          break;
         } else {
          $$in$i$i901 = $695;
         }
        } else {
         $$in$i$i901 = $691;
        }
        HEAP32[$690>>2] = $$in$i$i901;
        __THREW__ = 0;
        $698 = (invoke_ii(3796,(130689|0))|0);
        $699 = __THREW__; __THREW__ = 0;
        $700 = $699&1;
        if ($700) {
         label = 51;
         break;
        }
        $701 = ((($0)) + 324|0);
        HEAP32[$701>>2] = $698;
        __THREW__ = 0;
        $702 = (invoke_ii(3796,(130706|0))|0);
        $703 = __THREW__; __THREW__ = 0;
        $704 = $703&1;
        if ($704) {
         label = 51;
         break;
        }
        $705 = ((($0)) + 328|0);
        HEAP32[$705>>2] = $702;
        __THREW__ = 0;
        $706 = (invoke_ii(3796,(130724|0))|0);
        $707 = __THREW__; __THREW__ = 0;
        $708 = $707&1;
        if ($708) {
         label = 51;
         break;
        }
        $709 = ((($0)) + 332|0);
        HEAP32[$709>>2] = $706;
        __THREW__ = 0;
        $710 = (invoke_ii(3796,(130743|0))|0);
        $711 = __THREW__; __THREW__ = 0;
        $712 = $711&1;
        if ($712) {
         label = 51;
         break;
        }
        $713 = ((($0)) + 336|0);
        HEAP32[$713>>2] = $710;
        __THREW__ = 0;
        $714 = (invoke_ii(3796,(130762|0))|0);
        $715 = __THREW__; __THREW__ = 0;
        $716 = $715&1;
        if ($716) {
         label = 51;
         break;
        }
        $717 = ((($0)) + 340|0);
        HEAP32[$717>>2] = $714;
        __THREW__ = 0;
        $718 = (invoke_ii(3796,(130781|0))|0);
        $719 = __THREW__; __THREW__ = 0;
        $720 = $719&1;
        if ($720) {
         label = 51;
         break;
        }
        $721 = ((($0)) + 344|0);
        HEAP32[$721>>2] = $718;
        $722 = ((($0)) + 348|0);
        __THREW__ = 0;
        $723 = (invoke_ii(3796,(130800|0))|0);
        $724 = __THREW__; __THREW__ = 0;
        $725 = $724&1;
        if ($725) {
         label = 51;
         break;
        }
        $726 = ($723|0)==(0|0);
        if ($726) {
         __THREW__ = 0;
         $727 = (invoke_ii(3796,(130820|0))|0);
         $728 = __THREW__; __THREW__ = 0;
         $729 = $728&1;
         if ($729) {
          label = 51;
          break;
         } else {
          $$in$i$i921 = $727;
         }
        } else {
         $$in$i$i921 = $723;
        }
        HEAP32[$722>>2] = $$in$i$i921;
        __THREW__ = 0;
        $730 = (invoke_ii(3796,(130843|0))|0);
        $731 = __THREW__; __THREW__ = 0;
        $732 = $731&1;
        if ($732) {
         label = 51;
         break;
        }
        $733 = ((($0)) + 352|0);
        HEAP32[$733>>2] = $730;
        __THREW__ = 0;
        $734 = (invoke_ii(3796,(130863|0))|0);
        $735 = __THREW__; __THREW__ = 0;
        $736 = $735&1;
        if ($736) {
         label = 51;
         break;
        }
        $737 = ((($0)) + 356|0);
        HEAP32[$737>>2] = $734;
        __THREW__ = 0;
        $738 = (invoke_ii(3796,(130883|0))|0);
        $739 = __THREW__; __THREW__ = 0;
        $740 = $739&1;
        if ($740) {
         label = 51;
         break;
        }
        $741 = ((($0)) + 360|0);
        HEAP32[$741>>2] = $738;
        __THREW__ = 0;
        $742 = (invoke_ii(3796,(130901|0))|0);
        $743 = __THREW__; __THREW__ = 0;
        $744 = $743&1;
        if ($744) {
         label = 51;
         break;
        }
        $745 = ((($0)) + 364|0);
        HEAP32[$745>>2] = $742;
        $746 = ((($0)) + 368|0);
        __THREW__ = 0;
        $747 = (invoke_ii(3796,(130918|0))|0);
        $748 = __THREW__; __THREW__ = 0;
        $749 = $748&1;
        if ($749) {
         label = 51;
         break;
        }
        $750 = ($747|0)==(0|0);
        if ($750) {
         __THREW__ = 0;
         $751 = (invoke_ii(3796,(130936|0))|0);
         $752 = __THREW__; __THREW__ = 0;
         $753 = $752&1;
         if ($753) {
          label = 51;
          break;
         } else {
          $$in$i$i935 = $751;
         }
        } else {
         $$in$i$i935 = $747;
        }
        HEAP32[$746>>2] = $$in$i$i935;
        __THREW__ = 0;
        $754 = (invoke_ii(3796,(198867|0))|0);
        $755 = __THREW__; __THREW__ = 0;
        $756 = $755&1;
        if ($756) {
         label = 51;
         break;
        }
        $757 = ((($0)) + 372|0);
        HEAP32[$757>>2] = $754;
        $758 = ((($0)) + 376|0);
        __THREW__ = 0;
        $759 = (invoke_ii(3796,(197211|0))|0);
        $760 = __THREW__; __THREW__ = 0;
        $761 = $760&1;
        if ($761) {
         label = 51;
         break;
        }
        $762 = ($759|0)==(0|0);
        if ($762) {
         __THREW__ = 0;
         $763 = (invoke_ii(3796,(130957|0))|0);
         $764 = __THREW__; __THREW__ = 0;
         $765 = $764&1;
         if ($765) {
          label = 51;
          break;
         } else {
          $$in$i$i943 = $763;
         }
        } else {
         $$in$i$i943 = $759;
        }
        HEAP32[$758>>2] = $$in$i$i943;
        __THREW__ = 0;
        $766 = (invoke_ii(3796,(130978|0))|0);
        $767 = __THREW__; __THREW__ = 0;
        $768 = $767&1;
        if ($768) {
         label = 51;
         break;
        }
        $769 = ((($0)) + 380|0);
        HEAP32[$769>>2] = $766;
        __THREW__ = 0;
        $770 = (invoke_ii(3796,(130996|0))|0);
        $771 = __THREW__; __THREW__ = 0;
        $772 = $771&1;
        if ($772) {
         label = 51;
         break;
        }
        $773 = ((($0)) + 384|0);
        HEAP32[$773>>2] = $770;
        __THREW__ = 0;
        $774 = (invoke_ii(3796,(131013|0))|0);
        $775 = __THREW__; __THREW__ = 0;
        $776 = $775&1;
        if ($776) {
         label = 51;
         break;
        }
        $777 = ((($0)) + 388|0);
        HEAP32[$777>>2] = $774;
        $778 = ((($0)) + 392|0);
        __THREW__ = 0;
        $779 = (invoke_ii(3796,(131031|0))|0);
        $780 = __THREW__; __THREW__ = 0;
        $781 = $780&1;
        if ($781) {
         label = 51;
         break;
        }
        $782 = ($779|0)==(0|0);
        if ($782) {
         __THREW__ = 0;
         $783 = (invoke_ii(3796,(131050|0))|0);
         $784 = __THREW__; __THREW__ = 0;
         $785 = $784&1;
         if ($785) {
          label = 51;
          break;
         } else {
          $$in$i$i957 = $783;
         }
        } else {
         $$in$i$i957 = $779;
        }
        HEAP32[$778>>2] = $$in$i$i957;
        __THREW__ = 0;
        $786 = (invoke_ii(3796,(131072|0))|0);
        $787 = __THREW__; __THREW__ = 0;
        $788 = $787&1;
        if ($788) {
         label = 51;
         break;
        }
        $789 = ((($0)) + 396|0);
        HEAP32[$789>>2] = $786;
        __THREW__ = 0;
        $790 = (invoke_ii(3796,(131091|0))|0);
        $791 = __THREW__; __THREW__ = 0;
        $792 = $791&1;
        if ($792) {
         label = 51;
         break;
        }
        $793 = ((($0)) + 400|0);
        HEAP32[$793>>2] = $790;
        $794 = ((($0)) + 404|0);
        __THREW__ = 0;
        $795 = (invoke_ii(3796,(198024|0))|0);
        $796 = __THREW__; __THREW__ = 0;
        $797 = $796&1;
        if ($797) {
         label = 51;
         break;
        }
        $798 = ($795|0)==(0|0);
        if ($798) {
         __THREW__ = 0;
         $799 = (invoke_ii(3796,(149386|0))|0);
         $800 = __THREW__; __THREW__ = 0;
         $801 = $800&1;
         if ($801) {
          label = 51;
          break;
         } else {
          $$in$i$i969 = $799;
         }
        } else {
         $$in$i$i969 = $795;
        }
        HEAP32[$794>>2] = $$in$i$i969;
        $802 = ((($0)) + 408|0);
        __THREW__ = 0;
        $803 = (invoke_ii(3796,(149411|0))|0);
        $804 = __THREW__; __THREW__ = 0;
        $805 = $804&1;
        if ($805) {
         label = 51;
         break;
        }
        $806 = ($803|0)==(0|0);
        if ($806) {
         __THREW__ = 0;
         $807 = (invoke_ii(3796,(131110|0))|0);
         $808 = __THREW__; __THREW__ = 0;
         $809 = $808&1;
         if ($809) {
          label = 51;
          break;
         } else {
          $$in$i$i974 = $807;
         }
        } else {
         $$in$i$i974 = $803;
        }
        HEAP32[$802>>2] = $$in$i$i974;
        $810 = ((($0)) + 412|0);
        __THREW__ = 0;
        $811 = (invoke_ii(3796,(149434|0))|0);
        $812 = __THREW__; __THREW__ = 0;
        $813 = $812&1;
        if ($813) {
         label = 51;
         break;
        }
        $814 = ($811|0)==(0|0);
        if ($814) {
         __THREW__ = 0;
         $815 = (invoke_ii(3796,(131136|0))|0);
         $816 = __THREW__; __THREW__ = 0;
         $817 = $816&1;
         if ($817) {
          label = 51;
          break;
         } else {
          $$in$i$i979 = $815;
         }
        } else {
         $$in$i$i979 = $811;
        }
        HEAP32[$810>>2] = $$in$i$i979;
        __THREW__ = 0;
        $818 = (invoke_ii(3796,(198177|0))|0);
        $819 = __THREW__; __THREW__ = 0;
        $820 = $819&1;
        if ($820) {
         label = 51;
         break;
        }
        $821 = ((($0)) + 416|0);
        HEAP32[$821>>2] = $818;
        __THREW__ = 0;
        $822 = (invoke_ii(3796,(131162|0))|0);
        $823 = __THREW__; __THREW__ = 0;
        $824 = $823&1;
        if ($824) {
         label = 51;
         break;
        }
        $825 = ((($0)) + 116|0);
        HEAP32[$825>>2] = $822;
        __THREW__ = 0;
        $826 = (invoke_ii(3796,(131178|0))|0);
        $827 = __THREW__; __THREW__ = 0;
        $828 = $827&1;
        if ($828) {
         label = 51;
         break;
        }
        $829 = ((($0)) + 108|0);
        HEAP32[$829>>2] = $826;
        __THREW__ = 0;
        $830 = (invoke_ii(3796,(131204|0))|0);
        $831 = __THREW__; __THREW__ = 0;
        $832 = $831&1;
        if ($832) {
         label = 51;
         break;
        }
        $833 = ((($0)) + 68|0);
        HEAP32[$833>>2] = $830;
        __THREW__ = 0;
        $834 = (invoke_ii(3796,(131222|0))|0);
        $835 = __THREW__; __THREW__ = 0;
        $836 = $835&1;
        if ($836) {
         label = 51;
         break;
        }
        $837 = ((($0)) + 576|0);
        HEAP32[$837>>2] = $834;
        __THREW__ = 0;
        $838 = (invoke_ii(3796,(131237|0))|0);
        $839 = __THREW__; __THREW__ = 0;
        $840 = $839&1;
        if ($840) {
         label = 51;
         break;
        }
        $841 = ((($0)) + 420|0);
        HEAP32[$841>>2] = $838;
        __THREW__ = 0;
        $842 = (invoke_ii(3796,(131258|0))|0);
        $843 = __THREW__; __THREW__ = 0;
        $844 = $843&1;
        if ($844) {
         label = 51;
         break;
        }
        $845 = ((($0)) + 424|0);
        HEAP32[$845>>2] = $842;
        __THREW__ = 0;
        $846 = (invoke_ii(3796,(131279|0))|0);
        $847 = __THREW__; __THREW__ = 0;
        $848 = $847&1;
        if ($848) {
         label = 51;
         break;
        }
        $849 = ((($0)) + 428|0);
        HEAP32[$849>>2] = $846;
        __THREW__ = 0;
        $850 = (invoke_ii(3796,(131300|0))|0);
        $851 = __THREW__; __THREW__ = 0;
        $852 = $851&1;
        if ($852) {
         label = 51;
         break;
        }
        $853 = ((($0)) + 432|0);
        HEAP32[$853>>2] = $850;
        __THREW__ = 0;
        $854 = (invoke_ii(3796,(131321|0))|0);
        $855 = __THREW__; __THREW__ = 0;
        $856 = $855&1;
        if ($856) {
         label = 51;
         break;
        }
        $857 = ((($0)) + 436|0);
        HEAP32[$857>>2] = $854;
        __THREW__ = 0;
        $858 = (invoke_ii(3796,(131342|0))|0);
        $859 = __THREW__; __THREW__ = 0;
        $860 = $859&1;
        if ($860) {
         label = 51;
         break;
        }
        $861 = ((($0)) + 440|0);
        HEAP32[$861>>2] = $858;
        __THREW__ = 0;
        $862 = (invoke_ii(3796,(131363|0))|0);
        $863 = __THREW__; __THREW__ = 0;
        $864 = $863&1;
        if ($864) {
         label = 51;
         break;
        }
        $865 = ((($0)) + 444|0);
        HEAP32[$865>>2] = $862;
        $866 = ((($0)) + 448|0);
        __THREW__ = 0;
        $867 = (invoke_ii(3796,(131377|0))|0);
        $868 = __THREW__; __THREW__ = 0;
        $869 = $868&1;
        if ($869) {
         label = 51;
         break;
        }
        $870 = ($867|0)==(0|0);
        if ($870) {
         __THREW__ = 0;
         $871 = (invoke_ii(3796,(131397|0))|0);
         $872 = __THREW__; __THREW__ = 0;
         $873 = $872&1;
         if ($873) {
          label = 51;
          break;
         } else {
          $$in$i$i1018 = $871;
         }
        } else {
         $$in$i$i1018 = $867;
        }
        HEAP32[$866>>2] = $$in$i$i1018;
        __THREW__ = 0;
        $874 = (invoke_ii(3796,(131420|0))|0);
        $875 = __THREW__; __THREW__ = 0;
        $876 = $875&1;
        if ($876) {
         label = 51;
         break;
        }
        $877 = ((($0)) + 452|0);
        HEAP32[$877>>2] = $874;
        __THREW__ = 0;
        $878 = (invoke_ii(3796,(131438|0))|0);
        $879 = __THREW__; __THREW__ = 0;
        $880 = $879&1;
        if ($880) {
         label = 51;
         break;
        }
        $881 = ((($0)) + 456|0);
        HEAP32[$881>>2] = $878;
        $882 = ((($0)) + 460|0);
        __THREW__ = 0;
        $883 = (invoke_ii(3796,(131457|0))|0);
        $884 = __THREW__; __THREW__ = 0;
        $885 = $884&1;
        if ($885) {
         label = 51;
         break;
        }
        $886 = ($883|0)==(0|0);
        if ($886) {
         __THREW__ = 0;
         $887 = (invoke_ii(3796,(131473|0))|0);
         $888 = __THREW__; __THREW__ = 0;
         $889 = $888&1;
         if ($889) {
          label = 51;
          break;
         } else {
          $$in$i$i1027 = $887;
         }
        } else {
         $$in$i$i1027 = $883;
        }
        HEAP32[$882>>2] = $$in$i$i1027;
        $890 = ((($0)) + 464|0);
        __THREW__ = 0;
        $891 = (invoke_ii(3796,(131492|0))|0);
        $892 = __THREW__; __THREW__ = 0;
        $893 = $892&1;
        if ($893) {
         label = 51;
         break;
        }
        $894 = ($891|0)==(0|0);
        if ($894) {
         __THREW__ = 0;
         $895 = (invoke_ii(3796,(131515|0))|0);
         $896 = __THREW__; __THREW__ = 0;
         $897 = $896&1;
         if ($897) {
          label = 51;
          break;
         } else {
          $$in$i$i1032 = $895;
         }
        } else {
         $$in$i$i1032 = $891;
        }
        HEAP32[$890>>2] = $$in$i$i1032;
        $898 = ((($0)) + 468|0);
        __THREW__ = 0;
        $899 = (invoke_ii(3796,(131541|0))|0);
        $900 = __THREW__; __THREW__ = 0;
        $901 = $900&1;
        if ($901) {
         label = 51;
         break;
        }
        $902 = ($899|0)==(0|0);
        if ($902) {
         __THREW__ = 0;
         $903 = (invoke_ii(3796,(131571|0))|0);
         $904 = __THREW__; __THREW__ = 0;
         $905 = $904&1;
         if ($905) {
          label = 51;
          break;
         } else {
          $$in$i$i1038 = $903;
         }
        } else {
         $$in$i$i1038 = $899;
        }
        HEAP32[$898>>2] = $$in$i$i1038;
        $906 = ((($0)) + 472|0);
        __THREW__ = 0;
        $907 = (invoke_ii(3796,(131604|0))|0);
        $908 = __THREW__; __THREW__ = 0;
        $909 = $908&1;
        if ($909) {
         label = 51;
         break;
        }
        $910 = ($907|0)==(0|0);
        if ($910) {
         __THREW__ = 0;
         $911 = (invoke_ii(3796,(131623|0))|0);
         $912 = __THREW__; __THREW__ = 0;
         $913 = $912&1;
         if ($913) {
          label = 51;
          break;
         } else {
          $$in$i$i1043 = $911;
         }
        } else {
         $$in$i$i1043 = $907;
        }
        HEAP32[$906>>2] = $$in$i$i1043;
        $914 = ((($0)) + 476|0);
        __THREW__ = 0;
        $915 = (invoke_ii(3796,(131645|0))|0);
        $916 = __THREW__; __THREW__ = 0;
        $917 = $916&1;
        if ($917) {
         label = 51;
         break;
        }
        $918 = ($915|0)==(0|0);
        if ($918) {
         __THREW__ = 0;
         $919 = (invoke_ii(3796,(131667|0))|0);
         $920 = __THREW__; __THREW__ = 0;
         $921 = $920&1;
         if ($921) {
          label = 51;
          break;
         } else {
          $$in$i$i1049 = $919;
         }
        } else {
         $$in$i$i1049 = $915;
        }
        HEAP32[$914>>2] = $$in$i$i1049;
        $922 = ((($0)) + 480|0);
        __THREW__ = 0;
        $923 = (invoke_ii(3796,(131692|0))|0);
        $924 = __THREW__; __THREW__ = 0;
        $925 = $924&1;
        if ($925) {
         label = 51;
         break;
        }
        $926 = ($923|0)==(0|0);
        if ($926) {
         __THREW__ = 0;
         $927 = (invoke_ii(3796,(131705|0))|0);
         $928 = __THREW__; __THREW__ = 0;
         $929 = $928&1;
         if ($929) {
          label = 51;
          break;
         } else {
          $$in$i$i1055 = $927;
         }
        } else {
         $$in$i$i1055 = $923;
        }
        HEAP32[$922>>2] = $$in$i$i1055;
        $930 = ((($0)) + 484|0);
        __THREW__ = 0;
        $931 = (invoke_ii(3796,(131721|0))|0);
        $932 = __THREW__; __THREW__ = 0;
        $933 = $932&1;
        if ($933) {
         label = 51;
         break;
        }
        $934 = ($931|0)==(0|0);
        if ($934) {
         __THREW__ = 0;
         $935 = (invoke_ii(3796,(131734|0))|0);
         $936 = __THREW__; __THREW__ = 0;
         $937 = $936&1;
         if ($937) {
          label = 51;
          break;
         } else {
          $$in$i$i1060 = $935;
         }
        } else {
         $$in$i$i1060 = $931;
        }
        HEAP32[$930>>2] = $$in$i$i1060;
        $938 = ((($0)) + 488|0);
        __THREW__ = 0;
        $939 = (invoke_ii(3796,(131750|0))|0);
        $940 = __THREW__; __THREW__ = 0;
        $941 = $940&1;
        if ($941) {
         label = 51;
         break;
        }
        $942 = ($939|0)==(0|0);
        if ($942) {
         __THREW__ = 0;
         $943 = (invoke_ii(3796,(131763|0))|0);
         $944 = __THREW__; __THREW__ = 0;
         $945 = $944&1;
         if ($945) {
          label = 51;
          break;
         } else {
          $$in$i$i1065 = $943;
         }
        } else {
         $$in$i$i1065 = $939;
        }
        HEAP32[$938>>2] = $$in$i$i1065;
        $946 = ((($0)) + 492|0);
        __THREW__ = 0;
        $947 = (invoke_ii(3796,(131779|0))|0);
        $948 = __THREW__; __THREW__ = 0;
        $949 = $948&1;
        if ($949) {
         label = 51;
         break;
        }
        $950 = ($947|0)==(0|0);
        if ($950) {
         __THREW__ = 0;
         $951 = (invoke_ii(3796,(131792|0))|0);
         $952 = __THREW__; __THREW__ = 0;
         $953 = $952&1;
         if ($953) {
          label = 51;
          break;
         } else {
          $$in$i$i1070 = $951;
         }
        } else {
         $$in$i$i1070 = $947;
        }
        HEAP32[$946>>2] = $$in$i$i1070;
        $954 = ((($0)) + 496|0);
        __THREW__ = 0;
        $955 = (invoke_ii(3796,(131808|0))|0);
        $956 = __THREW__; __THREW__ = 0;
        $957 = $956&1;
        if ($957) {
         label = 51;
         break;
        }
        $958 = ($955|0)==(0|0);
        if ($958) {
         __THREW__ = 0;
         $959 = (invoke_ii(3796,(131822|0))|0);
         $960 = __THREW__; __THREW__ = 0;
         $961 = $960&1;
         if ($961) {
          label = 51;
          break;
         } else {
          $$in$i$i1075 = $959;
         }
        } else {
         $$in$i$i1075 = $955;
        }
        HEAP32[$954>>2] = $$in$i$i1075;
        $962 = ((($0)) + 500|0);
        __THREW__ = 0;
        $963 = (invoke_ii(3796,(131839|0))|0);
        $964 = __THREW__; __THREW__ = 0;
        $965 = $964&1;
        if ($965) {
         label = 51;
         break;
        }
        $966 = ($963|0)==(0|0);
        if ($966) {
         __THREW__ = 0;
         $967 = (invoke_ii(3796,(131853|0))|0);
         $968 = __THREW__; __THREW__ = 0;
         $969 = $968&1;
         if ($969) {
          label = 51;
          break;
         } else {
          $$in$i$i1080 = $967;
         }
        } else {
         $$in$i$i1080 = $963;
        }
        HEAP32[$962>>2] = $$in$i$i1080;
        $970 = ((($0)) + 504|0);
        __THREW__ = 0;
        $971 = (invoke_ii(3796,(131870|0))|0);
        $972 = __THREW__; __THREW__ = 0;
        $973 = $972&1;
        if ($973) {
         label = 51;
         break;
        }
        $974 = ($971|0)==(0|0);
        if ($974) {
         __THREW__ = 0;
         $975 = (invoke_ii(3796,(131884|0))|0);
         $976 = __THREW__; __THREW__ = 0;
         $977 = $976&1;
         if ($977) {
          label = 51;
          break;
         } else {
          $$in$i$i1086 = $975;
         }
        } else {
         $$in$i$i1086 = $971;
        }
        HEAP32[$970>>2] = $$in$i$i1086;
        $978 = ((($0)) + 508|0);
        __THREW__ = 0;
        $979 = (invoke_ii(3796,(131901|0))|0);
        $980 = __THREW__; __THREW__ = 0;
        $981 = $980&1;
        if ($981) {
         label = 51;
         break;
        }
        $982 = ($979|0)==(0|0);
        if ($982) {
         __THREW__ = 0;
         $983 = (invoke_ii(3796,(131915|0))|0);
         $984 = __THREW__; __THREW__ = 0;
         $985 = $984&1;
         if ($985) {
          label = 51;
          break;
         } else {
          $$in$i$i1092 = $983;
         }
        } else {
         $$in$i$i1092 = $979;
        }
        HEAP32[$978>>2] = $$in$i$i1092;
        $986 = ((($0)) + 512|0);
        __THREW__ = 0;
        $987 = (invoke_ii(3796,(131932|0))|0);
        $988 = __THREW__; __THREW__ = 0;
        $989 = $988&1;
        if ($989) {
         label = 51;
         break;
        }
        $990 = ($987|0)==(0|0);
        if ($990) {
         __THREW__ = 0;
         $991 = (invoke_ii(3796,(131946|0))|0);
         $992 = __THREW__; __THREW__ = 0;
         $993 = $992&1;
         if ($993) {
          label = 51;
          break;
         } else {
          $$in$i$i1098 = $991;
         }
        } else {
         $$in$i$i1098 = $987;
        }
        HEAP32[$986>>2] = $$in$i$i1098;
        $994 = ((($0)) + 520|0);
        __THREW__ = 0;
        $995 = (invoke_ii(3796,(131963|0))|0);
        $996 = __THREW__; __THREW__ = 0;
        $997 = $996&1;
        if ($997) {
         label = 51;
         break;
        }
        $998 = ($995|0)==(0|0);
        if ($998) {
         __THREW__ = 0;
         $999 = (invoke_ii(3796,(131978|0))|0);
         $1000 = __THREW__; __THREW__ = 0;
         $1001 = $1000&1;
         if ($1001) {
          label = 51;
          break;
         } else {
          $$in$i$i1103 = $999;
         }
        } else {
         $$in$i$i1103 = $995;
        }
        HEAP32[$994>>2] = $$in$i$i1103;
        $1002 = ((($0)) + 528|0);
        __THREW__ = 0;
        $1003 = (invoke_ii(3796,(131996|0))|0);
        $1004 = __THREW__; __THREW__ = 0;
        $1005 = $1004&1;
        if ($1005) {
         label = 51;
         break;
        }
        $1006 = ($1003|0)==(0|0);
        if ($1006) {
         __THREW__ = 0;
         $1007 = (invoke_ii(3796,(132010|0))|0);
         $1008 = __THREW__; __THREW__ = 0;
         $1009 = $1008&1;
         if ($1009) {
          label = 51;
          break;
         } else {
          $$in$i$i1108 = $1007;
         }
        } else {
         $$in$i$i1108 = $1003;
        }
        HEAP32[$1002>>2] = $$in$i$i1108;
        $1010 = ((($0)) + 536|0);
        __THREW__ = 0;
        $1011 = (invoke_ii(3796,(132027|0))|0);
        $1012 = __THREW__; __THREW__ = 0;
        $1013 = $1012&1;
        if ($1013) {
         label = 51;
         break;
        }
        $1014 = ($1011|0)==(0|0);
        if ($1014) {
         __THREW__ = 0;
         $1015 = (invoke_ii(3796,(132042|0))|0);
         $1016 = __THREW__; __THREW__ = 0;
         $1017 = $1016&1;
         if ($1017) {
          label = 51;
          break;
         } else {
          $$in$i$i1113 = $1015;
         }
        } else {
         $$in$i$i1113 = $1011;
        }
        HEAP32[$1010>>2] = $$in$i$i1113;
        $1018 = ((($0)) + 544|0);
        __THREW__ = 0;
        $1019 = (invoke_ii(3796,(132060|0))|0);
        $1020 = __THREW__; __THREW__ = 0;
        $1021 = $1020&1;
        if ($1021) {
         label = 51;
         break;
        }
        $1022 = ($1019|0)==(0|0);
        if ($1022) {
         __THREW__ = 0;
         $1023 = (invoke_ii(3796,(132074|0))|0);
         $1024 = __THREW__; __THREW__ = 0;
         $1025 = $1024&1;
         if ($1025) {
          label = 51;
          break;
         } else {
          $$in$i$i1118 = $1023;
         }
        } else {
         $$in$i$i1118 = $1019;
        }
        HEAP32[$1018>>2] = $$in$i$i1118;
        $1026 = ((($0)) + 552|0);
        __THREW__ = 0;
        $1027 = (invoke_ii(3796,(132091|0))|0);
        $1028 = __THREW__; __THREW__ = 0;
        $1029 = $1028&1;
        if ($1029) {
         label = 51;
         break;
        }
        $1030 = ($1027|0)==(0|0);
        if ($1030) {
         __THREW__ = 0;
         $1031 = (invoke_ii(3796,(132106|0))|0);
         $1032 = __THREW__; __THREW__ = 0;
         $1033 = $1032&1;
         if ($1033) {
          label = 51;
          break;
         } else {
          $$in$i$i1123 = $1031;
         }
        } else {
         $$in$i$i1123 = $1027;
        }
        HEAP32[$1026>>2] = $$in$i$i1123;
        $1034 = ((($0)) + 560|0);
        __THREW__ = 0;
        $1035 = (invoke_ii(3796,(132124|0))|0);
        $1036 = __THREW__; __THREW__ = 0;
        $1037 = $1036&1;
        if ($1037) {
         label = 51;
         break;
        }
        $1038 = ($1035|0)==(0|0);
        if ($1038) {
         __THREW__ = 0;
         $1039 = (invoke_ii(3796,(132138|0))|0);
         $1040 = __THREW__; __THREW__ = 0;
         $1041 = $1040&1;
         if ($1041) {
          label = 51;
          break;
         } else {
          $$in$i$i1128 = $1039;
         }
        } else {
         $$in$i$i1128 = $1035;
        }
        HEAP32[$1034>>2] = $$in$i$i1128;
        $1042 = ((($0)) + 568|0);
        __THREW__ = 0;
        $1043 = (invoke_ii(3796,(132155|0))|0);
        $1044 = __THREW__; __THREW__ = 0;
        $1045 = $1044&1;
        if ($1045) {
         label = 51;
         break;
        }
        $1046 = ($1043|0)==(0|0);
        if ($1046) {
         __THREW__ = 0;
         $1047 = (invoke_ii(3796,(132170|0))|0);
         $1048 = __THREW__; __THREW__ = 0;
         $1049 = $1048&1;
         if ($1049) {
          label = 51;
          break;
         } else {
          $$in$i$i1133 = $1047;
         }
        } else {
         $$in$i$i1133 = $1043;
        }
        HEAP32[$1042>>2] = $$in$i$i1133;
        $1050 = ((($0)) + 516|0);
        __THREW__ = 0;
        $1051 = (invoke_ii(3796,(132188|0))|0);
        $1052 = __THREW__; __THREW__ = 0;
        $1053 = $1052&1;
        if ($1053) {
         label = 51;
         break;
        }
        $1054 = ($1051|0)==(0|0);
        if ($1054) {
         __THREW__ = 0;
         $1055 = (invoke_ii(3796,(132203|0))|0);
         $1056 = __THREW__; __THREW__ = 0;
         $1057 = $1056&1;
         if ($1057) {
          label = 51;
          break;
         } else {
          $$in$i$i1138 = $1055;
         }
        } else {
         $$in$i$i1138 = $1051;
        }
        HEAP32[$1050>>2] = $$in$i$i1138;
        $1058 = ((($0)) + 524|0);
        __THREW__ = 0;
        $1059 = (invoke_ii(3796,(132221|0))|0);
        $1060 = __THREW__; __THREW__ = 0;
        $1061 = $1060&1;
        if ($1061) {
         label = 51;
         break;
        }
        $1062 = ($1059|0)==(0|0);
        if ($1062) {
         __THREW__ = 0;
         $1063 = (invoke_ii(3796,(132237|0))|0);
         $1064 = __THREW__; __THREW__ = 0;
         $1065 = $1064&1;
         if ($1065) {
          label = 51;
          break;
         } else {
          $$in$i$i1143 = $1063;
         }
        } else {
         $$in$i$i1143 = $1059;
        }
        HEAP32[$1058>>2] = $$in$i$i1143;
        $1066 = ((($0)) + 532|0);
        __THREW__ = 0;
        $1067 = (invoke_ii(3796,(132256|0))|0);
        $1068 = __THREW__; __THREW__ = 0;
        $1069 = $1068&1;
        if ($1069) {
         label = 51;
         break;
        }
        $1070 = ($1067|0)==(0|0);
        if ($1070) {
         __THREW__ = 0;
         $1071 = (invoke_ii(3796,(132271|0))|0);
         $1072 = __THREW__; __THREW__ = 0;
         $1073 = $1072&1;
         if ($1073) {
          label = 51;
          break;
         } else {
          $$in$i$i1148 = $1071;
         }
        } else {
         $$in$i$i1148 = $1067;
        }
        HEAP32[$1066>>2] = $$in$i$i1148;
        $1074 = ((($0)) + 540|0);
        __THREW__ = 0;
        $1075 = (invoke_ii(3796,(132289|0))|0);
        $1076 = __THREW__; __THREW__ = 0;
        $1077 = $1076&1;
        if ($1077) {
         label = 51;
         break;
        }
        $1078 = ($1075|0)==(0|0);
        if ($1078) {
         __THREW__ = 0;
         $1079 = (invoke_ii(3796,(132305|0))|0);
         $1080 = __THREW__; __THREW__ = 0;
         $1081 = $1080&1;
         if ($1081) {
          label = 51;
          break;
         } else {
          $$in$i$i1154 = $1079;
         }
        } else {
         $$in$i$i1154 = $1075;
        }
        HEAP32[$1074>>2] = $$in$i$i1154;
        $1082 = ((($0)) + 548|0);
        __THREW__ = 0;
        $1083 = (invoke_ii(3796,(132324|0))|0);
        $1084 = __THREW__; __THREW__ = 0;
        $1085 = $1084&1;
        if ($1085) {
         label = 51;
         break;
        }
        $1086 = ($1083|0)==(0|0);
        if ($1086) {
         __THREW__ = 0;
         $1087 = (invoke_ii(3796,(132339|0))|0);
         $1088 = __THREW__; __THREW__ = 0;
         $1089 = $1088&1;
         if ($1089) {
          label = 51;
          break;
         } else {
          $$in$i$i1160 = $1087;
         }
        } else {
         $$in$i$i1160 = $1083;
        }
        HEAP32[$1082>>2] = $$in$i$i1160;
        $1090 = ((($0)) + 556|0);
        __THREW__ = 0;
        $1091 = (invoke_ii(3796,(132357|0))|0);
        $1092 = __THREW__; __THREW__ = 0;
        $1093 = $1092&1;
        if ($1093) {
         label = 51;
         break;
        }
        $1094 = ($1091|0)==(0|0);
        if ($1094) {
         __THREW__ = 0;
         $1095 = (invoke_ii(3796,(132373|0))|0);
         $1096 = __THREW__; __THREW__ = 0;
         $1097 = $1096&1;
         if ($1097) {
          label = 51;
          break;
         } else {
          $$in$i$i1166 = $1095;
         }
        } else {
         $$in$i$i1166 = $1091;
        }
        HEAP32[$1090>>2] = $$in$i$i1166;
        $1098 = ((($0)) + 564|0);
        __THREW__ = 0;
        $1099 = (invoke_ii(3796,(132392|0))|0);
        $1100 = __THREW__; __THREW__ = 0;
        $1101 = $1100&1;
        if ($1101) {
         label = 51;
         break;
        }
        $1102 = ($1099|0)==(0|0);
        if ($1102) {
         __THREW__ = 0;
         $1103 = (invoke_ii(3796,(132407|0))|0);
         $1104 = __THREW__; __THREW__ = 0;
         $1105 = $1104&1;
         if ($1105) {
          label = 51;
          break;
         } else {
          $$in$i$i1172 = $1103;
         }
        } else {
         $$in$i$i1172 = $1099;
        }
        HEAP32[$1098>>2] = $$in$i$i1172;
        $1106 = ((($0)) + 572|0);
        __THREW__ = 0;
        $1107 = (invoke_ii(3796,(132425|0))|0);
        $1108 = __THREW__; __THREW__ = 0;
        $1109 = $1108&1;
        if ($1109) {
         label = 51;
         break;
        }
        $1110 = ($1107|0)==(0|0);
        if ($1110) {
         __THREW__ = 0;
         $1111 = (invoke_ii(3796,(132441|0))|0);
         $1112 = __THREW__; __THREW__ = 0;
         $1113 = $1112&1;
         if ($1113) {
          label = 51;
          break;
         } else {
          $$in$i$i1178 = $1111;
         }
        } else {
         $$in$i$i1178 = $1107;
        }
        HEAP32[$1106>>2] = $$in$i$i1178;
        __THREW__ = 0;
        $1114 = (invoke_ii(3796,(132460|0))|0);
        $1115 = __THREW__; __THREW__ = 0;
        $1116 = $1115&1;
        if ($1116) {
         label = 51;
         break;
        }
        $1117 = ((($0)) + 580|0);
        HEAP32[$1117>>2] = $1114;
        __THREW__ = 0;
        $1118 = (invoke_ii(3796,(132480|0))|0);
        $1119 = __THREW__; __THREW__ = 0;
        $1120 = $1119&1;
        if ($1120) {
         label = 51;
         break;
        }
        $1121 = ((($0)) + 584|0);
        HEAP32[$1121>>2] = $1118;
        __THREW__ = 0;
        $1122 = (invoke_ii(3796,(132502|0))|0);
        $1123 = __THREW__; __THREW__ = 0;
        $1124 = $1123&1;
        if ($1124) {
         label = 51;
         break;
        }
        $1125 = ((($0)) + 588|0);
        HEAP32[$1125>>2] = $1122;
        __THREW__ = 0;
        $1126 = (invoke_ii(3796,(132525|0))|0);
        $1127 = __THREW__; __THREW__ = 0;
        $1128 = $1127&1;
        if ($1128) {
         label = 51;
         break;
        }
        $1129 = ((($0)) + 592|0);
        HEAP32[$1129>>2] = $1126;
        __THREW__ = 0;
        $1130 = (invoke_ii(3796,(132548|0))|0);
        $1131 = __THREW__; __THREW__ = 0;
        $1132 = $1131&1;
        if ($1132) {
         label = 51;
         break;
        }
        $1133 = ((($0)) + 596|0);
        HEAP32[$1133>>2] = $1130;
        __THREW__ = 0;
        $1134 = (invoke_ii(3796,(132574|0))|0);
        $1135 = __THREW__; __THREW__ = 0;
        $1136 = $1135&1;
        if ($1136) {
         label = 51;
         break;
        }
        $1137 = ((($0)) + 600|0);
        HEAP32[$1137>>2] = $1134;
        __THREW__ = 0;
        $1138 = (invoke_ii(3796,(132602|0))|0);
        $1139 = __THREW__; __THREW__ = 0;
        $1140 = $1139&1;
        if ($1140) {
         label = 51;
         break;
        }
        $1141 = ((($0)) + 604|0);
        HEAP32[$1141>>2] = $1138;
        __THREW__ = 0;
        $1142 = (invoke_ii(3796,(132624|0))|0);
        $1143 = __THREW__; __THREW__ = 0;
        $1144 = $1143&1;
        if ($1144) {
         label = 51;
         break;
        }
        $1145 = ((($0)) + 608|0);
        HEAP32[$1145>>2] = $1142;
        __THREW__ = 0;
        $1146 = (invoke_ii(3796,(132643|0))|0);
        $1147 = __THREW__; __THREW__ = 0;
        $1148 = $1147&1;
        if ($1148) {
         label = 51;
         break;
        }
        $1149 = ((($0)) + 612|0);
        HEAP32[$1149>>2] = $1146;
        __THREW__ = 0;
        $1150 = (invoke_ii(3796,(132659|0))|0);
        $1151 = __THREW__; __THREW__ = 0;
        $1152 = $1151&1;
        if ($1152) {
         label = 51;
         break;
        }
        $1153 = ((($0)) + 616|0);
        HEAP32[$1153>>2] = $1150;
        __THREW__ = 0;
        $1154 = (invoke_ii(3796,(132671|0))|0);
        $1155 = __THREW__; __THREW__ = 0;
        $1156 = $1155&1;
        if ($1156) {
         label = 51;
         break;
        }
        $1157 = ((($0)) + 620|0);
        HEAP32[$1157>>2] = $1154;
        __THREW__ = 0;
        $1158 = (invoke_ii(3796,(132683|0))|0);
        $1159 = __THREW__; __THREW__ = 0;
        $1160 = $1159&1;
        if ($1160) {
         label = 51;
         break;
        }
        $1161 = ((($0)) + 624|0);
        HEAP32[$1161>>2] = $1158;
        __THREW__ = 0;
        $1162 = (invoke_ii(3796,(132695|0))|0);
        $1163 = __THREW__; __THREW__ = 0;
        $1164 = $1163&1;
        if ($1164) {
         label = 51;
         break;
        }
        $1165 = ((($0)) + 628|0);
        HEAP32[$1165>>2] = $1162;
        __THREW__ = 0;
        $1166 = (invoke_ii(3796,(132707|0))|0);
        $1167 = __THREW__; __THREW__ = 0;
        $1168 = $1167&1;
        if ($1168) {
         label = 51;
         break;
        }
        $1169 = ((($0)) + 632|0);
        HEAP32[$1169>>2] = $1166;
        __THREW__ = 0;
        $1170 = (invoke_ii(3796,(132720|0))|0);
        $1171 = __THREW__; __THREW__ = 0;
        $1172 = $1171&1;
        if ($1172) {
         label = 51;
         break;
        }
        $1173 = ((($0)) + 636|0);
        HEAP32[$1173>>2] = $1170;
        __THREW__ = 0;
        $1174 = (invoke_ii(3796,(132733|0))|0);
        $1175 = __THREW__; __THREW__ = 0;
        $1176 = $1175&1;
        if ($1176) {
         label = 51;
         break;
        }
        $1177 = ((($0)) + 640|0);
        HEAP32[$1177>>2] = $1174;
        __THREW__ = 0;
        $1178 = (invoke_ii(3796,(132746|0))|0);
        $1179 = __THREW__; __THREW__ = 0;
        $1180 = $1179&1;
        if ($1180) {
         label = 51;
         break;
        }
        $1181 = ((($0)) + 644|0);
        HEAP32[$1181>>2] = $1178;
        __THREW__ = 0;
        $1182 = (invoke_ii(3796,(132759|0))|0);
        $1183 = __THREW__; __THREW__ = 0;
        $1184 = $1183&1;
        if ($1184) {
         label = 51;
         break;
        }
        $1185 = ((($0)) + 648|0);
        HEAP32[$1185>>2] = $1182;
        __THREW__ = 0;
        $1186 = (invoke_ii(3796,(132778|0))|0);
        $1187 = __THREW__; __THREW__ = 0;
        $1188 = $1187&1;
        if ($1188) {
         label = 51;
         break;
        }
        $1189 = ((($0)) + 652|0);
        HEAP32[$1189>>2] = $1186;
        __THREW__ = 0;
        $1190 = (invoke_ii(3796,(132797|0))|0);
        $1191 = __THREW__; __THREW__ = 0;
        $1192 = $1191&1;
        if ($1192) {
         label = 51;
         break;
        }
        $1193 = ((($0)) + 656|0);
        HEAP32[$1193>>2] = $1190;
        __THREW__ = 0;
        $1194 = (invoke_ii(3796,(132816|0))|0);
        $1195 = __THREW__; __THREW__ = 0;
        $1196 = $1195&1;
        if ($1196) {
         label = 51;
         break;
        }
        $1197 = ((($0)) + 660|0);
        HEAP32[$1197>>2] = $1194;
        __THREW__ = 0;
        $1198 = (invoke_ii(3796,(132837|0))|0);
        $1199 = __THREW__; __THREW__ = 0;
        $1200 = $1199&1;
        if ($1200) {
         label = 51;
         break;
        }
        $1201 = ((($0)) + 664|0);
        HEAP32[$1201>>2] = $1198;
        __THREW__ = 0;
        $1202 = (invoke_ii(3796,(132858|0))|0);
        $1203 = __THREW__; __THREW__ = 0;
        $1204 = $1203&1;
        if ($1204) {
         label = 51;
         break;
        }
        $1205 = ((($0)) + 668|0);
        HEAP32[$1205>>2] = $1202;
        __THREW__ = 0;
        $1206 = (invoke_ii(3796,(132879|0))|0);
        $1207 = __THREW__; __THREW__ = 0;
        $1208 = $1207&1;
        if ($1208) {
         label = 51;
         break;
        }
        $1209 = ((($0)) + 672|0);
        HEAP32[$1209>>2] = $1206;
        __THREW__ = 0;
        $1210 = (invoke_ii(3796,(132900|0))|0);
        $1211 = __THREW__; __THREW__ = 0;
        $1212 = $1211&1;
        if ($1212) {
         label = 51;
         break;
        }
        $1213 = ((($0)) + 676|0);
        HEAP32[$1213>>2] = $1210;
        __THREW__ = 0;
        $1214 = (invoke_ii(3796,(132921|0))|0);
        $1215 = __THREW__; __THREW__ = 0;
        $1216 = $1215&1;
        if ($1216) {
         label = 51;
         break;
        }
        $1217 = ((($0)) + 680|0);
        HEAP32[$1217>>2] = $1214;
        __THREW__ = 0;
        $1218 = (invoke_ii(3796,(132942|0))|0);
        $1219 = __THREW__; __THREW__ = 0;
        $1220 = $1219&1;
        if ($1220) {
         label = 51;
         break;
        }
        $1221 = ((($0)) + 684|0);
        HEAP32[$1221>>2] = $1218;
        __THREW__ = 0;
        $1222 = (invoke_ii(3796,(132975|0))|0);
        $1223 = __THREW__; __THREW__ = 0;
        $1224 = $1223&1;
        if ($1224) {
         label = 51;
         break;
        }
        $1225 = ((($0)) + 688|0);
        HEAP32[$1225>>2] = $1222;
        $1226 = ((($0)) + 780|0);
        __THREW__ = 0;
        $1227 = (invoke_ii(3796,(132993|0))|0);
        $1228 = __THREW__; __THREW__ = 0;
        $1229 = $1228&1;
        if ($1229) {
         label = 51;
         break;
        }
        $1230 = ($1227|0)==(0|0);
        if ($1230) {
         __THREW__ = 0;
         $1231 = (invoke_ii(3796,(133009|0))|0);
         $1232 = __THREW__; __THREW__ = 0;
         $1233 = $1232&1;
         if ($1233) {
          label = 51;
          break;
         } else {
          $$in$i$i1254 = $1231;
         }
        } else {
         $$in$i$i1254 = $1227;
        }
        HEAP32[$1226>>2] = $$in$i$i1254;
        $1234 = ((($0)) + 720|0);
        __THREW__ = 0;
        $1235 = (invoke_ii(3796,(196553|0))|0);
        $1236 = __THREW__; __THREW__ = 0;
        $1237 = $1236&1;
        if ($1237) {
         label = 51;
         break;
        }
        $1238 = ($1235|0)==(0|0);
        if ($1238) {
         __THREW__ = 0;
         $1239 = (invoke_ii(3796,(133028|0))|0);
         $1240 = __THREW__; __THREW__ = 0;
         $1241 = $1240&1;
         if ($1241) {
          label = 51;
          break;
         } else {
          $$in$i$i1260 = $1239;
         }
        } else {
         $$in$i$i1260 = $1235;
        }
        HEAP32[$1234>>2] = $$in$i$i1260;
        $1242 = ((($0)) + 724|0);
        __THREW__ = 0;
        $1243 = (invoke_ii(3796,(197144|0))|0);
        $1244 = __THREW__; __THREW__ = 0;
        $1245 = $1244&1;
        if ($1245) {
         label = 51;
         break;
        }
        $1246 = ($1243|0)==(0|0);
        if ($1246) {
         __THREW__ = 0;
         $1247 = (invoke_ii(3796,(149555|0))|0);
         $1248 = __THREW__; __THREW__ = 0;
         $1249 = $1248&1;
         if ($1249) {
          label = 51;
          break;
         } else {
          $$in$i$i1265 = $1247;
         }
        } else {
         $$in$i$i1265 = $1243;
        }
        HEAP32[$1242>>2] = $$in$i$i1265;
        $1250 = ((($0)) + 728|0);
        __THREW__ = 0;
        $1251 = (invoke_ii(3796,(196605|0))|0);
        $1252 = __THREW__; __THREW__ = 0;
        $1253 = $1252&1;
        if ($1253) {
         label = 51;
         break;
        }
        $1254 = ($1251|0)==(0|0);
        if ($1254) {
         __THREW__ = 0;
         $1255 = (invoke_ii(3796,(133044|0))|0);
         $1256 = __THREW__; __THREW__ = 0;
         $1257 = $1256&1;
         if ($1257) {
          label = 51;
          break;
         } else {
          $$in$i$i1271 = $1255;
         }
        } else {
         $$in$i$i1271 = $1251;
        }
        HEAP32[$1250>>2] = $$in$i$i1271;
        $1258 = ((($0)) + 732|0);
        __THREW__ = 0;
        $1259 = (invoke_ii(3796,(196618|0))|0);
        $1260 = __THREW__; __THREW__ = 0;
        $1261 = $1260&1;
        if ($1261) {
         label = 51;
         break;
        }
        $1262 = ($1259|0)==(0|0);
        if ($1262) {
         __THREW__ = 0;
         $1263 = (invoke_ii(3796,(133060|0))|0);
         $1264 = __THREW__; __THREW__ = 0;
         $1265 = $1264&1;
         if ($1265) {
          label = 51;
          break;
         } else {
          $$in$i$i1276 = $1263;
         }
        } else {
         $$in$i$i1276 = $1259;
        }
        HEAP32[$1258>>2] = $$in$i$i1276;
        $1266 = ((($0)) + 736|0);
        __THREW__ = 0;
        $1267 = (invoke_ii(3796,(196566|0))|0);
        $1268 = __THREW__; __THREW__ = 0;
        $1269 = $1268&1;
        if ($1269) {
         label = 51;
         break;
        }
        $1270 = ($1267|0)==(0|0);
        if ($1270) {
         __THREW__ = 0;
         $1271 = (invoke_ii(3796,(133079|0))|0);
         $1272 = __THREW__; __THREW__ = 0;
         $1273 = $1272&1;
         if ($1273) {
          label = 51;
          break;
         } else {
          $$in$i$i1281 = $1271;
         }
        } else {
         $$in$i$i1281 = $1267;
        }
        HEAP32[$1266>>2] = $$in$i$i1281;
        $1274 = ((($0)) + 740|0);
        __THREW__ = 0;
        $1275 = (invoke_ii(3796,(196634|0))|0);
        $1276 = __THREW__; __THREW__ = 0;
        $1277 = $1276&1;
        if ($1277) {
         label = 51;
         break;
        }
        $1278 = ($1275|0)==(0|0);
        if ($1278) {
         __THREW__ = 0;
         $1279 = (invoke_ii(3796,(133098|0))|0);
         $1280 = __THREW__; __THREW__ = 0;
         $1281 = $1280&1;
         if ($1281) {
          label = 51;
          break;
         } else {
          $$in$i$i1287 = $1279;
         }
        } else {
         $$in$i$i1287 = $1275;
        }
        HEAP32[$1274>>2] = $$in$i$i1287;
        $1282 = ((($0)) + 744|0);
        __THREW__ = 0;
        $1283 = (invoke_ii(3796,(133112|0))|0);
        $1284 = __THREW__; __THREW__ = 0;
        $1285 = $1284&1;
        if ($1285) {
         label = 51;
         break;
        }
        $1286 = ($1283|0)==(0|0);
        if ($1286) {
         __THREW__ = 0;
         $1287 = (invoke_ii(3796,(133131|0))|0);
         $1288 = __THREW__; __THREW__ = 0;
         $1289 = $1288&1;
         if ($1289) {
          label = 51;
          break;
         } else {
          $$in$i$i1292 = $1287;
         }
        } else {
         $$in$i$i1292 = $1283;
        }
        HEAP32[$1282>>2] = $$in$i$i1292;
        $1290 = ((($0)) + 748|0);
        __THREW__ = 0;
        $1291 = (invoke_ii(3796,(133153|0))|0);
        $1292 = __THREW__; __THREW__ = 0;
        $1293 = $1292&1;
        if ($1293) {
         label = 51;
         break;
        }
        $1294 = ($1291|0)==(0|0);
        if ($1294) {
         __THREW__ = 0;
         $1295 = (invoke_ii(3796,(133165|0))|0);
         $1296 = __THREW__; __THREW__ = 0;
         $1297 = $1296&1;
         if ($1297) {
          label = 51;
          break;
         } else {
          $$in$i$i1297 = $1295;
         }
        } else {
         $$in$i$i1297 = $1291;
        }
        HEAP32[$1290>>2] = $$in$i$i1297;
        $1298 = ((($0)) + 752|0);
        __THREW__ = 0;
        $1299 = (invoke_ii(3796,(133180|0))|0);
        $1300 = __THREW__; __THREW__ = 0;
        $1301 = $1300&1;
        if ($1301) {
         label = 51;
         break;
        }
        $1302 = ($1299|0)==(0|0);
        if ($1302) {
         __THREW__ = 0;
         $1303 = (invoke_ii(3796,(133197|0))|0);
         $1304 = __THREW__; __THREW__ = 0;
         $1305 = $1304&1;
         if ($1305) {
          label = 51;
          break;
         } else {
          $$in$i$i1302 = $1303;
         }
        } else {
         $$in$i$i1302 = $1299;
        }
        HEAP32[$1298>>2] = $$in$i$i1302;
        $1306 = ((($0)) + 756|0);
        __THREW__ = 0;
        $1307 = (invoke_ii(3796,(133217|0))|0);
        $1308 = __THREW__; __THREW__ = 0;
        $1309 = $1308&1;
        if ($1309) {
         label = 51;
         break;
        }
        $1310 = ($1307|0)==(0|0);
        if ($1310) {
         __THREW__ = 0;
         $1311 = (invoke_ii(3796,(133231|0))|0);
         $1312 = __THREW__; __THREW__ = 0;
         $1313 = $1312&1;
         if ($1313) {
          label = 51;
          break;
         } else {
          $$in$i$i1307 = $1311;
         }
        } else {
         $$in$i$i1307 = $1307;
        }
        HEAP32[$1306>>2] = $$in$i$i1307;
        $1314 = ((($0)) + 760|0);
        __THREW__ = 0;
        $1315 = (invoke_ii(3796,(196582|0))|0);
        $1316 = __THREW__; __THREW__ = 0;
        $1317 = $1316&1;
        if ($1317) {
         label = 51;
         break;
        }
        $1318 = ($1315|0)==(0|0);
        if ($1318) {
         __THREW__ = 0;
         $1319 = (invoke_ii(3796,(133248|0))|0);
         $1320 = __THREW__; __THREW__ = 0;
         $1321 = $1320&1;
         if ($1321) {
          label = 51;
          break;
         } else {
          $$in$i$i1313 = $1319;
         }
        } else {
         $$in$i$i1313 = $1315;
        }
        HEAP32[$1314>>2] = $$in$i$i1313;
        $1322 = ((($0)) + 764|0);
        __THREW__ = 0;
        $1323 = (invoke_ii(3796,(133274|0))|0);
        $1324 = __THREW__; __THREW__ = 0;
        $1325 = $1324&1;
        if ($1325) {
         label = 51;
         break;
        }
        $1326 = ($1323|0)==(0|0);
        if ($1326) {
         __THREW__ = 0;
         $1327 = (invoke_ii(3796,(133294|0))|0);
         $1328 = __THREW__; __THREW__ = 0;
         $1329 = $1328&1;
         if ($1329) {
          label = 51;
          break;
         } else {
          $$in$i$i1318 = $1327;
         }
        } else {
         $$in$i$i1318 = $1323;
        }
        HEAP32[$1322>>2] = $$in$i$i1318;
        __THREW__ = 0;
        $1330 = (invoke_ii(3796,(133317|0))|0);
        $1331 = __THREW__; __THREW__ = 0;
        $1332 = $1331&1;
        if ($1332) {
         label = 51;
         break;
        }
        $1333 = ((($0)) + 768|0);
        HEAP32[$1333>>2] = $1330;
        $1334 = ((($0)) + 772|0);
        __THREW__ = 0;
        $1335 = (invoke_ii(3796,(133335|0))|0);
        $1336 = __THREW__; __THREW__ = 0;
        $1337 = $1336&1;
        if ($1337) {
         label = 51;
         break;
        }
        $1338 = ($1335|0)==(0|0);
        do {
         if ($1338) {
          __THREW__ = 0;
          $1339 = (invoke_ii(3796,(133352|0))|0);
          $1340 = __THREW__; __THREW__ = 0;
          $1341 = $1340&1;
          if ($1341) {
           label = 51;
           break L71;
          }
          $1342 = ($1339|0)==(0|0);
          if (!($1342)) {
           $$in$i$i1325 = $1339;
           break;
          }
          __THREW__ = 0;
          $1343 = (invoke_ii(3796,(133372|0))|0);
          $1344 = __THREW__; __THREW__ = 0;
          $1345 = $1344&1;
          if ($1345) {
           label = 51;
           break L71;
          } else {
           $$in$i$i1325 = $1343;
          }
         } else {
          $$in$i$i1325 = $1335;
         }
        } while(0);
        HEAP32[$1334>>2] = $$in$i$i1325;
        $1346 = ((($0)) + 776|0);
        __THREW__ = 0;
        $1347 = (invoke_ii(3796,(133391|0))|0);
        $1348 = __THREW__; __THREW__ = 0;
        $1349 = $1348&1;
        if ($1349) {
         label = 51;
         break;
        }
        $1350 = ($1347|0)==(0|0);
        if ($1350) {
         __THREW__ = 0;
         $1351 = (invoke_ii(3796,(133403|0))|0);
         $1352 = __THREW__; __THREW__ = 0;
         $1353 = $1352&1;
         if ($1353) {
          label = 51;
          break;
         } else {
          $$in$i$i1330 = $1351;
         }
        } else {
         $$in$i$i1330 = $1347;
        }
        HEAP32[$1346>>2] = $$in$i$i1330;
        $1354 = ((($0)) + 713|0);
        HEAP8[$1354>>0] = $1355;
        $1356 = ((($0)) + 714|0);
        HEAP8[$1356>>0] = $1355;
        $1357 = HEAP32[$6>>2]|0;
        __THREW__ = 0;
        $1358 = (invoke_iiid(3793,($1357|0),(133418|0),3.4028234663852886E+38)|0);
        $1359 = __THREW__; __THREW__ = 0;
        $1360 = $1359&1;
        if ($1360) {
         label = 51;
         break;
        }
        $1361 = ((($0)) + 715|0);
        $1362 = $1358&1;
        HEAP8[$1361>>0] = $1362;
        $1363 = HEAP32[$6>>2]|0;
        __THREW__ = 0;
        $1364 = (invoke_iiid(3793,($1363|0),(133447|0),3.4028234663852886E+38)|0);
        $1365 = __THREW__; __THREW__ = 0;
        $1366 = $1365&1;
        if ($1366) {
         label = 51;
         break;
        }
        if ($1364) {
         $$ph2827 = 1;
        } else {
         __THREW__ = 0;
         $1367 = (invoke_iiid(3793,($1363|0),(133474|0),3.4028234663852886E+38)|0);
         $1368 = __THREW__; __THREW__ = 0;
         $1369 = $1368&1;
         if ($1369) {
          label = 51;
          break;
         } else {
          $$ph2827 = $1367;
         }
        }
        $1375 = ((($0)) + 716|0);
        $1376 = $$ph2827&1;
        HEAP8[$1375>>0] = $1376;
        $1377 = HEAP32[$6>>2]|0;
        __THREW__ = 0;
        $1378 = (invoke_iiid(3793,($1377|0),(133501|0),3.4028234663852886E+38)|0);
        $1379 = __THREW__; __THREW__ = 0;
        $1380 = $1379&1;
        if ($1380) {
         label = 51;
         break;
        } else {
         $1383 = $1378;$1385 = $1354;$1388 = $1356;
        }
       } else {
        $1370 = ((($0)) + 720|0);
        $1371 = ((($0)) + 713|0);
        _memset(($242|0),0,652)|0;
        dest=$1370; stop=dest+64|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
        HEAP8[$1371>>0] = $1355;
        $1372 = ((($0)) + 714|0);
        HEAP8[$1372>>0] = $1355;
        $1373 = ((($0)) + 715|0);
        HEAP8[$1373>>0] = 0;
        $1374 = ((($0)) + 716|0);
        HEAP8[$1374>>0] = 0;
        $1383 = 0;$1385 = $1371;$1388 = $1372;
       }
       $1381 = ((($0)) + 717|0);
       $1382 = $1383&1;
       HEAP8[$1381>>0] = $1382;
       $1384 = HEAP8[$1385>>0]|0;
       $1386 = ($1384<<24>>24)==(0);
       if ($1386) {
        $1392 = 0;
       } else {
        $1387 = HEAP8[$1388>>0]|0;
        $1389 = ($1387<<24>>24)!=(0);
        $1392 = $1389;
       }
       $1390 = ((($0)) + 712|0);
       $1391 = $1392&1;
       HEAP8[$1390>>0] = $1391;
       $1393 = ((($0)) + 784|0);
       HEAP8[$1393>>0] = $1355;
       $1394 = ((($0)) + 788|0);
       if ($10) {
        __THREW__ = 0;
        $1395 = (invoke_ii(3796,(198792|0))|0);
        $1396 = __THREW__; __THREW__ = 0;
        $1397 = $1396&1;
        if ($1397) {
         label = 51;
         break;
        }
        $1398 = ($1395|0)==(0|0);
        if ($1398) {
         __THREW__ = 0;
         $1399 = (invoke_ii(3796,(133528|0))|0);
         $1400 = __THREW__; __THREW__ = 0;
         $1401 = $1400&1;
         if ($1401) {
          label = 51;
          break;
         } else {
          $$in$i$i1341 = $1399;
         }
        } else {
         $$in$i$i1341 = $1395;
        }
        HEAP32[$1394>>2] = $$in$i$i1341;
        $1402 = ((($0)) + 792|0);
        __THREW__ = 0;
        $1403 = (invoke_ii(3796,(133551|0))|0);
        $1404 = __THREW__; __THREW__ = 0;
        $1405 = $1404&1;
        if ($1405) {
         label = 51;
         break;
        }
        $1406 = ($1403|0)==(0|0);
        if ($1406) {
         __THREW__ = 0;
         $1407 = (invoke_ii(3796,(133564|0))|0);
         $1408 = __THREW__; __THREW__ = 0;
         $1409 = $1408&1;
         if ($1409) {
          label = 51;
          break;
         } else {
          $$in$i$i1346 = $1407;
         }
        } else {
         $$in$i$i1346 = $1403;
        }
        HEAP32[$1402>>2] = $$in$i$i1346;
        $1410 = ((($0)) + 796|0);
        __THREW__ = 0;
        $1411 = (invoke_ii(3796,(133580|0))|0);
        $1412 = __THREW__; __THREW__ = 0;
        $1413 = $1412&1;
        if ($1413) {
         label = 51;
         break;
        }
        $1414 = ($1411|0)==(0|0);
        if ($1414) {
         __THREW__ = 0;
         $1415 = (invoke_ii(3796,(133601|0))|0);
         $1416 = __THREW__; __THREW__ = 0;
         $1417 = $1416&1;
         if ($1417) {
          label = 51;
          break;
         } else {
          $$in$i$i1352 = $1415;
         }
        } else {
         $$in$i$i1352 = $1411;
        }
        HEAP32[$1410>>2] = $$in$i$i1352;
        $1418 = HEAP32[$6>>2]|0;
        __THREW__ = 0;
        $1419 = (invoke_iiid(3793,($1418|0),(149157|0),3.4028234663852886E+38)|0);
        $1420 = __THREW__; __THREW__ = 0;
        $1421 = $1420&1;
        if ($1421) {
         label = 51;
         break;
        }
        $1422 = ((($0)) + 800|0);
        $1423 = $1419&1;
        HEAP8[$1422>>0] = $1423;
        $1424 = HEAP32[$6>>2]|0;
        __THREW__ = 0;
        $1425 = (invoke_iiid(3793,($1424|0),(149180|0),3.4028234663852886E+38)|0);
        $1426 = __THREW__; __THREW__ = 0;
        $1427 = $1426&1;
        if ($1427) {
         label = 51;
         break;
        }
        $1428 = ((($0)) + 801|0);
        $1429 = $1425&1;
        HEAP8[$1428>>0] = $1429;
        $1430 = HEAP32[$6>>2]|0;
        __THREW__ = 0;
        $1431 = (invoke_iiid(3793,($1430|0),(133625|0),3.4028234663852886E+38)|0);
        $1432 = __THREW__; __THREW__ = 0;
        $1433 = $1432&1;
        if ($1433) {
         label = 51;
         break;
        }
        $1434 = ((($0)) + 802|0);
        $1435 = $1431&1;
        HEAP8[$1434>>0] = $1435;
        $1436 = HEAP32[$6>>2]|0;
        __THREW__ = 0;
        $1437 = (invoke_iiid(3793,($1436|0),(133645|0),3.4028234663852886E+38)|0);
        $1438 = __THREW__; __THREW__ = 0;
        $1439 = $1438&1;
        if ($1439) {
         label = 51;
         break;
        }
        $1440 = ((($0)) + 803|0);
        $1441 = $1437&1;
        HEAP8[$1440>>0] = $1441;
        $1442 = HEAP32[$6>>2]|0;
        __THREW__ = 0;
        $1443 = (invoke_iiid(3793,($1442|0),(133667|0),3.4028234663852886E+38)|0);
        $1444 = __THREW__; __THREW__ = 0;
        $1445 = $1444&1;
        if ($1445) {
         label = 51;
         break;
        }
        $1446 = ((($0)) + 804|0);
        $1447 = $1443&1;
        HEAP8[$1446>>0] = $1447;
        $1448 = HEAP32[$6>>2]|0;
        __THREW__ = 0;
        $1449 = (invoke_iiid(3793,($1448|0),(133690|0),3.4028234663852886E+38)|0);
        $1450 = __THREW__; __THREW__ = 0;
        $1451 = $1450&1;
        if ($1451) {
         label = 51;
         break;
        }
        $1452 = ((($0)) + 805|0);
        $1453 = $1449&1;
        HEAP8[$1452>>0] = $1453;
        $1454 = HEAP32[$6>>2]|0;
        __THREW__ = 0;
        $1455 = (invoke_iiid(3793,($1454|0),(133709|0),3.4028234663852886E+38)|0);
        $1456 = __THREW__; __THREW__ = 0;
        $1457 = $1456&1;
        if ($1457) {
         label = 51;
         break;
        }
        $1458 = ((($0)) + 806|0);
        $1459 = $1455&1;
        HEAP8[$1458>>0] = $1459;
        $1460 = ((($0)) + 808|0);
        __THREW__ = 0;
        $1461 = (invoke_ii(3796,(198199|0))|0);
        $1462 = __THREW__; __THREW__ = 0;
        $1463 = $1462&1;
        if ($1463) {
         label = 51;
         break;
        }
        $1464 = ($1461|0)==(0|0);
        do {
         if ($1464) {
          __THREW__ = 0;
          $1465 = (invoke_ii(3796,(149571|0))|0);
          $1466 = __THREW__; __THREW__ = 0;
          $1467 = $1466&1;
          if ($1467) {
           label = 51;
           break L71;
          }
          $1468 = ($1465|0)==(0|0);
          if (!($1468)) {
           $$in$i$i1371 = $1465;
           break;
          }
          __THREW__ = 0;
          $1469 = (invoke_ii(3796,(149596|0))|0);
          $1470 = __THREW__; __THREW__ = 0;
          $1471 = $1470&1;
          if ($1471) {
           label = 51;
           break L71;
          } else {
           $$in$i$i1371 = $1469;
          }
         } else {
          $$in$i$i1371 = $1461;
         }
        } while(0);
        HEAP32[$1460>>2] = $$in$i$i1371;
        $1472 = ((($0)) + 812|0);
        __THREW__ = 0;
        $1473 = (invoke_ii(3796,(198221|0))|0);
        $1474 = __THREW__; __THREW__ = 0;
        $1475 = $1474&1;
        if ($1475) {
         label = 51;
         break;
        }
        $1476 = ($1473|0)==(0|0);
        do {
         if ($1476) {
          __THREW__ = 0;
          $1477 = (invoke_ii(3796,(149621|0))|0);
          $1478 = __THREW__; __THREW__ = 0;
          $1479 = $1478&1;
          if ($1479) {
           label = 51;
           break L71;
          }
          $1480 = ($1477|0)==(0|0);
          if (!($1480)) {
           $$in$i$i1377 = $1477;
           break;
          }
          __THREW__ = 0;
          $1481 = (invoke_ii(3796,(149648|0))|0);
          $1482 = __THREW__; __THREW__ = 0;
          $1483 = $1482&1;
          if ($1483) {
           label = 51;
           break L71;
          } else {
           $$in$i$i1377 = $1481;
          }
         } else {
          $$in$i$i1377 = $1473;
         }
        } while(0);
        HEAP32[$1472>>2] = $$in$i$i1377;
        $1484 = ((($0)) + 824|0);
        __THREW__ = 0;
        $1485 = (invoke_ii(3796,(133728|0))|0);
        $1486 = __THREW__; __THREW__ = 0;
        $1487 = $1486&1;
        if ($1487) {
         label = 51;
         break;
        }
        $1488 = ($1485|0)==(0|0);
        if ($1488) {
         __THREW__ = 0;
         $1489 = (invoke_ii(3796,(133741|0))|0);
         $1490 = __THREW__; __THREW__ = 0;
         $1491 = $1490&1;
         if ($1491) {
          label = 51;
          break;
         } else {
          $$in$i$i1383 = $1489;
         }
        } else {
         $$in$i$i1383 = $1485;
        }
        HEAP32[$1484>>2] = $$in$i$i1383;
        $1492 = ((($0)) + 816|0);
        __THREW__ = 0;
        $1493 = (invoke_ii(3796,(133757|0))|0);
        $1494 = __THREW__; __THREW__ = 0;
        $1495 = $1494&1;
        if ($1495) {
         label = 51;
         break;
        }
        $1496 = ($1493|0)==(0|0);
        if ($1496) {
         __THREW__ = 0;
         $1497 = (invoke_ii(3796,(133778|0))|0);
         $1498 = __THREW__; __THREW__ = 0;
         $1499 = $1498&1;
         if ($1499) {
          label = 51;
          break;
         } else {
          $$in$i$i1388 = $1497;
         }
        } else {
         $$in$i$i1388 = $1493;
        }
        HEAP32[$1492>>2] = $$in$i$i1388;
        $1500 = ((($0)) + 820|0);
        __THREW__ = 0;
        $1501 = (invoke_ii(3796,(133802|0))|0);
        $1502 = __THREW__; __THREW__ = 0;
        $1503 = $1502&1;
        if ($1503) {
         label = 51;
         break;
        }
        $1504 = ($1501|0)==(0|0);
        if ($1504) {
         __THREW__ = 0;
         $1505 = (invoke_ii(3796,(133822|0))|0);
         $1506 = __THREW__; __THREW__ = 0;
         $1507 = $1506&1;
         if ($1507) {
          label = 51;
          break;
         } else {
          $$in$i$i1393 = $1505;
         }
        } else {
         $$in$i$i1393 = $1501;
        }
        HEAP32[$1500>>2] = $$in$i$i1393;
        $1508 = ((($0)) + 828|0);
        __THREW__ = 0;
        $1509 = (invoke_ii(3796,(133845|0))|0);
        $1510 = __THREW__; __THREW__ = 0;
        $1511 = $1510&1;
        if ($1511) {
         label = 51;
         break;
        }
        $1512 = ($1509|0)==(0|0);
        if ($1512) {
         __THREW__ = 0;
         $1513 = (invoke_ii(3796,(133863|0))|0);
         $1514 = __THREW__; __THREW__ = 0;
         $1515 = $1514&1;
         if ($1515) {
          label = 51;
          break;
         } else {
          $$in$i$i1399 = $1513;
         }
        } else {
         $$in$i$i1399 = $1509;
        }
        HEAP32[$1508>>2] = $$in$i$i1399;
        $1516 = ((($0)) + 832|0);
        __THREW__ = 0;
        $1517 = (invoke_ii(3796,(149486|0))|0);
        $1518 = __THREW__; __THREW__ = 0;
        $1519 = $1518&1;
        if ($1519) {
         label = 51;
         break;
        }
        $1520 = ($1517|0)==(0|0);
        if ($1520) {
         __THREW__ = 0;
         $1521 = (invoke_ii(3796,(149504|0))|0);
         $1522 = __THREW__; __THREW__ = 0;
         $1523 = $1522&1;
         if ($1523) {
          label = 51;
          break;
         } else {
          $$in$i$i1405 = $1521;
         }
        } else {
         $$in$i$i1405 = $1517;
        }
        HEAP32[$1516>>2] = $$in$i$i1405;
        $1524 = ((($0)) + 836|0);
        __THREW__ = 0;
        $1525 = (invoke_ii(3796,(133884|0))|0);
        $1526 = __THREW__; __THREW__ = 0;
        $1527 = $1526&1;
        if ($1527) {
         label = 51;
         break;
        }
        $1528 = ($1525|0)==(0|0);
        if ($1528) {
         __THREW__ = 0;
         $1529 = (invoke_ii(3796,(133903|0))|0);
         $1530 = __THREW__; __THREW__ = 0;
         $1531 = $1530&1;
         if ($1531) {
          label = 51;
          break;
         } else {
          $$in$i$i1410 = $1529;
         }
        } else {
         $$in$i$i1410 = $1525;
        }
        HEAP32[$1524>>2] = $$in$i$i1410;
        $1532 = ((($0)) + 840|0);
        __THREW__ = 0;
        $1533 = (invoke_ii(3796,(133925|0))|0);
        $1534 = __THREW__; __THREW__ = 0;
        $1535 = $1534&1;
        if ($1535) {
         label = 51;
         break;
        }
        $1536 = ($1533|0)==(0|0);
        if ($1536) {
         __THREW__ = 0;
         $1537 = (invoke_ii(3796,(133944|0))|0);
         $1538 = __THREW__; __THREW__ = 0;
         $1539 = $1538&1;
         if ($1539) {
          label = 51;
          break;
         } else {
          $$in$i$i1416 = $1537;
         }
        } else {
         $$in$i$i1416 = $1533;
        }
        HEAP32[$1532>>2] = $$in$i$i1416;
        $1540 = ((($0)) + 844|0);
        __THREW__ = 0;
        $1541 = (invoke_ii(3796,(133966|0))|0);
        $1542 = __THREW__; __THREW__ = 0;
        $1543 = $1542&1;
        if ($1543) {
         label = 51;
         break;
        }
        $1544 = ($1541|0)==(0|0);
        if ($1544) {
         __THREW__ = 0;
         $1545 = (invoke_ii(3796,(133985|0))|0);
         $1546 = __THREW__; __THREW__ = 0;
         $1547 = $1546&1;
         if ($1547) {
          label = 51;
          break;
         } else {
          $$in$i$i1422 = $1545;
         }
        } else {
         $$in$i$i1422 = $1541;
        }
        HEAP32[$1540>>2] = $$in$i$i1422;
        $1548 = ((($0)) + 848|0);
        __THREW__ = 0;
        $1549 = (invoke_ii(3796,(134007|0))|0);
        $1550 = __THREW__; __THREW__ = 0;
        $1551 = $1550&1;
        if ($1551) {
         label = 51;
         break;
        }
        $1552 = ($1549|0)==(0|0);
        if ($1552) {
         __THREW__ = 0;
         $1553 = (invoke_ii(3796,(134026|0))|0);
         $1554 = __THREW__; __THREW__ = 0;
         $1555 = $1554&1;
         if ($1555) {
          label = 51;
          break;
         } else {
          $$in$i$i1428 = $1553;
         }
        } else {
         $$in$i$i1428 = $1549;
        }
        HEAP32[$1548>>2] = $$in$i$i1428;
        $1556 = ((($0)) + 852|0);
        __THREW__ = 0;
        $1557 = (invoke_ii(3796,(134048|0))|0);
        $1558 = __THREW__; __THREW__ = 0;
        $1559 = $1558&1;
        if ($1559) {
         label = 51;
         break;
        }
        $1560 = ($1557|0)==(0|0);
        if ($1560) {
         __THREW__ = 0;
         $1561 = (invoke_ii(3796,(134066|0))|0);
         $1562 = __THREW__; __THREW__ = 0;
         $1563 = $1562&1;
         if ($1563) {
          label = 51;
          break;
         } else {
          $$in$i$i1434 = $1561;
         }
        } else {
         $$in$i$i1434 = $1557;
        }
        HEAP32[$1556>>2] = $$in$i$i1434;
        $1564 = ((($0)) + 856|0);
        __THREW__ = 0;
        $1565 = (invoke_ii(3796,(134087|0))|0);
        $1566 = __THREW__; __THREW__ = 0;
        $1567 = $1566&1;
        if ($1567) {
         label = 51;
         break;
        }
        $1568 = ($1565|0)==(0|0);
        if ($1568) {
         __THREW__ = 0;
         $1569 = (invoke_ii(3796,(134106|0))|0);
         $1570 = __THREW__; __THREW__ = 0;
         $1571 = $1570&1;
         if ($1571) {
          label = 51;
          break;
         } else {
          $$in$i$i1440 = $1569;
         }
        } else {
         $$in$i$i1440 = $1565;
        }
        HEAP32[$1564>>2] = $$in$i$i1440;
        $1572 = ((($0)) + 860|0);
        __THREW__ = 0;
        $1573 = (invoke_ii(3796,(134128|0))|0);
        $1574 = __THREW__; __THREW__ = 0;
        $1575 = $1574&1;
        if ($1575) {
         label = 51;
         break;
        }
        $1576 = ($1573|0)==(0|0);
        if ($1576) {
         __THREW__ = 0;
         $1577 = (invoke_ii(3796,(134147|0))|0);
         $1578 = __THREW__; __THREW__ = 0;
         $1579 = $1578&1;
         if ($1579) {
          label = 51;
          break;
         } else {
          $$in$i$i1446 = $1577;
         }
        } else {
         $$in$i$i1446 = $1573;
        }
        HEAP32[$1572>>2] = $$in$i$i1446;
        $1580 = ((($0)) + 864|0);
        __THREW__ = 0;
        $1581 = (invoke_ii(3796,(134169|0))|0);
        $1582 = __THREW__; __THREW__ = 0;
        $1583 = $1582&1;
        if ($1583) {
         label = 51;
         break;
        }
        $1584 = ($1581|0)==(0|0);
        if ($1584) {
         __THREW__ = 0;
         $1585 = (invoke_ii(3796,(134188|0))|0);
         $1586 = __THREW__; __THREW__ = 0;
         $1587 = $1586&1;
         if ($1587) {
          label = 51;
          break;
         } else {
          $$in$i$i1452 = $1585;
         }
        } else {
         $$in$i$i1452 = $1581;
        }
        HEAP32[$1580>>2] = $$in$i$i1452;
        $1588 = ((($0)) + 868|0);
        __THREW__ = 0;
        $1589 = (invoke_ii(3796,(134210|0))|0);
        $1590 = __THREW__; __THREW__ = 0;
        $1591 = $1590&1;
        if ($1591) {
         label = 51;
         break;
        }
        $1592 = ($1589|0)==(0|0);
        if ($1592) {
         __THREW__ = 0;
         $1593 = (invoke_ii(3796,(134229|0))|0);
         $1594 = __THREW__; __THREW__ = 0;
         $1595 = $1594&1;
         if ($1595) {
          label = 51;
          break;
         } else {
          $$in$i$i1458 = $1593;
         }
        } else {
         $$in$i$i1458 = $1589;
        }
        HEAP32[$1588>>2] = $$in$i$i1458;
        $1596 = ((($0)) + 872|0);
        __THREW__ = 0;
        $1597 = (invoke_ii(3796,(134251|0))|0);
        $1598 = __THREW__; __THREW__ = 0;
        $1599 = $1598&1;
        if ($1599) {
         label = 51;
         break;
        }
        $1600 = ($1597|0)==(0|0);
        if ($1600) {
         __THREW__ = 0;
         $1601 = (invoke_ii(3796,(134273|0))|0);
         $1602 = __THREW__; __THREW__ = 0;
         $1603 = $1602&1;
         if ($1603) {
          label = 51;
          break;
         } else {
          $$in$i$i1464 = $1601;
         }
        } else {
         $$in$i$i1464 = $1597;
        }
        HEAP32[$1596>>2] = $$in$i$i1464;
        $1604 = ((($0)) + 876|0);
        __THREW__ = 0;
        $1605 = (invoke_ii(3796,(134297|0))|0);
        $1606 = __THREW__; __THREW__ = 0;
        $1607 = $1606&1;
        if ($1607) {
         label = 51;
         break;
        }
        $1608 = ($1605|0)==(0|0);
        if ($1608) {
         __THREW__ = 0;
         $1609 = (invoke_ii(3796,(134322|0))|0);
         $1610 = __THREW__; __THREW__ = 0;
         $1611 = $1610&1;
         if ($1611) {
          label = 51;
          break;
         } else {
          $$in$i$i1470 = $1609;
         }
        } else {
         $$in$i$i1470 = $1605;
        }
        HEAP32[$1604>>2] = $$in$i$i1470;
        $1612 = ((($0)) + 880|0);
        __THREW__ = 0;
        $1613 = (invoke_ii(3796,(134349|0))|0);
        $1614 = __THREW__; __THREW__ = 0;
        $1615 = $1614&1;
        if ($1615) {
         label = 51;
         break;
        }
        $1616 = ($1613|0)==(0|0);
        if ($1616) {
         __THREW__ = 0;
         $1617 = (invoke_ii(3796,(134368|0))|0);
         $1618 = __THREW__; __THREW__ = 0;
         $1619 = $1618&1;
         if ($1619) {
          label = 51;
          break;
         } else {
          $$in$i$i1476 = $1617;
         }
        } else {
         $$in$i$i1476 = $1613;
        }
        HEAP32[$1612>>2] = $$in$i$i1476;
        $1620 = ((($0)) + 884|0);
        __THREW__ = 0;
        $1621 = (invoke_ii(3796,(134389|0))|0);
        $1622 = __THREW__; __THREW__ = 0;
        $1623 = $1622&1;
        if ($1623) {
         label = 51;
         break;
        }
        $1624 = ($1621|0)==(0|0);
        if ($1624) {
         __THREW__ = 0;
         $1625 = (invoke_ii(3796,(134411|0))|0);
         $1626 = __THREW__; __THREW__ = 0;
         $1627 = $1626&1;
         if ($1627) {
          label = 51;
          break;
         } else {
          $$in$i$i1482 = $1625;
         }
        } else {
         $$in$i$i1482 = $1621;
        }
        HEAP32[$1620>>2] = $$in$i$i1482;
        $1628 = ((($0)) + 888|0);
        __THREW__ = 0;
        $1629 = (invoke_ii(3796,(134435|0))|0);
        $1630 = __THREW__; __THREW__ = 0;
        $1631 = $1630&1;
        if ($1631) {
         label = 51;
         break;
        }
        $1632 = ($1629|0)==(0|0);
        if ($1632) {
         __THREW__ = 0;
         $1633 = (invoke_ii(3796,(134455|0))|0);
         $1634 = __THREW__; __THREW__ = 0;
         $1635 = $1634&1;
         if ($1635) {
          label = 51;
          break;
         } else {
          $$in$i$i1488 = $1633;
         }
        } else {
         $$in$i$i1488 = $1629;
        }
        HEAP32[$1628>>2] = $$in$i$i1488;
        $1636 = ((($0)) + 892|0);
        __THREW__ = 0;
        $1637 = (invoke_ii(3796,(134477|0))|0);
        $1638 = __THREW__; __THREW__ = 0;
        $1639 = $1638&1;
        if ($1639) {
         label = 51;
         break;
        }
        $1640 = ($1637|0)==(0|0);
        if ($1640) {
         __THREW__ = 0;
         $1641 = (invoke_ii(3796,(134499|0))|0);
         $1642 = __THREW__; __THREW__ = 0;
         $1643 = $1642&1;
         if ($1643) {
          label = 51;
          break;
         } else {
          $$in$i$i1493 = $1641;
         }
        } else {
         $$in$i$i1493 = $1637;
        }
        HEAP32[$1636>>2] = $$in$i$i1493;
        $1644 = ((($0)) + 896|0);
        __THREW__ = 0;
        $1645 = (invoke_ii(3796,(134523|0))|0);
        $1646 = __THREW__; __THREW__ = 0;
        $1647 = $1646&1;
        if ($1647) {
         label = 51;
         break;
        }
        $1648 = ($1645|0)==(0|0);
        if ($1648) {
         __THREW__ = 0;
         $1649 = (invoke_ii(3796,(134546|0))|0);
         $1650 = __THREW__; __THREW__ = 0;
         $1651 = $1650&1;
         if ($1651) {
          label = 51;
          break;
         } else {
          $$in$i$i1499 = $1649;
         }
        } else {
         $$in$i$i1499 = $1645;
        }
        HEAP32[$1644>>2] = $$in$i$i1499;
        $1652 = ((($0)) + 904|0);
        __THREW__ = 0;
        $1653 = (invoke_ii(3796,(134571|0))|0);
        $1654 = __THREW__; __THREW__ = 0;
        $1655 = $1654&1;
        if ($1655) {
         label = 51;
         break;
        }
        $1656 = ($1653|0)==(0|0);
        if ($1656) {
         __THREW__ = 0;
         $1657 = (invoke_ii(3796,(134584|0))|0);
         $1658 = __THREW__; __THREW__ = 0;
         $1659 = $1658&1;
         if ($1659) {
          label = 51;
          break;
         } else {
          $$in$i$i1504 = $1657;
         }
        } else {
         $$in$i$i1504 = $1653;
        }
        HEAP32[$1652>>2] = $$in$i$i1504;
        $1660 = ((($0)) + 932|0);
        __THREW__ = 0;
        $1661 = (invoke_ii(3796,(134600|0))|0);
        $1662 = __THREW__; __THREW__ = 0;
        $1663 = $1662&1;
        if ($1663) {
         label = 51;
         break;
        }
        $1664 = ($1661|0)==(0|0);
        if ($1664) {
         __THREW__ = 0;
         $1665 = (invoke_ii(3796,(134616|0))|0);
         $1666 = __THREW__; __THREW__ = 0;
         $1667 = $1666&1;
         if ($1667) {
          label = 51;
          break;
         } else {
          $$in$i$i1510 = $1665;
         }
        } else {
         $$in$i$i1510 = $1661;
        }
        HEAP32[$1660>>2] = $$in$i$i1510;
        $1668 = ((($0)) + 928|0);
        __THREW__ = 0;
        $1669 = (invoke_ii(3796,(134635|0))|0);
        $1670 = __THREW__; __THREW__ = 0;
        $1671 = $1670&1;
        if ($1671) {
         label = 51;
         break;
        }
        $1672 = ($1669|0)==(0|0);
        if ($1672) {
         __THREW__ = 0;
         $1673 = (invoke_ii(3796,(134645|0))|0);
         $1674 = __THREW__; __THREW__ = 0;
         $1675 = $1674&1;
         if ($1675) {
          label = 51;
          break;
         } else {
          $$in$i$i1516 = $1673;
         }
        } else {
         $$in$i$i1516 = $1669;
        }
        HEAP32[$1668>>2] = $$in$i$i1516;
        $1676 = ((($0)) + 908|0);
        __THREW__ = 0;
        $1677 = (invoke_ii(3796,(134658|0))|0);
        $1678 = __THREW__; __THREW__ = 0;
        $1679 = $1678&1;
        if ($1679) {
         label = 51;
         break;
        }
        $1680 = ($1677|0)==(0|0);
        if ($1680) {
         __THREW__ = 0;
         $1681 = (invoke_ii(3796,(134671|0))|0);
         $1682 = __THREW__; __THREW__ = 0;
         $1683 = $1682&1;
         if ($1683) {
          label = 51;
          break;
         } else {
          $$in$i$i1522 = $1681;
         }
        } else {
         $$in$i$i1522 = $1677;
        }
        HEAP32[$1676>>2] = $$in$i$i1522;
        $1684 = ((($0)) + 912|0);
        __THREW__ = 0;
        $1685 = (invoke_ii(3796,(134687|0))|0);
        $1686 = __THREW__; __THREW__ = 0;
        $1687 = $1686&1;
        if ($1687) {
         label = 51;
         break;
        }
        $1688 = ($1685|0)==(0|0);
        if ($1688) {
         __THREW__ = 0;
         $1689 = (invoke_ii(3796,(134698|0))|0);
         $1690 = __THREW__; __THREW__ = 0;
         $1691 = $1690&1;
         if ($1691) {
          label = 51;
          break;
         } else {
          $$in$i$i1528 = $1689;
         }
        } else {
         $$in$i$i1528 = $1685;
        }
        HEAP32[$1684>>2] = $$in$i$i1528;
        $1692 = ((($0)) + 916|0);
        __THREW__ = 0;
        $1693 = (invoke_ii(3796,(134712|0))|0);
        $1694 = __THREW__; __THREW__ = 0;
        $1695 = $1694&1;
        if ($1695) {
         label = 51;
         break;
        }
        $1696 = ($1693|0)==(0|0);
        if ($1696) {
         __THREW__ = 0;
         $1697 = (invoke_ii(3796,(134732|0))|0);
         $1698 = __THREW__; __THREW__ = 0;
         $1699 = $1698&1;
         if ($1699) {
          label = 51;
          break;
         } else {
          $$in$i$i1534 = $1697;
         }
        } else {
         $$in$i$i1534 = $1693;
        }
        HEAP32[$1692>>2] = $$in$i$i1534;
        $1700 = ((($0)) + 920|0);
        __THREW__ = 0;
        $1701 = (invoke_ii(3796,(134755|0))|0);
        $1702 = __THREW__; __THREW__ = 0;
        $1703 = $1702&1;
        if ($1703) {
         label = 51;
         break;
        }
        $1704 = ($1701|0)==(0|0);
        if ($1704) {
         __THREW__ = 0;
         $1705 = (invoke_ii(3796,(134773|0))|0);
         $1706 = __THREW__; __THREW__ = 0;
         $1707 = $1706&1;
         if ($1707) {
          label = 51;
          break;
         } else {
          $$in$i$i1540 = $1705;
         }
        } else {
         $$in$i$i1540 = $1701;
        }
        HEAP32[$1700>>2] = $$in$i$i1540;
        $1708 = ((($0)) + 900|0);
        __THREW__ = 0;
        $1709 = (invoke_ii(3796,(134794|0))|0);
        $1710 = __THREW__; __THREW__ = 0;
        $1711 = $1710&1;
        if ($1711) {
         label = 51;
         break;
        }
        $1712 = ($1709|0)==(0|0);
        if ($1712) {
         __THREW__ = 0;
         $1713 = (invoke_ii(3796,(134807|0))|0);
         $1714 = __THREW__; __THREW__ = 0;
         $1715 = $1714&1;
         if ($1715) {
          label = 51;
          break;
         } else {
          $$in$i$i1546 = $1713;
         }
        } else {
         $$in$i$i1546 = $1709;
        }
        HEAP32[$1708>>2] = $$in$i$i1546;
        $1716 = ((($0)) + 936|0);
        __THREW__ = 0;
        $1717 = (invoke_ii(3796,(134823|0))|0);
        $1718 = __THREW__; __THREW__ = 0;
        $1719 = $1718&1;
        if ($1719) {
         label = 51;
         break;
        }
        $1720 = ($1717|0)==(0|0);
        if ($1720) {
         __THREW__ = 0;
         $1721 = (invoke_ii(3796,(134842|0))|0);
         $1722 = __THREW__; __THREW__ = 0;
         $1723 = $1722&1;
         if ($1723) {
          label = 51;
          break;
         } else {
          $$in$i$i1552 = $1721;
         }
        } else {
         $$in$i$i1552 = $1717;
        }
        HEAP32[$1716>>2] = $$in$i$i1552;
        $1724 = ((($0)) + 940|0);
        __THREW__ = 0;
        $1725 = (invoke_ii(3796,(134864|0))|0);
        $1726 = __THREW__; __THREW__ = 0;
        $1727 = $1726&1;
        if ($1727) {
         label = 51;
         break;
        }
        $1728 = ($1725|0)==(0|0);
        if ($1728) {
         __THREW__ = 0;
         $1729 = (invoke_ii(3796,(134884|0))|0);
         $1730 = __THREW__; __THREW__ = 0;
         $1731 = $1730&1;
         if ($1731) {
          label = 51;
          break;
         } else {
          $$in$i$i1558 = $1729;
         }
        } else {
         $$in$i$i1558 = $1725;
        }
        HEAP32[$1724>>2] = $$in$i$i1558;
        $1732 = ((($0)) + 944|0);
        __THREW__ = 0;
        $1733 = (invoke_ii(3796,(134907|0))|0);
        $1734 = __THREW__; __THREW__ = 0;
        $1735 = $1734&1;
        if ($1735) {
         label = 51;
         break;
        }
        $1736 = ($1733|0)==(0|0);
        if ($1736) {
         __THREW__ = 0;
         $1737 = (invoke_ii(3796,(134929|0))|0);
         $1738 = __THREW__; __THREW__ = 0;
         $1739 = $1738&1;
         if ($1739) {
          label = 51;
          break;
         } else {
          $$in$i$i1564 = $1737;
         }
        } else {
         $$in$i$i1564 = $1733;
        }
        HEAP32[$1732>>2] = $$in$i$i1564;
        __THREW__ = 0;
        $1740 = (invoke_ii(3796,(134954|0))|0);
        $1741 = __THREW__; __THREW__ = 0;
        $1742 = $1741&1;
        if ($1742) {
         label = 51;
         break;
        }
        $1743 = ((($0)) + 924|0);
        HEAP32[$1743>>2] = $1740;
        __THREW__ = 0;
        $1744 = (invoke_ii(3796,(134969|0))|0);
        $1745 = __THREW__; __THREW__ = 0;
        $1746 = $1745&1;
        if ($1746) {
         label = 51;
         break;
        }
        $1748 = ((($0)) + 948|0);
        HEAP32[$1748>>2] = $1744;
        $1749 = HEAP32[$6>>2]|0;
        __THREW__ = 0;
        $1750 = (invoke_iiid(3793,($1749|0),(134985|0),3.4028234663852886E+38)|0);
        $1751 = __THREW__; __THREW__ = 0;
        $1752 = $1751&1;
        if ($1752) {
         label = 51;
         break;
        } else {
         $1755 = $1750;
        }
       } else {
        $1747 = ((($0)) + 808|0);
        ;HEAP32[$1394>>2]=0|0;HEAP32[$1394+4>>2]=0|0;HEAP32[$1394+8>>2]=0|0;HEAP32[$1394+12>>2]=0|0;HEAP16[$1394+16>>1]=0|0;HEAP8[$1394+18>>0]=0|0;
        _memset(($1747|0),0,144)|0;
        $1755 = 0;
       }
       $1753 = ((($0)) + 953|0);
       $1754 = $1755&1;
       HEAP8[$1753>>0] = $1754;
       $1756 = +HEAPF32[$55>>2];
       $1757 = $1756 >= 3.2000000476837158;
       $1758 = ((($0)) + 952|0);
       $1759 = $1757&1;
       HEAP8[$1758>>0] = $1759;
       $1760 = ((($0)) + 956|0);
       if ($10) {
        __THREW__ = 0;
        $1761 = (invoke_ii(3796,(135012|0))|0);
        $1762 = __THREW__; __THREW__ = 0;
        $1763 = $1762&1;
        if ($1763) {
         label = 51;
         break;
        }
        HEAP32[$1760>>2] = $1761;
        $1764 = HEAP8[$1758>>0]|0;
        $1765 = ($1764<<24>>24)==(0);
        if ($1765) {
         $1766 = HEAP32[$6>>2]|0;
         __THREW__ = 0;
         $1767 = (invoke_iiid(3793,($1766|0),(135026|0),3.4028234663852886E+38)|0);
         $1768 = __THREW__; __THREW__ = 0;
         $1769 = $1768&1;
         if ($1769) {
          label = 51;
          break;
         } else {
          $1772 = $1767;
         }
        } else {
         $1772 = 1;
        }
        $1770 = ((($0)) + 954|0);
        $1771 = $1772&1;
        HEAP8[$1770>>0] = $1771;
        $1773 = HEAP32[$6>>2]|0;
        __THREW__ = 0;
        $1774 = (invoke_iiid(3793,($1773|0),(135050|0),3.4028234663852886E+38)|0);
        $1775 = __THREW__; __THREW__ = 0;
        $1776 = $1775&1;
        if ($1776) {
         label = 51;
         break;
        }
        $1777 = ((($0)) + 960|0);
        $1778 = $1774&1;
        HEAP8[$1777>>0] = $1778;
        $1779 = HEAP32[$6>>2]|0;
        __THREW__ = 0;
        $1780 = (invoke_iiid(3793,($1779|0),(135072|0),3.4028234663852886E+38)|0);
        $1781 = __THREW__; __THREW__ = 0;
        $1782 = $1781&1;
        if ($1782) {
         label = 51;
         break;
        }
        $1783 = ((($0)) + 961|0);
        $1784 = $1780&1;
        HEAP8[$1783>>0] = $1784;
        __THREW__ = 0;
        $1785 = (invoke_ii(3796,(135096|0))|0);
        $1786 = __THREW__; __THREW__ = 0;
        $1787 = $1786&1;
        if ($1787) {
         label = 51;
         break;
        }
        $1788 = ((($0)) + 964|0);
        HEAP32[$1788>>2] = $1785;
        __THREW__ = 0;
        $1789 = (invoke_ii(3796,(135113|0))|0);
        $1790 = __THREW__; __THREW__ = 0;
        $1791 = $1790&1;
        if ($1791) {
         label = 51;
         break;
        }
        $1792 = ((($0)) + 968|0);
        HEAP32[$1792>>2] = $1789;
        __THREW__ = 0;
        $1793 = (invoke_ii(3796,(135130|0))|0);
        $1794 = __THREW__; __THREW__ = 0;
        $1795 = $1794&1;
        if ($1795) {
         label = 51;
         break;
        }
        $1796 = ((($0)) + 972|0);
        HEAP32[$1796>>2] = $1793;
        __THREW__ = 0;
        $1797 = (invoke_ii(3796,(135150|0))|0);
        $1798 = __THREW__; __THREW__ = 0;
        $1799 = $1798&1;
        if ($1799) {
         label = 51;
         break;
        }
        $1800 = ((($0)) + 976|0);
        HEAP32[$1800>>2] = $1797;
        __THREW__ = 0;
        $1801 = (invoke_ii(3796,(135169|0))|0);
        $1802 = __THREW__; __THREW__ = 0;
        $1803 = $1802&1;
        if ($1803) {
         label = 51;
         break;
        }
        $1804 = ((($0)) + 980|0);
        HEAP32[$1804>>2] = $1801;
        $1805 = ((($0)) + 984|0);
        __THREW__ = 0;
        $1806 = (invoke_ii(3796,(135199|0))|0);
        $1807 = __THREW__; __THREW__ = 0;
        $1808 = $1807&1;
        if ($1808) {
         label = 51;
         break;
        }
        $1809 = ($1806|0)==(0|0);
        if ($1809) {
         __THREW__ = 0;
         $1810 = (invoke_ii(3796,(135219|0))|0);
         $1811 = __THREW__; __THREW__ = 0;
         $1812 = $1811&1;
         if ($1812) {
          label = 51;
          break;
         } else {
          $$in$i$i1597 = $1810;
         }
        } else {
         $$in$i$i1597 = $1806;
        }
        HEAP32[$1805>>2] = $$in$i$i1597;
        $1813 = ((($0)) + 988|0);
        __THREW__ = 0;
        $1814 = (invoke_ii(3796,(135242|0))|0);
        $1815 = __THREW__; __THREW__ = 0;
        $1816 = $1815&1;
        if ($1816) {
         label = 51;
         break;
        }
        $1817 = ($1814|0)==(0|0);
        if ($1817) {
         __THREW__ = 0;
         $1818 = (invoke_ii(3796,(135262|0))|0);
         $1819 = __THREW__; __THREW__ = 0;
         $1820 = $1819&1;
         if ($1820) {
          label = 51;
          break;
         } else {
          $$in$i$i1603 = $1818;
         }
        } else {
         $$in$i$i1603 = $1814;
        }
        HEAP32[$1813>>2] = $$in$i$i1603;
        $1821 = ((($0)) + 992|0);
        __THREW__ = 0;
        $1822 = (invoke_ii(3796,(135285|0))|0);
        $1823 = __THREW__; __THREW__ = 0;
        $1824 = $1823&1;
        if ($1824) {
         label = 51;
         break;
        }
        $1825 = ($1822|0)==(0|0);
        if ($1825) {
         __THREW__ = 0;
         $1826 = (invoke_ii(3796,(135306|0))|0);
         $1827 = __THREW__; __THREW__ = 0;
         $1828 = $1827&1;
         if ($1828) {
          label = 51;
          break;
         } else {
          $$in$i$i1608 = $1826;
         }
        } else {
         $$in$i$i1608 = $1822;
        }
        HEAP32[$1821>>2] = $$in$i$i1608;
        $1829 = ((($0)) + 996|0);
        __THREW__ = 0;
        $1830 = (invoke_ii(3796,(135330|0))|0);
        $1831 = __THREW__; __THREW__ = 0;
        $1832 = $1831&1;
        if ($1832) {
         label = 51;
         break;
        }
        $1833 = ($1830|0)==(0|0);
        if ($1833) {
         __THREW__ = 0;
         $1834 = (invoke_ii(3796,(135351|0))|0);
         $1835 = __THREW__; __THREW__ = 0;
         $1836 = $1835&1;
         if ($1836) {
          label = 51;
          break;
         } else {
          $$in$i$i1614 = $1834;
         }
        } else {
         $$in$i$i1614 = $1830;
        }
        HEAP32[$1829>>2] = $$in$i$i1614;
        $1837 = ((($0)) + 1000|0);
        __THREW__ = 0;
        $1838 = (invoke_ii(3796,(135375|0))|0);
        $1839 = __THREW__; __THREW__ = 0;
        $1840 = $1839&1;
        if ($1840) {
         label = 51;
         break;
        }
        $1841 = ($1838|0)==(0|0);
        if ($1841) {
         __THREW__ = 0;
         $1842 = (invoke_ii(3796,(135397|0))|0);
         $1843 = __THREW__; __THREW__ = 0;
         $1844 = $1843&1;
         if ($1844) {
          label = 51;
          break;
         } else {
          $$in$i$i1619 = $1842;
         }
        } else {
         $$in$i$i1619 = $1838;
        }
        HEAP32[$1837>>2] = $$in$i$i1619;
        $1845 = ((($0)) + 1004|0);
        __THREW__ = 0;
        $1846 = (invoke_ii(3796,(135422|0))|0);
        $1847 = __THREW__; __THREW__ = 0;
        $1848 = $1847&1;
        if ($1848) {
         label = 51;
         break;
        }
        $1849 = ($1846|0)==(0|0);
        if ($1849) {
         __THREW__ = 0;
         $1850 = (invoke_ii(3796,(135445|0))|0);
         $1851 = __THREW__; __THREW__ = 0;
         $1852 = $1851&1;
         if ($1852) {
          label = 51;
          break;
         } else {
          $$in$i$i1625 = $1850;
         }
        } else {
         $$in$i$i1625 = $1846;
        }
        HEAP32[$1845>>2] = $$in$i$i1625;
        $1853 = ((($0)) + 1008|0);
        __THREW__ = 0;
        $1854 = (invoke_ii(3796,(135471|0))|0);
        $1855 = __THREW__; __THREW__ = 0;
        $1856 = $1855&1;
        if ($1856) {
         label = 51;
         break;
        }
        $1857 = ($1854|0)==(0|0);
        if ($1857) {
         __THREW__ = 0;
         $1858 = (invoke_ii(3796,(135495|0))|0);
         $1859 = __THREW__; __THREW__ = 0;
         $1860 = $1859&1;
         if ($1860) {
          label = 51;
          break;
         } else {
          $$in$i$i1631 = $1858;
         }
        } else {
         $$in$i$i1631 = $1854;
        }
        HEAP32[$1853>>2] = $$in$i$i1631;
        $1861 = ((($0)) + 1012|0);
        __THREW__ = 0;
        $1862 = (invoke_ii(3796,(135522|0))|0);
        $1863 = __THREW__; __THREW__ = 0;
        $1864 = $1863&1;
        if ($1864) {
         label = 51;
         break;
        }
        $1865 = ($1862|0)==(0|0);
        if ($1865) {
         __THREW__ = 0;
         $1866 = (invoke_ii(3796,(135546|0))|0);
         $1867 = __THREW__; __THREW__ = 0;
         $1868 = $1867&1;
         if ($1868) {
          label = 51;
          break;
         } else {
          $$in$i$i1637 = $1866;
         }
        } else {
         $$in$i$i1637 = $1862;
        }
        HEAP32[$1861>>2] = $$in$i$i1637;
        $1869 = ((($0)) + 1016|0);
        __THREW__ = 0;
        $1870 = (invoke_ii(3796,(135573|0))|0);
        $1871 = __THREW__; __THREW__ = 0;
        $1872 = $1871&1;
        if ($1872) {
         label = 51;
         break;
        }
        $1873 = ($1870|0)==(0|0);
        if ($1873) {
         __THREW__ = 0;
         $1874 = (invoke_ii(3796,(135598|0))|0);
         $1875 = __THREW__; __THREW__ = 0;
         $1876 = $1875&1;
         if ($1876) {
          label = 51;
          break;
         } else {
          $$in$i$i1643 = $1874;
         }
        } else {
         $$in$i$i1643 = $1870;
        }
        HEAP32[$1869>>2] = $$in$i$i1643;
        $1877 = ((($0)) + 1020|0);
        __THREW__ = 0;
        $1878 = (invoke_ii(3796,(135626|0))|0);
        $1879 = __THREW__; __THREW__ = 0;
        $1880 = $1879&1;
        if ($1880) {
         label = 51;
         break;
        }
        $1881 = ($1878|0)==(0|0);
        if ($1881) {
         __THREW__ = 0;
         $1882 = (invoke_ii(3796,(135652|0))|0);
         $1883 = __THREW__; __THREW__ = 0;
         $1884 = $1883&1;
         if ($1884) {
          label = 51;
          break;
         } else {
          $$in$i$i1649 = $1882;
         }
        } else {
         $$in$i$i1649 = $1878;
        }
        HEAP32[$1877>>2] = $$in$i$i1649;
        $1885 = ((($0)) + 1024|0);
        __THREW__ = 0;
        $1886 = (invoke_ii(3796,(135681|0))|0);
        $1887 = __THREW__; __THREW__ = 0;
        $1888 = $1887&1;
        if ($1888) {
         label = 51;
         break;
        }
        $1889 = ($1886|0)==(0|0);
        if ($1889) {
         __THREW__ = 0;
         $1890 = (invoke_ii(3796,(135695|0))|0);
         $1891 = __THREW__; __THREW__ = 0;
         $1892 = $1891&1;
         if ($1892) {
          label = 51;
          break;
         } else {
          $$in$i$i1655 = $1890;
         }
        } else {
         $$in$i$i1655 = $1886;
        }
        HEAP32[$1885>>2] = $$in$i$i1655;
        $1893 = ((($0)) + 1028|0);
        __THREW__ = 0;
        $1894 = (invoke_ii(3796,(135712|0))|0);
        $1895 = __THREW__; __THREW__ = 0;
        $1896 = $1895&1;
        if ($1896) {
         label = 51;
         break;
        }
        $1897 = ($1894|0)==(0|0);
        if ($1897) {
         __THREW__ = 0;
         $1898 = (invoke_ii(3796,(135729|0))|0);
         $1899 = __THREW__; __THREW__ = 0;
         $1900 = $1899&1;
         if ($1900) {
          label = 51;
          break;
         } else {
          $$in$i$i1661 = $1898;
         }
        } else {
         $$in$i$i1661 = $1894;
        }
        HEAP32[$1893>>2] = $$in$i$i1661;
        $1901 = ((($0)) + 1032|0);
        __THREW__ = 0;
        $1902 = (invoke_ii(3796,(135749|0))|0);
        $1903 = __THREW__; __THREW__ = 0;
        $1904 = $1903&1;
        if ($1904) {
         label = 51;
         break;
        }
        $1905 = ($1902|0)==(0|0);
        if ($1905) {
         __THREW__ = 0;
         $1906 = (invoke_ii(3796,(135763|0))|0);
         $1907 = __THREW__; __THREW__ = 0;
         $1908 = $1907&1;
         if ($1908) {
          label = 51;
          break;
         } else {
          $$in$i$i1667 = $1906;
         }
        } else {
         $$in$i$i1667 = $1902;
        }
        HEAP32[$1901>>2] = $$in$i$i1667;
        $1909 = ((($0)) + 1036|0);
        __THREW__ = 0;
        $1910 = (invoke_ii(3796,(135780|0))|0);
        $1911 = __THREW__; __THREW__ = 0;
        $1912 = $1911&1;
        if ($1912) {
         label = 51;
         break;
        }
        $1913 = ($1910|0)==(0|0);
        if ($1913) {
         __THREW__ = 0;
         $1914 = (invoke_ii(3796,(135792|0))|0);
         $1915 = __THREW__; __THREW__ = 0;
         $1916 = $1915&1;
         if ($1916) {
          label = 51;
          break;
         } else {
          $$in$i$i1673 = $1914;
         }
        } else {
         $$in$i$i1673 = $1910;
        }
        HEAP32[$1909>>2] = $$in$i$i1673;
        __THREW__ = 0;
        $1921 = (invoke_ii(3791,7937)|0);
        $1922 = __THREW__; __THREW__ = 0;
        $1923 = $1922&1;
        if ($1923) {
         label = 51;
         break;
        } else {
         $1924 = $1921;
        }
       } else {
        HEAP32[$1760>>2] = 0;
        $1917 = ((($0)) + 954|0);
        HEAP8[$1917>>0] = 0;
        $1918 = ((($0)) + 960|0);
        HEAP8[$1918>>0] = 0;
        $1919 = ((($0)) + 961|0);
        HEAP8[$1919>>0] = 0;
        $1920 = ((($0)) + 964|0);
        dest=$1920; stop=dest+76|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
        $1924 = 0;
       }
       $1925 = ($1924|0)!=(0|0);
       $1926 = $1925 ? $1924 : 221531;
       ;HEAP32[$5>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;
       $1927 = (_strlen($1926)|0);
       $1928 = ($1927>>>0)>(4294967279);
       do {
        if ($1928) {
         __THREW__ = 0;
         invoke_vi(3367,($5|0));
         $1929 = __THREW__; __THREW__ = 0;
        } else {
         $1930 = ($1927>>>0)<(11);
         if ($1930) {
          $1939 = $1927&255;
          $1940 = ((($5)) + 11|0);
          HEAP8[$1940>>0] = $1939;
          $1941 = ($1927|0)==(0);
          if ($1941) {
           $$017$i$i = $5;$$pre$phi3226Z2D = $1940;
          } else {
           $$016$i$i = $5;$$pre3225$pre$phiZZ2D = $1940;
           label = 654;
          }
         } else {
          $1931 = (($1927) + 16)|0;
          $1932 = $1931 & -16;
          __THREW__ = 0;
          $1933 = (invoke_ii(3276,($1932|0))|0);
          $1934 = __THREW__; __THREW__ = 0;
          $1935 = $1934&1;
          if ($1935) {
           break;
          }
          HEAP32[$5>>2] = $1933;
          $1936 = $1932 | -2147483648;
          $1937 = ((($5)) + 8|0);
          HEAP32[$1937>>2] = $1936;
          $1938 = ((($5)) + 4|0);
          HEAP32[$1938>>2] = $1927;
          $$pre3228 = ((($5)) + 11|0);
          $$016$i$i = $1933;$$pre3225$pre$phiZZ2D = $$pre3228;
          label = 654;
         }
         if ((label|0) == 654) {
          _memcpy(($$016$i$i|0),($1926|0),($1927|0))|0;
          $$017$i$i = $$016$i$i;$$pre$phi3226Z2D = $$pre3225$pre$phiZZ2D;
         }
         $1942 = (($$017$i$i) + ($1927)|0);
         HEAP8[$1942>>0] = 0;
         $1943 = HEAP8[$$pre$phi3226Z2D>>0]|0;
         $1944 = ($1943<<24>>24)<(0);
         $1945 = HEAP32[$5>>2]|0;
         $1946 = $1944 ? $1945 : $5;
         $1947 = ((($5)) + 4|0);
         $1948 = HEAP32[$1947>>2]|0;
         $1949 = $1943&255;
         $1950 = $1944 ? $1948 : $1949;
         $1951 = (($1946) + ($1950)|0);
         $1952 = $1951;
         $1953 = $1946;
         $1954 = ($1950|0)<(6);
         L829: do {
          if ($1954) {
           $$2$i$i$i1687 = $1951;
           label = 666;
          } else {
           $$02729$i$i$i = $1946;$1956 = $1950;
           while(1) {
            $1955 = (($1956) + -5)|0;
            $1957 = ($1955|0)==(0);
            if ($1957) {
             break;
            }
            $1958 = (_memchr($$02729$i$i$i,82,$1955)|0);
            $1959 = ($1958|0)==(0|0);
            if ($1959) {
             break;
            }
            $1960 = (_memcmp($1958,149696,6)|0);
            $1961 = ($1960|0)==(0);
            if ($1961) {
             label = 660;
             break;
            }
            $1962 = ((($1958)) + 1|0);
            $1963 = $1962;
            $1964 = (($1952) - ($1963))|0;
            $1965 = ($1964|0)<(6);
            if ($1965) {
             break;
            } else {
             $$02729$i$i$i = $1962;$1956 = $1964;
            }
           }
           if ((label|0) == 660) {
            $1966 = ($1958|0)==($1951|0);
            $1967 = $1958;
            $1968 = (($1967) - ($1953))|0;
            $1969 = ($1968|0)==(-1);
            $or$cond3211 = $1966 | $1969;
            if (!($or$cond3211)) {
             $2093 = 1;
             break;
            }
           }
           if ($1954) {
            $$2$i$i$i1687 = $1951;
            label = 666;
           } else {
            $$02729$i$i$i1683 = $1946;$1971 = $1950;
            while(1) {
             $1970 = (($1971) + -5)|0;
             $1972 = ($1970|0)==(0);
             if ($1972) {
              $$2$i$i$i1687 = $1951;
              label = 666;
              break L829;
             }
             $1973 = (_memchr($$02729$i$i$i1683,82,$1970)|0);
             $1974 = ($1973|0)==(0|0);
             if ($1974) {
              $$2$i$i$i1687 = $1951;
              label = 666;
              break L829;
             }
             $1975 = (_memcmp($1973,149703,6)|0);
             $1976 = ($1975|0)==(0);
             if ($1976) {
              $$2$i$i$i1687 = $1973;
              label = 666;
              break L829;
             }
             $1977 = ((($1973)) + 1|0);
             $1978 = $1977;
             $1979 = (($1952) - ($1978))|0;
             $1980 = ($1979|0)<(6);
             if ($1980) {
              $$2$i$i$i1687 = $1951;
              label = 666;
              break;
             } else {
              $$02729$i$i$i1683 = $1977;$1971 = $1979;
             }
            }
           }
          }
         } while(0);
         if ((label|0) == 666) {
          $1981 = $$2$i$i$i1687;
          $1982 = (($1981) - ($1953))|0;
          $1983 = ($1982|0)!=(-1);
          $not$3219 = ($$2$i$i$i1687|0)!=($1951|0);
          $1984 = $1983 & $not$3219;
          $2093 = $1984;
         }
         L846: do {
          if ($1954) {
           $$2$i$i$i1709 = $1951;
           label = 678;
          } else {
           $$02729$i$i$i1694 = $1946;$1986 = $1950;
           while(1) {
            $1985 = (($1986) + -5)|0;
            $1987 = ($1985|0)==(0);
            if ($1987) {
             break;
            }
            $1988 = (_memchr($$02729$i$i$i1694,70,$1985)|0);
            $1989 = ($1988|0)==(0|0);
            if ($1989) {
             break;
            }
            $1990 = (_memcmp($1988,135807,6)|0);
            $1991 = ($1990|0)==(0);
            if ($1991) {
             label = 672;
             break;
            }
            $1992 = ((($1988)) + 1|0);
            $1993 = $1992;
            $1994 = (($1952) - ($1993))|0;
            $1995 = ($1994|0)<(6);
            if ($1995) {
             break;
            } else {
             $$02729$i$i$i1694 = $1992;$1986 = $1994;
            }
           }
           if ((label|0) == 672) {
            $1996 = ($1988|0)==($1951|0);
            $1997 = $1988;
            $1998 = (($1997) - ($1953))|0;
            $1999 = ($1998|0)==(-1);
            $or$cond3212 = $1996 | $1999;
            if (!($or$cond3212)) {
             $2092 = 1;
             break;
            }
           }
           if ($1954) {
            $$2$i$i$i1709 = $1951;
            label = 678;
           } else {
            $$02729$i$i$i1705 = $1946;$2001 = $1950;
            while(1) {
             $2000 = (($2001) + -5)|0;
             $2002 = ($2000|0)==(0);
             if ($2002) {
              $$2$i$i$i1709 = $1951;
              label = 678;
              break L846;
             }
             $2003 = (_memchr($$02729$i$i$i1705,70,$2000)|0);
             $2004 = ($2003|0)==(0|0);
             if ($2004) {
              $$2$i$i$i1709 = $1951;
              label = 678;
              break L846;
             }
             $2005 = (_memcmp($2003,135814,6)|0);
             $2006 = ($2005|0)==(0);
             if ($2006) {
              $$2$i$i$i1709 = $2003;
              label = 678;
              break L846;
             }
             $2007 = ((($2003)) + 1|0);
             $2008 = $2007;
             $2009 = (($1952) - ($2008))|0;
             $2010 = ($2009|0)<(6);
             if ($2010) {
              $$2$i$i$i1709 = $1951;
              label = 678;
              break;
             } else {
              $$02729$i$i$i1705 = $2007;$2001 = $2009;
             }
            }
           }
          }
         } while(0);
         if ((label|0) == 678) {
          $2011 = $$2$i$i$i1709;
          $2012 = (($2011) - ($1953))|0;
          $2013 = ($2012|0)!=(-1);
          $not$3220 = ($$2$i$i$i1709|0)!=($1951|0);
          $2014 = $2013 & $not$3220;
          $2092 = $2014;
         }
         $2015 = ((($0)) + 1040|0);
         HEAP8[$2015>>0] = $$;
         do {
          if ($10) {
           $2016 = HEAP32[$6>>2]|0;
           __THREW__ = 0;
           $2017 = (invoke_iiid(3793,($2016|0),(135821|0),3.4028234663852886E+38)|0);
           $2018 = __THREW__; __THREW__ = 0;
           $2019 = $2018&1;
           if ($2019) {
            label = 721;
           } else {
            $2020 = ((($0)) + 1041|0);
            $2021 = $2017&1;
            HEAP8[$2020>>0] = $2021;
            $2022 = HEAP32[$6>>2]|0;
            __THREW__ = 0;
            $2023 = (invoke_iiid(3793,($2022|0),(135855|0),3.4028234663852886E+38)|0);
            $2024 = __THREW__; __THREW__ = 0;
            $2025 = $2024&1;
            if ($2025) {
             label = 721;
             break;
            }
            $2026 = ((($0)) + 1042|0);
            $2027 = $2023&1;
            HEAP8[$2026>>0] = $2027;
            $2028 = ((($0)) + 1043|0);
            HEAP8[$2028>>0] = $$;
            $2029 = HEAP32[$6>>2]|0;
            __THREW__ = 0;
            $2030 = (invoke_iiid(3793,($2029|0),(135878|0),3.4028234663852886E+38)|0);
            $2031 = __THREW__; __THREW__ = 0;
            $2032 = $2031&1;
            if ($2032) {
             label = 721;
             break;
            }
            if ($2030) {
             $2039 = 1;
            } else {
             $2033 = HEAP32[$6>>2]|0;
             __THREW__ = 0;
             $2034 = (invoke_iiid(3793,($2033|0),(135910|0),3.4028234663852886E+38)|0);
             $2035 = __THREW__; __THREW__ = 0;
             $2036 = $2035&1;
             if ($2036) {
              label = 721;
              break;
             } else {
              $2039 = $2034;
             }
            }
            $2037 = ((($0)) + 1044|0);
            $2038 = $2039&1;
            HEAP8[$2037>>0] = $2038;
            $2040 = HEAP32[$6>>2]|0;
            __THREW__ = 0;
            $2041 = (invoke_iiid(3793,($2040|0),(135921|0),3.4028234663852886E+38)|0);
            $2042 = __THREW__; __THREW__ = 0;
            $2043 = $2042&1;
            if ($2043) {
             label = 721;
             break;
            }
            $2044 = ((($0)) + 1045|0);
            $2045 = $2041&1;
            HEAP8[$2044>>0] = $2045;
            $2046 = ((($0)) + 1046|0);
            HEAP8[$2046>>0] = $2045;
            $2047 = HEAP32[$6>>2]|0;
            __THREW__ = 0;
            $2048 = (invoke_iiid(3793,($2047|0),(135954|0),3.4028234663852886E+38)|0);
            $2049 = __THREW__; __THREW__ = 0;
            $2050 = $2049&1;
            if ($2050) {
             label = 721;
             break;
            }
            $2051 = ((($0)) + 1047|0);
            $2052 = $2048&1;
            HEAP8[$2051>>0] = $2052;
            $2053 = HEAP32[$6>>2]|0;
            __THREW__ = 0;
            $2054 = (invoke_iiid(3793,($2053|0),(135990|0),3.4028234663852886E+38)|0);
            $2055 = __THREW__; __THREW__ = 0;
            $2056 = $2055&1;
            if ($2056) {
             label = 721;
             break;
            }
            $2057 = ((($0)) + 1048|0);
            $2058 = $2054&1;
            HEAP8[$2057>>0] = $2058;
            $2059 = HEAP32[$6>>2]|0;
            __THREW__ = 0;
            $2060 = (invoke_iiid(3793,($2059|0),(136015|0),3.4028234663852886E+38)|0);
            $2061 = __THREW__; __THREW__ = 0;
            $2062 = $2061&1;
            if ($2062) {
             label = 721;
             break;
            }
            $2063 = ((($0)) + 1049|0);
            $2064 = $2060&1;
            HEAP8[$2063>>0] = $2064;
            $2065 = HEAP32[$6>>2]|0;
            __THREW__ = 0;
            $2066 = (invoke_iiid(3793,($2065|0),(135921|0),3.4028234663852886E+38)|0);
            $2067 = __THREW__; __THREW__ = 0;
            $2068 = $2067&1;
            if ($2068) {
             label = 721;
            } else {
             $2080 = $2066;
             label = 691;
            }
           }
          } else {
           $2069 = ((($0)) + 1041|0);
           HEAP8[$2069>>0] = 0;
           $2070 = ((($0)) + 1042|0);
           HEAP8[$2070>>0] = 0;
           $2071 = ((($0)) + 1043|0);
           HEAP8[$2071>>0] = $$;
           $2072 = ((($0)) + 1044|0);
           HEAP8[$2072>>0] = 0;
           $2073 = ((($0)) + 1045|0);
           HEAP8[$2073>>0] = 0;
           $2074 = ((($0)) + 1046|0);
           HEAP8[$2074>>0] = 0;
           $2075 = ((($0)) + 1047|0);
           HEAP8[$2075>>0] = 0;
           $2076 = ((($0)) + 1048|0);
           HEAP8[$2076>>0] = 0;
           $2077 = ((($0)) + 1049|0);
           HEAP8[$2077>>0] = 0;
           $2080 = 0;
           label = 691;
          }
         } while(0);
         L876: do {
          if ((label|0) == 691) {
           $2078 = ((($0)) + 1050|0);
           $2079 = $2080&1;
           HEAP8[$2078>>0] = $2079;
           $2081 = ((($0)) + 1051|0);
           HEAP8[$2081>>0] = $$;
           $2082 = ((($0)) + 1052|0);
           HEAP8[$2082>>0] = $$;
           if ($10) {
            $2083 = HEAP32[$6>>2]|0;
            __THREW__ = 0;
            $2084 = (invoke_iiid(3793,($2083|0),(136047|0),3.4028234663852886E+38)|0);
            $2085 = __THREW__; __THREW__ = 0;
            $2086 = $2085&1;
            if ($2086) {
             label = 721;
             break;
            } else {
             $$pr = 1;$2089 = $2084;
            }
           } else {
            $$pr = 0;$2089 = 0;
           }
           $2087 = ((($0)) + 1053|0);
           $2088 = $2089&1;
           HEAP8[$2087>>0] = $2088;
           $2090 = ((($0)) + 1054|0);
           HEAP8[$2090>>0] = $$;
           $2091 = $2093 | $2092;
           $not$ = $2091 ^ 1;
           $2094 = ((($0)) + 1055|0);
           $2095 = $not$&1;
           HEAP8[$2094>>0] = $2095;
           if ($$pr) {
            $2096 = HEAP32[$6>>2]|0;
            __THREW__ = 0;
            $2097 = (invoke_iiid(3793,($2096|0),(134985|0),3.4028234663852886E+38)|0);
            $2098 = __THREW__; __THREW__ = 0;
            $2099 = $2098&1;
            if ($2099) {
             label = 721;
             break;
            }
            $2100 = ((($0)) + 1056|0);
            $2101 = $2097&1;
            HEAP8[$2100>>0] = $2101;
            $2102 = HEAP32[$6>>2]|0;
            __THREW__ = 0;
            $2103 = (invoke_iiid(3793,($2102|0),(136075|0),3.4028234663852886E+38)|0);
            $2104 = __THREW__; __THREW__ = 0;
            $2105 = $2104&1;
            if ($2105) {
             label = 721;
             break;
            }
            $2106 = ((($0)) + 1057|0);
            $2107 = $2103&1;
            HEAP8[$2106>>0] = $2107;
            $2108 = HEAP32[$6>>2]|0;
            __THREW__ = 0;
            $2109 = (invoke_iiid(3793,($2108|0),(136089|0),3.4028234663852886E+38)|0);
            $2110 = __THREW__; __THREW__ = 0;
            $2111 = $2110&1;
            if ($2111) {
             label = 721;
             break;
            }
            $2112 = ((($0)) + 1058|0);
            $2113 = $2109&1;
            HEAP8[$2112>>0] = $2113;
            $2114 = HEAP32[$6>>2]|0;
            __THREW__ = 0;
            $2115 = (invoke_iiid(3793,($2114|0),(136111|0),3.4028234663852886E+38)|0);
            $2116 = __THREW__; __THREW__ = 0;
            $2117 = $2116&1;
            if ($2117) {
             label = 721;
             break;
            } else {
             $2123 = $2115;
            }
           } else {
            $2118 = ((($0)) + 1056|0);
            HEAP8[$2118>>0] = 0;
            $2119 = ((($0)) + 1057|0);
            HEAP8[$2119>>0] = 0;
            $2120 = ((($0)) + 1058|0);
            HEAP8[$2120>>0] = 0;
            $2123 = 0;
           }
           $2121 = ((($0)) + 1064|0);
           $2122 = $2123&1;
           HEAP8[$2121>>0] = $2122;
           $2124 = ((($0)) + 1067|0);
           HEAP8[$2124>>0] = $$;
           $2125 = ((($0)) + 1068|0);
           HEAP8[$2125>>0] = $$;
           if ($10) {
            $2126 = HEAP32[$6>>2]|0;
            __THREW__ = 0;
            $2127 = (invoke_iiid(3793,($2126|0),(136135|0),3.4028234663852886E+38)|0);
            $2128 = __THREW__; __THREW__ = 0;
            $2129 = $2128&1;
            if ($2129) {
             label = 721;
             break;
            } else {
             $2132 = $2127;
            }
           } else {
            $2132 = 0;
           }
           $2130 = ((($0)) + 1065|0);
           $2131 = $2132&1;
           HEAP8[$2130>>0] = $2131;
           $2133 = HEAP8[$$pre$phi3226Z2D>>0]|0;
           $2134 = ($2133<<24>>24)<(0);
           $2135 = HEAP32[$5>>2]|0;
           $2136 = $2134 ? $2135 : $5;
           $2137 = HEAP32[$1947>>2]|0;
           $2138 = $2133&255;
           $2139 = $2134 ? $2137 : $2138;
           $2140 = (($2136) + ($2139)|0);
           $2141 = $2140;
           $2142 = $2136;
           $2143 = ($2139|0)<(10);
           L891: do {
            if (!($2143)) {
             $$02729$i$i$i1748 = $2136;$2145 = $2139;
             while(1) {
              $2144 = (($2145) + -9)|0;
              $2146 = ($2144|0)==(0);
              if ($2146) {
               break L891;
              }
              $2147 = (_memchr($$02729$i$i$i1748,71,$2144)|0);
              $2148 = ($2147|0)==(0|0);
              if ($2148) {
               break L891;
              }
              $2149 = (_memcmp($2147,136158,10)|0);
              $2150 = ($2149|0)==(0);
              if ($2150) {
               break;
              }
              $2151 = ((($2147)) + 1|0);
              $2152 = $2151;
              $2153 = (($2141) - ($2152))|0;
              $2154 = ($2153|0)<(10);
              if ($2154) {
               break L891;
              } else {
               $$02729$i$i$i1748 = $2151;$2145 = $2153;
              }
             }
             $2155 = ($2147|0)==($2140|0);
             $2156 = $2147;
             $2157 = (($2156) - ($2142))|0;
             $2158 = ($2157|0)==(-1);
             $or$cond3213 = $2155 | $2158;
             if ($or$cond3213) {
              break;
             }
             HEAP8[$2124>>0] = 0;
             __THREW__ = 0;
             $2159 = (invoke_ii(3265,4)|0);
             $2160 = __THREW__; __THREW__ = 0;
             $2161 = $2160&1;
             if ($2161) {
              label = 721;
              break L876;
             }
             if (!($2159)) {
              break;
             }
             __THREW__ = 0;
             $2162 = (invoke_ii(3266,4)|0);
             $2163 = __THREW__; __THREW__ = 0;
             $2164 = $2163&1;
             if ($2164) {
              label = 721;
              break L876;
             }
             __THREW__ = 0;
             $2165 = (invoke_iiii(3267,($2162|0),(136169|0),76)|0);
             $2166 = __THREW__; __THREW__ = 0;
             $2167 = $2166&1;
             if ($2167) {
              label = 721;
              break L876;
             }
             $2168 = HEAP32[$2165>>2]|0;
             $2169 = ((($2168)) + -12|0);
             $2170 = HEAP32[$2169>>2]|0;
             $2171 = (($2165) + ($2170)|0);
             __THREW__ = 0;
             invoke_vii(3257,($2|0),($2171|0));
             $2172 = __THREW__; __THREW__ = 0;
             $2173 = $2172&1;
             if ($2173) {
              label = 721;
              break L876;
             }
             __THREW__ = 0;
             $2174 = (invoke_iii(3255,($2|0),(215188|0))|0);
             $2175 = __THREW__; __THREW__ = 0;
             $2176 = $2175&1;
             do {
              if (!($2176)) {
               $2177 = HEAP32[$2174>>2]|0;
               $2178 = ((($2177)) + 28|0);
               $2179 = HEAP32[$2178>>2]|0;
               __THREW__ = 0;
               $2180 = (invoke_iii($2179|0,($2174|0),10)|0);
               $2181 = __THREW__; __THREW__ = 0;
               $2182 = $2181&1;
               if ($2182) {
                break;
               }
               __THREW__ = 0;
               invoke_vi(3263,($2|0));
               $2189 = __THREW__; __THREW__ = 0;
               $2190 = $2189&1;
               if ($2190) {
                label = 721;
                break L876;
               }
               __THREW__ = 0;
               (invoke_iii(3268,($2165|0),($2180|0))|0);
               $2191 = __THREW__; __THREW__ = 0;
               $2192 = $2191&1;
               if ($2192) {
                label = 721;
                break L876;
               }
               __THREW__ = 0;
               (invoke_ii(3269,($2165|0))|0);
               $2193 = __THREW__; __THREW__ = 0;
               $2194 = $2193&1;
               if ($2194) {
                label = 721;
                break L876;
               } else {
                break L891;
               }
              }
             } while(0);
             $2183 = ___cxa_find_matching_catch_2()|0;
             $2184 = tempRet0;
             __THREW__ = 0;
             invoke_vi(3263,($2|0));
             $2185 = __THREW__; __THREW__ = 0;
             $2186 = $2185&1;
             if ($2186) {
              $2187 = ___cxa_find_matching_catch_3(0|0)|0;
              $2188 = tempRet0;
              ___clang_call_terminate($2187);
              // unreachable;
             } else {
              $$sink549$sink556$index = $2183;$$sink549$sink556$index16 = $2184;
              break L876;
             }
            }
           } while(0);
           $2199 = ((($0)) + 1060|0);
           HEAP32[$2199>>2] = 0;
           if ($10) {
            __THREW__ = 0;
            invoke_vii(3797,3379,($2199|0));
            $2200 = __THREW__; __THREW__ = 0;
            $2201 = $2200&1;
            if ($2201) {
             label = 721;
             break;
            }
           }
           $2202 = (_getenv((154705|0))|0);
           $2203 = ($2202|0)==(0|0);
           do {
            if (!($2203)) {
             $2204 = (_atoi($2202)|0);
             $2205 = HEAP32[$2199>>2]|0;
             $2206 = ($2204|0)<($2205|0);
             if (!($2206)) {
              break;
             }
             HEAP32[$2199>>2] = $2204;
            }
           } while(0);
           $2209 = ((($0)) + 1072|0);
           L921: do {
            if ($10) {
             __THREW__ = 0;
             $2210 = (invoke_ii(3796,(136246|0))|0);
             $2211 = __THREW__; __THREW__ = 0;
             $2212 = $2211&1;
             if ($2212) {
              break;
             }
             $2213 = ($2210|0)==(0|0);
             if ($2213) {
              __THREW__ = 0;
              $2214 = (invoke_ii(3796,(136261|0))|0);
              $2215 = __THREW__; __THREW__ = 0;
              $2216 = $2215&1;
              if ($2216) {
               break;
              } else {
               $$in$i$i1769 = $2214;
              }
             } else {
              $$in$i$i1769 = $2210;
             }
             HEAP32[$2209>>2] = $$in$i$i1769;
             $2217 = ((($0)) + 1076|0);
             __THREW__ = 0;
             $2218 = (invoke_ii(3796,(196362|0))|0);
             $2219 = __THREW__; __THREW__ = 0;
             $2220 = $2219&1;
             if ($2220) {
              break;
             }
             $2221 = ($2218|0)==(0|0);
             if ($2221) {
              __THREW__ = 0;
              $2222 = (invoke_ii(3796,(136279|0))|0);
              $2223 = __THREW__; __THREW__ = 0;
              $2224 = $2223&1;
              if ($2224) {
               break;
              } else {
               $$in$i$i1774 = $2222;
              }
             } else {
              $$in$i$i1774 = $2218;
             }
             HEAP32[$2217>>2] = $$in$i$i1774;
             $2225 = ((($0)) + 1080|0);
             __THREW__ = 0;
             $2226 = (invoke_ii(3796,(196385|0))|0);
             $2227 = __THREW__; __THREW__ = 0;
             $2228 = $2227&1;
             if ($2228) {
              break;
             }
             $2229 = ($2226|0)==(0|0);
             if ($2229) {
              __THREW__ = 0;
              $2230 = (invoke_ii(3796,(136305|0))|0);
              $2231 = __THREW__; __THREW__ = 0;
              $2232 = $2231&1;
              if ($2232) {
               break;
              } else {
               $$in$i$i1779 = $2230;
              }
             } else {
              $$in$i$i1779 = $2226;
             }
             HEAP32[$2225>>2] = $$in$i$i1779;
             $2233 = ((($0)) + 1084|0);
             __THREW__ = 0;
             $2234 = (invoke_ii(3796,(136334|0))|0);
             $2235 = __THREW__; __THREW__ = 0;
             $2236 = $2235&1;
             if ($2236) {
              break;
             }
             $2237 = ($2234|0)==(0|0);
             if ($2237) {
              __THREW__ = 0;
              $2238 = (invoke_ii(3796,(136358|0))|0);
              $2239 = __THREW__; __THREW__ = 0;
              $2240 = $2239&1;
              if ($2240) {
               break;
              } else {
               $$in$i$i1784 = $2238;
              }
             } else {
              $$in$i$i1784 = $2234;
             }
             HEAP32[$2233>>2] = $$in$i$i1784;
             $2241 = ((($0)) + 1088|0);
             __THREW__ = 0;
             $2242 = (invoke_ii(3796,(136385|0))|0);
             $2243 = __THREW__; __THREW__ = 0;
             $2244 = $2243&1;
             if ($2244) {
              break;
             }
             $2245 = ($2242|0)==(0|0);
             if ($2245) {
              __THREW__ = 0;
              $2246 = (invoke_ii(3796,(136409|0))|0);
              $2247 = __THREW__; __THREW__ = 0;
              $2248 = $2247&1;
              if ($2248) {
               break;
              } else {
               $$in$i$i1789 = $2246;
              }
             } else {
              $$in$i$i1789 = $2242;
             }
             HEAP32[$2241>>2] = $$in$i$i1789;
             $2249 = ((($0)) + 1092|0);
             __THREW__ = 0;
             $2250 = (invoke_ii(3796,(136436|0))|0);
             $2251 = __THREW__; __THREW__ = 0;
             $2252 = $2251&1;
             if ($2252) {
              break;
             }
             $2253 = ($2250|0)==(0|0);
             do {
              if ($2253) {
               __THREW__ = 0;
               $2254 = (invoke_ii(3796,(136454|0))|0);
               $2255 = __THREW__; __THREW__ = 0;
               $2256 = $2255&1;
               if ($2256) {
                break L921;
               }
               $2257 = ($2254|0)==(0|0);
               if (!($2257)) {
                $$in$i$i1794 = $2254;
                break;
               }
               __THREW__ = 0;
               $2258 = (invoke_ii(3796,(136475|0))|0);
               $2259 = __THREW__; __THREW__ = 0;
               $2260 = $2259&1;
               if ($2260) {
                break L921;
               } else {
                $$in$i$i1794 = $2258;
               }
              } else {
               $$in$i$i1794 = $2250;
              }
             } while(0);
             HEAP32[$2249>>2] = $$in$i$i1794;
             $2261 = ((($0)) + 1096|0);
             __THREW__ = 0;
             $2262 = (invoke_ii(3796,(136496|0))|0);
             $2263 = __THREW__; __THREW__ = 0;
             $2264 = $2263&1;
             if ($2264) {
              break;
             }
             $2265 = ($2262|0)==(0|0);
             do {
              if ($2265) {
               __THREW__ = 0;
               $2266 = (invoke_ii(3796,(136515|0))|0);
               $2267 = __THREW__; __THREW__ = 0;
               $2268 = $2267&1;
               if ($2268) {
                break L921;
               }
               $2269 = ($2266|0)==(0|0);
               if (!($2269)) {
                $$in$i$i1800 = $2266;
                break;
               }
               __THREW__ = 0;
               $2270 = (invoke_ii(3796,(136537|0))|0);
               $2271 = __THREW__; __THREW__ = 0;
               $2272 = $2271&1;
               if ($2272) {
                break L921;
               } else {
                $$in$i$i1800 = $2270;
               }
              } else {
               $$in$i$i1800 = $2262;
              }
             } while(0);
             HEAP32[$2261>>2] = $$in$i$i1800;
             $2273 = ((($0)) + 1100|0);
             __THREW__ = 0;
             $2274 = (invoke_ii(3796,(136559|0))|0);
             $2275 = __THREW__; __THREW__ = 0;
             $2276 = $2275&1;
             if ($2276) {
              break;
             }
             $2277 = ($2274|0)==(0|0);
             if ($2277) {
              __THREW__ = 0;
              $2278 = (invoke_ii(3796,(136578|0))|0);
              $2279 = __THREW__; __THREW__ = 0;
              $2280 = $2279&1;
              if ($2280) {
               break;
              } else {
               $$in$i$i1806 = $2278;
              }
             } else {
              $$in$i$i1806 = $2274;
             }
             HEAP32[$2273>>2] = $$in$i$i1806;
             $2285 = +HEAPF32[$55>>2];
             $2286 = $2285 >= 1.2000000476837158;
             $2287 = ((($0)) + 1059|0);
             $2288 = $2286&1;
             HEAP8[$2287>>0] = $2288;
             $2289 = !($2285 >= 4.1999998092651367);
             if (!($2289)) {
              $2296 = 1;
              label = 760;
              break;
             }
             $2290 = HEAP32[$6>>2]|0;
             __THREW__ = 0;
             $2291 = (invoke_iiid(3793,($2290|0),(136600|0),3.4028234663852886E+38)|0);
             $2292 = __THREW__; __THREW__ = 0;
             $2293 = $2292&1;
             if (!($2293)) {
              $2296 = $2291;
              label = 760;
             }
            } else {
             ;HEAP32[$2209>>2]=0|0;HEAP32[$2209+4>>2]=0|0;HEAP32[$2209+8>>2]=0|0;HEAP32[$2209+12>>2]=0|0;HEAP32[$2209+16>>2]=0|0;HEAP32[$2209+20>>2]=0|0;HEAP32[$2209+24>>2]=0|0;HEAP32[$2209+28>>2]=0|0;
             $2281 = +HEAPF32[$55>>2];
             $2282 = $2281 >= 1.2000000476837158;
             $2283 = ((($0)) + 1059|0);
             $2284 = $2282&1;
             HEAP8[$2283>>0] = $2284;
             $2296 = 0;
             label = 760;
            }
           } while(0);
           L961: do {
            if ((label|0) == 760) {
             $2294 = ((($0)) + 1066|0);
             $2295 = $2296&1;
             HEAP8[$2294>>0] = $2295;
             $2297 = (_getenv((154760|0))|0);
             $2298 = ($2297|0)==(0|0);
             $2299 = $2296 ^ 1;
             $or$cond3214 = $2298 | $2299;
             if (!($or$cond3214)) {
              $2300 = (_strcmp($2297,167116)|0);
              $2301 = ($2300|0)==(0);
              if ($2301) {
               label = 763;
              } else {
               $2302 = (_strcmp($2297,136623)|0);
               $2303 = ($2302|0)==(0);
               if ($2303) {
                label = 763;
               } else {
                $$sink5 = 1;
               }
              }
              if ((label|0) == 763) {
               $$sink5 = 0;
              }
              HEAP8[$2294>>0] = $$sink5;
             }
             if ($10) {
              $2304 = HEAP32[$6>>2]|0;
              __THREW__ = 0;
              $2305 = (invoke_iiid(3793,($2304|0),(136631|0),3.4028234663852886E+38)|0);
              $2306 = __THREW__; __THREW__ = 0;
              $2307 = $2306&1;
              if ($2307) {
               break;
              }
              $2308 = ((($0)) + 1105|0);
              $2309 = $2305&1;
              HEAP8[$2308>>0] = $2309;
              if ($2305) {
               $$sink3223 = 1;
              } else {
               $2310 = +HEAPF32[$55>>2];
               $2311 = $2310 >= 1.2000000476837158;
               $2312 = $2311&1;
               $$sink3223 = $2312;
              }
              $2313 = ((($0)) + 1104|0);
              HEAP8[$2313>>0] = $$sink3223;
              $2314 = ((($0)) + 1108|0);
              HEAP32[$2314>>2] = 0;
              __THREW__ = 0;
              invoke_vii(3797,32883,($2314|0));
              $2315 = __THREW__; __THREW__ = 0;
              $2316 = $2315&1;
              if ($2316) {
               break;
              }
              $2317 = ((($0)) + 1112|0);
              __THREW__ = 0;
              $2318 = (invoke_ii(3796,(136648|0))|0);
              $2319 = __THREW__; __THREW__ = 0;
              $2320 = $2319&1;
              if ($2320) {
               break;
              }
              $2321 = ($2318|0)==(0|0);
              if ($2321) {
               __THREW__ = 0;
               $2322 = (invoke_ii(3796,(136661|0))|0);
               $2323 = __THREW__; __THREW__ = 0;
               $2324 = $2323&1;
               if ($2324) {
                break;
               } else {
                $$in$i$i1815 = $2322;
               }
              } else {
               $$in$i$i1815 = $2318;
              }
              HEAP32[$2317>>2] = $$in$i$i1815;
              $2325 = ((($0)) + 1116|0);
              __THREW__ = 0;
              $2326 = (invoke_ii(3796,(136677|0))|0);
              $2327 = __THREW__; __THREW__ = 0;
              $2328 = $2327&1;
              if ($2328) {
               break;
              }
              $2329 = ($2326|0)==(0|0);
              if ($2329) {
               __THREW__ = 0;
               $2330 = (invoke_ii(3796,(136693|0))|0);
               $2331 = __THREW__; __THREW__ = 0;
               $2332 = $2331&1;
               if ($2332) {
                break;
               } else {
                $$in$i$i1820 = $2330;
               }
              } else {
               $$in$i$i1820 = $2326;
              }
              HEAP32[$2325>>2] = $$in$i$i1820;
              $2333 = ((($0)) + 1124|0);
              __THREW__ = 0;
              $2334 = (invoke_ii(3796,(136712|0))|0);
              $2335 = __THREW__; __THREW__ = 0;
              $2336 = $2335&1;
              if ($2336) {
               break;
              }
              $2337 = ($2334|0)==(0|0);
              if ($2337) {
               __THREW__ = 0;
               $2338 = (invoke_ii(3796,(136735|0))|0);
               $2339 = __THREW__; __THREW__ = 0;
               $2340 = $2339&1;
               if ($2340) {
                break;
               } else {
                $$in$i$i1825 = $2338;
               }
              } else {
               $$in$i$i1825 = $2334;
              }
              HEAP32[$2333>>2] = $$in$i$i1825;
              $2341 = ((($0)) + 1128|0);
              __THREW__ = 0;
              $2342 = (invoke_ii(3796,(136761|0))|0);
              $2343 = __THREW__; __THREW__ = 0;
              $2344 = $2343&1;
              if ($2344) {
               break;
              }
              $2345 = ($2342|0)==(0|0);
              if ($2345) {
               __THREW__ = 0;
               $2346 = (invoke_ii(3796,(136787|0))|0);
               $2347 = __THREW__; __THREW__ = 0;
               $2348 = $2347&1;
               if ($2348) {
                break;
               } else {
                $$in$i$i1830 = $2346;
               }
              } else {
               $$in$i$i1830 = $2342;
              }
              HEAP32[$2341>>2] = $$in$i$i1830;
              __THREW__ = 0;
              $2356 = (invoke_ii(3796,(136816|0))|0);
              $2357 = __THREW__; __THREW__ = 0;
              $2358 = $2357&1;
              if ($2358) {
               break;
              }
              $2359 = ($2356|0)==(0|0);
              if ($2359) {
               __THREW__ = 0;
               $2360 = (invoke_ii(3796,(136836|0))|0);
               $2361 = __THREW__; __THREW__ = 0;
               $2362 = $2361&1;
               if ($2362) {
                break;
               } else {
                $$in$i$i1835 = $2360;
               }
              } else {
               $$in$i$i1835 = $2356;
              }
              $2364 = $$in$i$i1835;
             } else {
              $2349 = ((($0)) + 1105|0);
              HEAP8[$2349>>0] = 0;
              $2350 = ((($0)) + 1104|0);
              HEAP8[$2350>>0] = 0;
              $2351 = ((($0)) + 1108|0);
              HEAP32[$2351>>2] = 0;
              $2352 = ((($0)) + 1112|0);
              HEAP32[$2352>>2] = 0;
              $2353 = ((($0)) + 1116|0);
              HEAP32[$2353>>2] = 0;
              $2354 = ((($0)) + 1124|0);
              HEAP32[$2354>>2] = 0;
              $2355 = ((($0)) + 1128|0);
              HEAP32[$2355>>2] = 0;
              $2364 = 0;
             }
             $2363 = ((($0)) + 1120|0);
             HEAP32[$2363>>2] = $2364;
             $2365 = ((($0)) + 1580|0);
             __THREW__ = 0;
             $2366 = (invoke_ii(3796,(136859|0))|0);
             $2367 = __THREW__; __THREW__ = 0;
             $2368 = $2367&1;
             if ($2368) {
              break;
             }
             $2369 = ($2366|0)==(0|0);
             if ($2369) {
              __THREW__ = 0;
              $2370 = (invoke_ii(3796,(136884|0))|0);
              $2371 = __THREW__; __THREW__ = 0;
              $2372 = $2371&1;
              if ($2372) {
               break;
              } else {
               $$in$i$i1840 = $2370;
              }
             } else {
              $$in$i$i1840 = $2366;
             }
             HEAP32[$2365>>2] = $$in$i$i1840;
             $2373 = ((($0)) + 1584|0);
             __THREW__ = 0;
             $2374 = (invoke_ii(3796,(136912|0))|0);
             $2375 = __THREW__; __THREW__ = 0;
             $2376 = $2375&1;
             if ($2376) {
              break;
             }
             $2377 = ($2374|0)==(0|0);
             if ($2377) {
              __THREW__ = 0;
              $2378 = (invoke_ii(3796,(136935|0))|0);
              $2379 = __THREW__; __THREW__ = 0;
              $2380 = $2379&1;
              if ($2380) {
               break;
              } else {
               $$in$i$i1846 = $2378;
              }
             } else {
              $$in$i$i1846 = $2374;
             }
             HEAP32[$2373>>2] = $$in$i$i1846;
             L1008: do {
              if ($10) {
               $2381 = HEAP32[$6>>2]|0;
               __THREW__ = 0;
               $2382 = (invoke_iiid(3793,($2381|0),(136961|0),3.4028234663852886E+38)|0);
               $2383 = __THREW__; __THREW__ = 0;
               $2384 = $2383&1;
               if ($2384) {
                break L961;
               }
               $2385 = ((($0)) + 1140|0);
               $2386 = $2382&1;
               HEAP8[$2385>>0] = $2386;
               $2387 = ((($0)) + 1148|0);
               HEAP32[$2387>>2] = 0;
               __THREW__ = 0;
               invoke_vii(3797,3379,($2387|0));
               $2388 = __THREW__; __THREW__ = 0;
               $2389 = $2388&1;
               if ($2389) {
                break L961;
               }
               $2390 = ((($0)) + 1144|0);
               HEAP32[$2390>>2] = 0;
               __THREW__ = 0;
               invoke_vii(3797,35071,($2390|0));
               $2391 = __THREW__; __THREW__ = 0;
               $2392 = $2391&1;
               if ($2392) {
                break L961;
               }
               $2393 = ((($0)) + 692|0);
               __THREW__ = 0;
               $2394 = (invoke_ii(3796,(136982|0))|0);
               $2395 = __THREW__; __THREW__ = 0;
               $2396 = $2395&1;
               if ($2396) {
                break L961;
               }
               $2397 = ($2394|0)==(0|0);
               do {
                if ($2397) {
                 __THREW__ = 0;
                 $2398 = (invoke_ii(3796,(137001|0))|0);
                 $2399 = __THREW__; __THREW__ = 0;
                 $2400 = $2399&1;
                 if ($2400) {
                  break L961;
                 }
                 $2401 = ($2398|0)==(0|0);
                 if (!($2401)) {
                  $$in$i$i1854 = $2398;
                  break;
                 }
                 __THREW__ = 0;
                 $2402 = (invoke_ii(3796,(137023|0))|0);
                 $2403 = __THREW__; __THREW__ = 0;
                 $2404 = $2403&1;
                 if ($2404) {
                  break L961;
                 } else {
                  $$in$i$i1854 = $2402;
                 }
                } else {
                 $$in$i$i1854 = $2394;
                }
               } while(0);
               HEAP32[$2393>>2] = $$in$i$i1854;
               $2405 = ((($0)) + 696|0);
               __THREW__ = 0;
               $2406 = (invoke_ii(3796,(137044|0))|0);
               $2407 = __THREW__; __THREW__ = 0;
               $2408 = $2407&1;
               if ($2408) {
                break L961;
               }
               $2409 = ($2406|0)==(0|0);
               do {
                if ($2409) {
                 __THREW__ = 0;
                 $2410 = (invoke_ii(3796,(137072|0))|0);
                 $2411 = __THREW__; __THREW__ = 0;
                 $2412 = $2411&1;
                 if ($2412) {
                  break L961;
                 }
                 $2413 = ($2410|0)==(0|0);
                 if (!($2413)) {
                  $$in$i$i1860 = $2410;
                  break;
                 }
                 __THREW__ = 0;
                 $2414 = (invoke_ii(3796,(137103|0))|0);
                 $2415 = __THREW__; __THREW__ = 0;
                 $2416 = $2415&1;
                 if ($2416) {
                  break L961;
                 } else {
                  $$in$i$i1860 = $2414;
                 }
                } else {
                 $$in$i$i1860 = $2406;
                }
               } while(0);
               HEAP32[$2405>>2] = $$in$i$i1860;
               $2417 = ((($0)) + 700|0);
               __THREW__ = 0;
               $2418 = (invoke_ii(3796,(137133|0))|0);
               $2419 = __THREW__; __THREW__ = 0;
               $2420 = $2419&1;
               if ($2420) {
                break L961;
               }
               $2421 = ($2418|0)==(0|0);
               do {
                if ($2421) {
                 __THREW__ = 0;
                 $2422 = (invoke_ii(3796,(137164|0))|0);
                 $2423 = __THREW__; __THREW__ = 0;
                 $2424 = $2423&1;
                 if ($2424) {
                  break L961;
                 }
                 $2425 = ($2422|0)==(0|0);
                 if (!($2425)) {
                  $$in$i$i1866 = $2422;
                  break;
                 }
                 __THREW__ = 0;
                 $2426 = (invoke_ii(3796,(137198|0))|0);
                 $2427 = __THREW__; __THREW__ = 0;
                 $2428 = $2427&1;
                 if ($2428) {
                  break L961;
                 } else {
                  $$in$i$i1866 = $2426;
                 }
                } else {
                 $$in$i$i1866 = $2418;
                }
               } while(0);
               HEAP32[$2417>>2] = $$in$i$i1866;
               $2429 = ((($0)) + 704|0);
               __THREW__ = 0;
               $2430 = (invoke_ii(3796,(137231|0))|0);
               $2431 = __THREW__; __THREW__ = 0;
               $2432 = $2431&1;
               if ($2432) {
                break L961;
               }
               $2433 = ($2430|0)==(0|0);
               do {
                if ($2433) {
                 __THREW__ = 0;
                 $2434 = (invoke_ii(3796,(137251|0))|0);
                 $2435 = __THREW__; __THREW__ = 0;
                 $2436 = $2435&1;
                 if ($2436) {
                  break L961;
                 }
                 $2437 = ($2434|0)==(0|0);
                 if (!($2437)) {
                  $$in$i$i1873 = $2434;
                  break;
                 }
                 __THREW__ = 0;
                 $2438 = (invoke_ii(3796,(137274|0))|0);
                 $2439 = __THREW__; __THREW__ = 0;
                 $2440 = $2439&1;
                 if ($2440) {
                  break L961;
                 } else {
                  $$in$i$i1873 = $2438;
                 }
                } else {
                 $$in$i$i1873 = $2430;
                }
               } while(0);
               HEAP32[$2429>>2] = $$in$i$i1873;
               $2441 = ((($0)) + 708|0);
               __THREW__ = 0;
               $2442 = (invoke_ii(3796,(137296|0))|0);
               $2443 = __THREW__; __THREW__ = 0;
               $2444 = $2443&1;
               if ($2444) {
                break L961;
               }
               $2445 = ($2442|0)==(0|0);
               do {
                if ($2445) {
                 __THREW__ = 0;
                 $2446 = (invoke_ii(3796,(137322|0))|0);
                 $2447 = __THREW__; __THREW__ = 0;
                 $2448 = $2447&1;
                 if ($2448) {
                  break L961;
                 }
                 $2449 = ($2446|0)==(0|0);
                 if (!($2449)) {
                  $$in$i$i1879 = $2446;
                  break;
                 }
                 __THREW__ = 0;
                 $2450 = (invoke_ii(3796,(137351|0))|0);
                 $2451 = __THREW__; __THREW__ = 0;
                 $2452 = $2451&1;
                 if ($2452) {
                  break L961;
                 } else {
                  $$in$i$i1879 = $2450;
                 }
                } else {
                 $$in$i$i1879 = $2442;
                }
               } while(0);
               HEAP32[$2441>>2] = $$in$i$i1879;
               $2453 = ((($0)) + 1152|0);
               HEAP8[$2453>>0] = $1355;
               $2454 = ((($0)) + 1160|0);
               __THREW__ = 0;
               $2455 = (invoke_ii(3796,(198812|0))|0);
               $2456 = __THREW__; __THREW__ = 0;
               $2457 = $2456&1;
               if ($2457) {
                break L961;
               }
               $2458 = ($2455|0)==(0|0);
               if ($2458) {
                __THREW__ = 0;
                $2459 = (invoke_ii(3796,(137379|0))|0);
                $2460 = __THREW__; __THREW__ = 0;
                $2461 = $2460&1;
                if ($2461) {
                 break L961;
                } else {
                 $$in$i$i1885 = $2459;
                }
               } else {
                $$in$i$i1885 = $2455;
               }
               HEAP32[$2454>>2] = $$in$i$i1885;
               $2462 = ((($0)) + 1153|0);
               HEAP8[$2462>>0] = $$;
               $2463 = ((($0)) + 1154|0);
               HEAP8[$2463>>0] = $$;
               $2464 = HEAP32[$6>>2]|0;
               __THREW__ = 0;
               $2465 = (invoke_iiid(3793,($2464|0),(137395|0),3.4028234663852886E+38)|0);
               $2466 = __THREW__; __THREW__ = 0;
               $2467 = $2466&1;
               if ($2467) {
                break;
               }
               $2468 = ((($0)) + 1155|0);
               $2469 = $2465&1;
               HEAP8[$2468>>0] = $2469;
               $2470 = HEAP32[$6>>2]|0;
               __THREW__ = 0;
               $2471 = (invoke_iiid(3793,($2470|0),(137422|0),3.4028234663852886E+38)|0);
               $2472 = __THREW__; __THREW__ = 0;
               $2473 = $2472&1;
               if ($2473) {
                break;
               }
               $2474 = ((($0)) + 1156|0);
               $2475 = $2471&1;
               HEAP8[$2474>>0] = $2475;
               $2476 = ((($0)) + 1164|0);
               __THREW__ = 0;
               $2477 = (invoke_ii(3796,(198462|0))|0);
               $2478 = __THREW__; __THREW__ = 0;
               $2479 = $2478&1;
               if ($2479) {
                break;
               }
               $2480 = ($2477|0)==(0|0);
               if ($2480) {
                __THREW__ = 0;
                $2481 = (invoke_ii(3796,(137444|0))|0);
                $2482 = __THREW__; __THREW__ = 0;
                $2483 = $2482&1;
                if ($2483) {
                 break;
                } else {
                 $$in$i$i1894 = $2481;
                }
               } else {
                $$in$i$i1894 = $2477;
               }
               HEAP32[$2476>>2] = $$in$i$i1894;
               $2484 = ((($0)) + 1168|0);
               __THREW__ = 0;
               $2485 = (invoke_ii(3796,(198502|0))|0);
               $2486 = __THREW__; __THREW__ = 0;
               $2487 = $2486&1;
               if ($2487) {
                break;
               }
               $2488 = ($2485|0)==(0|0);
               if ($2488) {
                __THREW__ = 0;
                $2489 = (invoke_ii(3796,(137463|0))|0);
                $2490 = __THREW__; __THREW__ = 0;
                $2491 = $2490&1;
                if ($2491) {
                 break;
                } else {
                 $$in$i$i1900 = $2489;
                }
               } else {
                $$in$i$i1900 = $2485;
               }
               HEAP32[$2484>>2] = $$in$i$i1900;
               $2492 = ((($0)) + 1172|0);
               __THREW__ = 0;
               $2493 = (invoke_ii(3796,(137490|0))|0);
               $2494 = __THREW__; __THREW__ = 0;
               $2495 = $2494&1;
               if ($2495) {
                break;
               }
               $2496 = ($2493|0)==(0|0);
               if ($2496) {
                __THREW__ = 0;
                $2497 = (invoke_ii(3796,(137507|0))|0);
                $2498 = __THREW__; __THREW__ = 0;
                $2499 = $2498&1;
                if ($2499) {
                 break;
                } else {
                 $$in$i$i1906 = $2497;
                }
               } else {
                $$in$i$i1906 = $2493;
               }
               HEAP32[$2492>>2] = $$in$i$i1906;
               $2500 = ((($0)) + 1176|0);
               __THREW__ = 0;
               $2501 = (invoke_ii(3796,(137527|0))|0);
               $2502 = __THREW__; __THREW__ = 0;
               $2503 = $2502&1;
               if ($2503) {
                break;
               }
               $2504 = ($2501|0)==(0|0);
               if ($2504) {
                __THREW__ = 0;
                $2505 = (invoke_ii(3796,(137552|0))|0);
                $2506 = __THREW__; __THREW__ = 0;
                $2507 = $2506&1;
                if ($2507) {
                 break;
                } else {
                 $$in$i$i1912 = $2505;
                }
               } else {
                $$in$i$i1912 = $2501;
               }
               HEAP32[$2500>>2] = $$in$i$i1912;
               __THREW__ = 0;
               $2508 = (invoke_ii(3796,(137580|0))|0);
               $2509 = __THREW__; __THREW__ = 0;
               $2510 = $2509&1;
               if ($2510) {
                break;
               }
               $2511 = ((($0)) + 1180|0);
               HEAP32[$2511>>2] = $2508;
               __THREW__ = 0;
               $2512 = (invoke_ii(3796,(137590|0))|0);
               $2513 = __THREW__; __THREW__ = 0;
               $2514 = $2513&1;
               if ($2514) {
                break;
               }
               $2515 = ((($0)) + 1184|0);
               HEAP32[$2515>>2] = $2512;
               $2516 = HEAP32[$6>>2]|0;
               __THREW__ = 0;
               $2517 = (invoke_iiid(3793,($2516|0),(137601|0),1.3999999761581421)|0);
               $2518 = __THREW__; __THREW__ = 0;
               $2519 = $2518&1;
               if ($2519) {
                break;
               }
               $2520 = ((($0)) + 1188|0);
               $2521 = $2517&1;
               HEAP8[$2520>>0] = $2521;
               $2522 = HEAP32[$6>>2]|0;
               __THREW__ = 0;
               $2523 = (invoke_iiid(3793,($2522|0),(137621|0),3.4028234663852886E+38)|0);
               $2524 = __THREW__; __THREW__ = 0;
               $2525 = $2524&1;
               if ($2525) {
                break;
               }
               $2526 = ((($0)) + 1189|0);
               $2527 = $2523&1;
               HEAP8[$2526>>0] = $2527;
               $2528 = +HEAPF32[$55>>2];
               $2529 = $2528 >= 2.0;
               $2530 = ((($0)) + 1190|0);
               $2531 = $2529&1;
               HEAP8[$2530>>0] = $2531;
               $2532 = HEAP32[$6>>2]|0;
               __THREW__ = 0;
               $2533 = (invoke_iiid(3793,($2532|0),(137645|0),3.4028234663852886E+38)|0);
               $2534 = __THREW__; __THREW__ = 0;
               $2535 = $2534&1;
               if ($2535) {
                break;
               }
               $2536 = ((($0)) + 1191|0);
               $2537 = $2533&1;
               HEAP8[$2536>>0] = $2537;
               __THREW__ = 0;
               $2538 = (invoke_ii(3796,(137669|0))|0);
               $2539 = __THREW__; __THREW__ = 0;
               $2540 = $2539&1;
               if ($2540) {
                break;
               }
               $2541 = ((($0)) + 1192|0);
               HEAP32[$2541>>2] = $2538;
               $2542 = ((($0)) + 1196|0);
               __THREW__ = 0;
               $2543 = (invoke_ii(3796,(198847|0))|0);
               $2544 = __THREW__; __THREW__ = 0;
               $2545 = $2544&1;
               if ($2545) {
                break;
               }
               $2546 = ($2543|0)==(0|0);
               if ($2546) {
                __THREW__ = 0;
                $2547 = (invoke_ii(3796,(137692|0))|0);
                $2548 = __THREW__; __THREW__ = 0;
                $2549 = $2548&1;
                if ($2549) {
                 break;
                } else {
                 $$in$i$i1931 = $2547;
                }
               } else {
                $$in$i$i1931 = $2543;
               }
               HEAP32[$2542>>2] = $$in$i$i1931;
               __THREW__ = 0;
               $2550 = (invoke_ii(3796,(198553|0))|0);
               $2551 = __THREW__; __THREW__ = 0;
               $2552 = $2551&1;
               if ($2552) {
                break;
               }
               $2553 = ((($0)) + 1200|0);
               HEAP32[$2553>>2] = $2550;
               $2554 = ((($0)) + 1204|0);
               __THREW__ = 0;
               $2555 = (invoke_ii(3796,(198825|0))|0);
               $2556 = __THREW__; __THREW__ = 0;
               $2557 = $2556&1;
               if ($2557) {
                break;
               }
               $2558 = ($2555|0)==(0|0);
               if ($2558) {
                __THREW__ = 0;
                $2559 = (invoke_ii(3796,(137715|0))|0);
                $2560 = __THREW__; __THREW__ = 0;
                $2561 = $2560&1;
                if ($2561) {
                 break;
                } else {
                 $$in$i$i1940 = $2559;
                }
               } else {
                $$in$i$i1940 = $2555;
               }
               HEAP32[$2554>>2] = $$in$i$i1940;
               __THREW__ = 0;
               $2562 = (invoke_ii(3796,(137715|0))|0);
               $2563 = __THREW__; __THREW__ = 0;
               $2564 = $2563&1;
               if ($2564) {
                break;
               }
               $2565 = ((($0)) + 1208|0);
               HEAP32[$2565>>2] = $2562;
               $2566 = ((($0)) + 1212|0);
               __THREW__ = 0;
               $2567 = (invoke_ii(3796,(137740|0))|0);
               $2568 = __THREW__; __THREW__ = 0;
               $2569 = $2568&1;
               if ($2569) {
                break;
               }
               $2570 = ($2567|0)==(0|0);
               if ($2570) {
                __THREW__ = 0;
                $2571 = (invoke_ii(3796,(137753|0))|0);
                $2572 = __THREW__; __THREW__ = 0;
                $2573 = $2572&1;
                if ($2573) {
                 break;
                } else {
                 $$in$i$i1947 = $2571;
                }
               } else {
                $$in$i$i1947 = $2567;
               }
               HEAP32[$2566>>2] = $$in$i$i1947;
               $2574 = HEAP32[$6>>2]|0;
               __THREW__ = 0;
               $2575 = (invoke_iiid(3793,($2574|0),(137769|0),3.4028234663852886E+38)|0);
               $2576 = __THREW__; __THREW__ = 0;
               $2577 = $2576&1;
               if ($2577) {
                break;
               }
               if ($2575) {
                $$ph3018 = 1;
               } else {
                $2578 = +HEAPF32[$55>>2];
                $2579 = $2578 >= 2.0;
                $$ph3018 = $2579;
               }
               $2580 = ((($0)) + 1216|0);
               $2581 = $$ph3018&1;
               HEAP8[$2580>>0] = $2581;
               $2582 = ((($0)) + 1220|0);
               __THREW__ = 0;
               $2583 = (invoke_ii(3796,(137795|0))|0);
               $2584 = __THREW__; __THREW__ = 0;
               $2585 = $2584&1;
               if ($2585) {
                break;
               }
               $2586 = ($2583|0)==(0|0);
               if ($2586) {
                __THREW__ = 0;
                $2587 = (invoke_ii(3796,(137808|0))|0);
                $2588 = __THREW__; __THREW__ = 0;
                $2589 = $2588&1;
                if ($2589) {
                 break;
                } else {
                 $$in$i$i1954 = $2587;
                }
               } else {
                $$in$i$i1954 = $2583;
               }
               HEAP32[$2582>>2] = $$in$i$i1954;
               $2590 = ((($0)) + 1224|0);
               __THREW__ = 0;
               $2591 = (invoke_ii(3796,(137824|0))|0);
               $2592 = __THREW__; __THREW__ = 0;
               $2593 = $2592&1;
               if ($2593) {
                break;
               }
               $2594 = ($2591|0)==(0|0);
               if ($2594) {
                __THREW__ = 0;
                $2595 = (invoke_ii(3796,(137848|0))|0);
                $2596 = __THREW__; __THREW__ = 0;
                $2597 = $2596&1;
                if ($2597) {
                 break;
                } else {
                 $$in$i$i1960 = $2595;
                }
               } else {
                $$in$i$i1960 = $2591;
               }
               HEAP32[$2590>>2] = $$in$i$i1960;
               $2598 = +HEAPF32[$55>>2];
               $2599 = !($2598 >= 1.3999999761581421);
               do {
                if ($2599) {
                 $2600 = HEAP32[$6>>2]|0;
                 __THREW__ = 0;
                 $2601 = (invoke_iiid(3793,($2600|0),(137874|0),3.4028234663852886E+38)|0);
                 $2602 = __THREW__; __THREW__ = 0;
                 $2603 = $2602&1;
                 if ($2603) {
                  break L1008;
                 }
                 if ($2601) {
                  $2631 = 1;
                  break;
                 }
                 $2604 = HEAP32[$6>>2]|0;
                 __THREW__ = 0;
                 $2605 = (invoke_iiid(3793,($2604|0),(137898|0),3.4028234663852886E+38)|0);
                 $2606 = __THREW__; __THREW__ = 0;
                 $2607 = $2606&1;
                 if ($2607) {
                  break L1008;
                 }
                 if ($2605) {
                  $2631 = 1;
                  break;
                 }
                 $2608 = HEAP32[$6>>2]|0;
                 __THREW__ = 0;
                 $2609 = (invoke_iiid(3793,($2608|0),(137922|0),3.4028234663852886E+38)|0);
                 $2610 = __THREW__; __THREW__ = 0;
                 $2611 = $2610&1;
                 if ($2611) {
                  break L1008;
                 } else {
                  $2631 = $2609;
                 }
                } else {
                 $2631 = 1;
                }
               } while(0);
               $2629 = ((($0)) + 1236|0);
               $2630 = $2631&1;
               HEAP8[$2629>>0] = $2630;
               $2632 = ((($0)) + 1237|0);
               HEAP8[$2632>>0] = $1355;
               $2633 = +HEAPF32[$55>>2];
               $2634 = $2633 >= 2.0;
               $2635 = ((($0)) + 1238|0);
               $2636 = $2634&1;
               HEAP8[$2635>>0] = $2636;
               $2637 = ((($0)) + 1240|0);
               __THREW__ = 0;
               $2638 = (invoke_ii(3796,(137947|0))|0);
               $2639 = __THREW__; __THREW__ = 0;
               $2640 = $2639&1;
               if ($2640) {
                break;
               }
               $2641 = ($2638|0)==(0|0);
               if ($2641) {
                __THREW__ = 0;
                $2642 = (invoke_ii(3796,(137965|0))|0);
                $2643 = __THREW__; __THREW__ = 0;
                $2644 = $2643&1;
                if ($2644) {
                 break;
                } else {
                 $$in$i$i1972 = $2642;
                }
               } else {
                $$in$i$i1972 = $2638;
               }
               HEAP32[$2637>>2] = $$in$i$i1972;
               $2645 = ($$in$i$i1972|0)==(0|0);
               if (!($2645)) {
                label = 883;
                break;
               }
               if (!($10)) {
                $$0$$sroa_cast$i$i197432313233 = $2637;$2653 = 0;
                label = 881;
                break;
               }
               __THREW__ = 0;
               $2646 = (invoke_ii(3796,(137986|0))|0);
               $2647 = __THREW__; __THREW__ = 0;
               $2648 = $2647&1;
               if ($2648) {
                break;
               }
               $2649 = ($2646|0)==(0|0);
               if ($2649) {
                __THREW__ = 0;
                $2650 = (invoke_ii(3796,(138007|0))|0);
                $2651 = __THREW__; __THREW__ = 0;
                $2652 = $2651&1;
                if ($2652) {
                 break;
                } else {
                 $$in$i$i1977 = $2650;
                }
               } else {
                $$in$i$i1977 = $2646;
               }
               $$0$$sroa_cast$i$i197432313233 = $2637;$2653 = $$in$i$i1977;
               label = 881;
              } else {
               $2612 = ((($0)) + 1140|0);
               HEAP8[$2612>>0] = 0;
               $2613 = ((($0)) + 1148|0);
               HEAP32[$2613>>2] = 0;
               $2614 = ((($0)) + 1144|0);
               HEAP32[$2614>>2] = 0;
               $2615 = ((($0)) + 692|0);
               $2616 = ((($0)) + 1152|0);
               ;HEAP32[$2615>>2]=0|0;HEAP32[$2615+4>>2]=0|0;HEAP32[$2615+8>>2]=0|0;HEAP32[$2615+12>>2]=0|0;HEAP32[$2615+16>>2]=0|0;
               HEAP8[$2616>>0] = $1355;
               $2617 = ((($0)) + 1160|0);
               HEAP32[$2617>>2] = 0;
               $2618 = ((($0)) + 1153|0);
               HEAP8[$2618>>0] = $$;
               $2619 = ((($0)) + 1154|0);
               HEAP8[$2619>>0] = $$;
               $2620 = ((($0)) + 1155|0);
               HEAP8[$2620>>0] = 0;
               $2621 = ((($0)) + 1156|0);
               HEAP8[$2621>>0] = 0;
               $2622 = ((($0)) + 1164|0);
               $2623 = ((($0)) + 1220|0);
               HEAP32[$2623>>2] = 0;
               $2624 = ((($0)) + 1224|0);
               HEAP32[$2624>>2] = 0;
               $2625 = ((($0)) + 1236|0);
               HEAP8[$2625>>0] = 0;
               $2626 = ((($0)) + 1237|0);
               dest=$2622; stop=dest+52|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));HEAP8[$2622+52>>0]=0|0;
               HEAP8[$2626>>0] = $1355;
               $2627 = ((($0)) + 1238|0);
               HEAP8[$2627>>0] = 0;
               $2628 = ((($0)) + 1240|0);
               HEAP32[$2628>>2] = 0;
               $$0$$sroa_cast$i$i197432313233 = $2628;$2653 = 0;
               label = 881;
              }
             } while(0);
             if ((label|0) == 881) {
              HEAP32[$$0$$sroa_cast$i$i197432313233>>2] = $2653;
              label = 883;
             }
             L1117: do {
              if ((label|0) == 883) {
               $2656 = ((($0)) + 1244|0);
               do {
                if ($10) {
                 __THREW__ = 0;
                 $2657 = (invoke_ii(3796,(138029|0))|0);
                 $2658 = __THREW__; __THREW__ = 0;
                 $2659 = $2658&1;
                 if ($2659) {
                  break L1117;
                 }
                 $2660 = ($2657|0)==(0|0);
                 if ($2660) {
                  __THREW__ = 0;
                  $2661 = (invoke_ii(3796,(138047|0))|0);
                  $2662 = __THREW__; __THREW__ = 0;
                  $2663 = $2662&1;
                  if ($2663) {
                   break L1117;
                  } else {
                   $$in$i$i1983 = $2661;
                  }
                 } else {
                  $$in$i$i1983 = $2657;
                 }
                 HEAP32[$2656>>2] = $$in$i$i1983;
                 $2664 = ($$in$i$i1983|0)==(0|0);
                 if (!($2664)) {
                  break;
                 }
                 if (!($10)) {
                  $$0$$sroa_cast$i$i198532363238 = $2656;$2672 = 0;
                  label = 894;
                  break;
                 }
                 __THREW__ = 0;
                 $2665 = (invoke_ii(3796,(138068|0))|0);
                 $2666 = __THREW__; __THREW__ = 0;
                 $2667 = $2666&1;
                 if ($2667) {
                  break L1117;
                 }
                 $2668 = ($2665|0)==(0|0);
                 if ($2668) {
                  __THREW__ = 0;
                  $2669 = (invoke_ii(3796,(138089|0))|0);
                  $2670 = __THREW__; __THREW__ = 0;
                  $2671 = $2670&1;
                  if ($2671) {
                   break L1117;
                  } else {
                   $$in$i$i1989 = $2669;
                  }
                 } else {
                  $$in$i$i1989 = $2665;
                 }
                 $$0$$sroa_cast$i$i198532363238 = $2656;$2672 = $$in$i$i1989;
                 label = 894;
                } else {
                 HEAP32[$2656>>2] = 0;
                 $$0$$sroa_cast$i$i198532363238 = $2656;$2672 = 0;
                 label = 894;
                }
               } while(0);
               if ((label|0) == 894) {
                HEAP32[$$0$$sroa_cast$i$i198532363238>>2] = $2672;
               }
               $2673 = ((($0)) + 1248|0);
               do {
                if ($10) {
                 __THREW__ = 0;
                 $2674 = (invoke_ii(3796,(138111|0))|0);
                 $2675 = __THREW__; __THREW__ = 0;
                 $2676 = $2675&1;
                 if ($2676) {
                  break L1117;
                 }
                 $2677 = ($2674|0)==(0|0);
                 if ($2677) {
                  __THREW__ = 0;
                  $2678 = (invoke_ii(3796,(138130|0))|0);
                  $2679 = __THREW__; __THREW__ = 0;
                  $2680 = $2679&1;
                  if ($2680) {
                   break L1117;
                  } else {
                   $$in$i$i1995 = $2678;
                  }
                 } else {
                  $$in$i$i1995 = $2674;
                 }
                 HEAP32[$2673>>2] = $$in$i$i1995;
                 $2681 = ($$in$i$i1995|0)==(0|0);
                 if (!($2681)) {
                  break;
                 }
                 if (!($10)) {
                  $$0$$sroa_cast$i$i199732413243 = $2673;$2689 = 0;
                  label = 906;
                  break;
                 }
                 __THREW__ = 0;
                 $2682 = (invoke_ii(3796,(138152|0))|0);
                 $2683 = __THREW__; __THREW__ = 0;
                 $2684 = $2683&1;
                 if ($2684) {
                  break L1117;
                 }
                 $2685 = ($2682|0)==(0|0);
                 if ($2685) {
                  __THREW__ = 0;
                  $2686 = (invoke_ii(3796,(138174|0))|0);
                  $2687 = __THREW__; __THREW__ = 0;
                  $2688 = $2687&1;
                  if ($2688) {
                   break L1117;
                  } else {
                   $$in$i$i2001 = $2686;
                  }
                 } else {
                  $$in$i$i2001 = $2682;
                 }
                 $$0$$sroa_cast$i$i199732413243 = $2673;$2689 = $$in$i$i2001;
                 label = 906;
                } else {
                 HEAP32[$2673>>2] = 0;
                 $$0$$sroa_cast$i$i199732413243 = $2673;$2689 = 0;
                 label = 906;
                }
               } while(0);
               if ((label|0) == 906) {
                HEAP32[$$0$$sroa_cast$i$i199732413243>>2] = $2689;
               }
               $2690 = ((($0)) + 1228|0);
               HEAP8[$2690>>0] = $1355;
               if ($10) {
                $2691 = HEAP32[$6>>2]|0;
                __THREW__ = 0;
                $2692 = (invoke_iiid(3793,($2691|0),(138197|0),3.4028234663852886E+38)|0);
                $2693 = __THREW__; __THREW__ = 0;
                $2694 = $2693&1;
                if ($2694) {
                 break;
                }
                $2695 = ((($0)) + 1229|0);
                $2696 = $2692&1;
                HEAP8[$2695>>0] = $2696;
                $2697 = ((($0)) + 1232|0);
                __THREW__ = 0;
                $2698 = (invoke_ii(3796,(198615|0))|0);
                $2699 = __THREW__; __THREW__ = 0;
                $2700 = $2699&1;
                if ($2700) {
                 break;
                }
                $2701 = ($2698|0)==(0|0);
                if ($2701) {
                 __THREW__ = 0;
                 $2702 = (invoke_ii(3796,(138227|0))|0);
                 $2703 = __THREW__; __THREW__ = 0;
                 $2704 = $2703&1;
                 if ($2704) {
                  break;
                 } else {
                  $$in$i$i2009 = $2702;
                 }
                } else {
                 $$in$i$i2009 = $2698;
                }
                HEAP32[$2697>>2] = $$in$i$i2009;
                $2705 = ((($0)) + 1256|0);
                __THREW__ = 0;
                $2706 = (invoke_ii(3796,(196686|0))|0);
                $2707 = __THREW__; __THREW__ = 0;
                $2708 = $2707&1;
                if ($2708) {
                 break;
                }
                $2709 = ($2706|0)==(0|0);
                do {
                 if ($2709) {
                  __THREW__ = 0;
                  $2710 = (invoke_ii(3796,(138247|0))|0);
                  $2711 = __THREW__; __THREW__ = 0;
                  $2712 = $2711&1;
                  if ($2712) {
                   break L1117;
                  }
                  $2713 = ($2710|0)==(0|0);
                  if (!($2713)) {
                   $$in$i$i2014 = $2710;
                   break;
                  }
                  __THREW__ = 0;
                  $2714 = (invoke_ii(3796,(138269|0))|0);
                  $2715 = __THREW__; __THREW__ = 0;
                  $2716 = $2715&1;
                  if ($2716) {
                   break L1117;
                  } else {
                   $$in$i$i2014 = $2714;
                  }
                 } else {
                  $$in$i$i2014 = $2706;
                 }
                } while(0);
                HEAP32[$2705>>2] = $$in$i$i2014;
                $2717 = ((($0)) + 1260|0);
                __THREW__ = 0;
                $2718 = (invoke_ii(3796,(196664|0))|0);
                $2719 = __THREW__; __THREW__ = 0;
                $2720 = $2719&1;
                if ($2720) {
                 break;
                }
                $2721 = ($2718|0)==(0|0);
                do {
                 if ($2721) {
                  __THREW__ = 0;
                  $2722 = (invoke_ii(3796,(138291|0))|0);
                  $2723 = __THREW__; __THREW__ = 0;
                  $2724 = $2723&1;
                  if ($2724) {
                   break L1117;
                  }
                  $2725 = ($2722|0)==(0|0);
                  if (!($2725)) {
                   $$in$i$i2020 = $2722;
                   break;
                  }
                  __THREW__ = 0;
                  $2726 = (invoke_ii(3796,(138316|0))|0);
                  $2727 = __THREW__; __THREW__ = 0;
                  $2728 = $2727&1;
                  if ($2728) {
                   break L1117;
                  } else {
                   $$in$i$i2020 = $2726;
                  }
                 } else {
                  $$in$i$i2020 = $2718;
                 }
                } while(0);
                HEAP32[$2717>>2] = $$in$i$i2020;
                $2729 = ((($0)) + 1264|0);
                __THREW__ = 0;
                $2730 = (invoke_ii(3796,(196645|0))|0);
                $2731 = __THREW__; __THREW__ = 0;
                $2732 = $2731&1;
                if ($2732) {
                 break;
                }
                $2733 = ($2730|0)==(0|0);
                do {
                 if ($2733) {
                  __THREW__ = 0;
                  $2734 = (invoke_ii(3796,(138341|0))|0);
                  $2735 = __THREW__; __THREW__ = 0;
                  $2736 = $2735&1;
                  if ($2736) {
                   break L1117;
                  }
                  $2737 = ($2734|0)==(0|0);
                  if (!($2737)) {
                   $$in$i$i2026 = $2734;
                   break;
                  }
                  __THREW__ = 0;
                  $2738 = (invoke_ii(3796,(138363|0))|0);
                  $2739 = __THREW__; __THREW__ = 0;
                  $2740 = $2739&1;
                  if ($2740) {
                   break L1117;
                  } else {
                   $$in$i$i2026 = $2738;
                  }
                 } else {
                  $$in$i$i2026 = $2730;
                 }
                } while(0);
                HEAP32[$2729>>2] = $$in$i$i2026;
                $2741 = ((($0)) + 1268|0);
                __THREW__ = 0;
                $2742 = (invoke_ii(3796,(198770|0))|0);
                $2743 = __THREW__; __THREW__ = 0;
                $2744 = $2743&1;
                if ($2744) {
                 break;
                }
                $2745 = ($2742|0)==(0|0);
                do {
                 if ($2745) {
                  __THREW__ = 0;
                  $2746 = (invoke_ii(3796,(138385|0))|0);
                  $2747 = __THREW__; __THREW__ = 0;
                  $2748 = $2747&1;
                  if ($2748) {
                   break L1117;
                  }
                  $2749 = ($2746|0)==(0|0);
                  if (!($2749)) {
                   $$in$i$i2032 = $2746;
                   break;
                  }
                  __THREW__ = 0;
                  $2750 = (invoke_ii(3796,(138410|0))|0);
                  $2751 = __THREW__; __THREW__ = 0;
                  $2752 = $2751&1;
                  if ($2752) {
                   break L1117;
                  } else {
                   $$in$i$i2032 = $2750;
                  }
                 } else {
                  $$in$i$i2032 = $2742;
                 }
                } while(0);
                HEAP32[$2741>>2] = $$in$i$i2032;
                $2753 = ((($0)) + 1272|0);
                __THREW__ = 0;
                $2754 = (invoke_ii(3796,(138435|0))|0);
                $2755 = __THREW__; __THREW__ = 0;
                $2756 = $2755&1;
                if ($2756) {
                 break;
                }
                $2757 = ($2754|0)==(0|0);
                do {
                 if ($2757) {
                  __THREW__ = 0;
                  $2758 = (invoke_ii(3796,(138468|0))|0);
                  $2759 = __THREW__; __THREW__ = 0;
                  $2760 = $2759&1;
                  if ($2760) {
                   break L1117;
                  }
                  $2761 = ($2758|0)==(0|0);
                  if (!($2761)) {
                   $$in$i$i2038 = $2758;
                   break;
                  }
                  __THREW__ = 0;
                  $2762 = (invoke_ii(3796,(138504|0))|0);
                  $2763 = __THREW__; __THREW__ = 0;
                  $2764 = $2763&1;
                  if ($2764) {
                   break L1117;
                  } else {
                   $$in$i$i2038 = $2762;
                  }
                 } else {
                  $$in$i$i2038 = $2754;
                 }
                } while(0);
                HEAP32[$2753>>2] = $$in$i$i2038;
                __THREW__ = 0;
                $2765 = (invoke_ii(3796,(138540|0))|0);
                $2766 = __THREW__; __THREW__ = 0;
                $2767 = $2766&1;
                if ($2767) {
                 break;
                }
                $2768 = ((($0)) + 1276|0);
                HEAP32[$2768>>2] = $2765;
                $2769 = ((($0)) + 1280|0);
                __THREW__ = 0;
                $2770 = (invoke_ii(3796,(197539|0))|0);
                $2771 = __THREW__; __THREW__ = 0;
                $2772 = $2771&1;
                if ($2772) {
                 break;
                }
                $2773 = ($2770|0)==(0|0);
                do {
                 if ($2773) {
                  __THREW__ = 0;
                  $2774 = (invoke_ii(3796,(138583|0))|0);
                  $2775 = __THREW__; __THREW__ = 0;
                  $2776 = $2775&1;
                  if ($2776) {
                   break L1117;
                  }
                  $2777 = ($2774|0)==(0|0);
                  if (!($2777)) {
                   $$in$i$i2046 = $2774;
                   break;
                  }
                  __THREW__ = 0;
                  $2778 = (invoke_ii(3796,(138604|0))|0);
                  $2779 = __THREW__; __THREW__ = 0;
                  $2780 = $2779&1;
                  if ($2780) {
                   break L1117;
                  } else {
                   $$in$i$i2046 = $2778;
                  }
                 } else {
                  $$in$i$i2046 = $2770;
                 }
                } while(0);
                HEAP32[$2769>>2] = $$in$i$i2046;
                $2781 = ((($0)) + 1284|0);
                __THREW__ = 0;
                $2782 = (invoke_ii(3796,(197575|0))|0);
                $2783 = __THREW__; __THREW__ = 0;
                $2784 = $2783&1;
                if ($2784) {
                 break;
                }
                $2785 = ($2782|0)==(0|0);
                do {
                 if ($2785) {
                  __THREW__ = 0;
                  $2786 = (invoke_ii(3796,(138625|0))|0);
                  $2787 = __THREW__; __THREW__ = 0;
                  $2788 = $2787&1;
                  if ($2788) {
                   break L1117;
                  }
                  $2789 = ($2786|0)==(0|0);
                  if (!($2789)) {
                   $$in$i$i2053 = $2786;
                   break;
                  }
                  __THREW__ = 0;
                  $2790 = (invoke_ii(3796,(138649|0))|0);
                  $2791 = __THREW__; __THREW__ = 0;
                  $2792 = $2791&1;
                  if ($2792) {
                   break L1117;
                  } else {
                   $$in$i$i2053 = $2790;
                  }
                 } else {
                  $$in$i$i2053 = $2782;
                 }
                } while(0);
                HEAP32[$2781>>2] = $$in$i$i2053;
                $2793 = ((($0)) + 1288|0);
                __THREW__ = 0;
                $2794 = (invoke_ii(3796,(197557|0))|0);
                $2795 = __THREW__; __THREW__ = 0;
                $2796 = $2795&1;
                if ($2796) {
                 break;
                }
                $2797 = ($2794|0)==(0|0);
                do {
                 if ($2797) {
                  __THREW__ = 0;
                  $2798 = (invoke_ii(3796,(138673|0))|0);
                  $2799 = __THREW__; __THREW__ = 0;
                  $2800 = $2799&1;
                  if ($2800) {
                   break L1117;
                  }
                  $2801 = ($2798|0)==(0|0);
                  if (!($2801)) {
                   $$in$i$i2060 = $2798;
                   break;
                  }
                  __THREW__ = 0;
                  $2802 = (invoke_ii(3796,(138694|0))|0);
                  $2803 = __THREW__; __THREW__ = 0;
                  $2804 = $2803&1;
                  if ($2804) {
                   break L1117;
                  } else {
                   $$in$i$i2060 = $2802;
                  }
                 } else {
                  $$in$i$i2060 = $2794;
                 }
                } while(0);
                HEAP32[$2793>>2] = $$in$i$i2060;
                $2805 = ((($0)) + 1292|0);
                __THREW__ = 0;
                $2806 = (invoke_ii(3796,(198404|0))|0);
                $2807 = __THREW__; __THREW__ = 0;
                $2808 = $2807&1;
                if ($2808) {
                 break;
                }
                $2809 = ($2806|0)==(0|0);
                do {
                 if ($2809) {
                  __THREW__ = 0;
                  $2810 = (invoke_ii(3796,(138715|0))|0);
                  $2811 = __THREW__; __THREW__ = 0;
                  $2812 = $2811&1;
                  if ($2812) {
                   break L1117;
                  }
                  $2813 = ($2810|0)==(0|0);
                  if (!($2813)) {
                   $$in$i$i2067 = $2810;
                   break;
                  }
                  __THREW__ = 0;
                  $2814 = (invoke_ii(3796,(138743|0))|0);
                  $2815 = __THREW__; __THREW__ = 0;
                  $2816 = $2815&1;
                  if ($2816) {
                   break L1117;
                  } else {
                   $$in$i$i2067 = $2814;
                  }
                 } else {
                  $$in$i$i2067 = $2806;
                 }
                } while(0);
                HEAP32[$2805>>2] = $$in$i$i2067;
                $2817 = ((($0)) + 1296|0);
                __THREW__ = 0;
                $2818 = (invoke_ii(3796,(138771|0))|0);
                $2819 = __THREW__; __THREW__ = 0;
                $2820 = $2819&1;
                if ($2820) {
                 break;
                }
                $2821 = ($2818|0)==(0|0);
                do {
                 if ($2821) {
                  __THREW__ = 0;
                  $2822 = (invoke_ii(3796,(138794|0))|0);
                  $2823 = __THREW__; __THREW__ = 0;
                  $2824 = $2823&1;
                  if ($2824) {
                   break L1117;
                  }
                  $2825 = ($2822|0)==(0|0);
                  if (!($2825)) {
                   $$in$i$i2073 = $2822;
                   break;
                  }
                  __THREW__ = 0;
                  $2826 = (invoke_ii(3796,(138820|0))|0);
                  $2827 = __THREW__; __THREW__ = 0;
                  $2828 = $2827&1;
                  if ($2828) {
                   break L1117;
                  } else {
                   $$in$i$i2073 = $2826;
                  }
                 } else {
                  $$in$i$i2073 = $2818;
                 }
                } while(0);
                HEAP32[$2817>>2] = $$in$i$i2073;
                $2829 = ((($0)) + 1300|0);
                __THREW__ = 0;
                $2830 = (invoke_ii(3796,(197622|0))|0);
                $2831 = __THREW__; __THREW__ = 0;
                $2832 = $2831&1;
                if ($2832) {
                 break;
                }
                $2833 = ($2830|0)==(0|0);
                do {
                 if ($2833) {
                  __THREW__ = 0;
                  $2834 = (invoke_ii(3796,(138846|0))|0);
                  $2835 = __THREW__; __THREW__ = 0;
                  $2836 = $2835&1;
                  if ($2836) {
                   break L1117;
                  }
                  $2837 = ($2834|0)==(0|0);
                  if (!($2837)) {
                   $$in$i$i2079 = $2834;
                   break;
                  }
                  __THREW__ = 0;
                  $2838 = (invoke_ii(3796,(138872|0))|0);
                  $2839 = __THREW__; __THREW__ = 0;
                  $2840 = $2839&1;
                  if ($2840) {
                   break L1117;
                  } else {
                   $$in$i$i2079 = $2838;
                  }
                 } else {
                  $$in$i$i2079 = $2830;
                 }
                } while(0);
                HEAP32[$2829>>2] = $$in$i$i2079;
                $2841 = ((($0)) + 1304|0);
                __THREW__ = 0;
                $2842 = (invoke_ii(3796,(138898|0))|0);
                $2843 = __THREW__; __THREW__ = 0;
                $2844 = $2843&1;
                if ($2844) {
                 break;
                }
                $2845 = ($2842|0)==(0|0);
                do {
                 if ($2845) {
                  __THREW__ = 0;
                  $2846 = (invoke_ii(3796,(138921|0))|0);
                  $2847 = __THREW__; __THREW__ = 0;
                  $2848 = $2847&1;
                  if ($2848) {
                   break L1117;
                  }
                  $2849 = ($2846|0)==(0|0);
                  if (!($2849)) {
                   $$in$i$i2086 = $2846;
                   break;
                  }
                  __THREW__ = 0;
                  $2850 = (invoke_ii(3796,(138947|0))|0);
                  $2851 = __THREW__; __THREW__ = 0;
                  $2852 = $2851&1;
                  if ($2852) {
                   break L1117;
                  } else {
                   $$in$i$i2086 = $2850;
                  }
                 } else {
                  $$in$i$i2086 = $2842;
                 }
                } while(0);
                HEAP32[$2841>>2] = $$in$i$i2086;
                $2853 = ((($0)) + 1308|0);
                __THREW__ = 0;
                $2854 = (invoke_ii(3796,(138973|0))|0);
                $2855 = __THREW__; __THREW__ = 0;
                $2856 = $2855&1;
                if ($2856) {
                 break;
                }
                $2857 = ($2854|0)==(0|0);
                do {
                 if ($2857) {
                  __THREW__ = 0;
                  $2858 = (invoke_ii(3796,(138994|0))|0);
                  $2859 = __THREW__; __THREW__ = 0;
                  $2860 = $2859&1;
                  if ($2860) {
                   break L1117;
                  }
                  $2861 = ($2858|0)==(0|0);
                  if (!($2861)) {
                   $$in$i$i2092 = $2858;
                   break;
                  }
                  __THREW__ = 0;
                  $2862 = (invoke_ii(3796,(139018|0))|0);
                  $2863 = __THREW__; __THREW__ = 0;
                  $2864 = $2863&1;
                  if ($2864) {
                   break L1117;
                  } else {
                   $$in$i$i2092 = $2862;
                  }
                 } else {
                  $$in$i$i2092 = $2854;
                 }
                } while(0);
                HEAP32[$2853>>2] = $$in$i$i2092;
                $2865 = ((($0)) + 1312|0);
                __THREW__ = 0;
                $2866 = (invoke_ii(3796,(139042|0))|0);
                $2867 = __THREW__; __THREW__ = 0;
                $2868 = $2867&1;
                if ($2868) {
                 break;
                }
                $2869 = ($2866|0)==(0|0);
                do {
                 if ($2869) {
                  __THREW__ = 0;
                  $2870 = (invoke_ii(3796,(139068|0))|0);
                  $2871 = __THREW__; __THREW__ = 0;
                  $2872 = $2871&1;
                  if ($2872) {
                   break L1117;
                  }
                  $2873 = ($2870|0)==(0|0);
                  if (!($2873)) {
                   $$in$i$i2099 = $2870;
                   break;
                  }
                  __THREW__ = 0;
                  $2874 = (invoke_ii(3796,(139097|0))|0);
                  $2875 = __THREW__; __THREW__ = 0;
                  $2876 = $2875&1;
                  if ($2876) {
                   break L1117;
                  } else {
                   $$in$i$i2099 = $2874;
                  }
                 } else {
                  $$in$i$i2099 = $2866;
                 }
                } while(0);
                HEAP32[$2865>>2] = $$in$i$i2099;
                $2877 = ((($0)) + 1316|0);
                __THREW__ = 0;
                $2878 = (invoke_ii(3796,(139126|0))|0);
                $2879 = __THREW__; __THREW__ = 0;
                $2880 = $2879&1;
                if ($2880) {
                 break;
                }
                $2881 = ($2878|0)==(0|0);
                do {
                 if ($2881) {
                  __THREW__ = 0;
                  $2882 = (invoke_ii(3796,(139151|0))|0);
                  $2883 = __THREW__; __THREW__ = 0;
                  $2884 = $2883&1;
                  if ($2884) {
                   break L1117;
                  }
                  $2885 = ($2882|0)==(0|0);
                  if (!($2885)) {
                   $$in$i$i2105 = $2882;
                   break;
                  }
                  __THREW__ = 0;
                  $2886 = (invoke_ii(3796,(139179|0))|0);
                  $2887 = __THREW__; __THREW__ = 0;
                  $2888 = $2887&1;
                  if ($2888) {
                   break L1117;
                  } else {
                   $$in$i$i2105 = $2886;
                  }
                 } else {
                  $$in$i$i2105 = $2878;
                 }
                } while(0);
                HEAP32[$2877>>2] = $$in$i$i2105;
                $2889 = ((($0)) + 1320|0);
                __THREW__ = 0;
                $2890 = (invoke_ii(3796,(197596|0))|0);
                $2891 = __THREW__; __THREW__ = 0;
                $2892 = $2891&1;
                if ($2892) {
                 break;
                }
                $2893 = ($2890|0)==(0|0);
                do {
                 if ($2893) {
                  __THREW__ = 0;
                  $2894 = (invoke_ii(3796,(139207|0))|0);
                  $2895 = __THREW__; __THREW__ = 0;
                  $2896 = $2895&1;
                  if ($2896) {
                   break L1117;
                  }
                  $2897 = ($2894|0)==(0|0);
                  if (!($2897)) {
                   $$in$i$i2111 = $2894;
                   break;
                  }
                  __THREW__ = 0;
                  $2898 = (invoke_ii(3796,(139236|0))|0);
                  $2899 = __THREW__; __THREW__ = 0;
                  $2900 = $2899&1;
                  if ($2900) {
                   break L1117;
                  } else {
                   $$in$i$i2111 = $2898;
                  }
                 } else {
                  $$in$i$i2111 = $2890;
                 }
                } while(0);
                HEAP32[$2889>>2] = $$in$i$i2111;
                $2901 = ((($0)) + 1324|0);
                __THREW__ = 0;
                $2902 = (invoke_ii(3796,(198429|0))|0);
                $2903 = __THREW__; __THREW__ = 0;
                $2904 = $2903&1;
                if ($2904) {
                 break;
                }
                $2905 = ($2902|0)==(0|0);
                do {
                 if ($2905) {
                  __THREW__ = 0;
                  $2906 = (invoke_ii(3796,(139265|0))|0);
                  $2907 = __THREW__; __THREW__ = 0;
                  $2908 = $2907&1;
                  if ($2908) {
                   break L1117;
                  }
                  $2909 = ($2906|0)==(0|0);
                  if (!($2909)) {
                   $$in$i$i2117 = $2906;
                   break;
                  }
                  __THREW__ = 0;
                  $2910 = (invoke_ii(3796,(139285|0))|0);
                  $2911 = __THREW__; __THREW__ = 0;
                  $2912 = $2911&1;
                  if ($2912) {
                   break L1117;
                  } else {
                   $$in$i$i2117 = $2910;
                  }
                 } else {
                  $$in$i$i2117 = $2902;
                 }
                } while(0);
                HEAP32[$2901>>2] = $$in$i$i2117;
                $2913 = ((($0)) + 1328|0);
                __THREW__ = 0;
                $2914 = (invoke_ii(3796,(139305|0))|0);
                $2915 = __THREW__; __THREW__ = 0;
                $2916 = $2915&1;
                if ($2916) {
                 break;
                }
                $2917 = ($2914|0)==(0|0);
                do {
                 if ($2917) {
                  __THREW__ = 0;
                  $2918 = (invoke_ii(3796,(139323|0))|0);
                  $2919 = __THREW__; __THREW__ = 0;
                  $2920 = $2919&1;
                  if ($2920) {
                   break L1117;
                  }
                  $2921 = ($2918|0)==(0|0);
                  if (!($2921)) {
                   $$in$i$i2123 = $2918;
                   break;
                  }
                  __THREW__ = 0;
                  $2922 = (invoke_ii(3796,(139344|0))|0);
                  $2923 = __THREW__; __THREW__ = 0;
                  $2924 = $2923&1;
                  if ($2924) {
                   break L1117;
                  } else {
                   $$in$i$i2123 = $2922;
                  }
                 } else {
                  $$in$i$i2123 = $2914;
                 }
                } while(0);
                HEAP32[$2913>>2] = $$in$i$i2123;
                __THREW__ = 0;
                $2938 = (invoke_ii(3796,(196705|0))|0);
                $2939 = __THREW__; __THREW__ = 0;
                $2940 = $2939&1;
                if ($2940) {
                 break;
                }
                $2941 = ($2938|0)==(0|0);
                do {
                 if ($2941) {
                  __THREW__ = 0;
                  $2942 = (invoke_ii(3796,(139365|0))|0);
                  $2943 = __THREW__; __THREW__ = 0;
                  $2944 = $2943&1;
                  if ($2944) {
                   break L1117;
                  }
                  $2945 = ($2942|0)==(0|0);
                  if (!($2945)) {
                   $$in$i$i2129 = $2942;
                   break;
                  }
                  __THREW__ = 0;
                  $2946 = (invoke_ii(3796,(139397|0))|0);
                  $2947 = __THREW__; __THREW__ = 0;
                  $2948 = $2947&1;
                  if ($2948) {
                   break L1117;
                  } else {
                   $$in$i$i2129 = $2946;
                  }
                 } else {
                  $$in$i$i2129 = $2938;
                 }
                } while(0);
                $2950 = $$in$i$i2129;$2952 = $2705;$2955 = $2717;$2958 = $2729;$2961 = $2741;$2964 = $2769;$2967 = $2781;$2970 = $2793;$2973 = $2805;$2976 = $2829;$2979 = $2889;$2982 = $2901;
               } else {
                $2925 = ((($0)) + 1229|0);
                HEAP8[$2925>>0] = 0;
                $2926 = ((($0)) + 1232|0);
                HEAP32[$2926>>2] = 0;
                $2927 = ((($0)) + 1256|0);
                $2928 = ((($0)) + 1260|0);
                $2929 = ((($0)) + 1264|0);
                $2930 = ((($0)) + 1268|0);
                $2931 = ((($0)) + 1280|0);
                $2932 = ((($0)) + 1284|0);
                $2933 = ((($0)) + 1288|0);
                $2934 = ((($0)) + 1292|0);
                $2935 = ((($0)) + 1300|0);
                $2936 = ((($0)) + 1320|0);
                $2937 = ((($0)) + 1324|0);
                dest=$2927; stop=dest+76|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
                $2950 = 0;$2952 = $2927;$2955 = $2928;$2958 = $2929;$2961 = $2930;$2964 = $2931;$2967 = $2932;$2970 = $2933;$2973 = $2934;$2976 = $2935;$2979 = $2936;$2982 = $2937;
               }
               $2949 = ((($0)) + 1332|0);
               HEAP32[$2949>>2] = $2950;
               $2951 = HEAP32[$2952>>2]|0;
               $2953 = ($2951|0)==(0|0);
               do {
                if ($2953) {
                 $2986 = 0;
                } else {
                 $2954 = HEAP32[$2955>>2]|0;
                 $2956 = ($2954|0)==(0|0);
                 if ($2956) {
                  $2986 = 0;
                  break;
                 }
                 $2957 = HEAP32[$2958>>2]|0;
                 $2959 = ($2957|0)==(0|0);
                 if ($2959) {
                  $2986 = 0;
                  break;
                 }
                 $2960 = HEAP32[$2961>>2]|0;
                 $2962 = ($2960|0)==(0|0);
                 if ($2962) {
                  $2986 = 0;
                  break;
                 }
                 $2963 = HEAP32[$2964>>2]|0;
                 $2965 = ($2963|0)==(0|0);
                 if ($2965) {
                  $2986 = 0;
                  break;
                 }
                 $2966 = HEAP32[$2967>>2]|0;
                 $2968 = ($2966|0)==(0|0);
                 if ($2968) {
                  $2986 = 0;
                  break;
                 }
                 $2969 = HEAP32[$2970>>2]|0;
                 $2971 = ($2969|0)==(0|0);
                 if ($2971) {
                  $2986 = 0;
                  break;
                 }
                 $2972 = HEAP32[$2973>>2]|0;
                 $2974 = ($2972|0)==(0|0);
                 if ($2974) {
                  $2986 = 0;
                  break;
                 }
                 $2975 = HEAP32[$2976>>2]|0;
                 $2977 = ($2975|0)==(0|0);
                 if ($2977) {
                  $2986 = 0;
                  break;
                 }
                 $2978 = HEAP32[$2979>>2]|0;
                 $2980 = ($2978|0)==(0|0);
                 if ($2980) {
                  $2986 = 0;
                  break;
                 }
                 $2981 = HEAP32[$2982>>2]|0;
                 $2983 = ($2950|0)!=(0|0);
                 $not$3247 = ($2981|0)!=(0|0);
                 $$3246 = $2983 & $not$3247;
                 $2986 = $$3246;
                }
               } while(0);
               $2984 = ((($0)) + 1252|0);
               $2985 = $2986&1;
               HEAP8[$2984>>0] = $2985;
               if ($10) {
                $2987 = HEAP32[$6>>2]|0;
                __THREW__ = 0;
                $2988 = (invoke_iiid(3793,($2987|0),(139429|0),3.4028234663852886E+38)|0);
                $2989 = __THREW__; __THREW__ = 0;
                $2990 = $2989&1;
                if ($2990) {
                 break;
                }
                if ($2988) {
                 $$ph3065 = 1;
                } else {
                 $2991 = HEAP32[$6>>2]|0;
                 __THREW__ = 0;
                 $2992 = (invoke_iiid(3793,($2991|0),(139457|0),3.4028234663852886E+38)|0);
                 $2993 = __THREW__; __THREW__ = 0;
                 $2994 = $2993&1;
                 if ($2994) {
                  break;
                 } else {
                  $$ph3065 = $2992;
                 }
                }
                $2995 = ((($0)) + 1253|0);
                $2996 = $$ph3065&1;
                HEAP8[$2995>>0] = $2996;
                __THREW__ = 0;
                $2997 = (invoke_ii(3796,(139485|0))|0);
                $2998 = __THREW__; __THREW__ = 0;
                $2999 = $2998&1;
                if ($2999) {
                 break;
                }
                $3000 = ((($0)) + 1336|0);
                HEAP32[$3000>>2] = $2997;
                __THREW__ = 0;
                $3001 = (invoke_ii(3796,(139516|0))|0);
                $3002 = __THREW__; __THREW__ = 0;
                $3003 = $3002&1;
                if ($3003) {
                 break;
                }
                $3004 = ((($0)) + 1340|0);
                HEAP32[$3004>>2] = $3001;
                __THREW__ = 0;
                $3005 = (invoke_ii(3796,(139549|0))|0);
                $3006 = __THREW__; __THREW__ = 0;
                $3007 = $3006&1;
                if ($3007) {
                 break;
                }
                $3008 = ((($0)) + 1344|0);
                HEAP32[$3008>>2] = $3005;
                __THREW__ = 0;
                $3009 = (invoke_ii(3796,(139580|0))|0);
                $3010 = __THREW__; __THREW__ = 0;
                $3011 = $3010&1;
                if ($3011) {
                 break;
                }
                $3012 = ((($0)) + 1348|0);
                HEAP32[$3012>>2] = $3009;
                __THREW__ = 0;
                $3013 = (invoke_ii(3796,(139601|0))|0);
                $3014 = __THREW__; __THREW__ = 0;
                $3015 = $3014&1;
                if ($3015) {
                 break;
                }
                $3016 = ((($0)) + 1352|0);
                HEAP32[$3016>>2] = $3013;
                __THREW__ = 0;
                $3017 = (invoke_ii(3796,(139627|0))|0);
                $3018 = __THREW__; __THREW__ = 0;
                $3019 = $3018&1;
                if ($3019) {
                 break;
                }
                $3020 = ((($0)) + 1356|0);
                HEAP32[$3020>>2] = $3017;
                __THREW__ = 0;
                $3021 = (invoke_ii(3796,(139647|0))|0);
                $3022 = __THREW__; __THREW__ = 0;
                $3023 = $3022&1;
                if ($3023) {
                 break;
                }
                $3024 = ((($0)) + 1360|0);
                HEAP32[$3024>>2] = $3021;
                __THREW__ = 0;
                $3025 = (invoke_ii(3796,(139671|0))|0);
                $3026 = __THREW__; __THREW__ = 0;
                $3027 = $3026&1;
                if ($3027) {
                 break;
                }
                $3028 = ((($0)) + 1364|0);
                HEAP32[$3028>>2] = $3025;
                __THREW__ = 0;
                $3029 = (invoke_ii(3796,(139697|0))|0);
                $3030 = __THREW__; __THREW__ = 0;
                $3031 = $3030&1;
                if ($3031) {
                 break;
                }
                $3032 = ((($0)) + 1368|0);
                HEAP32[$3032>>2] = $3029;
                __THREW__ = 0;
                $3033 = (invoke_ii(3796,(139709|0))|0);
                $3034 = __THREW__; __THREW__ = 0;
                $3035 = $3034&1;
                if ($3035) {
                 break;
                }
                $3036 = ((($0)) + 1372|0);
                HEAP32[$3036>>2] = $3033;
                __THREW__ = 0;
                $3037 = (invoke_ii(3796,(139718|0))|0);
                $3038 = __THREW__; __THREW__ = 0;
                $3039 = $3038&1;
                if ($3039) {
                 break;
                }
                $3040 = ((($0)) + 1376|0);
                HEAP32[$3040>>2] = $3037;
                __THREW__ = 0;
                $3041 = (invoke_ii(3796,(139731|0))|0);
                $3042 = __THREW__; __THREW__ = 0;
                $3043 = $3042&1;
                if ($3043) {
                 break;
                }
                $3044 = ((($0)) + 1380|0);
                HEAP32[$3044>>2] = $3041;
                __THREW__ = 0;
                $3045 = (invoke_ii(3796,(139748|0))|0);
                $3046 = __THREW__; __THREW__ = 0;
                $3047 = $3046&1;
                if ($3047) {
                 break;
                }
                $3048 = ((($0)) + 1384|0);
                HEAP32[$3048>>2] = $3045;
                __THREW__ = 0;
                $3049 = (invoke_ii(3796,(139759|0))|0);
                $3050 = __THREW__; __THREW__ = 0;
                $3051 = $3050&1;
                if ($3051) {
                 break;
                }
                $3052 = ((($0)) + 1388|0);
                HEAP32[$3052>>2] = $3049;
                $3053 = ((($0)) + 1392|0);
                __THREW__ = 0;
                $3054 = (invoke_ii(3796,(139771|0))|0);
                $3055 = __THREW__; __THREW__ = 0;
                $3056 = $3055&1;
                if ($3056) {
                 break;
                }
                $3057 = ($3054|0)==(0|0);
                if ($3057) {
                 __THREW__ = 0;
                 $3058 = (invoke_ii(3796,(139792|0))|0);
                 $3059 = __THREW__; __THREW__ = 0;
                 $3060 = $3059&1;
                 if ($3060) {
                  break;
                 } else {
                  $$in$i$i2169 = $3058;
                 }
                } else {
                 $$in$i$i2169 = $3054;
                }
                HEAP32[$3053>>2] = $$in$i$i2169;
                $3061 = ((($0)) + 1396|0);
                __THREW__ = 0;
                $3062 = (invoke_ii(3796,(139816|0))|0);
                $3063 = __THREW__; __THREW__ = 0;
                $3064 = $3063&1;
                if ($3064) {
                 break;
                }
                $3065 = ($3062|0)==(0|0);
                if ($3065) {
                 __THREW__ = 0;
                 $3066 = (invoke_ii(3796,(139842|0))|0);
                 $3067 = __THREW__; __THREW__ = 0;
                 $3068 = $3067&1;
                 if ($3068) {
                  break;
                 } else {
                  $$in$i$i2174 = $3066;
                 }
                } else {
                 $$in$i$i2174 = $3062;
                }
                HEAP32[$3061>>2] = $$in$i$i2174;
                $3069 = ((($0)) + 1400|0);
                __THREW__ = 0;
                $3070 = (invoke_ii(3796,(139871|0))|0);
                $3071 = __THREW__; __THREW__ = 0;
                $3072 = $3071&1;
                if ($3072) {
                 break;
                }
                $3073 = ($3070|0)==(0|0);
                if ($3073) {
                 __THREW__ = 0;
                 $3074 = (invoke_ii(3796,(139894|0))|0);
                 $3075 = __THREW__; __THREW__ = 0;
                 $3076 = $3075&1;
                 if ($3076) {
                  break;
                 } else {
                  $$in$i$i2179 = $3074;
                 }
                } else {
                 $$in$i$i2179 = $3070;
                }
                HEAP32[$3069>>2] = $$in$i$i2179;
                $3077 = ((($0)) + 1404|0);
                __THREW__ = 0;
                $3078 = (invoke_ii(3796,(139920|0))|0);
                $3079 = __THREW__; __THREW__ = 0;
                $3080 = $3079&1;
                if ($3080) {
                 break;
                }
                $3081 = ($3078|0)==(0|0);
                if ($3081) {
                 __THREW__ = 0;
                 $3082 = (invoke_ii(3796,(139948|0))|0);
                 $3083 = __THREW__; __THREW__ = 0;
                 $3084 = $3083&1;
                 if ($3084) {
                  break;
                 } else {
                  $$in$i$i2184 = $3082;
                 }
                } else {
                 $$in$i$i2184 = $3078;
                }
                HEAP32[$3077>>2] = $$in$i$i2184;
                $3085 = ((($0)) + 1408|0);
                __THREW__ = 0;
                $3086 = (invoke_ii(3796,(139979|0))|0);
                $3087 = __THREW__; __THREW__ = 0;
                $3088 = $3087&1;
                if ($3088) {
                 break;
                }
                $3089 = ($3086|0)==(0|0);
                if ($3089) {
                 __THREW__ = 0;
                 $3090 = (invoke_ii(3796,(140004|0))|0);
                 $3091 = __THREW__; __THREW__ = 0;
                 $3092 = $3091&1;
                 if ($3092) {
                  break;
                 } else {
                  $$in$i$i2189 = $3090;
                 }
                } else {
                 $$in$i$i2189 = $3086;
                }
                HEAP32[$3085>>2] = $$in$i$i2189;
                $3093 = ((($0)) + 1412|0);
                __THREW__ = 0;
                $3094 = (invoke_ii(3796,(140032|0))|0);
                $3095 = __THREW__; __THREW__ = 0;
                $3096 = $3095&1;
                if ($3096) {
                 break;
                }
                $3097 = ($3094|0)==(0|0);
                if ($3097) {
                 __THREW__ = 0;
                 $3098 = (invoke_ii(3796,(140055|0))|0);
                 $3099 = __THREW__; __THREW__ = 0;
                 $3100 = $3099&1;
                 if ($3100) {
                  break;
                 } else {
                  $$in$i$i2195 = $3098;
                 }
                } else {
                 $$in$i$i2195 = $3094;
                }
                HEAP32[$3093>>2] = $$in$i$i2195;
                $3101 = ((($0)) + 1416|0);
                __THREW__ = 0;
                $3102 = (invoke_ii(3796,(140081|0))|0);
                $3103 = __THREW__; __THREW__ = 0;
                $3104 = $3103&1;
                if ($3104) {
                 break;
                }
                $3105 = ($3102|0)==(0|0);
                if ($3105) {
                 __THREW__ = 0;
                 $3106 = (invoke_ii(3796,(140109|0))|0);
                 $3107 = __THREW__; __THREW__ = 0;
                 $3108 = $3107&1;
                 if ($3108) {
                  break;
                 } else {
                  $$in$i$i2201 = $3106;
                 }
                } else {
                 $$in$i$i2201 = $3102;
                }
                HEAP32[$3101>>2] = $$in$i$i2201;
                $3109 = ((($0)) + 1420|0);
                __THREW__ = 0;
                $3110 = (invoke_ii(3796,(140140|0))|0);
                $3111 = __THREW__; __THREW__ = 0;
                $3112 = $3111&1;
                if ($3112) {
                 break;
                }
                $3113 = ($3110|0)==(0|0);
                if ($3113) {
                 __THREW__ = 0;
                 $3114 = (invoke_ii(3796,(140170|0))|0);
                 $3115 = __THREW__; __THREW__ = 0;
                 $3116 = $3115&1;
                 if ($3116) {
                  break;
                 } else {
                  $$in$i$i2206 = $3114;
                 }
                } else {
                 $$in$i$i2206 = $3110;
                }
                HEAP32[$3109>>2] = $$in$i$i2206;
                __THREW__ = 0;
                $3117 = (invoke_ii(3796,(140203|0))|0);
                $3118 = __THREW__; __THREW__ = 0;
                $3119 = $3118&1;
                if ($3119) {
                 break;
                }
                $3120 = ((($0)) + 1424|0);
                HEAP32[$3120>>2] = $3117;
                __THREW__ = 0;
                $3121 = (invoke_ii(3796,(140227|0))|0);
                $3122 = __THREW__; __THREW__ = 0;
                $3123 = $3122&1;
                if ($3123) {
                 break;
                }
                $3124 = ((($0)) + 1428|0);
                HEAP32[$3124>>2] = $3121;
                __THREW__ = 0;
                $3125 = (invoke_ii(3796,(140254|0))|0);
                $3126 = __THREW__; __THREW__ = 0;
                $3127 = $3126&1;
                if ($3127) {
                 break;
                }
                $3128 = ((($0)) + 1432|0);
                HEAP32[$3128>>2] = $3125;
                __THREW__ = 0;
                $3129 = (invoke_ii(3796,(140278|0))|0);
                $3130 = __THREW__; __THREW__ = 0;
                $3131 = $3130&1;
                if ($3131) {
                 break;
                }
                $3132 = ((($0)) + 1436|0);
                HEAP32[$3132>>2] = $3129;
                __THREW__ = 0;
                $3133 = (invoke_ii(3796,(140300|0))|0);
                $3134 = __THREW__; __THREW__ = 0;
                $3135 = $3134&1;
                if ($3135) {
                 break;
                }
                $3136 = ((($0)) + 1440|0);
                HEAP32[$3136>>2] = $3133;
                __THREW__ = 0;
                $3137 = (invoke_ii(3796,(140325|0))|0);
                $3138 = __THREW__; __THREW__ = 0;
                $3139 = $3138&1;
                if ($3139) {
                 break;
                }
                $3140 = ((($0)) + 1444|0);
                HEAP32[$3140>>2] = $3137;
                __THREW__ = 0;
                $3141 = (invoke_ii(3796,(140351|0))|0);
                $3142 = __THREW__; __THREW__ = 0;
                $3143 = $3142&1;
                if ($3143) {
                 break;
                }
                $3144 = ((($0)) + 1448|0);
                HEAP32[$3144>>2] = $3141;
                __THREW__ = 0;
                $3145 = (invoke_ii(3796,(140375|0))|0);
                $3146 = __THREW__; __THREW__ = 0;
                $3147 = $3146&1;
                if ($3147) {
                 break;
                }
                $3148 = ((($0)) + 1452|0);
                HEAP32[$3148>>2] = $3145;
                __THREW__ = 0;
                $3149 = (invoke_ii(3796,(140405|0))|0);
                $3150 = __THREW__; __THREW__ = 0;
                $3151 = $3150&1;
                if ($3151) {
                 break;
                }
                $3152 = ((($0)) + 1456|0);
                HEAP32[$3152>>2] = $3149;
                __THREW__ = 0;
                $3153 = (invoke_ii(3796,(140438|0))|0);
                $3154 = __THREW__; __THREW__ = 0;
                $3155 = $3154&1;
                if ($3155) {
                 break;
                }
                $3156 = ((($0)) + 1460|0);
                HEAP32[$3156>>2] = $3153;
                __THREW__ = 0;
                $3157 = (invoke_ii(3796,(140477|0))|0);
                $3158 = __THREW__; __THREW__ = 0;
                $3159 = $3158&1;
                if ($3159) {
                 break;
                }
                $3160 = ((($0)) + 1464|0);
                HEAP32[$3160>>2] = $3157;
                __THREW__ = 0;
                $3161 = (invoke_ii(3796,(140504|0))|0);
                $3162 = __THREW__; __THREW__ = 0;
                $3163 = $3162&1;
                if ($3163) {
                 break;
                }
                $3164 = ((($0)) + 1468|0);
                HEAP32[$3164>>2] = $3161;
                __THREW__ = 0;
                $3165 = (invoke_ii(3796,(140534|0))|0);
                $3166 = __THREW__; __THREW__ = 0;
                $3167 = $3166&1;
                if ($3167) {
                 break;
                }
                $3168 = ((($0)) + 1472|0);
                HEAP32[$3168>>2] = $3165;
                __THREW__ = 0;
                $3169 = (invoke_ii(3796,(140565|0))|0);
                $3170 = __THREW__; __THREW__ = 0;
                $3171 = $3170&1;
                if ($3171) {
                 break;
                }
                $3172 = ((($0)) + 1476|0);
                HEAP32[$3172>>2] = $3169;
                __THREW__ = 0;
                $3173 = (invoke_ii(3796,(140590|0))|0);
                $3174 = __THREW__; __THREW__ = 0;
                $3175 = $3174&1;
                if ($3175) {
                 break;
                }
                $3176 = ((($0)) + 1480|0);
                HEAP32[$3176>>2] = $3173;
                __THREW__ = 0;
                $3177 = (invoke_ii(3796,(140616|0))|0);
                $3178 = __THREW__; __THREW__ = 0;
                $3179 = $3178&1;
                if ($3179) {
                 break;
                }
                $3180 = ((($0)) + 1484|0);
                HEAP32[$3180>>2] = $3177;
                $3181 = ((($0)) + 1492|0);
                __THREW__ = 0;
                $3182 = (invoke_ii(3796,(197905|0))|0);
                $3183 = __THREW__; __THREW__ = 0;
                $3184 = $3183&1;
                if ($3184) {
                 break;
                }
                $3185 = ($3182|0)==(0|0);
                if ($3185) {
                 __THREW__ = 0;
                 $3186 = (invoke_ii(3796,(140644|0))|0);
                 $3187 = __THREW__; __THREW__ = 0;
                 $3188 = $3187&1;
                 if ($3188) {
                  break;
                 } else {
                  $$in$i$i2254 = $3186;
                 }
                } else {
                 $$in$i$i2254 = $3182;
                }
                HEAP32[$3181>>2] = $$in$i$i2254;
                $3189 = ((($0)) + 1500|0);
                __THREW__ = 0;
                $3190 = (invoke_ii(3796,(197944|0))|0);
                $3191 = __THREW__; __THREW__ = 0;
                $3192 = $3191&1;
                if ($3192) {
                 break;
                }
                $3193 = ($3190|0)==(0|0);
                if ($3193) {
                 __THREW__ = 0;
                 $3194 = (invoke_ii(3796,(140665|0))|0);
                 $3195 = __THREW__; __THREW__ = 0;
                 $3196 = $3195&1;
                 if ($3196) {
                  break;
                 } else {
                  $$in$i$i2260 = $3194;
                 }
                } else {
                 $$in$i$i2260 = $3190;
                }
                HEAP32[$3189>>2] = $$in$i$i2260;
                $3197 = ((($0)) + 1488|0);
                __THREW__ = 0;
                $3198 = (invoke_ii(3796,(197923|0))|0);
                $3199 = __THREW__; __THREW__ = 0;
                $3200 = $3199&1;
                if ($3200) {
                 break;
                }
                $3201 = ($3198|0)==(0|0);
                if ($3201) {
                 __THREW__ = 0;
                 $3202 = (invoke_ii(3796,(140686|0))|0);
                 $3203 = __THREW__; __THREW__ = 0;
                 $3204 = $3203&1;
                 if ($3204) {
                  break;
                 } else {
                  $$in$i$i2266 = $3202;
                 }
                } else {
                 $$in$i$i2266 = $3198;
                }
                HEAP32[$3197>>2] = $$in$i$i2266;
                $3205 = ((($0)) + 1496|0);
                __THREW__ = 0;
                $3206 = (invoke_ii(3796,(140710|0))|0);
                $3207 = __THREW__; __THREW__ = 0;
                $3208 = $3207&1;
                if ($3208) {
                 break;
                }
                $3209 = ($3206|0)==(0|0);
                if ($3209) {
                 __THREW__ = 0;
                 $3210 = (invoke_ii(3796,(140726|0))|0);
                 $3211 = __THREW__; __THREW__ = 0;
                 $3212 = $3211&1;
                 if ($3212) {
                  break;
                 } else {
                  $$in$i$i2272 = $3210;
                 }
                } else {
                 $$in$i$i2272 = $3206;
                }
                HEAP32[$3205>>2] = $$in$i$i2272;
                $3213 = HEAP32[$6>>2]|0;
                __THREW__ = 0;
                $3214 = (invoke_iiid(3793,($3213|0),(140745|0),4.3000001907348633)|0);
                $3215 = __THREW__; __THREW__ = 0;
                $3216 = $3215&1;
                if ($3216) {
                 break;
                }
                $3217 = ((($0)) + 1504|0);
                $3218 = $3214&1;
                HEAP8[$3217>>0] = $3218;
                $3219 = ((($0)) + 1508|0);
                __THREW__ = 0;
                $3220 = (invoke_ii(3796,(140774|0))|0);
                $3221 = __THREW__; __THREW__ = 0;
                $3222 = $3221&1;
                if ($3222) {
                 break;
                }
                $3223 = ($3220|0)==(0|0);
                if ($3223) {
                 __THREW__ = 0;
                 $3224 = (invoke_ii(3796,(140793|0))|0);
                 $3225 = __THREW__; __THREW__ = 0;
                 $3226 = $3225&1;
                 if ($3226) {
                  break;
                 } else {
                  $$in$i$i2278 = $3224;
                 }
                } else {
                 $$in$i$i2278 = $3220;
                }
                HEAP32[$3219>>2] = $$in$i$i2278;
                $3227 = ((($0)) + 1512|0);
                __THREW__ = 0;
                $3228 = (invoke_ii(3796,(140815|0))|0);
                $3229 = __THREW__; __THREW__ = 0;
                $3230 = $3229&1;
                if ($3230) {
                 break;
                }
                $3231 = ($3228|0)==(0|0);
                if ($3231) {
                 __THREW__ = 0;
                 $3232 = (invoke_ii(3796,(140841|0))|0);
                 $3233 = __THREW__; __THREW__ = 0;
                 $3234 = $3233&1;
                 if ($3234) {
                  break;
                 } else {
                  $$in$i$i2283 = $3232;
                 }
                } else {
                 $$in$i$i2283 = $3228;
                }
                HEAP32[$3227>>2] = $$in$i$i2283;
                $3235 = ((($0)) + 1516|0);
                __THREW__ = 0;
                $3236 = (invoke_ii(3796,(140870|0))|0);
                $3237 = __THREW__; __THREW__ = 0;
                $3238 = $3237&1;
                if ($3238) {
                 break;
                }
                $3239 = ($3236|0)==(0|0);
                if ($3239) {
                 __THREW__ = 0;
                 $3240 = (invoke_ii(3796,(140892|0))|0);
                 $3241 = __THREW__; __THREW__ = 0;
                 $3242 = $3241&1;
                 if ($3242) {
                  break;
                 } else {
                  $$in$i$i2288 = $3240;
                 }
                } else {
                 $$in$i$i2288 = $3236;
                }
                HEAP32[$3235>>2] = $$in$i$i2288;
                $3243 = ((($0)) + 1520|0);
                __THREW__ = 0;
                $3244 = (invoke_ii(3796,(140917|0))|0);
                $3245 = __THREW__; __THREW__ = 0;
                $3246 = $3245&1;
                if ($3246) {
                 break;
                }
                $3247 = ($3244|0)==(0|0);
                if ($3247) {
                 __THREW__ = 0;
                 $3248 = (invoke_ii(3796,(140944|0))|0);
                 $3249 = __THREW__; __THREW__ = 0;
                 $3250 = $3249&1;
                 if ($3250) {
                  break;
                 } else {
                  $$in$i$i2294 = $3248;
                 }
                } else {
                 $$in$i$i2294 = $3244;
                }
                HEAP32[$3243>>2] = $$in$i$i2294;
                $3251 = ((($0)) + 1524|0);
                __THREW__ = 0;
                $3252 = (invoke_ii(3796,(140870|0))|0);
                $3253 = __THREW__; __THREW__ = 0;
                $3254 = $3253&1;
                if ($3254) {
                 break;
                }
                $3255 = ($3252|0)==(0|0);
                if ($3255) {
                 __THREW__ = 0;
                 $3256 = (invoke_ii(3796,(140892|0))|0);
                 $3257 = __THREW__; __THREW__ = 0;
                 $3258 = $3257&1;
                 if ($3258) {
                  break;
                 } else {
                  $$in$i$i2300 = $3256;
                 }
                } else {
                 $$in$i$i2300 = $3252;
                }
                HEAP32[$3251>>2] = $$in$i$i2300;
                $3259 = ((($0)) + 1528|0);
                __THREW__ = 0;
                $3260 = (invoke_ii(3796,(140870|0))|0);
                $3261 = __THREW__; __THREW__ = 0;
                $3262 = $3261&1;
                if ($3262) {
                 break;
                }
                $3263 = ($3260|0)==(0|0);
                if ($3263) {
                 __THREW__ = 0;
                 $3264 = (invoke_ii(3796,(140892|0))|0);
                 $3265 = __THREW__; __THREW__ = 0;
                 $3266 = $3265&1;
                 if ($3266) {
                  break;
                 } else {
                  $$in$i$i2305 = $3264;
                 }
                } else {
                 $$in$i$i2305 = $3260;
                }
                HEAP32[$3259>>2] = $$in$i$i2305;
                $3267 = ((($0)) + 1532|0);
                __THREW__ = 0;
                $3268 = (invoke_ii(3796,(140974|0))|0);
                $3269 = __THREW__; __THREW__ = 0;
                $3270 = $3269&1;
                if ($3270) {
                 break;
                }
                $3271 = ($3268|0)==(0|0);
                if ($3271) {
                 __THREW__ = 0;
                 $3272 = (invoke_ii(3796,(140996|0))|0);
                 $3273 = __THREW__; __THREW__ = 0;
                 $3274 = $3273&1;
                 if ($3274) {
                  break;
                 } else {
                  $$in$i$i2310 = $3272;
                 }
                } else {
                 $$in$i$i2310 = $3268;
                }
                HEAP32[$3267>>2] = $$in$i$i2310;
                $3275 = ((($0)) + 1536|0);
                __THREW__ = 0;
                $3276 = (invoke_ii(3796,(141021|0))|0);
                $3277 = __THREW__; __THREW__ = 0;
                $3278 = $3277&1;
                if ($3278) {
                 break;
                }
                $3279 = ($3276|0)==(0|0);
                if ($3279) {
                 __THREW__ = 0;
                 $3280 = (invoke_ii(3796,(141047|0))|0);
                 $3281 = __THREW__; __THREW__ = 0;
                 $3282 = $3281&1;
                 if ($3282) {
                  break;
                 } else {
                  $$in$i$i2316 = $3280;
                 }
                } else {
                 $$in$i$i2316 = $3276;
                }
                HEAP32[$3275>>2] = $$in$i$i2316;
                $3283 = ((($0)) + 1540|0);
                __THREW__ = 0;
                $3284 = (invoke_ii(3796,(141076|0))|0);
                $3285 = __THREW__; __THREW__ = 0;
                $3286 = $3285&1;
                if ($3286) {
                 break;
                }
                $3287 = ($3284|0)==(0|0);
                if ($3287) {
                 __THREW__ = 0;
                 $3288 = (invoke_ii(3796,(141103|0))|0);
                 $3289 = __THREW__; __THREW__ = 0;
                 $3290 = $3289&1;
                 if ($3290) {
                  break;
                 } else {
                  $$in$i$i2321 = $3288;
                 }
                } else {
                 $$in$i$i2321 = $3284;
                }
                HEAP32[$3283>>2] = $$in$i$i2321;
                $3291 = ((($0)) + 1544|0);
                __THREW__ = 0;
                $3292 = (invoke_ii(3796,(141133|0))|0);
                $3293 = __THREW__; __THREW__ = 0;
                $3294 = $3293&1;
                if ($3294) {
                 break;
                }
                $3295 = ($3292|0)==(0|0);
                if ($3295) {
                 __THREW__ = 0;
                 $3296 = (invoke_ii(3796,(141160|0))|0);
                 $3297 = __THREW__; __THREW__ = 0;
                 $3298 = $3297&1;
                 if ($3298) {
                  break;
                 } else {
                  $$in$i$i2326 = $3296;
                 }
                } else {
                 $$in$i$i2326 = $3292;
                }
                HEAP32[$3291>>2] = $$in$i$i2326;
                __THREW__ = 0;
                $3302 = (invoke_ii(3796,(141190|0))|0);
                $3303 = __THREW__; __THREW__ = 0;
                $3304 = $3303&1;
                if ($3304) {
                 break;
                }
                $3305 = ($3302|0)==(0|0);
                if ($3305) {
                 __THREW__ = 0;
                 $3306 = (invoke_ii(3796,(141208|0))|0);
                 $3307 = __THREW__; __THREW__ = 0;
                 $3308 = $3307&1;
                 if ($3308) {
                  break;
                 } else {
                  $$in$i$i2332 = $3306;
                 }
                } else {
                 $$in$i$i2332 = $3302;
                }
                $3310 = $$in$i$i2332;
               } else {
                $3299 = ((($0)) + 1253|0);
                HEAP8[$3299>>0] = 0;
                $3300 = ((($0)) + 1336|0);
                $3301 = ((($0)) + 1508|0);
                _memset(($3300|0),0,169)|0;
                dest=$3301; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
                $3310 = 0;
               }
               $3309 = ((($0)) + 1548|0);
               HEAP32[$3309>>2] = $3310;
               $3311 = ((($0)) + 1552|0);
               __THREW__ = 0;
               $3312 = (invoke_ii(3796,(141229|0))|0);
               $3313 = __THREW__; __THREW__ = 0;
               $3314 = $3313&1;
               if ($3314) {
                break;
               }
               $3315 = ($3312|0)==(0|0);
               if ($3315) {
                __THREW__ = 0;
                $3316 = (invoke_ii(3796,(141249|0))|0);
                $3317 = __THREW__; __THREW__ = 0;
                $3318 = $3317&1;
                if ($3318) {
                 break;
                } else {
                 $$in$i$i2337 = $3316;
                }
               } else {
                $$in$i$i2337 = $3312;
               }
               HEAP32[$3311>>2] = $$in$i$i2337;
               $3319 = ((($0)) + 1588|0);
               __THREW__ = 0;
               $3320 = (invoke_ii(3796,(141272|0))|0);
               $3321 = __THREW__; __THREW__ = 0;
               $3322 = $3321&1;
               if ($3322) {
                break;
               }
               $3323 = ($3320|0)==(0|0);
               if ($3323) {
                __THREW__ = 0;
                $3324 = (invoke_ii(3796,(141306|0))|0);
                $3325 = __THREW__; __THREW__ = 0;
                $3326 = $3325&1;
                if ($3326) {
                 break;
                } else {
                 $$in$i$i2342 = $3324;
                }
               } else {
                $$in$i$i2342 = $3320;
               }
               HEAP32[$3319>>2] = $$in$i$i2342;
               $3327 = ((($0)) + 1592|0);
               __THREW__ = 0;
               $3328 = (invoke_ii(3796,(141343|0))|0);
               $3329 = __THREW__; __THREW__ = 0;
               $3330 = $3329&1;
               if ($3330) {
                break;
               }
               $3331 = ($3328|0)==(0|0);
               if ($3331) {
                __THREW__ = 0;
                $3332 = (invoke_ii(3796,(141379|0))|0);
                $3333 = __THREW__; __THREW__ = 0;
                $3334 = $3333&1;
                if ($3334) {
                 break;
                } else {
                 $$in$i$i2347 = $3332;
                }
               } else {
                $$in$i$i2347 = $3328;
               }
               HEAP32[$3327>>2] = $$in$i$i2347;
               $3335 = ((($0)) + 1596|0);
               __THREW__ = 0;
               $3336 = (invoke_ii(3796,(141418|0))|0);
               $3337 = __THREW__; __THREW__ = 0;
               $3338 = $3337&1;
               if ($3338) {
                break;
               }
               $3339 = ($3336|0)==(0|0);
               if ($3339) {
                __THREW__ = 0;
                $3340 = (invoke_ii(3796,(141464|0))|0);
                $3341 = __THREW__; __THREW__ = 0;
                $3342 = $3341&1;
                if ($3342) {
                 break;
                } else {
                 $$in$i$i2352 = $3340;
                }
               } else {
                $$in$i$i2352 = $3336;
               }
               HEAP32[$3335>>2] = $$in$i$i2352;
               __THREW__ = 0;
               $3343 = (invoke_ii(3796,(197778|0))|0);
               $3344 = __THREW__; __THREW__ = 0;
               $3345 = $3344&1;
               if ($3345) {
                break;
               }
               $3346 = ((($0)) + 1560|0);
               HEAP32[$3346>>2] = $3343;
               $3347 = ((($0)) + 1564|0);
               __THREW__ = 0;
               $3348 = (invoke_ii(3796,(141513|0))|0);
               $3349 = __THREW__; __THREW__ = 0;
               $3350 = $3349&1;
               if ($3350) {
                break;
               }
               $3351 = ($3348|0)==(0|0);
               if ($3351) {
                __THREW__ = 0;
                $3352 = (invoke_ii(3796,(141538|0))|0);
                $3353 = __THREW__; __THREW__ = 0;
                $3354 = $3353&1;
                if ($3354) {
                 break;
                } else {
                 $$in$i$i2359 = $3352;
                }
               } else {
                $$in$i$i2359 = $3348;
               }
               HEAP32[$3347>>2] = $$in$i$i2359;
               $3355 = ((($0)) + 1572|0);
               __THREW__ = 0;
               $3356 = (invoke_ii(3796,(141566|0))|0);
               $3357 = __THREW__; __THREW__ = 0;
               $3358 = $3357&1;
               if ($3358) {
                break;
               }
               $3359 = ($3356|0)==(0|0);
               if ($3359) {
                __THREW__ = 0;
                $3360 = (invoke_ii(3796,(141596|0))|0);
                $3361 = __THREW__; __THREW__ = 0;
                $3362 = $3361&1;
                if ($3362) {
                 break;
                } else {
                 $$in$i$i2364 = $3360;
                }
               } else {
                $$in$i$i2364 = $3356;
               }
               HEAP32[$3355>>2] = $$in$i$i2364;
               $3363 = ((($0)) + 1568|0);
               __THREW__ = 0;
               $3364 = (invoke_ii(3796,(141629|0))|0);
               $3365 = __THREW__; __THREW__ = 0;
               $3366 = $3365&1;
               if ($3366) {
                break;
               }
               $3367 = ($3364|0)==(0|0);
               if ($3367) {
                __THREW__ = 0;
                $3368 = (invoke_ii(3796,(141663|0))|0);
                $3369 = __THREW__; __THREW__ = 0;
                $3370 = $3369&1;
                if ($3370) {
                 break;
                } else {
                 $$in$i$i2369 = $3368;
                }
               } else {
                $$in$i$i2369 = $3364;
               }
               HEAP32[$3363>>2] = $$in$i$i2369;
               $3371 = ((($0)) + 1556|0);
               __THREW__ = 0;
               $3372 = (invoke_ii(3796,(141700|0))|0);
               $3373 = __THREW__; __THREW__ = 0;
               $3374 = $3373&1;
               if ($3374) {
                break;
               }
               $3375 = ($3372|0)==(0|0);
               if ($3375) {
                __THREW__ = 0;
                $3376 = (invoke_ii(3796,(141730|0))|0);
                $3377 = __THREW__; __THREW__ = 0;
                $3378 = $3377&1;
                if ($3378) {
                 break;
                } else {
                 $$in$i$i2374 = $3376;
                }
               } else {
                $$in$i$i2374 = $3372;
               }
               HEAP32[$3371>>2] = $$in$i$i2374;
               $3379 = ((($0)) + 1576|0);
               __THREW__ = 0;
               $3380 = (invoke_ii(3796,(141763|0))|0);
               $3381 = __THREW__; __THREW__ = 0;
               $3382 = $3381&1;
               if ($3382) {
                break;
               }
               $3383 = ($3380|0)==(0|0);
               if ($3383) {
                __THREW__ = 0;
                $3384 = (invoke_ii(3796,(141781|0))|0);
                $3385 = __THREW__; __THREW__ = 0;
                $3386 = $3385&1;
                if ($3386) {
                 break;
                } else {
                 $$in$i$i2379 = $3384;
                }
               } else {
                $$in$i$i2379 = $3380;
               }
               HEAP32[$3379>>2] = $$in$i$i2379;
               __THREW__ = 0;
               $3387 = (invoke_ii(3796,(136859|0))|0);
               $3388 = __THREW__; __THREW__ = 0;
               $3389 = $3388&1;
               if ($3389) {
                break;
               }
               $3390 = ($3387|0)==(0|0);
               if ($3390) {
                __THREW__ = 0;
                $3391 = (invoke_ii(3796,(141802|0))|0);
                $3392 = __THREW__; __THREW__ = 0;
                $3393 = $3392&1;
                if ($3393) {
                 break;
                } else {
                 $$in$i$i2385 = $3391;
                }
               } else {
                $$in$i$i2385 = $3387;
               }
               HEAP32[$2365>>2] = $$in$i$i2385;
               __THREW__ = 0;
               $3394 = (invoke_ii(3796,(136912|0))|0);
               $3395 = __THREW__; __THREW__ = 0;
               $3396 = $3395&1;
               if ($3396) {
                break;
               }
               $3397 = ($3394|0)==(0|0);
               if ($3397) {
                __THREW__ = 0;
                $3398 = (invoke_ii(3796,(141830|0))|0);
                $3399 = __THREW__; __THREW__ = 0;
                $3400 = $3399&1;
                if ($3400) {
                 break;
                } else {
                 $$in$i$i2391 = $3398;
                }
               } else {
                $$in$i$i2391 = $3394;
               }
               HEAP32[$2373>>2] = $$in$i$i2391;
               if ($10) {
                $3401 = HEAP32[$6>>2]|0;
                __THREW__ = 0;
                $3402 = (invoke_iiid(3793,($3401|0),(141856|0),4.0999999046325684)|0);
                $3403 = __THREW__; __THREW__ = 0;
                $3404 = $3403&1;
                if ($3404) {
                 break;
                }
                $3405 = ((($0)) + 1600|0);
                $3406 = $3402&1;
                HEAP8[$3405>>0] = $3406;
                __THREW__ = 0;
                $3407 = (invoke_ii(3796,(141878|0))|0);
                $3408 = __THREW__; __THREW__ = 0;
                $3409 = $3408&1;
                if ($3409) {
                 break;
                }
                $3410 = ((($0)) + 1604|0);
                HEAP32[$3410>>2] = $3407;
                __THREW__ = 0;
                $3411 = (invoke_ii(3796,(141895|0))|0);
                $3412 = __THREW__; __THREW__ = 0;
                $3413 = $3412&1;
                if ($3413) {
                 break;
                }
                $3414 = ((($0)) + 1608|0);
                HEAP32[$3414>>2] = $3411;
                __THREW__ = 0;
                $3415 = (invoke_ii(3796,(141914|0))|0);
                $3416 = __THREW__; __THREW__ = 0;
                $3417 = $3416&1;
                if ($3417) {
                 break;
                }
                $3418 = ((($0)) + 1612|0);
                HEAP32[$3418>>2] = $3415;
                __THREW__ = 0;
                $3419 = (invoke_ii(3796,(141934|0))|0);
                $3420 = __THREW__; __THREW__ = 0;
                $3421 = $3420&1;
                if ($3421) {
                 break;
                }
                $3422 = ((($0)) + 1616|0);
                HEAP32[$3422>>2] = $3419;
                __THREW__ = 0;
                $3423 = (invoke_ii(3796,(141950|0))|0);
                $3424 = __THREW__; __THREW__ = 0;
                $3425 = $3424&1;
                if ($3425) {
                 break;
                }
                $3426 = ((($0)) + 1620|0);
                HEAP32[$3426>>2] = $3423;
                __THREW__ = 0;
                $3427 = (invoke_ii(3796,(141967|0))|0);
                $3428 = __THREW__; __THREW__ = 0;
                $3429 = $3428&1;
                if ($3429) {
                 break;
                }
                $3430 = ((($0)) + 1624|0);
                HEAP32[$3430>>2] = $3427;
                __THREW__ = 0;
                $3431 = (invoke_ii(3796,(141985|0))|0);
                $3432 = __THREW__; __THREW__ = 0;
                $3433 = $3432&1;
                if ($3433) {
                 break;
                }
                $3434 = ((($0)) + 1628|0);
                HEAP32[$3434>>2] = $3431;
                __THREW__ = 0;
                $3435 = (invoke_ii(3796,(142004|0))|0);
                $3436 = __THREW__; __THREW__ = 0;
                $3437 = $3436&1;
                if ($3437) {
                 break;
                }
                $3438 = ((($0)) + 1632|0);
                HEAP32[$3438>>2] = $3435;
                $3439 = ((($0)) + 1636|0);
                __THREW__ = 0;
                $3440 = (invoke_ii(3796,(142024|0))|0);
                $3441 = __THREW__; __THREW__ = 0;
                $3442 = $3441&1;
                if ($3442) {
                 break;
                }
                $3443 = ($3440|0)==(0|0);
                if ($3443) {
                 __THREW__ = 0;
                 $3444 = (invoke_ii(3796,(142048|0))|0);
                 $3445 = __THREW__; __THREW__ = 0;
                 $3446 = $3445&1;
                 if ($3446) {
                  break;
                 } else {
                  $$in$i$i2417 = $3444;
                 }
                } else {
                 $$in$i$i2417 = $3440;
                }
                HEAP32[$3439>>2] = $$in$i$i2417;
                __THREW__ = 0;
                $3447 = (invoke_ii(3796,(142071|0))|0);
                $3448 = __THREW__; __THREW__ = 0;
                $3449 = $3448&1;
                if ($3449) {
                 break;
                }
                $3450 = ((($0)) + 1640|0);
                HEAP32[$3450>>2] = $3447;
                __THREW__ = 0;
                $3451 = (invoke_ii(3796,(142085|0))|0);
                $3452 = __THREW__; __THREW__ = 0;
                $3453 = $3452&1;
                if ($3453) {
                 break;
                }
                $3454 = ((($0)) + 1644|0);
                HEAP32[$3454>>2] = $3451;
                __THREW__ = 0;
                $3455 = (invoke_ii(3796,(142100|0))|0);
                $3456 = __THREW__; __THREW__ = 0;
                $3457 = $3456&1;
                if ($3457) {
                 break;
                }
                $3458 = ((($0)) + 1648|0);
                HEAP32[$3458>>2] = $3455;
                __THREW__ = 0;
                $3459 = (invoke_ii(3796,(142124|0))|0);
                $3460 = __THREW__; __THREW__ = 0;
                $3461 = $3460&1;
                if ($3461) {
                 break;
                }
                $3462 = ((($0)) + 1652|0);
                HEAP32[$3462>>2] = $3459;
                __THREW__ = 0;
                $3463 = (invoke_ii(3796,(142143|0))|0);
                $3464 = __THREW__; __THREW__ = 0;
                $3465 = $3464&1;
                if ($3465) {
                 break;
                }
                $3466 = ((($0)) + 1656|0);
                HEAP32[$3466>>2] = $3463;
                __THREW__ = 0;
                $3467 = (invoke_ii(3796,(142163|0))|0);
                $3468 = __THREW__; __THREW__ = 0;
                $3469 = $3468&1;
                if ($3469) {
                 break;
                }
                $3470 = ((($0)) + 1660|0);
                HEAP32[$3470>>2] = $3467;
                $3471 = ((($0)) + 1664|0);
                __THREW__ = 0;
                $3472 = (invoke_ii(3796,(197883|0))|0);
                $3473 = __THREW__; __THREW__ = 0;
                $3474 = $3473&1;
                if ($3474) {
                 break;
                }
                $3475 = ($3472|0)==(0|0);
                if ($3475) {
                 __THREW__ = 0;
                 $3476 = (invoke_ii(3796,(149252|0))|0);
                 $3477 = __THREW__; __THREW__ = 0;
                 $3478 = $3477&1;
                 if ($3478) {
                  break;
                 } else {
                  $$in$i$i2439 = $3476;
                 }
                } else {
                 $$in$i$i2439 = $3472;
                }
                HEAP32[$3471>>2] = $$in$i$i2439;
                $3479 = ((($0)) + 1668|0);
                __THREW__ = 0;
                $3480 = (invoke_ii(3796,(198446|0))|0);
                $3481 = __THREW__; __THREW__ = 0;
                $3482 = $3481&1;
                if ($3482) {
                 break;
                }
                $3483 = ($3480|0)==(0|0);
                if ($3483) {
                 __THREW__ = 0;
                 $3484 = (invoke_ii(3796,(149277|0))|0);
                 $3485 = __THREW__; __THREW__ = 0;
                 $3486 = $3485&1;
                 if ($3486) {
                  break;
                 } else {
                  $$in$i$i2445 = $3484;
                 }
                } else {
                 $$in$i$i2445 = $3480;
                }
                HEAP32[$3479>>2] = $$in$i$i2445;
                $3487 = ((($0)) + 1672|0);
                __THREW__ = 0;
                $3488 = (invoke_ii(3796,(149296|0))|0);
                $3489 = __THREW__; __THREW__ = 0;
                $3490 = $3489&1;
                if ($3490) {
                 break;
                }
                $3491 = ($3488|0)==(0|0);
                if ($3491) {
                 __THREW__ = 0;
                 $3492 = (invoke_ii(3796,(149314|0))|0);
                 $3493 = __THREW__; __THREW__ = 0;
                 $3494 = $3493&1;
                 if ($3494) {
                  break;
                 } else {
                  $$in$i$i2451 = $3492;
                 }
                } else {
                 $$in$i$i2451 = $3488;
                }
                HEAP32[$3487>>2] = $$in$i$i2451;
                $3495 = ((($0)) + 1676|0);
                __THREW__ = 0;
                $3496 = (invoke_ii(3796,(149335|0))|0);
                $3497 = __THREW__; __THREW__ = 0;
                $3498 = $3497&1;
                if ($3498) {
                 break;
                }
                $3499 = ($3496|0)==(0|0);
                if ($3499) {
                 __THREW__ = 0;
                 $3500 = (invoke_ii(3796,(149359|0))|0);
                 $3501 = __THREW__; __THREW__ = 0;
                 $3502 = $3501&1;
                 if ($3502) {
                  break;
                 } else {
                  $$in$i$i2456 = $3500;
                 }
                } else {
                 $$in$i$i2456 = $3496;
                }
                HEAP32[$3495>>2] = $$in$i$i2456;
                __THREW__ = 0;
                $3503 = (invoke_ii(3791,7938)|0);
                $3504 = __THREW__; __THREW__ = 0;
                $3505 = $3504&1;
                if ($3505) {
                 break;
                }
                $3506 = ($3503|0)==(0|0);
                if ($3506) {
                 label = 1196;
                } else {
                 __THREW__ = 0;
                 $3507 = (+invoke_di(3792,($3503|0)));
                 $3508 = __THREW__; __THREW__ = 0;
                 $3509 = $3508&1;
                 if ($3509) {
                  break;
                 }
                 $3510 = $3507;
                 $3511 = !($3510 >= 2.0);
                 if ($3511) {
                  label = 1196;
                 }
                }
                if ((label|0) == 1196) {
                 $3512 = HEAP32[$6>>2]|0;
                 __THREW__ = 0;
                 (invoke_iiid(3793,($3512|0),(149675|0),3.4028234663852886E+38)|0);
                 $3513 = __THREW__; __THREW__ = 0;
                 $3514 = $3513&1;
                 if ($3514) {
                  break;
                 }
                }
                $3515 = ((($0)) + 1684|0);
                __THREW__ = 0;
                invoke_vii(3797,35661,($3515|0));
                $3516 = __THREW__; __THREW__ = 0;
                $3517 = $3516&1;
                if ($3517) {
                 break;
                }
                $3520 = HEAP32[$3515>>2]|0;
                $3521 = ((($0)) + 1680|0);
                HEAP32[$3521>>2] = $3520;
                __THREW__ = 0;
                $3522 = (invoke_ii(3796,(142185|0))|0);
                $3523 = __THREW__; __THREW__ = 0;
                $3524 = $3523&1;
                if ($3524) {
                 break;
                }
                $3526 = $3522;
               } else {
                $3518 = ((($0)) + 1600|0);
                HEAP8[$3518>>0] = 0;
                $3519 = ((($0)) + 1604|0);
                dest=$3519; stop=dest+84|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
                $3526 = 0;
               }
               $3525 = ((($0)) + 1688|0);
               HEAP32[$3525>>2] = $3526;
               $3527 = HEAP8[$$pre$phi3226Z2D>>0]|0;
               $3528 = ($3527<<24>>24)<(0);
               if (!($3528)) {
                STACKTOP = sp;return;
               }
               $3529 = HEAP32[$5>>2]|0;
               __ZdlPv($3529);
               STACKTOP = sp;return;
              }
             } while(0);
             $2654 = ___cxa_find_matching_catch_2()|0;
             $2655 = tempRet0;
             $$sink549$sink556$index = $2654;$$sink549$sink556$index16 = $2655;
             break L876;
            }
           } while(0);
           $2207 = ___cxa_find_matching_catch_2()|0;
           $2208 = tempRet0;
           $$sink549$sink556$index = $2207;$$sink549$sink556$index16 = $2208;
          }
         } while(0);
         if ((label|0) == 721) {
          $2197 = ___cxa_find_matching_catch_2()|0;
          $2198 = tempRet0;
          $$sink549$sink556$index = $2197;$$sink549$sink556$index16 = $2198;
         }
         $3530 = HEAP8[$$pre$phi3226Z2D>>0]|0;
         $3531 = ($3530<<24>>24)<(0);
         if ($3531) {
          $3532 = HEAP32[$5>>2]|0;
          __ZdlPv($3532);
         }
         $$5 = $$sink549$sink556$index;$$5514 = $$sink549$sink556$index16;
         break L1;
        }
       } while(0);
       $2195 = ___cxa_find_matching_catch_2()|0;
       $2196 = tempRet0;
       $$5 = $2195;$$5514 = $2196;
       break L1;
      }
     }
    } while(0);
    if ((label|0) == 51) {
     $162 = ___cxa_find_matching_catch_2()|0;
     $163 = tempRet0;
     $eh$lpad$body606$index8Z2D = $163;$eh$lpad$body606$indexZ2D = $162;
    }
    $$5 = $eh$lpad$body606$indexZ2D;$$5514 = $eh$lpad$body606$index8Z2D;
    break;
   }
   $$5 = $eh$lpad$body$indexZ2D;$$5514 = $eh$lpad$body$index2Z2D;
  }
 } while(0);
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $3533 = __THREW__; __THREW__ = 0;
 $3534 = $3533&1;
 if ($3534) {
  $3535 = ___cxa_find_matching_catch_3(0|0)|0;
  $3536 = tempRet0;
  ___clang_call_terminate($3535);
  // unreachable;
 } else {
  ___resumeException($$5|0);
  // unreachable;
 }
}
function __ZN3osg12GLExtensionsD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZN3osg12GLExtensions3SetEjPS0_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[(208356)>>2]|0;
 $3 = HEAP32[52088]|0;
 $4 = (($2) - ($3))|0;
 $5 = $4 >> 2;
 $6 = ($5>>>0)>($0>>>0);
 L1: do {
  if (!($6)) {
   $7 = (($0) + 1)|0;
   $8 = ($7>>>0)>($5>>>0);
   $9 = $3;
   $10 = $2;
   if ($8) {
    $11 = (($7) - ($5))|0;
    __ZNSt3__26vectorIN3osg7ref_ptrINS1_12GLExtensionsEEENS_9allocatorIS4_EEE8__appendEj(208352,$11);
    break;
   }
   $12 = ($7>>>0)<($5>>>0);
   if ($12) {
    $13 = (($9) + ($7<<2)|0);
    $14 = ($10|0)==($13|0);
    if (!($14)) {
     $16 = $10;
     while(1) {
      $15 = ((($16)) + -4|0);
      HEAP32[(208356)>>2] = $15;
      $17 = HEAP32[$15>>2]|0;
      $18 = ($17|0)==(0|0);
      if (!($18)) {
       $19 = ((($17)) + 8|0);
       $20 = HEAP32[$19>>2]|0;HEAP32[$19>>2] = (($20-1)|0);
       $21 = ($20|0)==(1);
       if ($21) {
        __THREW__ = 0;
        invoke_viii(3262,($17|0),1,1);
        $22 = __THREW__; __THREW__ = 0;
        $23 = $22&1;
        if ($23) {
         break;
        }
       }
      }
      HEAP32[$15>>2] = 0;
      $24 = HEAP32[(208356)>>2]|0;
      $25 = ($24|0)==($13|0);
      if ($25) {
       break L1;
      } else {
       $16 = $24;
      }
     }
     $26 = ___cxa_find_matching_catch_2()|0;
     $27 = tempRet0;
     ___cxa_call_unexpected(($26|0));
     // unreachable;
    }
   }
  }
 } while(0);
 $28 = HEAP32[52088]|0;
 $29 = (($28) + ($0<<2)|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ($30|0)==($1|0);
 if ($31) {
  return;
 }
 HEAP32[$29>>2] = $1;
 $32 = ($1|0)==(0|0);
 if (!($32)) {
  $33 = ((($1)) + 8|0);
  $34 = HEAP32[$33>>2]|0;HEAP32[$33>>2] = (($34+1)|0);
 }
 $35 = ($30|0)==(0|0);
 if ($35) {
  return;
 }
 $36 = ((($30)) + 8|0);
 $37 = HEAP32[$36>>2]|0;HEAP32[$36>>2] = (($37-1)|0);
 $38 = ($37|0)==(1);
 if (!($38)) {
  return;
 }
 __ZNK3osg10Referenced24signalObserversAndDeleteEbb($30,1,1);
 return;
}
function __ZNK3osg12GLExtensions17getProgramInfoLogEjRNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$pre = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp + 4|0;
 $4 = sp;
 HEAP32[$3>>2] = 0;
 HEAP32[$4>>2] = 0;
 $5 = ((($0)) + 104|0);
 $6 = HEAP32[$5>>2]|0;
 FUNCTION_TABLE_viii[$6 & 8191]($1,35716,$3);
 $7 = HEAP32[$3>>2]|0;
 $8 = ($7|0)>(1);
 if (!($8)) {
  $14 = 0;
  STACKTOP = sp;return ($14|0);
 }
 $9 = (__Znaj($7)|0);
 $10 = ((($0)) + 112|0);
 $11 = HEAP32[$10>>2]|0;
 FUNCTION_TABLE_viiii[$11 & 8191]($1,$7,$4,$9);
 $12 = HEAP32[$4>>2]|0;
 $13 = ($12|0)>(0);
 if ($13) {
  (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($2,$9)|0);
 }
 __ZdaPv($9);
 $$pre = HEAP32[$4>>2]|0;
 $phitmp = ($$pre|0)>(0);
 $14 = $phitmp;
 STACKTOP = sp;return ($14|0);
}
function __ZNK3osg12GLExtensions16getShaderInfoLogEjRNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$pre = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp + 4|0;
 $4 = sp;
 HEAP32[$3>>2] = 0;
 HEAP32[$4>>2] = 0;
 $5 = ((($0)) + 120|0);
 $6 = HEAP32[$5>>2]|0;
 FUNCTION_TABLE_viii[$6 & 8191]($1,35716,$3);
 $7 = HEAP32[$3>>2]|0;
 $8 = ($7|0)>(1);
 if (!($8)) {
  $14 = 0;
  STACKTOP = sp;return ($14|0);
 }
 $9 = (__Znaj($7)|0);
 $10 = ((($0)) + 124|0);
 $11 = HEAP32[$10>>2]|0;
 FUNCTION_TABLE_viiii[$11 & 8191]($1,$7,$4,$9);
 $12 = HEAP32[$4>>2]|0;
 $13 = ($12|0)>(0);
 if ($13) {
  (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($2,$9)|0);
 }
 __ZdaPv($9);
 $$pre = HEAP32[$4>>2]|0;
 $phitmp = ($$pre|0)>(0);
 $14 = $phitmp;
 STACKTOP = sp;return ($14|0);
}
function __ZN3osg14GraphicsObjectD2Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg10ReferencedD2Ev($0);
 return;
}
function __ZN3osg14GraphicsObjectD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZN3osg21GraphicsObjectManagerD2Ev($0) {
 $0 = $0|0;
 var $$pre = 0, $$pre$phi11Z2D = 0, $$pre$phi17Z2D = 0, $$pre10 = 0, $$pre12 = 0, $$pre16 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 HEAP32[$0>>2] = (60188);
 __THREW__ = 0;
 $2 = (invoke_ii(3265,4)|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 L1: do {
  if ($4) {
   label = 19;
  } else {
   do {
    if ($2) {
     __THREW__ = 0;
     $5 = (invoke_ii(3266,4)|0);
     $6 = __THREW__; __THREW__ = 0;
     $7 = $6&1;
     if ($7) {
      label = 19;
      break L1;
     }
     $8 = ((($0)) + 12|0);
     $9 = ((($8)) + 11|0);
     $10 = HEAP8[$9>>0]|0;
     $11 = ($10<<24>>24)<(0);
     $12 = HEAP32[$8>>2]|0;
     $13 = $11 ? $12 : $8;
     $14 = ((($0)) + 16|0);
     $15 = HEAP32[$14>>2]|0;
     $16 = $10&255;
     $17 = $11 ? $15 : $16;
     __THREW__ = 0;
     $18 = (invoke_iiii(3267,($5|0),($13|0),($17|0))|0);
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      label = 19;
      break L1;
     }
     __THREW__ = 0;
     $21 = (invoke_iiii(3267,($18|0),(142243|0),3)|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      label = 19;
      break L1;
     }
     $24 = HEAP8[$9>>0]|0;
     $25 = ($24<<24>>24)<(0);
     $26 = HEAP32[$8>>2]|0;
     $27 = $25 ? $26 : $8;
     $28 = HEAP32[$14>>2]|0;
     $29 = $24&255;
     $30 = $25 ? $28 : $29;
     __THREW__ = 0;
     $31 = (invoke_iiii(3267,($21|0),($27|0),($30|0))|0);
     $32 = __THREW__; __THREW__ = 0;
     $33 = $32&1;
     if ($33) {
      label = 19;
      break L1;
     }
     __THREW__ = 0;
     $34 = (invoke_iiii(3267,($31|0),(142247|0),2)|0);
     $35 = __THREW__; __THREW__ = 0;
     $36 = $35&1;
     if ($36) {
      label = 19;
      break L1;
     }
     __THREW__ = 0;
     $37 = (invoke_iii(3275,($34|0),($0|0))|0);
     $38 = __THREW__; __THREW__ = 0;
     $39 = $38&1;
     if ($39) {
      label = 19;
      break L1;
     }
     $40 = HEAP32[$37>>2]|0;
     $41 = ((($40)) + -12|0);
     $42 = HEAP32[$41>>2]|0;
     $43 = (($37) + ($42)|0);
     __THREW__ = 0;
     invoke_vii(3257,($1|0),($43|0));
     $44 = __THREW__; __THREW__ = 0;
     $45 = $44&1;
     if ($45) {
      label = 19;
      break L1;
     }
     __THREW__ = 0;
     $46 = (invoke_iii(3255,($1|0),(215188|0))|0);
     $47 = __THREW__; __THREW__ = 0;
     $48 = $47&1;
     if (!($48)) {
      $49 = HEAP32[$46>>2]|0;
      $50 = ((($49)) + 28|0);
      $51 = HEAP32[$50>>2]|0;
      __THREW__ = 0;
      $52 = (invoke_iii($51|0,($46|0),10)|0);
      $53 = __THREW__; __THREW__ = 0;
      $54 = $53&1;
      if (!($54)) {
       __THREW__ = 0;
       invoke_vi(3263,($1|0));
       $61 = __THREW__; __THREW__ = 0;
       $62 = $61&1;
       if ($62) {
        label = 19;
        break L1;
       }
       __THREW__ = 0;
       (invoke_iii(3268,($37|0),($52|0))|0);
       $63 = __THREW__; __THREW__ = 0;
       $64 = $63&1;
       if ($64) {
        label = 19;
        break L1;
       }
       __THREW__ = 0;
       (invoke_ii(3269,($37|0))|0);
       $65 = __THREW__; __THREW__ = 0;
       $66 = $65&1;
       if ($66) {
        label = 19;
        break L1;
       } else {
        $$pre$phi17Z2D = $9;
        break;
       }
      }
     }
     $55 = ___cxa_find_matching_catch_2()|0;
     $56 = tempRet0;
     __THREW__ = 0;
     invoke_vi(3263,($1|0));
     $57 = __THREW__; __THREW__ = 0;
     $58 = $57&1;
     if ($58) {
      $59 = ___cxa_find_matching_catch_3(0|0)|0;
      $60 = tempRet0;
      ___clang_call_terminate($59);
      // unreachable;
     } else {
      $$pre$phi11Z2D = $9;$eh$lpad$body$index2Z2D = $56;$eh$lpad$body$indexZ2D = $55;
      break L1;
     }
    } else {
     $$pre12 = ((($0)) + 12|0);
     $$pre16 = ((($$pre12)) + 11|0);
     $$pre$phi17Z2D = $$pre16;
    }
   } while(0);
   $75 = HEAP8[$$pre$phi17Z2D>>0]|0;
   $76 = ($75<<24>>24)<(0);
   if (!($76)) {
    __ZN3osg10ReferencedD2Ev($0);
    STACKTOP = sp;return;
   }
   $77 = ((($0)) + 12|0);
   $78 = HEAP32[$77>>2]|0;
   __ZdlPv($78);
   __ZN3osg10ReferencedD2Ev($0);
   STACKTOP = sp;return;
  }
 } while(0);
 if ((label|0) == 19) {
  $67 = ___cxa_find_matching_catch_2()|0;
  $68 = tempRet0;
  $$pre = ((($0)) + 12|0);
  $$pre10 = ((($$pre)) + 11|0);
  $$pre$phi11Z2D = $$pre10;$eh$lpad$body$index2Z2D = $68;$eh$lpad$body$indexZ2D = $67;
 }
 $69 = HEAP8[$$pre$phi11Z2D>>0]|0;
 $70 = ($69<<24>>24)<(0);
 if ($70) {
  $71 = ((($0)) + 12|0);
  $72 = HEAP32[$71>>2]|0;
  __ZdlPv($72);
 }
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $73 = __THREW__; __THREW__ = 0;
 $74 = $73&1;
 if ($74) {
  $79 = ___cxa_find_matching_catch_3(0|0)|0;
  $80 = tempRet0;
  ___clang_call_terminate($79);
  // unreachable;
 } else {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
}
function __ZN3osg21GraphicsObjectManagerD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1861,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZN3osg15GLObjectManagerD2Ev($0) {
 $0 = $0|0;
 var $$023$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (60240);
 $1 = ((($0)) + 40|0);
 $2 = ((($0)) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if (!($4)) {
  $5 = ((($0)) + 44|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = HEAP32[$1>>2]|0;
  $8 = ((($7)) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = HEAP32[$6>>2]|0;
  $11 = ((($10)) + 4|0);
  HEAP32[$11>>2] = $9;
  $12 = HEAP32[$8>>2]|0;
  HEAP32[$12>>2] = $10;
  HEAP32[$2>>2] = 0;
  $13 = ($6|0)==($1|0);
  if (!($13)) {
   $$023$i$i = $6;
   while(1) {
    $14 = ((($$023$i$i)) + 4|0);
    $15 = HEAP32[$14>>2]|0;
    __ZdlPv($$023$i$i);
    $16 = ($15|0)==($1|0);
    if ($16) {
     break;
    } else {
     $$023$i$i = $15;
    }
   }
  }
 }
 $17 = ((($0)) + 28|0);
 __THREW__ = 0;
 invoke_vi(707,($17|0));
 $18 = __THREW__; __THREW__ = 0;
 $19 = $18&1;
 if (!($19)) {
  __ZN3osg21GraphicsObjectManagerD2Ev($0);
  return;
 }
 $20 = ___cxa_find_matching_catch_2()|0;
 $21 = tempRet0;
 __THREW__ = 0;
 invoke_vi(1861,($0|0));
 $22 = __THREW__; __THREW__ = 0;
 $23 = $22&1;
 if ($23) {
  $24 = ___cxa_find_matching_catch_3(0|0)|0;
  $25 = tempRet0;
  ___clang_call_terminate($24);
  // unreachable;
 } else {
  ___resumeException($20|0);
  // unreachable;
 }
}
function __ZN3osg15GLObjectManagerD0Ev($0) {
 $0 = $0|0;
 var $$023$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (60240);
 $1 = ((($0)) + 40|0);
 $2 = ((($0)) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if (!($4)) {
  $5 = ((($0)) + 44|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = HEAP32[$1>>2]|0;
  $8 = ((($7)) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = HEAP32[$6>>2]|0;
  $11 = ((($10)) + 4|0);
  HEAP32[$11>>2] = $9;
  $12 = HEAP32[$8>>2]|0;
  HEAP32[$12>>2] = $10;
  HEAP32[$2>>2] = 0;
  $13 = ($6|0)==($1|0);
  if (!($13)) {
   $$023$i$i$i = $6;
   while(1) {
    $14 = ((($$023$i$i$i)) + 4|0);
    $15 = HEAP32[$14>>2]|0;
    __ZdlPv($$023$i$i$i);
    $16 = ($15|0)==($1|0);
    if ($16) {
     break;
    } else {
     $$023$i$i$i = $15;
    }
   }
  }
 }
 $17 = ((($0)) + 28|0);
 __THREW__ = 0;
 invoke_vi(707,($17|0));
 $18 = __THREW__; __THREW__ = 0;
 $19 = $18&1;
 if ($19) {
  $22 = ___cxa_find_matching_catch_2()|0;
  $23 = tempRet0;
  __THREW__ = 0;
  invoke_vi(1861,($0|0));
  $24 = __THREW__; __THREW__ = 0;
  $25 = $24&1;
  if ($25) {
   $26 = ___cxa_find_matching_catch_3(0|0)|0;
   $27 = tempRet0;
   ___clang_call_terminate($26);
   // unreachable;
  } else {
   $eh$lpad$body$index2Z2D = $23;$eh$lpad$body$indexZ2D = $22;
   __ZdlPv($0);
   ___resumeException($eh$lpad$body$indexZ2D|0);
   // unreachable;
  }
 }
 __THREW__ = 0;
 invoke_vi(1861,($0|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if (!($21)) {
  __ZdlPv($0);
  return;
 }
 $28 = ___cxa_find_matching_catch_2()|0;
 $29 = tempRet0;
 $eh$lpad$body$index2Z2D = $29;$eh$lpad$body$indexZ2D = $28;
 __ZdlPv($0);
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
}
function __ZN3osg15GLObjectManager21flushDeletedGLObjectsEdRd($0,$1,$2) {
 $0 = $0|0;
 $1 = +$1;
 $2 = $2|0;
 var $$0$lcssa = 0.0, $$sink$i = 0.0, $$sroa$027$040 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0.0, $18 = 0, $19 = 0, $20 = 0, $21 = 0.0, $22 = 0.0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0.0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0.0, $55 = 0, $56 = 0, $57 = 0.0, $58 = 0.0, $59 = 0.0, $6 = 0, $60 = 0.0, $61 = 0, $62 = 0;
 var $63 = 0.0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond39 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = +HEAPF64[$2>>3];
 $4 = !($3 <= 0.0);
 if (!($4)) {
  return;
 }
 $5 = (__ZN3osg5Timer8instanceEv()|0);
 $6 = (__ZNK3osg5Timer4tickEv($5)|0);
 $7 = tempRet0;
 $8 = ((($0)) + 28|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($9)) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 (FUNCTION_TABLE_ii[$11 & 8191]($8)|0);
 $12 = ((($0)) + 44|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($0)) + 40|0);
 $15 = $13;
 $16 = ($15|0)!=($14|0);
 $17 = +HEAPF64[$2>>3];
 $18 = $17 > 0.0;
 $or$cond39 = $16 & $18;
 L4: do {
  if ($or$cond39) {
   $19 = ((($0)) + 48|0);
   $20 = ((($5)) + 8|0);
   $$sroa$027$040 = $13;$35 = $15;
   while(1) {
    $26 = HEAP32[$0>>2]|0;
    $27 = ((($26)) + 52|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = $$sroa$027$040;
    $30 = ((($29)) + 8|0);
    $31 = HEAP32[$30>>2]|0;
    __THREW__ = 0;
    invoke_vii($28|0,($0|0),($31|0));
    $32 = __THREW__; __THREW__ = 0;
    $33 = $32&1;
    if ($33) {
     break;
    }
    $34 = ((($35)) + 4|0);
    $36 = HEAP32[$34>>2]|0;
    $37 = HEAP32[$35>>2]|0;
    $38 = ((($37)) + 4|0);
    HEAP32[$38>>2] = $36;
    $39 = HEAP32[$34>>2]|0;
    HEAP32[$39>>2] = $37;
    $40 = HEAP32[$19>>2]|0;
    $41 = (($40) + -1)|0;
    HEAP32[$19>>2] = $41;
    $42 = $$sroa$027$040;
    __ZdlPv($42);
    __THREW__ = 0;
    $43 = (invoke_ii(3385,($5|0))|0);
    $44 = tempRet0;
    $45 = __THREW__; __THREW__ = 0;
    $46 = $45&1;
    if ($46) {
     break;
    }
    $47 = ($44>>>0)>($7>>>0);
    $48 = ($43>>>0)>($6>>>0);
    $49 = ($44|0)==($7|0);
    $50 = $49 & $48;
    $51 = $47 | $50;
    if ($51) {
     $52 = (_i64Subtract(($43|0),($44|0),($6|0),($7|0))|0);
     $53 = tempRet0;
     $54 = (+($52>>>0)) + (4294967296.0*(+($53>>>0)));
     $$sink$i = $54;
    } else {
     $55 = (_i64Subtract(($6|0),($7|0),($43|0),($44|0))|0);
     $56 = tempRet0;
     $57 = (+($55>>>0)) + (4294967296.0*(+($56>>>0)));
     $58 = -$57;
     $$sink$i = $58;
    }
    $59 = +HEAPF64[$20>>3];
    $60 = $$sink$i * $59;
    $61 = $36;
    $62 = ($61|0)!=($14|0);
    $63 = +HEAPF64[$2>>3];
    $64 = $60 < $63;
    $or$cond = $62 & $64;
    if ($or$cond) {
     $$sroa$027$040 = $36;$35 = $61;
    } else {
     $$0$lcssa = $60;$22 = $63;
     break L4;
    }
   }
   $65 = ___cxa_find_matching_catch_2()|0;
   $66 = tempRet0;
   $67 = HEAP32[$8>>2]|0;
   $68 = ((($67)) + 12|0);
   $69 = HEAP32[$68>>2]|0;
   __THREW__ = 0;
   (invoke_ii($69|0,($8|0))|0);
   $70 = __THREW__; __THREW__ = 0;
   $71 = $70&1;
   if ($71) {
    $72 = ___cxa_find_matching_catch_3(0|0)|0;
    $73 = tempRet0;
    ___clang_call_terminate($72);
    // unreachable;
   } else {
    ___resumeException($65|0);
    // unreachable;
   }
  } else {
   $$0$lcssa = 0.0;$22 = $17;
  }
 } while(0);
 $21 = $22 - $$0$lcssa;
 HEAPF64[$2>>3] = $21;
 $23 = HEAP32[$8>>2]|0;
 $24 = ((($23)) + 12|0);
 $25 = HEAP32[$24>>2]|0;
 (FUNCTION_TABLE_ii[$25 & 8191]($8)|0);
 return;
}
function __ZN3osg15GLObjectManager24flushAllDeletedGLObjectsEv($0) {
 $0 = $0|0;
 var $$023$i$i = 0, $$sroa$05$0 = 0, $$sroa$05$016 = 0, $$sroa$05$017 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 (FUNCTION_TABLE_ii[$4 & 8191]($1)|0);
 $5 = ((($0)) + 40|0);
 $6 = ((($0)) + 44|0);
 $$sroa$05$016 = HEAP32[$6>>2]|0;
 $7 = $$sroa$05$016;
 $8 = ($7|0)==($5|0);
 L1: do {
  if (!($8)) {
   $$sroa$05$017 = $$sroa$05$016;$35 = $7;
   while(1) {
    $26 = HEAP32[$0>>2]|0;
    $27 = ((($26)) + 52|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = $$sroa$05$017;
    $30 = ((($29)) + 8|0);
    $31 = HEAP32[$30>>2]|0;
    __THREW__ = 0;
    invoke_vii($28|0,($0|0),($31|0));
    $32 = __THREW__; __THREW__ = 0;
    $33 = $32&1;
    if ($33) {
     break;
    }
    $34 = ((($35)) + 4|0);
    $$sroa$05$0 = HEAP32[$34>>2]|0;
    $36 = $$sroa$05$0;
    $37 = ($36|0)==($5|0);
    if ($37) {
     break L1;
    } else {
     $$sroa$05$017 = $$sroa$05$0;$35 = $36;
    }
   }
   $38 = ___cxa_find_matching_catch_2()|0;
   $39 = tempRet0;
   $40 = HEAP32[$1>>2]|0;
   $41 = ((($40)) + 12|0);
   $42 = HEAP32[$41>>2]|0;
   __THREW__ = 0;
   (invoke_ii($42|0,($1|0))|0);
   $43 = __THREW__; __THREW__ = 0;
   $44 = $43&1;
   if ($44) {
    $45 = ___cxa_find_matching_catch_3(0|0)|0;
    $46 = tempRet0;
    ___clang_call_terminate($45);
    // unreachable;
   } else {
    ___resumeException($38|0);
    // unreachable;
   }
  }
 } while(0);
 $9 = ((($0)) + 48|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0);
 if ($11) {
  $23 = HEAP32[$1>>2]|0;
  $24 = ((($23)) + 12|0);
  $25 = HEAP32[$24>>2]|0;
  (FUNCTION_TABLE_ii[$25 & 8191]($1)|0);
  return;
 }
 $12 = HEAP32[$6>>2]|0;
 $13 = HEAP32[$5>>2]|0;
 $14 = ((($13)) + 4|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP32[$12>>2]|0;
 $17 = ((($16)) + 4|0);
 HEAP32[$17>>2] = $15;
 $18 = HEAP32[$14>>2]|0;
 HEAP32[$18>>2] = $16;
 HEAP32[$9>>2] = 0;
 $19 = ($12|0)==($5|0);
 if ($19) {
  $23 = HEAP32[$1>>2]|0;
  $24 = ((($23)) + 12|0);
  $25 = HEAP32[$24>>2]|0;
  (FUNCTION_TABLE_ii[$25 & 8191]($1)|0);
  return;
 } else {
  $$023$i$i = $12;
 }
 while(1) {
  $20 = ((($$023$i$i)) + 4|0);
  $21 = HEAP32[$20>>2]|0;
  __ZdlPv($$023$i$i);
  $22 = ($21|0)==($5|0);
  if ($22) {
   break;
  } else {
   $$023$i$i = $21;
  }
 }
 $23 = HEAP32[$1>>2]|0;
 $24 = ((($23)) + 12|0);
 $25 = HEAP32[$24>>2]|0;
 (FUNCTION_TABLE_ii[$25 & 8191]($1)|0);
 return;
}
function __ZN3osg15GLObjectManager18deleteAllGLObjectsEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $2 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 $3 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
 $4 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($3,142280,5)|0);
 $5 = ((($0)) + 12|0);
 $6 = ((($5)) + 11|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = ($7<<24>>24)<(0);
 $9 = HEAP32[$5>>2]|0;
 $10 = $8 ? $9 : $5;
 $11 = ((($0)) + 16|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = $7&255;
 $14 = $8 ? $12 : $13;
 $15 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($4,$10,$14)|0);
 $16 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($15,142325,42)|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ((($17)) + -12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($16) + ($19)|0);
 __ZNKSt3__28ios_base6getlocEv($1,$20);
 __THREW__ = 0;
 $21 = (invoke_iii(3255,($1|0),(215188|0))|0);
 $22 = __THREW__; __THREW__ = 0;
 $23 = $22&1;
 if (!($23)) {
  $24 = HEAP32[$21>>2]|0;
  $25 = ((($24)) + 28|0);
  $26 = HEAP32[$25>>2]|0;
  __THREW__ = 0;
  $27 = (invoke_iii($26|0,($21|0),10)|0);
  $28 = __THREW__; __THREW__ = 0;
  $29 = $28&1;
  if (!($29)) {
   __ZNSt3__26localeD2Ev($1);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($16,$27)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($16)|0);
   STACKTOP = sp;return;
  }
 }
 $30 = ___cxa_find_matching_catch_2()|0;
 $31 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($1|0));
 $32 = __THREW__; __THREW__ = 0;
 $33 = $32&1;
 if ($33) {
  $34 = ___cxa_find_matching_catch_3(0|0)|0;
  $35 = tempRet0;
  ___clang_call_terminate($34);
  // unreachable;
 } else {
  ___resumeException($30|0);
  // unreachable;
 }
}
function __ZN3osg15GLObjectManager19discardAllGLObjectsEv($0) {
 $0 = $0|0;
 var $$023$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 (FUNCTION_TABLE_ii[$4 & 8191]($1)|0);
 $5 = ((($0)) + 40|0);
 $6 = ((($0)) + 48|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0);
 if (!($8)) {
  $9 = ((($0)) + 44|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = HEAP32[$5>>2]|0;
  $12 = ((($11)) + 4|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = HEAP32[$10>>2]|0;
  $15 = ((($14)) + 4|0);
  HEAP32[$15>>2] = $13;
  $16 = HEAP32[$12>>2]|0;
  HEAP32[$16>>2] = $14;
  HEAP32[$6>>2] = 0;
  $17 = ($10|0)==($5|0);
  if (!($17)) {
   $$023$i$i = $10;
   while(1) {
    $18 = ((($$023$i$i)) + 4|0);
    $19 = HEAP32[$18>>2]|0;
    __ZdlPv($$023$i$i);
    $20 = ($19|0)==($5|0);
    if ($20) {
     break;
    } else {
     $$023$i$i = $19;
    }
   }
  }
 }
 $21 = HEAP32[$1>>2]|0;
 $22 = ((($21)) + 12|0);
 $23 = HEAP32[$22>>2]|0;
 (FUNCTION_TABLE_ii[$23 & 8191]($1)|0);
 return;
}
function __ZN3osg15GLObjectManager27scheduleGLObjectForDeletionEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 (FUNCTION_TABLE_ii[$5 & 8191]($2)|0);
 $6 = ((($0)) + 40|0);
 __THREW__ = 0;
 $7 = (invoke_ii(3276,12)|0);
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if (!($9)) {
  $10 = ((($7)) + 8|0);
  HEAP32[$10>>2] = $1;
  $11 = ((($7)) + 4|0);
  HEAP32[$11>>2] = $6;
  $12 = HEAP32[$6>>2]|0;
  HEAP32[$7>>2] = $12;
  $13 = ((($12)) + 4|0);
  HEAP32[$13>>2] = $7;
  HEAP32[$6>>2] = $7;
  $14 = ((($0)) + 48|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (($15) + 1)|0;
  HEAP32[$14>>2] = $16;
  $17 = HEAP32[$2>>2]|0;
  $18 = ((($17)) + 12|0);
  $19 = HEAP32[$18>>2]|0;
  (FUNCTION_TABLE_ii[$19 & 8191]($2)|0);
  return;
 }
 $20 = ___cxa_find_matching_catch_2()|0;
 $21 = tempRet0;
 $22 = HEAP32[$2>>2]|0;
 $23 = ((($22)) + 12|0);
 $24 = HEAP32[$23>>2]|0;
 __THREW__ = 0;
 (invoke_ii($24|0,($2|0))|0);
 $25 = __THREW__; __THREW__ = 0;
 $26 = $25&1;
 if ($26) {
  $27 = ___cxa_find_matching_catch_3(0|0)|0;
  $28 = tempRet0;
  ___clang_call_terminate($27);
  // unreachable;
 } else {
  ___resumeException($20|0);
  // unreachable;
 }
}
function __ZN3osg15GLObjectManager14createGLObjectEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $2 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
 if (!($2)) {
  STACKTOP = sp;return 0;
 }
 $3 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
 $4 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($3,142280,5)|0);
 $5 = ((($0)) + 12|0);
 $6 = ((($5)) + 11|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = ($7<<24>>24)<(0);
 $9 = HEAP32[$5>>2]|0;
 $10 = $8 ? $9 : $5;
 $11 = ((($0)) + 16|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = $7&255;
 $14 = $8 ? $12 : $13;
 $15 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($4,$10,$14)|0);
 $16 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($15,142286,38)|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ((($17)) + -12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($16) + ($19)|0);
 __ZNKSt3__28ios_base6getlocEv($1,$20);
 __THREW__ = 0;
 $21 = (invoke_iii(3255,($1|0),(215188|0))|0);
 $22 = __THREW__; __THREW__ = 0;
 $23 = $22&1;
 if (!($23)) {
  $24 = HEAP32[$21>>2]|0;
  $25 = ((($24)) + 28|0);
  $26 = HEAP32[$25>>2]|0;
  __THREW__ = 0;
  $27 = (invoke_iii($26|0,($21|0),10)|0);
  $28 = __THREW__; __THREW__ = 0;
  $29 = $28&1;
  if (!($29)) {
   __ZNSt3__26localeD2Ev($1);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($16,$27)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($16)|0);
   STACKTOP = sp;return 0;
  }
 }
 $30 = ___cxa_find_matching_catch_2()|0;
 $31 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($1|0));
 $32 = __THREW__; __THREW__ = 0;
 $33 = $32&1;
 if ($33) {
  $34 = ___cxa_find_matching_catch_3(0|0)|0;
  $35 = tempRet0;
  ___clang_call_terminate($34);
  // unreachable;
 } else {
  ___resumeException($30|0);
  // unreachable;
 }
 return (0)|0;
}
function __ZN3osg21flushDeletedGLObjectsEjdRd($0,$1,$2) {
 $0 = $0|0;
 $1 = +$1;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (__ZN3osg14getContextDataEj($0)|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($4)) + 28|0);
 $6 = HEAP32[$5>>2]|0;
 FUNCTION_TABLE_vidi[$6 & 4095]($3,$1,$2);
 return;
}
function __ZN3osg24flushAllDeletedGLObjectsEj($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__ZN3osg14getContextDataEj($0)|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 32|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vi[$4 & 8191]($1);
 return;
}
function __ZN3osg18deleteAllGLObjectsEj($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__ZN3osg14getContextDataEj($0)|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 36|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vi[$4 & 8191]($1);
 return;
}
function __ZN3osg19discardAllGLObjectsEj($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__ZN3osg14getContextDataEj($0)|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 40|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vi[$4 & 8191]($1);
 return;
}
function __ZN3osg14GraphicsObjectC2Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg10ReferencedC2Ev($0);
 HEAP32[$0>>2] = (60168);
 return;
}
function __ZN3osg21GraphicsObjectManagerC2ERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEj($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$04 = 0, $$pre$phi12Z2D = 0, $$pre11 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 __ZN3osg10ReferencedC2Ev($0);
 HEAP32[$0>>2] = (60188);
 $4 = ((($0)) + 12|0);
 __THREW__ = 0;
 invoke_vii(3457,($4|0),($1|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $72 = ___cxa_find_matching_catch_2()|0;
  $73 = tempRet0;
  $$0 = $73;$$04 = $72;
 } else {
  $7 = ((($0)) + 24|0);
  HEAP32[$7>>2] = $2;
  __THREW__ = 0;
  $8 = (invoke_ii(3265,4)|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  do {
   if ($10) {
    label = 20;
   } else {
    if (!($8)) {
     STACKTOP = sp;return;
    }
    __THREW__ = 0;
    $11 = (invoke_ii(3266,4)|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     label = 20;
    } else {
     $14 = ((($4)) + 11|0);
     $15 = HEAP8[$14>>0]|0;
     $16 = ($15<<24>>24)<(0);
     $17 = HEAP32[$4>>2]|0;
     $18 = $16 ? $17 : $4;
     $19 = ((($0)) + 16|0);
     $20 = HEAP32[$19>>2]|0;
     $21 = $15&255;
     $22 = $16 ? $20 : $21;
     __THREW__ = 0;
     $23 = (invoke_iiii(3267,($11|0),($18|0),($22|0))|0);
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if ($25) {
      label = 20;
     } else {
      __THREW__ = 0;
      $26 = (invoke_iiii(3267,($23|0),(142392|0),2)|0);
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       label = 20;
      } else {
       $29 = HEAP8[$14>>0]|0;
       $30 = ($29<<24>>24)<(0);
       $31 = HEAP32[$4>>2]|0;
       $32 = $30 ? $31 : $4;
       $33 = HEAP32[$19>>2]|0;
       $34 = $29&255;
       $35 = $30 ? $33 : $34;
       __THREW__ = 0;
       $36 = (invoke_iiii(3267,($26|0),($32|0),($35|0))|0);
       $37 = __THREW__; __THREW__ = 0;
       $38 = $37&1;
       if ($38) {
        label = 20;
       } else {
        __THREW__ = 0;
        $39 = (invoke_iiii(3267,($36|0),(142247|0),2)|0);
        $40 = __THREW__; __THREW__ = 0;
        $41 = $40&1;
        if ($41) {
         label = 20;
        } else {
         __THREW__ = 0;
         $42 = (invoke_iii(3275,($39|0),($0|0))|0);
         $43 = __THREW__; __THREW__ = 0;
         $44 = $43&1;
         if ($44) {
          label = 20;
         } else {
          $45 = HEAP32[$42>>2]|0;
          $46 = ((($45)) + -12|0);
          $47 = HEAP32[$46>>2]|0;
          $48 = (($42) + ($47)|0);
          __THREW__ = 0;
          invoke_vii(3257,($3|0),($48|0));
          $49 = __THREW__; __THREW__ = 0;
          $50 = $49&1;
          if ($50) {
           label = 20;
          } else {
           __THREW__ = 0;
           $51 = (invoke_iii(3255,($3|0),(215188|0))|0);
           $52 = __THREW__; __THREW__ = 0;
           $53 = $52&1;
           if (!($53)) {
            $54 = HEAP32[$51>>2]|0;
            $55 = ((($54)) + 28|0);
            $56 = HEAP32[$55>>2]|0;
            __THREW__ = 0;
            $57 = (invoke_iii($56|0,($51|0),10)|0);
            $58 = __THREW__; __THREW__ = 0;
            $59 = $58&1;
            if (!($59)) {
             __THREW__ = 0;
             invoke_vi(3263,($3|0));
             $60 = __THREW__; __THREW__ = 0;
             $61 = $60&1;
             if ($61) {
              label = 20;
              break;
             }
             __THREW__ = 0;
             (invoke_iii(3268,($42|0),($57|0))|0);
             $68 = __THREW__; __THREW__ = 0;
             $69 = $68&1;
             if ($69) {
              label = 20;
              break;
             }
             __THREW__ = 0;
             (invoke_ii(3269,($42|0))|0);
             $70 = __THREW__; __THREW__ = 0;
             $71 = $70&1;
             if ($71) {
              label = 20;
              break;
             }
             STACKTOP = sp;return;
            }
           }
           $62 = ___cxa_find_matching_catch_2()|0;
           $63 = tempRet0;
           __THREW__ = 0;
           invoke_vi(3263,($3|0));
           $64 = __THREW__; __THREW__ = 0;
           $65 = $64&1;
           if ($65) {
            $66 = ___cxa_find_matching_catch_3(0|0)|0;
            $67 = tempRet0;
            ___clang_call_terminate($66);
            // unreachable;
           } else {
            $$pre$phi12Z2D = $14;$eh$lpad$body$index2Z2D = $63;$eh$lpad$body$indexZ2D = $62;
            break;
           }
          }
         }
        }
       }
      }
     }
    }
   }
  } while(0);
  if ((label|0) == 20) {
   $74 = ___cxa_find_matching_catch_2()|0;
   $75 = tempRet0;
   $$pre11 = ((($4)) + 11|0);
   $$pre$phi12Z2D = $$pre11;$eh$lpad$body$index2Z2D = $75;$eh$lpad$body$indexZ2D = $74;
  }
  $76 = HEAP8[$$pre$phi12Z2D>>0]|0;
  $77 = ($76<<24>>24)<(0);
  if ($77) {
   $78 = HEAP32[$4>>2]|0;
   __ZdlPv($78);
   $$0 = $eh$lpad$body$index2Z2D;$$04 = $eh$lpad$body$indexZ2D;
  } else {
   $$0 = $eh$lpad$body$index2Z2D;$$04 = $eh$lpad$body$indexZ2D;
  }
 }
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $79 = __THREW__; __THREW__ = 0;
 $80 = $79&1;
 if ($80) {
  $81 = ___cxa_find_matching_catch_3(0|0)|0;
  $82 = tempRet0;
  ___clang_call_terminate($81);
  // unreachable;
 } else {
  ___resumeException($$04|0);
  // unreachable;
 }
}
function __ZN3osg15GLObjectManagerC2ERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEj($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg21GraphicsObjectManagerC2ERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEj($0,$1,$2);
 HEAP32[$0>>2] = (60240);
 $3 = ((($0)) + 28|0);
 __THREW__ = 0;
 invoke_vii(3507,($3|0),0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = ((($0)) + 40|0);
  HEAP32[$6>>2] = $6;
  $7 = ((($0)) + 44|0);
  HEAP32[$7>>2] = $6;
  $8 = ((($0)) + 48|0);
  HEAP32[$8>>2] = 0;
  return;
 }
 $9 = ___cxa_find_matching_catch_2()|0;
 $10 = tempRet0;
 __THREW__ = 0;
 invoke_vi(1861,($0|0));
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if ($12) {
  $13 = ___cxa_find_matching_catch_3(0|0)|0;
  $14 = tempRet0;
  ___clang_call_terminate($13);
  // unreachable;
 } else {
  ___resumeException($9|0);
  // unreachable;
 }
}
function __ZN3osg21GraphicsCostEstimatorD2Ev($0) {
 $0 = $0|0;
 var $$0 = 0, $$02 = 0, $$1 = 0, $$13 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (60304);
 $1 = ((($0)) + 20|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  label = 4;
 } else {
  $4 = ((($2)) + 8|0);
  $5 = HEAP32[$4>>2]|0;HEAP32[$4>>2] = (($5-1)|0);
  $6 = ($5|0)==(1);
  if ($6) {
   __THREW__ = 0;
   invoke_viii(3262,($2|0),1,1);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $25 = ___cxa_find_matching_catch_2()|0;
    $26 = tempRet0;
    $27 = ((($0)) + 16|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = ($28|0)==(0|0);
    if (!($29)) {
     $30 = ((($28)) + 8|0);
     $31 = HEAP32[$30>>2]|0;HEAP32[$30>>2] = (($31-1)|0);
     $32 = ($31|0)==(1);
     if ($32) {
      __THREW__ = 0;
      invoke_viii(3262,($28|0),1,1);
      $33 = __THREW__; __THREW__ = 0;
      $34 = $33&1;
      if ($34) {
       $49 = ___cxa_find_matching_catch_3(0|0)|0;
       $50 = tempRet0;
       ___clang_call_terminate($49);
       // unreachable;
      }
     }
    }
    HEAP32[$27>>2] = 0;
    $$0 = $26;$$02 = $25;
    label = 17;
   } else {
    label = 4;
   }
  } else {
   label = 4;
  }
 }
 do {
  if ((label|0) == 4) {
   HEAP32[$1>>2] = 0;
   $9 = ((($0)) + 16|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($10|0)==(0|0);
   if (!($11)) {
    $12 = ((($10)) + 8|0);
    $13 = HEAP32[$12>>2]|0;HEAP32[$12>>2] = (($13-1)|0);
    $14 = ($13|0)==(1);
    if ($14) {
     __THREW__ = 0;
     invoke_viii(3262,($10|0),1,1);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      $35 = ___cxa_find_matching_catch_2()|0;
      $36 = tempRet0;
      $$0 = $36;$$02 = $35;
      label = 17;
      break;
     }
    }
   }
   HEAP32[$9>>2] = 0;
   $17 = ((($0)) + 12|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = ($18|0)==(0|0);
   if ($19) {
    HEAP32[$17>>2] = 0;
    __ZN3osg10ReferencedD2Ev($0);
    return;
   }
   $20 = ((($18)) + 8|0);
   $21 = HEAP32[$20>>2]|0;HEAP32[$20>>2] = (($21-1)|0);
   $22 = ($21|0)==(1);
   if (!($22)) {
    HEAP32[$17>>2] = 0;
    __ZN3osg10ReferencedD2Ev($0);
    return;
   }
   __THREW__ = 0;
   invoke_viii(3262,($18|0),1,1);
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if ($24) {
    $37 = ___cxa_find_matching_catch_2()|0;
    $38 = tempRet0;
    $$1 = $38;$$13 = $37;
    break;
   } else {
    HEAP32[$17>>2] = 0;
    __ZN3osg10ReferencedD2Ev($0);
    return;
   }
  }
 } while(0);
 if ((label|0) == 17) {
  $39 = ((($0)) + 12|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = ($40|0)==(0|0);
  if (!($41)) {
   $42 = ((($40)) + 8|0);
   $43 = HEAP32[$42>>2]|0;HEAP32[$42>>2] = (($43-1)|0);
   $44 = ($43|0)==(1);
   if ($44) {
    __THREW__ = 0;
    invoke_viii(3262,($40|0),1,1);
    $45 = __THREW__; __THREW__ = 0;
    $46 = $45&1;
    if ($46) {
     $49 = ___cxa_find_matching_catch_3(0|0)|0;
     $50 = tempRet0;
     ___clang_call_terminate($49);
     // unreachable;
    }
   }
  }
  HEAP32[$39>>2] = 0;
  $$1 = $$0;$$13 = $$02;
 }
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $47 = __THREW__; __THREW__ = 0;
 $48 = $47&1;
 if ($48) {
  $49 = ___cxa_find_matching_catch_3(0|0)|0;
  $50 = tempRet0;
  ___clang_call_terminate($49);
  // unreachable;
 } else {
  ___resumeException($$13|0);
  // unreachable;
 }
}
function __ZN3osg21GraphicsCostEstimatorD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1864,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZN3osg21GeometryCostEstimatorD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK3osg21GeometryCostEstimator19estimateCompileCostEPKNS_8GeometryE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$04967 = 0, $$05066 = 0, $$069 = 0, $$in = 0, $10 = 0, $100 = 0, $101 = 0.0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0.0, $107 = 0.0, $108 = 0.0, $109 = 0.0, $11 = 0, $110 = 0.0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0.0, $135 = 0.0, $136 = 0, $137 = 0, $138 = 0, $139 = 0.0, $14 = 0, $140 = 0.0, $141 = 0.0, $142 = 0.0, $143 = 0.0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0.0, $166 = 0.0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0.0, $171 = 0.0, $172 = 0.0, $173 = 0.0, $174 = 0.0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0.0, $195 = 0.0, $196 = 0, $197 = 0, $198 = 0, $199 = 0.0, $20 = 0.0, $200 = 0.0, $201 = 0.0, $202 = 0.0, $203 = 0.0, $204 = 0;
 var $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0.0, $212 = 0, $213 = 0.0, $214 = 0.0, $215 = 0.0, $216 = 0.0, $217 = 0, $218 = 0.0, $219 = 0.0, $22 = 0.0, $220 = 0.0, $221 = 0.0, $222 = 0.0;
 var $223 = 0.0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0.0, $28 = 0.0, $29 = 0.0, $3 = 0, $30 = 0.0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0.0, $4 = 0;
 var $40 = 0, $41 = 0.0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0.0, $47 = 0.0, $48 = 0.0, $49 = 0.0, $5 = 0, $50 = 0.0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0.0, $6 = 0, $60 = 0, $61 = 0.0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0.0, $67 = 0.0, $68 = 0.0, $69 = 0.0, $7 = 0, $70 = 0.0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0.0, $8 = 0, $80 = 0, $81 = 0.0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0.0, $87 = 0.0, $88 = 0.0, $89 = 0.0, $9 = 0, $90 = 0.0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0.0, $phitmp$i = 0.0, $phitmp$i51 = 0.0, $phitmp$i52 = 0.0, $phitmp$i53 = 0.0, $phitmp$i54 = 0.0, $phitmp$i55 = 0.0, $phitmp$i56 = 0.0, $phitmp$i57 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($2)) + 183|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)==(0);
 do {
  if ($5) {
   $6 = ((($2)) + 181|0);
   $7 = HEAP8[$6>>0]|0;
   $8 = ($7<<24>>24)==(0);
   if (!($8)) {
    $9 = ((($2)) + 180|0);
    $10 = HEAP8[$9>>0]|0;
    $11 = ($10<<24>>24)==(0);
    if (!($11)) {
     $217 = 1;
     break;
    }
   }
   ;HEAP32[$0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
   return;
  } else {
   $217 = 0;
  }
 } while(0);
 ;HEAP32[$0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
 $12 = ((($2)) + 228|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  $50 = 0.0;
 } else {
  $15 = HEAP32[$13>>2]|0;
  $16 = ((($15)) + 144|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = (FUNCTION_TABLE_ii[$17 & 8191]($13)|0);
  $19 = ((($1)) + 16|0);
  $20 = +HEAPF64[$19>>3];
  $21 = ((($1)) + 24|0);
  $22 = +HEAPF64[$21>>3];
  $23 = ((($1)) + 32|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = ($18>>>0)>($24>>>0);
  $26 = (($18) - ($24))|0;
  $phitmp$i55 = (+($26>>>0));
  $27 = $25 ? $phitmp$i55 : 0.0;
  $28 = $22 * $27;
  $29 = $20 + $28;
  $30 = $29 + 0.0;
  HEAPF64[$0>>3] = $30;
  $50 = $30;
 }
 $31 = ((($2)) + 232|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = ($32|0)==(0|0);
 if ($33) {
  $70 = $50;
 } else {
  $34 = HEAP32[$32>>2]|0;
  $35 = ((($34)) + 144|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = (FUNCTION_TABLE_ii[$36 & 8191]($32)|0);
  $38 = ((($1)) + 16|0);
  $39 = +HEAPF64[$38>>3];
  $40 = ((($1)) + 24|0);
  $41 = +HEAPF64[$40>>3];
  $42 = ((($1)) + 32|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = ($37>>>0)>($43>>>0);
  $45 = (($37) - ($43))|0;
  $phitmp$i57 = (+($45>>>0));
  $46 = $44 ? $phitmp$i57 : 0.0;
  $47 = $41 * $46;
  $48 = $39 + $47;
  $49 = $50 + $48;
  HEAPF64[$0>>3] = $49;
  $70 = $49;
 }
 $51 = ((($2)) + 236|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = ($52|0)==(0|0);
 if ($53) {
  $90 = $70;
 } else {
  $54 = HEAP32[$52>>2]|0;
  $55 = ((($54)) + 144|0);
  $56 = HEAP32[$55>>2]|0;
  $57 = (FUNCTION_TABLE_ii[$56 & 8191]($52)|0);
  $58 = ((($1)) + 16|0);
  $59 = +HEAPF64[$58>>3];
  $60 = ((($1)) + 24|0);
  $61 = +HEAPF64[$60>>3];
  $62 = ((($1)) + 32|0);
  $63 = HEAP32[$62>>2]|0;
  $64 = ($57>>>0)>($63>>>0);
  $65 = (($57) - ($63))|0;
  $phitmp$i56 = (+($65>>>0));
  $66 = $64 ? $phitmp$i56 : 0.0;
  $67 = $61 * $66;
  $68 = $59 + $67;
  $69 = $70 + $68;
  HEAPF64[$0>>3] = $69;
  $90 = $69;
 }
 $71 = ((($2)) + 240|0);
 $72 = HEAP32[$71>>2]|0;
 $73 = ($72|0)==(0|0);
 if ($73) {
  $110 = $90;
 } else {
  $74 = HEAP32[$72>>2]|0;
  $75 = ((($74)) + 144|0);
  $76 = HEAP32[$75>>2]|0;
  $77 = (FUNCTION_TABLE_ii[$76 & 8191]($72)|0);
  $78 = ((($1)) + 16|0);
  $79 = +HEAPF64[$78>>3];
  $80 = ((($1)) + 24|0);
  $81 = +HEAPF64[$80>>3];
  $82 = ((($1)) + 32|0);
  $83 = HEAP32[$82>>2]|0;
  $84 = ($77>>>0)>($83>>>0);
  $85 = (($77) - ($83))|0;
  $phitmp$i54 = (+($85>>>0));
  $86 = $84 ? $phitmp$i54 : 0.0;
  $87 = $81 * $86;
  $88 = $79 + $87;
  $89 = $90 + $88;
  HEAPF64[$0>>3] = $89;
  $110 = $89;
 }
 $91 = ((($2)) + 244|0);
 $92 = HEAP32[$91>>2]|0;
 $93 = ($92|0)==(0|0);
 if ($93) {
  $218 = $110;
 } else {
  $94 = HEAP32[$92>>2]|0;
  $95 = ((($94)) + 144|0);
  $96 = HEAP32[$95>>2]|0;
  $97 = (FUNCTION_TABLE_ii[$96 & 8191]($92)|0);
  $98 = ((($1)) + 16|0);
  $99 = +HEAPF64[$98>>3];
  $100 = ((($1)) + 24|0);
  $101 = +HEAPF64[$100>>3];
  $102 = ((($1)) + 32|0);
  $103 = HEAP32[$102>>2]|0;
  $104 = ($97>>>0)>($103>>>0);
  $105 = (($97) - ($103))|0;
  $phitmp$i53 = (+($105>>>0));
  $106 = $104 ? $phitmp$i53 : 0.0;
  $107 = $101 * $106;
  $108 = $99 + $107;
  $109 = $110 + $108;
  HEAPF64[$0>>3] = $109;
  $218 = $109;
 }
 $111 = ((($2)) + 248|0);
 $112 = ((($2)) + 252|0);
 $113 = HEAP32[$112>>2]|0;
 $114 = HEAP32[$111>>2]|0;
 $115 = ($113|0)==($114|0);
 if ($115) {
  $219 = $218;
 } else {
  $116 = ((($1)) + 16|0);
  $117 = ((($1)) + 24|0);
  $118 = ((($1)) + 32|0);
  $$069 = 0;$143 = $218;
  while(1) {
   $127 = (__ZNK3osg8Geometry16getTexCoordArrayEj($2,$$069)|0);
   $128 = ($127|0)==(0|0);
   if ($128) {
    $221 = $143;
   } else {
    $129 = (__ZNK3osg8Geometry16getTexCoordArrayEj($2,$$069)|0);
    $130 = HEAP32[$129>>2]|0;
    $131 = ((($130)) + 144|0);
    $132 = HEAP32[$131>>2]|0;
    $133 = (FUNCTION_TABLE_ii[$132 & 8191]($129)|0);
    $134 = +HEAPF64[$116>>3];
    $135 = +HEAPF64[$117>>3];
    $136 = HEAP32[$118>>2]|0;
    $137 = ($133>>>0)>($136>>>0);
    $138 = (($133) - ($136))|0;
    $phitmp$i52 = (+($138>>>0));
    $139 = $137 ? $phitmp$i52 : 0.0;
    $140 = $135 * $139;
    $141 = $134 + $140;
    $142 = $143 + $141;
    HEAPF64[$0>>3] = $142;
    $221 = $142;
   }
   $144 = (($$069) + 1)|0;
   $145 = HEAP32[$112>>2]|0;
   $146 = HEAP32[$111>>2]|0;
   $147 = (($145) - ($146))|0;
   $148 = $147 >> 2;
   $149 = ($144>>>0)<($148>>>0);
   if ($149) {
    $$069 = $144;$143 = $221;
   } else {
    $219 = $221;
    break;
   }
  }
 }
 $119 = ((($2)) + 260|0);
 $120 = ((($2)) + 264|0);
 $121 = HEAP32[$120>>2]|0;
 $122 = HEAP32[$119>>2]|0;
 $123 = ($121|0)==($122|0);
 if ($123) {
  $220 = $219;
 } else {
  $124 = ((($1)) + 16|0);
  $125 = ((($1)) + 24|0);
  $126 = ((($1)) + 32|0);
  $$04967 = 0;$174 = $219;
  while(1) {
   $158 = (__ZNK3osg8Geometry20getVertexAttribArrayEj($2,$$04967)|0);
   $159 = ($158|0)==(0|0);
   if ($159) {
    $222 = $174;
   } else {
    $160 = (__ZNK3osg8Geometry20getVertexAttribArrayEj($2,$$04967)|0);
    $161 = HEAP32[$160>>2]|0;
    $162 = ((($161)) + 144|0);
    $163 = HEAP32[$162>>2]|0;
    $164 = (FUNCTION_TABLE_ii[$163 & 8191]($160)|0);
    $165 = +HEAPF64[$124>>3];
    $166 = +HEAPF64[$125>>3];
    $167 = HEAP32[$126>>2]|0;
    $168 = ($164>>>0)>($167>>>0);
    $169 = (($164) - ($167))|0;
    $phitmp$i51 = (+($169>>>0));
    $170 = $168 ? $phitmp$i51 : 0.0;
    $171 = $166 * $170;
    $172 = $165 + $171;
    $173 = $174 + $172;
    HEAPF64[$0>>3] = $173;
    $222 = $173;
   }
   $175 = (($$04967) + 1)|0;
   $176 = HEAP32[$120>>2]|0;
   $177 = HEAP32[$119>>2]|0;
   $178 = (($176) - ($177))|0;
   $179 = $178 >> 2;
   $180 = ($175>>>0)<($179>>>0);
   if ($180) {
    $$04967 = $175;$174 = $222;
   } else {
    $220 = $222;
    break;
   }
  }
 }
 $150 = ((($2)) + 216|0);
 $151 = ((($2)) + 220|0);
 $152 = HEAP32[$151>>2]|0;
 $153 = HEAP32[$150>>2]|0;
 $154 = ($152|0)==($153|0);
 if ($154) {
  $215 = $220;
 } else {
  $155 = ((($1)) + 40|0);
  $156 = ((($1)) + 48|0);
  $157 = ((($1)) + 56|0);
  $$05066 = 0;$$in = $153;$203 = $220;
  while(1) {
   $181 = $$in;
   $182 = (($181) + ($$05066<<2)|0);
   $183 = HEAP32[$182>>2]|0;
   $184 = ($183|0)==(0|0);
   if ($184) {
    $223 = $203;
   } else {
    $185 = HEAP32[$183>>2]|0;
    $186 = ((($185)) + 180|0);
    $187 = HEAP32[$186>>2]|0;
    $188 = (FUNCTION_TABLE_ii[$187 & 8191]($183)|0);
    $189 = ($188|0)==(0|0);
    if ($189) {
     $223 = $203;
    } else {
     $190 = HEAP32[$188>>2]|0;
     $191 = ((($190)) + 144|0);
     $192 = HEAP32[$191>>2]|0;
     $193 = (FUNCTION_TABLE_ii[$192 & 8191]($188)|0);
     $194 = +HEAPF64[$155>>3];
     $195 = +HEAPF64[$156>>3];
     $196 = HEAP32[$157>>2]|0;
     $197 = ($193>>>0)>($196>>>0);
     $198 = (($193) - ($196))|0;
     $phitmp$i = (+($198>>>0));
     $199 = $197 ? $phitmp$i : 0.0;
     $200 = $195 * $199;
     $201 = $194 + $200;
     $202 = $203 + $201;
     HEAPF64[$0>>3] = $202;
     $223 = $202;
    }
   }
   $204 = (($$05066) + 1)|0;
   $205 = HEAP32[$151>>2]|0;
   $206 = HEAP32[$150>>2]|0;
   $207 = (($205) - ($206))|0;
   $208 = $207 >> 2;
   $209 = ($204>>>0)<($208>>>0);
   if ($209) {
    $$05066 = $204;$$in = $206;$203 = $223;
   } else {
    $215 = $223;
    break;
   }
  }
 }
 if (!($217)) {
  return;
 }
 $210 = ((($1)) + 112|0);
 $211 = +HEAPF64[$210>>3];
 $212 = ((($1)) + 120|0);
 $213 = +HEAPF64[$212>>3];
 $214 = $213 * $215;
 $216 = $211 + $214;
 HEAPF64[$0>>3] = $216;
 return;
}
function __ZN3osg20TextureCostEstimatorD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK3osg20TextureCostEstimator19estimateCompileCostEPKNS_7TextureE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$010 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0.0, $23 = 0.0, $24 = 0, $25 = 0, $26 = 0, $27 = 0.0, $28 = 0.0;
 var $29 = 0.0, $3 = 0, $30 = 0.0, $31 = 0.0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0.0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0.0, $7 = 0, $8 = 0, $9 = 0;
 var $phitmp$i = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 ;HEAP32[$0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
 $4 = HEAP32[$2>>2]|0;
 $5 = ((($4)) + 208|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_ii[$6 & 8191]($2)|0);
 $8 = ($7|0)==(0);
 if ($8) {
  $40 = 0.0;
 } else {
  $9 = ((($1)) + 16|0);
  $10 = ((($1)) + 24|0);
  $11 = ((($1)) + 32|0);
  $$010 = 0;$31 = 0.0;
  while(1) {
   $13 = HEAP32[$2>>2]|0;
   $14 = ((($13)) + 204|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_iii[$15 & 8191]($2,$$010)|0);
   $17 = ($16|0)==(0|0);
   if ($17) {
    $61 = $31;
   } else {
    $18 = HEAP32[$16>>2]|0;
    $19 = ((($18)) + 144|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = (FUNCTION_TABLE_ii[$20 & 8191]($16)|0);
    $22 = +HEAPF64[$9>>3];
    $23 = +HEAPF64[$10>>3];
    $24 = HEAP32[$11>>2]|0;
    $25 = ($21>>>0)>($24>>>0);
    $26 = (($21) - ($24))|0;
    $phitmp$i = (+($26>>>0));
    $27 = $25 ? $phitmp$i : 0.0;
    $28 = $23 * $27;
    $29 = $22 + $28;
    $30 = $31 + $29;
    HEAPF64[$0>>3] = $30;
    $61 = $30;
   }
   $32 = (($$010) + 1)|0;
   $33 = HEAP32[$2>>2]|0;
   $34 = ((($33)) + 208|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = (FUNCTION_TABLE_ii[$35 & 8191]($2)|0);
   $37 = ($32>>>0)<($36>>>0);
   if ($37) {
    $$010 = $32;$31 = $61;
   } else {
    $40 = $61;
    break;
   }
  }
 }
 $12 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
 if (!($12)) {
  STACKTOP = sp;return;
 }
 $38 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
 $39 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($38,142484,50)|0);
 $41 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEd($39,$40)|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ((($42)) + -12|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = (($41) + ($44)|0);
 __ZNKSt3__28ios_base6getlocEv($3,$45);
 __THREW__ = 0;
 $46 = (invoke_iii(3255,($3|0),(215188|0))|0);
 $47 = __THREW__; __THREW__ = 0;
 $48 = $47&1;
 if (!($48)) {
  $49 = HEAP32[$46>>2]|0;
  $50 = ((($49)) + 28|0);
  $51 = HEAP32[$50>>2]|0;
  __THREW__ = 0;
  $52 = (invoke_iii($51|0,($46|0),10)|0);
  $53 = __THREW__; __THREW__ = 0;
  $54 = $53&1;
  if (!($54)) {
   __ZNSt3__26localeD2Ev($3);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($41,$52)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($41)|0);
   STACKTOP = sp;return;
  }
 }
 $55 = ___cxa_find_matching_catch_2()|0;
 $56 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($3|0));
 $57 = __THREW__; __THREW__ = 0;
 $58 = $57&1;
 if ($58) {
  $59 = ___cxa_find_matching_catch_3(0|0)|0;
  $60 = tempRet0;
  ___clang_call_terminate($59);
  // unreachable;
 } else {
  ___resumeException($55|0);
  // unreachable;
 }
}
function __ZN3osg20ProgramCostEstimatorD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK3osg20ProgramCostEstimator19estimateCompileCostEPKNS_7ProgramE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 ;HEAP32[$0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
 return;
}
function __ZN3osg21GraphicsCostEstimatorC2Ev($0) {
 $0 = $0|0;
 var $$0 = 0, $$02 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg10ReferencedC2Ev($0);
 HEAP32[$0>>2] = (60304);
 $1 = ((($0)) + 12|0);
 HEAP32[$1>>2] = 0;
 $2 = ((($0)) + 16|0);
 HEAP32[$2>>2] = 0;
 $3 = ((($0)) + 20|0);
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 $4 = (invoke_ii(3276,128)|0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 do {
  if ($6) {
   label = 20;
  } else {
   __THREW__ = 0;
   invoke_vi(3282,($4|0));
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $74 = ___cxa_find_matching_catch_2()|0;
    $75 = tempRet0;
    __ZdlPv($4);
    $$0 = $75;$$02 = $74;
    break;
   }
   HEAP32[$4>>2] = (60324);
   $9 = ((($4)) + 16|0);
   $10 = ((($4)) + 24|0);
   $11 = ((($4)) + 32|0);
   $12 = ((($4)) + 40|0);
   $13 = ((($4)) + 48|0);
   $14 = ((($4)) + 56|0);
   $15 = ((($4)) + 64|0);
   $16 = ((($4)) + 72|0);
   $17 = ((($4)) + 80|0);
   $18 = ((($4)) + 88|0);
   $19 = ((($4)) + 96|0);
   $20 = ((($4)) + 104|0);
   HEAPF64[$9>>3] = 1.0000000000000001E-5;
   HEAPF64[$10>>3] = 1.0E-10;
   HEAP32[$11>>2] = 256;
   HEAPF64[$12>>3] = 1.0000000000000001E-5;
   HEAPF64[$13>>3] = 1.0E-10;
   HEAP32[$14>>2] = 256;
   HEAPF64[$15>>3] = 1.0000000000000001E-5;
   HEAPF64[$16>>3] = 1.9999999999999999E-11;
   HEAP32[$17>>2] = 256;
   HEAPF64[$18>>3] = 1.0000000000000001E-5;
   HEAPF64[$19>>3] = 1.9999999999999999E-11;
   HEAP32[$20>>2] = 256;
   $21 = ((($4)) + 112|0);
   HEAPF64[$21>>3] = 0.0;
   $22 = ((($4)) + 120|0);
   HEAPF64[$22>>3] = 10.0;
   $23 = HEAP32[$1>>2]|0;
   $24 = ($23|0)==($4|0);
   if (!($24)) {
    HEAP32[$1>>2] = $4;
    $25 = ((($4)) + 8|0);
    $26 = HEAP32[$25>>2]|0;HEAP32[$25>>2] = (($26+1)|0);
    $27 = ($23|0)==(0|0);
    if (!($27)) {
     $28 = ((($23)) + 8|0);
     $29 = HEAP32[$28>>2]|0;HEAP32[$28>>2] = (($29-1)|0);
     $30 = ($29|0)==(1);
     if ($30) {
      __THREW__ = 0;
      invoke_viii(3262,($23|0),1,1);
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if ($32) {
       label = 20;
       break;
      }
     }
    }
   }
   __THREW__ = 0;
   $33 = (invoke_ii(3276,64)|0);
   $34 = __THREW__; __THREW__ = 0;
   $35 = $34&1;
   if ($35) {
    label = 20;
   } else {
    __THREW__ = 0;
    invoke_vi(3282,($33|0));
    $36 = __THREW__; __THREW__ = 0;
    $37 = $36&1;
    if ($37) {
     $76 = ___cxa_find_matching_catch_2()|0;
     $77 = tempRet0;
     __ZdlPv($33);
     $$0 = $77;$$02 = $76;
     break;
    }
    HEAP32[$33>>2] = (60344);
    $38 = ((($33)) + 16|0);
    $39 = ((($33)) + 24|0);
    $40 = ((($33)) + 32|0);
    $41 = ((($33)) + 40|0);
    $42 = ((($33)) + 48|0);
    $43 = ((($33)) + 56|0);
    HEAPF64[$38>>3] = 1.0000000000000001E-5;
    HEAPF64[$39>>3] = 1.0E-10;
    HEAP32[$40>>2] = 256;
    HEAPF64[$41>>3] = 1.0000000000000001E-5;
    HEAPF64[$42>>3] = 1.9999999999999999E-11;
    HEAP32[$43>>2] = 256;
    $44 = HEAP32[$2>>2]|0;
    $45 = ($44|0)==($33|0);
    if (!($45)) {
     HEAP32[$2>>2] = $33;
     $46 = ((($33)) + 8|0);
     $47 = HEAP32[$46>>2]|0;HEAP32[$46>>2] = (($47+1)|0);
     $48 = ($44|0)==(0|0);
     if (!($48)) {
      $49 = ((($44)) + 8|0);
      $50 = HEAP32[$49>>2]|0;HEAP32[$49>>2] = (($50-1)|0);
      $51 = ($50|0)==(1);
      if ($51) {
       __THREW__ = 0;
       invoke_viii(3262,($44|0),1,1);
       $52 = __THREW__; __THREW__ = 0;
       $53 = $52&1;
       if ($53) {
        label = 20;
        break;
       }
      }
     }
    }
    __THREW__ = 0;
    $54 = (invoke_ii(3276,88)|0);
    $55 = __THREW__; __THREW__ = 0;
    $56 = $55&1;
    if ($56) {
     label = 20;
    } else {
     __THREW__ = 0;
     invoke_vi(3282,($54|0));
     $57 = __THREW__; __THREW__ = 0;
     $58 = $57&1;
     if ($58) {
      $78 = ___cxa_find_matching_catch_2()|0;
      $79 = tempRet0;
      __ZdlPv($54);
      $$0 = $79;$$02 = $78;
      break;
     }
     HEAP32[$54>>2] = (60364);
     $59 = ((($54)) + 16|0);
     $60 = ((($54)) + 40|0);
     $61 = ((($54)) + 64|0);
     ;HEAP32[$59>>2]=0|0;HEAP32[$59+4>>2]=0|0;HEAP32[$59+8>>2]=0|0;HEAP32[$59+12>>2]=0|0;HEAP32[$59+16>>2]=0|0;
     ;HEAP32[$60>>2]=0|0;HEAP32[$60+4>>2]=0|0;HEAP32[$60+8>>2]=0|0;HEAP32[$60+12>>2]=0|0;HEAP32[$60+16>>2]=0|0;
     ;HEAP32[$61>>2]=0|0;HEAP32[$61+4>>2]=0|0;HEAP32[$61+8>>2]=0|0;HEAP32[$61+12>>2]=0|0;HEAP32[$61+16>>2]=0|0;
     $62 = HEAP32[$3>>2]|0;
     $63 = ($62|0)==($54|0);
     if ($63) {
      return;
     }
     HEAP32[$3>>2] = $54;
     $64 = ((($54)) + 8|0);
     $65 = HEAP32[$64>>2]|0;HEAP32[$64>>2] = (($65+1)|0);
     $66 = ($62|0)==(0|0);
     if ($66) {
      return;
     }
     $67 = ((($62)) + 8|0);
     $68 = HEAP32[$67>>2]|0;HEAP32[$67>>2] = (($68-1)|0);
     $69 = ($68|0)==(1);
     if (!($69)) {
      return;
     }
     __THREW__ = 0;
     invoke_viii(3262,($62|0),1,1);
     $70 = __THREW__; __THREW__ = 0;
     $71 = $70&1;
     if ($71) {
      label = 20;
     } else {
      return;
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 20) {
  $72 = ___cxa_find_matching_catch_2()|0;
  $73 = tempRet0;
  $$0 = $73;$$02 = $72;
 }
 $80 = HEAP32[$3>>2]|0;
 $81 = ($80|0)==(0|0);
 if (!($81)) {
  $82 = ((($80)) + 8|0);
  $83 = HEAP32[$82>>2]|0;HEAP32[$82>>2] = (($83-1)|0);
  $84 = ($83|0)==(1);
  if ($84) {
   __THREW__ = 0;
   invoke_viii(3262,($80|0),1,1);
   $85 = __THREW__; __THREW__ = 0;
   $86 = $85&1;
   if ($86) {
    $103 = ___cxa_find_matching_catch_3(0|0)|0;
    $104 = tempRet0;
    ___clang_call_terminate($103);
    // unreachable;
   }
  }
 }
 HEAP32[$3>>2] = 0;
 $87 = HEAP32[$2>>2]|0;
 $88 = ($87|0)==(0|0);
 if (!($88)) {
  $89 = ((($87)) + 8|0);
  $90 = HEAP32[$89>>2]|0;HEAP32[$89>>2] = (($90-1)|0);
  $91 = ($90|0)==(1);
  if ($91) {
   __THREW__ = 0;
   invoke_viii(3262,($87|0),1,1);
   $92 = __THREW__; __THREW__ = 0;
   $93 = $92&1;
   if ($93) {
    $103 = ___cxa_find_matching_catch_3(0|0)|0;
    $104 = tempRet0;
    ___clang_call_terminate($103);
    // unreachable;
   }
  }
 }
 HEAP32[$2>>2] = 0;
 $94 = HEAP32[$1>>2]|0;
 $95 = ($94|0)==(0|0);
 if (!($95)) {
  $96 = ((($94)) + 8|0);
  $97 = HEAP32[$96>>2]|0;HEAP32[$96>>2] = (($97-1)|0);
  $98 = ($97|0)==(1);
  if ($98) {
   __THREW__ = 0;
   invoke_viii(3262,($94|0),1,1);
   $99 = __THREW__; __THREW__ = 0;
   $100 = $99&1;
   if ($100) {
    $103 = ___cxa_find_matching_catch_3(0|0)|0;
    $104 = tempRet0;
    ___clang_call_terminate($103);
    // unreachable;
   }
  }
 }
 HEAP32[$1>>2] = 0;
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $101 = __THREW__; __THREW__ = 0;
 $102 = $101&1;
 if ($102) {
  $103 = ___cxa_find_matching_catch_3(0|0)|0;
  $104 = tempRet0;
  ___clang_call_terminate($103);
  // unreachable;
 } else {
  ___resumeException($$02|0);
  // unreachable;
 }
}
function __ZN3osg21GraphicsCostEstimator9calibrateERNS_10RenderInfoE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $4 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
 $5 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($4,142564,36)|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($6)) + -12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($5) + ($8)|0);
 __ZNKSt3__28ios_base6getlocEv($2,$9);
 __THREW__ = 0;
 $10 = (invoke_iii(3255,($2|0),(215188|0))|0);
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if (!($12)) {
  $13 = HEAP32[$10>>2]|0;
  $14 = ((($13)) + 28|0);
  $15 = HEAP32[$14>>2]|0;
  __THREW__ = 0;
  $16 = (invoke_iii($15|0,($10|0),10)|0);
  $17 = __THREW__; __THREW__ = 0;
  $18 = $17&1;
  if (!($18)) {
   __ZNSt3__26localeD2Ev($2);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($5,$16)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($5)|0);
   STACKTOP = sp;return;
  }
 }
 $19 = ___cxa_find_matching_catch_2()|0;
 $20 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($2|0));
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if ($22) {
  $23 = ___cxa_find_matching_catch_3(0|0)|0;
  $24 = tempRet0;
  ___clang_call_terminate($23);
  // unreachable;
 } else {
  ___resumeException($19|0);
  // unreachable;
 }
}
function __ZN3osg15GraphicsContext25WindowingSystemInterfacesD2Ev($0) {
 $0 = $0|0;
 var $$pre$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (60384);
 $1 = ((($0)) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  __ZN3osg10ReferencedD2Ev($0);
  return;
 }
 $4 = ((($0)) + 16|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==($2|0);
 do {
  if ($6) {
   $20 = $2;
  } else {
   $8 = $5;
   while(1) {
    $7 = ((($8)) + -4|0);
    HEAP32[$4>>2] = $7;
    $9 = HEAP32[$7>>2]|0;
    $10 = ($9|0)==(0|0);
    if (!($10)) {
     $11 = ((($9)) + 8|0);
     $12 = HEAP32[$11>>2]|0;HEAP32[$11>>2] = (($12-1)|0);
     $13 = ($12|0)==(1);
     if ($13) {
      __THREW__ = 0;
      invoke_viii(3262,($9|0),1,1);
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if ($15) {
       label = 7;
       break;
      }
     }
    }
    HEAP32[$7>>2] = 0;
    $16 = HEAP32[$4>>2]|0;
    $17 = ($16|0)==($2|0);
    if ($17) {
     label = 8;
     break;
    } else {
     $8 = $16;
    }
   }
   if ((label|0) == 7) {
    $18 = ___cxa_find_matching_catch_2()|0;
    $19 = tempRet0;
    ___cxa_call_unexpected(($18|0));
    // unreachable;
   }
   else if ((label|0) == 8) {
    $$pre$i = HEAP32[$1>>2]|0;
    $20 = $$pre$i;
    break;
   }
  }
 } while(0);
 __ZdlPv($20);
 __ZN3osg10ReferencedD2Ev($0);
 return;
}
function __ZN3osg15GraphicsContext25WindowingSystemInterfacesD0Ev($0) {
 $0 = $0|0;
 var $$pre$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (60384);
 $1 = ((($0)) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = ((($0)) + 16|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==($2|0);
  do {
   if ($6) {
    $20 = $2;
   } else {
    $8 = $5;
    while(1) {
     $7 = ((($8)) + -4|0);
     HEAP32[$4>>2] = $7;
     $9 = HEAP32[$7>>2]|0;
     $10 = ($9|0)==(0|0);
     if (!($10)) {
      $11 = ((($9)) + 8|0);
      $12 = HEAP32[$11>>2]|0;HEAP32[$11>>2] = (($12-1)|0);
      $13 = ($12|0)==(1);
      if ($13) {
       __THREW__ = 0;
       invoke_viii(3262,($9|0),1,1);
       $14 = __THREW__; __THREW__ = 0;
       $15 = $14&1;
       if ($15) {
        label = 7;
        break;
       }
      }
     }
     HEAP32[$7>>2] = 0;
     $16 = HEAP32[$4>>2]|0;
     $17 = ($16|0)==($2|0);
     if ($17) {
      label = 8;
      break;
     } else {
      $8 = $16;
     }
    }
    if ((label|0) == 7) {
     $18 = ___cxa_find_matching_catch_2()|0;
     $19 = tempRet0;
     ___cxa_call_unexpected(($18|0));
     // unreachable;
    }
    else if ((label|0) == 8) {
     $$pre$i$i = HEAP32[$1>>2]|0;
     $20 = $$pre$i$i;
     break;
    }
   }
  } while(0);
  __ZdlPv($20);
 }
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if ($22) {
  $23 = ___cxa_find_matching_catch_2()|0;
  $24 = tempRet0;
  __ZdlPv($0);
  ___resumeException($23|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZN3osg15GraphicsContextD2Ev($0) {
 $0 = $0|0;
 var $$0 = 0, $$02 = 0, $$023$i$i = 0, $$023$i$i18 = 0, $$023$i$i28 = 0, $$023$i$i37 = 0, $$1 = 0, $$13 = 0, $$2 = 0, $$24 = 0, $$3 = 0, $$35 = 0, $$5 = 0, $$57 = 0, $$6 = 0, $$68 = 0, $$7 = 0, $$79 = 0, $$8 = 0, $$810 = 0;
 var $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0;
 var $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0;
 var $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0;
 var $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0;
 var $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0;
 var $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0;
 var $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0;
 var $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0;
 var $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (60404);
 __THREW__ = 0;
 invoke_vii(3398,($0|0),0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if ($2) {
   label = 36;
  } else {
   __THREW__ = 0;
   invoke_vi(3798,($0|0));
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if ($4) {
    label = 36;
   } else {
    $5 = ((($0)) + 116|0);
    $6 = HEAP32[$5>>2]|0;
    $7 = ($6|0)==(0|0);
    if (!($7)) {
     $8 = ((($6)) + 8|0);
     $9 = HEAP32[$8>>2]|0;HEAP32[$8>>2] = (($9-1)|0);
     $10 = ($9|0)==(1);
     if ($10) {
      __THREW__ = 0;
      invoke_viii(3262,($6|0),1,1);
      $11 = __THREW__; __THREW__ = 0;
      $12 = $11&1;
      if ($12) {
       $128 = ___cxa_find_matching_catch_2()|0;
       $129 = tempRet0;
       $$0 = $129;$$02 = $128;
       label = 42;
       break;
      }
     }
    }
    HEAP32[$5>>2] = 0;
    $13 = ((($0)) + 112|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ($14|0)==(0|0);
    if (!($15)) {
     $16 = ((($14)) + 8|0);
     $17 = HEAP32[$16>>2]|0;HEAP32[$16>>2] = (($17-1)|0);
     $18 = ($17|0)==(1);
     if ($18) {
      __THREW__ = 0;
      invoke_viii(3262,($14|0),1,1);
      $19 = __THREW__; __THREW__ = 0;
      $20 = $19&1;
      if ($20) {
       $130 = ___cxa_find_matching_catch_2()|0;
       $131 = tempRet0;
       $$1 = $131;$$13 = $130;
       label = 47;
       break;
      }
     }
    }
    HEAP32[$13>>2] = 0;
    $21 = ((($0)) + 108|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = ($22|0)==(0|0);
    if (!($23)) {
     $24 = ((($22)) + 8|0);
     $25 = HEAP32[$24>>2]|0;HEAP32[$24>>2] = (($25-1)|0);
     $26 = ($25|0)==(1);
     if ($26) {
      __THREW__ = 0;
      invoke_viii(3262,($22|0),1,1);
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       $140 = ___cxa_find_matching_catch_2()|0;
       $141 = tempRet0;
       $$2 = $141;$$24 = $140;
       label = 52;
       break;
      }
     }
    }
    HEAP32[$21>>2] = 0;
    $29 = ((($0)) + 104|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = ($30|0)==(0|0);
    if (!($31)) {
     $32 = HEAP32[$30>>2]|0;
     $33 = ((($32)) + -12|0);
     $34 = HEAP32[$33>>2]|0;
     $35 = (($30) + ($34)|0);
     $36 = ((($35)) + 8|0);
     $37 = HEAP32[$36>>2]|0;HEAP32[$36>>2] = (($37-1)|0);
     $38 = ($37|0)==(1);
     if ($38) {
      __THREW__ = 0;
      invoke_viii(3262,($35|0),1,1);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if ($40) {
       $150 = ___cxa_find_matching_catch_2()|0;
       $151 = tempRet0;
       $$3 = $151;$$35 = $150;
       label = 56;
       break;
      }
     }
    }
    HEAP32[$29>>2] = 0;
    $41 = ((($0)) + 92|0);
    $42 = ((($0)) + 100|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = ($43|0)==(0);
    L24: do {
     if (!($44)) {
      $45 = ((($0)) + 96|0);
      $46 = HEAP32[$45>>2]|0;
      $47 = HEAP32[$41>>2]|0;
      $48 = ((($47)) + 4|0);
      $49 = HEAP32[$48>>2]|0;
      $50 = HEAP32[$46>>2]|0;
      $51 = ((($50)) + 4|0);
      HEAP32[$51>>2] = $49;
      $52 = HEAP32[$48>>2]|0;
      HEAP32[$52>>2] = $50;
      HEAP32[$42>>2] = 0;
      $53 = ($46|0)==($41|0);
      if (!($53)) {
       $$023$i$i = $46;
       while(1) {
        $54 = ((($$023$i$i)) + 4|0);
        $55 = HEAP32[$54>>2]|0;
        $56 = ((($$023$i$i)) + 8|0);
        $57 = HEAP32[$56>>2]|0;
        $58 = ($57|0)==(0|0);
        if (!($58)) {
         $59 = HEAP32[$57>>2]|0;
         $60 = ((($59)) + -12|0);
         $61 = HEAP32[$60>>2]|0;
         $62 = (($57) + ($61)|0);
         $63 = ((($62)) + 8|0);
         $64 = HEAP32[$63>>2]|0;HEAP32[$63>>2] = (($64-1)|0);
         $65 = ($64|0)==(1);
         if ($65) {
          __THREW__ = 0;
          invoke_viii(3262,($62|0),1,1);
          $66 = __THREW__; __THREW__ = 0;
          $67 = $66&1;
          if ($67) {
           break;
          }
         }
        }
        __ZdlPv($$023$i$i);
        $68 = ($55|0)==($41|0);
        if ($68) {
         break L24;
        } else {
         $$023$i$i = $55;
        }
       }
       $69 = ___cxa_find_matching_catch_2()|0;
       $70 = tempRet0;
       ___cxa_call_unexpected(($69|0));
       // unreachable;
      }
     }
    } while(0);
    $71 = ((($0)) + 88|0);
    $72 = HEAP32[$71>>2]|0;
    $73 = ($72|0)==(0|0);
    if (!($73)) {
     $74 = HEAP32[$72>>2]|0;
     $75 = ((($74)) + -12|0);
     $76 = HEAP32[$75>>2]|0;
     $77 = (($72) + ($76)|0);
     $78 = ((($77)) + 8|0);
     $79 = HEAP32[$78>>2]|0;HEAP32[$78>>2] = (($79-1)|0);
     $80 = ($79|0)==(1);
     if ($80) {
      __THREW__ = 0;
      invoke_viii(3262,($77|0),1,1);
      $81 = __THREW__; __THREW__ = 0;
      $82 = $81&1;
      if ($82) {
       $206 = ___cxa_find_matching_catch_2()|0;
       $207 = tempRet0;
       $$5 = $207;$$57 = $206;
       label = 69;
       break;
      }
     }
    }
    HEAP32[$71>>2] = 0;
    $83 = ((($0)) + 76|0);
    __THREW__ = 0;
    invoke_vi(707,($83|0));
    $84 = __THREW__; __THREW__ = 0;
    $85 = $84&1;
    if ($85) {
     $208 = ___cxa_find_matching_catch_2()|0;
     $209 = tempRet0;
     $$6 = $209;$$68 = $208;
     label = 71;
     break;
    }
    $86 = ((($0)) + 48|0);
    $87 = HEAP32[$86>>2]|0;
    $88 = ($87|0)==(0|0);
    if (!($88)) {
     $89 = ((($87)) + 8|0);
     $90 = HEAP32[$89>>2]|0;HEAP32[$89>>2] = (($90-1)|0);
     $91 = ($90|0)==(1);
     if ($91) {
      __THREW__ = 0;
      invoke_viii(3262,($87|0),1,1);
      $92 = __THREW__; __THREW__ = 0;
      $93 = $92&1;
      if ($93) {
       $213 = ___cxa_find_matching_catch_2()|0;
       $214 = tempRet0;
       $$7 = $214;$$79 = $213;
       label = 76;
       break;
      }
     }
    }
    HEAP32[$86>>2] = 0;
    $94 = ((($0)) + 44|0);
    $95 = HEAP32[$94>>2]|0;
    $96 = ($95|0)==(0|0);
    if (!($96)) {
     $97 = ((($95)) + 8|0);
     $98 = HEAP32[$97>>2]|0;HEAP32[$97>>2] = (($98-1)|0);
     $99 = ($98|0)==(1);
     if ($99) {
      __THREW__ = 0;
      invoke_viii(3262,($95|0),1,1);
      $100 = __THREW__; __THREW__ = 0;
      $101 = $100&1;
      if ($101) {
       $223 = ___cxa_find_matching_catch_2()|0;
       $224 = tempRet0;
       $$8 = $224;$$810 = $223;
       break;
      }
     }
    }
    HEAP32[$94>>2] = 0;
    $102 = ((($0)) + 32|0);
    $103 = ((($0)) + 40|0);
    $104 = HEAP32[$103>>2]|0;
    $105 = ($104|0)==(0);
    if ($105) {
     __ZN3osg6ObjectD2Ev($0);
     return;
    }
    $106 = ((($0)) + 36|0);
    $107 = HEAP32[$106>>2]|0;
    $108 = HEAP32[$102>>2]|0;
    $109 = ((($108)) + 4|0);
    $110 = HEAP32[$109>>2]|0;
    $111 = HEAP32[$107>>2]|0;
    $112 = ((($111)) + 4|0);
    HEAP32[$112>>2] = $110;
    $113 = HEAP32[$109>>2]|0;
    HEAP32[$113>>2] = $111;
    HEAP32[$103>>2] = 0;
    $114 = ($107|0)==($102|0);
    if ($114) {
     __ZN3osg6ObjectD2Ev($0);
     return;
    } else {
     $$023$i$i18 = $107;
    }
    while(1) {
     $115 = ((($$023$i$i18)) + 4|0);
     $116 = HEAP32[$115>>2]|0;
     __ZdlPv($$023$i$i18);
     $117 = ($116|0)==($102|0);
     if ($117) {
      break;
     } else {
      $$023$i$i18 = $116;
     }
    }
    __ZN3osg6ObjectD2Ev($0);
    return;
   }
  }
 } while(0);
 if ((label|0) == 36) {
  $118 = ___cxa_find_matching_catch_2()|0;
  $119 = tempRet0;
  $120 = ((($0)) + 116|0);
  $121 = HEAP32[$120>>2]|0;
  $122 = ($121|0)==(0|0);
  if (!($122)) {
   $123 = ((($121)) + 8|0);
   $124 = HEAP32[$123>>2]|0;HEAP32[$123>>2] = (($124-1)|0);
   $125 = ($124|0)==(1);
   if ($125) {
    __THREW__ = 0;
    invoke_viii(3262,($121|0),1,1);
    $126 = __THREW__; __THREW__ = 0;
    $127 = $126&1;
    if ($127) {
     $251 = ___cxa_find_matching_catch_3(0|0)|0;
     $252 = tempRet0;
     ___clang_call_terminate($251);
     // unreachable;
    }
   }
  }
  HEAP32[$120>>2] = 0;
  $$0 = $119;$$02 = $118;
  label = 42;
 }
 if ((label|0) == 42) {
  $132 = ((($0)) + 112|0);
  $133 = HEAP32[$132>>2]|0;
  $134 = ($133|0)==(0|0);
  if (!($134)) {
   $135 = ((($133)) + 8|0);
   $136 = HEAP32[$135>>2]|0;HEAP32[$135>>2] = (($136-1)|0);
   $137 = ($136|0)==(1);
   if ($137) {
    __THREW__ = 0;
    invoke_viii(3262,($133|0),1,1);
    $138 = __THREW__; __THREW__ = 0;
    $139 = $138&1;
    if ($139) {
     $251 = ___cxa_find_matching_catch_3(0|0)|0;
     $252 = tempRet0;
     ___clang_call_terminate($251);
     // unreachable;
    }
   }
  }
  HEAP32[$132>>2] = 0;
  $$1 = $$0;$$13 = $$02;
  label = 47;
 }
 if ((label|0) == 47) {
  $142 = ((($0)) + 108|0);
  $143 = HEAP32[$142>>2]|0;
  $144 = ($143|0)==(0|0);
  if (!($144)) {
   $145 = ((($143)) + 8|0);
   $146 = HEAP32[$145>>2]|0;HEAP32[$145>>2] = (($146-1)|0);
   $147 = ($146|0)==(1);
   if ($147) {
    __THREW__ = 0;
    invoke_viii(3262,($143|0),1,1);
    $148 = __THREW__; __THREW__ = 0;
    $149 = $148&1;
    if ($149) {
     $251 = ___cxa_find_matching_catch_3(0|0)|0;
     $252 = tempRet0;
     ___clang_call_terminate($251);
     // unreachable;
    }
   }
  }
  HEAP32[$142>>2] = 0;
  $$2 = $$1;$$24 = $$13;
  label = 52;
 }
 if ((label|0) == 52) {
  $152 = ((($0)) + 104|0);
  $153 = HEAP32[$152>>2]|0;
  $154 = ($153|0)==(0|0);
  if (!($154)) {
   $155 = HEAP32[$153>>2]|0;
   $156 = ((($155)) + -12|0);
   $157 = HEAP32[$156>>2]|0;
   $158 = (($153) + ($157)|0);
   $159 = ((($158)) + 8|0);
   $160 = HEAP32[$159>>2]|0;HEAP32[$159>>2] = (($160-1)|0);
   $161 = ($160|0)==(1);
   if ($161) {
    __THREW__ = 0;
    invoke_viii(3262,($158|0),1,1);
    $162 = __THREW__; __THREW__ = 0;
    $163 = $162&1;
    if ($163) {
     $251 = ___cxa_find_matching_catch_3(0|0)|0;
     $252 = tempRet0;
     ___clang_call_terminate($251);
     // unreachable;
    }
   }
  }
  HEAP32[$152>>2] = 0;
  $$3 = $$2;$$35 = $$24;
  label = 56;
 }
 if ((label|0) == 56) {
  $164 = ((($0)) + 92|0);
  $165 = ((($0)) + 100|0);
  $166 = HEAP32[$165>>2]|0;
  $167 = ($166|0)==(0);
  L90: do {
   if (!($167)) {
    $168 = ((($0)) + 96|0);
    $169 = HEAP32[$168>>2]|0;
    $170 = HEAP32[$164>>2]|0;
    $171 = ((($170)) + 4|0);
    $172 = HEAP32[$171>>2]|0;
    $173 = HEAP32[$169>>2]|0;
    $174 = ((($173)) + 4|0);
    HEAP32[$174>>2] = $172;
    $175 = HEAP32[$171>>2]|0;
    HEAP32[$175>>2] = $173;
    HEAP32[$165>>2] = 0;
    $176 = ($169|0)==($164|0);
    if (!($176)) {
     $$023$i$i28 = $169;
     while(1) {
      $177 = ((($$023$i$i28)) + 4|0);
      $178 = HEAP32[$177>>2]|0;
      $179 = ((($$023$i$i28)) + 8|0);
      $180 = HEAP32[$179>>2]|0;
      $181 = ($180|0)==(0|0);
      if (!($181)) {
       $182 = HEAP32[$180>>2]|0;
       $183 = ((($182)) + -12|0);
       $184 = HEAP32[$183>>2]|0;
       $185 = (($180) + ($184)|0);
       $186 = ((($185)) + 8|0);
       $187 = HEAP32[$186>>2]|0;HEAP32[$186>>2] = (($187-1)|0);
       $188 = ($187|0)==(1);
       if ($188) {
        __THREW__ = 0;
        invoke_viii(3262,($185|0),1,1);
        $189 = __THREW__; __THREW__ = 0;
        $190 = $189&1;
        if ($190) {
         break;
        }
       }
      }
      __ZdlPv($$023$i$i28);
      $191 = ($178|0)==($164|0);
      if ($191) {
       break L90;
      } else {
       $$023$i$i28 = $178;
      }
     }
     $192 = ___cxa_find_matching_catch_2()|0;
     $193 = tempRet0;
     ___cxa_call_unexpected(($192|0));
     // unreachable;
    }
   }
  } while(0);
  $194 = ((($0)) + 88|0);
  $195 = HEAP32[$194>>2]|0;
  $196 = ($195|0)==(0|0);
  if (!($196)) {
   $197 = HEAP32[$195>>2]|0;
   $198 = ((($197)) + -12|0);
   $199 = HEAP32[$198>>2]|0;
   $200 = (($195) + ($199)|0);
   $201 = ((($200)) + 8|0);
   $202 = HEAP32[$201>>2]|0;HEAP32[$201>>2] = (($202-1)|0);
   $203 = ($202|0)==(1);
   if ($203) {
    __THREW__ = 0;
    invoke_viii(3262,($200|0),1,1);
    $204 = __THREW__; __THREW__ = 0;
    $205 = $204&1;
    if ($205) {
     $251 = ___cxa_find_matching_catch_3(0|0)|0;
     $252 = tempRet0;
     ___clang_call_terminate($251);
     // unreachable;
    }
   }
  }
  HEAP32[$194>>2] = 0;
  $$5 = $$3;$$57 = $$35;
  label = 69;
 }
 if ((label|0) == 69) {
  $210 = ((($0)) + 76|0);
  __THREW__ = 0;
  invoke_vi(707,($210|0));
  $211 = __THREW__; __THREW__ = 0;
  $212 = $211&1;
  if ($212) {
   $251 = ___cxa_find_matching_catch_3(0|0)|0;
   $252 = tempRet0;
   ___clang_call_terminate($251);
   // unreachable;
  } else {
   $$6 = $$5;$$68 = $$57;
   label = 71;
  }
 }
 if ((label|0) == 71) {
  $215 = ((($0)) + 48|0);
  $216 = HEAP32[$215>>2]|0;
  $217 = ($216|0)==(0|0);
  if (!($217)) {
   $218 = ((($216)) + 8|0);
   $219 = HEAP32[$218>>2]|0;HEAP32[$218>>2] = (($219-1)|0);
   $220 = ($219|0)==(1);
   if ($220) {
    __THREW__ = 0;
    invoke_viii(3262,($216|0),1,1);
    $221 = __THREW__; __THREW__ = 0;
    $222 = $221&1;
    if ($222) {
     $251 = ___cxa_find_matching_catch_3(0|0)|0;
     $252 = tempRet0;
     ___clang_call_terminate($251);
     // unreachable;
    }
   }
  }
  HEAP32[$215>>2] = 0;
  $$7 = $$6;$$79 = $$68;
  label = 76;
 }
 if ((label|0) == 76) {
  $225 = ((($0)) + 44|0);
  $226 = HEAP32[$225>>2]|0;
  $227 = ($226|0)==(0|0);
  if (!($227)) {
   $228 = ((($226)) + 8|0);
   $229 = HEAP32[$228>>2]|0;HEAP32[$228>>2] = (($229-1)|0);
   $230 = ($229|0)==(1);
   if ($230) {
    __THREW__ = 0;
    invoke_viii(3262,($226|0),1,1);
    $231 = __THREW__; __THREW__ = 0;
    $232 = $231&1;
    if ($232) {
     $251 = ___cxa_find_matching_catch_3(0|0)|0;
     $252 = tempRet0;
     ___clang_call_terminate($251);
     // unreachable;
    }
   }
  }
  HEAP32[$225>>2] = 0;
  $$8 = $$7;$$810 = $$79;
 }
 $233 = ((($0)) + 32|0);
 $234 = ((($0)) + 40|0);
 $235 = HEAP32[$234>>2]|0;
 $236 = ($235|0)==(0);
 if (!($236)) {
  $237 = ((($0)) + 36|0);
  $238 = HEAP32[$237>>2]|0;
  $239 = HEAP32[$233>>2]|0;
  $240 = ((($239)) + 4|0);
  $241 = HEAP32[$240>>2]|0;
  $242 = HEAP32[$238>>2]|0;
  $243 = ((($242)) + 4|0);
  HEAP32[$243>>2] = $241;
  $244 = HEAP32[$240>>2]|0;
  HEAP32[$244>>2] = $242;
  HEAP32[$234>>2] = 0;
  $245 = ($238|0)==($233|0);
  if (!($245)) {
   $$023$i$i37 = $238;
   while(1) {
    $246 = ((($$023$i$i37)) + 4|0);
    $247 = HEAP32[$246>>2]|0;
    __ZdlPv($$023$i$i37);
    $248 = ($247|0)==($233|0);
    if ($248) {
     break;
    } else {
     $$023$i$i37 = $247;
    }
   }
  }
 }
 __THREW__ = 0;
 invoke_vi(388,($0|0));
 $249 = __THREW__; __THREW__ = 0;
 $250 = $249&1;
 if ($250) {
  $251 = ___cxa_find_matching_catch_3(0|0)|0;
  $252 = tempRet0;
  ___clang_call_terminate($251);
  // unreachable;
 } else {
  ___resumeException($$810|0);
  // unreachable;
 }
}
function __ZN3osg15GraphicsContextD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1871,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK3osg15GraphicsContext12isSameKindAsEPKNS_6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,24816,0)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK3osg15GraphicsContext11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175113|0);
}
function __ZNK3osg15GraphicsContext9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (142652|0);
}
function __ZN3osg15GraphicsContext13runOperationsEv($0) {
 $0 = $0|0;
 var $$4 = 0, $$413 = 0, $$cast$i$i = 0, $$pre = 0, $$pre89 = 0, $$pre90 = 0, $$pre91 = 0, $$pre93 = 0, $$sroa$045$086 = 0, $$sroa$052$087 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0;
 var $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0;
 var $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0;
 var $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i29 = 0, $scevgep5$i$i$i = 0, $scevgep5$i$i$i30 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $2 = sp + 4|0;
 HEAP32[$2>>2] = 0;
 $3 = ((($2)) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = ((($2)) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = ((($0)) + 36|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($0)) + 32|0);
 $8 = ($6|0)==($7|0);
 L1: do {
  if ($8) {
   $25 = 0;$26 = 0;
   label = 9;
  } else {
   $9 = ((($2)) + 8|0);
   $11 = $6;$12 = 0;$14 = 0;$21 = $6;
   while(1) {
    $10 = ((($11)) + 8|0);
    $13 = ($12|0)==($14|0);
    if ($13) {
     __THREW__ = 0;
     invoke_vii(3424,($2|0),($10|0));
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      label = 13;
      break L1;
     }
    } else {
     $15 = HEAP32[$10>>2]|0;
     HEAP32[$12>>2] = $15;
     $16 = HEAP32[$3>>2]|0;
     $17 = ((($16)) + 4|0);
     HEAP32[$3>>2] = $17;
    }
    $20 = ((($21)) + 4|0);
    $22 = HEAP32[$20>>2]|0;
    $$cast$i$i = $22;
    $23 = ($$cast$i$i|0)==($7|0);
    if ($23) {
     break;
    }
    $24 = $22;
    $$pre = HEAP32[$3>>2]|0;
    $$pre89 = HEAP32[$9>>2]|0;
    $11 = $24;$12 = $$pre;$14 = $$pre89;$21 = $$cast$i$i;
   }
   $$pre90 = HEAP32[$2>>2]|0;
   $$pre91 = HEAP32[$3>>2]|0;
   $25 = $$pre90;$26 = $$pre91;
   label = 9;
  }
 } while(0);
 L11: do {
  if ((label|0) == 9) {
   __THREW__ = 0;
   invoke_viii(3423,($25|0),($26|0),($1|0));
   $27 = __THREW__; __THREW__ = 0;
   $28 = $27&1;
   if ($28) {
    label = 13;
   } else {
    $29 = HEAP32[$2>>2]|0;
    $30 = HEAP32[$3>>2]|0;
    $31 = ($29|0)==($30|0);
    L14: do {
     if (!($31)) {
      $$sroa$052$087 = $29;$201 = $30;
      while(1) {
       $43 = HEAP32[$$sroa$052$087>>2]|0;
       $44 = ((($43)) + 628|0);
       $45 = HEAP32[$44>>2]|0;
       $46 = ($45|0)==(0|0);
       if ($46) {
        $56 = $201;
       } else {
        $47 = HEAP32[$45>>2]|0;
        $48 = ((($47)) + 16|0);
        $49 = HEAP32[$48>>2]|0;
        __THREW__ = 0;
        invoke_vii($49|0,($45|0),($0|0));
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         break;
        }
        $$pre93 = HEAP32[$3>>2]|0;
        $56 = $$pre93;
       }
       $54 = ((($$sroa$052$087)) + 4|0);
       $55 = ($54|0)==($56|0);
       if ($55) {
        break L14;
       } else {
        $$sroa$052$087 = $54;$201 = $56;
       }
      }
      $52 = ___cxa_find_matching_catch_2()|0;
      $53 = tempRet0;
      $$4 = $52;$$413 = $53;
      break L11;
     }
    } while(0);
    $32 = ((($0)) + 96|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = ((($0)) + 92|0);
    $35 = $33;
    $36 = ($35|0)==($34|0);
    L23: do {
     if (!($36)) {
      $37 = ((($0)) + 76|0);
      $38 = ((($0)) + 104|0);
      $39 = ((($0)) + 100|0);
      $40 = ((($0)) + 88|0);
      $$sroa$045$086 = $33;$98 = $35;
      while(1) {
       $66 = HEAP32[$37>>2]|0;
       $67 = ((($66)) + 8|0);
       $68 = HEAP32[$67>>2]|0;
       __THREW__ = 0;
       (invoke_ii($68|0,($37|0))|0);
       $69 = __THREW__; __THREW__ = 0;
       $70 = $69&1;
       if ($70) {
        label = 39;
        break;
       }
       $71 = $$sroa$045$086;
       $72 = HEAP32[$38>>2]|0;
       $73 = ((($71)) + 8|0);
       $74 = HEAP32[$73>>2]|0;
       $75 = ($72|0)==($74|0);
       if (!($75)) {
        HEAP32[$38>>2] = $74;
        $76 = ($74|0)==(0|0);
        if (!($76)) {
         $77 = HEAP32[$74>>2]|0;
         $78 = ((($77)) + -12|0);
         $79 = HEAP32[$78>>2]|0;
         $80 = (($74) + ($79)|0);
         $81 = ((($80)) + 8|0);
         $82 = HEAP32[$81>>2]|0;HEAP32[$81>>2] = (($82+1)|0);
        }
        $83 = ($72|0)==(0|0);
        if (!($83)) {
         $84 = HEAP32[$72>>2]|0;
         $85 = ((($84)) + -12|0);
         $86 = HEAP32[$85>>2]|0;
         $87 = (($72) + ($86)|0);
         $88 = ((($87)) + 8|0);
         $89 = HEAP32[$88>>2]|0;HEAP32[$88>>2] = (($89-1)|0);
         $90 = ($89|0)==(1);
         if ($90) {
          __THREW__ = 0;
          invoke_viii(3262,($87|0),1,1);
          $91 = __THREW__; __THREW__ = 0;
          $92 = $91&1;
          if ($92) {
           label = 50;
           break;
          }
         }
        }
       }
       $93 = HEAP32[$38>>2]|0;
       $94 = ((($93)) + 16|0);
       $95 = HEAP8[$94>>0]|0;
       $96 = ($95<<24>>24)==(0);
       $97 = ((($98)) + 4|0);
       $99 = HEAP32[$97>>2]|0;
       if ($96) {
        $100 = HEAP32[$98>>2]|0;
        $101 = ((($100)) + 4|0);
        HEAP32[$101>>2] = $99;
        $102 = HEAP32[$97>>2]|0;
        HEAP32[$102>>2] = $100;
        $103 = HEAP32[$39>>2]|0;
        $104 = (($103) + -1)|0;
        HEAP32[$39>>2] = $104;
        $105 = ((($98)) + 8|0);
        $106 = HEAP32[$105>>2]|0;
        $107 = ($106|0)==(0|0);
        if (!($107)) {
         $108 = HEAP32[$106>>2]|0;
         $109 = ((($108)) + -12|0);
         $110 = HEAP32[$109>>2]|0;
         $111 = (($106) + ($110)|0);
         $112 = ((($111)) + 8|0);
         $113 = HEAP32[$112>>2]|0;HEAP32[$112>>2] = (($113-1)|0);
         $114 = ($113|0)==(1);
         if ($114) {
          __THREW__ = 0;
          invoke_viii(3262,($111|0),1,1);
          $115 = __THREW__; __THREW__ = 0;
          $116 = $115&1;
          if ($116) {
           label = 50;
           break;
          }
         }
        }
        $117 = $$sroa$045$086;
        __ZdlPv($117);
        $118 = HEAP32[$39>>2]|0;
        $119 = ($118|0)==(0);
        if ($119) {
         $120 = HEAP32[$40>>2]|0;
         $121 = ((($120)) + 4|0);
         $122 = ((($120)) + 24|0);
         $123 = HEAP8[$122>>0]|0;
         $124 = ($123<<24>>24)==(0);
         if (!($124)) {
          $125 = HEAP32[$121>>2]|0;
          $126 = ((($125)) + 8|0);
          $127 = HEAP32[$126>>2]|0;
          __THREW__ = 0;
          (invoke_ii($127|0,($121|0))|0);
          $128 = __THREW__; __THREW__ = 0;
          $129 = $128&1;
          if ($129) {
           label = 50;
           break;
          }
          HEAP8[$122>>0] = 0;
          $130 = HEAP32[$121>>2]|0;
          $131 = ((($130)) + 12|0);
          $132 = HEAP32[$131>>2]|0;
          __THREW__ = 0;
          (invoke_ii($132|0,($121|0))|0);
          $133 = __THREW__; __THREW__ = 0;
          $134 = $133&1;
          if ($134) {
           label = 50;
           break;
          }
         }
        }
       }
       $137 = HEAP32[$37>>2]|0;
       $138 = ((($137)) + 12|0);
       $139 = HEAP32[$138>>2]|0;
       __THREW__ = 0;
       (invoke_ii($139|0,($37|0))|0);
       $140 = __THREW__; __THREW__ = 0;
       $141 = $140&1;
       if ($141) {
        label = 49;
        break;
       }
       $142 = HEAP32[$38>>2]|0;
       $143 = ($142|0)==(0|0);
       if (!($143)) {
        $144 = HEAP32[$142>>2]|0;
        $145 = ((($144)) + 4|0);
        $146 = HEAP32[$145>>2]|0;
        __THREW__ = 0;
        invoke_vii($146|0,($142|0),($0|0));
        $147 = __THREW__; __THREW__ = 0;
        $148 = $147&1;
        if ($148) {
         label = 39;
         break;
        }
        $149 = HEAP32[$37>>2]|0;
        $150 = ((($149)) + 8|0);
        $151 = HEAP32[$150>>2]|0;
        __THREW__ = 0;
        (invoke_ii($151|0,($37|0))|0);
        $152 = __THREW__; __THREW__ = 0;
        $153 = $152&1;
        if ($153) {
         label = 39;
         break;
        }
        $154 = HEAP32[$38>>2]|0;
        $155 = ($154|0)==(0|0);
        if (!($155)) {
         HEAP32[$38>>2] = 0;
         $156 = HEAP32[$154>>2]|0;
         $157 = ((($156)) + -12|0);
         $158 = HEAP32[$157>>2]|0;
         $159 = (($154) + ($158)|0);
         $160 = ((($159)) + 8|0);
         $161 = HEAP32[$160>>2]|0;HEAP32[$160>>2] = (($161-1)|0);
         $162 = ($161|0)==(1);
         if ($162) {
          __THREW__ = 0;
          invoke_viii(3262,($159|0),1,1);
          $163 = __THREW__; __THREW__ = 0;
          $164 = $163&1;
          if ($164) {
           label = 51;
           break;
          }
         }
        }
        $165 = HEAP32[$37>>2]|0;
        $166 = ((($165)) + 12|0);
        $167 = HEAP32[$166>>2]|0;
        __THREW__ = 0;
        (invoke_ii($167|0,($37|0))|0);
        $168 = __THREW__; __THREW__ = 0;
        $169 = $168&1;
        if ($169) {
         label = 52;
         break;
        }
       }
       $170 = $99;
       $171 = ($170|0)==($34|0);
       if ($171) {
        break L23;
       } else {
        $$sroa$045$086 = $99;$98 = $170;
       }
      }
      if ((label|0) == 39) {
       $135 = ___cxa_find_matching_catch_2()|0;
       $136 = tempRet0;
       $$4 = $135;$$413 = $136;
       break L11;
      }
      else if ((label|0) == 49) {
       $172 = ___cxa_find_matching_catch_2()|0;
       $173 = tempRet0;
       $$4 = $172;$$413 = $173;
       break L11;
      }
      else if ((label|0) == 50) {
       $174 = ___cxa_find_matching_catch_2()|0;
       $175 = tempRet0;
       $176 = HEAP32[$37>>2]|0;
       $177 = ((($176)) + 12|0);
       $178 = HEAP32[$177>>2]|0;
       __THREW__ = 0;
       (invoke_ii($178|0,($37|0))|0);
       $179 = __THREW__; __THREW__ = 0;
       $180 = $179&1;
       if (!($180)) {
        $$4 = $174;$$413 = $175;
        break L11;
       }
       $199 = ___cxa_find_matching_catch_3(0|0)|0;
       $200 = tempRet0;
       ___clang_call_terminate($199);
       // unreachable;
      }
      else if ((label|0) == 51) {
       $181 = ___cxa_find_matching_catch_2()|0;
       $182 = tempRet0;
       $183 = HEAP32[$37>>2]|0;
       $184 = ((($183)) + 12|0);
       $185 = HEAP32[$184>>2]|0;
       __THREW__ = 0;
       (invoke_ii($185|0,($37|0))|0);
       $186 = __THREW__; __THREW__ = 0;
       $187 = $186&1;
       if (!($187)) {
        $$4 = $181;$$413 = $182;
        break L11;
       }
       $199 = ___cxa_find_matching_catch_3(0|0)|0;
       $200 = tempRet0;
       ___clang_call_terminate($199);
       // unreachable;
      }
      else if ((label|0) == 52) {
       $188 = ___cxa_find_matching_catch_2()|0;
       $189 = tempRet0;
       $$4 = $188;$$413 = $189;
       break L11;
      }
     }
    } while(0);
    $57 = HEAP32[$2>>2]|0;
    $58 = ($57|0)==(0|0);
    if ($58) {
     STACKTOP = sp;return;
    }
    $59 = HEAP32[$3>>2]|0;
    $60 = ($59|0)==($57|0);
    if (!($60)) {
     $scevgep$i$i$i29 = ((($59)) + -4|0);
     $61 = $scevgep$i$i$i29;
     $62 = $57;
     $63 = (($61) - ($62))|0;
     $64 = $63 >>> 2;
     $65 = $64 ^ -1;
     $scevgep5$i$i$i30 = (($59) + ($65<<2)|0);
     HEAP32[$3>>2] = $scevgep5$i$i$i30;
    }
    __ZdlPv($57);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 13) {
  $41 = ___cxa_find_matching_catch_2()|0;
  $42 = tempRet0;
  $$4 = $41;$$413 = $42;
 }
 $190 = HEAP32[$2>>2]|0;
 $191 = ($190|0)==(0|0);
 if ($191) {
  ___resumeException($$4|0);
  // unreachable;
 }
 $192 = HEAP32[$3>>2]|0;
 $193 = ($192|0)==($190|0);
 if (!($193)) {
  $scevgep$i$i$i = ((($192)) + -4|0);
  $194 = $scevgep$i$i$i;
  $195 = $190;
  $196 = (($194) - ($195))|0;
  $197 = $196 >>> 2;
  $198 = $197 ^ -1;
  $scevgep5$i$i$i = (($192) + ($198<<2)|0);
  HEAP32[$3>>2] = $scevgep5$i$i$i;
 }
 __ZdlPv($190);
 ___resumeException($$4|0);
 // unreachable;
}
function __ZN3osg15GraphicsContext5clearEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0.0, $26 = 0, $27 = 0.0;
 var $28 = 0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0.0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__ZN3osg5Timer8instanceEv()|0);
 $2 = (__ZNK3osg5Timer4tickEv($1)|0);
 $3 = tempRet0;
 $4 = ((($0)) + 120|0);
 $5 = $4;
 $6 = $5;
 HEAP32[$6>>2] = $2;
 $7 = (($5) + 4)|0;
 $8 = $7;
 HEAP32[$8>>2] = $3;
 $9 = ((($0)) + 68|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0);
 if ($11) {
  return;
 }
 $12 = ((($0)) + 44|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  return;
 }
 $15 = ((($13)) + 40|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ((($13)) + 44|0);
 $18 = HEAP32[$17>>2]|0;
 _glViewport(0,0,($16|0),($18|0));
 $19 = HEAP32[$12>>2]|0;
 $20 = ((($19)) + 40|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ((($19)) + 44|0);
 $23 = HEAP32[$22>>2]|0;
 _glScissor(0,0,($21|0),($23|0));
 $24 = ((($0)) + 52|0);
 $25 = +HEAPF32[$24>>2];
 $26 = ((($0)) + 56|0);
 $27 = +HEAPF32[$26>>2];
 $28 = ((($0)) + 60|0);
 $29 = +HEAPF32[$28>>2];
 $30 = ((($0)) + 64|0);
 $31 = +HEAPF32[$30>>2];
 _glClearColor((+$25),(+$27),(+$29),(+$31));
 $32 = HEAP32[$9>>2]|0;
 _glClear(($32|0));
 return;
}
function __ZN3osg15GraphicsContext21resizedImplementationEiiii($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0$i$i$i$i = 0, $$0$ph$i$i$i$i = 0, $$024$i$i$i$i = 0, $$025$i$i$i$i = 0, $$036$i$i$i = 0, $$090236 = 0, $$13 = 0, $$13104 = 0, $$in = 0, $$in$i$i$i$i = 0, $$pre$i$i$i$i = 0, $$pre246 = 0, $$pre248 = 0, $$pre248$pre = 0, $$sink = 0, $$sink$be$i$i = 0, $$sroa$0182$0 = 0, $$sroa$0182$0238 = 0, $$sroa$0182$0239 = 0, $10 = 0;
 var $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0;
 var $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0;
 var $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0;
 var $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0;
 var $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0;
 var $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0;
 var $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0.0, $217 = 0, $218 = 0, $219 = 0.0, $22 = 0, $220 = 0, $221 = 0, $222 = 0.0, $223 = 0, $224 = 0, $225 = 0, $226 = 0.0, $227 = 0;
 var $228 = 0, $229 = 0.0, $23 = 0, $230 = 0, $231 = 0, $232 = 0.0, $233 = 0, $234 = 0, $235 = 0, $236 = 0.0, $237 = 0.0, $238 = 0, $239 = 0.0, $24 = 0, $240 = 0.0, $241 = 0, $242 = 0.0, $243 = 0.0, $244 = 0, $245 = 0;
 var $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0;
 var $264 = 0, $265 = 0, $266 = 0.0, $267 = 0, $268 = 0.0, $269 = 0, $27 = 0, $270 = 0.0, $271 = 0, $272 = 0.0, $273 = 0, $274 = 0.0, $275 = 0, $276 = 0.0, $277 = 0, $278 = 0.0, $279 = 0, $28 = 0.0, $280 = 0.0, $281 = 0;
 var $282 = 0.0, $283 = 0, $284 = 0.0, $285 = 0, $286 = 0.0, $287 = 0, $288 = 0.0, $289 = 0, $29 = 0, $290 = 0.0, $291 = 0, $292 = 0.0, $293 = 0, $294 = 0.0, $295 = 0, $296 = 0.0, $297 = 0, $298 = 0, $299 = 0, $30 = 0;
 var $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0.0, $310 = 0, $311 = 0, $312 = 0, $313 = 0.0, $314 = 0, $315 = 0.0, $316 = 0, $317 = 0.0, $318 = 0;
 var $319 = 0.0, $32 = 0.0, $320 = 0, $321 = 0.0, $322 = 0, $323 = 0.0, $324 = 0, $325 = 0.0, $326 = 0, $327 = 0.0, $328 = 0, $329 = 0.0, $33 = 0.0, $330 = 0, $331 = 0.0, $332 = 0, $333 = 0.0, $334 = 0, $335 = 0.0, $336 = 0;
 var $337 = 0.0, $338 = 0, $339 = 0.0, $34 = 0, $340 = 0, $341 = 0.0, $342 = 0, $343 = 0.0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0;
 var $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0.0, $360 = 0, $361 = 0, $362 = 0.0, $363 = 0, $364 = 0.0, $365 = 0, $366 = 0.0, $367 = 0, $368 = 0.0, $369 = 0, $37 = 0.0, $370 = 0.0, $371 = 0, $372 = 0.0;
 var $373 = 0, $374 = 0.0, $375 = 0, $376 = 0.0, $377 = 0, $378 = 0.0, $379 = 0, $38 = 0.0, $380 = 0.0, $381 = 0, $382 = 0.0, $383 = 0, $384 = 0.0, $385 = 0, $386 = 0.0, $387 = 0, $388 = 0.0, $389 = 0, $39 = 0, $390 = 0.0;
 var $391 = 0, $392 = 0.0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0.0;
 var $41 = 0, $410 = 0, $411 = 0.0, $412 = 0, $413 = 0.0, $414 = 0, $415 = 0.0, $416 = 0, $417 = 0.0, $418 = 0, $419 = 0.0, $42 = 0, $420 = 0, $421 = 0.0, $422 = 0, $423 = 0.0, $424 = 0, $425 = 0.0, $426 = 0, $427 = 0.0;
 var $428 = 0, $429 = 0.0, $43 = 0, $430 = 0, $431 = 0.0, $432 = 0, $433 = 0.0, $434 = 0, $435 = 0.0, $436 = 0, $437 = 0.0, $438 = 0, $439 = 0.0, $44 = 0.0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0;
 var $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0.0, $461 = 0, $462 = 0.0, $463 = 0;
 var $464 = 0.0, $465 = 0, $466 = 0.0, $467 = 0, $468 = 0.0, $469 = 0, $47 = 0, $470 = 0.0, $471 = 0, $472 = 0.0, $473 = 0, $474 = 0.0, $475 = 0, $476 = 0.0, $477 = 0, $478 = 0.0, $479 = 0, $48 = 0, $480 = 0.0, $481 = 0;
 var $482 = 0.0, $483 = 0, $484 = 0.0, $485 = 0, $486 = 0.0, $487 = 0, $488 = 0.0, $489 = 0, $49 = 0, $490 = 0.0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0;
 var $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0.0, $508 = 0, $509 = 0.0, $51 = 0, $510 = 0, $511 = 0.0, $512 = 0, $513 = 0.0, $514 = 0, $515 = 0.0, $516 = 0, $517 = 0.0;
 var $518 = 0, $519 = 0.0, $52 = 0, $520 = 0, $521 = 0.0, $522 = 0, $523 = 0.0, $524 = 0, $525 = 0.0, $526 = 0, $527 = 0.0, $528 = 0, $529 = 0.0, $53 = 0, $530 = 0, $531 = 0.0, $532 = 0, $533 = 0.0, $534 = 0, $535 = 0.0;
 var $536 = 0, $537 = 0.0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0;
 var $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0.0, $57 = 0, $570 = 0, $571 = 0.0;
 var $572 = 0, $573 = 0.0, $574 = 0, $575 = 0.0, $576 = 0, $577 = 0.0, $578 = 0, $579 = 0.0, $58 = 0, $580 = 0, $581 = 0.0, $582 = 0, $583 = 0.0, $584 = 0, $585 = 0.0, $586 = 0, $587 = 0.0, $588 = 0, $589 = 0.0, $59 = 0;
 var $590 = 0, $591 = 0.0, $592 = 0, $593 = 0.0, $594 = 0, $595 = 0.0, $596 = 0, $597 = 0.0, $598 = 0, $599 = 0.0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0;
 var $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0.0, $617 = 0, $618 = 0.0, $619 = 0, $62 = 0, $620 = 0.0, $621 = 0, $622 = 0.0, $623 = 0, $624 = 0.0, $625 = 0;
 var $626 = 0.0, $627 = 0, $628 = 0.0, $629 = 0, $63 = 0, $630 = 0.0, $631 = 0, $632 = 0.0, $633 = 0, $634 = 0.0, $635 = 0, $636 = 0.0, $637 = 0, $638 = 0.0, $639 = 0, $64 = 0, $640 = 0.0, $641 = 0, $642 = 0.0, $643 = 0;
 var $644 = 0.0, $645 = 0, $646 = 0.0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0;
 var $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$sink198$index52Z2D = 0, $eh$lpad$body$sink198$indexZ2D = 0, $eh$lpad$body111$sink197$index45Z2D = 0, $eh$lpad$body111$sink197$indexZ2D = 0, $eh$lpad$body118$sink196$index38Z2D = 0, $eh$lpad$body118$sink196$indexZ2D = 0, $eh$lpad$body126$sink195$index31Z2D = 0, $eh$lpad$body126$sink195$indexZ2D = 0, $eh$lpad$body133$sink194$index24Z2D = 0, $eh$lpad$body133$sink194$indexZ2D = 0, $eh$lpad$body140$sink193$index17Z2D = 0, $eh$lpad$body140$sink193$indexZ2D = 0, $eh$lpad$body147$sink192$index10Z2D = 0, $eh$lpad$body147$sink192$indexZ2D = 0, $eh$lpad$body154$sink191$index3Z2D = 0, $eh$lpad$body154$sink191$indexZ2D = 0, $or$cond = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 2064|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(2064|0);
 $5 = sp + 1920|0;
 $6 = sp + 1792|0;
 $7 = sp + 1664|0;
 $8 = sp + 1536|0;
 $9 = sp + 1408|0;
 $10 = sp + 1280|0;
 $11 = sp + 1152|0;
 $12 = sp + 1024|0;
 $13 = sp + 2048|0;
 $14 = sp + 896|0;
 $15 = sp + 768|0;
 $16 = sp + 640|0;
 $17 = sp + 512|0;
 $18 = sp + 384|0;
 $19 = sp + 256|0;
 $20 = sp + 128|0;
 $21 = sp;
 $22 = ((($13)) + 4|0);
 HEAP32[$22>>2] = 0;
 $23 = ((($13)) + 8|0);
 HEAP32[$23>>2] = 0;
 $24 = ((($13)) + 4|0);
 HEAP32[$13>>2] = $24;
 $25 = ((($0)) + 44|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($26|0)==(0|0);
 if ($27) {
  $667 = 0;
  __ZNSt3__26__treeIPN3osg8ViewportENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($13,$667);
  STACKTOP = sp;return;
 }
 $28 = (+($3|0));
 $29 = ((($26)) + 40|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (+($30|0));
 $32 = $28 / $31;
 $33 = (+($4|0));
 $34 = ((($26)) + 44|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (+($35|0));
 $37 = $33 / $36;
 $38 = $32 / $37;
 $39 = ((($0)) + 36|0);
 $$sroa$0182$0238 = HEAP32[$39>>2]|0;
 $40 = ((($0)) + 32|0);
 $41 = $$sroa$0182$0238;
 $42 = ($41|0)==($40|0);
 L4: do {
  if ($42) {
   $$pre248 = 0;$166 = $26;
  } else {
   $43 = $38 != 1.0;
   $44 = 1.0 / $38;
   $45 = ((($5)) + 8|0);
   $46 = ((($5)) + 16|0);
   $47 = ((($5)) + 24|0);
   $48 = ((($5)) + 32|0);
   $49 = ((($5)) + 40|0);
   $50 = ((($5)) + 48|0);
   $51 = ((($5)) + 56|0);
   $52 = ((($5)) + 64|0);
   $53 = ((($5)) + 72|0);
   $54 = ((($5)) + 80|0);
   $55 = ((($5)) + 88|0);
   $56 = ((($5)) + 96|0);
   $57 = ((($5)) + 104|0);
   $58 = ((($5)) + 112|0);
   $59 = ((($5)) + 120|0);
   $60 = ((($6)) + 8|0);
   $61 = ((($6)) + 16|0);
   $62 = ((($6)) + 24|0);
   $63 = ((($6)) + 32|0);
   $64 = ((($6)) + 40|0);
   $65 = ((($6)) + 48|0);
   $66 = ((($6)) + 56|0);
   $67 = ((($6)) + 64|0);
   $68 = ((($6)) + 72|0);
   $69 = ((($6)) + 80|0);
   $70 = ((($6)) + 88|0);
   $71 = ((($6)) + 96|0);
   $72 = ((($6)) + 104|0);
   $73 = ((($6)) + 112|0);
   $74 = ((($6)) + 120|0);
   $75 = ((($7)) + 8|0);
   $76 = ((($7)) + 16|0);
   $77 = ((($7)) + 24|0);
   $78 = ((($7)) + 32|0);
   $79 = ((($7)) + 40|0);
   $80 = ((($7)) + 48|0);
   $81 = ((($7)) + 56|0);
   $82 = ((($7)) + 64|0);
   $83 = ((($7)) + 72|0);
   $84 = ((($7)) + 80|0);
   $85 = ((($7)) + 88|0);
   $86 = ((($7)) + 96|0);
   $87 = ((($7)) + 104|0);
   $88 = ((($7)) + 112|0);
   $89 = ((($7)) + 120|0);
   $90 = ((($8)) + 8|0);
   $91 = ((($8)) + 16|0);
   $92 = ((($8)) + 24|0);
   $93 = ((($8)) + 32|0);
   $94 = ((($8)) + 40|0);
   $95 = ((($8)) + 48|0);
   $96 = ((($8)) + 56|0);
   $97 = ((($8)) + 64|0);
   $98 = ((($8)) + 72|0);
   $99 = ((($8)) + 80|0);
   $100 = ((($8)) + 88|0);
   $101 = ((($8)) + 96|0);
   $102 = ((($8)) + 104|0);
   $103 = ((($8)) + 112|0);
   $104 = ((($8)) + 120|0);
   $105 = ((($11)) + 8|0);
   $106 = ((($11)) + 16|0);
   $107 = ((($11)) + 24|0);
   $108 = ((($11)) + 32|0);
   $109 = ((($11)) + 40|0);
   $110 = ((($11)) + 48|0);
   $111 = ((($11)) + 56|0);
   $112 = ((($11)) + 64|0);
   $113 = ((($11)) + 72|0);
   $114 = ((($11)) + 80|0);
   $115 = ((($11)) + 88|0);
   $116 = ((($11)) + 96|0);
   $117 = ((($11)) + 104|0);
   $118 = ((($11)) + 112|0);
   $119 = ((($11)) + 120|0);
   $120 = ((($12)) + 8|0);
   $121 = ((($12)) + 16|0);
   $122 = ((($12)) + 24|0);
   $123 = ((($12)) + 32|0);
   $124 = ((($12)) + 40|0);
   $125 = ((($12)) + 48|0);
   $126 = ((($12)) + 56|0);
   $127 = ((($12)) + 64|0);
   $128 = ((($12)) + 72|0);
   $129 = ((($12)) + 80|0);
   $130 = ((($12)) + 88|0);
   $131 = ((($12)) + 96|0);
   $132 = ((($12)) + 104|0);
   $133 = ((($12)) + 112|0);
   $134 = ((($12)) + 120|0);
   $135 = ((($9)) + 8|0);
   $136 = ((($9)) + 16|0);
   $137 = ((($9)) + 24|0);
   $138 = ((($9)) + 32|0);
   $139 = ((($9)) + 40|0);
   $140 = ((($9)) + 48|0);
   $141 = ((($9)) + 56|0);
   $142 = ((($9)) + 64|0);
   $143 = ((($9)) + 72|0);
   $144 = ((($9)) + 80|0);
   $145 = ((($9)) + 88|0);
   $146 = ((($9)) + 96|0);
   $147 = ((($9)) + 104|0);
   $148 = ((($9)) + 112|0);
   $149 = ((($9)) + 120|0);
   $150 = ((($10)) + 8|0);
   $151 = ((($10)) + 16|0);
   $152 = ((($10)) + 24|0);
   $153 = ((($10)) + 32|0);
   $154 = ((($10)) + 40|0);
   $155 = ((($10)) + 48|0);
   $156 = ((($10)) + 56|0);
   $157 = ((($10)) + 64|0);
   $158 = ((($10)) + 72|0);
   $159 = ((($10)) + 80|0);
   $160 = ((($10)) + 88|0);
   $161 = ((($10)) + 96|0);
   $162 = ((($10)) + 104|0);
   $163 = ((($10)) + 112|0);
   $164 = ((($10)) + 120|0);
   $$sroa$0182$0239 = $$sroa$0182$0238;$664 = $41;
   L6: while(1) {
    $170 = $$sroa$0182$0239;
    $171 = ((($170)) + 8|0);
    $172 = HEAP32[$171>>2]|0;
    $173 = ((($172)) + 576|0);
    $174 = HEAP32[$173>>2]|0;
    $175 = ($174|0)==(0);
    L8: do {
     if (!($175)) {
      $176 = ((($172)) + 288|0);
      $177 = HEAP32[$176>>2]|0;
      $178 = $177;
      $179 = ($177|0)==(0|0);
      L10: do {
       if (!($179)) {
        $180 = HEAP32[$24>>2]|0;
        $181 = ($180|0)==(0|0);
        do {
         if ($181) {
          $$025$i$i$i$i = $24;$$036$i$i$i = $24;
         } else {
          $183 = $180;
          while(1) {
           $182 = ((($183)) + 16|0);
           $184 = HEAP32[$182>>2]|0;
           $185 = ($177>>>0)<($184>>>0);
           if ($185) {
            $$sink$be$i$i = $183;
           } else {
            $186 = ($184>>>0)<($177>>>0);
            if (!($186)) {
             break L10;
            }
            $187 = ((($183)) + 4|0);
            $$sink$be$i$i = $187;
           }
           $188 = HEAP32[$$sink$be$i$i>>2]|0;
           $189 = ($188|0)==(0|0);
           if ($189) {
            $$0$i$i$i$i = $22;$$024$i$i$i$i = $180;
            break;
           } else {
            $183 = $188;
           }
          }
          while(1) {
           $190 = ((($$024$i$i$i$i)) + 16|0);
           $191 = HEAP32[$190>>2]|0;
           $192 = ($177>>>0)<($191>>>0);
           if ($192) {
            $193 = HEAP32[$$024$i$i$i$i>>2]|0;
            $194 = ($193|0)==(0|0);
            if ($194) {
             label = 17;
             break;
            } else {
             $$0$ph$i$i$i$i = $$024$i$i$i$i;$$in$i$i$i$i = $193;
            }
           } else {
            $195 = ($191>>>0)<($177>>>0);
            if (!($195)) {
             label = 21;
             break;
            }
            $196 = ((($$024$i$i$i$i)) + 4|0);
            $197 = HEAP32[$196>>2]|0;
            $198 = ($197|0)==(0|0);
            if ($198) {
             label = 20;
             break;
            } else {
             $$0$ph$i$i$i$i = $196;$$in$i$i$i$i = $197;
            }
           }
           $$0$i$i$i$i = $$0$ph$i$i$i$i;$$024$i$i$i$i = $$in$i$i$i$i;
          }
          if ((label|0) == 17) {
           label = 0;
           $$025$i$i$i$i = $$024$i$i$i$i;$$036$i$i$i = $$024$i$i$i$i;
           break;
          }
          else if ((label|0) == 20) {
           label = 0;
           $$025$i$i$i$i = $196;$$036$i$i$i = $$024$i$i$i$i;
           break;
          }
          else if ((label|0) == 21) {
           label = 0;
           $$025$i$i$i$i = $$0$i$i$i$i;$$036$i$i$i = $$024$i$i$i$i;
           break;
          }
         }
        } while(0);
        $199 = HEAP32[$$025$i$i$i$i>>2]|0;
        $200 = ($199|0)==(0|0);
        if ($200) {
         __THREW__ = 0;
         $201 = (invoke_ii(3276,20)|0);
         $202 = __THREW__; __THREW__ = 0;
         $203 = $202&1;
         if ($203) {
          label = 31;
          break L6;
         }
         $204 = ((($201)) + 16|0);
         HEAP32[$204>>2] = $178;
         HEAP32[$201>>2] = 0;
         $205 = ((($201)) + 4|0);
         HEAP32[$205>>2] = 0;
         $206 = ((($201)) + 8|0);
         HEAP32[$206>>2] = $$036$i$i$i;
         HEAP32[$$025$i$i$i$i>>2] = $201;
         $207 = HEAP32[$13>>2]|0;
         $208 = HEAP32[$207>>2]|0;
         $209 = ($208|0)==(0|0);
         if ($209) {
          $212 = $201;
         } else {
          $210 = $208;
          HEAP32[$13>>2] = $210;
          $$pre$i$i$i$i = HEAP32[$$025$i$i$i$i>>2]|0;
          $212 = $$pre$i$i$i$i;
         }
         $211 = HEAP32[$22>>2]|0;
         __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($211,$212);
         $213 = HEAP32[$23>>2]|0;
         $214 = (($213) + 1)|0;
         HEAP32[$23>>2] = $214;
        }
        $215 = ((($177)) + 56|0);
        $216 = +HEAPF64[$215>>3];
        $217 = $216 == 0.0;
        $218 = ((($177)) + 64|0);
        $219 = +HEAPF64[$218>>3];
        $220 = $219 == 0.0;
        $or$cond = $217 & $220;
        if ($or$cond) {
         $221 = ((($177)) + 72|0);
         $222 = +HEAPF64[$221>>3];
         $223 = HEAP32[$25>>2]|0;
         $224 = ((($223)) + 40|0);
         $225 = HEAP32[$224>>2]|0;
         $226 = (+($225|0));
         $227 = !($222 >= $226);
         if (!($227)) {
          $228 = ((($177)) + 80|0);
          $229 = +HEAPF64[$228>>3];
          $230 = ((($223)) + 44|0);
          $231 = HEAP32[$230>>2]|0;
          $232 = (+($231|0));
          $233 = !($229 >= $232);
          if (!($233)) {
           ;HEAP32[$215>>2]=0|0;HEAP32[$215+4>>2]=0|0;HEAP32[$215+8>>2]=0|0;HEAP32[$215+12>>2]=0|0;
           HEAPF64[$221>>3] = $28;
           HEAPF64[$228>>3] = $33;
           break;
          }
         }
        }
        $236 = $32 * $216;
        HEAPF64[$215>>3] = $236;
        $237 = $37 * $219;
        HEAPF64[$218>>3] = $237;
        $238 = ((($177)) + 72|0);
        $239 = +HEAPF64[$238>>3];
        $240 = $32 * $239;
        HEAPF64[$238>>3] = $240;
        $241 = ((($177)) + 80|0);
        $242 = +HEAPF64[$241>>3];
        $243 = $37 * $242;
        HEAPF64[$241>>3] = $243;
       }
      } while(0);
      if ($43) {
       $244 = ((($172)) + 220|0);
       $245 = HEAP32[$244>>2]|0;
       $246 = ($245|0)!=(0|0);
       do {
        if ($246) {
         __THREW__ = 0;
         $247 = (invoke_iii(3428,($245|0),($172|0))|0);
         $248 = __THREW__; __THREW__ = 0;
         $249 = $248&1;
         if ($249) {
          label = 39;
          break L6;
         }
         $250 = ($247|0)==(0|0);
         if ($250) {
          $450 = ((($245)) + 16|0);
          $451 = HEAP32[$450>>2]|0;
          $$sink = $451;
          break;
         }
         $251 = ((($172)) + 136|0);
         $252 = HEAP32[$251>>2]|0;
         $253 = ($252|0)==(0);
         if ($253) {
          $254 = ((($245)) + 16|0);
          $255 = HEAP32[$254>>2]|0;
          $256 = ((($255)) + 296|0);
          $257 = HEAP32[$256>>2]|0;
          switch ($257|0) {
          case 1:  {
           __THREW__ = 0;
           invoke_vi(3299,($14|0));
           $260 = __THREW__; __THREW__ = 0;
           $261 = $260&1;
           if ($261) {
            label = 48;
            break L6;
           }
           __THREW__ = 0;
           invoke_viddd(3305,($14|0),(+$44),1.0,1.0);
           $262 = __THREW__; __THREW__ = 0;
           $263 = $262&1;
           if ($263) {
            label = 48;
            break L6;
           }
           $264 = ((($247)) + 8|0);
           $265 = ($264|0)==($14|0);
           if ($265) {
            $266 = +HEAPF64[$14>>3];
            HEAPF64[$5>>3] = $266;
            $267 = ((($247)) + 16|0);
            $268 = +HEAPF64[$267>>3];
            HEAPF64[$45>>3] = $268;
            $269 = ((($247)) + 24|0);
            $270 = +HEAPF64[$269>>3];
            HEAPF64[$46>>3] = $270;
            $271 = ((($247)) + 32|0);
            $272 = +HEAPF64[$271>>3];
            HEAPF64[$47>>3] = $272;
            $273 = ((($247)) + 40|0);
            $274 = +HEAPF64[$273>>3];
            HEAPF64[$48>>3] = $274;
            $275 = ((($247)) + 48|0);
            $276 = +HEAPF64[$275>>3];
            HEAPF64[$49>>3] = $276;
            $277 = ((($247)) + 56|0);
            $278 = +HEAPF64[$277>>3];
            HEAPF64[$50>>3] = $278;
            $279 = ((($247)) + 64|0);
            $280 = +HEAPF64[$279>>3];
            HEAPF64[$51>>3] = $280;
            $281 = ((($247)) + 72|0);
            $282 = +HEAPF64[$281>>3];
            HEAPF64[$52>>3] = $282;
            $283 = ((($247)) + 80|0);
            $284 = +HEAPF64[$283>>3];
            HEAPF64[$53>>3] = $284;
            $285 = ((($247)) + 88|0);
            $286 = +HEAPF64[$285>>3];
            HEAPF64[$54>>3] = $286;
            $287 = ((($247)) + 96|0);
            $288 = +HEAPF64[$287>>3];
            HEAPF64[$55>>3] = $288;
            $289 = ((($247)) + 104|0);
            $290 = +HEAPF64[$289>>3];
            HEAPF64[$56>>3] = $290;
            $291 = ((($247)) + 112|0);
            $292 = +HEAPF64[$291>>3];
            HEAPF64[$57>>3] = $292;
            $293 = ((($247)) + 120|0);
            $294 = +HEAPF64[$293>>3];
            HEAPF64[$58>>3] = $294;
            $295 = ((($247)) + 128|0);
            $296 = +HEAPF64[$295>>3];
            HEAPF64[$59>>3] = $296;
            __THREW__ = 0;
            invoke_vii(3302,($14|0),($5|0));
            $297 = __THREW__; __THREW__ = 0;
            $298 = $297&1;
            if ($298) {
             label = 45;
             break L6;
            }
           } else {
            __THREW__ = 0;
            invoke_vii(3302,($264|0),($14|0));
            $301 = __THREW__; __THREW__ = 0;
            $302 = $301&1;
            if ($302) {
             label = 49;
             break L6;
            }
           }
           break L8;
           break;
          }
          case 2:  {
           __THREW__ = 0;
           invoke_vi(3299,($15|0));
           $307 = __THREW__; __THREW__ = 0;
           $308 = $307&1;
           if ($308) {
            label = 59;
            break L6;
           }
           __THREW__ = 0;
           invoke_viddd(3305,($15|0),1.0,(+$38),1.0);
           $309 = __THREW__; __THREW__ = 0;
           $310 = $309&1;
           if ($310) {
            label = 59;
            break L6;
           }
           $311 = ((($247)) + 8|0);
           $312 = ($311|0)==($15|0);
           if ($312) {
            $313 = +HEAPF64[$15>>3];
            HEAPF64[$6>>3] = $313;
            $314 = ((($247)) + 16|0);
            $315 = +HEAPF64[$314>>3];
            HEAPF64[$60>>3] = $315;
            $316 = ((($247)) + 24|0);
            $317 = +HEAPF64[$316>>3];
            HEAPF64[$61>>3] = $317;
            $318 = ((($247)) + 32|0);
            $319 = +HEAPF64[$318>>3];
            HEAPF64[$62>>3] = $319;
            $320 = ((($247)) + 40|0);
            $321 = +HEAPF64[$320>>3];
            HEAPF64[$63>>3] = $321;
            $322 = ((($247)) + 48|0);
            $323 = +HEAPF64[$322>>3];
            HEAPF64[$64>>3] = $323;
            $324 = ((($247)) + 56|0);
            $325 = +HEAPF64[$324>>3];
            HEAPF64[$65>>3] = $325;
            $326 = ((($247)) + 64|0);
            $327 = +HEAPF64[$326>>3];
            HEAPF64[$66>>3] = $327;
            $328 = ((($247)) + 72|0);
            $329 = +HEAPF64[$328>>3];
            HEAPF64[$67>>3] = $329;
            $330 = ((($247)) + 80|0);
            $331 = +HEAPF64[$330>>3];
            HEAPF64[$68>>3] = $331;
            $332 = ((($247)) + 88|0);
            $333 = +HEAPF64[$332>>3];
            HEAPF64[$69>>3] = $333;
            $334 = ((($247)) + 96|0);
            $335 = +HEAPF64[$334>>3];
            HEAPF64[$70>>3] = $335;
            $336 = ((($247)) + 104|0);
            $337 = +HEAPF64[$336>>3];
            HEAPF64[$71>>3] = $337;
            $338 = ((($247)) + 112|0);
            $339 = +HEAPF64[$338>>3];
            HEAPF64[$72>>3] = $339;
            $340 = ((($247)) + 120|0);
            $341 = +HEAPF64[$340>>3];
            HEAPF64[$73>>3] = $341;
            $342 = ((($247)) + 128|0);
            $343 = +HEAPF64[$342>>3];
            HEAPF64[$74>>3] = $343;
            __THREW__ = 0;
            invoke_vii(3302,($15|0),($6|0));
            $344 = __THREW__; __THREW__ = 0;
            $345 = $344&1;
            if ($345) {
             label = 56;
             break L6;
            }
           } else {
            __THREW__ = 0;
            invoke_vii(3302,($311|0),($15|0));
            $348 = __THREW__; __THREW__ = 0;
            $349 = $348&1;
            if ($349) {
             label = 60;
             break L6;
            }
           }
           break L8;
           break;
          }
          default: {
           break L8;
          }
          }
         } else {
          $354 = ((($172)) + 296|0);
          $355 = HEAP32[$354>>2]|0;
          switch ($355|0) {
          case 1:  {
           __THREW__ = 0;
           invoke_vi(3299,($16|0));
           $356 = __THREW__; __THREW__ = 0;
           $357 = $356&1;
           if ($357) {
            label = 71;
            break L6;
           }
           __THREW__ = 0;
           invoke_viddd(3305,($16|0),(+$44),1.0,1.0);
           $358 = __THREW__; __THREW__ = 0;
           $359 = $358&1;
           if ($359) {
            label = 71;
            break L6;
           }
           $360 = ((($172)) + 304|0);
           $361 = ($360|0)==($16|0);
           if ($361) {
            $362 = +HEAPF64[$16>>3];
            HEAPF64[$7>>3] = $362;
            $363 = ((($172)) + 312|0);
            $364 = +HEAPF64[$363>>3];
            HEAPF64[$75>>3] = $364;
            $365 = ((($172)) + 320|0);
            $366 = +HEAPF64[$365>>3];
            HEAPF64[$76>>3] = $366;
            $367 = ((($172)) + 328|0);
            $368 = +HEAPF64[$367>>3];
            HEAPF64[$77>>3] = $368;
            $369 = ((($172)) + 336|0);
            $370 = +HEAPF64[$369>>3];
            HEAPF64[$78>>3] = $370;
            $371 = ((($172)) + 344|0);
            $372 = +HEAPF64[$371>>3];
            HEAPF64[$79>>3] = $372;
            $373 = ((($172)) + 352|0);
            $374 = +HEAPF64[$373>>3];
            HEAPF64[$80>>3] = $374;
            $375 = ((($172)) + 360|0);
            $376 = +HEAPF64[$375>>3];
            HEAPF64[$81>>3] = $376;
            $377 = ((($172)) + 368|0);
            $378 = +HEAPF64[$377>>3];
            HEAPF64[$82>>3] = $378;
            $379 = ((($172)) + 376|0);
            $380 = +HEAPF64[$379>>3];
            HEAPF64[$83>>3] = $380;
            $381 = ((($172)) + 384|0);
            $382 = +HEAPF64[$381>>3];
            HEAPF64[$84>>3] = $382;
            $383 = ((($172)) + 392|0);
            $384 = +HEAPF64[$383>>3];
            HEAPF64[$85>>3] = $384;
            $385 = ((($172)) + 400|0);
            $386 = +HEAPF64[$385>>3];
            HEAPF64[$86>>3] = $386;
            $387 = ((($172)) + 408|0);
            $388 = +HEAPF64[$387>>3];
            HEAPF64[$87>>3] = $388;
            $389 = ((($172)) + 416|0);
            $390 = +HEAPF64[$389>>3];
            HEAPF64[$88>>3] = $390;
            $391 = ((($172)) + 424|0);
            $392 = +HEAPF64[$391>>3];
            HEAPF64[$89>>3] = $392;
            __THREW__ = 0;
            invoke_vii(3302,($16|0),($7|0));
            $393 = __THREW__; __THREW__ = 0;
            $394 = $393&1;
            if ($394) {
             label = 68;
             break L6;
            }
           } else {
            __THREW__ = 0;
            invoke_vii(3302,($360|0),($16|0));
            $397 = __THREW__; __THREW__ = 0;
            $398 = $397&1;
            if ($398) {
             label = 72;
             break L6;
            }
           }
           break L8;
           break;
          }
          case 2:  {
           __THREW__ = 0;
           invoke_vi(3299,($17|0));
           $403 = __THREW__; __THREW__ = 0;
           $404 = $403&1;
           if ($404) {
            label = 82;
            break L6;
           }
           __THREW__ = 0;
           invoke_viddd(3305,($17|0),1.0,(+$38),1.0);
           $405 = __THREW__; __THREW__ = 0;
           $406 = $405&1;
           if ($406) {
            label = 82;
            break L6;
           }
           $407 = ((($172)) + 304|0);
           $408 = ($407|0)==($17|0);
           if ($408) {
            $409 = +HEAPF64[$17>>3];
            HEAPF64[$8>>3] = $409;
            $410 = ((($172)) + 312|0);
            $411 = +HEAPF64[$410>>3];
            HEAPF64[$90>>3] = $411;
            $412 = ((($172)) + 320|0);
            $413 = +HEAPF64[$412>>3];
            HEAPF64[$91>>3] = $413;
            $414 = ((($172)) + 328|0);
            $415 = +HEAPF64[$414>>3];
            HEAPF64[$92>>3] = $415;
            $416 = ((($172)) + 336|0);
            $417 = +HEAPF64[$416>>3];
            HEAPF64[$93>>3] = $417;
            $418 = ((($172)) + 344|0);
            $419 = +HEAPF64[$418>>3];
            HEAPF64[$94>>3] = $419;
            $420 = ((($172)) + 352|0);
            $421 = +HEAPF64[$420>>3];
            HEAPF64[$95>>3] = $421;
            $422 = ((($172)) + 360|0);
            $423 = +HEAPF64[$422>>3];
            HEAPF64[$96>>3] = $423;
            $424 = ((($172)) + 368|0);
            $425 = +HEAPF64[$424>>3];
            HEAPF64[$97>>3] = $425;
            $426 = ((($172)) + 376|0);
            $427 = +HEAPF64[$426>>3];
            HEAPF64[$98>>3] = $427;
            $428 = ((($172)) + 384|0);
            $429 = +HEAPF64[$428>>3];
            HEAPF64[$99>>3] = $429;
            $430 = ((($172)) + 392|0);
            $431 = +HEAPF64[$430>>3];
            HEAPF64[$100>>3] = $431;
            $432 = ((($172)) + 400|0);
            $433 = +HEAPF64[$432>>3];
            HEAPF64[$101>>3] = $433;
            $434 = ((($172)) + 408|0);
            $435 = +HEAPF64[$434>>3];
            HEAPF64[$102>>3] = $435;
            $436 = ((($172)) + 416|0);
            $437 = +HEAPF64[$436>>3];
            HEAPF64[$103>>3] = $437;
            $438 = ((($172)) + 424|0);
            $439 = +HEAPF64[$438>>3];
            HEAPF64[$104>>3] = $439;
            __THREW__ = 0;
            invoke_vii(3302,($17|0),($8|0));
            $440 = __THREW__; __THREW__ = 0;
            $441 = $440&1;
            if ($441) {
             label = 79;
             break L6;
            }
           } else {
            __THREW__ = 0;
            invoke_vii(3302,($407|0),($17|0));
            $444 = __THREW__; __THREW__ = 0;
            $445 = $444&1;
            if ($445) {
             label = 83;
             break L6;
            }
           }
           break L8;
           break;
          }
          default: {
           break L8;
          }
          }
         }
        } else {
         $$sink = $172;
        }
       } while(0);
       $452 = ((($$sink)) + 296|0);
       $453 = HEAP32[$452>>2]|0;
       switch ($453|0) {
       case 1:  {
        __THREW__ = 0;
        invoke_vi(3299,($18|0));
        $454 = __THREW__; __THREW__ = 0;
        $455 = $454&1;
        if ($455) {
         label = 95;
         break L6;
        }
        __THREW__ = 0;
        invoke_viddd(3305,($18|0),(+$44),1.0,1.0);
        $456 = __THREW__; __THREW__ = 0;
        $457 = $456&1;
        if ($457) {
         label = 95;
         break L6;
        }
        $458 = ((($172)) + 304|0);
        $459 = ($458|0)==($18|0);
        if ($459) {
         $460 = +HEAPF64[$18>>3];
         HEAPF64[$9>>3] = $460;
         $461 = ((($172)) + 312|0);
         $462 = +HEAPF64[$461>>3];
         HEAPF64[$135>>3] = $462;
         $463 = ((($172)) + 320|0);
         $464 = +HEAPF64[$463>>3];
         HEAPF64[$136>>3] = $464;
         $465 = ((($172)) + 328|0);
         $466 = +HEAPF64[$465>>3];
         HEAPF64[$137>>3] = $466;
         $467 = ((($172)) + 336|0);
         $468 = +HEAPF64[$467>>3];
         HEAPF64[$138>>3] = $468;
         $469 = ((($172)) + 344|0);
         $470 = +HEAPF64[$469>>3];
         HEAPF64[$139>>3] = $470;
         $471 = ((($172)) + 352|0);
         $472 = +HEAPF64[$471>>3];
         HEAPF64[$140>>3] = $472;
         $473 = ((($172)) + 360|0);
         $474 = +HEAPF64[$473>>3];
         HEAPF64[$141>>3] = $474;
         $475 = ((($172)) + 368|0);
         $476 = +HEAPF64[$475>>3];
         HEAPF64[$142>>3] = $476;
         $477 = ((($172)) + 376|0);
         $478 = +HEAPF64[$477>>3];
         HEAPF64[$143>>3] = $478;
         $479 = ((($172)) + 384|0);
         $480 = +HEAPF64[$479>>3];
         HEAPF64[$144>>3] = $480;
         $481 = ((($172)) + 392|0);
         $482 = +HEAPF64[$481>>3];
         HEAPF64[$145>>3] = $482;
         $483 = ((($172)) + 400|0);
         $484 = +HEAPF64[$483>>3];
         HEAPF64[$146>>3] = $484;
         $485 = ((($172)) + 408|0);
         $486 = +HEAPF64[$485>>3];
         HEAPF64[$147>>3] = $486;
         $487 = ((($172)) + 416|0);
         $488 = +HEAPF64[$487>>3];
         HEAPF64[$148>>3] = $488;
         $489 = ((($172)) + 424|0);
         $490 = +HEAPF64[$489>>3];
         HEAPF64[$149>>3] = $490;
         __THREW__ = 0;
         invoke_vii(3302,($18|0),($9|0));
         $491 = __THREW__; __THREW__ = 0;
         $492 = $491&1;
         if ($492) {
          label = 92;
          break L6;
         }
        } else {
         __THREW__ = 0;
         invoke_vii(3302,($458|0),($18|0));
         $495 = __THREW__; __THREW__ = 0;
         $496 = $495&1;
         if ($496) {
          label = 96;
          break L6;
         }
        }
        break;
       }
       case 2:  {
        __THREW__ = 0;
        invoke_vi(3299,($19|0));
        $501 = __THREW__; __THREW__ = 0;
        $502 = $501&1;
        if ($502) {
         label = 106;
         break L6;
        }
        __THREW__ = 0;
        invoke_viddd(3305,($19|0),1.0,(+$38),1.0);
        $503 = __THREW__; __THREW__ = 0;
        $504 = $503&1;
        if ($504) {
         label = 106;
         break L6;
        }
        $505 = ((($172)) + 304|0);
        $506 = ($505|0)==($19|0);
        if ($506) {
         $507 = +HEAPF64[$19>>3];
         HEAPF64[$10>>3] = $507;
         $508 = ((($172)) + 312|0);
         $509 = +HEAPF64[$508>>3];
         HEAPF64[$150>>3] = $509;
         $510 = ((($172)) + 320|0);
         $511 = +HEAPF64[$510>>3];
         HEAPF64[$151>>3] = $511;
         $512 = ((($172)) + 328|0);
         $513 = +HEAPF64[$512>>3];
         HEAPF64[$152>>3] = $513;
         $514 = ((($172)) + 336|0);
         $515 = +HEAPF64[$514>>3];
         HEAPF64[$153>>3] = $515;
         $516 = ((($172)) + 344|0);
         $517 = +HEAPF64[$516>>3];
         HEAPF64[$154>>3] = $517;
         $518 = ((($172)) + 352|0);
         $519 = +HEAPF64[$518>>3];
         HEAPF64[$155>>3] = $519;
         $520 = ((($172)) + 360|0);
         $521 = +HEAPF64[$520>>3];
         HEAPF64[$156>>3] = $521;
         $522 = ((($172)) + 368|0);
         $523 = +HEAPF64[$522>>3];
         HEAPF64[$157>>3] = $523;
         $524 = ((($172)) + 376|0);
         $525 = +HEAPF64[$524>>3];
         HEAPF64[$158>>3] = $525;
         $526 = ((($172)) + 384|0);
         $527 = +HEAPF64[$526>>3];
         HEAPF64[$159>>3] = $527;
         $528 = ((($172)) + 392|0);
         $529 = +HEAPF64[$528>>3];
         HEAPF64[$160>>3] = $529;
         $530 = ((($172)) + 400|0);
         $531 = +HEAPF64[$530>>3];
         HEAPF64[$161>>3] = $531;
         $532 = ((($172)) + 408|0);
         $533 = +HEAPF64[$532>>3];
         HEAPF64[$162>>3] = $533;
         $534 = ((($172)) + 416|0);
         $535 = +HEAPF64[$534>>3];
         HEAPF64[$163>>3] = $535;
         $536 = ((($172)) + 424|0);
         $537 = +HEAPF64[$536>>3];
         HEAPF64[$164>>3] = $537;
         __THREW__ = 0;
         invoke_vii(3302,($19|0),($10|0));
         $538 = __THREW__; __THREW__ = 0;
         $539 = $538&1;
         if ($539) {
          label = 103;
          break L6;
         }
        } else {
         __THREW__ = 0;
         invoke_vii(3302,($505|0),($19|0));
         $542 = __THREW__; __THREW__ = 0;
         $543 = $542&1;
         if ($543) {
          label = 107;
          break L6;
         }
        }
        break;
       }
       default: {
       }
       }
       if ($246) {
        $548 = ((($245)) + 16|0);
        $549 = HEAP32[$548>>2]|0;
        $550 = ($172|0)==($549|0);
        if ($550) {
         $551 = ((($245)) + 20|0);
         $552 = ((($245)) + 24|0);
         $553 = HEAP32[$552>>2]|0;
         $554 = HEAP32[$551>>2]|0;
         $555 = ($553|0)==($554|0);
         if (!($555)) {
          $$090236 = 0;$$in = $554;
          while(1) {
           $556 = $$in;
           $557 = (((($556) + (($$090236*272)|0)|0)) + 4|0);
           $558 = HEAP32[$557>>2]|0;
           $559 = ($558|0)==(0|0);
           L112: do {
            if (!($559)) {
             $560 = ((($558)) + 136|0);
             $561 = HEAP32[$560>>2]|0;
             $562 = ($561|0)==(0);
             if ($562) {
              switch ($453|0) {
              case 1:  {
               __THREW__ = 0;
               invoke_vi(3299,($20|0));
               $563 = __THREW__; __THREW__ = 0;
               $564 = $563&1;
               if ($564) {
                label = 123;
                break L6;
               }
               __THREW__ = 0;
               invoke_viddd(3305,($20|0),(+$38),1.0,1.0);
               $565 = __THREW__; __THREW__ = 0;
               $566 = $565&1;
               if ($566) {
                label = 123;
                break L6;
               }
               $567 = (((($556) + (($$090236*272)|0)|0)) + 8|0);
               $568 = ($567|0)==($20|0);
               if ($568) {
                $569 = +HEAPF64[$20>>3];
                HEAPF64[$11>>3] = $569;
                $570 = (((($556) + (($$090236*272)|0)|0)) + 16|0);
                $571 = +HEAPF64[$570>>3];
                HEAPF64[$105>>3] = $571;
                $572 = (((($556) + (($$090236*272)|0)|0)) + 24|0);
                $573 = +HEAPF64[$572>>3];
                HEAPF64[$106>>3] = $573;
                $574 = (((($556) + (($$090236*272)|0)|0)) + 32|0);
                $575 = +HEAPF64[$574>>3];
                HEAPF64[$107>>3] = $575;
                $576 = (((($556) + (($$090236*272)|0)|0)) + 40|0);
                $577 = +HEAPF64[$576>>3];
                HEAPF64[$108>>3] = $577;
                $578 = (((($556) + (($$090236*272)|0)|0)) + 48|0);
                $579 = +HEAPF64[$578>>3];
                HEAPF64[$109>>3] = $579;
                $580 = (((($556) + (($$090236*272)|0)|0)) + 56|0);
                $581 = +HEAPF64[$580>>3];
                HEAPF64[$110>>3] = $581;
                $582 = (((($556) + (($$090236*272)|0)|0)) + 64|0);
                $583 = +HEAPF64[$582>>3];
                HEAPF64[$111>>3] = $583;
                $584 = (((($556) + (($$090236*272)|0)|0)) + 72|0);
                $585 = +HEAPF64[$584>>3];
                HEAPF64[$112>>3] = $585;
                $586 = (((($556) + (($$090236*272)|0)|0)) + 80|0);
                $587 = +HEAPF64[$586>>3];
                HEAPF64[$113>>3] = $587;
                $588 = (((($556) + (($$090236*272)|0)|0)) + 88|0);
                $589 = +HEAPF64[$588>>3];
                HEAPF64[$114>>3] = $589;
                $590 = (((($556) + (($$090236*272)|0)|0)) + 96|0);
                $591 = +HEAPF64[$590>>3];
                HEAPF64[$115>>3] = $591;
                $592 = (((($556) + (($$090236*272)|0)|0)) + 104|0);
                $593 = +HEAPF64[$592>>3];
                HEAPF64[$116>>3] = $593;
                $594 = (((($556) + (($$090236*272)|0)|0)) + 112|0);
                $595 = +HEAPF64[$594>>3];
                HEAPF64[$117>>3] = $595;
                $596 = (((($556) + (($$090236*272)|0)|0)) + 120|0);
                $597 = +HEAPF64[$596>>3];
                HEAPF64[$118>>3] = $597;
                $598 = (((($556) + (($$090236*272)|0)|0)) + 128|0);
                $599 = +HEAPF64[$598>>3];
                HEAPF64[$119>>3] = $599;
                __THREW__ = 0;
                invoke_vii(3302,($20|0),($11|0));
                $600 = __THREW__; __THREW__ = 0;
                $601 = $600&1;
                if ($601) {
                 label = 120;
                 break L6;
                }
               } else {
                __THREW__ = 0;
                invoke_vii(3302,($567|0),($20|0));
                $604 = __THREW__; __THREW__ = 0;
                $605 = $604&1;
                if ($605) {
                 label = 124;
                 break L6;
                }
               }
               break L112;
               break;
              }
              case 2:  {
               __THREW__ = 0;
               invoke_vi(3299,($21|0));
               $610 = __THREW__; __THREW__ = 0;
               $611 = $610&1;
               if ($611) {
                label = 134;
                break L6;
               }
               __THREW__ = 0;
               invoke_viddd(3305,($21|0),1.0,(+$44),1.0);
               $612 = __THREW__; __THREW__ = 0;
               $613 = $612&1;
               if ($613) {
                label = 134;
                break L6;
               }
               $614 = (((($556) + (($$090236*272)|0)|0)) + 8|0);
               $615 = ($614|0)==($21|0);
               if ($615) {
                $616 = +HEAPF64[$21>>3];
                HEAPF64[$12>>3] = $616;
                $617 = (((($556) + (($$090236*272)|0)|0)) + 16|0);
                $618 = +HEAPF64[$617>>3];
                HEAPF64[$120>>3] = $618;
                $619 = (((($556) + (($$090236*272)|0)|0)) + 24|0);
                $620 = +HEAPF64[$619>>3];
                HEAPF64[$121>>3] = $620;
                $621 = (((($556) + (($$090236*272)|0)|0)) + 32|0);
                $622 = +HEAPF64[$621>>3];
                HEAPF64[$122>>3] = $622;
                $623 = (((($556) + (($$090236*272)|0)|0)) + 40|0);
                $624 = +HEAPF64[$623>>3];
                HEAPF64[$123>>3] = $624;
                $625 = (((($556) + (($$090236*272)|0)|0)) + 48|0);
                $626 = +HEAPF64[$625>>3];
                HEAPF64[$124>>3] = $626;
                $627 = (((($556) + (($$090236*272)|0)|0)) + 56|0);
                $628 = +HEAPF64[$627>>3];
                HEAPF64[$125>>3] = $628;
                $629 = (((($556) + (($$090236*272)|0)|0)) + 64|0);
                $630 = +HEAPF64[$629>>3];
                HEAPF64[$126>>3] = $630;
                $631 = (((($556) + (($$090236*272)|0)|0)) + 72|0);
                $632 = +HEAPF64[$631>>3];
                HEAPF64[$127>>3] = $632;
                $633 = (((($556) + (($$090236*272)|0)|0)) + 80|0);
                $634 = +HEAPF64[$633>>3];
                HEAPF64[$128>>3] = $634;
                $635 = (((($556) + (($$090236*272)|0)|0)) + 88|0);
                $636 = +HEAPF64[$635>>3];
                HEAPF64[$129>>3] = $636;
                $637 = (((($556) + (($$090236*272)|0)|0)) + 96|0);
                $638 = +HEAPF64[$637>>3];
                HEAPF64[$130>>3] = $638;
                $639 = (((($556) + (($$090236*272)|0)|0)) + 104|0);
                $640 = +HEAPF64[$639>>3];
                HEAPF64[$131>>3] = $640;
                $641 = (((($556) + (($$090236*272)|0)|0)) + 112|0);
                $642 = +HEAPF64[$641>>3];
                HEAPF64[$132>>3] = $642;
                $643 = (((($556) + (($$090236*272)|0)|0)) + 120|0);
                $644 = +HEAPF64[$643>>3];
                HEAPF64[$133>>3] = $644;
                $645 = (((($556) + (($$090236*272)|0)|0)) + 128|0);
                $646 = +HEAPF64[$645>>3];
                HEAPF64[$134>>3] = $646;
                __THREW__ = 0;
                invoke_vii(3302,($21|0),($12|0));
                $647 = __THREW__; __THREW__ = 0;
                $648 = $647&1;
                if ($648) {
                 label = 131;
                 break L6;
                }
               } else {
                __THREW__ = 0;
                invoke_vii(3302,($614|0),($21|0));
                $651 = __THREW__; __THREW__ = 0;
                $652 = $651&1;
                if ($652) {
                 label = 135;
                 break L6;
                }
               }
               break L112;
               break;
              }
              default: {
               break L112;
              }
              }
             }
            }
           } while(0);
           $657 = (($$090236) + 1)|0;
           $658 = HEAP32[$552>>2]|0;
           $659 = HEAP32[$551>>2]|0;
           $660 = (($658) - ($659))|0;
           $661 = (($660|0) / 272)&-1;
           $662 = ($657>>>0)<($661>>>0);
           if ($662) {
            $$090236 = $657;$$in = $659;
           } else {
            break;
           }
          }
         }
        }
       }
      }
     }
    } while(0);
    $663 = ((($664)) + 4|0);
    $$sroa$0182$0 = HEAP32[$663>>2]|0;
    $665 = $$sroa$0182$0;
    $666 = ($665|0)==($40|0);
    if ($666) {
     label = 4;
     break;
    } else {
     $$sroa$0182$0239 = $$sroa$0182$0;$664 = $665;
    }
   }
   switch (label|0) {
    case 4: {
     $$pre246 = HEAP32[$25>>2]|0;
     $$pre248$pre = HEAP32[$24>>2]|0;
     $$pre248 = $$pre248$pre;$166 = $$pre246;
     break L4;
     break;
    }
    case 31: {
     $234 = ___cxa_find_matching_catch_2()|0;
     $235 = tempRet0;
     $$13 = $234;$$13104 = $235;
     $668 = HEAP32[$24>>2]|0;
     __ZNSt3__26__treeIPN3osg8ViewportENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($13,$668);
     ___resumeException($$13|0);
     // unreachable;
     break;
    }
    case 39: {
     $258 = ___cxa_find_matching_catch_2()|0;
     $259 = tempRet0;
     $$13 = $258;$$13104 = $259;
     $668 = HEAP32[$24>>2]|0;
     __ZNSt3__26__treeIPN3osg8ViewportENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($13,$668);
     ___resumeException($$13|0);
     // unreachable;
     break;
    }
    case 45: {
     $299 = ___cxa_find_matching_catch_2()|0;
     $300 = tempRet0;
     $eh$lpad$body154$sink191$index3Z2D = $300;$eh$lpad$body154$sink191$indexZ2D = $299;
     label = 50;
     break;
    }
    case 48: {
     $303 = ___cxa_find_matching_catch_2()|0;
     $304 = tempRet0;
     $eh$lpad$body154$sink191$index3Z2D = $304;$eh$lpad$body154$sink191$indexZ2D = $303;
     label = 50;
     break;
    }
    case 49: {
     $305 = ___cxa_find_matching_catch_2()|0;
     $306 = tempRet0;
     $eh$lpad$body154$sink191$index3Z2D = $306;$eh$lpad$body154$sink191$indexZ2D = $305;
     label = 50;
     break;
    }
    case 56: {
     $346 = ___cxa_find_matching_catch_2()|0;
     $347 = tempRet0;
     $eh$lpad$body147$sink192$index10Z2D = $347;$eh$lpad$body147$sink192$indexZ2D = $346;
     label = 61;
     break;
    }
    case 59: {
     $350 = ___cxa_find_matching_catch_2()|0;
     $351 = tempRet0;
     $eh$lpad$body147$sink192$index10Z2D = $351;$eh$lpad$body147$sink192$indexZ2D = $350;
     label = 61;
     break;
    }
    case 60: {
     $352 = ___cxa_find_matching_catch_2()|0;
     $353 = tempRet0;
     $eh$lpad$body147$sink192$index10Z2D = $353;$eh$lpad$body147$sink192$indexZ2D = $352;
     label = 61;
     break;
    }
    case 68: {
     $395 = ___cxa_find_matching_catch_2()|0;
     $396 = tempRet0;
     $eh$lpad$body140$sink193$index17Z2D = $396;$eh$lpad$body140$sink193$indexZ2D = $395;
     label = 73;
     break;
    }
    case 71: {
     $399 = ___cxa_find_matching_catch_2()|0;
     $400 = tempRet0;
     $eh$lpad$body140$sink193$index17Z2D = $400;$eh$lpad$body140$sink193$indexZ2D = $399;
     label = 73;
     break;
    }
    case 72: {
     $401 = ___cxa_find_matching_catch_2()|0;
     $402 = tempRet0;
     $eh$lpad$body140$sink193$index17Z2D = $402;$eh$lpad$body140$sink193$indexZ2D = $401;
     label = 73;
     break;
    }
    case 79: {
     $442 = ___cxa_find_matching_catch_2()|0;
     $443 = tempRet0;
     $eh$lpad$body133$sink194$index24Z2D = $443;$eh$lpad$body133$sink194$indexZ2D = $442;
     label = 84;
     break;
    }
    case 82: {
     $446 = ___cxa_find_matching_catch_2()|0;
     $447 = tempRet0;
     $eh$lpad$body133$sink194$index24Z2D = $447;$eh$lpad$body133$sink194$indexZ2D = $446;
     label = 84;
     break;
    }
    case 83: {
     $448 = ___cxa_find_matching_catch_2()|0;
     $449 = tempRet0;
     $eh$lpad$body133$sink194$index24Z2D = $449;$eh$lpad$body133$sink194$indexZ2D = $448;
     label = 84;
     break;
    }
    case 92: {
     $493 = ___cxa_find_matching_catch_2()|0;
     $494 = tempRet0;
     $eh$lpad$body126$sink195$index31Z2D = $494;$eh$lpad$body126$sink195$indexZ2D = $493;
     label = 97;
     break;
    }
    case 95: {
     $497 = ___cxa_find_matching_catch_2()|0;
     $498 = tempRet0;
     $eh$lpad$body126$sink195$index31Z2D = $498;$eh$lpad$body126$sink195$indexZ2D = $497;
     label = 97;
     break;
    }
    case 96: {
     $499 = ___cxa_find_matching_catch_2()|0;
     $500 = tempRet0;
     $eh$lpad$body126$sink195$index31Z2D = $500;$eh$lpad$body126$sink195$indexZ2D = $499;
     label = 97;
     break;
    }
    case 103: {
     $540 = ___cxa_find_matching_catch_2()|0;
     $541 = tempRet0;
     $eh$lpad$body118$sink196$index38Z2D = $541;$eh$lpad$body118$sink196$indexZ2D = $540;
     label = 108;
     break;
    }
    case 106: {
     $544 = ___cxa_find_matching_catch_2()|0;
     $545 = tempRet0;
     $eh$lpad$body118$sink196$index38Z2D = $545;$eh$lpad$body118$sink196$indexZ2D = $544;
     label = 108;
     break;
    }
    case 107: {
     $546 = ___cxa_find_matching_catch_2()|0;
     $547 = tempRet0;
     $eh$lpad$body118$sink196$index38Z2D = $547;$eh$lpad$body118$sink196$indexZ2D = $546;
     label = 108;
     break;
    }
    case 120: {
     $602 = ___cxa_find_matching_catch_2()|0;
     $603 = tempRet0;
     $eh$lpad$body111$sink197$index45Z2D = $603;$eh$lpad$body111$sink197$indexZ2D = $602;
     label = 125;
     break;
    }
    case 123: {
     $606 = ___cxa_find_matching_catch_2()|0;
     $607 = tempRet0;
     $eh$lpad$body111$sink197$index45Z2D = $607;$eh$lpad$body111$sink197$indexZ2D = $606;
     label = 125;
     break;
    }
    case 124: {
     $608 = ___cxa_find_matching_catch_2()|0;
     $609 = tempRet0;
     $eh$lpad$body111$sink197$index45Z2D = $609;$eh$lpad$body111$sink197$indexZ2D = $608;
     label = 125;
     break;
    }
    case 131: {
     $649 = ___cxa_find_matching_catch_2()|0;
     $650 = tempRet0;
     $eh$lpad$body$sink198$index52Z2D = $650;$eh$lpad$body$sink198$indexZ2D = $649;
     label = 136;
     break;
    }
    case 134: {
     $653 = ___cxa_find_matching_catch_2()|0;
     $654 = tempRet0;
     $eh$lpad$body$sink198$index52Z2D = $654;$eh$lpad$body$sink198$indexZ2D = $653;
     label = 136;
     break;
    }
    case 135: {
     $655 = ___cxa_find_matching_catch_2()|0;
     $656 = tempRet0;
     $eh$lpad$body$sink198$index52Z2D = $656;$eh$lpad$body$sink198$indexZ2D = $655;
     label = 136;
     break;
    }
   }
   if ((label|0) == 50) {
    $$13 = $eh$lpad$body154$sink191$indexZ2D;$$13104 = $eh$lpad$body154$sink191$index3Z2D;
    $668 = HEAP32[$24>>2]|0;
    __ZNSt3__26__treeIPN3osg8ViewportENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($13,$668);
    ___resumeException($$13|0);
    // unreachable;
   }
   else if ((label|0) == 61) {
    $$13 = $eh$lpad$body147$sink192$indexZ2D;$$13104 = $eh$lpad$body147$sink192$index10Z2D;
    $668 = HEAP32[$24>>2]|0;
    __ZNSt3__26__treeIPN3osg8ViewportENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($13,$668);
    ___resumeException($$13|0);
    // unreachable;
   }
   else if ((label|0) == 73) {
    $$13 = $eh$lpad$body140$sink193$indexZ2D;$$13104 = $eh$lpad$body140$sink193$index17Z2D;
    $668 = HEAP32[$24>>2]|0;
    __ZNSt3__26__treeIPN3osg8ViewportENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($13,$668);
    ___resumeException($$13|0);
    // unreachable;
   }
   else if ((label|0) == 84) {
    $$13 = $eh$lpad$body133$sink194$indexZ2D;$$13104 = $eh$lpad$body133$sink194$index24Z2D;
    $668 = HEAP32[$24>>2]|0;
    __ZNSt3__26__treeIPN3osg8ViewportENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($13,$668);
    ___resumeException($$13|0);
    // unreachable;
   }
   else if ((label|0) == 97) {
    $$13 = $eh$lpad$body126$sink195$indexZ2D;$$13104 = $eh$lpad$body126$sink195$index31Z2D;
    $668 = HEAP32[$24>>2]|0;
    __ZNSt3__26__treeIPN3osg8ViewportENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($13,$668);
    ___resumeException($$13|0);
    // unreachable;
   }
   else if ((label|0) == 108) {
    $$13 = $eh$lpad$body118$sink196$indexZ2D;$$13104 = $eh$lpad$body118$sink196$index38Z2D;
    $668 = HEAP32[$24>>2]|0;
    __ZNSt3__26__treeIPN3osg8ViewportENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($13,$668);
    ___resumeException($$13|0);
    // unreachable;
   }
   else if ((label|0) == 125) {
    $$13 = $eh$lpad$body111$sink197$indexZ2D;$$13104 = $eh$lpad$body111$sink197$index45Z2D;
    $668 = HEAP32[$24>>2]|0;
    __ZNSt3__26__treeIPN3osg8ViewportENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($13,$668);
    ___resumeException($$13|0);
    // unreachable;
   }
   else if ((label|0) == 136) {
    $$13 = $eh$lpad$body$sink198$indexZ2D;$$13104 = $eh$lpad$body$sink198$index52Z2D;
    $668 = HEAP32[$24>>2]|0;
    __ZNSt3__26__treeIPN3osg8ViewportENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($13,$668);
    ___resumeException($$13|0);
    // unreachable;
   }
  }
 } while(0);
 $165 = ((($166)) + 32|0);
 HEAP32[$165>>2] = $1;
 $167 = ((($166)) + 36|0);
 HEAP32[$167>>2] = $2;
 $168 = ((($166)) + 40|0);
 HEAP32[$168>>2] = $3;
 $169 = ((($166)) + 44|0);
 HEAP32[$169>>2] = $4;
 $667 = $$pre248;
 __ZNSt3__26__treeIPN3osg8ViewportENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($13,$667);
 STACKTOP = sp;return;
}
function __ZNSt3__26__treeIPN3osg8ViewportENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 } else {
  $3 = HEAP32[$1>>2]|0;
  __ZNSt3__26__treeIPN3osg8ViewportENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($0,$3);
  $4 = ((($1)) + 4|0);
  $5 = HEAP32[$4>>2]|0;
  __ZNSt3__26__treeIPN3osg8ViewportENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($0,$5);
  __ZdlPv($1);
  return;
 }
}
function __ZN3osg15GraphicsContext5closeEb($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$1$off0 = 0, $$pr = 0, $$sroa$021$0 = 0, $$sroa$021$028 = 0, $$sroa$021$029 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0;
 var $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0;
 var $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0;
 var $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0;
 var $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $2 = sp + 24|0;
 $3 = sp + 20|0;
 $4 = sp + 16|0;
 $5 = sp + 12|0;
 $6 = sp + 8|0;
 $7 = sp + 4|0;
 $8 = sp;
 $9 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
 do {
  if ($9) {
   $10 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
   $11 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($10,142668,6)|0);
   $12 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEb($11,$1)|0);
   $13 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($12,174996,1)|0);
   $14 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEPKv($13,$0)|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = ((($15)) + -12|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (($14) + ($17)|0);
   __ZNKSt3__28ios_base6getlocEv($8,$18);
   __THREW__ = 0;
   $19 = (invoke_iii(3255,($8|0),(215188|0))|0);
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if (!($21)) {
    $22 = HEAP32[$19>>2]|0;
    $23 = ((($22)) + 28|0);
    $24 = HEAP32[$23>>2]|0;
    __THREW__ = 0;
    $25 = (invoke_iii($24|0,($19|0),10)|0);
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if (!($27)) {
     __ZNSt3__26localeD2Ev($8);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($14,$25)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($14)|0);
     break;
    }
   }
   $28 = ___cxa_find_matching_catch_2()|0;
   $29 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($8|0));
   $30 = __THREW__; __THREW__ = 0;
   $31 = $30&1;
   if ($31) {
    $32 = ___cxa_find_matching_catch_3(0|0)|0;
    $33 = tempRet0;
    ___clang_call_terminate($32);
    // unreachable;
   } else {
    ___resumeException($28|0);
    // unreachable;
   }
  }
 } while(0);
 __ZN3osg15GraphicsContext17setGraphicsThreadEPNS_14GraphicsThreadE($0,0);
 $34 = ((($0)) + 48|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = ($35|0)==(0|0);
 if ($36) {
  $$1$off0 = 0;
 } else {
  $37 = ((($35)) + 124|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = (__ZN3osg14getContextDataEj($38)|0);
  $40 = ($39|0)==(0|0);
  if ($40) {
   $$1$off0 = 0;
  } else {
   $41 = ((($39)) + 28|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = ($42>>>0)>(1);
   $$1$off0 = $43;
  }
 }
 $44 = ((($0)) + 36|0);
 $$sroa$021$028 = HEAP32[$44>>2]|0;
 $45 = ((($0)) + 32|0);
 $46 = $$sroa$021$028;
 $47 = ($46|0)==($45|0);
 L15: do {
  if (!($47)) {
   $$sroa$021$029 = $$sroa$021$028;$85 = $46;
   while(1) {
    $50 = $$sroa$021$029;
    $51 = ((($50)) + 8|0);
    $52 = HEAP32[$51>>2]|0;
    $53 = ($52|0)==(0|0);
    if (!($53)) {
     $54 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
     if ($54) {
      $55 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
      $56 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($55,142675,32)|0);
      $57 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEPKv($56,$52)|0);
      $58 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($57,142708,8)|0);
      $59 = HEAP32[$34>>2]|0;
      $60 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEPKv($58,$59)|0);
      $61 = HEAP32[$60>>2]|0;
      $62 = ((($61)) + -12|0);
      $63 = HEAP32[$62>>2]|0;
      $64 = (($60) + ($63)|0);
      __ZNKSt3__28ios_base6getlocEv($7,$64);
      __THREW__ = 0;
      $65 = (invoke_iii(3255,($7|0),(215188|0))|0);
      $66 = __THREW__; __THREW__ = 0;
      $67 = $66&1;
      if ($67) {
       break;
      }
      $68 = HEAP32[$65>>2]|0;
      $69 = ((($68)) + 28|0);
      $70 = HEAP32[$69>>2]|0;
      __THREW__ = 0;
      $71 = (invoke_iii($70|0,($65|0),10)|0);
      $72 = __THREW__; __THREW__ = 0;
      $73 = $72&1;
      if ($73) {
       break;
      }
      __ZNSt3__26localeD2Ev($7);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($60,$71)|0);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($60)|0);
     }
     $80 = HEAP32[$52>>2]|0;
     $81 = ((($80)) + 136|0);
     $82 = HEAP32[$81>>2]|0;
     $83 = HEAP32[$34>>2]|0;
     FUNCTION_TABLE_vii[$82 & 8191]($52,$83);
    }
    $84 = ((($85)) + 4|0);
    $$sroa$021$0 = HEAP32[$84>>2]|0;
    $86 = $$sroa$021$0;
    $87 = ($86|0)==($45|0);
    if ($87) {
     break L15;
    } else {
     $$sroa$021$029 = $$sroa$021$0;$85 = $86;
    }
   }
   $74 = ___cxa_find_matching_catch_2()|0;
   $75 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($7|0));
   $76 = __THREW__; __THREW__ = 0;
   $77 = $76&1;
   if ($77) {
    $78 = ___cxa_find_matching_catch_3(0|0)|0;
    $79 = tempRet0;
    ___clang_call_terminate($78);
    // unreachable;
   } else {
    ___resumeException($74|0);
    // unreachable;
   }
  }
 } while(0);
 $48 = HEAP32[$34>>2]|0;
 $49 = ($48|0)==(0|0);
 if (!($49)) {
  __ZN3osg5State16releaseGLObjectsEv($48);
 }
 if ($1) {
  $88 = HEAP32[$34>>2]|0;
  $89 = ($88|0)==(0|0);
  do {
   if (!($89)) {
    $90 = HEAP32[$0>>2]|0;
    $91 = ((($90)) + 156|0);
    $92 = HEAP32[$91>>2]|0;
    $93 = (FUNCTION_TABLE_ii[$92 & 8191]($0)|0);
    if ($93) {
     $94 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
     do {
      if ($94) {
       $95 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
       $96 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($95,142717,28)|0);
       $97 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEb($96,$$1$off0)|0);
       $98 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($97,142746,24)|0);
       $99 = HEAP32[$34>>2]|0;
       $100 = ((($99)) + 124|0);
       $101 = HEAP32[$100>>2]|0;
       $102 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($98,$101)|0);
       $103 = HEAP32[$102>>2]|0;
       $104 = ((($103)) + -12|0);
       $105 = HEAP32[$104>>2]|0;
       $106 = (($102) + ($105)|0);
       __ZNKSt3__28ios_base6getlocEv($6,$106);
       __THREW__ = 0;
       $107 = (invoke_iii(3255,($6|0),(215188|0))|0);
       $108 = __THREW__; __THREW__ = 0;
       $109 = $108&1;
       if (!($109)) {
        $110 = HEAP32[$107>>2]|0;
        $111 = ((($110)) + 28|0);
        $112 = HEAP32[$111>>2]|0;
        __THREW__ = 0;
        $113 = (invoke_iii($112|0,($107|0),10)|0);
        $114 = __THREW__; __THREW__ = 0;
        $115 = $114&1;
        if (!($115)) {
         __ZNSt3__26localeD2Ev($6);
         (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($102,$113)|0);
         (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($102)|0);
         break;
        }
       }
       $116 = ___cxa_find_matching_catch_2()|0;
       $117 = tempRet0;
       __THREW__ = 0;
       invoke_vi(3263,($6|0));
       $118 = __THREW__; __THREW__ = 0;
       $119 = $118&1;
       if ($119) {
        $120 = ___cxa_find_matching_catch_3(0|0)|0;
        $121 = tempRet0;
        ___clang_call_terminate($120);
        // unreachable;
       } else {
        ___resumeException($116|0);
        // unreachable;
       }
      }
     } while(0);
     $122 = (__ZN11OpenThreads6Thread13CurrentThreadEv()|0);
     $123 = ((($0)) + 72|0);
     HEAP32[$123>>2] = $122;
     $124 = HEAP32[$0>>2]|0;
     $125 = ((($124)) + 164|0);
     $126 = HEAP32[$125>>2]|0;
     $127 = (FUNCTION_TABLE_ii[$126 & 8191]($0)|0);
     if (!($127)) {
      $182 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
      if (!($182)) {
       break;
      }
      $183 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
      $184 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($183,142824,75)|0);
      $185 = HEAP32[$184>>2]|0;
      $186 = ((($185)) + -12|0);
      $187 = HEAP32[$186>>2]|0;
      $188 = (($184) + ($187)|0);
      __ZNKSt3__28ios_base6getlocEv($3,$188);
      __THREW__ = 0;
      $189 = (invoke_iii(3255,($3|0),(215188|0))|0);
      $190 = __THREW__; __THREW__ = 0;
      $191 = $190&1;
      if (!($191)) {
       $192 = HEAP32[$189>>2]|0;
       $193 = ((($192)) + 28|0);
       $194 = HEAP32[$193>>2]|0;
       __THREW__ = 0;
       $195 = (invoke_iii($194|0,($189|0),10)|0);
       $196 = __THREW__; __THREW__ = 0;
       $197 = $196&1;
       if (!($197)) {
        __ZNSt3__26localeD2Ev($3);
        (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($184,$195)|0);
        (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($184)|0);
        break;
       }
      }
      $198 = ___cxa_find_matching_catch_2()|0;
      $199 = tempRet0;
      __THREW__ = 0;
      invoke_vi(3263,($3|0));
      $200 = __THREW__; __THREW__ = 0;
      $201 = $200&1;
      if ($201) {
       $202 = ___cxa_find_matching_catch_3(0|0)|0;
       $203 = tempRet0;
       ___clang_call_terminate($202);
       // unreachable;
      } else {
       ___resumeException($198|0);
       // unreachable;
      }
     }
     $128 = HEAP32[$34>>2]|0;
     __ZN3osg5State24initializeExtensionProcsEv($128);
     do {
      if ($$1$off0) {
       $179 = HEAP32[$34>>2]|0;
       $180 = ((($179)) + 124|0);
       $181 = HEAP32[$180>>2]|0;
       __ZN3osg24flushAllDeletedGLObjectsEj($181);
      } else {
       $129 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
       do {
        if ($129) {
         $130 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
         $131 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($130,142771,26)|0);
         $132 = HEAP32[$131>>2]|0;
         $133 = ((($132)) + -12|0);
         $134 = HEAP32[$133>>2]|0;
         $135 = (($131) + ($134)|0);
         __ZNKSt3__28ios_base6getlocEv($5,$135);
         __THREW__ = 0;
         $136 = (invoke_iii(3255,($5|0),(215188|0))|0);
         $137 = __THREW__; __THREW__ = 0;
         $138 = $137&1;
         if (!($138)) {
          $139 = HEAP32[$136>>2]|0;
          $140 = ((($139)) + 28|0);
          $141 = HEAP32[$140>>2]|0;
          __THREW__ = 0;
          $142 = (invoke_iii($141|0,($136|0),10)|0);
          $143 = __THREW__; __THREW__ = 0;
          $144 = $143&1;
          if (!($144)) {
           __ZNSt3__26localeD2Ev($5);
           (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($131,$142)|0);
           (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($131)|0);
           break;
          }
         }
         $145 = ___cxa_find_matching_catch_2()|0;
         $146 = tempRet0;
         __THREW__ = 0;
         invoke_vi(3263,($5|0));
         $147 = __THREW__; __THREW__ = 0;
         $148 = $147&1;
         if ($148) {
          $149 = ___cxa_find_matching_catch_3(0|0)|0;
          $150 = tempRet0;
          ___clang_call_terminate($149);
          // unreachable;
         } else {
          ___resumeException($145|0);
          // unreachable;
         }
        }
       } while(0);
       $151 = HEAP32[$34>>2]|0;
       $152 = ((($151)) + 124|0);
       $153 = HEAP32[$152>>2]|0;
       __ZN3osg18deleteAllGLObjectsEj($153);
       $154 = HEAP32[$34>>2]|0;
       $155 = ((($154)) + 124|0);
       $156 = HEAP32[$155>>2]|0;
       __ZN3osg24flushAllDeletedGLObjectsEj($156);
       $157 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
       if ($157) {
        $158 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
        $159 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($158,142798,25)|0);
        $160 = HEAP32[$159>>2]|0;
        $161 = ((($160)) + -12|0);
        $162 = HEAP32[$161>>2]|0;
        $163 = (($159) + ($162)|0);
        __ZNKSt3__28ios_base6getlocEv($4,$163);
        __THREW__ = 0;
        $164 = (invoke_iii(3255,($4|0),(215188|0))|0);
        $165 = __THREW__; __THREW__ = 0;
        $166 = $165&1;
        if (!($166)) {
         $167 = HEAP32[$164>>2]|0;
         $168 = ((($167)) + 28|0);
         $169 = HEAP32[$168>>2]|0;
         __THREW__ = 0;
         $170 = (invoke_iii($169|0,($164|0),10)|0);
         $171 = __THREW__; __THREW__ = 0;
         $172 = $171&1;
         if (!($172)) {
          __ZNSt3__26localeD2Ev($4);
          (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($159,$170)|0);
          (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($159)|0);
          break;
         }
        }
        $173 = ___cxa_find_matching_catch_2()|0;
        $174 = tempRet0;
        __THREW__ = 0;
        invoke_vi(3263,($4|0));
        $175 = __THREW__; __THREW__ = 0;
        $176 = $175&1;
        if ($176) {
         $177 = ___cxa_find_matching_catch_3(0|0)|0;
         $178 = tempRet0;
         ___clang_call_terminate($177);
         // unreachable;
        } else {
         ___resumeException($173|0);
         // unreachable;
        }
       }
      }
     } while(0);
     $204 = HEAP32[$0>>2]|0;
     $205 = ((($204)) + 172|0);
     $206 = HEAP32[$205>>2]|0;
     (FUNCTION_TABLE_ii[$206 & 8191]($0)|0);
     HEAP32[$123>>2] = (-1);
    }
   }
  } while(0);
  $207 = HEAP32[$0>>2]|0;
  $208 = ((($207)) + 160|0);
  $209 = HEAP32[$208>>2]|0;
  FUNCTION_TABLE_vi[$209 & 8191]($0);
 }
 if (!($$1$off0)) {
  $210 = HEAP32[$34>>2]|0;
  $211 = ($210|0)==(0|0);
  if ($211) {
   STACKTOP = sp;return;
  }
  $212 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
  do {
   if ($212) {
    $213 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
    $214 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($213,142900,40)|0);
    $215 = HEAP32[$214>>2]|0;
    $216 = ((($215)) + -12|0);
    $217 = HEAP32[$216>>2]|0;
    $218 = (($214) + ($217)|0);
    __ZNKSt3__28ios_base6getlocEv($2,$218);
    __THREW__ = 0;
    $219 = (invoke_iii(3255,($2|0),(215188|0))|0);
    $220 = __THREW__; __THREW__ = 0;
    $221 = $220&1;
    if (!($221)) {
     $222 = HEAP32[$219>>2]|0;
     $223 = ((($222)) + 28|0);
     $224 = HEAP32[$223>>2]|0;
     __THREW__ = 0;
     $225 = (invoke_iii($224|0,($219|0),10)|0);
     $226 = __THREW__; __THREW__ = 0;
     $227 = $226&1;
     if (!($227)) {
      __ZNSt3__26localeD2Ev($2);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($214,$225)|0);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($214)|0);
      break;
     }
    }
    $228 = ___cxa_find_matching_catch_2()|0;
    $229 = tempRet0;
    __THREW__ = 0;
    invoke_vi(3263,($2|0));
    $230 = __THREW__; __THREW__ = 0;
    $231 = $230&1;
    if ($231) {
     $232 = ___cxa_find_matching_catch_3(0|0)|0;
     $233 = tempRet0;
     ___clang_call_terminate($232);
     // unreachable;
    } else {
     ___resumeException($228|0);
     // unreachable;
    }
   }
  } while(0);
  $234 = HEAP32[$34>>2]|0;
  $235 = ((($234)) + 124|0);
  $236 = HEAP32[$235>>2]|0;
  __ZN3osg19discardAllGLObjectsEj($236);
 }
 $$pr = HEAP32[$34>>2]|0;
 $237 = ($$pr|0)==(0|0);
 if ($237) {
  STACKTOP = sp;return;
 }
 $238 = ((($$pr)) + 124|0);
 $239 = HEAP32[$238>>2]|0;
 __ZN3osg11ContextData28decrementContextIDUsageCountEj($239);
 $240 = HEAP32[$34>>2]|0;
 $241 = ($240|0)==(0|0);
 if ($241) {
  STACKTOP = sp;return;
 }
 HEAP32[$34>>2] = 0;
 $242 = ((($240)) + 8|0);
 $243 = HEAP32[$242>>2]|0;HEAP32[$242>>2] = (($243-1)|0);
 $244 = ($243|0)==(1);
 if (!($244)) {
  STACKTOP = sp;return;
 }
 __ZNK3osg10Referenced24signalObserversAndDeleteEbb($240,1,1);
 STACKTOP = sp;return;
}
function __ZN3osg15GraphicsContext17setGraphicsThreadEPNS_14GraphicsThreadE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$$i$i = 0, $$pr = 0, $$pr$i$i = 0, $$pre = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 108|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==($1|0);
 if ($4) {
  return;
 }
 $5 = ($3|0)==(0|0);
 if ($5) {
  $17 = 0;
 } else {
  $6 = HEAP32[$3>>2]|0;
  $7 = ((($6)) + 16|0);
  $8 = HEAP32[$7>>2]|0;
  (FUNCTION_TABLE_ii[$8 & 8191]($3)|0);
  $9 = HEAP32[$2>>2]|0;
  $10 = ((($9)) + 20|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($11|0)==(0|0);
  if (!($12)) {
   HEAP32[$10>>2] = 0;
   $13 = ((($11)) + 8|0);
   $14 = HEAP32[$13>>2]|0;HEAP32[$13>>2] = (($14-1)|0);
   $15 = ($14|0)==(1);
   if ($15) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($11,1,1);
   }
  }
  $16 = ((($9)) + 24|0);
  HEAP32[$16>>2] = 0;
  $$pre = HEAP32[$2>>2]|0;
  $17 = $$pre;
 }
 $18 = ($17|0)==($1|0);
 if ($18) {
  $26 = $1;
 } else {
  HEAP32[$2>>2] = $1;
  $19 = ($1|0)==(0|0);
  if (!($19)) {
   $20 = ((($1)) + 8|0);
   $21 = HEAP32[$20>>2]|0;HEAP32[$20>>2] = (($21+1)|0);
  }
  $22 = ($17|0)==(0|0);
  if (!($22)) {
   $23 = ((($17)) + 8|0);
   $24 = HEAP32[$23>>2]|0;HEAP32[$23>>2] = (($24-1)|0);
   $25 = ($24|0)==(1);
   if ($25) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($17,1,1);
   }
  }
  $$pr = HEAP32[$2>>2]|0;
  $26 = $$pr;
 }
 $27 = ($26|0)==(0|0);
 if ($27) {
  return;
 }
 $28 = (__ZNK3osg10Referenced22getOrCreateObserverSetEv($0)|0);
 $29 = ((($26)) + 20|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ($30|0)==($28|0);
 if ($31) {
  $39 = $28;
 } else {
  HEAP32[$29>>2] = $28;
  $32 = ($28|0)==(0|0);
  if (!($32)) {
   $33 = ((($28)) + 8|0);
   $34 = HEAP32[$33>>2]|0;HEAP32[$33>>2] = (($34+1)|0);
  }
  $35 = ($30|0)==(0|0);
  if (!($35)) {
   $36 = ((($30)) + 8|0);
   $37 = HEAP32[$36>>2]|0;HEAP32[$36>>2] = (($37-1)|0);
   $38 = ($37|0)==(1);
   if ($38) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($30,1,1);
   }
  }
  $$pr$i$i = HEAP32[$29>>2]|0;
  $39 = $$pr$i$i;
 }
 $40 = ($39|0)==(0|0);
 if ($40) {
  $45 = 0;
 } else {
  $41 = ((($39)) + 24|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = ($42|0)!=(0|0);
  $$$i$i = $43 ? $0 : 0;
  $45 = $$$i$i;
 }
 $44 = ((($26)) + 24|0);
 HEAP32[$44>>2] = $45;
 return;
}
function __ZN3osg23SyncSwapBuffersCallbackD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZN3osg23SyncSwapBuffersCallback25swapBuffersImplementationEPNS_15GraphicsContextE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 180|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vi[$4 & 8191]($1);
 $5 = ((($1)) + 48|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($6)) + 784|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($8)) + 1380|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  return;
 }
 $12 = ((($0)) + 12|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0|0);
 if (!($14)) {
  (FUNCTION_TABLE_iiiii[$10 & 8191]($13,0,1000000000,0)|0);
  $15 = ((($8)) + 1376|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = HEAP32[$12>>2]|0;
  FUNCTION_TABLE_vi[$16 & 8191]($17);
 }
 $18 = ((($8)) + 1368|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (FUNCTION_TABLE_iii[$19 & 8191](37143,0)|0);
 HEAP32[$12>>2] = $20;
 return;
}
function __GLOBAL__sub_I_GraphicsContext_cpp() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF32[52095] = 1.0;
 HEAPF32[(208384)>>2] = 0.0;
 HEAPF32[(208388)>>2] = 0.0;
 HEAPF32[52098] = 0.0;
 HEAPF32[(208396)>>2] = 1.0;
 HEAPF32[(208400)>>2] = 0.0;
 HEAPF32[52101] = 0.0;
 HEAPF32[(208408)>>2] = 0.0;
 HEAPF32[(208412)>>2] = 1.0;
 (__ZN3osg15GraphicsContext28getWindowingSystemInterfacesEv()|0);
 return;
}
function __ZN3osg15GraphicsContext28getWindowingSystemInterfacesEv() {
 var $$0 = 0, $$01 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[206064]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  return (208416|0);
 }
 $2 = (___cxa_guard_acquire(206064)|0);
 $3 = ($2|0)==(0);
 if ($3) {
  return (208416|0);
 }
 __THREW__ = 0;
 $4 = (invoke_ii(3276,24)|0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $14 = ___cxa_find_matching_catch_2()|0;
  $15 = tempRet0;
  $$0 = $15;$$01 = $14;
  ___resumeException($$01|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_vi(3282,($4|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $16 = ___cxa_find_matching_catch_2()|0;
  $17 = tempRet0;
  __ZdlPv($4);
  $$0 = $17;$$01 = $16;
  ___resumeException($$01|0);
  // unreachable;
 } else {
  HEAP32[$4>>2] = (60384);
  $9 = ((($4)) + 12|0);
  HEAP32[$9>>2] = 0;
  $10 = ((($4)) + 16|0);
  HEAP32[$10>>2] = 0;
  $11 = ((($4)) + 20|0);
  HEAP32[$11>>2] = 0;
  HEAP32[52104] = $4;
  $12 = ((($4)) + 8|0);
  $13 = HEAP32[$12>>2]|0;HEAP32[$12>>2] = (($13+1)|0);
  (___cxa_atexit((3799|0),(208416|0),(___dso_handle|0))|0);
  return (208416|0);
 }
 return (0)|0;
}
function __ZN3osg7ref_ptrINS_15GraphicsContext25WindowingSystemInterfacesEED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = ((($1)) + 8|0);
  $4 = HEAP32[$3>>2]|0;HEAP32[$3>>2] = (($4-1)|0);
  $5 = ($4|0)==(1);
  if ($5) {
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($1,1,1);
  }
 }
 HEAP32[$0>>2] = 0;
 return;
}
function __ZN3osg15GraphicsContext25WindowingSystemInterfaces27getWindowingSystemInterfaceERKNSt3__212basic_stringIcNS2_11char_traitsIcEENS2_9allocatorIcEEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$02026$i38 = 0, $$02125$i39 = 0, $$027$i37 = 0, $$1 = 0, $$pre = 0, $$pre27 = 0, $$pre28 = 0, $$sroa$09$021 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp + 8|0;
 $3 = sp + 4|0;
 $4 = sp;
 $5 = ((($0)) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($0)) + 16|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6|0)==($8|0);
 if ($9) {
  $10 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
  if (!($10)) {
   $$1 = 0;
   STACKTOP = sp;return ($$1|0);
  }
  $11 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
  $12 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($11,143035,115)|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ((($13)) + -12|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (($12) + ($15)|0);
  __ZNKSt3__28ios_base6getlocEv($4,$16);
  __THREW__ = 0;
  $17 = (invoke_iii(3255,($4|0),(215188|0))|0);
  $18 = __THREW__; __THREW__ = 0;
  $19 = $18&1;
  if (!($19)) {
   $20 = HEAP32[$17>>2]|0;
   $21 = ((($20)) + 28|0);
   $22 = HEAP32[$21>>2]|0;
   __THREW__ = 0;
   $23 = (invoke_iii($22|0,($17|0),10)|0);
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   if (!($25)) {
    __ZNSt3__26localeD2Ev($4);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($12,$23)|0);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($12)|0);
    $$1 = 0;
    STACKTOP = sp;return ($$1|0);
   }
  }
  $26 = ___cxa_find_matching_catch_2()|0;
  $27 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3263,($4|0));
  $28 = __THREW__; __THREW__ = 0;
  $29 = $28&1;
  if ($29) {
   $30 = ___cxa_find_matching_catch_3(0|0)|0;
   $31 = tempRet0;
   ___clang_call_terminate($30);
   // unreachable;
  } else {
   ___resumeException($26|0);
   // unreachable;
  }
 }
 $32 = ((($1)) + 11|0);
 $33 = HEAP8[$32>>0]|0;
 $34 = ($33<<24>>24)<(0);
 $35 = ((($1)) + 4|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = $33&255;
 $38 = $34 ? $36 : $37;
 $39 = ($38|0)==(0);
 if ($39) {
  $140 = HEAP32[$6>>2]|0;
  $$1 = $140;
  STACKTOP = sp;return ($$1|0);
 }
 $$sroa$09$021 = $6;$49 = $33;$52 = $36;
 L19: while(1) {
  $40 = HEAP32[$$sroa$09$021>>2]|0;
  $41 = ((($40)) + 12|0);
  $42 = ((($41)) + 11|0);
  $43 = HEAP8[$42>>0]|0;
  $44 = ($43<<24>>24)<(0);
  $45 = ((($40)) + 16|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = $43&255;
  $48 = $44 ? $46 : $47;
  $50 = ($49<<24>>24)<(0);
  $51 = $49&255;
  $53 = $50 ? $52 : $51;
  $54 = ($48|0)==($53|0);
  do {
   if ($54) {
    $55 = HEAP32[$41>>2]|0;
    $56 = $44 ? $55 : $41;
    $57 = HEAP32[$1>>2]|0;
    $58 = $50 ? $57 : $1;
    $59 = ($48|0)==(0);
    if ($44) {
     if ($59) {
      $$1 = $40;
      label = 36;
      break L19;
     }
     $70 = (_memcmp($56,$58,$48)|0);
     $phitmp$i = ($70|0)==(0);
     if ($phitmp$i) {
      $$1 = $40;
      label = 36;
      break L19;
     } else {
      break;
     }
    }
    if ($59) {
     $$1 = $40;
     label = 36;
     break L19;
    }
    $60 = $55;
    $61 = $60&255;
    $62 = HEAP8[$58>>0]|0;
    $63 = ($61<<24>>24)==($62<<24>>24);
    if ($63) {
     $$02026$i38 = $41;$$02125$i39 = $47;$$027$i37 = $58;
     while(1) {
      $64 = (($$02125$i39) + -1)|0;
      $65 = ((($$02026$i38)) + 1|0);
      $66 = ($64|0)==(0);
      if ($66) {
       $$1 = $40;
       label = 36;
       break L19;
      }
      $67 = ((($$027$i37)) + 1|0);
      $$pre28 = HEAP8[$65>>0]|0;
      $68 = HEAP8[$67>>0]|0;
      $69 = ($$pre28<<24>>24)==($68<<24>>24);
      if ($69) {
       $$02026$i38 = $65;$$02125$i39 = $64;$$027$i37 = $67;
      } else {
       break;
      }
     }
    }
   }
  } while(0);
  $71 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
  if ($71) {
   $72 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
   $73 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($72,143151,19)|0);
   $74 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($73,143171,63)|0);
   $75 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($74,143235,8)|0);
   $76 = HEAP32[$$sroa$09$021>>2]|0;
   $77 = ((($76)) + 12|0);
   $78 = ((($77)) + 11|0);
   $79 = HEAP8[$78>>0]|0;
   $80 = ($79<<24>>24)<(0);
   $81 = HEAP32[$77>>2]|0;
   $82 = $80 ? $81 : $77;
   $83 = ((($76)) + 16|0);
   $84 = HEAP32[$83>>2]|0;
   $85 = $79&255;
   $86 = $80 ? $84 : $85;
   $87 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($75,$82,$86)|0);
   $88 = HEAP32[$87>>2]|0;
   $89 = ((($88)) + -12|0);
   $90 = HEAP32[$89>>2]|0;
   $91 = (($87) + ($90)|0);
   __ZNKSt3__28ios_base6getlocEv($2,$91);
   __THREW__ = 0;
   $92 = (invoke_iii(3255,($2|0),(215188|0))|0);
   $93 = __THREW__; __THREW__ = 0;
   $94 = $93&1;
   if ($94) {
    label = 22;
    break;
   }
   $95 = HEAP32[$92>>2]|0;
   $96 = ((($95)) + 28|0);
   $97 = HEAP32[$96>>2]|0;
   __THREW__ = 0;
   $98 = (invoke_iii($97|0,($92|0),10)|0);
   $99 = __THREW__; __THREW__ = 0;
   $100 = $99&1;
   if ($100) {
    label = 22;
    break;
   }
   __ZNSt3__26localeD2Ev($2);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($87,$98)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($87)|0);
  }
  $107 = ((($$sroa$09$021)) + 4|0);
  $108 = HEAP32[$7>>2]|0;
  $109 = ($107|0)==($108|0);
  if ($109) {
   label = 28;
   break;
  }
  $$pre = HEAP8[$32>>0]|0;
  $$pre27 = HEAP32[$35>>2]|0;
  $$sroa$09$021 = $107;$49 = $$pre;$52 = $$pre27;
 }
 if ((label|0) == 22) {
  $101 = ___cxa_find_matching_catch_2()|0;
  $102 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3263,($2|0));
  $103 = __THREW__; __THREW__ = 0;
  $104 = $103&1;
  if ($104) {
   $105 = ___cxa_find_matching_catch_3(0|0)|0;
   $106 = tempRet0;
   ___clang_call_terminate($105);
   // unreachable;
  } else {
   ___resumeException($101|0);
   // unreachable;
  }
 }
 else if ((label|0) == 28) {
  $110 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
  if (!($110)) {
   $$1 = 0;
   STACKTOP = sp;return ($$1|0);
  }
  $111 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
  $112 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($111,143244,120)|0);
  $113 = HEAP8[$32>>0]|0;
  $114 = ($113<<24>>24)<(0);
  $115 = HEAP32[$1>>2]|0;
  $116 = $114 ? $115 : $1;
  $117 = HEAP32[$35>>2]|0;
  $118 = $113&255;
  $119 = $114 ? $117 : $118;
  $120 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($112,$116,$119)|0);
  $121 = HEAP32[$120>>2]|0;
  $122 = ((($121)) + -12|0);
  $123 = HEAP32[$122>>2]|0;
  $124 = (($120) + ($123)|0);
  __ZNKSt3__28ios_base6getlocEv($3,$124);
  __THREW__ = 0;
  $125 = (invoke_iii(3255,($3|0),(215188|0))|0);
  $126 = __THREW__; __THREW__ = 0;
  $127 = $126&1;
  if (!($127)) {
   $128 = HEAP32[$125>>2]|0;
   $129 = ((($128)) + 28|0);
   $130 = HEAP32[$129>>2]|0;
   __THREW__ = 0;
   $131 = (invoke_iii($130|0,($125|0),10)|0);
   $132 = __THREW__; __THREW__ = 0;
   $133 = $132&1;
   if (!($133)) {
    __ZNSt3__26localeD2Ev($3);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($120,$131)|0);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($120)|0);
    $$1 = 0;
    STACKTOP = sp;return ($$1|0);
   }
  }
  $134 = ___cxa_find_matching_catch_2()|0;
  $135 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3263,($3|0));
  $136 = __THREW__; __THREW__ = 0;
  $137 = $136&1;
  if ($137) {
   $138 = ___cxa_find_matching_catch_3(0|0)|0;
   $139 = tempRet0;
   ___clang_call_terminate($138);
   // unreachable;
  } else {
   ___resumeException($134|0);
   // unreachable;
  }
 }
 else if ((label|0) == 36) {
  STACKTOP = sp;return ($$1|0);
 }
 return (0)|0;
}
function __ZN3osg15GraphicsContext27getWindowingSystemInterfaceERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN3osg15GraphicsContext28getWindowingSystemInterfacesEv()|0);
 $1 = HEAP32[52104]|0;
 $2 = (__ZN3osg15GraphicsContext25WindowingSystemInterfaces27getWindowingSystemInterfaceERKNSt3__212basic_stringIcNS2_11char_traitsIcEENS2_9allocatorIcEEEE($1,$0)|0);
 return ($2|0);
}
function __ZN3osg15GraphicsContext21createGraphicsContextEPNS0_6TraitsE($0) {
 $0 = $0|0;
 var $$0 = 0, $$07 = 0, $$0818 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $2 = ($0|0)!=(0|0);
 if ($2) {
  $3 = ((($0)) + 48|0);
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_($1,$3);
 } else {
  ;HEAP32[$1>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;
 }
 __THREW__ = 0;
 (invoke_i(3800)|0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = HEAP32[52104]|0;
  __THREW__ = 0;
  $7 = (invoke_iii(3801,($6|0),($1|0))|0);
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   $10 = ($7|0)==(0|0);
   if (!($10)) {
    $11 = ((($7)) + 8|0);
    $12 = HEAP32[$11>>2]|0;HEAP32[$11>>2] = (($12+1)|0);
   }
   $13 = ((($1)) + 11|0);
   $14 = HEAP8[$13>>0]|0;
   $15 = ($14<<24>>24)<(0);
   if ($15) {
    $16 = HEAP32[$1>>2]|0;
    __ZdlPv($16);
   }
   if ($10) {
    $$0818 = 0;
    STACKTOP = sp;return ($$0818|0);
   }
   if ($2) {
    $17 = ((($0)) + 24|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = ($18|0)<(0);
    if ($19) {
     HEAP32[$17>>2] = 0;
    }
    $20 = ((($0)) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = ($21|0)<(0);
    if ($22) {
     HEAP32[$20>>2] = 0;
    }
   }
   $36 = HEAP32[$7>>2]|0;
   $37 = ((($36)) + 36|0);
   $38 = HEAP32[$37>>2]|0;
   __THREW__ = 0;
   $39 = (invoke_iii($38|0,($7|0),($0|0))|0);
   $40 = __THREW__; __THREW__ = 0;
   $41 = $40&1;
   if (!($41)) {
    $42 = ((($7)) + 8|0);
    $43 = HEAP32[$42>>2]|0;HEAP32[$42>>2] = (($43-1)|0);
    $44 = ($43|0)==(1);
    if (!($44)) {
     $$0818 = $39;
     STACKTOP = sp;return ($$0818|0);
    }
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($7,1,1);
    $$0818 = $39;
    STACKTOP = sp;return ($$0818|0);
   }
   $29 = ___cxa_find_matching_catch_2()|0;
   $30 = tempRet0;
   $31 = ((($7)) + 8|0);
   $32 = HEAP32[$31>>2]|0;HEAP32[$31>>2] = (($32-1)|0);
   $33 = ($32|0)==(1);
   if ($33) {
    __THREW__ = 0;
    invoke_viii(3262,($7|0),1,1);
    $34 = __THREW__; __THREW__ = 0;
    $35 = $34&1;
    if ($35) {
     $45 = ___cxa_find_matching_catch_3(0|0)|0;
     $46 = tempRet0;
     ___clang_call_terminate($45);
     // unreachable;
    }
   }
   $$0 = $30;$$07 = $29;
   ___resumeException($$07|0);
   // unreachable;
  }
 }
 $23 = ___cxa_find_matching_catch_2()|0;
 $24 = tempRet0;
 $25 = ((($1)) + 11|0);
 $26 = HEAP8[$25>>0]|0;
 $27 = ($26<<24>>24)<(0);
 if ($27) {
  $28 = HEAP32[$1>>2]|0;
  __ZdlPv($28);
 }
 $$0 = $24;$$07 = $23;
 ___resumeException($$07|0);
 // unreachable;
 return (0)|0;
}
function __ZN3osg15GraphicsContext16ScreenIdentifierC2Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 ;HEAP32[$0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;HEAP32[$0+16>>2]=0|0;
 return;
}
function __ZN3osg15GraphicsContext16ScreenIdentifier11readDISPLAYEv($0) {
 $0 = $0|0;
 var $$016$i$i = 0, $$017$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $2 = (_getenv((143365|0))|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 ;HEAP32[$1>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;
 $4 = (_strlen($2)|0);
 $5 = ($4>>>0)>(4294967279);
 if ($5) {
  __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv($1);
  // unreachable;
 }
 $6 = ($4>>>0)<(11);
 if ($6) {
  $13 = $4&255;
  $14 = ((($1)) + 11|0);
  HEAP8[$14>>0] = $13;
  $15 = ($4|0)==(0);
  if ($15) {
   $$017$i$i = $1;
  } else {
   $$016$i$i = $1;
   label = 7;
  }
 } else {
  $7 = (($4) + 16)|0;
  $8 = $7 & -16;
  $9 = (__Znwj($8)|0);
  HEAP32[$1>>2] = $9;
  $10 = $8 | -2147483648;
  $11 = ((($1)) + 8|0);
  HEAP32[$11>>2] = $10;
  $12 = ((($1)) + 4|0);
  HEAP32[$12>>2] = $4;
  $$016$i$i = $9;
  label = 7;
 }
 if ((label|0) == 7) {
  _memcpy(($$016$i$i|0),($2|0),($4|0))|0;
  $$017$i$i = $$016$i$i;
 }
 $16 = (($$017$i$i) + ($4)|0);
 HEAP8[$16>>0] = 0;
 __THREW__ = 0;
 invoke_vii(3802,($0|0),($1|0));
 $17 = __THREW__; __THREW__ = 0;
 $18 = $17&1;
 if ($18) {
  $23 = ___cxa_find_matching_catch_2()|0;
  $24 = tempRet0;
  $25 = ((($1)) + 11|0);
  $26 = HEAP8[$25>>0]|0;
  $27 = ($26<<24>>24)<(0);
  if (!($27)) {
   ___resumeException($23|0);
   // unreachable;
  }
  $28 = HEAP32[$1>>2]|0;
  __ZdlPv($28);
  ___resumeException($23|0);
  // unreachable;
 } else {
  $19 = ((($1)) + 11|0);
  $20 = HEAP8[$19>>0]|0;
  $21 = ($20<<24>>24)<(0);
  if ($21) {
   $22 = HEAP32[$1>>2]|0;
   __ZdlPv($22);
  }
  STACKTOP = sp;return;
 }
}
function __ZN3osg15GraphicsContext16ScreenIdentifier19setScreenIdentifierERKNSt3__212basic_stringIcNS2_11char_traitsIcEENS2_9allocatorIcEEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $or$cond = 0, $or$cond44 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $2 = sp + 24|0;
 $3 = sp + 12|0;
 $4 = sp;
 $5 = (__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5rfindEcj($1,58,-1)|0);
 $6 = (__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5rfindEcj($1,46,-1)|0);
 $7 = ($6|0)!=(-1);
 $8 = ($5|0)!=(-1);
 $or$cond = $8 & $7;
 $9 = ($6>>>0)<($5>>>0);
 $or$cond44 = $9 & $or$cond;
 $$0 = $or$cond44 ? -1 : $6;
 $10 = ($5|0)==(-1);
 do {
  if ($10) {
   (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($0,221531)|0);
  } else {
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_jjRKS4_($2,$1,0,$5,$1);
   __THREW__ = 0;
   (invoke_iii(3477,($0|0),($2|0))|0);
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if (!($12)) {
    $13 = ((($2)) + 11|0);
    $14 = HEAP8[$13>>0]|0;
    $15 = ($14<<24>>24)<(0);
    if ($15) {
     $16 = HEAP32[$2>>2]|0;
     __ZdlPv($16);
    }
    break;
   }
   $17 = ___cxa_find_matching_catch_2()|0;
   $18 = tempRet0;
   $19 = ((($2)) + 11|0);
   $20 = HEAP8[$19>>0]|0;
   $21 = ($20<<24>>24)<(0);
   if (!($21)) {
    ___resumeException($17|0);
    // unreachable;
   }
   $22 = HEAP32[$2>>2]|0;
   __ZdlPv($22);
   ___resumeException($17|0);
   // unreachable;
  }
 } while(0);
 $23 = (($5) + 1)|0;
 $24 = ($$0|0)==(-1);
 do {
  if ($24) {
   $25 = ((($1)) + 11|0);
   $26 = HEAP8[$25>>0]|0;
   $27 = ($26<<24>>24)<(0);
   if ($27) {
    $28 = ((($1)) + 4|0);
    $29 = HEAP32[$28>>2]|0;
    $31 = $29;
    break;
   } else {
    $30 = $26&255;
    $31 = $30;
    break;
   }
  } else {
   $31 = $$0;
  }
 } while(0);
 $32 = ($31>>>0)>($23>>>0);
 if ($32) {
  $33 = (($31) - ($23))|0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_jjRKS4_($3,$1,$23,$33,$1);
  $34 = ((($3)) + 11|0);
  $35 = HEAP8[$34>>0]|0;
  $36 = ($35<<24>>24)<(0);
  $37 = HEAP32[$3>>2]|0;
  $38 = $36 ? $37 : $3;
  $39 = (_atoi($38)|0);
  $40 = ((($0)) + 12|0);
  HEAP32[$40>>2] = $39;
  if ($36) {
   __ZdlPv($37);
  }
 } else {
  $41 = ((($0)) + 12|0);
  HEAP32[$41>>2] = -1;
 }
 if (!($24)) {
  $42 = (($$0) + 1)|0;
  $43 = ((($1)) + 11|0);
  $44 = HEAP8[$43>>0]|0;
  $45 = ($44<<24>>24)<(0);
  $46 = ((($1)) + 4|0);
  $47 = HEAP32[$46>>2]|0;
  $48 = $44&255;
  $49 = $45 ? $47 : $48;
  $50 = ($42>>>0)<($49>>>0);
  if ($50) {
   $51 = $$0 ^ -1;
   $52 = (($49) + ($51))|0;
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_jjRKS4_($4,$1,$42,$52,$1);
   $53 = ((($4)) + 11|0);
   $54 = HEAP8[$53>>0]|0;
   $55 = ($54<<24>>24)<(0);
   $56 = HEAP32[$4>>2]|0;
   $57 = $55 ? $56 : $4;
   $58 = (_atoi($57)|0);
   $59 = ((($0)) + 16|0);
   HEAP32[$59>>2] = $58;
   if (!($55)) {
    STACKTOP = sp;return;
   }
   __ZdlPv($56);
   STACKTOP = sp;return;
  }
 }
 $60 = ((($0)) + 16|0);
 HEAP32[$60>>2] = -1;
 STACKTOP = sp;return;
}
function __ZN3osg15GraphicsContext6TraitsC2EPNS_15DisplaySettingsE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$013 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 __ZN3osg10ReferencedC2Ev($0);
 $3 = ((($0)) + 12|0);
 ;HEAP32[$3>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;HEAP32[$3+12>>2]=0|0;HEAP32[$3+16>>2]=0|0;
 HEAP32[$0>>2] = (60624);
 $4 = ((($0)) + 32|0);
 $5 = ((($0)) + 48|0);
 $6 = ((($0)) + 60|0);
 $7 = ((($0)) + 73|0);
 dest=$4; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));HEAP8[$4+40>>0]=0|0;
 HEAP8[$7>>0] = 1;
 $8 = ((($0)) + 76|0);
 HEAP32[$8>>2] = 8;
 $9 = ((($0)) + 80|0);
 HEAP32[$9>>2] = 8;
 $10 = ((($0)) + 84|0);
 HEAP32[$10>>2] = 8;
 $11 = ((($0)) + 88|0);
 HEAP32[$11>>2] = 0;
 $12 = ((($0)) + 92|0);
 HEAP32[$12>>2] = 24;
 $13 = ((($0)) + 96|0);
 $14 = ((($0)) + 100|0);
 $15 = ((($0)) + 104|0);
 $16 = ((($0)) + 109|0);
 $17 = ((($0)) + 112|0);
 $18 = ((($0)) + 132|0);
 ;HEAP32[$13>>2]=0|0;HEAP32[$13+4>>2]=0|0;HEAP32[$13+8>>2]=0|0;HEAP16[$13+12>>1]=0|0;HEAP8[$13+14>>0]=0|0;
 ;HEAP32[$17>>2]=0|0;HEAP32[$17+4>>2]=0|0;HEAP32[$17+8>>2]=0|0;HEAP32[$17+12>>2]=0|0;HEAP32[$17+16>>2]=0|0;
 HEAP8[$18>>0] = 1;
 $19 = ((($0)) + 133|0);
 HEAP8[$19>>0] = 0;
 $20 = ((($0)) + 136|0);
 HEAP32[$20>>2] = 0;
 $21 = ((($0)) + 140|0);
 HEAP32[$21>>2] = 0;
 $22 = ((($0)) + 144|0);
 HEAP8[$22>>0] = 0;
 $23 = ((($0)) + 145|0);
 HEAP8[$23>>0] = 1;
 $24 = ((($0)) + 148|0);
 $25 = ((($0)) + 152|0);
 $26 = $25;
 $27 = $26;
 HEAP32[$27>>2] = 0;
 $28 = (($26) + 4)|0;
 $29 = $28;
 HEAP32[$29>>2] = 0;
 $30 = ((($24)) + 11|0);
 HEAP8[$30>>0] = 3;
 ;HEAP8[$24>>0]=HEAP8[143373>>0]|0;HEAP8[$24+1>>0]=HEAP8[143373+1>>0]|0;HEAP8[$24+2>>0]=HEAP8[143373+2>>0]|0;
 $31 = ((($24)) + 3|0);
 HEAP8[$31>>0] = 0;
 $32 = ((($0)) + 160|0);
 $33 = ((($0)) + 164|0);
 $34 = ((($0)) + 168|0);
 $35 = ((($0)) + 176|0);
 $36 = ((($0)) + 184|0);
 HEAP32[$36>>2] = 0;
 $37 = ((($0)) + 188|0);
 $38 = ((($0)) + 192|0);
 HEAP32[$38>>2] = 0;
 $39 = ((($0)) + 196|0);
 HEAP32[$39>>2] = 0;
 $40 = ((($0)) + 192|0);
 ;HEAP32[$32>>2]=0|0;HEAP32[$32+4>>2]=0|0;HEAP32[$32+8>>2]=0|0;HEAP32[$32+12>>2]=0|0;HEAP32[$32+16>>2]=0|0;HEAP16[$32+20>>1]=0|0;
 HEAP32[$37>>2] = $40;
 $41 = ($1|0)==(0|0);
 if ($41) {
  STACKTOP = sp;return;
 }
 $42 = ((($1)) + 60|0);
 $43 = HEAP32[$42>>2]|0;
 HEAP32[$11>>2] = $43;
 $44 = ((($1)) + 64|0);
 $45 = HEAP32[$44>>2]|0;
 HEAP32[$13>>2] = $45;
 $46 = ((($1)) + 88|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = ($47|0)==(0);
 if (!($48)) {
  HEAP32[$14>>2] = 1;
 }
 HEAP32[$15>>2] = $47;
 $49 = ((($1)) + 16|0);
 $50 = HEAP8[$49>>0]|0;
 $51 = ($50<<24>>24)==(0);
 L7: do {
  if (!($51)) {
   $52 = ((($1)) + 20|0);
   $53 = HEAP32[$52>>2]|0;
   switch ($53|0) {
   case 0:  {
    HEAP8[$16>>0] = 1;
    break L7;
    break;
   }
   case 6: case 8: case 7:  {
    HEAP32[$13>>2] = 8;
    break L7;
    break;
   }
   default: {
    break L7;
   }
   }
  }
 } while(0);
 $54 = ((($1)) + 132|0);
 __THREW__ = 0;
 invoke_vii(3457,($2|0),($54|0));
 $55 = __THREW__; __THREW__ = 0;
 $56 = $55&1;
 do {
  if ($56) {
   $69 = ___cxa_find_matching_catch_2()|0;
   $70 = tempRet0;
   $$0 = $70;$$013 = $69;
  } else {
   __THREW__ = 0;
   (invoke_iii(3477,($24|0),($2|0))|0);
   $57 = __THREW__; __THREW__ = 0;
   $58 = $57&1;
   if ($58) {
    $71 = ___cxa_find_matching_catch_2()|0;
    $72 = tempRet0;
    $73 = ((($2)) + 11|0);
    $74 = HEAP8[$73>>0]|0;
    $75 = ($74<<24>>24)<(0);
    if (!($75)) {
     $$0 = $72;$$013 = $71;
     break;
    }
    $76 = HEAP32[$2>>2]|0;
    __ZdlPv($76);
    $$0 = $72;$$013 = $71;
    break;
   }
   $59 = ((($2)) + 11|0);
   $60 = HEAP8[$59>>0]|0;
   $61 = ($60<<24>>24)<(0);
   if ($61) {
    $62 = HEAP32[$2>>2]|0;
    __ZdlPv($62);
   }
   $63 = ((($1)) + 144|0);
   $64 = HEAP32[$63>>2]|0;
   HEAP32[$32>>2] = $64;
   $65 = ((($1)) + 148|0);
   $66 = HEAP32[$65>>2]|0;
   HEAP32[$33>>2] = $66;
   $67 = ((($1)) + 152|0);
   $68 = HEAP32[$67>>2]|0;
   HEAP32[$36>>2] = $68;
   STACKTOP = sp;return;
  }
 } while(0);
 $77 = HEAP32[$40>>2]|0;
 __ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEE7destroyEPNS_11__tree_nodeIjPvEE($37,$77);
 $78 = HEAP32[$35>>2]|0;
 $79 = ($78|0)==(0|0);
 if (!($79)) {
  $80 = ((($78)) + 8|0);
  $81 = HEAP32[$80>>2]|0;HEAP32[$80>>2] = (($81-1)|0);
  $82 = ($81|0)==(1);
  if ($82) {
   __THREW__ = 0;
   invoke_viii(3262,($78|0),1,1);
   $83 = __THREW__; __THREW__ = 0;
   $84 = $83&1;
   if ($84) {
    $109 = ___cxa_find_matching_catch_3(0|0)|0;
    $110 = tempRet0;
    ___clang_call_terminate($109);
    // unreachable;
   }
  }
 }
 HEAP32[$35>>2] = 0;
 $85 = HEAP32[$34>>2]|0;
 $86 = ($85|0)==(0|0);
 if (!($86)) {
  $87 = ((($85)) + 8|0);
  $88 = HEAP32[$87>>2]|0;HEAP32[$87>>2] = (($88-1)|0);
  $89 = ($88|0)==(1);
  if ($89) {
   __THREW__ = 0;
   invoke_viii(3262,($85|0),1,1);
   $90 = __THREW__; __THREW__ = 0;
   $91 = $90&1;
   if ($91) {
    $109 = ___cxa_find_matching_catch_3(0|0)|0;
    $110 = tempRet0;
    ___clang_call_terminate($109);
    // unreachable;
   }
  }
 }
 HEAP32[$34>>2] = 0;
 $92 = HEAP8[$30>>0]|0;
 $93 = ($92<<24>>24)<(0);
 if ($93) {
  $94 = HEAP32[$24>>2]|0;
  __ZdlPv($94);
 }
 $95 = ((($6)) + 11|0);
 $96 = HEAP8[$95>>0]|0;
 $97 = ($96<<24>>24)<(0);
 if ($97) {
  $98 = HEAP32[$6>>2]|0;
  __ZdlPv($98);
 }
 $99 = ((($5)) + 11|0);
 $100 = HEAP8[$99>>0]|0;
 $101 = ($100<<24>>24)<(0);
 if ($101) {
  $102 = HEAP32[$5>>2]|0;
  __ZdlPv($102);
 }
 $103 = ((($3)) + 11|0);
 $104 = HEAP8[$103>>0]|0;
 $105 = ($104<<24>>24)<(0);
 if ($105) {
  $106 = HEAP32[$3>>2]|0;
  __ZdlPv($106);
 }
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $107 = __THREW__; __THREW__ = 0;
 $108 = $107&1;
 if ($108) {
  $109 = ___cxa_find_matching_catch_3(0|0)|0;
  $110 = tempRet0;
  ___clang_call_terminate($109);
  // unreachable;
 } else {
  ___resumeException($$013|0);
  // unreachable;
 }
}
function __ZN3osg15GraphicsContext6TraitsD2Ev($0) {
 $0 = $0|0;
 var $$1 = 0, $$13 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (60624);
 $1 = ((($0)) + 188|0);
 $2 = ((($0)) + 192|0);
 $3 = HEAP32[$2>>2]|0;
 __ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEE7destroyEPNS_11__tree_nodeIjPvEE($1,$3);
 $4 = ((($0)) + 176|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  label = 4;
 } else {
  $7 = ((($5)) + 8|0);
  $8 = HEAP32[$7>>2]|0;HEAP32[$7>>2] = (($8-1)|0);
  $9 = ($8|0)==(1);
  if ($9) {
   __THREW__ = 0;
   invoke_viii(3262,($5|0),1,1);
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if ($11) {
    $42 = ___cxa_find_matching_catch_2()|0;
    $43 = tempRet0;
    $44 = ((($0)) + 168|0);
    $45 = HEAP32[$44>>2]|0;
    $46 = ($45|0)==(0|0);
    if (!($46)) {
     $47 = ((($45)) + 8|0);
     $48 = HEAP32[$47>>2]|0;HEAP32[$47>>2] = (($48-1)|0);
     $49 = ($48|0)==(1);
     if ($49) {
      __THREW__ = 0;
      invoke_viii(3262,($45|0),1,1);
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       $74 = ___cxa_find_matching_catch_3(0|0)|0;
       $75 = tempRet0;
       ___clang_call_terminate($74);
       // unreachable;
      }
     }
    }
    HEAP32[$44>>2] = 0;
    $$1 = $43;$$13 = $42;
   } else {
    label = 4;
   }
  } else {
   label = 4;
  }
 }
 do {
  if ((label|0) == 4) {
   HEAP32[$4>>2] = 0;
   $12 = ((($0)) + 168|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = ($13|0)==(0|0);
   if (!($14)) {
    $15 = ((($13)) + 8|0);
    $16 = HEAP32[$15>>2]|0;HEAP32[$15>>2] = (($16-1)|0);
    $17 = ($16|0)==(1);
    if ($17) {
     __THREW__ = 0;
     invoke_viii(3262,($13|0),1,1);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      $40 = ___cxa_find_matching_catch_2()|0;
      $41 = tempRet0;
      $$1 = $41;$$13 = $40;
      break;
     }
    }
   }
   HEAP32[$12>>2] = 0;
   $20 = ((($0)) + 148|0);
   $21 = ((($20)) + 11|0);
   $22 = HEAP8[$21>>0]|0;
   $23 = ($22<<24>>24)<(0);
   if ($23) {
    $24 = HEAP32[$20>>2]|0;
    __ZdlPv($24);
   }
   $25 = ((($0)) + 60|0);
   $26 = ((($25)) + 11|0);
   $27 = HEAP8[$26>>0]|0;
   $28 = ($27<<24>>24)<(0);
   if ($28) {
    $29 = HEAP32[$25>>2]|0;
    __ZdlPv($29);
   }
   $30 = ((($0)) + 48|0);
   $31 = ((($30)) + 11|0);
   $32 = HEAP8[$31>>0]|0;
   $33 = ($32<<24>>24)<(0);
   if ($33) {
    $34 = HEAP32[$30>>2]|0;
    __ZdlPv($34);
   }
   $35 = ((($0)) + 12|0);
   $36 = ((($35)) + 11|0);
   $37 = HEAP8[$36>>0]|0;
   $38 = ($37<<24>>24)<(0);
   if (!($38)) {
    __ZN3osg10ReferencedD2Ev($0);
    return;
   }
   $39 = HEAP32[$35>>2]|0;
   __ZdlPv($39);
   __ZN3osg10ReferencedD2Ev($0);
   return;
  }
 } while(0);
 $52 = ((($0)) + 148|0);
 $53 = ((($52)) + 11|0);
 $54 = HEAP8[$53>>0]|0;
 $55 = ($54<<24>>24)<(0);
 if ($55) {
  $56 = HEAP32[$52>>2]|0;
  __ZdlPv($56);
 }
 $57 = ((($0)) + 60|0);
 $58 = ((($57)) + 11|0);
 $59 = HEAP8[$58>>0]|0;
 $60 = ($59<<24>>24)<(0);
 if ($60) {
  $61 = HEAP32[$57>>2]|0;
  __ZdlPv($61);
 }
 $62 = ((($0)) + 48|0);
 $63 = ((($62)) + 11|0);
 $64 = HEAP8[$63>>0]|0;
 $65 = ($64<<24>>24)<(0);
 if ($65) {
  $66 = HEAP32[$62>>2]|0;
  __ZdlPv($66);
 }
 $67 = ((($0)) + 12|0);
 $68 = ((($67)) + 11|0);
 $69 = HEAP8[$68>>0]|0;
 $70 = ($69<<24>>24)<(0);
 if ($70) {
  $71 = HEAP32[$67>>2]|0;
  __ZdlPv($71);
 }
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $72 = __THREW__; __THREW__ = 0;
 $73 = $72&1;
 if ($73) {
  $74 = ___cxa_find_matching_catch_3(0|0)|0;
  $75 = tempRet0;
  ___clang_call_terminate($74);
  // unreachable;
 } else {
  ___resumeException($$13|0);
  // unreachable;
 }
}
function __ZN3osg15GraphicsContext6TraitsD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1878,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZN3osg15GraphicsContext18createNewContextIDEv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN3osg11ContextData18createNewContextIDEv()|0);
 return ($0|0);
}
function __ZN3osg15GraphicsContext15getMaxContextIDEv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN3osg11ContextData15getMaxContextIDEv()|0);
 return ($0|0);
}
function __ZN3osg15GraphicsContext28incrementContextIDUsageCountEj($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg11ContextData28incrementContextIDUsageCountEj($0);
 return;
}
function __ZN3osg15GraphicsContext25getOrCreateCompileContextEj($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__ZN3osg11ContextData25getOrCreateCompileContextEj($0)|0);
 return ($1|0);
}
function __ZN3osg15GraphicsContextC2Ev($0) {
 $0 = $0|0;
 var $$0 = 0, $$02 = 0, $$023$i$i = 0, $$023$i$i8 = 0, $$2 = 0, $$24 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg10ReferencedC2Ev($0);
 $1 = ((($0)) + 12|0);
 ;HEAP32[$1>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;
 $2 = ((($0)) + 24|0);
 HEAP32[$2>>2] = 2;
 $3 = ((($0)) + 28|0);
 HEAP32[$3>>2] = 0;
 HEAP32[$0>>2] = (60404);
 $4 = ((($0)) + 32|0);
 HEAP32[$4>>2] = $4;
 $5 = ((($0)) + 36|0);
 HEAP32[$5>>2] = $4;
 $6 = ((($0)) + 40|0);
 $7 = ((($0)) + 44|0);
 $8 = ((($0)) + 48|0);
 $9 = ((($0)) + 64|0);
 ;HEAP32[$6>>2]=0|0;HEAP32[$6+4>>2]=0|0;HEAP32[$6+8>>2]=0|0;HEAP32[$6+12>>2]=0|0;HEAP32[$6+16>>2]=0|0;HEAP32[$6+20>>2]=0|0;
 HEAPF32[$9>>2] = 1.0;
 $10 = ((($0)) + 68|0);
 HEAP32[$10>>2] = 0;
 $11 = ((($0)) + 72|0);
 HEAP32[$11>>2] = 0;
 $12 = ((($0)) + 76|0);
 __THREW__ = 0;
 invoke_vii(3507,($12|0),0);
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 if ($14) {
  $52 = ___cxa_find_matching_catch_2()|0;
  $53 = tempRet0;
  $$2 = $53;$$24 = $52;
 } else {
  $15 = ((($0)) + 88|0);
  HEAP32[$15>>2] = 0;
  $16 = ((($0)) + 92|0);
  HEAP32[$16>>2] = $16;
  $17 = ((($0)) + 96|0);
  HEAP32[$17>>2] = $16;
  $18 = ((($0)) + 100|0);
  $19 = ((($0)) + 104|0);
  $20 = ((($0)) + 108|0);
  $21 = ((($0)) + 112|0);
  $22 = ((($0)) + 116|0);
  ;HEAP32[$18>>2]=0|0;HEAP32[$18+4>>2]=0|0;HEAP32[$18+8>>2]=0|0;HEAP32[$18+12>>2]=0|0;HEAP32[$18+16>>2]=0|0;HEAP32[$18+20>>2]=0|0;HEAP32[$18+24>>2]=0|0;HEAP32[$18+28>>2]=0|0;
  $23 = HEAP32[$0>>2]|0;
  $24 = HEAP32[$23>>2]|0;
  __THREW__ = 0;
  invoke_vii($24|0,($0|0),1);
  $25 = __THREW__; __THREW__ = 0;
  $26 = $25&1;
  do {
   if ($26) {
    label = 12;
   } else {
    __THREW__ = 0;
    $27 = (invoke_ii(3276,40)|0);
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if ($29) {
     label = 12;
    } else {
     __THREW__ = 0;
     invoke_vi(3803,($27|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      $56 = ___cxa_find_matching_catch_2()|0;
      $57 = tempRet0;
      __ZdlPv($27);
      $$0 = $57;$$02 = $56;
      break;
     }
     $32 = HEAP32[$15>>2]|0;
     $33 = ($32|0)==($27|0);
     if (!($33)) {
      HEAP32[$15>>2] = $27;
      $34 = HEAP32[$27>>2]|0;
      $35 = ((($34)) + -12|0);
      $36 = HEAP32[$35>>2]|0;
      $37 = (($27) + ($36)|0);
      $38 = ((($37)) + 8|0);
      $39 = HEAP32[$38>>2]|0;HEAP32[$38>>2] = (($39+1)|0);
      $40 = ($32|0)==(0|0);
      if (!($40)) {
       $41 = HEAP32[$32>>2]|0;
       $42 = ((($41)) + -12|0);
       $43 = HEAP32[$42>>2]|0;
       $44 = (($32) + ($43)|0);
       $45 = ((($44)) + 8|0);
       $46 = HEAP32[$45>>2]|0;HEAP32[$45>>2] = (($46-1)|0);
       $47 = ($46|0)==(1);
       if ($47) {
        __THREW__ = 0;
        invoke_viii(3262,($44|0),1,1);
        $48 = __THREW__; __THREW__ = 0;
        $49 = $48&1;
        if ($49) {
         label = 12;
         break;
        }
       }
      }
     }
     __THREW__ = 0;
     invoke_vi(3804,($0|0));
     $50 = __THREW__; __THREW__ = 0;
     $51 = $50&1;
     if ($51) {
      label = 12;
     } else {
      return;
     }
    }
   }
  } while(0);
  if ((label|0) == 12) {
   $54 = ___cxa_find_matching_catch_2()|0;
   $55 = tempRet0;
   $$0 = $55;$$02 = $54;
  }
  $58 = HEAP32[$22>>2]|0;
  $59 = ($58|0)==(0|0);
  if (!($59)) {
   $60 = ((($58)) + 8|0);
   $61 = HEAP32[$60>>2]|0;HEAP32[$60>>2] = (($61-1)|0);
   $62 = ($61|0)==(1);
   if ($62) {
    __THREW__ = 0;
    invoke_viii(3262,($58|0),1,1);
    $63 = __THREW__; __THREW__ = 0;
    $64 = $63&1;
    if ($64) {
     $159 = ___cxa_find_matching_catch_3(0|0)|0;
     $160 = tempRet0;
     ___clang_call_terminate($159);
     // unreachable;
    }
   }
  }
  HEAP32[$22>>2] = 0;
  $65 = HEAP32[$21>>2]|0;
  $66 = ($65|0)==(0|0);
  if (!($66)) {
   $67 = ((($65)) + 8|0);
   $68 = HEAP32[$67>>2]|0;HEAP32[$67>>2] = (($68-1)|0);
   $69 = ($68|0)==(1);
   if ($69) {
    __THREW__ = 0;
    invoke_viii(3262,($65|0),1,1);
    $70 = __THREW__; __THREW__ = 0;
    $71 = $70&1;
    if ($71) {
     $159 = ___cxa_find_matching_catch_3(0|0)|0;
     $160 = tempRet0;
     ___clang_call_terminate($159);
     // unreachable;
    }
   }
  }
  HEAP32[$21>>2] = 0;
  $72 = HEAP32[$20>>2]|0;
  $73 = ($72|0)==(0|0);
  if (!($73)) {
   $74 = ((($72)) + 8|0);
   $75 = HEAP32[$74>>2]|0;HEAP32[$74>>2] = (($75-1)|0);
   $76 = ($75|0)==(1);
   if ($76) {
    __THREW__ = 0;
    invoke_viii(3262,($72|0),1,1);
    $77 = __THREW__; __THREW__ = 0;
    $78 = $77&1;
    if ($78) {
     $159 = ___cxa_find_matching_catch_3(0|0)|0;
     $160 = tempRet0;
     ___clang_call_terminate($159);
     // unreachable;
    }
   }
  }
  HEAP32[$20>>2] = 0;
  $79 = HEAP32[$19>>2]|0;
  $80 = ($79|0)==(0|0);
  if (!($80)) {
   $81 = HEAP32[$79>>2]|0;
   $82 = ((($81)) + -12|0);
   $83 = HEAP32[$82>>2]|0;
   $84 = (($79) + ($83)|0);
   $85 = ((($84)) + 8|0);
   $86 = HEAP32[$85>>2]|0;HEAP32[$85>>2] = (($86-1)|0);
   $87 = ($86|0)==(1);
   if ($87) {
    __THREW__ = 0;
    invoke_viii(3262,($84|0),1,1);
    $88 = __THREW__; __THREW__ = 0;
    $89 = $88&1;
    if ($89) {
     $159 = ___cxa_find_matching_catch_3(0|0)|0;
     $160 = tempRet0;
     ___clang_call_terminate($159);
     // unreachable;
    }
   }
  }
  HEAP32[$19>>2] = 0;
  $90 = HEAP32[$18>>2]|0;
  $91 = ($90|0)==(0);
  L39: do {
   if (!($91)) {
    $92 = HEAP32[$17>>2]|0;
    $93 = HEAP32[$16>>2]|0;
    $94 = ((($93)) + 4|0);
    $95 = HEAP32[$94>>2]|0;
    $96 = HEAP32[$92>>2]|0;
    $97 = ((($96)) + 4|0);
    HEAP32[$97>>2] = $95;
    $98 = HEAP32[$94>>2]|0;
    HEAP32[$98>>2] = $96;
    HEAP32[$18>>2] = 0;
    $99 = ($92|0)==($16|0);
    if (!($99)) {
     $$023$i$i8 = $92;
     while(1) {
      $100 = ((($$023$i$i8)) + 4|0);
      $101 = HEAP32[$100>>2]|0;
      $102 = ((($$023$i$i8)) + 8|0);
      $103 = HEAP32[$102>>2]|0;
      $104 = ($103|0)==(0|0);
      if (!($104)) {
       $105 = HEAP32[$103>>2]|0;
       $106 = ((($105)) + -12|0);
       $107 = HEAP32[$106>>2]|0;
       $108 = (($103) + ($107)|0);
       $109 = ((($108)) + 8|0);
       $110 = HEAP32[$109>>2]|0;HEAP32[$109>>2] = (($110-1)|0);
       $111 = ($110|0)==(1);
       if ($111) {
        __THREW__ = 0;
        invoke_viii(3262,($108|0),1,1);
        $112 = __THREW__; __THREW__ = 0;
        $113 = $112&1;
        if ($113) {
         break;
        }
       }
      }
      __ZdlPv($$023$i$i8);
      $114 = ($101|0)==($16|0);
      if ($114) {
       break L39;
      } else {
       $$023$i$i8 = $101;
      }
     }
     $115 = ___cxa_find_matching_catch_2()|0;
     $116 = tempRet0;
     ___cxa_call_unexpected(($115|0));
     // unreachable;
    }
   }
  } while(0);
  $117 = HEAP32[$15>>2]|0;
  $118 = ($117|0)==(0|0);
  if (!($118)) {
   $119 = HEAP32[$117>>2]|0;
   $120 = ((($119)) + -12|0);
   $121 = HEAP32[$120>>2]|0;
   $122 = (($117) + ($121)|0);
   $123 = ((($122)) + 8|0);
   $124 = HEAP32[$123>>2]|0;HEAP32[$123>>2] = (($124-1)|0);
   $125 = ($124|0)==(1);
   if ($125) {
    __THREW__ = 0;
    invoke_viii(3262,($122|0),1,1);
    $126 = __THREW__; __THREW__ = 0;
    $127 = $126&1;
    if ($127) {
     $159 = ___cxa_find_matching_catch_3(0|0)|0;
     $160 = tempRet0;
     ___clang_call_terminate($159);
     // unreachable;
    }
   }
  }
  HEAP32[$15>>2] = 0;
  __THREW__ = 0;
  invoke_vi(707,($12|0));
  $128 = __THREW__; __THREW__ = 0;
  $129 = $128&1;
  if ($129) {
   $159 = ___cxa_find_matching_catch_3(0|0)|0;
   $160 = tempRet0;
   ___clang_call_terminate($159);
   // unreachable;
  } else {
   $$2 = $$0;$$24 = $$02;
  }
 }
 $130 = HEAP32[$8>>2]|0;
 $131 = ($130|0)==(0|0);
 if (!($131)) {
  $132 = ((($130)) + 8|0);
  $133 = HEAP32[$132>>2]|0;HEAP32[$132>>2] = (($133-1)|0);
  $134 = ($133|0)==(1);
  if ($134) {
   __THREW__ = 0;
   invoke_viii(3262,($130|0),1,1);
   $135 = __THREW__; __THREW__ = 0;
   $136 = $135&1;
   if ($136) {
    $159 = ___cxa_find_matching_catch_3(0|0)|0;
    $160 = tempRet0;
    ___clang_call_terminate($159);
    // unreachable;
   }
  }
 }
 HEAP32[$8>>2] = 0;
 $137 = HEAP32[$7>>2]|0;
 $138 = ($137|0)==(0|0);
 if (!($138)) {
  $139 = ((($137)) + 8|0);
  $140 = HEAP32[$139>>2]|0;HEAP32[$139>>2] = (($140-1)|0);
  $141 = ($140|0)==(1);
  if ($141) {
   __THREW__ = 0;
   invoke_viii(3262,($137|0),1,1);
   $142 = __THREW__; __THREW__ = 0;
   $143 = $142&1;
   if ($143) {
    $159 = ___cxa_find_matching_catch_3(0|0)|0;
    $160 = tempRet0;
    ___clang_call_terminate($159);
    // unreachable;
   }
  }
 }
 HEAP32[$7>>2] = 0;
 $144 = HEAP32[$6>>2]|0;
 $145 = ($144|0)==(0);
 if (!($145)) {
  $146 = HEAP32[$5>>2]|0;
  $147 = HEAP32[$4>>2]|0;
  $148 = ((($147)) + 4|0);
  $149 = HEAP32[$148>>2]|0;
  $150 = HEAP32[$146>>2]|0;
  $151 = ((($150)) + 4|0);
  HEAP32[$151>>2] = $149;
  $152 = HEAP32[$148>>2]|0;
  HEAP32[$152>>2] = $150;
  HEAP32[$6>>2] = 0;
  $153 = ($146|0)==($4|0);
  if (!($153)) {
   $$023$i$i = $146;
   while(1) {
    $154 = ((($$023$i$i)) + 4|0);
    $155 = HEAP32[$154>>2]|0;
    __ZdlPv($$023$i$i);
    $156 = ($155|0)==($4|0);
    if ($156) {
     break;
    } else {
     $$023$i$i = $155;
    }
   }
  }
 }
 __THREW__ = 0;
 invoke_vi(388,($0|0));
 $157 = __THREW__; __THREW__ = 0;
 $158 = $157&1;
 if ($158) {
  $159 = ___cxa_find_matching_catch_3(0|0)|0;
  $160 = tempRet0;
  ___clang_call_terminate($159);
  // unreachable;
 } else {
  ___resumeException($$24|0);
  // unreachable;
 }
}
function __ZN3osg8RefBlockC1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 28|0);
 __ZN3osg10ReferencedC2Eb($1,1);
 $2 = ((($0)) + 4|0);
 __THREW__ = 0;
 invoke_vii(3507,($2|0),0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $15 = ___cxa_find_matching_catch_2()|0;
  $16 = tempRet0;
  $eh$lpad$body$index2Z2D = $16;$eh$lpad$body$indexZ2D = $15;
 } else {
  $5 = ((($0)) + 16|0);
  __THREW__ = 0;
  invoke_vi(3508,($5|0));
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if (!($7)) {
   $14 = ((($0)) + 24|0);
   HEAP8[$14>>0] = 0;
   HEAP32[$0>>2] = (60648);
   HEAP32[$1>>2] = (60672);
   return;
  }
  $8 = ___cxa_find_matching_catch_2()|0;
  $9 = tempRet0;
  __THREW__ = 0;
  invoke_vi(707,($2|0));
  $10 = __THREW__; __THREW__ = 0;
  $11 = $10&1;
  if ($11) {
   $12 = ___cxa_find_matching_catch_3(0|0)|0;
   $13 = tempRet0;
   ___clang_call_terminate($12);
   // unreachable;
  } else {
   $eh$lpad$body$index2Z2D = $9;$eh$lpad$body$indexZ2D = $8;
  }
 }
 __THREW__ = 0;
 invoke_vi(712,($1|0));
 $17 = __THREW__; __THREW__ = 0;
 $18 = $17&1;
 if ($18) {
  $19 = ___cxa_find_matching_catch_3(0|0)|0;
  $20 = tempRet0;
  ___clang_call_terminate($19);
  // unreachable;
 } else {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
}
function __ZN3osg8RefBlockD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 4|0);
 __THREW__ = 0;
 invoke_vi(3805,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  $4 = ((($0)) + 28|0);
  __ZN3osg10ReferencedD2Ev($4);
  return;
 }
 $5 = ___cxa_find_matching_catch_2()|0;
 $6 = tempRet0;
 $7 = ((($0)) + 28|0);
 __THREW__ = 0;
 invoke_vi(712,($7|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $10 = ___cxa_find_matching_catch_3(0|0)|0;
  $11 = tempRet0;
  ___clang_call_terminate($10);
  // unreachable;
 } else {
  ___resumeException($5|0);
  // unreachable;
 }
}
function __ZN3osg8RefBlockD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 4|0);
 __THREW__ = 0;
 invoke_vi(3805,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $7 = ___cxa_find_matching_catch_2()|0;
  $8 = tempRet0;
  $9 = ((($0)) + 28|0);
  __THREW__ = 0;
  invoke_vi(712,($9|0));
  $10 = __THREW__; __THREW__ = 0;
  $11 = $10&1;
  if ($11) {
   $12 = ___cxa_find_matching_catch_3(0|0)|0;
   $13 = tempRet0;
   ___clang_call_terminate($12);
   // unreachable;
  } else {
   $eh$lpad$body$index2Z2D = $8;$eh$lpad$body$indexZ2D = $7;
   __ZdlPv($0);
   ___resumeException($eh$lpad$body$indexZ2D|0);
   // unreachable;
  }
 }
 $4 = ((($0)) + 28|0);
 __THREW__ = 0;
 invoke_vi(712,($4|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if (!($6)) {
  __ZdlPv($0);
  return;
 }
 $14 = ___cxa_find_matching_catch_2()|0;
 $15 = tempRet0;
 $eh$lpad$body$index2Z2D = $15;$eh$lpad$body$indexZ2D = $14;
 __ZdlPv($0);
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
}
function __ZTv0_n16_N3osg8RefBlockD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 $5 = ((($4)) + 4|0);
 __THREW__ = 0;
 invoke_vi(3805,($5|0));
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if (!($7)) {
  $15 = ((($4)) + 28|0);
  __ZN3osg10ReferencedD2Ev($15);
  return;
 }
 $8 = ___cxa_find_matching_catch_2()|0;
 $9 = tempRet0;
 $10 = ((($4)) + 28|0);
 __THREW__ = 0;
 invoke_vi(712,($10|0));
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if ($12) {
  $13 = ___cxa_find_matching_catch_3(0|0)|0;
  $14 = tempRet0;
  ___clang_call_terminate($13);
  // unreachable;
 } else {
  ___resumeException($8|0);
  // unreachable;
 }
}
function __ZTv0_n16_N3osg8RefBlockD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$i$index2Z2D = 0;
 var $eh$lpad$body$i$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 $5 = ((($4)) + 4|0);
 __THREW__ = 0;
 invoke_vi(3805,($5|0));
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if ($7) {
  $11 = ___cxa_find_matching_catch_2()|0;
  $12 = tempRet0;
  $13 = ((($4)) + 28|0);
  __THREW__ = 0;
  invoke_vi(712,($13|0));
  $14 = __THREW__; __THREW__ = 0;
  $15 = $14&1;
  if ($15) {
   $16 = ___cxa_find_matching_catch_3(0|0)|0;
   $17 = tempRet0;
   ___clang_call_terminate($16);
   // unreachable;
  } else {
   $eh$lpad$body$i$index2Z2D = $12;$eh$lpad$body$i$indexZ2D = $11;
   __ZdlPv($4);
   ___resumeException($eh$lpad$body$i$indexZ2D|0);
   // unreachable;
  }
 }
 $8 = ((($4)) + 28|0);
 __THREW__ = 0;
 invoke_vi(712,($8|0));
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if (!($10)) {
  __ZdlPv($4);
  return;
 }
 $18 = ___cxa_find_matching_catch_2()|0;
 $19 = tempRet0;
 $eh$lpad$body$i$index2Z2D = $19;$eh$lpad$body$i$indexZ2D = $18;
 __ZdlPv($4);
 ___resumeException($eh$lpad$body$i$indexZ2D|0);
 // unreachable;
}
function __ZN11OpenThreads5BlockD2Ev($0) {
 $0 = $0|0;
 var $$0 = 0, $$02 = 0, $$pre = 0, $$pre$phiZ2D = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 __THREW__ = 0;
 (invoke_ii($3|0,($0|0))|0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 do {
  if ($5) {
   label = 9;
  } else {
   $6 = ((($0)) + 20|0);
   $7 = HEAP8[$6>>0]|0;
   $8 = ($7<<24>>24)==(0);
   if ($8) {
    HEAP8[$6>>0] = 1;
    $9 = ((($0)) + 12|0);
    __THREW__ = 0;
    (invoke_ii(2504,($9|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     $12 = ___cxa_find_matching_catch_2()|0;
     $13 = tempRet0;
     $14 = HEAP32[$0>>2]|0;
     $15 = ((($14)) + 12|0);
     $16 = HEAP32[$15>>2]|0;
     __THREW__ = 0;
     (invoke_ii($16|0,($0|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if (!($18)) {
      $$pre$phiZ2D = $9;$eh$lpad$body$index2Z2D = $13;$eh$lpad$body$indexZ2D = $12;
      label = 10;
      break;
     }
     $24 = ___cxa_find_matching_catch_3(0|0)|0;
     $25 = tempRet0;
     ___clang_call_terminate($24);
     // unreachable;
    }
   }
   $19 = HEAP32[$0>>2]|0;
   $20 = ((($19)) + 12|0);
   $21 = HEAP32[$20>>2]|0;
   __THREW__ = 0;
   (invoke_ii($21|0,($0|0))|0);
   $22 = __THREW__; __THREW__ = 0;
   $23 = $22&1;
   if ($23) {
    label = 9;
   } else {
    $26 = ((($0)) + 12|0);
    __THREW__ = 0;
    invoke_vi(2499,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     $33 = ___cxa_find_matching_catch_2()|0;
     $34 = tempRet0;
     $$0 = $34;$$02 = $33;
     break;
    } else {
     __ZN11OpenThreads5MutexD2Ev($0);
     return;
    }
   }
  }
 } while(0);
 if ((label|0) == 9) {
  $29 = ___cxa_find_matching_catch_2()|0;
  $30 = tempRet0;
  $$pre = ((($0)) + 12|0);
  $$pre$phiZ2D = $$pre;$eh$lpad$body$index2Z2D = $30;$eh$lpad$body$indexZ2D = $29;
  label = 10;
 }
 if ((label|0) == 10) {
  __THREW__ = 0;
  invoke_vi(2499,($$pre$phiZ2D|0));
  $31 = __THREW__; __THREW__ = 0;
  $32 = $31&1;
  if ($32) {
   $37 = ___cxa_find_matching_catch_3(0|0)|0;
   $38 = tempRet0;
   ___clang_call_terminate($37);
   // unreachable;
  } else {
   $$0 = $eh$lpad$body$index2Z2D;$$02 = $eh$lpad$body$indexZ2D;
  }
 }
 __THREW__ = 0;
 invoke_vi(707,($0|0));
 $35 = __THREW__; __THREW__ = 0;
 $36 = $35&1;
 if ($36) {
  $37 = ___cxa_find_matching_catch_3(0|0)|0;
  $38 = tempRet0;
  ___clang_call_terminate($37);
  // unreachable;
 } else {
  ___resumeException($$02|0);
  // unreachable;
 }
}
function __ZN3osg15GraphicsContext7realizeEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + 152|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (FUNCTION_TABLE_ii[$3 & 8191]($0)|0);
 return ($4|0);
}
function __ZN3osg15GraphicsContext11makeCurrentEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__ZN11OpenThreads6Thread13CurrentThreadEv()|0);
 $2 = ((($0)) + 72|0);
 HEAP32[$2>>2] = $1;
 $3 = HEAP32[$0>>2]|0;
 $4 = ((($3)) + 164|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_ii[$5 & 8191]($0)|0);
 if (!($6)) {
  return ($6|0);
 }
 $7 = ((($0)) + 48|0);
 $8 = HEAP32[$7>>2]|0;
 __ZN3osg5State24initializeExtensionProcsEv($8);
 return ($6|0);
}
function __ZN3osg15GraphicsContext14releaseContextEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + 172|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (FUNCTION_TABLE_ii[$3 & 8191]($0)|0);
 $5 = ((($0)) + 72|0);
 HEAP32[$5>>2] = (-1);
 return ($4|0);
}
function __ZN3osg15GraphicsContext18makeContextCurrentEPS0_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $3 = ((($2)) + 168|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_iii[$4 & 8191]($0,$1)|0);
 if (!($5)) {
  return ($5|0);
 }
 $6 = (__ZN11OpenThreads6Thread13CurrentThreadEv()|0);
 $7 = ((($0)) + 72|0);
 HEAP32[$7>>2] = $6;
 $8 = ((($0)) + 48|0);
 $9 = HEAP32[$8>>2]|0;
 __ZN3osg5State24initializeExtensionProcsEv($9);
 return ($5|0);
}
function __ZN3osg15GraphicsContext11swapBuffersEv($0) {
 $0 = $0|0;
 var $$pre$phi4Z2D = 0, $$pre$phiZ2D = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 72|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (__ZN11OpenThreads6Thread13CurrentThreadEv()|0);
 $4 = ($2|0)==($3|0);
 if ($4) {
  $5 = ((($0)) + 48|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==(0|0);
  if (!($7)) {
   $8 = HEAP32[$6>>2]|0;
   $9 = ((($8)) + 12|0);
   $10 = HEAP32[$9>>2]|0;
   FUNCTION_TABLE_vi[$10 & 8191]($6);
  }
  $11 = ((($0)) + 116|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($12|0)==(0|0);
  if ($13) {
   $17 = HEAP32[$0>>2]|0;
   $18 = ((($17)) + 180|0);
   $19 = HEAP32[$18>>2]|0;
   FUNCTION_TABLE_vi[$19 & 8191]($0);
   $$pre$phiZ2D = $0;
  } else {
   $14 = HEAP32[$12>>2]|0;
   $15 = ((($14)) + 12|0);
   $16 = HEAP32[$15>>2]|0;
   FUNCTION_TABLE_vii[$16 & 8191]($12,$0);
   $$pre$phiZ2D = $0;
  }
  $20 = HEAP32[$$pre$phiZ2D>>2]|0;
  $21 = ((($20)) + 148|0);
  $22 = HEAP32[$21>>2]|0;
  FUNCTION_TABLE_vi[$22 & 8191]($0);
  return;
 }
 $23 = ((($0)) + 108|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)==(0|0);
 if (!($25)) {
  $26 = HEAP32[$1>>2]|0;
  $27 = ((($24)) + 12|0);
  $28 = ($26|0)==($27|0);
  if ($28) {
   $29 = (__Znwj(32)|0);
   __THREW__ = 0;
   invoke_vi(3448,($29|0));
   $30 = __THREW__; __THREW__ = 0;
   $31 = $30&1;
   if ($31) {
    $32 = ___cxa_find_matching_catch_2()|0;
    $33 = tempRet0;
    __ZdlPv($29);
    ___resumeException($32|0);
    // unreachable;
   }
   __ZN3osg15OperationThread3addEPNS_9OperationE($24,$29);
   return;
  }
 }
 $34 = (__ZN11OpenThreads6Thread13CurrentThreadEv()|0);
 HEAP32[$1>>2] = $34;
 $35 = HEAP32[$0>>2]|0;
 $36 = ((($35)) + 164|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (FUNCTION_TABLE_ii[$37 & 8191]($0)|0);
 $39 = ((($0)) + 48|0);
 if ($38) {
  $40 = HEAP32[$39>>2]|0;
  __ZN3osg5State24initializeExtensionProcsEv($40);
 }
 $41 = HEAP32[$39>>2]|0;
 $42 = ($41|0)==(0|0);
 if (!($42)) {
  $43 = HEAP32[$41>>2]|0;
  $44 = ((($43)) + 12|0);
  $45 = HEAP32[$44>>2]|0;
  FUNCTION_TABLE_vi[$45 & 8191]($41);
 }
 $46 = ((($0)) + 116|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = ($47|0)==(0|0);
 if ($48) {
  $52 = HEAP32[$0>>2]|0;
  $53 = ((($52)) + 180|0);
  $54 = HEAP32[$53>>2]|0;
  FUNCTION_TABLE_vi[$54 & 8191]($0);
  $$pre$phi4Z2D = $0;
 } else {
  $49 = HEAP32[$47>>2]|0;
  $50 = ((($49)) + 12|0);
  $51 = HEAP32[$50>>2]|0;
  FUNCTION_TABLE_vii[$51 & 8191]($47,$0);
  $$pre$phi4Z2D = $0;
 }
 $55 = HEAP32[$$pre$phi4Z2D>>2]|0;
 $56 = ((($55)) + 148|0);
 $57 = HEAP32[$56>>2]|0;
 FUNCTION_TABLE_vi[$57 & 8191]($0);
 return;
}
function __ZN3osg15GraphicsContext20createGraphicsThreadEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 108|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  return;
 }
 $4 = (__Znwj(52)|0);
 __THREW__ = 0;
 invoke_vi(3806,($4|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $13 = ___cxa_find_matching_catch_2()|0;
  $14 = tempRet0;
  __ZdlPv($4);
  ___resumeException($13|0);
  // unreachable;
 }
 __ZN3osg15GraphicsContext17setGraphicsThreadEPNS_14GraphicsThreadE($0,$4);
 $7 = ((($0)) + 44|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if ($9) {
  return;
 }
 $10 = HEAP32[$1>>2]|0;
 $11 = ((($10)) + 12|0);
 $12 = ((($8)) + 188|0);
 (__ZN11OpenThreads6Thread20setProcessorAffinityERKNS_8AffinityE($11,$12)|0);
 return;
}
function __ZN3osg15GraphicsContext3addEPNS_9OperationE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$1 = 0, $$14 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
 do {
  if ($3) {
   $4 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
   $5 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($4,145946,9)|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ((($6)) + -12|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($5) + ($8)|0);
   __ZNKSt3__28ios_base6getlocEv($2,$9);
   __THREW__ = 0;
   $10 = (invoke_iii(3255,($2|0),(215188|0))|0);
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if (!($12)) {
    $13 = HEAP32[$10>>2]|0;
    $14 = ((($13)) + 28|0);
    $15 = HEAP32[$14>>2]|0;
    __THREW__ = 0;
    $16 = (invoke_iii($15|0,($10|0),10)|0);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if (!($18)) {
     __ZNSt3__26localeD2Ev($2);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($5,$16)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($5)|0);
     break;
    }
   }
   $19 = ___cxa_find_matching_catch_2()|0;
   $20 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($2|0));
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if ($22) {
    $23 = ___cxa_find_matching_catch_3(0|0)|0;
    $24 = tempRet0;
    ___clang_call_terminate($23);
    // unreachable;
   } else {
    ___resumeException($19|0);
    // unreachable;
   }
  }
 } while(0);
 $25 = ((($0)) + 76|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ((($26)) + 8|0);
 $28 = HEAP32[$27>>2]|0;
 (FUNCTION_TABLE_ii[$28 & 8191]($25)|0);
 $29 = ($1|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$1>>2]|0;
  $31 = ((($30)) + -12|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = (($1) + ($32)|0);
  $34 = ((($33)) + 8|0);
  $35 = HEAP32[$34>>2]|0;HEAP32[$34>>2] = (($35+1)|0);
 }
 $36 = ((($0)) + 92|0);
 __THREW__ = 0;
 $37 = (invoke_ii(3276,12)|0);
 $38 = __THREW__; __THREW__ = 0;
 $39 = $38&1;
 do {
  if ($39) {
   $97 = ___cxa_find_matching_catch_2()|0;
   $98 = tempRet0;
   if ($29) {
    $$1 = $98;$$14 = $97;
   } else {
    $99 = HEAP32[$1>>2]|0;
    $100 = ((($99)) + -12|0);
    $101 = HEAP32[$100>>2]|0;
    $102 = (($1) + ($101)|0);
    $103 = ((($102)) + 8|0);
    $104 = HEAP32[$103>>2]|0;HEAP32[$103>>2] = (($104-1)|0);
    $105 = ($104|0)==(1);
    if ($105) {
     __THREW__ = 0;
     invoke_viii(3262,($102|0),1,1);
     $106 = __THREW__; __THREW__ = 0;
     $107 = $106&1;
     if ($107) {
      $115 = ___cxa_find_matching_catch_3(0|0)|0;
      $116 = tempRet0;
      ___clang_call_terminate($115);
      // unreachable;
     } else {
      $$1 = $98;$$14 = $97;
     }
    } else {
     $$1 = $98;$$14 = $97;
    }
   }
  } else {
   $40 = ((($37)) + 8|0);
   HEAP32[$40>>2] = $1;
   if (!($29)) {
    $41 = HEAP32[$1>>2]|0;
    $42 = ((($41)) + -12|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = (($1) + ($43)|0);
    $45 = ((($44)) + 8|0);
    $46 = HEAP32[$45>>2]|0;HEAP32[$45>>2] = (($46+1)|0);
   }
   $47 = ((($37)) + 4|0);
   HEAP32[$47>>2] = $36;
   $48 = HEAP32[$36>>2]|0;
   HEAP32[$37>>2] = $48;
   $49 = ((($48)) + 4|0);
   HEAP32[$49>>2] = $37;
   HEAP32[$36>>2] = $37;
   $50 = ((($0)) + 100|0);
   $51 = HEAP32[$50>>2]|0;
   $52 = (($51) + 1)|0;
   HEAP32[$50>>2] = $52;
   if (!($29)) {
    $53 = HEAP32[$1>>2]|0;
    $54 = ((($53)) + -12|0);
    $55 = HEAP32[$54>>2]|0;
    $56 = (($1) + ($55)|0);
    $57 = ((($56)) + 8|0);
    $58 = HEAP32[$57>>2]|0;HEAP32[$57>>2] = (($58-1)|0);
    $59 = ($58|0)==(1);
    if ($59) {
     __THREW__ = 0;
     invoke_viii(3262,($56|0),1,1);
     $60 = __THREW__; __THREW__ = 0;
     $61 = $60&1;
     if ($61) {
      $95 = ___cxa_find_matching_catch_2()|0;
      $96 = tempRet0;
      $$1 = $96;$$14 = $95;
      break;
     }
    }
   }
   $62 = ((($0)) + 88|0);
   $63 = HEAP32[$62>>2]|0;
   $64 = ((($63)) + 4|0);
   $65 = ((($63)) + 24|0);
   $66 = HEAP8[$65>>0]|0;
   $67 = ($66<<24>>24)==(1);
   if ($67) {
    $92 = HEAP32[$25>>2]|0;
    $93 = ((($92)) + 12|0);
    $94 = HEAP32[$93>>2]|0;
    (FUNCTION_TABLE_ii[$94 & 8191]($25)|0);
    STACKTOP = sp;return;
   }
   $68 = HEAP32[$64>>2]|0;
   $69 = ((($68)) + 8|0);
   $70 = HEAP32[$69>>2]|0;
   __THREW__ = 0;
   (invoke_ii($70|0,($64|0))|0);
   $71 = __THREW__; __THREW__ = 0;
   $72 = $71&1;
   do {
    if ($72) {
     label = 28;
    } else {
     $73 = HEAP8[$65>>0]|0;
     $74 = ($73<<24>>24)==(0);
     if ($74) {
      HEAP8[$65>>0] = 1;
      $75 = ((($63)) + 16|0);
      __THREW__ = 0;
      (invoke_ii(2504,($75|0))|0);
      $76 = __THREW__; __THREW__ = 0;
      $77 = $76&1;
      if ($77) {
       $78 = ___cxa_find_matching_catch_2()|0;
       $79 = tempRet0;
       $80 = HEAP32[$64>>2]|0;
       $81 = ((($80)) + 12|0);
       $82 = HEAP32[$81>>2]|0;
       __THREW__ = 0;
       (invoke_ii($82|0,($64|0))|0);
       $83 = __THREW__; __THREW__ = 0;
       $84 = $83&1;
       if (!($84)) {
        $eh$lpad$body$index2Z2D = $79;$eh$lpad$body$indexZ2D = $78;
        break;
       }
       $85 = ___cxa_find_matching_catch_3(0|0)|0;
       $86 = tempRet0;
       ___clang_call_terminate($85);
       // unreachable;
      }
     }
     $87 = HEAP32[$64>>2]|0;
     $88 = ((($87)) + 12|0);
     $89 = HEAP32[$88>>2]|0;
     __THREW__ = 0;
     (invoke_ii($89|0,($64|0))|0);
     $90 = __THREW__; __THREW__ = 0;
     $91 = $90&1;
     if ($91) {
      label = 28;
     } else {
      $92 = HEAP32[$25>>2]|0;
      $93 = ((($92)) + 12|0);
      $94 = HEAP32[$93>>2]|0;
      (FUNCTION_TABLE_ii[$94 & 8191]($25)|0);
      STACKTOP = sp;return;
     }
    }
   } while(0);
   if ((label|0) == 28) {
    $108 = ___cxa_find_matching_catch_2()|0;
    $109 = tempRet0;
    $eh$lpad$body$index2Z2D = $109;$eh$lpad$body$indexZ2D = $108;
   }
   $$1 = $eh$lpad$body$index2Z2D;$$14 = $eh$lpad$body$indexZ2D;
  }
 } while(0);
 $110 = HEAP32[$25>>2]|0;
 $111 = ((($110)) + 12|0);
 $112 = HEAP32[$111>>2]|0;
 __THREW__ = 0;
 (invoke_ii($112|0,($25|0))|0);
 $113 = __THREW__; __THREW__ = 0;
 $114 = $113&1;
 if ($114) {
  $115 = ___cxa_find_matching_catch_3(0|0)|0;
  $116 = tempRet0;
  ___clang_call_terminate($115);
  // unreachable;
 } else {
  ___resumeException($$14|0);
  // unreachable;
 }
}
function __ZN3osg15GraphicsContext9addCameraEPNS_6CameraE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = $1;
 $3 = ((($0)) + 32|0);
 $4 = (__Znwj(12)|0);
 $5 = ((($4)) + 8|0);
 HEAP32[$5>>2] = $2;
 $6 = ((($4)) + 4|0);
 HEAP32[$6>>2] = $3;
 $7 = HEAP32[$3>>2]|0;
 HEAP32[$4>>2] = $7;
 $8 = ((($7)) + 4|0);
 HEAP32[$8>>2] = $4;
 HEAP32[$3>>2] = $4;
 $9 = ((($0)) + 40|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 1)|0;
 HEAP32[$9>>2] = $11;
 return;
}
function __ZN3osg15GraphicsContext12removeCameraEPNS_6CameraE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$0$i$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$i$i$i$i29 = 0, $$0$ph$i$i$i$i = 0, $$0$ph$lcssa$i$i$i = 0, $$0$ph13$i$i$i = 0, $$020 = 0, $$024$i$i$i$i = 0, $$025$i$i$i$i = 0, $$036$i$i$i = 0, $$07$ph12$i$i$i = 0, $$0710$i$i$i = 0, $$cast$i = 0, $$in$i$i$i$i = 0, $$pre$i$i$i$i = 0, $$sroa$0$0$copyload$i = 0, $$sroa$0$0$copyload4$i = 0, $$sroa$033$0$be = 0;
 var $$sroa$033$096 = 0, $$sroa$050$0 = 0, $$sroa$050$098 = 0, $$sroa$050$099 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = ((($0)) + 36|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 32|0);
 $6 = ($4|0)==($5|0);
 L1: do {
  if ($6) {
   $$sroa$0$0$copyload$i = $4;
  } else {
   $$sroa$0$0$copyload4$i = $4;$8 = $4;
   while(1) {
    $7 = ((($8)) + 8|0);
    $9 = HEAP32[$7>>2]|0;
    $10 = ($9|0)==($1|0);
    if ($10) {
     $$sroa$0$0$copyload$i = $$sroa$0$0$copyload4$i;
     break L1;
    }
    $11 = ((($$sroa$0$0$copyload4$i)) + 4|0);
    $12 = HEAP32[$11>>2]|0;
    $$cast$i = $12;
    $13 = ($$cast$i|0)==($5|0);
    $14 = $12;
    if ($13) {
     break;
    } else {
     $$sroa$0$0$copyload4$i = $$cast$i;$8 = $14;
    }
   }
   STACKTOP = sp;return;
  }
 } while(0);
 $15 = ($$sroa$0$0$copyload$i|0)==($5|0);
 if ($15) {
  STACKTOP = sp;return;
 }
 $16 = ((($2)) + 4|0);
 HEAP32[$16>>2] = 0;
 $17 = ((($2)) + 8|0);
 HEAP32[$17>>2] = 0;
 $18 = ((($2)) + 4|0);
 HEAP32[$2>>2] = $18;
 $19 = ((($1)) + 124|0);
 $$0 = 0;
 while(1) {
  $20 = HEAP32[$1>>2]|0;
  $21 = ((($20)) + 224|0);
  $22 = HEAP32[$21>>2]|0;
  __THREW__ = 0;
  $23 = (invoke_ii($22|0,($1|0))|0);
  $24 = __THREW__; __THREW__ = 0;
  $25 = $24&1;
  if ($25) {
   label = 58;
   break;
  }
  $26 = ($$0>>>0)<($23>>>0);
  if (!($26)) {
   label = 9;
   break;
  }
  $29 = HEAP32[$19>>2]|0;
  $30 = (($29) + ($$0<<2)|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = $31;
  $33 = HEAP32[$18>>2]|0;
  $34 = ($33|0)==(0|0);
  do {
   if ($34) {
    $$025$i$i$i$i = $18;$$036$i$i$i = $18;
   } else {
    $$0$i$i$i$i29 = $16;$$024$i$i$i$i = $33;
    while(1) {
     $35 = ((($$024$i$i$i$i)) + 16|0);
     $36 = HEAP32[$35>>2]|0;
     $37 = ($31>>>0)<($36>>>0);
     if ($37) {
      $38 = HEAP32[$$024$i$i$i$i>>2]|0;
      $39 = ($38|0)==(0|0);
      if ($39) {
       label = 14;
       break;
      } else {
       $$0$ph$i$i$i$i = $$024$i$i$i$i;$$in$i$i$i$i = $38;
      }
     } else {
      $40 = ($36>>>0)<($31>>>0);
      if (!($40)) {
       label = 18;
       break;
      }
      $41 = ((($$024$i$i$i$i)) + 4|0);
      $42 = HEAP32[$41>>2]|0;
      $43 = ($42|0)==(0|0);
      if ($43) {
       label = 17;
       break;
      } else {
       $$0$ph$i$i$i$i = $41;$$in$i$i$i$i = $42;
      }
     }
     $$0$i$i$i$i29 = $$0$ph$i$i$i$i;$$024$i$i$i$i = $$in$i$i$i$i;
    }
    if ((label|0) == 14) {
     label = 0;
     $$025$i$i$i$i = $$024$i$i$i$i;$$036$i$i$i = $$024$i$i$i$i;
     break;
    }
    else if ((label|0) == 17) {
     label = 0;
     $$025$i$i$i$i = $41;$$036$i$i$i = $$024$i$i$i$i;
     break;
    }
    else if ((label|0) == 18) {
     label = 0;
     $$025$i$i$i$i = $$0$i$i$i$i29;$$036$i$i$i = $$024$i$i$i$i;
     break;
    }
   }
  } while(0);
  $44 = HEAP32[$$025$i$i$i$i>>2]|0;
  $45 = ($44|0)==(0|0);
  if ($45) {
   __THREW__ = 0;
   $46 = (invoke_ii(3276,20)|0);
   $47 = __THREW__; __THREW__ = 0;
   $48 = $47&1;
   if ($48) {
    label = 58;
    break;
   }
   $49 = ((($46)) + 16|0);
   HEAP32[$49>>2] = $32;
   HEAP32[$46>>2] = 0;
   $50 = ((($46)) + 4|0);
   HEAP32[$50>>2] = 0;
   $51 = ((($46)) + 8|0);
   HEAP32[$51>>2] = $$036$i$i$i;
   HEAP32[$$025$i$i$i$i>>2] = $46;
   $52 = HEAP32[$2>>2]|0;
   $53 = HEAP32[$52>>2]|0;
   $54 = ($53|0)==(0|0);
   if ($54) {
    $57 = $46;
   } else {
    $55 = $53;
    HEAP32[$2>>2] = $55;
    $$pre$i$i$i$i = HEAP32[$$025$i$i$i$i>>2]|0;
    $57 = $$pre$i$i$i$i;
   }
   $56 = HEAP32[$16>>2]|0;
   __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($56,$57);
   $58 = HEAP32[$17>>2]|0;
   $59 = (($58) + 1)|0;
   HEAP32[$17>>2] = $59;
  }
  $60 = (($$0) + 1)|0;
  $$0 = $60;
 }
 if ((label|0) == 9) {
  $$sroa$050$098 = HEAP32[$3>>2]|0;
  $27 = $$sroa$050$098;
  $28 = ($27|0)==($5|0);
  L38: do {
   if (!($28)) {
    $$sroa$050$099 = $$sroa$050$098;$64 = $27;
    L39: while(1) {
     $65 = ($64|0)==($$sroa$0$0$copyload$i|0);
     L41: do {
      if (!($65)) {
       $66 = $$sroa$050$099;
       $67 = ((($66)) + 8|0);
       $68 = HEAP32[$67>>2]|0;
       $69 = ((($68)) + 124|0);
       $$020 = 0;
       while(1) {
        $70 = HEAP32[$68>>2]|0;
        $71 = ((($70)) + 224|0);
        $72 = HEAP32[$71>>2]|0;
        __THREW__ = 0;
        $73 = (invoke_ii($72|0,($68|0))|0);
        $74 = __THREW__; __THREW__ = 0;
        $75 = $74&1;
        if ($75) {
         break L39;
        }
        $76 = ($$020>>>0)<($73>>>0);
        if (!($76)) {
         break L41;
        }
        $77 = HEAP32[$69>>2]|0;
        $78 = (($77) + ($$020<<2)|0);
        $79 = HEAP32[$78>>2]|0;
        $80 = HEAP32[$18>>2]|0;
        $81 = ($80|0)==(0|0);
        if (!($81)) {
         $$0$ph13$i$i$i = $18;$$07$ph12$i$i$i = $80;
         L48: while(1) {
          $$0710$i$i$i = $$07$ph12$i$i$i;
          while(1) {
           $82 = ((($$0710$i$i$i)) + 16|0);
           $83 = HEAP32[$82>>2]|0;
           $84 = ($83>>>0)<($79>>>0);
           if (!($84)) {
            break;
           }
           $87 = ((($$0710$i$i$i)) + 4|0);
           $88 = HEAP32[$87>>2]|0;
           $89 = ($88|0)==(0|0);
           if ($89) {
            $$0$ph$lcssa$i$i$i = $$0$ph13$i$i$i;
            break L48;
           } else {
            $$0710$i$i$i = $88;
           }
          }
          $85 = HEAP32[$$0710$i$i$i>>2]|0;
          $86 = ($85|0)==(0|0);
          if ($86) {
           $$0$ph$lcssa$i$i$i = $$0710$i$i$i;
           break;
          } else {
           $$0$ph13$i$i$i = $$0710$i$i$i;$$07$ph12$i$i$i = $85;
          }
         }
         $90 = ($$0$ph$lcssa$i$i$i|0)==($18|0);
         if (!($90)) {
          $91 = ((($$0$ph$lcssa$i$i$i)) + 16|0);
          $92 = HEAP32[$91>>2]|0;
          $93 = ($79>>>0)<($92>>>0);
          if (!($93)) {
           $94 = ((($$0$ph$lcssa$i$i$i)) + 4|0);
           $95 = HEAP32[$94>>2]|0;
           $96 = ($95|0)==(0|0);
           if ($96) {
            $97 = ((($$0$ph$lcssa$i$i$i)) + 8|0);
            $98 = HEAP32[$97>>2]|0;
            $99 = HEAP32[$98>>2]|0;
            $100 = ($99|0)==($$0$ph$lcssa$i$i$i|0);
            if ($100) {
             $$0$i$i$i$i = $98;
            } else {
             $104 = $97;
             while(1) {
              $103 = HEAP32[$104>>2]|0;
              $105 = ((($103)) + 8|0);
              $106 = HEAP32[$105>>2]|0;
              $107 = HEAP32[$106>>2]|0;
              $108 = ($107|0)==($103|0);
              if ($108) {
               $$0$i$i$i$i = $106;
               break;
              } else {
               $104 = $105;
              }
             }
            }
           } else {
            $$0$i$i$i$i$i = $95;
            while(1) {
             $101 = HEAP32[$$0$i$i$i$i$i>>2]|0;
             $102 = ($101|0)==(0|0);
             if ($102) {
              break;
             } else {
              $$0$i$i$i$i$i = $101;
             }
            }
            $$0$i$i$i$i = $$0$i$i$i$i$i;
           }
           $109 = HEAP32[$2>>2]|0;
           $110 = ($109|0)==($$0$ph$lcssa$i$i$i|0);
           if ($110) {
            $111 = $$0$i$i$i$i;
            HEAP32[$2>>2] = $111;
           }
           $112 = HEAP32[$17>>2]|0;
           $113 = (($112) + -1)|0;
           HEAP32[$17>>2] = $113;
           __ZNSt3__213__tree_removeIPNS_16__tree_node_baseIPvEEEEvT_S5_($80,$$0$ph$lcssa$i$i$i);
           __ZdlPv($$0$ph$lcssa$i$i$i);
          }
         }
        }
        $114 = (($$020) + 1)|0;
        $$020 = $114;
       }
      }
     } while(0);
     $115 = ((($64)) + 4|0);
     $$sroa$050$0 = HEAP32[$115>>2]|0;
     $116 = $$sroa$050$0;
     $117 = ($116|0)==($5|0);
     if ($117) {
      break L38;
     } else {
      $$sroa$050$099 = $$sroa$050$0;$64 = $116;
     }
    }
    $161 = ___cxa_find_matching_catch_2()|0;
    $162 = tempRet0;
    $163 = HEAP32[$18>>2]|0;
    __ZNSt3__26__treeIPN3osg4NodeENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($2,$163);
    ___resumeException($161|0);
    // unreachable;
   }
  } while(0);
  $61 = HEAP32[$2>>2]|0;
  $62 = ($61|0)==($18|0);
  L72: do {
   if (!($62)) {
    $63 = ((($0)) + 48|0);
    $$sroa$033$096 = $61;
    while(1) {
     $118 = ((($$sroa$033$096)) + 16|0);
     $119 = HEAP32[$118>>2]|0;
     $120 = HEAP32[$119>>2]|0;
     $121 = ((($120)) + 136|0);
     $122 = HEAP32[$121>>2]|0;
     $123 = HEAP32[$63>>2]|0;
     __THREW__ = 0;
     invoke_vii($122|0,($119|0),($123|0));
     $124 = __THREW__; __THREW__ = 0;
     $125 = $124&1;
     if ($125) {
      break;
     }
     $126 = ((($$sroa$033$096)) + 4|0);
     $127 = HEAP32[$126>>2]|0;
     $128 = ($127|0)==(0|0);
     if ($128) {
      $129 = ((($$sroa$033$096)) + 8|0);
      $130 = HEAP32[$129>>2]|0;
      $131 = HEAP32[$130>>2]|0;
      $132 = ($131|0)==($$sroa$033$096|0);
      if ($132) {
       $$sroa$033$0$be = $130;
      } else {
       $137 = $129;
       while(1) {
        $136 = HEAP32[$137>>2]|0;
        $138 = ((($136)) + 8|0);
        $139 = HEAP32[$138>>2]|0;
        $140 = HEAP32[$139>>2]|0;
        $141 = ($140|0)==($136|0);
        if ($141) {
         $$sroa$033$0$be = $139;
         break;
        } else {
         $137 = $138;
        }
       }
      }
     } else {
      $$0$i$i$i = $127;
      while(1) {
       $134 = HEAP32[$$0$i$i$i>>2]|0;
       $135 = ($134|0)==(0|0);
       if ($135) {
        break;
       } else {
        $$0$i$i$i = $134;
       }
      }
      $$sroa$033$0$be = $$0$i$i$i;
     }
     $133 = ($$sroa$033$0$be|0)==($18|0);
     if ($133) {
      break L72;
     } else {
      $$sroa$033$096 = $$sroa$033$0$be;
     }
    }
    $161 = ___cxa_find_matching_catch_2()|0;
    $162 = tempRet0;
    $163 = HEAP32[$18>>2]|0;
    __ZNSt3__26__treeIPN3osg4NodeENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($2,$163);
    ___resumeException($161|0);
    // unreachable;
   }
  } while(0);
  $142 = ((($1)) + 632|0);
  $143 = HEAP32[$142>>2]|0;
  $144 = ($143|0)==(0|0);
  if (!($144)) {
   $145 = HEAP32[$143>>2]|0;
   $146 = ((($145)) + 136|0);
   $147 = HEAP32[$146>>2]|0;
   $148 = ((($0)) + 48|0);
   $149 = HEAP32[$148>>2]|0;
   __THREW__ = 0;
   invoke_vii($147|0,($143|0),($149|0));
   $150 = __THREW__; __THREW__ = 0;
   $151 = $150&1;
   if ($151) {
    $161 = ___cxa_find_matching_catch_2()|0;
    $162 = tempRet0;
    $163 = HEAP32[$18>>2]|0;
    __ZNSt3__26__treeIPN3osg4NodeENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($2,$163);
    ___resumeException($161|0);
    // unreachable;
   }
  }
  $152 = ((($$sroa$0$0$copyload$i)) + 4|0);
  $153 = HEAP32[$152>>2]|0;
  $154 = HEAP32[$$sroa$0$0$copyload$i>>2]|0;
  $155 = ((($154)) + 4|0);
  HEAP32[$155>>2] = $153;
  $156 = HEAP32[$152>>2]|0;
  HEAP32[$156>>2] = $154;
  $157 = ((($0)) + 40|0);
  $158 = HEAP32[$157>>2]|0;
  $159 = (($158) + -1)|0;
  HEAP32[$157>>2] = $159;
  __ZdlPv($$sroa$0$0$copyload$i);
  $160 = HEAP32[$18>>2]|0;
  __ZNSt3__26__treeIPN3osg4NodeENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($2,$160);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 58) {
  $161 = ___cxa_find_matching_catch_2()|0;
  $162 = tempRet0;
  $163 = HEAP32[$18>>2]|0;
  __ZNSt3__26__treeIPN3osg4NodeENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($2,$163);
  ___resumeException($161|0);
  // unreachable;
 }
}
function __ZN3osg23SyncSwapBuffersCallbackC2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 __ZN3osg10ReferencedC2Ev($0);
 HEAP32[$0>>2] = (60600);
 __THREW__ = 0;
 $2 = (invoke_ii(3265,4)|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 do {
  if ($4) {
   label = 14;
  } else {
   if (!($2)) {
    $42 = ((($0)) + 12|0);
    HEAP32[$42>>2] = 0;
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   $5 = (invoke_ii(3266,4)|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if ($7) {
    label = 14;
   } else {
    __THREW__ = 0;
    $8 = (invoke_iiii(3267,($5|0),(143488|0),32)|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     label = 14;
    } else {
     $11 = HEAP32[$8>>2]|0;
     $12 = ((($11)) + -12|0);
     $13 = HEAP32[$12>>2]|0;
     $14 = (($8) + ($13)|0);
     __THREW__ = 0;
     invoke_vii(3257,($1|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      label = 14;
     } else {
      __THREW__ = 0;
      $17 = (invoke_iii(3255,($1|0),(215188|0))|0);
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if (!($19)) {
       $20 = HEAP32[$17>>2]|0;
       $21 = ((($20)) + 28|0);
       $22 = HEAP32[$21>>2]|0;
       __THREW__ = 0;
       $23 = (invoke_iii($22|0,($17|0),10)|0);
       $24 = __THREW__; __THREW__ = 0;
       $25 = $24&1;
       if (!($25)) {
        __THREW__ = 0;
        invoke_vi(3263,($1|0));
        $32 = __THREW__; __THREW__ = 0;
        $33 = $32&1;
        if ($33) {
         label = 14;
         break;
        }
        __THREW__ = 0;
        (invoke_iii(3268,($8|0),($23|0))|0);
        $34 = __THREW__; __THREW__ = 0;
        $35 = $34&1;
        if ($35) {
         label = 14;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(3269,($8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         label = 14;
         break;
        }
        $42 = ((($0)) + 12|0);
        HEAP32[$42>>2] = 0;
        STACKTOP = sp;return;
       }
      }
      $26 = ___cxa_find_matching_catch_2()|0;
      $27 = tempRet0;
      __THREW__ = 0;
      invoke_vi(3263,($1|0));
      $28 = __THREW__; __THREW__ = 0;
      $29 = $28&1;
      if ($29) {
       $30 = ___cxa_find_matching_catch_3(0|0)|0;
       $31 = tempRet0;
       ___clang_call_terminate($30);
       // unreachable;
      } else {
       $eh$lpad$body$index2Z2D = $27;$eh$lpad$body$indexZ2D = $26;
       break;
      }
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 14) {
  $38 = ___cxa_find_matching_catch_2()|0;
  $39 = tempRet0;
  $eh$lpad$body$index2Z2D = $39;$eh$lpad$body$indexZ2D = $38;
 }
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $40 = __THREW__; __THREW__ = 0;
 $41 = $40&1;
 if ($41) {
  $43 = ___cxa_find_matching_catch_3(0|0)|0;
  $44 = tempRet0;
  ___clang_call_terminate($43);
  // unreachable;
 } else {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
}
function __ZN3osg14GraphicsThreadD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1884,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZN3osg14GraphicsThread3runEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 20|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = ((($2)) + 24|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0|0);
  if (!($6)) {
   $7 = ((($0)) + 24|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ($8|0)==(0|0);
   if (!($9)) {
    $10 = (___dynamic_cast($8,26112,24816,0)|0);
    $11 = ($10|0)==(0|0);
    if (!($11)) {
     (__ZN3osg15GraphicsContext11makeCurrentEv($10)|0);
     $12 = ((($10)) + 48|0);
     $13 = HEAP32[$12>>2]|0;
     __ZN3osg5State24initializeExtensionProcsEv($13);
     __ZN3osg15OperationThread3runEv($0);
     $14 = ((($0)) + 44|0);
     $15 = HEAP32[$14>>2]|0;
     __ZN3osg14OperationQueue20releaseAllOperationsEv($15);
     (__ZN3osg15GraphicsContext14releaseContextEv($10)|0);
     return;
    }
   }
  }
 }
 __ZN3osg15OperationThread3runEv($0);
 $16 = ((($0)) + 44|0);
 $17 = HEAP32[$16>>2]|0;
 __ZN3osg14OperationQueue20releaseAllOperationsEv($17);
 return;
}
function __ZThn12_N3osg14GraphicsThreadD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -12|0);
 __ZN3osg15OperationThreadD2Ev($1);
 return;
}
function __ZThn12_N3osg14GraphicsThreadD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -12|0);
 __THREW__ = 0;
 invoke_vi(1884,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch_2()|0;
  $5 = tempRet0;
  __ZdlPv($1);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZdlPv($1);
  return;
 }
}
function __ZThn12_N3osg14GraphicsThread3runEv($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -12|0);
 __ZN3osg14GraphicsThread3runEv($1);
 return;
}
function __ZN11OpenThreads6Thread13cancelCleanupEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN3osg22BlockAndFlushOperation7releaseEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 20|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 (FUNCTION_TABLE_ii[$4 & 8191]($1)|0);
 $5 = ((($0)) + 40|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = ($6<<24>>24)==(0);
 if (!($7)) {
  $20 = HEAP32[$1>>2]|0;
  $21 = ((($20)) + 12|0);
  $22 = HEAP32[$21>>2]|0;
  (FUNCTION_TABLE_ii[$22 & 8191]($1)|0);
  return;
 }
 HEAP8[$5>>0] = 1;
 $8 = ((($0)) + 32|0);
 __THREW__ = 0;
 (invoke_ii(2504,($8|0))|0);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if (!($10)) {
  $20 = HEAP32[$1>>2]|0;
  $21 = ((($20)) + 12|0);
  $22 = HEAP32[$21>>2]|0;
  (FUNCTION_TABLE_ii[$22 & 8191]($1)|0);
  return;
 }
 $11 = ___cxa_find_matching_catch_2()|0;
 $12 = tempRet0;
 $13 = HEAP32[$1>>2]|0;
 $14 = ((($13)) + 12|0);
 $15 = HEAP32[$14>>2]|0;
 __THREW__ = 0;
 (invoke_ii($15|0,($1|0))|0);
 $16 = __THREW__; __THREW__ = 0;
 $17 = $16&1;
 if ($17) {
  $18 = ___cxa_find_matching_catch_3(0|0)|0;
  $19 = tempRet0;
  ___clang_call_terminate($18);
  // unreachable;
 } else {
  ___resumeException($11|0);
  // unreachable;
 }
}
function __ZN3osg17GraphicsOperationclEPNS_6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 }
 $3 = (___dynamic_cast($1,26112,24816,0)|0);
 $4 = ($3|0)==(0|0);
 if ($4) {
  return;
 }
 $5 = HEAP32[$0>>2]|0;
 $6 = ((($5)) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 FUNCTION_TABLE_vii[$7 & 8191]($0,$3);
 return;
}
function __ZN3osg22BlockAndFlushOperationD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 20|0);
 __THREW__ = 0;
 invoke_vi(3805,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  HEAP32[$0>>2] = ((25004));
  $4 = ((($0)) + 44|0);
  HEAP32[$4>>2] = ((25036));
  $5 = ((($0)) + 4|0);
  $6 = ((($5)) + 11|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = ($7<<24>>24)<(0);
  if (!($8)) {
   __ZN3osg10ReferencedD2Ev($4);
   return;
  }
  $9 = HEAP32[$5>>2]|0;
  __ZdlPv($9);
  __ZN3osg10ReferencedD2Ev($4);
  return;
 }
 $10 = ___cxa_find_matching_catch_2()|0;
 $11 = tempRet0;
 HEAP32[$0>>2] = ((25004));
 $12 = ((($0)) + 44|0);
 HEAP32[$12>>2] = ((25036));
 $13 = ((($0)) + 4|0);
 $14 = ((($13)) + 11|0);
 $15 = HEAP8[$14>>0]|0;
 $16 = ($15<<24>>24)<(0);
 if ($16) {
  $17 = HEAP32[$13>>2]|0;
  __ZdlPv($17);
 }
 __THREW__ = 0;
 invoke_vi(712,($12|0));
 $18 = __THREW__; __THREW__ = 0;
 $19 = $18&1;
 if ($19) {
  $20 = ___cxa_find_matching_catch_3(0|0)|0;
  $21 = tempRet0;
  ___clang_call_terminate($20);
  // unreachable;
 } else {
  ___resumeException($10|0);
  // unreachable;
 }
}
function __ZN3osg22BlockAndFlushOperationD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 20|0);
 __THREW__ = 0;
 invoke_vi(3805,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $10 = ___cxa_find_matching_catch_2()|0;
  $11 = tempRet0;
  HEAP32[$0>>2] = ((25004));
  $12 = ((($0)) + 44|0);
  HEAP32[$12>>2] = ((25036));
  $13 = ((($0)) + 4|0);
  $14 = ((($13)) + 11|0);
  $15 = HEAP8[$14>>0]|0;
  $16 = ($15<<24>>24)<(0);
  if ($16) {
   $17 = HEAP32[$13>>2]|0;
   __ZdlPv($17);
  }
  __THREW__ = 0;
  invoke_vi(712,($12|0));
  $20 = __THREW__; __THREW__ = 0;
  $21 = $20&1;
  if ($21) {
   $22 = ___cxa_find_matching_catch_3(0|0)|0;
   $23 = tempRet0;
   ___clang_call_terminate($22);
   // unreachable;
  } else {
   $eh$lpad$body$index2Z2D = $11;$eh$lpad$body$indexZ2D = $10;
   __ZdlPv($0);
   ___resumeException($eh$lpad$body$indexZ2D|0);
   // unreachable;
  }
 }
 HEAP32[$0>>2] = ((25004));
 $4 = ((($0)) + 44|0);
 HEAP32[$4>>2] = ((25036));
 $5 = ((($0)) + 4|0);
 $6 = ((($5)) + 11|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = ($7<<24>>24)<(0);
 if ($8) {
  $9 = HEAP32[$5>>2]|0;
  __ZdlPv($9);
 }
 __THREW__ = 0;
 invoke_vi(712,($4|0));
 $18 = __THREW__; __THREW__ = 0;
 $19 = $18&1;
 if (!($19)) {
  __ZdlPv($0);
  return;
 }
 $24 = ___cxa_find_matching_catch_2()|0;
 $25 = tempRet0;
 $eh$lpad$body$index2Z2D = $25;$eh$lpad$body$indexZ2D = $24;
 __ZdlPv($0);
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
}
function __ZN3osg22BlockAndFlushOperationclEPNS_15GraphicsContextE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 _glFlush();
 $2 = ((($0)) + 20|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 (FUNCTION_TABLE_ii[$5 & 8191]($2)|0);
 $6 = ((($0)) + 40|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = ($7<<24>>24)==(0);
 if (!($8)) {
  $21 = HEAP32[$2>>2]|0;
  $22 = ((($21)) + 12|0);
  $23 = HEAP32[$22>>2]|0;
  (FUNCTION_TABLE_ii[$23 & 8191]($2)|0);
  return;
 }
 HEAP8[$6>>0] = 1;
 $9 = ((($0)) + 32|0);
 __THREW__ = 0;
 (invoke_ii(2504,($9|0))|0);
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if (!($11)) {
  $21 = HEAP32[$2>>2]|0;
  $22 = ((($21)) + 12|0);
  $23 = HEAP32[$22>>2]|0;
  (FUNCTION_TABLE_ii[$23 & 8191]($2)|0);
  return;
 }
 $12 = ___cxa_find_matching_catch_2()|0;
 $13 = tempRet0;
 $14 = HEAP32[$2>>2]|0;
 $15 = ((($14)) + 12|0);
 $16 = HEAP32[$15>>2]|0;
 __THREW__ = 0;
 (invoke_ii($16|0,($2|0))|0);
 $17 = __THREW__; __THREW__ = 0;
 $18 = $17&1;
 if ($18) {
  $19 = ___cxa_find_matching_catch_3(0|0)|0;
  $20 = tempRet0;
  ___clang_call_terminate($19);
  // unreachable;
 } else {
  ___resumeException($12|0);
  // unreachable;
 }
}
function __ZTv0_n16_N3osg22BlockAndFlushOperationD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 $5 = ((($4)) + 20|0);
 __THREW__ = 0;
 invoke_vi(3805,($5|0));
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if (!($7)) {
  HEAP32[$4>>2] = ((25004));
  $8 = ((($4)) + 44|0);
  HEAP32[$8>>2] = ((25036));
  $9 = ((($4)) + 4|0);
  $10 = ((($9)) + 11|0);
  $11 = HEAP8[$10>>0]|0;
  $12 = ($11<<24>>24)<(0);
  if (!($12)) {
   __ZN3osg10ReferencedD2Ev($8);
   return;
  }
  $13 = HEAP32[$9>>2]|0;
  __ZdlPv($13);
  __ZN3osg10ReferencedD2Ev($8);
  return;
 }
 $14 = ___cxa_find_matching_catch_2()|0;
 $15 = tempRet0;
 HEAP32[$4>>2] = ((25004));
 $16 = ((($4)) + 44|0);
 HEAP32[$16>>2] = ((25036));
 $17 = ((($4)) + 4|0);
 $18 = ((($17)) + 11|0);
 $19 = HEAP8[$18>>0]|0;
 $20 = ($19<<24>>24)<(0);
 if ($20) {
  $21 = HEAP32[$17>>2]|0;
  __ZdlPv($21);
 }
 __THREW__ = 0;
 invoke_vi(712,($16|0));
 $22 = __THREW__; __THREW__ = 0;
 $23 = $22&1;
 if ($23) {
  $24 = ___cxa_find_matching_catch_3(0|0)|0;
  $25 = tempRet0;
  ___clang_call_terminate($24);
  // unreachable;
 } else {
  ___resumeException($14|0);
  // unreachable;
 }
}
function __ZTv0_n16_N3osg22BlockAndFlushOperationD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __ZN3osg22BlockAndFlushOperationD0Ev($4);
 return;
}
function __ZN3osg21EndOfDynamicDrawBlockD2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  $3 = ((($0)) + 12|0);
  __ZN11OpenThreads10BlockCountD2Ev($3);
  return;
 }
 $4 = ___cxa_find_matching_catch_2()|0;
 $5 = tempRet0;
 $6 = ((($0)) + 12|0);
 __THREW__ = 0;
 invoke_vi(3807,($6|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch_3(0|0)|0;
  $10 = tempRet0;
  ___clang_call_terminate($9);
  // unreachable;
 } else {
  ___resumeException($4|0);
  // unreachable;
 }
}
function __ZN3osg21EndOfDynamicDrawBlockD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $6 = ___cxa_find_matching_catch_2()|0;
  $7 = tempRet0;
  $8 = ((($0)) + 12|0);
  __THREW__ = 0;
  invoke_vi(3807,($8|0));
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if ($10) {
   $11 = ___cxa_find_matching_catch_3(0|0)|0;
   $12 = tempRet0;
   ___clang_call_terminate($11);
   // unreachable;
  } else {
   $eh$lpad$body$index2Z2D = $7;$eh$lpad$body$indexZ2D = $6;
   __ZdlPv($0);
   ___resumeException($eh$lpad$body$indexZ2D|0);
   // unreachable;
  }
 }
 $3 = ((($0)) + 12|0);
 __THREW__ = 0;
 invoke_vi(3807,($3|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  __ZdlPv($0);
  return;
 }
 $13 = ___cxa_find_matching_catch_2()|0;
 $14 = tempRet0;
 $eh$lpad$body$index2Z2D = $14;$eh$lpad$body$indexZ2D = $13;
 __ZdlPv($0);
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
}
function __ZN3osg21EndOfDynamicDrawBlock9completedEPNS_5StateE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 (FUNCTION_TABLE_ii[$5 & 8191]($2)|0);
 $6 = ((($0)) + 36|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0);
 if (!($8)) {
  $9 = (($7) + -1)|0;
  HEAP32[$6>>2] = $9;
  $10 = ($9|0)==(0);
  if ($10) {
   $11 = ((($0)) + 24|0);
   __THREW__ = 0;
   (invoke_ii(2504,($11|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if ($13) {
    $14 = ___cxa_find_matching_catch_2()|0;
    $15 = tempRet0;
    $16 = HEAP32[$2>>2]|0;
    $17 = ((($16)) + 12|0);
    $18 = HEAP32[$17>>2]|0;
    __THREW__ = 0;
    (invoke_ii($18|0,($2|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     $21 = ___cxa_find_matching_catch_3(0|0)|0;
     $22 = tempRet0;
     ___clang_call_terminate($21);
     // unreachable;
    } else {
     ___resumeException($14|0);
     // unreachable;
    }
   }
  }
 }
 $23 = HEAP32[$2>>2]|0;
 $24 = ((($23)) + 12|0);
 $25 = HEAP32[$24>>2]|0;
 (FUNCTION_TABLE_ii[$25 & 8191]($2)|0);
 return;
}
function __ZN11OpenThreads10BlockCountD2Ev($0) {
 $0 = $0|0;
 var $$0 = 0, $$02 = 0, $$pre = 0, $$pre$phiZ2D = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 20|0);
 HEAP32[$1>>2] = 0;
 $2 = HEAP32[$0>>2]|0;
 $3 = ((($2)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 __THREW__ = 0;
 (invoke_ii($4|0,($0|0))|0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 do {
  if ($6) {
   label = 9;
  } else {
   $7 = ((($0)) + 24|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ($8|0)==(0);
   if (!($9)) {
    HEAP32[$7>>2] = 0;
    $10 = ((($0)) + 12|0);
    __THREW__ = 0;
    (invoke_ii(2504,($10|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     $13 = ___cxa_find_matching_catch_2()|0;
     $14 = tempRet0;
     $15 = HEAP32[$0>>2]|0;
     $16 = ((($15)) + 12|0);
     $17 = HEAP32[$16>>2]|0;
     __THREW__ = 0;
     (invoke_ii($17|0,($0|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if (!($19)) {
      $$pre$phiZ2D = $10;$eh$lpad$body$index2Z2D = $14;$eh$lpad$body$indexZ2D = $13;
      label = 10;
      break;
     }
     $25 = ___cxa_find_matching_catch_3(0|0)|0;
     $26 = tempRet0;
     ___clang_call_terminate($25);
     // unreachable;
    }
   }
   $20 = HEAP32[$0>>2]|0;
   $21 = ((($20)) + 12|0);
   $22 = HEAP32[$21>>2]|0;
   __THREW__ = 0;
   (invoke_ii($22|0,($0|0))|0);
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if ($24) {
    label = 9;
   } else {
    $27 = ((($0)) + 12|0);
    __THREW__ = 0;
    invoke_vi(2499,($27|0));
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if ($29) {
     $34 = ___cxa_find_matching_catch_2()|0;
     $35 = tempRet0;
     $$0 = $35;$$02 = $34;
     break;
    } else {
     __ZN11OpenThreads5MutexD2Ev($0);
     return;
    }
   }
  }
 } while(0);
 if ((label|0) == 9) {
  $30 = ___cxa_find_matching_catch_2()|0;
  $31 = tempRet0;
  $$pre = ((($0)) + 12|0);
  $$pre$phiZ2D = $$pre;$eh$lpad$body$index2Z2D = $31;$eh$lpad$body$indexZ2D = $30;
  label = 10;
 }
 if ((label|0) == 10) {
  __THREW__ = 0;
  invoke_vi(2499,($$pre$phiZ2D|0));
  $32 = __THREW__; __THREW__ = 0;
  $33 = $32&1;
  if ($33) {
   $38 = ___cxa_find_matching_catch_3(0|0)|0;
   $39 = tempRet0;
   ___clang_call_terminate($38);
   // unreachable;
  } else {
   $$0 = $eh$lpad$body$index2Z2D;$$02 = $eh$lpad$body$indexZ2D;
  }
 }
 __THREW__ = 0;
 invoke_vi(707,($0|0));
 $36 = __THREW__; __THREW__ = 0;
 $37 = $36&1;
 if ($37) {
  $38 = ___cxa_find_matching_catch_3(0|0)|0;
  $39 = tempRet0;
  ___clang_call_terminate($38);
  // unreachable;
 } else {
  ___resumeException($$02|0);
  // unreachable;
 }
}
function __ZN3osg20SwapBuffersOperationD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = ((2636));
 $1 = ((($0)) + 20|0);
 HEAP32[$1>>2] = ((2668));
 $2 = ((($0)) + 4|0);
 $3 = ((($2)) + 11|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)<(0);
 if (!($5)) {
  __ZN3osg10ReferencedD2Ev($1);
  return;
 }
 $6 = HEAP32[$2>>2]|0;
 __ZdlPv($6);
 __ZN3osg10ReferencedD2Ev($1);
 return;
}
function __ZN3osg20SwapBuffersOperationD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = ((2636));
 $1 = ((($0)) + 20|0);
 HEAP32[$1>>2] = ((2668));
 $2 = ((($0)) + 4|0);
 $3 = ((($2)) + 11|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)<(0);
 if ($5) {
  $6 = HEAP32[$2>>2]|0;
  __ZdlPv($6);
 }
 __THREW__ = 0;
 invoke_vi(712,($1|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch_2()|0;
  $10 = tempRet0;
  __ZdlPv($0);
  ___resumeException($9|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZN3osg20SwapBuffersOperationclEPNS_15GraphicsContextE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$pre$phiZ2D = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = HEAP32[$3>>2]|0;
  $6 = ((($5)) + 12|0);
  $7 = HEAP32[$6>>2]|0;
  FUNCTION_TABLE_vi[$7 & 8191]($3);
 }
 $8 = ((($1)) + 116|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if ($10) {
  $14 = HEAP32[$1>>2]|0;
  $15 = ((($14)) + 180|0);
  $16 = HEAP32[$15>>2]|0;
  FUNCTION_TABLE_vi[$16 & 8191]($1);
  $$pre$phiZ2D = $1;
 } else {
  $11 = HEAP32[$9>>2]|0;
  $12 = ((($11)) + 12|0);
  $13 = HEAP32[$12>>2]|0;
  FUNCTION_TABLE_vii[$13 & 8191]($9,$1);
  $$pre$phiZ2D = $1;
 }
 $17 = HEAP32[$$pre$phiZ2D>>2]|0;
 $18 = ((($17)) + 148|0);
 $19 = HEAP32[$18>>2]|0;
 FUNCTION_TABLE_vi[$19 & 8191]($1);
 return;
}
function __ZTv0_n16_N3osg20SwapBuffersOperationD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 HEAP32[$4>>2] = ((2636));
 $5 = ((($4)) + 20|0);
 HEAP32[$5>>2] = ((2668));
 $6 = ((($4)) + 4|0);
 $7 = ((($6)) + 11|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = ($8<<24>>24)<(0);
 if (!($9)) {
  __ZN3osg10ReferencedD2Ev($5);
  return;
 }
 $10 = HEAP32[$6>>2]|0;
 __ZdlPv($10);
 __ZN3osg10ReferencedD2Ev($5);
 return;
}
function __ZTv0_n16_N3osg20SwapBuffersOperationD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 HEAP32[$4>>2] = ((2636));
 $5 = ((($4)) + 20|0);
 HEAP32[$5>>2] = ((2668));
 $6 = ((($4)) + 4|0);
 $7 = ((($6)) + 11|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = ($8<<24>>24)<(0);
 if ($9) {
  $10 = HEAP32[$6>>2]|0;
  __ZdlPv($10);
 }
 __THREW__ = 0;
 invoke_vi(712,($5|0));
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if ($12) {
  $13 = ___cxa_find_matching_catch_2()|0;
  $14 = tempRet0;
  __ZdlPv($4);
  ___resumeException($13|0);
  // unreachable;
 } else {
  __ZdlPv($4);
  return;
 }
}
function __ZN3osg16BarrierOperation7releaseEv($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 20|0);
 __ZN11OpenThreads7Barrier7releaseEv($1);
 return;
}
function __ZN3osg16BarrierOperationclEPNS_6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 32|0);
 $3 = HEAP32[$2>>2]|0;
 switch ($3|0) {
 case 2:  {
  _glFinish();
  break;
 }
 case 1:  {
  _glFlush();
  break;
 }
 default: {
 }
 }
 $4 = ((($0)) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($5)) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 FUNCTION_TABLE_vii[$7 & 8191]($4,0);
 return;
}
function __ZN3osg16BarrierOperationD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 20|0);
 __THREW__ = 0;
 invoke_vi(2494,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  HEAP32[$0>>2] = ((25244));
  $4 = ((($0)) + 36|0);
  HEAP32[$4>>2] = ((25276));
  $5 = ((($0)) + 4|0);
  $6 = ((($5)) + 11|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = ($7<<24>>24)<(0);
  if (!($8)) {
   __ZN3osg10ReferencedD2Ev($4);
   return;
  }
  $9 = HEAP32[$5>>2]|0;
  __ZdlPv($9);
  __ZN3osg10ReferencedD2Ev($4);
  return;
 }
 $10 = ___cxa_find_matching_catch_2()|0;
 $11 = tempRet0;
 HEAP32[$0>>2] = ((25244));
 $12 = ((($0)) + 36|0);
 HEAP32[$12>>2] = ((25276));
 $13 = ((($0)) + 4|0);
 $14 = ((($13)) + 11|0);
 $15 = HEAP8[$14>>0]|0;
 $16 = ($15<<24>>24)<(0);
 if ($16) {
  $17 = HEAP32[$13>>2]|0;
  __ZdlPv($17);
 }
 __THREW__ = 0;
 invoke_vi(712,($12|0));
 $18 = __THREW__; __THREW__ = 0;
 $19 = $18&1;
 if ($19) {
  $20 = ___cxa_find_matching_catch_3(0|0)|0;
  $21 = tempRet0;
  ___clang_call_terminate($20);
  // unreachable;
 } else {
  ___resumeException($10|0);
  // unreachable;
 }
}
function __ZN3osg16BarrierOperationD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 20|0);
 __THREW__ = 0;
 invoke_vi(2494,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $10 = ___cxa_find_matching_catch_2()|0;
  $11 = tempRet0;
  HEAP32[$0>>2] = ((25244));
  $12 = ((($0)) + 36|0);
  HEAP32[$12>>2] = ((25276));
  $13 = ((($0)) + 4|0);
  $14 = ((($13)) + 11|0);
  $15 = HEAP8[$14>>0]|0;
  $16 = ($15<<24>>24)<(0);
  if ($16) {
   $17 = HEAP32[$13>>2]|0;
   __ZdlPv($17);
  }
  __THREW__ = 0;
  invoke_vi(712,($12|0));
  $20 = __THREW__; __THREW__ = 0;
  $21 = $20&1;
  if ($21) {
   $22 = ___cxa_find_matching_catch_3(0|0)|0;
   $23 = tempRet0;
   ___clang_call_terminate($22);
   // unreachable;
  } else {
   $eh$lpad$body$index2Z2D = $11;$eh$lpad$body$indexZ2D = $10;
   __ZdlPv($0);
   ___resumeException($eh$lpad$body$indexZ2D|0);
   // unreachable;
  }
 }
 HEAP32[$0>>2] = ((25244));
 $4 = ((($0)) + 36|0);
 HEAP32[$4>>2] = ((25276));
 $5 = ((($0)) + 4|0);
 $6 = ((($5)) + 11|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = ($7<<24>>24)<(0);
 if ($8) {
  $9 = HEAP32[$5>>2]|0;
  __ZdlPv($9);
 }
 __THREW__ = 0;
 invoke_vi(712,($4|0));
 $18 = __THREW__; __THREW__ = 0;
 $19 = $18&1;
 if (!($19)) {
  __ZdlPv($0);
  return;
 }
 $24 = ___cxa_find_matching_catch_2()|0;
 $25 = tempRet0;
 $eh$lpad$body$index2Z2D = $25;$eh$lpad$body$indexZ2D = $24;
 __ZdlPv($0);
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
}
function __ZThn20_N3osg16BarrierOperationD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -20|0);
 $2 = ((($1)) + 20|0);
 __THREW__ = 0;
 invoke_vi(2494,($2|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if (!($4)) {
  HEAP32[$1>>2] = ((25244));
  $5 = ((($1)) + 36|0);
  HEAP32[$5>>2] = ((25276));
  $6 = ((($1)) + 15|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = ($7<<24>>24)<(0);
  if (!($8)) {
   __ZN3osg10ReferencedD2Ev($5);
   return;
  }
  $9 = ((($1)) + 4|0);
  $10 = HEAP32[$9>>2]|0;
  __ZdlPv($10);
  __ZN3osg10ReferencedD2Ev($5);
  return;
 }
 $11 = ___cxa_find_matching_catch_2()|0;
 $12 = tempRet0;
 HEAP32[$1>>2] = ((25244));
 $13 = ((($1)) + 36|0);
 HEAP32[$13>>2] = ((25276));
 $14 = ((($1)) + 15|0);
 $15 = HEAP8[$14>>0]|0;
 $16 = ($15<<24>>24)<(0);
 if ($16) {
  $17 = ((($1)) + 4|0);
  $18 = HEAP32[$17>>2]|0;
  __ZdlPv($18);
 }
 __THREW__ = 0;
 invoke_vi(712,($13|0));
 $19 = __THREW__; __THREW__ = 0;
 $20 = $19&1;
 if ($20) {
  $21 = ___cxa_find_matching_catch_3(0|0)|0;
  $22 = tempRet0;
  ___clang_call_terminate($21);
  // unreachable;
 } else {
  ___resumeException($11|0);
  // unreachable;
 }
}
function __ZThn20_N3osg16BarrierOperationD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -20|0);
 __ZN3osg16BarrierOperationD0Ev($1);
 return;
}
function __ZThn20_N3osg16BarrierOperation7releaseEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -20|0);
 $2 = ((($1)) + 20|0);
 __ZN11OpenThreads7Barrier7releaseEv($2);
 return;
}
function __ZTv0_n16_N3osg16BarrierOperationD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 $5 = ((($4)) + 20|0);
 __THREW__ = 0;
 invoke_vi(2494,($5|0));
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if (!($7)) {
  HEAP32[$4>>2] = ((25244));
  $8 = ((($4)) + 36|0);
  HEAP32[$8>>2] = ((25276));
  $9 = ((($4)) + 4|0);
  $10 = ((($9)) + 11|0);
  $11 = HEAP8[$10>>0]|0;
  $12 = ($11<<24>>24)<(0);
  if (!($12)) {
   __ZN3osg10ReferencedD2Ev($8);
   return;
  }
  $13 = HEAP32[$9>>2]|0;
  __ZdlPv($13);
  __ZN3osg10ReferencedD2Ev($8);
  return;
 }
 $14 = ___cxa_find_matching_catch_2()|0;
 $15 = tempRet0;
 HEAP32[$4>>2] = ((25244));
 $16 = ((($4)) + 36|0);
 HEAP32[$16>>2] = ((25276));
 $17 = ((($4)) + 4|0);
 $18 = ((($17)) + 11|0);
 $19 = HEAP8[$18>>0]|0;
 $20 = ($19<<24>>24)<(0);
 if ($20) {
  $21 = HEAP32[$17>>2]|0;
  __ZdlPv($21);
 }
 __THREW__ = 0;
 invoke_vi(712,($16|0));
 $22 = __THREW__; __THREW__ = 0;
 $23 = $22&1;
 if ($23) {
  $24 = ___cxa_find_matching_catch_3(0|0)|0;
  $25 = tempRet0;
  ___clang_call_terminate($24);
  // unreachable;
 } else {
  ___resumeException($14|0);
  // unreachable;
 }
}
function __ZTv0_n16_N3osg16BarrierOperationD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __ZN3osg16BarrierOperationD0Ev($4);
 return;
}
function __ZN3osg13RunOperationsD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = ((2636));
 $1 = ((($0)) + 20|0);
 HEAP32[$1>>2] = ((2668));
 $2 = ((($0)) + 4|0);
 $3 = ((($2)) + 11|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)<(0);
 if (!($5)) {
  __ZN3osg10ReferencedD2Ev($1);
  return;
 }
 $6 = HEAP32[$2>>2]|0;
 __ZdlPv($6);
 __ZN3osg10ReferencedD2Ev($1);
 return;
}
function __ZN3osg13RunOperationsD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = ((2636));
 $1 = ((($0)) + 20|0);
 HEAP32[$1>>2] = ((2668));
 $2 = ((($0)) + 4|0);
 $3 = ((($2)) + 11|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)<(0);
 if ($5) {
  $6 = HEAP32[$2>>2]|0;
  __ZdlPv($6);
 }
 __THREW__ = 0;
 invoke_vi(712,($1|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch_2()|0;
  $10 = tempRet0;
  __ZdlPv($0);
  ___resumeException($9|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZN3osg13RunOperationsclEPNS_15GraphicsContextE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 140|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vi[$4 & 8191]($1);
 return;
}
function __ZTv0_n16_N3osg13RunOperationsD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 HEAP32[$4>>2] = ((2636));
 $5 = ((($4)) + 20|0);
 HEAP32[$5>>2] = ((2668));
 $6 = ((($4)) + 4|0);
 $7 = ((($6)) + 11|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = ($8<<24>>24)<(0);
 if (!($9)) {
  __ZN3osg10ReferencedD2Ev($5);
  return;
 }
 $10 = HEAP32[$6>>2]|0;
 __ZdlPv($10);
 __ZN3osg10ReferencedD2Ev($5);
 return;
}
function __ZTv0_n16_N3osg13RunOperationsD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 HEAP32[$4>>2] = ((2636));
 $5 = ((($4)) + 20|0);
 HEAP32[$5>>2] = ((2668));
 $6 = ((($4)) + 4|0);
 $7 = ((($6)) + 11|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = ($8<<24>>24)<(0);
 if ($9) {
  $10 = HEAP32[$6>>2]|0;
  __ZdlPv($10);
 }
 __THREW__ = 0;
 invoke_vi(712,($5|0));
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if ($12) {
  $13 = ___cxa_find_matching_catch_2()|0;
  $14 = tempRet0;
  __ZdlPv($4);
  ___resumeException($13|0);
  // unreachable;
 } else {
  __ZdlPv($4);
  return;
 }
}
function __ZN3osg14GraphicsThreadC2Ev($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg15OperationThreadC2Ev($0);
 HEAP32[$0>>2] = (60692);
 $1 = ((($0)) + 12|0);
 HEAP32[$1>>2] = (60720);
 return;
}
function __ZN3osg22BlockAndFlushOperationC1Ev($0) {
 $0 = $0|0;
 var $$1 = 0, $$13 = 0, $$2 = 0, $$24 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $2 = ((($0)) + 44|0);
 __ZN3osg10ReferencedC2Eb($2,1);
 ;HEAP32[$1>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;
 $3 = ((($1)) + 11|0);
 HEAP8[$3>>0] = 5;
 ;HEAP8[$1>>0]=HEAP8[143789>>0]|0;HEAP8[$1+1>>0]=HEAP8[143789+1>>0]|0;HEAP8[$1+2>>0]=HEAP8[143789+2>>0]|0;HEAP8[$1+3>>0]=HEAP8[143789+3>>0]|0;HEAP8[$1+4>>0]=HEAP8[143789+4>>0]|0;
 $4 = ((($1)) + 5|0);
 HEAP8[$4>>0] = 0;
 HEAP32[$0>>2] = ((25004));
 HEAP32[$2>>2] = ((25036));
 $5 = ((($0)) + 4|0);
 __THREW__ = 0;
 invoke_vii(3457,($5|0),($1|0));
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if ($7) {
  $35 = ___cxa_find_matching_catch_2()|0;
  $36 = tempRet0;
  $37 = HEAP8[$3>>0]|0;
  $38 = ($37<<24>>24)<(0);
  if ($38) {
   $39 = HEAP32[$1>>2]|0;
   __ZdlPv($39);
  }
  $$2 = $36;$$24 = $35;
 } else {
  $8 = ((($0)) + 16|0);
  HEAP8[$8>>0] = 0;
  HEAP32[$0>>2] = ((25076));
  HEAP32[$2>>2] = ((25112));
  $9 = HEAP8[$3>>0]|0;
  $10 = ($9<<24>>24)<(0);
  if ($10) {
   $11 = HEAP32[$1>>2]|0;
   __ZdlPv($11);
  }
  $12 = ((($0)) + 20|0);
  __THREW__ = 0;
  invoke_vii(3507,($12|0),0);
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  do {
   if ($14) {
    $40 = ___cxa_find_matching_catch_2()|0;
    $41 = tempRet0;
    $eh$lpad$body$index2Z2D = $41;$eh$lpad$body$indexZ2D = $40;
    label = 15;
   } else {
    $15 = ((($0)) + 32|0);
    __THREW__ = 0;
    invoke_vi(3508,($15|0));
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     $18 = ___cxa_find_matching_catch_2()|0;
     $19 = tempRet0;
     __THREW__ = 0;
     invoke_vi(707,($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if (!($21)) {
      $eh$lpad$body$index2Z2D = $19;$eh$lpad$body$indexZ2D = $18;
      label = 15;
      break;
     }
     $22 = ___cxa_find_matching_catch_3(0|0)|0;
     $23 = tempRet0;
     ___clang_call_terminate($22);
     // unreachable;
    }
    $24 = ((($0)) + 40|0);
    HEAP8[$24>>0] = 0;
    HEAP32[$0>>2] = (60752);
    HEAP32[$2>>2] = (60788);
    $25 = HEAP32[$12>>2]|0;
    $26 = ((($25)) + 8|0);
    $27 = HEAP32[$26>>2]|0;
    __THREW__ = 0;
    (invoke_ii($27|0,($12|0))|0);
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if (!($29)) {
     HEAP8[$24>>0] = 0;
     $30 = HEAP32[$12>>2]|0;
     $31 = ((($30)) + 12|0);
     $32 = HEAP32[$31>>2]|0;
     __THREW__ = 0;
     (invoke_ii($32|0,($12|0))|0);
     $33 = __THREW__; __THREW__ = 0;
     $34 = $33&1;
     if (!($34)) {
      STACKTOP = sp;return;
     }
    }
    $42 = ___cxa_find_matching_catch_2()|0;
    $43 = tempRet0;
    __THREW__ = 0;
    invoke_vi(3805,($12|0));
    $44 = __THREW__; __THREW__ = 0;
    $45 = $44&1;
    if ($45) {
     $52 = ___cxa_find_matching_catch_3(0|0)|0;
     $53 = tempRet0;
     ___clang_call_terminate($52);
     // unreachable;
    } else {
     $$1 = $43;$$13 = $42;
    }
   }
  } while(0);
  if ((label|0) == 15) {
   $$1 = $eh$lpad$body$index2Z2D;$$13 = $eh$lpad$body$indexZ2D;
  }
  HEAP32[$0>>2] = ((25004));
  HEAP32[$2>>2] = ((25036));
  $46 = ((($5)) + 11|0);
  $47 = HEAP8[$46>>0]|0;
  $48 = ($47<<24>>24)<(0);
  if ($48) {
   $49 = HEAP32[$5>>2]|0;
   __ZdlPv($49);
   $$2 = $$1;$$24 = $$13;
  } else {
   $$2 = $$1;$$24 = $$13;
  }
 }
 __THREW__ = 0;
 invoke_vi(712,($2|0));
 $50 = __THREW__; __THREW__ = 0;
 $51 = $50&1;
 if ($51) {
  $52 = ___cxa_find_matching_catch_3(0|0)|0;
  $53 = tempRet0;
  ___clang_call_terminate($52);
  // unreachable;
 } else {
  ___resumeException($$24|0);
  // unreachable;
 }
}
function __ZN3osg21EndOfDynamicDrawBlockC2Ej($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 12|0);
 __ZN11OpenThreads5MutexC2ENS0_9MutexTypeE($2,0);
 $3 = ((($0)) + 24|0);
 __THREW__ = 0;
 invoke_vi(3508,($3|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch_2()|0;
  $7 = tempRet0;
  __THREW__ = 0;
  invoke_vi(707,($2|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if ($9) {
   $10 = ___cxa_find_matching_catch_3(0|0)|0;
   $11 = tempRet0;
   ___clang_call_terminate($10);
   // unreachable;
  } else {
   ___resumeException($6|0);
   // unreachable;
  }
 }
 $12 = ((($0)) + 32|0);
 HEAP32[$12>>2] = $1;
 $13 = ((($0)) + 36|0);
 HEAP32[$13>>2] = 0;
 __THREW__ = 0;
 invoke_vi(3282,($0|0));
 $14 = __THREW__; __THREW__ = 0;
 $15 = $14&1;
 if (!($15)) {
  HEAP32[$0>>2] = (60808);
  return;
 }
 $16 = ___cxa_find_matching_catch_2()|0;
 $17 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3807,($2|0));
 $18 = __THREW__; __THREW__ = 0;
 $19 = $18&1;
 if ($19) {
  $20 = ___cxa_find_matching_catch_3(0|0)|0;
  $21 = tempRet0;
  ___clang_call_terminate($20);
  // unreachable;
 } else {
  ___resumeException($16|0);
  // unreachable;
 }
}
function __ZN3osg5Group21setThreadSafeRefUnrefEb($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$sink9 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg4Node21setThreadSafeRefUnrefEb($0,$1);
 $2 = ((($0)) + 124|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 128|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if ($6) {
  return;
 } else {
  $$sink9 = $3;
 }
 while(1) {
  $7 = HEAP32[$$sink9>>2]|0;
  $8 = HEAP32[$7>>2]|0;
  $9 = HEAP32[$8>>2]|0;
  FUNCTION_TABLE_vii[$9 & 8191]($7,$1);
  $10 = ((($$sink9)) + 4|0);
  $11 = HEAP32[$4>>2]|0;
  $12 = ($10|0)==($11|0);
  if ($12) {
   break;
  } else {
   $$sink9 = $10;
  }
 }
 return;
}
function __ZN3osg5GroupD2Ev($0) {
 $0 = $0|0;
 var $$pre = 0, $$pre$i = 0, $$pre$i6 = 0, $$sroa$011$016 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (61120);
 $1 = ((($0)) + 124|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 128|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2|0)==($4|0);
 do {
  if ($5) {
   $6 = $2;$8 = $2;
  } else {
   $$sroa$011$016 = $2;
   while(1) {
    $24 = HEAP32[$$sroa$011$016>>2]|0;
    __THREW__ = 0;
    invoke_vii(3808,($24|0),($0|0));
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if ($26) {
     break;
    }
    $27 = ((($$sroa$011$016)) + 4|0);
    $28 = HEAP32[$3>>2]|0;
    $29 = ($27|0)==($28|0);
    if ($29) {
     label = 2;
     break;
    } else {
     $$sroa$011$016 = $27;
    }
   }
   if ((label|0) == 2) {
    $$pre = HEAP32[$1>>2]|0;
    $6 = $$pre;$8 = $27;
    break;
   }
   $30 = ___cxa_find_matching_catch_2()|0;
   $31 = tempRet0;
   $32 = HEAP32[$1>>2]|0;
   $33 = ($32|0)==(0|0);
   if (!($33)) {
    $34 = HEAP32[$3>>2]|0;
    $35 = ($34|0)==($32|0);
    do {
     if ($35) {
      $49 = $32;
     } else {
      $37 = $34;
      while(1) {
       $36 = ((($37)) + -4|0);
       HEAP32[$3>>2] = $36;
       $38 = HEAP32[$36>>2]|0;
       $39 = ($38|0)==(0|0);
       if (!($39)) {
        $40 = ((($38)) + 8|0);
        $41 = HEAP32[$40>>2]|0;HEAP32[$40>>2] = (($41-1)|0);
        $42 = ($41|0)==(1);
        if ($42) {
         __THREW__ = 0;
         invoke_viii(3262,($38|0),1,1);
         $43 = __THREW__; __THREW__ = 0;
         $44 = $43&1;
         if ($44) {
          label = 20;
          break;
         }
        }
       }
       HEAP32[$36>>2] = 0;
       $45 = HEAP32[$3>>2]|0;
       $46 = ($45|0)==($32|0);
       if ($46) {
        label = 21;
        break;
       } else {
        $37 = $45;
       }
      }
      if ((label|0) == 20) {
       $47 = ___cxa_find_matching_catch_2()|0;
       $48 = tempRet0;
       ___cxa_call_unexpected(($47|0));
       // unreachable;
      }
      else if ((label|0) == 21) {
       $$pre$i = HEAP32[$1>>2]|0;
       $49 = $$pre$i;
       break;
      }
     }
    } while(0);
    __ZdlPv($49);
   }
   __THREW__ = 0;
   invoke_vi(2026,($0|0));
   $50 = __THREW__; __THREW__ = 0;
   $51 = $50&1;
   if ($51) {
    $52 = ___cxa_find_matching_catch_3(0|0)|0;
    $53 = tempRet0;
    ___clang_call_terminate($52);
    // unreachable;
   } else {
    ___resumeException($30|0);
    // unreachable;
   }
  }
 } while(0);
 $7 = ($6|0)==(0|0);
 if ($7) {
  __ZN3osg4NodeD2Ev($0);
  return;
 }
 $9 = ($8|0)==($6|0);
 do {
  if ($9) {
   $23 = $6;
  } else {
   $11 = $8;
   while(1) {
    $10 = ((($11)) + -4|0);
    HEAP32[$3>>2] = $10;
    $12 = HEAP32[$10>>2]|0;
    $13 = ($12|0)==(0|0);
    if (!($13)) {
     $14 = ((($12)) + 8|0);
     $15 = HEAP32[$14>>2]|0;HEAP32[$14>>2] = (($15-1)|0);
     $16 = ($15|0)==(1);
     if ($16) {
      __THREW__ = 0;
      invoke_viii(3262,($12|0),1,1);
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if ($18) {
       label = 9;
       break;
      }
     }
    }
    HEAP32[$10>>2] = 0;
    $19 = HEAP32[$3>>2]|0;
    $20 = ($19|0)==($6|0);
    if ($20) {
     label = 10;
     break;
    } else {
     $11 = $19;
    }
   }
   if ((label|0) == 9) {
    $21 = ___cxa_find_matching_catch_2()|0;
    $22 = tempRet0;
    ___cxa_call_unexpected(($21|0));
    // unreachable;
   }
   else if ((label|0) == 10) {
    $$pre$i6 = HEAP32[$1>>2]|0;
    $23 = $$pre$i6;
    break;
   }
  }
 } while(0);
 __ZdlPv($23);
 __ZN3osg4NodeD2Ev($0);
 return;
}
function __ZN3osg5GroupD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1924,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK3osg5Group9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(136)|0);
 __THREW__ = 0;
 invoke_vi(3809,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $7 = ___cxa_find_matching_catch_2()|0;
  $8 = tempRet0;
  __ZdlPv($1);
  ___resumeException($7|0);
  // unreachable;
 } else {
  HEAP32[$1>>2] = (61120);
  $4 = ((($1)) + 124|0);
  HEAP32[$4>>2] = 0;
  $5 = ((($1)) + 128|0);
  HEAP32[$5>>2] = 0;
  $6 = ((($1)) + 132|0);
  HEAP32[$6>>2] = 0;
  return ($1|0);
 }
 return (0)|0;
}
function __ZNK3osg5Group5cloneERKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(136)|0);
 __THREW__ = 0;
 invoke_viii(3764,($2|0),($0|0),($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch_2()|0;
  $6 = tempRet0;
  __ZdlPv($2);
  ___resumeException($5|0);
  // unreachable;
 } else {
  return ($2|0);
 }
 return (0)|0;
}
function __ZNK3osg5Group12isSameKindAsEPKNS_6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,25304,0)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK3osg5Group11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175113|0);
}
function __ZNK3osg5Group9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (143949|0);
}
function __ZN3osg5Group21resizeGLObjectBuffersEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$sink9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg4Node21resizeGLObjectBuffersEj($0,$1);
 $2 = ((($0)) + 124|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 128|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if ($6) {
  return;
 } else {
  $$sink9 = $3;
 }
 while(1) {
  $7 = HEAP32[$$sink9>>2]|0;
  $8 = HEAP32[$7>>2]|0;
  $9 = ((($8)) + 132|0);
  $10 = HEAP32[$9>>2]|0;
  FUNCTION_TABLE_vii[$10 & 8191]($7,$1);
  $11 = ((($$sink9)) + 4|0);
  $12 = HEAP32[$4>>2]|0;
  $13 = ($11|0)==($12|0);
  if ($13) {
   break;
  } else {
   $$sink9 = $11;
  }
 }
 return;
}
function __ZNK3osg5Group16releaseGLObjectsEPNS_5StateE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$sroa$04$08 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZNK3osg4Node16releaseGLObjectsEPNS_5StateE($0,$1);
 $2 = ((($0)) + 124|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 128|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if ($6) {
  return;
 } else {
  $$sroa$04$08 = $3;
 }
 while(1) {
  $7 = HEAP32[$$sroa$04$08>>2]|0;
  $8 = HEAP32[$7>>2]|0;
  $9 = ((($8)) + 136|0);
  $10 = HEAP32[$9>>2]|0;
  FUNCTION_TABLE_vii[$10 & 8191]($7,$1);
  $11 = ((($$sroa$04$08)) + 4|0);
  $12 = HEAP32[$4>>2]|0;
  $13 = ($11|0)==($12|0);
  if ($13) {
   break;
  } else {
   $$sroa$04$08 = $11;
  }
 }
 return;
}
function __ZN3osg5Group6acceptERNS_11NodeVisitorE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$byval_copy = 0, $$pre$i$i = 0, $$sink$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i = 0, $scevgep5$i$i$i$i = 0, $scevgep5$i$i$i$sink$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy = sp + 8|0;
 $2 = sp + 4|0;
 $3 = sp;
 $4 = ((($1)) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($1)) + 24|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($0)) + 116|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $9 | $7;
 $11 = $10 & $5;
 $12 = ($11|0)==(0);
 if ($12) {
  STACKTOP = sp;return;
 }
 HEAP32[$2>>2] = $0;
 $13 = ((($1)) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(1);
 $16 = ((($1)) + 28|0);
 $17 = $0;
 do {
  if ($15) {
   $25 = HEAP32[$16>>2]|0;
   HEAP32[$3>>2] = $25;
   ;HEAP32[$$byval_copy>>2]=HEAP32[$3>>2]|0;
   (__ZNSt3__26vectorIPN3osg4NodeENS_9allocatorIS3_EEE6insertENS_11__wrap_iterIPKS3_EERS8_($16,$$byval_copy,$2)|0);
  } else {
   $18 = ((($1)) + 32|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ((($1)) + 36|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = ($19|0)==($21|0);
   if ($22) {
    __ZNSt3__26vectorIPN3osg4NodeENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_($16,$2);
    break;
   } else {
    HEAP32[$19>>2] = $17;
    $23 = HEAP32[$18>>2]|0;
    $24 = ((($23)) + 4|0);
    HEAP32[$18>>2] = $24;
    break;
   }
  }
 } while(0);
 $26 = HEAP32[$1>>2]|0;
 $27 = ((($26)) + 120|0);
 $28 = HEAP32[$27>>2]|0;
 FUNCTION_TABLE_vii[$28 & 8191]($1,$0);
 $29 = HEAP32[$13>>2]|0;
 $30 = ($29|0)==(1);
 do {
  if ($30) {
   $34 = ((($1)) + 28|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ((($35)) + 4|0);
   $37 = ((($1)) + 32|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = $36;
   $40 = (($38) - ($39))|0;
   $41 = $40 >> 2;
   $42 = ($41|0)==(0);
   $43 = $38;
   if ($42) {
    $45 = $43;
   } else {
    _memmove(($35|0),($36|0),($40|0))|0;
    $$pre$i$i = HEAP32[$37>>2]|0;
    $45 = $$pre$i$i;
   }
   $44 = (($35) + ($41<<2)|0);
   $46 = ($45|0)==($44|0);
   if ($46) {
    STACKTOP = sp;return;
   } else {
    $scevgep$i$i$i$i = ((($45)) + -4|0);
    $47 = $scevgep$i$i$i$i;
    $48 = $44;
    $49 = (($47) - ($48))|0;
    $50 = $49 >>> 2;
    $51 = $50 ^ -1;
    $scevgep5$i$i$i$i = (($45) + ($51<<2)|0);
    $$sink$i = $37;$scevgep5$i$i$i$sink$i = $scevgep5$i$i$i$i;
    break;
   }
  } else {
   $31 = ((($1)) + 32|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ((($32)) + -4|0);
   $$sink$i = $31;$scevgep5$i$i$i$sink$i = $33;
  }
 } while(0);
 HEAP32[$$sink$i>>2] = $scevgep5$i$i$i$sink$i;
 STACKTOP = sp;return;
}
function __ZN3osg5Group8traverseERNS_11NodeVisitorE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$sroa$03$07 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 124|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 128|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if ($6) {
  return;
 } else {
  $$sroa$03$07 = $3;
 }
 while(1) {
  $7 = HEAP32[$$sroa$03$07>>2]|0;
  $8 = HEAP32[$7>>2]|0;
  $9 = ((($8)) + 188|0);
  $10 = HEAP32[$9>>2]|0;
  FUNCTION_TABLE_vii[$10 & 8191]($7,$1);
  $11 = ((($$sroa$03$07)) + 4|0);
  $12 = HEAP32[$4>>2]|0;
  $13 = ($11|0)==($12|0);
  if ($13) {
   break;
  } else {
   $$sroa$03$07 = $11;
  }
 }
 return;
}
function __ZNK3osg5Group12computeBoundEv($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$not = 0, $$sroa$040$074 = 0, $$sroa$040$172 = 0, $$sroa$047$073 = 0.0, $$sroa$047$1 = 0.0, $$sroa$047$3 = 0.0, $$sroa$047$5 = 0.0, $$sroa$10$075 = 0.0, $$sroa$10$1 = 0.0, $$sroa$10$3 = 0.0, $$sroa$10$5 = 0.0, $$sroa$18$076 = 0.0, $$sroa$18$1 = 0.0, $$sroa$18$3 = 0.0, $$sroa$18$5 = 0.0, $$sroa$26$077 = 0.0, $$sroa$26$1 = 0.0, $$sroa$26$3 = 0.0, $$sroa$26$5 = 0.0, $$sroa$34$078 = 0.0;
 var $$sroa$34$1 = 0.0, $$sroa$34$3 = 0.0, $$sroa$34$5 = 0.0, $$sroa$42$079 = 0.0, $$sroa$42$3 = 0.0, $10 = 0, $100 = 0.0, $101 = 0, $102 = 0.0, $103 = 0.0, $104 = 0.0, $105 = 0.0, $106 = 0.0, $107 = 0.0, $108 = 0.0, $109 = 0.0, $11 = 0, $110 = 0.0, $111 = 0.0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0.0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0.0;
 var $27 = 0.0, $28 = 0, $29 = 0, $3 = 0, $30 = 0.0, $31 = 0, $32 = 0.0, $33 = 0, $34 = 0, $35 = 0.0, $36 = 0, $37 = 0.0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0.0, $48 = 0, $49 = 0.0, $5 = 0, $50 = 0.0, $51 = 0, $52 = 0.0, $53 = 0, $54 = 0, $55 = 0.0, $56 = 0.0, $57 = 0, $58 = 0.0, $59 = 0, $6 = 0, $60 = 0, $61 = 0.0, $62 = 0.0;
 var $63 = 0, $64 = 0.0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0.0, $72 = 0.0, $73 = 0.0, $74 = 0.0, $75 = 0.0, $76 = 0.0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0.0, $91 = 0, $92 = 0, $93 = 0.0, $94 = 0.0, $95 = 0.0, $96 = 0.0, $97 = 0, $98 = 0.0, $99 = 0.0;
 var $brmerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF32[$0>>2] = 0.0;
 $2 = ((($0)) + 4|0);
 HEAPF32[$2>>2] = 0.0;
 $3 = ((($0)) + 8|0);
 HEAPF32[$3>>2] = 0.0;
 $4 = ((($0)) + 12|0);
 HEAPF32[$4>>2] = -1.0;
 $5 = ((($1)) + 124|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($1)) + 128|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6|0)==($8|0);
 if ($9) {
  return;
 } else {
  $$sroa$040$074 = $6;$$sroa$047$073 = 3.4028234663852886E+38;$$sroa$10$075 = 3.4028234663852886E+38;$$sroa$18$076 = 3.4028234663852886E+38;$$sroa$26$077 = -3.4028234663852886E+38;$$sroa$34$078 = -3.4028234663852886E+38;$$sroa$42$079 = -3.4028234663852886E+38;
 }
 while(1) {
  $10 = HEAP32[$$sroa$040$074>>2]|0;
  $11 = HEAP32[$10>>2]|0;
  $12 = ((($11)) + 156|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (FUNCTION_TABLE_ii[$13 & 8191]($10)|0);
  $15 = ($14|0)==(0|0);
  if ($15) {
   label = 4;
  } else {
   $16 = ((($14)) + 136|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = ($17|0)==(0);
   if ($18) {
    label = 4;
   } else {
    $$sroa$047$5 = $$sroa$047$073;$$sroa$10$5 = $$sroa$10$075;$$sroa$18$5 = $$sroa$18$076;$$sroa$26$5 = $$sroa$26$077;$$sroa$34$5 = $$sroa$34$078;$$sroa$42$3 = $$sroa$42$079;
   }
  }
  do {
   if ((label|0) == 4) {
    label = 0;
    $19 = HEAP32[$10>>2]|0;
    $20 = ((($19)) + 80|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (FUNCTION_TABLE_ii[$21 & 8191]($10)|0);
    $23 = ($22|0)==(0|0);
    if ($23) {
     $45 = (__ZNK3osg4Node8getBoundEv($10)|0);
     $46 = ((($45)) + 12|0);
     $47 = +HEAPF32[$46>>2];
     $48 = !($47 >= 0.0);
     if ($48) {
      $$sroa$047$5 = $$sroa$047$073;$$sroa$10$5 = $$sroa$10$075;$$sroa$18$5 = $$sroa$18$076;$$sroa$26$5 = $$sroa$26$077;$$sroa$34$5 = $$sroa$34$078;$$sroa$42$3 = $$sroa$42$079;
      break;
     }
     $49 = +HEAPF32[$45>>2];
     $50 = $49 - $47;
     $51 = $50 < $$sroa$047$073;
     $$sroa$047$3 = $51 ? $50 : $$sroa$047$073;
     $52 = $47 + $49;
     $53 = $52 > $$sroa$26$077;
     $$sroa$26$3 = $53 ? $52 : $$sroa$26$077;
     $54 = ((($45)) + 4|0);
     $55 = +HEAPF32[$54>>2];
     $56 = $55 - $47;
     $57 = $56 < $$sroa$10$075;
     $$sroa$10$3 = $57 ? $56 : $$sroa$10$075;
     $58 = $55 + $47;
     $59 = $58 > $$sroa$34$078;
     $$sroa$34$3 = $59 ? $58 : $$sroa$34$078;
     $60 = ((($45)) + 8|0);
     $61 = +HEAPF32[$60>>2];
     $62 = $61 - $47;
     $63 = $62 < $$sroa$18$076;
     $$sroa$18$3 = $63 ? $62 : $$sroa$18$076;
     $64 = $61 + $47;
     $65 = $64 > $$sroa$42$079;
     if (!($65)) {
      $$sroa$047$5 = $$sroa$047$3;$$sroa$10$5 = $$sroa$10$3;$$sroa$18$5 = $$sroa$18$3;$$sroa$26$5 = $$sroa$26$3;$$sroa$34$5 = $$sroa$34$3;$$sroa$42$3 = $$sroa$42$079;
      break;
     }
     $$sroa$047$5 = $$sroa$047$3;$$sroa$10$5 = $$sroa$10$3;$$sroa$18$5 = $$sroa$18$3;$$sroa$26$5 = $$sroa$26$3;$$sroa$34$5 = $$sroa$34$3;$$sroa$42$3 = $64;
     break;
    }
    $24 = (__ZNK3osg8Drawable14getBoundingBoxEv($22)|0);
    $25 = ((($24)) + 12|0);
    $26 = +HEAPF32[$25>>2];
    $27 = +HEAPF32[$24>>2];
    $28 = !($26 >= $27);
    if ($28) {
     $$sroa$047$5 = $$sroa$047$073;$$sroa$10$5 = $$sroa$10$075;$$sroa$18$5 = $$sroa$18$076;$$sroa$26$5 = $$sroa$26$077;$$sroa$34$5 = $$sroa$34$078;$$sroa$42$3 = $$sroa$42$079;
    } else {
     $29 = ((($24)) + 16|0);
     $30 = +HEAPF32[$29>>2];
     $31 = ((($24)) + 4|0);
     $32 = +HEAPF32[$31>>2];
     $33 = !($30 >= $32);
     if ($33) {
      $$sroa$047$5 = $$sroa$047$073;$$sroa$10$5 = $$sroa$10$075;$$sroa$18$5 = $$sroa$18$076;$$sroa$26$5 = $$sroa$26$077;$$sroa$34$5 = $$sroa$34$078;$$sroa$42$3 = $$sroa$42$079;
     } else {
      $34 = ((($24)) + 20|0);
      $35 = +HEAPF32[$34>>2];
      $36 = ((($24)) + 8|0);
      $37 = +HEAPF32[$36>>2];
      $38 = !($35 >= $37);
      if ($38) {
       $$sroa$047$5 = $$sroa$047$073;$$sroa$10$5 = $$sroa$10$075;$$sroa$18$5 = $$sroa$18$076;$$sroa$26$5 = $$sroa$26$077;$$sroa$34$5 = $$sroa$34$078;$$sroa$42$3 = $$sroa$42$079;
      } else {
       $39 = $27 < $$sroa$047$073;
       $$sroa$047$1 = $39 ? $27 : $$sroa$047$073;
       $40 = $26 > $$sroa$26$077;
       $$sroa$26$1 = $40 ? $26 : $$sroa$26$077;
       $41 = $32 < $$sroa$10$075;
       $$sroa$10$1 = $41 ? $32 : $$sroa$10$075;
       $42 = $30 > $$sroa$34$078;
       $$sroa$34$1 = $42 ? $30 : $$sroa$34$078;
       $43 = $37 < $$sroa$18$076;
       $$sroa$18$1 = $43 ? $37 : $$sroa$18$076;
       $44 = $35 > $$sroa$42$079;
       if ($44) {
        $$sroa$047$5 = $$sroa$047$1;$$sroa$10$5 = $$sroa$10$1;$$sroa$18$5 = $$sroa$18$1;$$sroa$26$5 = $$sroa$26$1;$$sroa$34$5 = $$sroa$34$1;$$sroa$42$3 = $35;
       } else {
        $$sroa$047$5 = $$sroa$047$1;$$sroa$10$5 = $$sroa$10$1;$$sroa$18$5 = $$sroa$18$1;$$sroa$26$5 = $$sroa$26$1;$$sroa$34$5 = $$sroa$34$1;$$sroa$42$3 = $$sroa$42$079;
       }
      }
     }
    }
   }
  } while(0);
  $66 = ((($$sroa$040$074)) + 4|0);
  $67 = HEAP32[$7>>2]|0;
  $68 = ($66|0)==($67|0);
  if ($68) {
   break;
  } else {
   $$sroa$040$074 = $66;$$sroa$047$073 = $$sroa$047$5;$$sroa$10$075 = $$sroa$10$5;$$sroa$18$076 = $$sroa$18$5;$$sroa$26$077 = $$sroa$26$5;$$sroa$34$078 = $$sroa$34$5;$$sroa$42$079 = $$sroa$42$3;
  }
 }
 $69 = !($$sroa$26$5 >= $$sroa$047$5);
 if ($69) {
  return;
 }
 $70 = !($$sroa$34$5 >= $$sroa$10$5);
 $$not = !($$sroa$42$3 >= $$sroa$18$5);
 $brmerge = $70 | $$not;
 if ($brmerge) {
  return;
 }
 $71 = $$sroa$047$5 + $$sroa$26$5;
 $72 = $$sroa$10$5 + $$sroa$34$5;
 $73 = $$sroa$18$5 + $$sroa$42$3;
 $74 = $71 * 0.5;
 $75 = $72 * 0.5;
 $76 = $73 * 0.5;
 HEAPF32[$0>>2] = $74;
 HEAPF32[$2>>2] = $75;
 HEAPF32[$3>>2] = $76;
 HEAPF32[$4>>2] = 0.0;
 $77 = HEAP32[$5>>2]|0;
 $78 = ($77|0)==($66|0);
 if ($78) {
  return;
 }
 $$sroa$040$172 = $77;$93 = 0.0;
 while(1) {
  $79 = HEAP32[$$sroa$040$172>>2]|0;
  $80 = HEAP32[$79>>2]|0;
  $81 = ((($80)) + 156|0);
  $82 = HEAP32[$81>>2]|0;
  $83 = (FUNCTION_TABLE_ii[$82 & 8191]($79)|0);
  $84 = ($83|0)==(0|0);
  if ($84) {
   label = 20;
  } else {
   $85 = ((($83)) + 136|0);
   $86 = HEAP32[$85>>2]|0;
   $87 = ($86|0)==(0);
   if ($87) {
    label = 20;
   } else {
    $116 = $93;
   }
  }
  do {
   if ((label|0) == 20) {
    label = 0;
    $88 = (__ZNK3osg4Node8getBoundEv($79)|0);
    $89 = ((($88)) + 12|0);
    $90 = +HEAPF32[$89>>2];
    $91 = !($90 >= 0.0);
    if ($91) {
     $116 = $93;
    } else {
     $92 = !($93 >= 0.0);
     if ($92) {
      ;HEAP32[$0>>2]=HEAP32[$88>>2]|0;HEAP32[$0+4>>2]=HEAP32[$88+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$88+8>>2]|0;
      HEAPF32[$4>>2] = $90;
      $116 = $90;
      break;
     }
     $94 = +HEAPF32[$88>>2];
     $95 = +HEAPF32[$0>>2];
     $96 = $94 - $95;
     $97 = ((($88)) + 4|0);
     $98 = +HEAPF32[$97>>2];
     $99 = +HEAPF32[$2>>2];
     $100 = $98 - $99;
     $101 = ((($88)) + 8|0);
     $102 = +HEAPF32[$101>>2];
     $103 = +HEAPF32[$3>>2];
     $104 = $102 - $103;
     $105 = $96 * $96;
     $106 = $100 * $100;
     $107 = $105 + $106;
     $108 = $104 * $104;
     $109 = $107 + $108;
     $110 = (+Math_sqrt((+$109)));
     $111 = $90 + $110;
     $112 = $111 > $93;
     if ($112) {
      HEAPF32[$4>>2] = $111;
      $116 = $111;
     } else {
      $116 = $93;
     }
    }
   }
  } while(0);
  $113 = ((($$sroa$040$172)) + 4|0);
  $114 = HEAP32[$7>>2]|0;
  $115 = ($113|0)==($114|0);
  if ($115) {
   break;
  } else {
   $$sroa$040$172 = $113;$93 = $116;
  }
 }
 return;
}
function __ZN3osg5Group8addChildEPNS_4NodeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 124|0);
 $3 = ((($0)) + 128|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$2>>2]|0;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 2;
 $8 = (__ZN3osg5Group11insertChildEjPNS_4NodeE($0,$7,$1)|0);
 return ($8|0);
}
function __ZN3osg5Group11insertChildEjPNS_4NodeE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$024 = 0, $$025 = 0, $$026 = 0, $$byval_copy = 0, $$pre$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy = sp + 12|0;
 $3 = sp + 8|0;
 $4 = sp + 4|0;
 $5 = sp;
 $6 = ($2|0)==(0|0);
 if ($6) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $7 = HEAP32[$2>>2]|0;
 $8 = ((($7)) + 140|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (FUNCTION_TABLE_ii[$9 & 8191]($2)|0);
 $11 = ($10|0)==(0|0);
 if (!($11)) {
  $12 = ((($10)) + 272|0);
  $13 = HEAP8[$12>>0]|0;
  $14 = ($13<<24>>24)==(0);
  if (!($14)) {
   __ZN3osg8Geometry17fixDeprecatedDataEv($10);
  }
 }
 $15 = ((($0)) + 124|0);
 $16 = ((($0)) + 128|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = HEAP32[$15>>2]|0;
 $19 = (($17) - ($18))|0;
 $20 = $19 >> 2;
 $21 = ($20>>>0)>($1>>>0);
 do {
  if ($21) {
   $50 = $18;
   $51 = (($50) + ($1<<2)|0);
   $52 = $51;
   HEAP32[$4>>2] = $52;
   HEAP32[$5>>2] = $2;
   $53 = ((($2)) + 8|0);
   $54 = HEAP32[$53>>2]|0;HEAP32[$53>>2] = (($54+1)|0);
   __THREW__ = 0;
   ;HEAP32[$$byval_copy>>2]=HEAP32[$4>>2]|0;
   (invoke_iiii(3811,($15|0),($$byval_copy|0),($5|0))|0);
   $55 = __THREW__; __THREW__ = 0;
   $56 = $55&1;
   if (!($56)) {
    $57 = HEAP32[$5>>2]|0;
    $58 = ($57|0)==(0|0);
    if (!($58)) {
     $59 = ((($57)) + 8|0);
     $60 = HEAP32[$59>>2]|0;HEAP32[$59>>2] = (($60-1)|0);
     $61 = ($60|0)==(1);
     if ($61) {
      __ZNK3osg10Referenced24signalObserversAndDeleteEbb($57,1,1);
     }
    }
    $$026 = $1;
    break;
   }
   $62 = ___cxa_find_matching_catch_2()|0;
   $63 = tempRet0;
   $64 = HEAP32[$5>>2]|0;
   $65 = ($64|0)==(0|0);
   if (!($65)) {
    $66 = ((($64)) + 8|0);
    $67 = HEAP32[$66>>2]|0;HEAP32[$66>>2] = (($67-1)|0);
    $68 = ($67|0)==(1);
    if ($68) {
     __THREW__ = 0;
     invoke_viii(3262,($64|0),1,1);
     $69 = __THREW__; __THREW__ = 0;
     $70 = $69&1;
     if ($70) {
      $108 = ___cxa_find_matching_catch_3(0|0)|0;
      $109 = tempRet0;
      ___clang_call_terminate($108);
      // unreachable;
     }
    }
   }
   $$024 = $63;$$025 = $62;
   ___resumeException($$025|0);
   // unreachable;
  } else {
   HEAP32[$3>>2] = $2;
   $22 = ((($2)) + 8|0);
   $23 = HEAP32[$22>>2]|0;HEAP32[$22>>2] = (($23+1)|0);
   $24 = HEAP32[$16>>2]|0;
   $25 = ((($0)) + 132|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = ($24|0)==($26|0);
   if ($27) {
    __THREW__ = 0;
    invoke_vii(3810,($15|0),($3|0));
    $34 = __THREW__; __THREW__ = 0;
    $35 = $34&1;
    if ($35) {
     $41 = ___cxa_find_matching_catch_2()|0;
     $42 = tempRet0;
     $43 = HEAP32[$3>>2]|0;
     $44 = ($43|0)==(0|0);
     if (!($44)) {
      $45 = ((($43)) + 8|0);
      $46 = HEAP32[$45>>2]|0;HEAP32[$45>>2] = (($46-1)|0);
      $47 = ($46|0)==(1);
      if ($47) {
       __THREW__ = 0;
       invoke_viii(3262,($43|0),1,1);
       $48 = __THREW__; __THREW__ = 0;
       $49 = $48&1;
       if ($49) {
        $108 = ___cxa_find_matching_catch_3(0|0)|0;
        $109 = tempRet0;
        ___clang_call_terminate($108);
        // unreachable;
       }
      }
     }
     $$024 = $42;$$025 = $41;
     ___resumeException($$025|0);
     // unreachable;
    }
   } else {
    $28 = HEAP32[$3>>2]|0;
    HEAP32[$24>>2] = $28;
    $29 = ($28|0)==(0|0);
    if ($29) {
     $33 = $24;
    } else {
     $30 = ((($28)) + 8|0);
     $31 = HEAP32[$30>>2]|0;HEAP32[$30>>2] = (($31+1)|0);
     $$pre$i = HEAP32[$16>>2]|0;
     $33 = $$pre$i;
    }
    $32 = ((($33)) + 4|0);
    HEAP32[$16>>2] = $32;
   }
   $36 = HEAP32[$3>>2]|0;
   $37 = ($36|0)==(0|0);
   if (!($37)) {
    $38 = ((($36)) + 8|0);
    $39 = HEAP32[$38>>2]|0;HEAP32[$38>>2] = (($39-1)|0);
    $40 = ($39|0)==(1);
    if ($40) {
     __ZNK3osg10Referenced24signalObserversAndDeleteEbb($36,1,1);
    }
   }
   $$026 = $20;
  }
 } while(0);
 __ZN3osg4Node9addParentEPNS_5GroupE($2,$0);
 $71 = HEAP32[$0>>2]|0;
 $72 = ((($71)) + 236|0);
 $73 = HEAP32[$72>>2]|0;
 FUNCTION_TABLE_vii[$73 & 8191]($0,$$026);
 __ZN3osg4Node10dirtyBoundEv($0);
 $74 = ((($2)) + 88|0);
 $75 = HEAP32[$74>>2]|0;
 $76 = ($75|0)==(0);
 if ($76) {
  $77 = ((($2)) + 84|0);
  $78 = HEAP32[$77>>2]|0;
  $79 = ($78|0)==(0|0);
  if (!($79)) {
   label = 30;
  }
 } else {
  label = 30;
 }
 if ((label|0) == 30) {
  $80 = ((($0)) + 88|0);
  $81 = HEAP32[$80>>2]|0;
  $82 = (($81) + 1)|0;
  __ZN3osg4Node38setNumChildrenRequiringUpdateTraversalEj($0,$82);
 }
 $83 = ((($2)) + 96|0);
 $84 = HEAP32[$83>>2]|0;
 $85 = ($84|0)==(0);
 if ($85) {
  $86 = ((($2)) + 92|0);
  $87 = HEAP32[$86>>2]|0;
  $88 = ($87|0)==(0|0);
  if (!($88)) {
   label = 33;
  }
 } else {
  label = 33;
 }
 if ((label|0) == 33) {
  $89 = ((($0)) + 96|0);
  $90 = HEAP32[$89>>2]|0;
  $91 = (($90) + 1)|0;
  __ZN3osg4Node37setNumChildrenRequiringEventTraversalEj($0,$91);
 }
 $92 = ((($2)) + 108|0);
 $93 = HEAP32[$92>>2]|0;
 $94 = ($93|0)==(0);
 if ($94) {
  $95 = ((($2)) + 104|0);
  $96 = HEAP8[$95>>0]|0;
  $97 = ($96<<24>>24)==(0);
  if ($97) {
   label = 36;
  }
 } else {
  label = 36;
 }
 if ((label|0) == 36) {
  $98 = ((($0)) + 108|0);
  $99 = HEAP32[$98>>2]|0;
  $100 = (($99) + 1)|0;
  __ZN3osg4Node33setNumChildrenWithCullingDisabledEj($0,$100);
 }
 $101 = ((($2)) + 112|0);
 $102 = HEAP32[$101>>2]|0;
 $103 = ($102|0)==(0);
 if ($103) {
  $104 = (___dynamic_cast($2,25952,26152,0)|0);
  $phitmp = ($104|0)==(0|0);
  if ($phitmp) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $105 = ((($0)) + 112|0);
 $106 = HEAP32[$105>>2]|0;
 $107 = (($106) + 1)|0;
 __ZN3osg4Node31setNumChildrenWithOccluderNodesEj($0,$107);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN3osg5Group11removeChildEPNS_4NodeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$079$i = 0, $$1$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 124|0);
 $3 = ((($0)) + 128|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$2>>2]|0;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 2;
 $8 = ($7|0)==(0);
 $9 = $5;
 L1: do {
  if ($8) {
   $$1$i = 0;
  } else {
   $$079$i = 0;
   while(1) {
    $10 = (($9) + ($$079$i<<2)|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)==($1|0);
    if ($12) {
     $$1$i = $$079$i;
     break L1;
    }
    $13 = (($$079$i) + 1)|0;
    $14 = ($13>>>0)<($7>>>0);
    if ($14) {
     $$079$i = $13;
    } else {
     $$0 = 0;
     break;
    }
   }
   return ($$0|0);
  }
 } while(0);
 $15 = ($$1$i>>>0)<($7>>>0);
 if (!($15)) {
  $$0 = 0;
  return ($$0|0);
 }
 $16 = HEAP32[$0>>2]|0;
 $17 = ((($16)) + 216|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (FUNCTION_TABLE_iiii[$18 & 8191]($0,$$1$i,1)|0);
 $$0 = $19;
 return ($$0|0);
}
function __ZN3osg5Group14removeChildrenEjj($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$051 = 0, $$05270 = 0, $$053$lcssa = 0, $$05369 = 0, $$054$lcssa = 0, $$05468 = 0, $$056$lcssa = 0, $$05667 = 0, $$058$lcssa = 0, $$05866 = 0, $$1 = 0, $$155 = 0, $$157 = 0, $$159 = 0, $$byval_copy = 0, $$byval_copy1 = 0, $$in = 0, $$pre = 0, $$pre$phiZ2D = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $exitcond = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $$byval_copy1 = sp + 20|0;
 $$byval_copy = sp + 16|0;
 $3 = sp + 12|0;
 $4 = sp + 8|0;
 $5 = sp + 4|0;
 $6 = sp;
 $7 = ((($0)) + 124|0);
 $8 = ((($0)) + 128|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$7>>2]|0;
 $11 = (($9) - ($10))|0;
 $12 = $11 >> 2;
 $13 = ($12>>>0)>($1>>>0);
 $14 = ($2|0)!=(0);
 $or$cond = $14 & $13;
 if (!($or$cond)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $15 = (($2) + ($1))|0;
 $16 = ($15>>>0)>($12>>>0);
 if ($16) {
  $17 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(5)|0);
  do {
   if ($17) {
    $18 = (__ZN3osg6notifyENS_14NotifySeverityE(5)|0);
    $19 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($18,143795,86)|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = ((($20)) + -12|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = (($19) + ($22)|0);
    __ZNKSt3__28ios_base6getlocEv($4,$23);
    __THREW__ = 0;
    $24 = (invoke_iii(3255,($4|0),(215188|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = HEAP32[$24>>2]|0;
     $28 = ((($27)) + 28|0);
     $29 = HEAP32[$28>>2]|0;
     __THREW__ = 0;
     $30 = (invoke_iii($29|0,($24|0),10)|0);
     $31 = __THREW__; __THREW__ = 0;
     $32 = $31&1;
     if (!($32)) {
      __ZNSt3__26localeD2Ev($4);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($19,$30)|0);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($19)|0);
      break;
     }
    }
    $33 = ___cxa_find_matching_catch_2()|0;
    $34 = tempRet0;
    __THREW__ = 0;
    invoke_vi(3263,($4|0));
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     $37 = ___cxa_find_matching_catch_3(0|0)|0;
     $38 = tempRet0;
     ___clang_call_terminate($37);
     // unreachable;
    } else {
     ___resumeException($33|0);
     // unreachable;
    }
   }
  } while(0);
  $39 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(5)|0);
  do {
   if ($39) {
    $40 = (__ZN3osg6notifyENS_14NotifySeverityE(5)|0);
    $41 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($40,143882,66)|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = ((($42)) + -12|0);
    $44 = HEAP32[$43>>2]|0;
    $45 = (($41) + ($44)|0);
    __ZNKSt3__28ios_base6getlocEv($3,$45);
    __THREW__ = 0;
    $46 = (invoke_iii(3255,($3|0),(215188|0))|0);
    $47 = __THREW__; __THREW__ = 0;
    $48 = $47&1;
    if (!($48)) {
     $49 = HEAP32[$46>>2]|0;
     $50 = ((($49)) + 28|0);
     $51 = HEAP32[$50>>2]|0;
     __THREW__ = 0;
     $52 = (invoke_iii($51|0,($46|0),10)|0);
     $53 = __THREW__; __THREW__ = 0;
     $54 = $53&1;
     if (!($54)) {
      __ZNSt3__26localeD2Ev($3);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($41,$52)|0);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($41)|0);
      break;
     }
    }
    $55 = ___cxa_find_matching_catch_2()|0;
    $56 = tempRet0;
    __THREW__ = 0;
    invoke_vi(3263,($3|0));
    $57 = __THREW__; __THREW__ = 0;
    $58 = $57&1;
    if ($58) {
     $59 = ___cxa_find_matching_catch_3(0|0)|0;
     $60 = tempRet0;
     ___clang_call_terminate($59);
     // unreachable;
    } else {
     ___resumeException($55|0);
     // unreachable;
    }
   }
  } while(0);
  $61 = HEAP32[$8>>2]|0;
  $62 = HEAP32[$7>>2]|0;
  $63 = (($61) - ($62))|0;
  $64 = $63 >> 2;
  $$051 = $64;$$in = $62;
 } else {
  $$051 = $15;$$in = $10;
 }
 $65 = ($$051>>>0)>($1>>>0);
 L27: do {
  if ($65) {
   $66 = $$in;
   $$05270 = $1;$$05369 = 0;$$05468 = 0;$$05667 = 0;$$05866 = 0;$78 = $66;
   while(1) {
    $77 = (($78) + ($$05270<<2)|0);
    $79 = HEAP32[$77>>2]|0;
    __ZN3osg4Node12removeParentEPNS_5GroupE($79,$0);
    $80 = ((($79)) + 88|0);
    $81 = HEAP32[$80>>2]|0;
    $82 = ($81|0)==(0);
    if ($82) {
     $83 = ((($79)) + 84|0);
     $84 = HEAP32[$83>>2]|0;
     $85 = ($84|0)==(0|0);
     if ($85) {
      $$159 = $$05866;
     } else {
      label = 24;
     }
    } else {
     label = 24;
    }
    if ((label|0) == 24) {
     label = 0;
     $86 = (($$05866) + 1)|0;
     $$159 = $86;
    }
    $87 = ((($79)) + 96|0);
    $88 = HEAP32[$87>>2]|0;
    $89 = ($88|0)==(0);
    if ($89) {
     $90 = ((($79)) + 92|0);
     $91 = HEAP32[$90>>2]|0;
     $92 = ($91|0)==(0|0);
     if ($92) {
      $$157 = $$05667;
     } else {
      label = 27;
     }
    } else {
     label = 27;
    }
    if ((label|0) == 27) {
     label = 0;
     $93 = (($$05667) + 1)|0;
     $$157 = $93;
    }
    $94 = ((($79)) + 108|0);
    $95 = HEAP32[$94>>2]|0;
    $96 = ($95|0)==(0);
    if ($96) {
     $97 = ((($79)) + 104|0);
     $98 = HEAP8[$97>>0]|0;
     $99 = ($98<<24>>24)==(0);
     if ($99) {
      label = 30;
     } else {
      $$155 = $$05468;
     }
    } else {
     label = 30;
    }
    if ((label|0) == 30) {
     label = 0;
     $100 = (($$05468) + 1)|0;
     $$155 = $100;
    }
    $101 = ((($79)) + 112|0);
    $102 = HEAP32[$101>>2]|0;
    $103 = ($102|0)==(0);
    if ($103) {
     $104 = (___dynamic_cast($79,25952,26152,0)|0);
     $105 = ($104|0)==(0|0);
     if ($105) {
      $$1 = $$05369;
     } else {
      label = 33;
     }
    } else {
     label = 33;
    }
    if ((label|0) == 33) {
     label = 0;
     $106 = (($$05369) + 1)|0;
     $$1 = $106;
    }
    $107 = (($$05270) + 1)|0;
    $exitcond = ($107|0)==($$051|0);
    if ($exitcond) {
     $$053$lcssa = $$1;$$054$lcssa = $$155;$$056$lcssa = $$157;$$058$lcssa = $$159;$$pre$phiZ2D = $7;
     break L27;
    }
    $$pre = HEAP32[$7>>2]|0;
    $$05270 = $107;$$05369 = $$1;$$05468 = $$155;$$05667 = $$157;$$05866 = $$159;$78 = $$pre;
   }
  } else {
   $$053$lcssa = 0;$$054$lcssa = 0;$$056$lcssa = 0;$$058$lcssa = 0;$$pre$phiZ2D = $7;
  }
 } while(0);
 $67 = HEAP32[$0>>2]|0;
 $68 = ((($67)) + 232|0);
 $69 = HEAP32[$68>>2]|0;
 $70 = (($$051) - ($1))|0;
 FUNCTION_TABLE_viii[$69 & 8191]($0,$1,$70);
 $71 = HEAP32[$$pre$phiZ2D>>2]|0;
 $72 = (($71) + ($1<<2)|0);
 $73 = $72;
 HEAP32[$5>>2] = $73;
 $74 = (($71) + ($$051<<2)|0);
 $75 = $74;
 HEAP32[$6>>2] = $75;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$5>>2]|0;
 ;HEAP32[$$byval_copy1>>2]=HEAP32[$6>>2]|0;
 (__ZNSt3__26vectorIN3osg7ref_ptrINS1_4NodeEEENS_9allocatorIS4_EEE5eraseENS_11__wrap_iterIPKS4_EESB_($7,$$byval_copy,$$byval_copy1)|0);
 $76 = ($$058$lcssa|0)==(0);
 if (!($76)) {
  $108 = ((($0)) + 88|0);
  $109 = HEAP32[$108>>2]|0;
  $110 = (($109) - ($$058$lcssa))|0;
  __ZN3osg4Node38setNumChildrenRequiringUpdateTraversalEj($0,$110);
 }
 $111 = ($$056$lcssa|0)==(0);
 if (!($111)) {
  $112 = ((($0)) + 96|0);
  $113 = HEAP32[$112>>2]|0;
  $114 = (($113) - ($$056$lcssa))|0;
  __ZN3osg4Node37setNumChildrenRequiringEventTraversalEj($0,$114);
 }
 $115 = ($$054$lcssa|0)==(0);
 if (!($115)) {
  $116 = ((($0)) + 108|0);
  $117 = HEAP32[$116>>2]|0;
  $118 = (($117) - ($$054$lcssa))|0;
  __ZN3osg4Node33setNumChildrenWithCullingDisabledEj($0,$118);
 }
 $119 = ($$053$lcssa|0)==(0);
 if (!($119)) {
  $120 = ((($0)) + 112|0);
  $121 = HEAP32[$120>>2]|0;
  $122 = (($121) - ($$053$lcssa))|0;
  __ZN3osg4Node31setNumChildrenWithOccluderNodesEj($0,$122);
 }
 __ZN3osg4Node10dirtyBoundEv($0);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN3osg5Group12replaceChildEPNS_4NodeES2_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$079$i = 0, $$1 = 0, $$1$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($2|0)==(0|0);
 $4 = ($1|0)==($2|0);
 $or$cond = $3 | $4;
 if ($or$cond) {
  $$1 = 0;
  return ($$1|0);
 }
 $5 = ((($0)) + 124|0);
 $6 = ((($0)) + 128|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$5>>2]|0;
 $9 = (($7) - ($8))|0;
 $10 = $9 >> 2;
 $11 = ($10|0)==(0);
 $12 = $8;
 L4: do {
  if ($11) {
   $$1$i = 0;
  } else {
   $$079$i = 0;
   while(1) {
    $13 = (($12) + ($$079$i<<2)|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ($14|0)==($1|0);
    if ($15) {
     $$1$i = $$079$i;
     break L4;
    }
    $16 = (($$079$i) + 1)|0;
    $17 = ($16>>>0)<($10>>>0);
    if ($17) {
     $$079$i = $16;
    } else {
     $$1 = 0;
     break;
    }
   }
   return ($$1|0);
  }
 } while(0);
 $18 = ($$1$i>>>0)<($10>>>0);
 if (!($18)) {
  $$1 = 0;
  return ($$1|0);
 }
 $19 = HEAP32[$0>>2]|0;
 $20 = ((($19)) + 228|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (FUNCTION_TABLE_iiii[$21 & 8191]($0,$$1$i,$2)|0);
 $$1 = $22;
 return ($$1|0);
}
function __ZNK3osg5Group14getNumChildrenEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 124|0);
 $2 = ((($0)) + 128|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$1>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 return ($6|0);
}
function __ZN3osg5Group8setChildEjPNS_4NodeE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$045 = 0, $$047 = 0, $$049 = 0, $$057 = 0, $$1 = 0, $$146 = 0, $$148 = 0, $$150 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $phitmp = 0, $phitmp58 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 124|0);
 $4 = ((($0)) + 128|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$3>>2]|0;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 2;
 $9 = ($8>>>0)>($1>>>0);
 $10 = ($2|0)!=(0|0);
 $or$cond = $10 & $9;
 if (!($or$cond)) {
  $$057 = 0;
  return ($$057|0);
 }
 $11 = $6;
 $12 = (($11) + ($1<<2)|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0|0);
 if (!($14)) {
  $15 = ((($13)) + 8|0);
  $16 = HEAP32[$15>>2]|0;HEAP32[$15>>2] = (($16+1)|0);
 }
 __THREW__ = 0;
 invoke_vii(3808,($13|0),($0|0));
 $17 = __THREW__; __THREW__ = 0;
 $18 = $17&1;
 do {
  if (!($18)) {
   $19 = HEAP32[$3>>2]|0;
   $20 = (($19) + ($1<<2)|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = ($21|0)==($2|0);
   if (!($22)) {
    HEAP32[$20>>2] = $2;
    $23 = ((($2)) + 8|0);
    $24 = HEAP32[$23>>2]|0;HEAP32[$23>>2] = (($24+1)|0);
    $25 = ($21|0)==(0|0);
    if (!($25)) {
     $26 = ((($21)) + 8|0);
     $27 = HEAP32[$26>>2]|0;HEAP32[$26>>2] = (($27-1)|0);
     $28 = ($27|0)==(1);
     if ($28) {
      __THREW__ = 0;
      invoke_viii(3262,($21|0),1,1);
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if ($30) {
       break;
      }
     }
    }
   }
   __THREW__ = 0;
   invoke_vii(3812,($2|0),($0|0));
   $31 = __THREW__; __THREW__ = 0;
   $32 = $31&1;
   if (!($32)) {
    __THREW__ = 0;
    invoke_vi(3323,($0|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = ((($13)) + 88|0);
     $36 = HEAP32[$35>>2]|0;
     $37 = ($36|0)==(0);
     if ($37) {
      $38 = ((($13)) + 84|0);
      $39 = HEAP32[$38>>2]|0;
      $40 = ($39|0)==(0|0);
      if ($40) {
       $$049 = 0;
      } else {
       label = 13;
      }
     } else {
      label = 13;
     }
     if ((label|0) == 13) {
      $$049 = -1;
     }
     $41 = ((($2)) + 88|0);
     $42 = HEAP32[$41>>2]|0;
     $43 = ($42|0)==(0);
     if ($43) {
      $44 = ((($2)) + 84|0);
      $45 = HEAP32[$44>>2]|0;
      $46 = ($45|0)==(0|0);
      if ($46) {
       $$150 = $$049;
      } else {
       label = 16;
      }
     } else {
      label = 16;
     }
     if ((label|0) == 16) {
      $47 = (($$049) + 1)|0;
      $$150 = $47;
     }
     $48 = ($$150|0)==(0);
     if (!($48)) {
      $49 = ((($0)) + 88|0);
      $50 = HEAP32[$49>>2]|0;
      $51 = (($50) + ($$150))|0;
      __THREW__ = 0;
      invoke_vii(3813,($0|0),($51|0));
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       break;
      }
     }
     $54 = ((($13)) + 96|0);
     $55 = HEAP32[$54>>2]|0;
     $56 = ($55|0)==(0);
     if ($56) {
      $57 = ((($13)) + 92|0);
      $58 = HEAP32[$57>>2]|0;
      $59 = ($58|0)==(0|0);
      if ($59) {
       $$047 = 0;
      } else {
       label = 21;
      }
     } else {
      label = 21;
     }
     if ((label|0) == 21) {
      $$047 = -1;
     }
     $60 = ((($2)) + 96|0);
     $61 = HEAP32[$60>>2]|0;
     $62 = ($61|0)==(0);
     if ($62) {
      $63 = ((($2)) + 92|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = ($64|0)==(0|0);
      if ($65) {
       $$148 = $$047;
      } else {
       label = 24;
      }
     } else {
      label = 24;
     }
     if ((label|0) == 24) {
      $66 = (($$047) + 1)|0;
      $$148 = $66;
     }
     $67 = ($$148|0)==(0);
     if (!($67)) {
      $68 = ((($0)) + 96|0);
      $69 = HEAP32[$68>>2]|0;
      $70 = (($69) + ($$148))|0;
      __THREW__ = 0;
      invoke_vii(3814,($0|0),($70|0));
      $71 = __THREW__; __THREW__ = 0;
      $72 = $71&1;
      if ($72) {
       break;
      }
     }
     $73 = ((($13)) + 108|0);
     $74 = HEAP32[$73>>2]|0;
     $75 = ($74|0)==(0);
     if ($75) {
      $76 = ((($13)) + 104|0);
      $77 = HEAP8[$76>>0]|0;
      $78 = ($77<<24>>24)==(0);
      if ($78) {
       label = 29;
      } else {
       $$045 = 0;
      }
     } else {
      label = 29;
     }
     if ((label|0) == 29) {
      $$045 = -1;
     }
     $79 = ((($2)) + 108|0);
     $80 = HEAP32[$79>>2]|0;
     $81 = ($80|0)==(0);
     if ($81) {
      $82 = ((($2)) + 104|0);
      $83 = HEAP8[$82>>0]|0;
      $84 = ($83<<24>>24)==(0);
      if ($84) {
       label = 32;
      } else {
       $$146 = $$045;
      }
     } else {
      label = 32;
     }
     if ((label|0) == 32) {
      $85 = (($$045) + 1)|0;
      $$146 = $85;
     }
     $86 = ($$146|0)==(0);
     if (!($86)) {
      $87 = ((($0)) + 108|0);
      $88 = HEAP32[$87>>2]|0;
      $89 = (($88) + ($$146))|0;
      __THREW__ = 0;
      invoke_vii(3815,($0|0),($89|0));
      $90 = __THREW__; __THREW__ = 0;
      $91 = $90&1;
      if ($91) {
       break;
      }
     }
     $92 = ((($13)) + 112|0);
     $93 = HEAP32[$92>>2]|0;
     $94 = ($93|0)==(0);
     if ($94) {
      $95 = (___dynamic_cast($13,25952,26152,0)|0);
      $phitmp = ($95|0)==(0|0);
      if ($phitmp) {
       $$0 = 0;
      } else {
       label = 37;
      }
     } else {
      label = 37;
     }
     if ((label|0) == 37) {
      $$0 = -1;
     }
     $96 = ((($2)) + 112|0);
     $97 = HEAP32[$96>>2]|0;
     $98 = ($97|0)==(0);
     if ($98) {
      $99 = (___dynamic_cast($2,25952,26152,0)|0);
      $phitmp58 = ($99|0)==(0|0);
      if ($phitmp58) {
       $$1 = $$0;
      } else {
       label = 40;
      }
     } else {
      label = 40;
     }
     if ((label|0) == 40) {
      $100 = (($$0) + 1)|0;
      $$1 = $100;
     }
     $101 = ($$1|0)==(0);
     if (!($101)) {
      $102 = ((($0)) + 112|0);
      $103 = HEAP32[$102>>2]|0;
      $104 = (($103) + ($$1))|0;
      __THREW__ = 0;
      invoke_vii(3816,($0|0),($104|0));
      $105 = __THREW__; __THREW__ = 0;
      $106 = $105&1;
      if ($106) {
       break;
      }
     }
     $107 = ((($13)) + 8|0);
     $108 = HEAP32[$107>>2]|0;HEAP32[$107>>2] = (($108-1)|0);
     $109 = ($108|0)==(1);
     if (!($109)) {
      $$057 = 1;
      return ($$057|0);
     }
     __ZNK3osg10Referenced24signalObserversAndDeleteEbb($13,1,1);
     $$057 = 1;
     return ($$057|0);
    }
   }
  }
 } while(0);
 $110 = ___cxa_find_matching_catch_2()|0;
 $111 = tempRet0;
 if ($14) {
  ___resumeException($110|0);
  // unreachable;
 }
 $112 = ((($13)) + 8|0);
 $113 = HEAP32[$112>>2]|0;HEAP32[$112>>2] = (($113-1)|0);
 $114 = ($113|0)==(1);
 if (!($114)) {
  ___resumeException($110|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(3262,($13|0),1,1);
 $115 = __THREW__; __THREW__ = 0;
 $116 = $115&1;
 if ($116) {
  $117 = ___cxa_find_matching_catch_3(0|0)|0;
  $118 = tempRet0;
  ___clang_call_terminate($117);
  // unreachable;
 } else {
  ___resumeException($110|0);
  // unreachable;
 }
 return (0)|0;
}
function __ZNSt3__26vectorIN3osg7ref_ptrINS1_4NodeEEENS_9allocatorIS4_EEE5eraseENS_11__wrap_iterIPKS4_EESB_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$lcssa$i$i = 0, $$078$i$i = 0, $$09$i$i = 0, $$cast = 0, $$pre = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = HEAP32[$0>>2]|0;
 $4 = $3;
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) - ($4))|0;
 $7 = $6 >> 2;
 $8 = (($3) + ($7<<2)|0);
 $$cast = $5;
 $9 = HEAP32[$2>>2]|0;
 $10 = ($$cast|0)==($9|0);
 if ($10) {
  return ($8|0);
 }
 $11 = $9;
 $12 = (($11) - ($5))|0;
 $13 = $12 >> 2;
 $14 = (($8) + ($13<<2)|0);
 $15 = ((($0)) + 4|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($14|0)==($16|0);
 if ($17) {
  $$0$lcssa$i$i = $8;$31 = $14;
 } else {
  $$078$i$i = $14;$$09$i$i = $8;
  while(1) {
   $18 = HEAP32[$$09$i$i>>2]|0;
   $19 = HEAP32[$$078$i$i>>2]|0;
   $20 = ($18|0)==($19|0);
   if (!($20)) {
    HEAP32[$$09$i$i>>2] = $19;
    $21 = ($19|0)==(0|0);
    if (!($21)) {
     $22 = ((($19)) + 8|0);
     $23 = HEAP32[$22>>2]|0;HEAP32[$22>>2] = (($23+1)|0);
    }
    $24 = ($18|0)==(0|0);
    if (!($24)) {
     $25 = ((($18)) + 8|0);
     $26 = HEAP32[$25>>2]|0;HEAP32[$25>>2] = (($26-1)|0);
     $27 = ($26|0)==(1);
     if ($27) {
      __ZNK3osg10Referenced24signalObserversAndDeleteEbb($18,1,1);
     }
    }
   }
   $28 = ((($$078$i$i)) + 4|0);
   $29 = ((($$09$i$i)) + 4|0);
   $30 = ($28|0)==($16|0);
   if ($30) {
    break;
   } else {
    $$078$i$i = $28;$$09$i$i = $29;
   }
  }
  $$pre = HEAP32[$15>>2]|0;
  $$0$lcssa$i$i = $29;$31 = $$pre;
 }
 $32 = ($31|0)==($$0$lcssa$i$i|0);
 if ($32) {
  return ($8|0);
 } else {
  $34 = $31;
 }
 while(1) {
  $33 = ((($34)) + -4|0);
  HEAP32[$15>>2] = $33;
  $35 = HEAP32[$33>>2]|0;
  $36 = ($35|0)==(0|0);
  if (!($36)) {
   $37 = ((($35)) + 8|0);
   $38 = HEAP32[$37>>2]|0;HEAP32[$37>>2] = (($38-1)|0);
   $39 = ($38|0)==(1);
   if ($39) {
    __THREW__ = 0;
    invoke_viii(3262,($35|0),1,1);
    $40 = __THREW__; __THREW__ = 0;
    $41 = $40&1;
    if ($41) {
     label = 16;
     break;
    }
   }
  }
  HEAP32[$33>>2] = 0;
  $42 = HEAP32[$15>>2]|0;
  $43 = ($42|0)==($$0$lcssa$i$i|0);
  if ($43) {
   label = 17;
   break;
  } else {
   $34 = $42;
  }
 }
 if ((label|0) == 16) {
  $44 = ___cxa_find_matching_catch_2()|0;
  $45 = tempRet0;
  ___cxa_call_unexpected(($44|0));
  // unreachable;
 }
 else if ((label|0) == 17) {
  return ($8|0);
 }
 return (0)|0;
}
function __ZNSt3__26vectorIN3osg7ref_ptrINS1_4NodeEEENS_9allocatorIS4_EEE6insertENS_11__wrap_iterIPKS4_EERS9_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$ = 0, $$0 = 0, $$017$i = 0, $$025 = 0, $$056$i$i$i = 0, $$06$i$i = 0, $$07$i$i = 0, $$07$i$i$i = 0, $$idx = 0, $$in$i = 0, $$pre = 0, $$pre$i = 0, $$pre82 = 0, $$sroa$11$1 = 0, $$sroa$11$2 = 0, $$sroa$11$3 = 0, $$sroa$26$2 = 0, $$sroa$26$3 = 0, $$sroa$46$1 = 0, $$sroa$speculated$$i = 0;
 var $$sroa$speculated$i = 0, $$sroa$speculated$i38 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = HEAP32[$0>>2]|0;
 $4 = $3;
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) - ($4))|0;
 $7 = $6 >> 2;
 $8 = (($3) + ($7<<2)|0);
 $9 = ((($0)) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ((($0)) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($10>>>0)<($12>>>0);
 $14 = $10;
 $15 = $12;
 if ($13) {
  $16 = ($8|0)==($10|0);
  if ($16) {
   $17 = HEAP32[$2>>2]|0;
   HEAP32[$8>>2] = $17;
   $18 = ($17|0)==(0|0);
   if ($18) {
    $22 = $8;
   } else {
    $19 = ((($17)) + 8|0);
    $20 = HEAP32[$19>>2]|0;HEAP32[$19>>2] = (($20+1)|0);
    $$pre82 = HEAP32[$9>>2]|0;
    $22 = $$pre82;
   }
   $21 = ((($22)) + 4|0);
   HEAP32[$9>>2] = $21;
   $$0 = $8;
   return ($$0|0);
  }
  $23 = ((($8)) + 4|0);
  $24 = $23;
  $25 = (($14) - ($24))|0;
  $26 = $25 >> 2;
  $27 = (($8) + ($26<<2)|0);
  $28 = ($27>>>0)<($10>>>0);
  if ($28) {
   $$017$i = $27;$44 = $10;
   while(1) {
    $43 = HEAP32[$$017$i>>2]|0;
    HEAP32[$44>>2] = $43;
    $45 = ($43|0)==(0|0);
    if ($45) {
     $50 = $44;
    } else {
     $46 = ((($43)) + 8|0);
     $47 = HEAP32[$46>>2]|0;HEAP32[$46>>2] = (($47+1)|0);
     $$pre$i = HEAP32[$9>>2]|0;
     $50 = $$pre$i;
    }
    $48 = ((($$017$i)) + 4|0);
    $49 = ((($50)) + 4|0);
    HEAP32[$9>>2] = $49;
    $51 = ($48>>>0)<($10>>>0);
    if ($51) {
     $$017$i = $48;$44 = $49;
    } else {
     break;
    }
   }
  }
  $29 = ($26|0)==(0);
  if (!($29)) {
   $$056$i$i$i = $27;$$07$i$i$i = $10;
   while(1) {
    $30 = ((($$056$i$i$i)) + -4|0);
    $31 = ((($$07$i$i$i)) + -4|0);
    $32 = HEAP32[$31>>2]|0;
    $33 = HEAP32[$30>>2]|0;
    $34 = ($32|0)==($33|0);
    if (!($34)) {
     HEAP32[$31>>2] = $33;
     $36 = ($33|0)==(0|0);
     if (!($36)) {
      $37 = ((($33)) + 8|0);
      $38 = HEAP32[$37>>2]|0;HEAP32[$37>>2] = (($38+1)|0);
     }
     $39 = ($32|0)==(0|0);
     if (!($39)) {
      $40 = ((($32)) + 8|0);
      $41 = HEAP32[$40>>2]|0;HEAP32[$40>>2] = (($41-1)|0);
      $42 = ($41|0)==(1);
      if ($42) {
       __ZNK3osg10Referenced24signalObserversAndDeleteEbb($32,1,1);
      }
     }
    }
    $35 = ($30|0)==($8|0);
    if ($35) {
     break;
    } else {
     $$056$i$i$i = $30;$$07$i$i$i = $31;
    }
   }
  }
  $52 = ($8>>>0)>($2>>>0);
  if ($52) {
   $$025 = $2;
  } else {
   $53 = HEAP32[$9>>2]|0;
   $54 = ($53>>>0)>($2>>>0);
   $55 = ((($2)) + 4|0);
   $$ = $54 ? $55 : $2;
   $$025 = $$;
  }
  $56 = HEAP32[$8>>2]|0;
  $57 = HEAP32[$$025>>2]|0;
  $58 = ($56|0)==($57|0);
  if ($58) {
   $$0 = $8;
   return ($$0|0);
  }
  HEAP32[$8>>2] = $57;
  $59 = ($57|0)==(0|0);
  if (!($59)) {
   $60 = ((($57)) + 8|0);
   $61 = HEAP32[$60>>2]|0;HEAP32[$60>>2] = (($61+1)|0);
  }
  $62 = ($56|0)==(0|0);
  if ($62) {
   $$0 = $8;
   return ($$0|0);
  }
  $63 = ((($56)) + 8|0);
  $64 = HEAP32[$63>>2]|0;HEAP32[$63>>2] = (($64-1)|0);
  $65 = ($64|0)==(1);
  if (!($65)) {
   $$0 = $8;
   return ($$0|0);
  }
  __ZNK3osg10Referenced24signalObserversAndDeleteEbb($56,1,1);
  $$0 = $8;
  return ($$0|0);
 }
 $66 = (($14) - ($4))|0;
 $67 = $66 >> 2;
 $68 = (($67) + 1)|0;
 $69 = ($68>>>0)>(1073741823);
 if ($69) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $70 = (($15) - ($4))|0;
 $71 = $70 >> 2;
 $72 = ($71>>>0)<(536870911);
 $73 = $70 >> 1;
 $74 = ($73>>>0)<($68>>>0);
 $$sroa$speculated$i38 = $74 ? $68 : $73;
 $$sroa$speculated$$i = $72 ? $$sroa$speculated$i38 : 1073741823;
 $75 = $6 >> 2;
 $76 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($76) {
   $115 = 0;$86 = 0;
  } else {
   $77 = ($$sroa$speculated$$i>>>0)>(1073741823);
   if (!($77)) {
    $83 = $$sroa$speculated$$i << 2;
    $84 = (__Znwj($83)|0);
    $115 = $84;$86 = $84;
    break;
   }
   $78 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($78|0),(204840|0));
   $79 = __THREW__; __THREW__ = 0;
   $80 = $79&1;
   if ($80) {
    $81 = ___cxa_find_matching_catch_2()|0;
    $82 = tempRet0;
    ___cxa_free_exception(($78|0));
    ___resumeException($81|0);
    // unreachable;
   } else {
    HEAP32[$78>>2] = (99824);
    ___cxa_throw(($78|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $85 = (($86) + ($75<<2)|0);
 $87 = $85;
 $88 = (($86) + ($$sroa$speculated$$i<<2)|0);
 $89 = $88;
 $90 = ($75|0)==($$sroa$speculated$$i|0);
 L58: do {
  if ($90) {
   $91 = ($6|0)>(0);
   if ($91) {
    $92 = (($$sroa$speculated$$i) + 1)|0;
    $93 = (($92|0) / -2)&-1;
    $94 = (($85) + ($93<<2)|0);
    $95 = $94;
    $$sroa$11$1 = $95;$$sroa$46$1 = $89;
    break;
   }
   $$idx = $$sroa$speculated$$i << 2;
   $96 = $$idx >> 1;
   $97 = ($96|0)==(0);
   $$sroa$speculated$i = $97 ? 1 : $96;
   $98 = ($$sroa$speculated$i>>>0)>(1073741823);
   do {
    if ($98) {
     $99 = (___cxa_allocate_exception(8)|0);
     __THREW__ = 0;
     invoke_vii(3366,($99|0),(204840|0));
     $100 = __THREW__; __THREW__ = 0;
     $101 = $100&1;
     if ($101) {
      $103 = ___cxa_find_matching_catch_2()|0;
      $104 = tempRet0;
      ___cxa_free_exception(($99|0));
      $eh$lpad$body$index2Z2D = $104;$eh$lpad$body$indexZ2D = $103;
      break;
     } else {
      HEAP32[$99>>2] = (99824);
      __THREW__ = 0;
      invoke_viii(3695,($99|0),(34608|0),(3230|0));
      $102 = __THREW__; __THREW__ = 0;
      label = 64;
      break;
     }
    } else {
     $105 = $$sroa$speculated$i << 2;
     __THREW__ = 0;
     $106 = (invoke_ii(3276,($105|0))|0);
     $107 = __THREW__; __THREW__ = 0;
     $108 = $107&1;
     if ($108) {
      label = 64;
     } else {
      $109 = $$sroa$speculated$i >>> 2;
      $110 = (($106) + ($109<<2)|0);
      $111 = $110;
      $112 = (($106) + ($$sroa$speculated$i<<2)|0);
      $113 = $112;
      $114 = ($86|0)==(0|0);
      if ($114) {
       $$sroa$11$1 = $111;$$sroa$46$1 = $113;
       break L58;
      }
      __ZdlPv($115);
      $$sroa$11$1 = $111;$$sroa$46$1 = $113;
      break L58;
     }
    }
   } while(0);
   if ((label|0) == 64) {
    $168 = ___cxa_find_matching_catch_2()|0;
    $169 = tempRet0;
    $eh$lpad$body$index2Z2D = $169;$eh$lpad$body$indexZ2D = $168;
   }
   $170 = ($86|0)==(0|0);
   if ($170) {
    ___resumeException($eh$lpad$body$indexZ2D|0);
    // unreachable;
   }
   __ZdlPv($115);
   ___resumeException($eh$lpad$body$indexZ2D|0);
   // unreachable;
  } else {
   $$sroa$11$1 = $87;$$sroa$46$1 = $89;
  }
 } while(0);
 $116 = $$sroa$11$1;
 $117 = HEAP32[$2>>2]|0;
 HEAP32[$116>>2] = $117;
 $118 = ($117|0)==(0|0);
 if (!($118)) {
  $119 = ((($117)) + 8|0);
  $120 = HEAP32[$119>>2]|0;HEAP32[$119>>2] = (($120+1)|0);
 }
 $121 = ((($116)) + 4|0);
 $122 = $121;
 $123 = $$sroa$11$1;
 $124 = HEAP32[$0>>2]|0;
 $125 = ($124|0)==($8|0);
 if ($125) {
  $$in$i = $123;$$sroa$11$3 = $$sroa$11$1;
 } else {
  $$06$i$i = $8;$$sroa$11$2 = $$sroa$11$1;$128 = $123;
  while(1) {
   $126 = ((($$06$i$i)) + -4|0);
   $127 = ((($128)) + -4|0);
   $129 = HEAP32[$126>>2]|0;
   HEAP32[$127>>2] = $129;
   $130 = ($129|0)==(0|0);
   if (!($130)) {
    $131 = ((($129)) + 8|0);
    $132 = HEAP32[$131>>2]|0;HEAP32[$131>>2] = (($132+1)|0);
   }
   $133 = $$sroa$11$2;
   $134 = ((($133)) + -4|0);
   $135 = $134;
   $136 = ($126|0)==($124|0);
   if ($136) {
    $$in$i = $134;$$sroa$11$3 = $135;
    break;
   } else {
    $$06$i$i = $126;$$sroa$11$2 = $135;$128 = $134;
   }
  }
 }
 $137 = HEAP32[$9>>2]|0;
 $138 = ($137|0)==($8|0);
 if ($138) {
  $139 = $$in$i;
  $$sroa$26$3 = $122;$152 = $139;$153 = $8;
 } else {
  $$07$i$i = $8;$$sroa$26$2 = $122;$141 = $116;
  while(1) {
   $140 = ((($141)) + 4|0);
   $142 = HEAP32[$$07$i$i>>2]|0;
   HEAP32[$140>>2] = $142;
   $143 = ($142|0)==(0|0);
   if (!($143)) {
    $144 = ((($142)) + 8|0);
    $145 = HEAP32[$144>>2]|0;HEAP32[$144>>2] = (($145+1)|0);
   }
   $146 = ((($$07$i$i)) + 4|0);
   $147 = $$sroa$26$2;
   $148 = ((($147)) + 4|0);
   $149 = $148;
   $150 = ($146|0)==($137|0);
   if ($150) {
    break;
   } else {
    $$07$i$i = $146;$$sroa$26$2 = $149;$141 = $147;
   }
  }
  $$pre = HEAP32[$9>>2]|0;
  $$sroa$26$3 = $149;$152 = $$sroa$11$3;$153 = $$pre;
 }
 $151 = HEAP32[$0>>2]|0;
 HEAP32[$0>>2] = $152;
 HEAP32[$9>>2] = $$sroa$26$3;
 HEAP32[$11>>2] = $$sroa$46$1;
 $154 = ($153|0)==($151|0);
 L98: do {
  if (!($154)) {
   $156 = $153;
   while(1) {
    $155 = ((($156)) + -4|0);
    $157 = HEAP32[$155>>2]|0;
    $158 = ($157|0)==(0|0);
    if (!($158)) {
     $159 = ((($157)) + 8|0);
     $160 = HEAP32[$159>>2]|0;HEAP32[$159>>2] = (($160-1)|0);
     $161 = ($160|0)==(1);
     if ($161) {
      __THREW__ = 0;
      invoke_viii(3262,($157|0),1,1);
      $162 = __THREW__; __THREW__ = 0;
      $163 = $162&1;
      if ($163) {
       break;
      }
     }
    }
    HEAP32[$155>>2] = 0;
    $164 = ($155|0)==($151|0);
    if ($164) {
     break L98;
    } else {
     $156 = $155;
    }
   }
   $165 = ___cxa_find_matching_catch_2()|0;
   $166 = tempRet0;
   ___cxa_call_unexpected(($165|0));
   // unreachable;
  }
 } while(0);
 $167 = ($151|0)==(0|0);
 if ($167) {
  $$0 = $123;
  return ($$0|0);
 }
 __ZdlPv($151);
 $$0 = $123;
 return ($$0|0);
}
function __ZN3osg5GroupC2ERKS0_RKNS_6CopyOpE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$pre$i = 0, $$sroa$015$020 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg4NodeC2ERKS0_RKNS_6CopyOpE($0,$1,$2);
 HEAP32[$0>>2] = (61120);
 $3 = ((($0)) + 124|0);
 HEAP32[$3>>2] = 0;
 $4 = ((($0)) + 128|0);
 HEAP32[$4>>2] = 0;
 $5 = ((($0)) + 132|0);
 HEAP32[$5>>2] = 0;
 $6 = ((($1)) + 124|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($1)) + 128|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($7|0)==($9|0);
 if ($10) {
  return;
 }
 $$sroa$015$020 = $7;
 while(1) {
  $11 = HEAP32[$2>>2]|0;
  $12 = ((($11)) + 16|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = HEAP32[$$sroa$015$020>>2]|0;
  __THREW__ = 0;
  $15 = (invoke_iii($13|0,($2|0),($14|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if ($17) {
   break;
  }
  $18 = ($15|0)==(0|0);
  if (!($18)) {
   $19 = HEAP32[$0>>2]|0;
   $20 = ((($19)) + 204|0);
   $21 = HEAP32[$20>>2]|0;
   __THREW__ = 0;
   (invoke_iii($21|0,($0|0),($15|0))|0);
   $22 = __THREW__; __THREW__ = 0;
   $23 = $22&1;
   if ($23) {
    break;
   }
  }
  $24 = ((($$sroa$015$020)) + 4|0);
  $25 = HEAP32[$8>>2]|0;
  $26 = ($24|0)==($25|0);
  if ($26) {
   label = 3;
   break;
  } else {
   $$sroa$015$020 = $24;
  }
 }
 if ((label|0) == 3) {
  return;
 }
 $27 = ___cxa_find_matching_catch_2()|0;
 $28 = tempRet0;
 $29 = HEAP32[$3>>2]|0;
 $30 = ($29|0)==(0|0);
 if (!($30)) {
  $31 = HEAP32[$4>>2]|0;
  $32 = ($31|0)==($29|0);
  do {
   if ($32) {
    $46 = $29;
   } else {
    $34 = $31;
    while(1) {
     $33 = ((($34)) + -4|0);
     HEAP32[$4>>2] = $33;
     $35 = HEAP32[$33>>2]|0;
     $36 = ($35|0)==(0|0);
     if (!($36)) {
      $37 = ((($35)) + 8|0);
      $38 = HEAP32[$37>>2]|0;HEAP32[$37>>2] = (($38-1)|0);
      $39 = ($38|0)==(1);
      if ($39) {
       __THREW__ = 0;
       invoke_viii(3262,($35|0),1,1);
       $40 = __THREW__; __THREW__ = 0;
       $41 = $40&1;
       if ($41) {
        label = 14;
        break;
       }
      }
     }
     HEAP32[$33>>2] = 0;
     $42 = HEAP32[$4>>2]|0;
     $43 = ($42|0)==($29|0);
     if ($43) {
      label = 15;
      break;
     } else {
      $34 = $42;
     }
    }
    if ((label|0) == 14) {
     $44 = ___cxa_find_matching_catch_2()|0;
     $45 = tempRet0;
     ___cxa_call_unexpected(($44|0));
     // unreachable;
    }
    else if ((label|0) == 15) {
     $$pre$i = HEAP32[$3>>2]|0;
     $46 = $$pre$i;
     break;
    }
   }
  } while(0);
  __ZdlPv($46);
 }
 __THREW__ = 0;
 invoke_vi(2026,($0|0));
 $47 = __THREW__; __THREW__ = 0;
 $48 = $47&1;
 if ($48) {
  $49 = ___cxa_find_matching_catch_3(0|0)|0;
  $50 = tempRet0;
  ___clang_call_terminate($49);
  // unreachable;
 } else {
  ___resumeException($27|0);
  // unreachable;
 }
}
function __ZN3osg5GroupC2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg4NodeC2Ev($0);
 HEAP32[$0>>2] = (61120);
 $1 = ((($0)) + 124|0);
 HEAP32[$1>>2] = 0;
 $2 = ((($0)) + 128|0);
 HEAP32[$2>>2] = 0;
 $3 = ((($0)) + 132|0);
 HEAP32[$3>>2] = 0;
 return;
}
function __ZN3osg5ImageD2Ev($0) {
 $0 = $0|0;
 var $$pre$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $scevgep$i$i$i = 0, $scevgep5$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (61368);
 $1 = ((($0)) + 112|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = ((($0)) + 108|0);
  $5 = HEAP32[$4>>2]|0;
  switch ($5|0) {
  case 1:  {
   __ZdaPv($2);
   break;
  }
  case 2:  {
   _free($2);
   break;
  }
  default: {
  }
  }
  HEAP32[$1>>2] = 0;
 }
 $6 = ((($0)) + 128|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = ((($0)) + 132|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10|0)==($7|0);
  do {
   if ($11) {
    $25 = $7;
   } else {
    $13 = $10;
    while(1) {
     $12 = ((($13)) + -4|0);
     HEAP32[$9>>2] = $12;
     $14 = HEAP32[$12>>2]|0;
     $15 = ($14|0)==(0|0);
     if (!($15)) {
      $16 = ((($14)) + 8|0);
      $17 = HEAP32[$16>>2]|0;HEAP32[$16>>2] = (($17-1)|0);
      $18 = ($17|0)==(1);
      if ($18) {
       __THREW__ = 0;
       invoke_viii(3262,($14|0),1,1);
       $19 = __THREW__; __THREW__ = 0;
       $20 = $19&1;
       if ($20) {
        label = 12;
        break;
       }
      }
     }
     HEAP32[$12>>2] = 0;
     $21 = HEAP32[$9>>2]|0;
     $22 = ($21|0)==($7|0);
     if ($22) {
      label = 13;
      break;
     } else {
      $13 = $21;
     }
    }
    if ((label|0) == 12) {
     $23 = ___cxa_find_matching_catch_2()|0;
     $24 = tempRet0;
     ___cxa_call_unexpected(($23|0));
     // unreachable;
    }
    else if ((label|0) == 13) {
     $$pre$i = HEAP32[$6>>2]|0;
     $25 = $$pre$i;
     break;
    }
   }
  } while(0);
  __ZdlPv($25);
 }
 $26 = ((($0)) + 116|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ($27|0)==(0|0);
 if (!($28)) {
  $29 = ((($0)) + 120|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = ($30|0)==($27|0);
  if (!($31)) {
   $scevgep$i$i$i = ((($30)) + -4|0);
   $32 = $scevgep$i$i$i;
   $33 = $27;
   $34 = (($32) - ($33))|0;
   $35 = $34 >>> 2;
   $36 = $35 ^ -1;
   $scevgep5$i$i$i = (($30) + ($36<<2)|0);
   HEAP32[$29>>2] = $scevgep5$i$i$i;
  }
  __ZdlPv($27);
 }
 $37 = ((($0)) + 52|0);
 $38 = ((($37)) + 11|0);
 $39 = HEAP8[$38>>0]|0;
 $40 = ($39<<24>>24)<(0);
 if (!($40)) {
  __ZN3osg10BufferDataD2Ev($0);
  return;
 }
 $41 = HEAP32[$37>>2]|0;
 __ZdlPv($41);
 __ZN3osg10BufferDataD2Ev($0);
 return;
}
function __ZN3osg5ImageD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1933,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK3osg5Image9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $1 = (__Znwj(140)|0);
 __THREW__ = 0;
 invoke_vii(3435,($1|0),1);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $12 = ___cxa_find_matching_catch_2()|0;
  $13 = tempRet0;
  __ZdlPv($1);
  ___resumeException($12|0);
  // unreachable;
 } else {
  $4 = ((($1)) + 12|0);
  ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;
  $5 = ((($1)) + 24|0);
  $6 = ((($1)) + 28|0);
  ;HEAP32[$6>>2]=0|0;HEAP32[$6+4>>2]=0|0;HEAP32[$6+8>>2]=0|0;HEAP32[$6+12>>2]=0|0;HEAP32[$6+16>>2]=0|0;HEAP32[$6+20>>2]=0|0;
  HEAP32[$1>>2] = (61368);
  $7 = ((($1)) + 52|0);
  $8 = ((($1)) + 100|0);
  dest=$7; stop=dest+48|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
  HEAP32[$8>>2] = 4;
  $9 = ((($1)) + 104|0);
  HEAPF32[$9>>2] = 1.0;
  $10 = ((($1)) + 108|0);
  HEAP32[$10>>2] = 1;
  $11 = ((($1)) + 112|0);
  ;HEAP32[$11>>2]=0|0;HEAP32[$11+4>>2]=0|0;HEAP32[$11+8>>2]=0|0;HEAP32[$11+12>>2]=0|0;HEAP32[$11+16>>2]=0|0;HEAP32[$11+20>>2]=0|0;HEAP32[$11+24>>2]=0|0;
  HEAP32[$5>>2] = 1;
  return ($1|0);
 }
 return (0)|0;
}
function __ZNK3osg5Image5cloneERKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(140)|0);
 __THREW__ = 0;
 invoke_viii(3817,($2|0),($0|0),($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch_2()|0;
  $6 = tempRet0;
  __ZdlPv($2);
  ___resumeException($5|0);
  // unreachable;
 } else {
  return ($2|0);
 }
 return (0)|0;
}
function __ZNK3osg5Image12isSameKindAsEPKNS_6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,25320,0)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK3osg5Image11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175113|0);
}
function __ZNK3osg5Image9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (144718|0);
}
function __ZNK3osg5Image14getDataPointerEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 112|0);
 $2 = HEAP32[$1>>2]|0;
 return ($2|0);
}
function __ZNK3osg5Image16getTotalDataSizeEv($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__ZNK3osg5Image35getTotalSizeInBytesIncludingMipmapsEv($0)|0);
 return ($1|0);
}
function __ZN3osg5Image7asImageEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ($0|0);
}
function __ZNK3osg5Image7asImageEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ($0|0);
}
function __ZNK3osg5Image7compareERKS0_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$$$i$i$i = 0, $$$i$i$i = 0, $$0 = 0, $$lobit = 0, $$phi$trans$insert = 0, $$pre = 0, $$sroa$speculated$i$i$i = 0, $$sroa$speculated$i$i$i25 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $notlhs = 0, $notrhs = 0;
 var $or$cond$not = 0, $or$cond24 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 52|0);
 $3 = ((($2)) + 11|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)<(0);
 if ($5) {
  $6 = ((($0)) + 56|0);
  $7 = HEAP32[$6>>2]|0;
  $9 = $7;
 } else {
  $8 = $4&255;
  $9 = $8;
 }
 $10 = ($9|0)==(0);
 if ($10) {
  label = 6;
 } else {
  $11 = ((($1)) + 52|0);
  $12 = ((($11)) + 11|0);
  $13 = HEAP8[$12>>0]|0;
  $14 = ($13<<24>>24)<(0);
  $15 = ((($1)) + 56|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = $13&255;
  $18 = $14 ? $16 : $17;
  $19 = ($18|0)==(0);
  if ($19) {
   label = 6;
  }
 }
 if ((label|0) == 6) {
  $20 = ((($0)) + 112|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = ((($1)) + 112|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = ($21>>>0)<($23>>>0);
  if ($24) {
   $$0 = -1;
   return ($$0|0);
  }
  $25 = ($21>>>0)>($23>>>0);
  if ($25) {
   $$0 = 1;
   return ($$0|0);
  }
 }
 $26 = ((($0)) + 72|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ((($1)) + 72|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ($27|0)<($29|0);
 if ($30) {
  $$0 = -1;
  return ($$0|0);
 }
 $31 = ($29|0)<($27|0);
 if ($31) {
  $$0 = 1;
  return ($$0|0);
 }
 $32 = ((($0)) + 76|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ((($1)) + 76|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = ($33|0)<($35|0);
 if ($36) {
  $$0 = -1;
  return ($$0|0);
 }
 $37 = ($35|0)<($33|0);
 if ($37) {
  $$0 = 1;
  return ($$0|0);
 }
 $38 = ((($0)) + 88|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = ((($1)) + 88|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = ($39|0)<($41|0);
 if ($42) {
  $$0 = -1;
  return ($$0|0);
 }
 $43 = ($41|0)<($39|0);
 if ($43) {
  $$0 = 1;
  return ($$0|0);
 }
 $44 = ((($0)) + 92|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = ((($1)) + 92|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = ($45>>>0)<($47>>>0);
 if ($48) {
  $$0 = -1;
  return ($$0|0);
 }
 $49 = ($47>>>0)<($45>>>0);
 if ($49) {
  $$0 = 1;
  return ($$0|0);
 }
 $50 = ((($0)) + 96|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = ((($1)) + 96|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = ($51>>>0)<($53>>>0);
 if ($54) {
  $$0 = -1;
  return ($$0|0);
 }
 $55 = ($53>>>0)<($51>>>0);
 if ($55) {
  $$0 = 1;
  return ($$0|0);
 }
 $56 = ((($0)) + 100|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = ((($1)) + 100|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = ($57>>>0)<($59>>>0);
 if ($60) {
  $$0 = -1;
  return ($$0|0);
 }
 $61 = ($59>>>0)<($57>>>0);
 if ($61) {
  $$0 = 1;
  return ($$0|0);
 }
 $62 = ((($0)) + 120|0);
 $63 = HEAP32[$62>>2]|0;
 $64 = ((($1)) + 116|0);
 $65 = HEAP32[$64>>2]|0;
 $66 = ((($1)) + 120|0);
 $67 = HEAP32[$66>>2]|0;
 $68 = ($65|0)==($67|0);
 $$phi$trans$insert = ((($0)) + 116|0);
 $$pre = HEAP32[$$phi$trans$insert>>2]|0;
 L50: do {
  if (!($68)) {
   $69 = $$pre;$73 = $65;
   while(1) {
    $70 = ($69|0)==($63|0);
    if ($70) {
     $$0 = -1;
     label = 41;
     break;
    }
    $71 = HEAP32[$69>>2]|0;
    $72 = HEAP32[$73>>2]|0;
    $74 = ($71>>>0)<($72>>>0);
    if ($74) {
     $$0 = -1;
     label = 41;
     break;
    }
    $75 = ($72>>>0)<($71>>>0);
    if ($75) {
     break L50;
    }
    $76 = ((($69)) + 4|0);
    $77 = ((($73)) + 4|0);
    $78 = ($77|0)==($67|0);
    if ($78) {
     break L50;
    } else {
     $69 = $76;$73 = $77;
    }
   }
   if ((label|0) == 41) {
    return ($$0|0);
   }
  }
 } while(0);
 $79 = ($$pre|0)==($63|0);
 L60: do {
  if (!($79)) {
   $80 = $65;$84 = $$pre;
   while(1) {
    $81 = ($80|0)==($67|0);
    if ($81) {
     $$0 = 1;
     label = 41;
     break;
    }
    $82 = HEAP32[$80>>2]|0;
    $83 = HEAP32[$84>>2]|0;
    $85 = ($82>>>0)<($83>>>0);
    if ($85) {
     $$0 = 1;
     label = 41;
     break;
    }
    $86 = ($83>>>0)<($82>>>0);
    if ($86) {
     break L60;
    }
    $87 = ((($80)) + 4|0);
    $88 = ((($84)) + 4|0);
    $89 = ($88|0)==($63|0);
    if ($89) {
     break L60;
    } else {
     $80 = $87;$84 = $88;
    }
   }
   if ((label|0) == 41) {
    return ($$0|0);
   }
  }
 } while(0);
 $90 = ((($0)) + 32|0);
 $91 = HEAP32[$90>>2]|0;
 $92 = ((($1)) + 32|0);
 $93 = HEAP32[$92>>2]|0;
 $94 = ($91>>>0)<($93>>>0);
 if ($94) {
  $$0 = -1;
  return ($$0|0);
 }
 $95 = ($93>>>0)<($91>>>0);
 if ($95) {
  $$0 = 1;
  return ($$0|0);
 }
 $96 = ((($0)) + 112|0);
 $97 = HEAP32[$96>>2]|0;
 $98 = ((($1)) + 112|0);
 $99 = HEAP32[$98>>2]|0;
 $notlhs = ($97|0)!=(0|0);
 $notrhs = ($99|0)!=(0|0);
 $or$cond$not = $notlhs | $notrhs;
 $100 = ($97|0)==($99|0);
 $or$cond24 = $100 & $or$cond$not;
 if ($or$cond24) {
  $$0 = 0;
  return ($$0|0);
 }
 $101 = ((($1)) + 52|0);
 $102 = ((($101)) + 11|0);
 $103 = HEAP8[$102>>0]|0;
 $104 = ($103<<24>>24)<(0);
 $105 = ((($1)) + 56|0);
 $106 = HEAP32[$105>>2]|0;
 $107 = $103&255;
 $108 = $104 ? $106 : $107;
 $109 = ((($0)) + 56|0);
 $110 = HEAP32[$109>>2]|0;
 $111 = $4&255;
 $112 = $5 ? $110 : $111;
 $113 = ($108>>>0)<($112>>>0);
 $$sroa$speculated$i$i$i25 = $113 ? $108 : $112;
 $114 = ($$sroa$speculated$i$i$i25|0)==(0);
 do {
  if ($114) {
   label = 35;
  } else {
   $115 = HEAP32[$2>>2]|0;
   $116 = $5 ? $115 : $2;
   $117 = HEAP32[$101>>2]|0;
   $118 = $104 ? $117 : $101;
   $119 = (_memcmp($116,$118,$$sroa$speculated$i$i$i25)|0);
   $120 = ($119|0)==(0);
   if ($120) {
    label = 35;
    break;
   }
   $122 = ($119|0)<(0);
   if ($122) {
    $$0 = -1;
   } else {
    break;
   }
   return ($$0|0);
  }
 } while(0);
 do {
  if ((label|0) == 35) {
   $121 = ($112>>>0)<($108>>>0);
   if ($121) {
    $$0 = -1;
   } else {
    break;
   }
   return ($$0|0);
  }
 } while(0);
 $123 = ($112>>>0)<($108>>>0);
 $$sroa$speculated$i$i$i = $123 ? $112 : $108;
 $124 = ($$sroa$speculated$i$i$i|0)==(0);
 if ($124) {
  label = 39;
 } else {
  $125 = HEAP32[$101>>2]|0;
  $126 = $104 ? $125 : $101;
  $127 = HEAP32[$2>>2]|0;
  $128 = $5 ? $127 : $2;
  $129 = (_memcmp($126,$128,$$sroa$speculated$i$i$i)|0);
  $130 = ($129|0)==(0);
  if ($130) {
   label = 39;
  } else {
   $131 = $129;
  }
 }
 if ((label|0) == 39) {
  $$$i$i$i = $123&1;
  $$$$i$i$i = $113 ? -1 : $$$i$i$i;
  $131 = $$$$i$i$i;
 }
 $$lobit = $131 >>> 31;
 $$0 = $$lobit;
 return ($$0|0);
}
function __ZN3osg5Image13allocateImageEiiijji($0,$1,$2,$3,$4,$5,$6) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 var $$024 = 0, $$off0 = 0, $$pr = 0, $$pre$i = 0, $$sroa$02$06$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $scevgep$i$i$i = 0, $scevgep5$i$i$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $7 = ((($0)) + 116|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($0)) + 120|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==($8|0);
 if (!($11)) {
  $scevgep$i$i$i = ((($10)) + -4|0);
  $12 = $scevgep$i$i$i;
  $13 = $8;
  $14 = (($12) - ($13))|0;
  $15 = $14 >>> 2;
  $16 = $15 ^ -1;
  $scevgep5$i$i$i = (($10) + ($16<<2)|0);
  HEAP32[$9>>2] = $scevgep5$i$i$i;
 }
 $17 = ((($0)) + 112|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ($18|0)==(0|0);
 if ($19) {
  $$024 = 0;
 } else {
  $20 = ((($0)) + 72|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = ((($0)) + 92|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = ((($0)) + 96|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = ((($0)) + 100|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = (__ZN3osg5Image22computePixelSizeInBitsEjj($23,$25)|0);
  $29 = Math_imul($28, $21)|0;
  $30 = ($27|0)!=(0);
  $31 = $27 << 3;
  $32 = $30 ? $31 : 8;
  $33 = (($29|0) / ($32|0))&-1;
  $34 = (($29|0) % ($32|0))&-1;
  $35 = ($34|0)!=(0);
  $36 = $35&1;
  $37 = (($36) + ($33))|0;
  $38 = ((($0)) + 76|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = ((($0)) + 80|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = Math_imul($39, $27)|0;
  $43 = Math_imul($42, $41)|0;
  $44 = Math_imul($43, $37)|0;
  $$024 = $44;
 }
 $45 = (__ZN3osg5Image22computePixelSizeInBitsEjj($4,$5)|0);
 $46 = Math_imul($45, $1)|0;
 $47 = ($6|0)!=(0);
 $48 = $6 << 3;
 $49 = $47 ? $48 : 8;
 $50 = (($46|0) / ($49|0))&-1;
 $51 = (($46|0) % ($49|0))&-1;
 $52 = ($51|0)!=(0);
 $53 = $52&1;
 $54 = (($53) + ($50))|0;
 $55 = Math_imul($3, $2)|0;
 $56 = Math_imul($55, $6)|0;
 $57 = Math_imul($56, $54)|0;
 $58 = ($57|0)==($$024|0);
 do {
  if ($58) {
   label = 22;
  } else {
   $59 = ($57|0)==(0);
   if ($59) {
    $76 = HEAP32[$17>>2]|0;
    $77 = ($76|0)==(0|0);
    if (!($77)) {
     $78 = ((($0)) + 108|0);
     $79 = HEAP32[$78>>2]|0;
     switch ($79|0) {
     case 1:  {
      __ZdaPv($76);
      break;
     }
     case 2:  {
      _free($76);
      break;
     }
     default: {
     }
     }
     HEAP32[$17>>2] = 0;
    }
    $80 = ((($0)) + 72|0);
    $81 = HEAP32[$80>>2]|0;
    $100 = $81;$108 = $80;
    label = 28;
    break;
   }
   $60 = (__Znaj($57)|0);
   $61 = HEAP32[$17>>2]|0;
   $62 = ($61|0)==(0|0);
   $$pre$i = ((($0)) + 108|0);
   if (!($62)) {
    $63 = HEAP32[$$pre$i>>2]|0;
    switch ($63|0) {
    case 1:  {
     __ZdaPv($61);
     break;
    }
    case 2:  {
     _free($61);
     break;
    }
    default: {
    }
    }
    HEAP32[$17>>2] = 0;
   }
   HEAP32[$17>>2] = $60;
   HEAP32[$$pre$i>>2] = 1;
   $64 = ((($0)) + 32|0);
   $65 = HEAP32[$64>>2]|0;
   $66 = (($65) + 1)|0;
   HEAP32[$64>>2] = $66;
   $67 = ((($0)) + 44|0);
   $68 = HEAP32[$67>>2]|0;
   $69 = ($68|0)==(0|0);
   if (!($69)) {
    $70 = HEAP32[$68>>2]|0;
    $71 = ((($70)) + 20|0);
    $72 = HEAP32[$71>>2]|0;
    FUNCTION_TABLE_vii[$72 & 8191]($68,$0);
   }
   $73 = ((($0)) + 40|0);
   $74 = HEAP32[$73>>2]|0;
   $75 = ($74|0)==(0|0);
   if ($75) {
    label = 22;
   } else {
    __ZN3osg12BufferObject5dirtyEv($74);
    label = 22;
   }
  }
 } while(0);
 do {
  if ((label|0) == 22) {
   $$pr = HEAP32[$17>>2]|0;
   $82 = ($$pr|0)==(0|0);
   $83 = ((($0)) + 72|0);
   $84 = HEAP32[$83>>2]|0;
   if ($82) {
    $100 = $84;$108 = $83;
    label = 28;
   } else {
    $85 = ($84|0)==($1|0);
    $86 = ((($0)) + 76|0);
    if ($85) {
     $87 = HEAP32[$86>>2]|0;
     $88 = ($87|0)==($2|0);
     if ($88) {
      $89 = ((($0)) + 80|0);
      $90 = HEAP32[$89>>2]|0;
      $91 = ($90|0)!=($3|0);
      $138 = $91;
     } else {
      $138 = 1;
     }
    } else {
     $138 = 1;
    }
    HEAP32[$83>>2] = $1;
    HEAP32[$86>>2] = $2;
    $92 = ((($0)) + 80|0);
    HEAP32[$92>>2] = $3;
    $93 = ((($0)) + 92|0);
    HEAP32[$93>>2] = $4;
    $94 = ((($0)) + 96|0);
    HEAP32[$94>>2] = $5;
    $95 = ((($0)) + 100|0);
    HEAP32[$95>>2] = $6;
    $96 = ((($0)) + 84|0);
    HEAP32[$96>>2] = 0;
    $97 = ((($0)) + 88|0);
    $98 = HEAP32[$97>>2]|0;
    $99 = ($98|0)==(0);
    if ($99) {
     HEAP32[$97>>2] = $4;
     if ($138) {
      label = 33;
      break;
     } else {
      break;
     }
    } else {
     if ($138) {
      label = 33;
      break;
     } else {
      break;
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 28) {
  $101 = ($100|0)==(0);
  $102 = ((($0)) + 76|0);
  if ($101) {
   $103 = HEAP32[$102>>2]|0;
   $104 = ($103|0)==(0);
   if ($104) {
    $105 = ((($0)) + 80|0);
    $106 = HEAP32[$105>>2]|0;
    $107 = ($106|0)!=(0);
    $$off0 = $107;
   } else {
    $$off0 = 1;
   }
  } else {
   $$off0 = 1;
  }
  HEAP32[$108>>2] = 0;
  HEAP32[$102>>2] = 0;
  $109 = ((($0)) + 80|0);
  HEAP32[$109>>2] = 0;
  $110 = ((($0)) + 92|0);
  HEAP32[$110>>2] = 0;
  $111 = ((($0)) + 96|0);
  HEAP32[$111>>2] = 0;
  $112 = ((($0)) + 100|0);
  HEAP32[$112>>2] = 0;
  $113 = ((($0)) + 84|0);
  HEAP32[$113>>2] = 0;
  if ($$off0) {
   label = 33;
  }
 }
 if ((label|0) == 33) {
  $114 = ((($0)) + 128|0);
  $115 = HEAP32[$114>>2]|0;
  $116 = ((($0)) + 132|0);
  $117 = HEAP32[$116>>2]|0;
  $118 = ($115|0)==($117|0);
  if (!($118)) {
   $$sroa$02$06$i = $115;
   while(1) {
    $119 = HEAP32[$$sroa$02$06$i>>2]|0;
    $120 = HEAP32[$119>>2]|0;
    $121 = ((($120)) + 12|0);
    $122 = HEAP32[$121>>2]|0;
    FUNCTION_TABLE_vii[$122 & 8191]($119,$0);
    $123 = ((($$sroa$02$06$i)) + 4|0);
    $124 = HEAP32[$116>>2]|0;
    $125 = ($123|0)==($124|0);
    if ($125) {
     break;
    } else {
     $$sroa$02$06$i = $123;
    }
   }
  }
 }
 $126 = ((($0)) + 32|0);
 $127 = HEAP32[$126>>2]|0;
 $128 = (($127) + 1)|0;
 HEAP32[$126>>2] = $128;
 $129 = ((($0)) + 44|0);
 $130 = HEAP32[$129>>2]|0;
 $131 = ($130|0)==(0|0);
 if (!($131)) {
  $132 = HEAP32[$130>>2]|0;
  $133 = ((($132)) + 20|0);
  $134 = HEAP32[$133>>2]|0;
  FUNCTION_TABLE_vii[$134 & 8191]($130,$0);
 }
 $135 = ((($0)) + 40|0);
 $136 = HEAP32[$135>>2]|0;
 $137 = ($136|0)==(0|0);
 if ($137) {
  return;
 }
 __ZN3osg12BufferObject5dirtyEv($136);
 return;
}
function __ZN3osg5Image8setImageEiiiijjPhNS0_14AllocationModeEii($0,$1,$2,$3,$4,$5,$6,$7,$8,$9,$10) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 $8 = $8|0;
 $9 = $9|0;
 $10 = $10|0;
 var $$pre$i = 0, $$sroa$02$06$i = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $scevgep$i$i$i = 0, $scevgep5$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $11 = ((($0)) + 116|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ((($0)) + 120|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==($12|0);
 if (!($15)) {
  $scevgep$i$i$i = ((($14)) + -4|0);
  $16 = $scevgep$i$i$i;
  $17 = $12;
  $18 = (($16) - ($17))|0;
  $19 = $18 >>> 2;
  $20 = $19 ^ -1;
  $scevgep5$i$i$i = (($14) + ($20<<2)|0);
  HEAP32[$13>>2] = $scevgep5$i$i$i;
 }
 $21 = ((($0)) + 72|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==($1|0);
 $24 = ((($0)) + 76|0);
 if ($23) {
  $25 = HEAP32[$24>>2]|0;
  $26 = ($25|0)==($2|0);
  if ($26) {
   $27 = ((($0)) + 80|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = ($28|0)!=($3|0);
   $73 = $29;
  } else {
   $73 = 1;
  }
 } else {
  $73 = 1;
 }
 HEAP32[$21>>2] = $1;
 HEAP32[$24>>2] = $2;
 $30 = ((($0)) + 80|0);
 HEAP32[$30>>2] = $3;
 $31 = ((($0)) + 88|0);
 HEAP32[$31>>2] = $4;
 $32 = ((($0)) + 92|0);
 HEAP32[$32>>2] = $5;
 $33 = ((($0)) + 96|0);
 HEAP32[$33>>2] = $6;
 $34 = ((($0)) + 112|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = ($35|0)==(0|0);
 $$pre$i = ((($0)) + 108|0);
 if (!($36)) {
  $37 = HEAP32[$$pre$i>>2]|0;
  switch ($37|0) {
  case 1:  {
   __ZdaPv($35);
   break;
  }
  case 2:  {
   _free($35);
   break;
  }
  default: {
  }
  }
  HEAP32[$34>>2] = 0;
 }
 HEAP32[$34>>2] = $7;
 HEAP32[$$pre$i>>2] = $8;
 $38 = ((($0)) + 32|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($39) + 1)|0;
 HEAP32[$38>>2] = $40;
 $41 = ((($0)) + 44|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ($42|0)==(0|0);
 if (!($43)) {
  $44 = HEAP32[$42>>2]|0;
  $45 = ((($44)) + 20|0);
  $46 = HEAP32[$45>>2]|0;
  FUNCTION_TABLE_vii[$46 & 8191]($42,$0);
 }
 $47 = ((($0)) + 40|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = ($48|0)==(0|0);
 if (!($49)) {
  __ZN3osg12BufferObject5dirtyEv($48);
 }
 $50 = ((($0)) + 100|0);
 HEAP32[$50>>2] = $9;
 $51 = ((($0)) + 84|0);
 HEAP32[$51>>2] = $10;
 $52 = HEAP32[$38>>2]|0;
 $53 = (($52) + 1)|0;
 HEAP32[$38>>2] = $53;
 $54 = HEAP32[$41>>2]|0;
 $55 = ($54|0)==(0|0);
 if (!($55)) {
  $56 = HEAP32[$54>>2]|0;
  $57 = ((($56)) + 20|0);
  $58 = HEAP32[$57>>2]|0;
  FUNCTION_TABLE_vii[$58 & 8191]($54,$0);
 }
 $59 = HEAP32[$47>>2]|0;
 $60 = ($59|0)==(0|0);
 if (!($60)) {
  __ZN3osg12BufferObject5dirtyEv($59);
 }
 if (!($73)) {
  return;
 }
 $61 = ((($0)) + 128|0);
 $62 = HEAP32[$61>>2]|0;
 $63 = ((($0)) + 132|0);
 $64 = HEAP32[$63>>2]|0;
 $65 = ($62|0)==($64|0);
 if ($65) {
  return;
 } else {
  $$sroa$02$06$i = $62;
 }
 while(1) {
  $66 = HEAP32[$$sroa$02$06$i>>2]|0;
  $67 = HEAP32[$66>>2]|0;
  $68 = ((($67)) + 12|0);
  $69 = HEAP32[$68>>2]|0;
  FUNCTION_TABLE_vii[$69 & 8191]($66,$0);
  $70 = ((($$sroa$02$06$i)) + 4|0);
  $71 = HEAP32[$63>>2]|0;
  $72 = ($70|0)==($71|0);
  if ($72) {
   break;
  } else {
   $$sroa$02$06$i = $70;
  }
 }
 return;
}
function __ZN3osg5Image10readPixelsEiiiijji($0,$1,$2,$3,$4,$5,$6,$7) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $8 = HEAP32[$0>>2]|0;
 $9 = ((($8)) + 176|0);
 $10 = HEAP32[$9>>2]|0;
 FUNCTION_TABLE_viiiiiii[$10 & 8191]($0,$3,$4,1,$5,$6,$7);
 $11 = ((($0)) + 100|0);
 $12 = HEAP32[$11>>2]|0;
 _glPixelStorei(3333,($12|0));
 $13 = ((($0)) + 84|0);
 $14 = HEAP32[$13>>2]|0;
 _glPixelStorei(3330,($14|0));
 $15 = ((($0)) + 112|0);
 $16 = HEAP32[$15>>2]|0;
 _glReadPixels(($1|0),($2|0),($3|0),($4|0),($5|0),($6|0),($16|0));
 return;
}
function __ZN3osg5Image27readImageFromCurrentTextureEjbjj($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $5 = sp;
 $6 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
 if (!($6)) {
  STACKTOP = sp;return;
 }
 $7 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
 $8 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($7,144657,60)|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($9)) + -12|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($8) + ($11)|0);
 __ZNKSt3__28ios_base6getlocEv($5,$12);
 __THREW__ = 0;
 $13 = (invoke_iii(3255,($5|0),(215188|0))|0);
 $14 = __THREW__; __THREW__ = 0;
 $15 = $14&1;
 if (!($15)) {
  $16 = HEAP32[$13>>2]|0;
  $17 = ((($16)) + 28|0);
  $18 = HEAP32[$17>>2]|0;
  __THREW__ = 0;
  $19 = (invoke_iii($18|0,($13|0),10)|0);
  $20 = __THREW__; __THREW__ = 0;
  $21 = $20&1;
  if (!($21)) {
   __ZNSt3__26localeD2Ev($5);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($8,$19)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($8)|0);
   STACKTOP = sp;return;
  }
 }
 $22 = ___cxa_find_matching_catch_2()|0;
 $23 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($5|0));
 $24 = __THREW__; __THREW__ = 0;
 $25 = $24&1;
 if ($25) {
  $26 = ___cxa_find_matching_catch_3(0|0)|0;
  $27 = tempRet0;
  ___clang_call_terminate($26);
  // unreachable;
 } else {
  ___resumeException($22|0);
  // unreachable;
 }
}
function __ZN3osg5Image10scaleImageEiiij($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$pre$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0;
 var $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0;
 var $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(80|0);
 $5 = sp + 72|0;
 $6 = sp + 68|0;
 $7 = sp + 64|0;
 $8 = sp;
 $9 = ((($0)) + 72|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==($1|0);
 if ($11) {
  $12 = ((($0)) + 76|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($13|0)==($2|0);
  if ($14) {
   $15 = ((($0)) + 80|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ($16|0)==($3|0);
   if ($17) {
    STACKTOP = sp;return;
   }
  }
 }
 $18 = ((($0)) + 112|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)==(0|0);
 if ($20) {
  $21 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
  if (!($21)) {
   STACKTOP = sp;return;
  }
  $22 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
  $23 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($22,144510,67)|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = ((($24)) + -12|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($23) + ($26)|0);
  __ZNKSt3__28ios_base6getlocEv($7,$27);
  __THREW__ = 0;
  $28 = (invoke_iii(3255,($7|0),(215188|0))|0);
  $29 = __THREW__; __THREW__ = 0;
  $30 = $29&1;
  if (!($30)) {
   $31 = HEAP32[$28>>2]|0;
   $32 = ((($31)) + 28|0);
   $33 = HEAP32[$32>>2]|0;
   __THREW__ = 0;
   $34 = (invoke_iii($33|0,($28|0),10)|0);
   $35 = __THREW__; __THREW__ = 0;
   $36 = $35&1;
   if (!($36)) {
    __ZNSt3__26localeD2Ev($7);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($23,$34)|0);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($23)|0);
    STACKTOP = sp;return;
   }
  }
  $37 = ___cxa_find_matching_catch_2()|0;
  $38 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3263,($7|0));
  $39 = __THREW__; __THREW__ = 0;
  $40 = $39&1;
  if ($40) {
   $41 = ___cxa_find_matching_catch_3(0|0)|0;
   $42 = tempRet0;
   ___clang_call_terminate($41);
   // unreachable;
  } else {
   ___resumeException($37|0);
   // unreachable;
  }
 }
 $43 = ((($0)) + 80|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = ($44|0)!=(1);
 $46 = ($3|0)!=(1);
 $or$cond = $46 | $45;
 if ($or$cond) {
  $47 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
  if (!($47)) {
   STACKTOP = sp;return;
  }
  $48 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
  $49 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($48,144578,78)|0);
  $50 = HEAP32[$49>>2]|0;
  $51 = ((($50)) + -12|0);
  $52 = HEAP32[$51>>2]|0;
  $53 = (($49) + ($52)|0);
  __ZNKSt3__28ios_base6getlocEv($6,$53);
  __THREW__ = 0;
  $54 = (invoke_iii(3255,($6|0),(215188|0))|0);
  $55 = __THREW__; __THREW__ = 0;
  $56 = $55&1;
  if (!($56)) {
   $57 = HEAP32[$54>>2]|0;
   $58 = ((($57)) + 28|0);
   $59 = HEAP32[$58>>2]|0;
   __THREW__ = 0;
   $60 = (invoke_iii($59|0,($54|0),10)|0);
   $61 = __THREW__; __THREW__ = 0;
   $62 = $61&1;
   if (!($62)) {
    __ZNSt3__26localeD2Ev($6);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($49,$60)|0);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($49)|0);
    STACKTOP = sp;return;
   }
  }
  $63 = ___cxa_find_matching_catch_2()|0;
  $64 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3263,($6|0));
  $65 = __THREW__; __THREW__ = 0;
  $66 = $65&1;
  if ($66) {
   $67 = ___cxa_find_matching_catch_3(0|0)|0;
   $68 = tempRet0;
   ___clang_call_terminate($67);
   // unreachable;
  } else {
   ___resumeException($63|0);
   // unreachable;
  }
 }
 $69 = ((($0)) + 92|0);
 $70 = HEAP32[$69>>2]|0;
 $71 = ((($0)) + 100|0);
 $72 = HEAP32[$71>>2]|0;
 $73 = (__ZN3osg5Image22computePixelSizeInBitsEjj($70,$4)|0);
 $74 = Math_imul($73, $1)|0;
 $75 = ($72|0)!=(0);
 $76 = $72 << 3;
 $77 = $75 ? $76 : 8;
 $78 = (($74|0) / ($77|0))&-1;
 $79 = (($74|0) % ($77|0))&-1;
 $80 = ($79|0)!=(0);
 $81 = $80&1;
 $82 = (($81) + ($78))|0;
 $83 = Math_imul($72, $2)|0;
 $84 = Math_imul($83, $82)|0;
 $85 = (__Znaj($84)|0);
 __ZN3osg17PixelStorageModesC2Ev($8);
 $86 = HEAP32[$71>>2]|0;
 HEAP32[$8>>2] = $86;
 $87 = ((($0)) + 84|0);
 $88 = HEAP32[$87>>2]|0;
 $89 = ((($8)) + 4|0);
 HEAP32[$89>>2] = $88;
 $90 = ((($8)) + 32|0);
 HEAP32[$90>>2] = $86;
 $91 = HEAP32[$69>>2]|0;
 $92 = HEAP32[$9>>2]|0;
 $93 = ((($0)) + 76|0);
 $94 = HEAP32[$93>>2]|0;
 $95 = ((($0)) + 96|0);
 $96 = HEAP32[$95>>2]|0;
 $97 = HEAP32[$18>>2]|0;
 $98 = (__ZN3osg13gluScaleImageEPNS_17PixelStorageModesEjiijPKviijPv($8,$91,$92,$94,$96,$97,$1,$2,$4,$85)|0);
 $99 = ($98|0)==(0);
 do {
  if ($99) {
   HEAP32[$9>>2] = $1;
   HEAP32[$93>>2] = $2;
   HEAP32[$87>>2] = 0;
   HEAP32[$95>>2] = $4;
   $100 = HEAP32[$18>>2]|0;
   $101 = ($100|0)==(0|0);
   $$pre$i = ((($0)) + 108|0);
   if (!($101)) {
    $102 = HEAP32[$$pre$i>>2]|0;
    switch ($102|0) {
    case 1:  {
     __ZdaPv($100);
     break;
    }
    case 2:  {
     _free($100);
     break;
    }
    default: {
    }
    }
    HEAP32[$18>>2] = 0;
   }
   HEAP32[$18>>2] = $85;
   HEAP32[$$pre$i>>2] = 1;
   $103 = ((($0)) + 32|0);
   $104 = HEAP32[$103>>2]|0;
   $105 = (($104) + 1)|0;
   HEAP32[$103>>2] = $105;
   $106 = ((($0)) + 44|0);
   $107 = HEAP32[$106>>2]|0;
   $108 = ($107|0)==(0|0);
   if (!($108)) {
    $109 = HEAP32[$107>>2]|0;
    $110 = ((($109)) + 20|0);
    $111 = HEAP32[$110>>2]|0;
    FUNCTION_TABLE_vii[$111 & 8191]($107,$0);
   }
   $112 = ((($0)) + 40|0);
   $113 = HEAP32[$112>>2]|0;
   $114 = ($113|0)==(0|0);
   if (!($114)) {
    __ZN3osg12BufferObject5dirtyEv($113);
   }
  } else {
   __ZdaPv($85);
   $115 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
   if ($115) {
    $116 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
    $117 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($116,144411,58)|0);
    $118 = (__ZN3osg14gluErrorStringEj($98)|0);
    $119 = (_strlen($118)|0);
    $120 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($117,$118,$119)|0);
    $121 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($120,144470,39)|0);
    $122 = HEAP32[$121>>2]|0;
    $123 = ((($122)) + -12|0);
    $124 = HEAP32[$123>>2]|0;
    $125 = (($121) + ($124)|0);
    __ZNKSt3__28ios_base6getlocEv($5,$125);
    __THREW__ = 0;
    $126 = (invoke_iii(3255,($5|0),(215188|0))|0);
    $127 = __THREW__; __THREW__ = 0;
    $128 = $127&1;
    if (!($128)) {
     $129 = HEAP32[$126>>2]|0;
     $130 = ((($129)) + 28|0);
     $131 = HEAP32[$130>>2]|0;
     __THREW__ = 0;
     $132 = (invoke_iii($131|0,($126|0),10)|0);
     $133 = __THREW__; __THREW__ = 0;
     $134 = $133&1;
     if (!($134)) {
      __ZNSt3__26localeD2Ev($5);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($121,$132)|0);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($121)|0);
      break;
     }
    }
    $135 = ___cxa_find_matching_catch_2()|0;
    $136 = tempRet0;
    __THREW__ = 0;
    invoke_vi(3263,($5|0));
    $137 = __THREW__; __THREW__ = 0;
    $138 = $137&1;
    if ($138) {
     $139 = ___cxa_find_matching_catch_3(0|0)|0;
     $140 = tempRet0;
     ___clang_call_terminate($139);
     // unreachable;
    } else {
     ___resumeException($135|0);
     // unreachable;
    }
   }
  }
 } while(0);
 $141 = ((($0)) + 32|0);
 $142 = HEAP32[$141>>2]|0;
 $143 = (($142) + 1)|0;
 HEAP32[$141>>2] = $143;
 $144 = ((($0)) + 44|0);
 $145 = HEAP32[$144>>2]|0;
 $146 = ($145|0)==(0|0);
 if (!($146)) {
  $147 = HEAP32[$145>>2]|0;
  $148 = ((($147)) + 20|0);
  $149 = HEAP32[$148>>2]|0;
  FUNCTION_TABLE_vii[$149 & 8191]($145,$0);
 }
 $150 = ((($0)) + 40|0);
 $151 = HEAP32[$150>>2]|0;
 $152 = ($151|0)==(0|0);
 if (!($152)) {
  __ZN3osg12BufferObject5dirtyEv($151);
 }
 STACKTOP = sp;return;
}
function __ZN3osg5Image12copySubImageEiiiPKS0_($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0$i = 0, $$pre = 0, $$pre$phi42Z2D = 0, $$pre$phi44Z2D = 0, $$pre$phiZ2D = 0, $$pre41 = 0, $$pre43 = 0, $$sink = 0, $$sink$i$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0;
 var $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0;
 var $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0;
 var $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0;
 var $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(96|0);
 $5 = sp + 80|0;
 $6 = sp + 76|0;
 $7 = sp + 72|0;
 $8 = sp + 68|0;
 $9 = sp + 64|0;
 $10 = sp;
 $11 = ($4|0)==(0|0);
 if ($11) {
  STACKTOP = sp;return;
 }
 $12 = $2 | $1;
 $13 = $12 | $3;
 $14 = ($13|0)<(0);
 if ($14) {
  $15 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
  if (!($15)) {
   STACKTOP = sp;return;
  }
  $16 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
  $17 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($16,144099,93)|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = ((($18)) + -12|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = (($17) + ($20)|0);
  __ZNKSt3__28ios_base6getlocEv($9,$21);
  __THREW__ = 0;
  $22 = (invoke_iii(3255,($9|0),(215188|0))|0);
  $23 = __THREW__; __THREW__ = 0;
  $24 = $23&1;
  if (!($24)) {
   $25 = HEAP32[$22>>2]|0;
   $26 = ((($25)) + 28|0);
   $27 = HEAP32[$26>>2]|0;
   __THREW__ = 0;
   $28 = (invoke_iii($27|0,($22|0),10)|0);
   $29 = __THREW__; __THREW__ = 0;
   $30 = $29&1;
   if (!($30)) {
    __ZNSt3__26localeD2Ev($9);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($17,$28)|0);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($17)|0);
    STACKTOP = sp;return;
   }
  }
  $31 = ___cxa_find_matching_catch_2()|0;
  $32 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3263,($9|0));
  $33 = __THREW__; __THREW__ = 0;
  $34 = $33&1;
  if ($34) {
   $35 = ___cxa_find_matching_catch_3(0|0)|0;
   $36 = tempRet0;
   ___clang_call_terminate($35);
   // unreachable;
  } else {
   ___resumeException($31|0);
   // unreachable;
  }
 }
 $37 = ((($0)) + 112|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = ($38|0)==(0|0);
 if ($39) {
  $40 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
  do {
   if ($40) {
    $41 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
    $42 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($41,144193,16)|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = ((($43)) + -12|0);
    $45 = HEAP32[$44>>2]|0;
    $46 = (($42) + ($45)|0);
    __ZNKSt3__28ios_base6getlocEv($8,$46);
    __THREW__ = 0;
    $47 = (invoke_iii(3255,($8|0),(215188|0))|0);
    $48 = __THREW__; __THREW__ = 0;
    $49 = $48&1;
    if (!($49)) {
     $50 = HEAP32[$47>>2]|0;
     $51 = ((($50)) + 28|0);
     $52 = HEAP32[$51>>2]|0;
     __THREW__ = 0;
     $53 = (invoke_iii($52|0,($47|0),10)|0);
     $54 = __THREW__; __THREW__ = 0;
     $55 = $54&1;
     if (!($55)) {
      __ZNSt3__26localeD2Ev($8);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($42,$53)|0);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($42)|0);
      break;
     }
    }
    $56 = ___cxa_find_matching_catch_2()|0;
    $57 = tempRet0;
    __THREW__ = 0;
    invoke_vi(3263,($8|0));
    $58 = __THREW__; __THREW__ = 0;
    $59 = $58&1;
    if ($59) {
     $60 = ___cxa_find_matching_catch_3(0|0)|0;
     $61 = tempRet0;
     ___clang_call_terminate($60);
     // unreachable;
    } else {
     ___resumeException($56|0);
     // unreachable;
    }
   }
  } while(0);
  $62 = HEAP32[$0>>2]|0;
  $63 = ((($62)) + 176|0);
  $64 = HEAP32[$63>>2]|0;
  $65 = ((($4)) + 72|0);
  $66 = HEAP32[$65>>2]|0;
  $67 = (($66) + ($1))|0;
  $68 = ((($4)) + 76|0);
  $69 = HEAP32[$68>>2]|0;
  $70 = (($69) + ($2))|0;
  $71 = ((($4)) + 80|0);
  $72 = HEAP32[$71>>2]|0;
  $73 = (($72) + ($3))|0;
  $74 = ((($4)) + 92|0);
  $75 = HEAP32[$74>>2]|0;
  $76 = ((($4)) + 96|0);
  $77 = HEAP32[$76>>2]|0;
  $78 = ((($4)) + 100|0);
  $79 = HEAP32[$78>>2]|0;
  FUNCTION_TABLE_viiiiiii[$64 & 8191]($0,$67,$70,$73,$75,$77,$79);
 }
 $80 = ((($0)) + 72|0);
 $81 = HEAP32[$80>>2]|0;
 $82 = ($81|0)>($1|0);
 if ($82) {
  $83 = ((($0)) + 76|0);
  $84 = HEAP32[$83>>2]|0;
  $85 = ($84|0)>($2|0);
  if ($85) {
   $86 = ((($0)) + 80|0);
   $87 = HEAP32[$86>>2]|0;
   $88 = ($87|0)>($3|0);
   if ($88) {
    $111 = ((($0)) + 92|0);
    $112 = HEAP32[$111>>2]|0;
    $113 = ((($4)) + 92|0);
    $114 = HEAP32[$113>>2]|0;
    $115 = ($112|0)==($114|0);
    if (!($115)) {
     $116 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
     if (!($116)) {
      STACKTOP = sp;return;
     }
     $117 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
     $118 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($117,144307,103)|0);
     $119 = HEAP32[$118>>2]|0;
     $120 = ((($119)) + -12|0);
     $121 = HEAP32[$120>>2]|0;
     $122 = (($118) + ($121)|0);
     __ZNKSt3__28ios_base6getlocEv($6,$122);
     __THREW__ = 0;
     $123 = (invoke_iii(3255,($6|0),(215188|0))|0);
     $124 = __THREW__; __THREW__ = 0;
     $125 = $124&1;
     if (!($125)) {
      $126 = HEAP32[$123>>2]|0;
      $127 = ((($126)) + 28|0);
      $128 = HEAP32[$127>>2]|0;
      __THREW__ = 0;
      $129 = (invoke_iii($128|0,($123|0),10)|0);
      $130 = __THREW__; __THREW__ = 0;
      $131 = $130&1;
      if (!($131)) {
       __ZNSt3__26localeD2Ev($6);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($118,$129)|0);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($118)|0);
       STACKTOP = sp;return;
      }
     }
     $132 = ___cxa_find_matching_catch_2()|0;
     $133 = tempRet0;
     __THREW__ = 0;
     invoke_vi(3263,($6|0));
     $134 = __THREW__; __THREW__ = 0;
     $135 = $134&1;
     if ($135) {
      $136 = ___cxa_find_matching_catch_3(0|0)|0;
      $137 = tempRet0;
      ___clang_call_terminate($136);
      // unreachable;
     } else {
      ___resumeException($132|0);
      // unreachable;
     }
    }
    $138 = HEAP32[$37>>2]|0;
    $139 = ($138|0)==(0|0);
    if ($139) {
     $$pre = ((($0)) + 100|0);
     $$pre41 = ((($0)) + 84|0);
     $$pre43 = ((($0)) + 96|0);
     $$0$i = 0;$$pre$phi42Z2D = $$pre41;$$pre$phi44Z2D = $$pre43;$$pre$phiZ2D = $$pre;
    } else {
     $140 = ((($0)) + 96|0);
     $141 = HEAP32[$140>>2]|0;
     $142 = (__ZN3osg5Image22computePixelSizeInBitsEjj($112,$141)|0);
     $143 = Math_imul($142, $1)|0;
     $144 = $143 >>> 3;
     $145 = (($138) + ($144)|0);
     $146 = ((($0)) + 84|0);
     $147 = HEAP32[$146>>2]|0;
     $148 = ($147|0)==(0);
     $$sink$i$i = $148 ? $80 : $146;
     $149 = HEAP32[$$sink$i$i>>2]|0;
     $150 = HEAP32[$111>>2]|0;
     $151 = HEAP32[$140>>2]|0;
     $152 = ((($0)) + 100|0);
     $153 = HEAP32[$152>>2]|0;
     $154 = (__ZN3osg5Image22computePixelSizeInBitsEjj($150,$151)|0);
     $155 = Math_imul($154, $149)|0;
     $156 = ($153|0)!=(0);
     $157 = $153 << 3;
     $158 = $156 ? $157 : 8;
     $159 = (($155|0) / ($158|0))&-1;
     $160 = (($155|0) % ($158|0))&-1;
     $161 = ($160|0)!=(0);
     $162 = $161&1;
     $163 = (($162) + ($159))|0;
     $164 = Math_imul($153, $2)|0;
     $165 = Math_imul($164, $163)|0;
     $166 = (($145) + ($165)|0);
     $167 = HEAP32[$80>>2]|0;
     $168 = HEAP32[$111>>2]|0;
     $169 = HEAP32[$140>>2]|0;
     $170 = HEAP32[$152>>2]|0;
     $171 = (__ZN3osg5Image22computePixelSizeInBitsEjj($168,$169)|0);
     $172 = Math_imul($171, $167)|0;
     $173 = ($170|0)!=(0);
     $174 = $170 << 3;
     $175 = $173 ? $174 : 8;
     $176 = (($172|0) / ($175|0))&-1;
     $177 = (($172|0) % ($175|0))&-1;
     $178 = ($177|0)!=(0);
     $179 = $178&1;
     $180 = (($179) + ($176))|0;
     $181 = HEAP32[$83>>2]|0;
     $182 = Math_imul($170, $3)|0;
     $183 = Math_imul($182, $181)|0;
     $184 = Math_imul($183, $180)|0;
     $185 = (($166) + ($184)|0);
     $$0$i = $185;$$pre$phi42Z2D = $146;$$pre$phi44Z2D = $140;$$pre$phiZ2D = $152;
    }
    __ZN3osg17PixelStorageModesC2Ev($10);
    $186 = HEAP32[$$pre$phiZ2D>>2]|0;
    HEAP32[$10>>2] = $186;
    $187 = HEAP32[$$pre$phi42Z2D>>2]|0;
    $188 = ($187|0)!=(0);
    $$sink = $188 ? $$pre$phi42Z2D : $80;
    $189 = HEAP32[$$sink>>2]|0;
    $190 = ((($10)) + 4|0);
    HEAP32[$190>>2] = $189;
    $191 = ((($4)) + 100|0);
    $192 = HEAP32[$191>>2]|0;
    $193 = ((($10)) + 32|0);
    HEAP32[$193>>2] = $192;
    $194 = ((($4)) + 84|0);
    $195 = HEAP32[$194>>2]|0;
    $196 = ((($10)) + 36|0);
    HEAP32[$196>>2] = $195;
    $197 = HEAP32[$111>>2]|0;
    $198 = ((($4)) + 72|0);
    $199 = HEAP32[$198>>2]|0;
    $200 = ((($4)) + 76|0);
    $201 = HEAP32[$200>>2]|0;
    $202 = ((($4)) + 96|0);
    $203 = HEAP32[$202>>2]|0;
    $204 = ((($4)) + 112|0);
    $205 = HEAP32[$204>>2]|0;
    $206 = HEAP32[$$pre$phi44Z2D>>2]|0;
    $207 = (__ZN3osg13gluScaleImageEPNS_17PixelStorageModesEjiijPKviijPv($10,$197,$199,$201,$203,$205,$199,$201,$206,$$0$i)|0);
    $208 = ($207|0)==(0);
    do {
     if (!($208)) {
      $209 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
      if ($209) {
       $210 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
       $211 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($210,144411,58)|0);
       $212 = (__ZN3osg14gluErrorStringEj($207)|0);
       $213 = (_strlen($212)|0);
       $214 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($211,$212,$213)|0);
       $215 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($214,144470,39)|0);
       $216 = HEAP32[$215>>2]|0;
       $217 = ((($216)) + -12|0);
       $218 = HEAP32[$217>>2]|0;
       $219 = (($215) + ($218)|0);
       __ZNKSt3__28ios_base6getlocEv($5,$219);
       __THREW__ = 0;
       $220 = (invoke_iii(3255,($5|0),(215188|0))|0);
       $221 = __THREW__; __THREW__ = 0;
       $222 = $221&1;
       if (!($222)) {
        $223 = HEAP32[$220>>2]|0;
        $224 = ((($223)) + 28|0);
        $225 = HEAP32[$224>>2]|0;
        __THREW__ = 0;
        $226 = (invoke_iii($225|0,($220|0),10)|0);
        $227 = __THREW__; __THREW__ = 0;
        $228 = $227&1;
        if (!($228)) {
         __ZNSt3__26localeD2Ev($5);
         (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($215,$226)|0);
         (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($215)|0);
         break;
        }
       }
       $229 = ___cxa_find_matching_catch_2()|0;
       $230 = tempRet0;
       __THREW__ = 0;
       invoke_vi(3263,($5|0));
       $231 = __THREW__; __THREW__ = 0;
       $232 = $231&1;
       if ($232) {
        $233 = ___cxa_find_matching_catch_3(0|0)|0;
        $234 = tempRet0;
        ___clang_call_terminate($233);
        // unreachable;
       } else {
        ___resumeException($229|0);
        // unreachable;
       }
      }
     }
    } while(0);
    STACKTOP = sp;return;
   }
  }
 }
 $89 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
 if (!($89)) {
  STACKTOP = sp;return;
 }
 $90 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
 $91 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($90,144210,96)|0);
 $92 = HEAP32[$91>>2]|0;
 $93 = ((($92)) + -12|0);
 $94 = HEAP32[$93>>2]|0;
 $95 = (($91) + ($94)|0);
 __ZNKSt3__28ios_base6getlocEv($7,$95);
 __THREW__ = 0;
 $96 = (invoke_iii(3255,($7|0),(215188|0))|0);
 $97 = __THREW__; __THREW__ = 0;
 $98 = $97&1;
 if (!($98)) {
  $99 = HEAP32[$96>>2]|0;
  $100 = ((($99)) + 28|0);
  $101 = HEAP32[$100>>2]|0;
  __THREW__ = 0;
  $102 = (invoke_iii($101|0,($96|0),10)|0);
  $103 = __THREW__; __THREW__ = 0;
  $104 = $103&1;
  if (!($104)) {
   __ZNSt3__26localeD2Ev($7);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($91,$102)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($91)|0);
   STACKTOP = sp;return;
  }
 }
 $105 = ___cxa_find_matching_catch_2()|0;
 $106 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($7|0));
 $107 = __THREW__; __THREW__ = 0;
 $108 = $107&1;
 if ($108) {
  $109 = ___cxa_find_matching_catch_3(0|0)|0;
  $110 = tempRet0;
  ___clang_call_terminate($109);
  // unreachable;
 } else {
  ___resumeException($105|0);
  // unreachable;
 }
}
function __ZNK3osg5Image18isImageTranslucentEv($0) {
 $0 = $0|0;
 var $$0$i = 0, $$01014$i = 0, $$01014$i59 = 0, $$01014$i63 = 0, $$01014$i66 = 0, $$01014$i70 = 0, $$01014$i74 = 0, $$01112$i = 0, $$01112$i79 = 0, $$01112$i82 = 0, $$01112$i85 = 0, $$01112$i88 = 0, $$01112$i92 = 0, $$01112$i95 = 0, $$01112$i98 = 0, $$01213$i = 0, $$01213$i60 = 0, $$01213$i64 = 0, $$01213$i67 = 0, $$01213$i71 = 0;
 var $$01213$i75 = 0, $$051133 = 0, $$052134 = 0, $$056 = 0, $$057 = 0, $$0913$i = 0, $$0913$i78 = 0, $$0913$i81 = 0, $$0913$i84 = 0, $$0913$i87 = 0, $$0913$i91 = 0, $$0913$i94 = 0, $$0913$i97 = 0, $$255 = 0, $$pre = 0, $$sink$i$i = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0;
 var $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0.0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0;
 var $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0;
 var $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0;
 var $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0;
 var $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $switch$split12D = 0, $switch$split2D = 0, $switch$split42D = 0, $switch$split72D = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 92|0);
 $2 = HEAP32[$1>>2]|0;
 $switch$split2D = ($2|0)<(32993);
 L1: do {
  if ($switch$split2D) {
   switch ($2|0) {
   case 6406:  {
    $$056 = 1;$$057 = 0;
    break L1;
    break;
   }
   case 6410:  {
    $$056 = 2;$$057 = 1;
    break L1;
    break;
   }
   case 6408:  {
    $$056 = 4;$$057 = 3;
    break L1;
    break;
   }
   default: {
    $$255 = 0;
    return ($$255|0);
   }
   }
  } else {
   switch ($2|0) {
   case 32993:  {
    $$056 = 4;$$057 = 3;
    break L1;
    break;
   }
   case 33777: case 33778: case 33779:  {
    $3 = ((($0)) + 72|0);
    $4 = HEAP32[$3>>2]|0;
    $5 = ((($0)) + 76|0);
    $6 = HEAP32[$5>>2]|0;
    $7 = ((($0)) + 112|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = (__ZN9dxtc_tool26CompressedImageTranslucentEjjjPv($4,$6,$2,$8)|0);
    $$255 = $9;
    return ($$255|0);
    break;
   }
   default: {
    $$255 = 0;
    return ($$255|0);
   }
   }
  }
 } while(0);
 $10 = ((($0)) + 80|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)>(0);
 if (!($12)) {
  $$255 = 0;
  return ($$255|0);
 }
 $13 = ((($0)) + 76|0);
 $14 = ((($0)) + 112|0);
 $15 = ((($0)) + 96|0);
 $16 = ((($0)) + 72|0);
 $17 = ((($0)) + 84|0);
 $18 = ((($0)) + 100|0);
 $$pre = HEAP32[$13>>2]|0;
 $$052134 = 0;$19 = $$pre;
 L17: while(1) {
  $20 = ($19|0)>(0);
  if ($20) {
   $$051133 = 0;$179 = $19;
   while(1) {
    $21 = HEAP32[$14>>2]|0;
    $22 = ($21|0)==(0|0);
    if ($22) {
     $$0$i = 0;$175 = $179;
    } else {
     $23 = HEAP32[$1>>2]|0;
     $24 = HEAP32[$15>>2]|0;
     (__ZN3osg5Image22computePixelSizeInBitsEjj($23,$24)|0);
     $25 = HEAP32[$17>>2]|0;
     $26 = ($25|0)==(0);
     $$sink$i$i = $26 ? $16 : $17;
     $27 = HEAP32[$$sink$i$i>>2]|0;
     $28 = HEAP32[$1>>2]|0;
     $29 = HEAP32[$15>>2]|0;
     $30 = HEAP32[$18>>2]|0;
     $31 = (__ZN3osg5Image22computePixelSizeInBitsEjj($28,$29)|0);
     $32 = Math_imul($31, $27)|0;
     $33 = ($30|0)!=(0);
     $34 = $30 << 3;
     $35 = $33 ? $34 : 8;
     $36 = (($32|0) / ($35|0))&-1;
     $37 = (($32|0) % ($35|0))&-1;
     $38 = ($37|0)!=(0);
     $39 = $38&1;
     $40 = (($39) + ($36))|0;
     $41 = Math_imul($30, $$051133)|0;
     $42 = Math_imul($41, $40)|0;
     $43 = (($21) + ($42)|0);
     $44 = HEAP32[$16>>2]|0;
     $45 = HEAP32[$1>>2]|0;
     $46 = HEAP32[$15>>2]|0;
     $47 = HEAP32[$18>>2]|0;
     $48 = (__ZN3osg5Image22computePixelSizeInBitsEjj($45,$46)|0);
     $49 = Math_imul($48, $44)|0;
     $50 = ($47|0)!=(0);
     $51 = $47 << 3;
     $52 = $50 ? $51 : 8;
     $53 = (($49|0) / ($52|0))&-1;
     $54 = (($49|0) % ($52|0))&-1;
     $55 = ($54|0)!=(0);
     $56 = $55&1;
     $57 = (($56) + ($53))|0;
     $58 = HEAP32[$13>>2]|0;
     $59 = Math_imul($47, $$052134)|0;
     $60 = Math_imul($59, $58)|0;
     $61 = Math_imul($60, $57)|0;
     $62 = (($43) + ($61)|0);
     $$0$i = $62;$175 = $58;
    }
    $63 = HEAP32[$15>>2]|0;
    $switch$split12D = ($63|0)<(5131);
    L25: do {
     if ($switch$split12D) {
      switch ($63|0) {
      case 5120:  {
       $64 = HEAP32[$16>>2]|0;
       $65 = ($64|0)==(0);
       if ($65) {
        break L25;
       }
       $66 = (($$0$i) + ($$057)|0);
       $$01112$i98 = $66;$$0913$i97 = 0;
       while(1) {
        $67 = HEAP8[$$01112$i98>>0]|0;
        $68 = ($67<<24>>24)==(127);
        if (!($68)) {
         $$255 = 1;
         label = 70;
         break L17;
        }
        $69 = (($$01112$i98) + ($$056)|0);
        $70 = (($$0913$i97) + 1)|0;
        $71 = ($70>>>0)<($64>>>0);
        if ($71) {
         $$01112$i98 = $69;$$0913$i97 = $70;
        } else {
         break;
        }
       }
       break;
      }
      case 5121:  {
       $72 = HEAP32[$16>>2]|0;
       $73 = ($72|0)==(0);
       if ($73) {
        break L25;
       }
       $74 = (($$0$i) + ($$057)|0);
       $$01112$i95 = $74;$$0913$i94 = 0;
       while(1) {
        $75 = HEAP8[$$01112$i95>>0]|0;
        $76 = ($75<<24>>24)==(-1);
        if (!($76)) {
         $$255 = 1;
         label = 70;
         break L17;
        }
        $77 = (($$01112$i95) + ($$056)|0);
        $78 = (($$0913$i94) + 1)|0;
        $79 = ($78>>>0)<($72>>>0);
        if ($79) {
         $$01112$i95 = $77;$$0913$i94 = $78;
        } else {
         break;
        }
       }
       break;
      }
      case 5122:  {
       $80 = HEAP32[$16>>2]|0;
       $81 = ($80|0)==(0);
       if ($81) {
        break L25;
       }
       $82 = (($$0$i) + ($$057<<1)|0);
       $$01112$i92 = $82;$$0913$i91 = 0;
       while(1) {
        $83 = HEAP16[$$01112$i92>>1]|0;
        $84 = ($83<<16>>16)==(32767);
        if (!($84)) {
         $$255 = 1;
         label = 70;
         break L17;
        }
        $85 = (($$01112$i92) + ($$056<<1)|0);
        $86 = (($$0913$i91) + 1)|0;
        $87 = ($86>>>0)<($80>>>0);
        if ($87) {
         $$01112$i92 = $85;$$0913$i91 = $86;
        } else {
         break;
        }
       }
       break;
      }
      case 5123:  {
       $88 = HEAP32[$16>>2]|0;
       $89 = ($88|0)==(0);
       if ($89) {
        break L25;
       }
       $90 = (($$0$i) + ($$057<<1)|0);
       $$01112$i88 = $90;$$0913$i87 = 0;
       while(1) {
        $91 = HEAP16[$$01112$i88>>1]|0;
        $92 = ($91<<16>>16)==(-1);
        if (!($92)) {
         $$255 = 1;
         label = 70;
         break L17;
        }
        $93 = (($$01112$i88) + ($$056<<1)|0);
        $94 = (($$0913$i87) + 1)|0;
        $95 = ($94>>>0)<($88>>>0);
        if ($95) {
         $$01112$i88 = $93;$$0913$i87 = $94;
        } else {
         break;
        }
       }
       break;
      }
      case 5124:  {
       $96 = HEAP32[$16>>2]|0;
       $97 = ($96|0)==(0);
       if ($97) {
        break L25;
       }
       $98 = (($$0$i) + ($$057<<2)|0);
       $$01112$i85 = $98;$$0913$i84 = 0;
       while(1) {
        $99 = HEAP32[$$01112$i85>>2]|0;
        $100 = ($99|0)==(2147483647);
        if (!($100)) {
         $$255 = 1;
         label = 70;
         break L17;
        }
        $101 = (($$01112$i85) + ($$056<<2)|0);
        $102 = (($$0913$i84) + 1)|0;
        $103 = ($102>>>0)<($96>>>0);
        if ($103) {
         $$01112$i85 = $101;$$0913$i84 = $102;
        } else {
         break;
        }
       }
       break;
      }
      case 5125:  {
       $104 = HEAP32[$16>>2]|0;
       $105 = ($104|0)==(0);
       if ($105) {
        break L25;
       }
       $106 = (($$0$i) + ($$057<<2)|0);
       $$01112$i82 = $106;$$0913$i81 = 0;
       while(1) {
        $107 = HEAP32[$$01112$i82>>2]|0;
        $108 = ($107|0)==(-1);
        if (!($108)) {
         $$255 = 1;
         label = 70;
         break L17;
        }
        $109 = (($$01112$i82) + ($$056<<2)|0);
        $110 = (($$0913$i81) + 1)|0;
        $111 = ($110>>>0)<($104>>>0);
        if ($111) {
         $$01112$i82 = $109;$$0913$i81 = $110;
        } else {
         break;
        }
       }
       break;
      }
      case 5126:  {
       $112 = HEAP32[$16>>2]|0;
       $113 = ($112|0)==(0);
       if ($113) {
        break L25;
       }
       $114 = (($$0$i) + ($$057<<2)|0);
       $$01112$i79 = $114;$$0913$i78 = 0;
       while(1) {
        $115 = +HEAPF32[$$01112$i79>>2];
        $116 = $115 < 1.0;
        if ($116) {
         $$255 = 1;
         label = 70;
         break L17;
        }
        $117 = (($$01112$i79) + ($$056<<2)|0);
        $118 = (($$0913$i78) + 1)|0;
        $119 = ($118>>>0)<($112>>>0);
        if ($119) {
         $$01112$i79 = $117;$$0913$i78 = $118;
        } else {
         break;
        }
       }
       break;
      }
      default: {
       break L25;
      }
      }
     } else {
      $switch$split42D = ($63|0)<(32822);
      if ($switch$split42D) {
       $switch$split72D = ($63|0)<(32819);
       if ($switch$split72D) {
        switch ($63|0) {
        case 5131:  {
         break;
        }
        default: {
         break L25;
        }
        }
        $165 = HEAP32[$16>>2]|0;
        $166 = ($165|0)==(0);
        if ($166) {
         break;
        }
        $167 = (($$0$i) + ($$057<<1)|0);
        $$01112$i = $167;$$0913$i = 0;
        while(1) {
         $168 = HEAP16[$$01112$i>>1]|0;
         $169 = ($168&65535)<(15360);
         if ($169) {
          $$255 = 1;
          label = 70;
          break L17;
         }
         $170 = (($$01112$i) + ($$056<<1)|0);
         $171 = (($$0913$i) + 1)|0;
         $172 = ($171>>>0)<($165>>>0);
         if ($172) {
          $$01112$i = $170;$$0913$i = $171;
         } else {
          break L25;
         }
        }
       }
       switch ($63|0) {
       case 32820:  {
        $120 = HEAP32[$16>>2]|0;
        $121 = ($120|0)==(0);
        if ($121) {
         break L25;
        }
        $$01014$i74 = 0;$$01213$i75 = $$0$i;
        while(1) {
         $122 = HEAP16[$$01213$i75>>1]|0;
         $123 = $122 & 1;
         $124 = ($123<<16>>16)==(0);
         if ($124) {
          $$255 = 1;
          label = 70;
          break L17;
         }
         $125 = ((($$01213$i75)) + 2|0);
         $126 = (($$01014$i74) + 1)|0;
         $127 = ($126>>>0)<($120>>>0);
         if ($127) {
          $$01014$i74 = $126;$$01213$i75 = $125;
         } else {
          break L25;
         }
        }
        break;
       }
       case 32819:  {
        $135 = HEAP32[$16>>2]|0;
        $136 = ($135|0)==(0);
        if ($136) {
         break L25;
        }
        $$01014$i66 = 0;$$01213$i67 = $$0$i;
        while(1) {
         $137 = HEAP16[$$01213$i67>>1]|0;
         $138 = $137 & 15;
         $139 = ($138<<16>>16)==(15);
         if (!($139)) {
          $$255 = 1;
          label = 70;
          break L17;
         }
         $140 = ((($$01213$i67)) + 2|0);
         $141 = (($$01014$i66) + 1)|0;
         $142 = ($141>>>0)<($135>>>0);
         if ($142) {
          $$01014$i66 = $141;$$01213$i67 = $140;
         } else {
          break L25;
         }
        }
        break;
       }
       default: {
        break L25;
       }
       }
      }
      switch ($63|0) {
      case 33638:  {
       $128 = HEAP32[$16>>2]|0;
       $129 = ($128|0)==(0);
       if ($129) {
        break L25;
       }
       $$01014$i70 = 0;$$01213$i71 = $$0$i;
       while(1) {
        $130 = HEAP16[$$01213$i71>>1]|0;
        $131 = ($130<<16>>16)>(-1);
        if ($131) {
         $$255 = 1;
         label = 70;
         break L17;
        }
        $132 = ((($$01213$i71)) + 2|0);
        $133 = (($$01014$i70) + 1)|0;
        $134 = ($133>>>0)<($128>>>0);
        if ($134) {
         $$01014$i70 = $133;$$01213$i71 = $132;
        } else {
         break;
        }
       }
       break;
      }
      case 33637:  {
       $143 = HEAP32[$16>>2]|0;
       $144 = ($143|0)==(0);
       if ($144) {
        break L25;
       }
       $$01014$i63 = 0;$$01213$i64 = $$0$i;
       while(1) {
        $145 = HEAP16[$$01213$i64>>1]|0;
        $146 = ($145&65535)<(61440);
        if ($146) {
         $$255 = 1;
         label = 70;
         break L17;
        }
        $147 = ((($$01213$i64)) + 2|0);
        $148 = (($$01014$i63) + 1)|0;
        $149 = ($148>>>0)<($143>>>0);
        if ($149) {
         $$01014$i63 = $148;$$01213$i64 = $147;
        } else {
         break;
        }
       }
       break;
      }
      case 32822:  {
       $150 = HEAP32[$16>>2]|0;
       $151 = ($150|0)==(0);
       if ($151) {
        break L25;
       }
       $$01014$i59 = 0;$$01213$i60 = $$0$i;
       while(1) {
        $152 = HEAP32[$$01213$i60>>2]|0;
        $153 = $152 & 3;
        $154 = ($153|0)==(3);
        if (!($154)) {
         $$255 = 1;
         label = 70;
         break L17;
        }
        $155 = ((($$01213$i60)) + 4|0);
        $156 = (($$01014$i59) + 1)|0;
        $157 = ($156>>>0)<($150>>>0);
        if ($157) {
         $$01014$i59 = $156;$$01213$i60 = $155;
        } else {
         break;
        }
       }
       break;
      }
      case 33640:  {
       $158 = HEAP32[$16>>2]|0;
       $159 = ($158|0)==(0);
       if ($159) {
        break L25;
       }
       $$01014$i = 0;$$01213$i = $$0$i;
       while(1) {
        $160 = HEAP32[$$01213$i>>2]|0;
        $161 = ($160>>>0)<(3221225472);
        if ($161) {
         $$255 = 1;
         label = 70;
         break L17;
        }
        $162 = ((($$01213$i)) + 4|0);
        $163 = (($$01014$i) + 1)|0;
        $164 = ($163>>>0)<($158>>>0);
        if ($164) {
         $$01014$i = $163;$$01213$i = $162;
        } else {
         break;
        }
       }
       break;
      }
      default: {
       break L25;
      }
      }
     }
    } while(0);
    $173 = (($$051133) + 1)|0;
    $174 = ($173|0)<($175|0);
    if ($174) {
     $$051133 = $173;$179 = $175;
    } else {
     $180 = $175;
     break;
    }
   }
  } else {
   $180 = $19;
  }
  $176 = (($$052134) + 1)|0;
  $177 = HEAP32[$10>>2]|0;
  $178 = ($176|0)<($177|0);
  if ($178) {
   $$052134 = $176;$19 = $180;
  } else {
   $$255 = 0;
   label = 70;
   break;
  }
 }
 if ((label|0) == 70) {
  return ($$255|0);
 }
 return (0)|0;
}
function __ZNK3osg5Image18requiresUpdateCallEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function __ZN3osg5Image6updateEPNS_11NodeVisitorE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN3osg5Image13sendFocusHintEb($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function __ZN3osg5Image16sendPointerEventEiii($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function __ZN3osg5Image12sendKeyEventEib($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function __ZN3osg5Image20setFrameLastRenderedEPKNS_10FrameStampE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN3osg5Image22computePixelSizeInBitsEjj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$off = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $switch = 0, $switch$split112D = 0;
 var $switch$split22D = 0, $switch$split2D = 0, $switch$split52D = 0, $switch$split82D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp + 4|0;
 $3 = sp;
 L1: do {
  switch ($0|0) {
  case 37489: case 37488: case 37495: case 37494: case 37493: case 37492: case 36196: case 35842: case 35840: case 36283: case 36284: case 33777: case 33776:  {
   $$0 = 4;
   break;
  }
  case 33778:  {
   $$0 = 8;
   break;
  }
  case 33779:  {
   $$0 = 8;
   break;
  }
  case 36286:  {
   $$0 = 8;
   break;
  }
  case 36285:  {
   $$0 = 8;
   break;
  }
  case 35841:  {
   $$0 = 2;
   break;
  }
  case 35843:  {
   $$0 = 2;
   break;
  }
  case 37496:  {
   $$0 = 8;
   break;
  }
  case 37497:  {
   $$0 = 8;
   break;
  }
  case 37490:  {
   $$0 = 8;
   break;
  }
  case 37491:  {
   $$0 = 8;
   break;
  }
  default: {
   $$off = (($0) + -34025)|0;
   $switch = ($$off>>>0)<(6);
   if ($switch) {
    $4 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
    if (!($4)) {
     $$0 = 0;
     break L1;
    }
    $5 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
    $6 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($5,143968,95)|0);
    $7 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($6,$0)|0);
    $8 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($7,155598,14)|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = ((($9)) + -12|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = (($8) + ($11)|0);
    __ZNKSt3__28ios_base6getlocEv($3,$12);
    __THREW__ = 0;
    $13 = (invoke_iii(3255,($3|0),(215188|0))|0);
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if (!($15)) {
     $16 = HEAP32[$13>>2]|0;
     $17 = ((($16)) + 28|0);
     $18 = HEAP32[$17>>2]|0;
     __THREW__ = 0;
     $19 = (invoke_iii($18|0,($13|0),10)|0);
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if (!($21)) {
      __ZNSt3__26localeD2Ev($3);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($8,$19)|0);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($8)|0);
      $$0 = 0;
      break L1;
     }
    }
    $22 = ___cxa_find_matching_catch_2()|0;
    $23 = tempRet0;
    __THREW__ = 0;
    invoke_vi(3263,($3|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     $26 = ___cxa_find_matching_catch_3(0|0)|0;
     $27 = tempRet0;
     ___clang_call_terminate($26);
     // unreachable;
    } else {
     ___resumeException($22|0);
     // unreachable;
    }
   }
   do {
    switch ($0|0) {
    case 32842: case 32831:  {
     $$0 = 4;
     break L1;
     break;
    }
    case 32832:  {
     $$0 = 8;
     break L1;
     break;
    }
    case 32833:  {
     $$0 = 12;
     break L1;
     break;
    }
    case 32834:  {
     $$0 = 16;
     break L1;
     break;
    }
    case 32835:  {
     $$0 = 8;
     break L1;
     break;
    }
    case 32836:  {
     $$0 = 8;
     break L1;
     break;
    }
    case 32837:  {
     $$0 = 16;
     break L1;
     break;
    }
    case 32838:  {
     $$0 = 16;
     break L1;
     break;
    }
    case 32839:  {
     $$0 = 24;
     break L1;
     break;
    }
    case 32840:  {
     $$0 = 32;
     break L1;
     break;
    }
    case 32843:  {
     $$0 = 8;
     break L1;
     break;
    }
    case 32844:  {
     $$0 = 12;
     break L1;
     break;
    }
    case 32845:  {
     $$0 = 16;
     break L1;
     break;
    }
    default: {
     $switch$split2D = ($1|0)<(32819);
     L16: do {
      if ($switch$split2D) {
       $switch$split22D = ($1|0)<(5125);
       L18: do {
        if ($switch$split22D) {
         switch ($1|0) {
         case 5123: case 5122:  {
          label = 36;
          break L18;
          break;
         }
         case 5124:  {
          label = 37;
          break L18;
          break;
         }
         case 5121: case 5120:  {
          break;
         }
         default: {
          break L16;
         }
         }
         $29 = (__ZN3osg5Image20computeNumComponentsEj($0)|0);
         $30 = $29 << 3;
         $$0 = $30;
         break L1;
        } else {
         $switch$split52D = ($1|0)<(5131);
         if ($switch$split52D) {
          switch ($1|0) {
          case 5126: case 5125:  {
           label = 37;
           break L18;
           break;
          }
          default: {
           break L16;
          }
          }
         }
         $switch$split82D = ($1|0)<(6656);
         if ($switch$split82D) {
          switch ($1|0) {
          case 5131:  {
           label = 36;
           break L18;
           break;
          }
          default: {
           break L16;
          }
          }
         }
         $switch$split112D = ($1|0)<(32818);
         if (!($switch$split112D)) {
          switch ($1|0) {
          case 32818:  {
           $$0 = 8;
           break L1;
           break;
          }
          default: {
           break L16;
          }
          }
         }
         switch ($1|0) {
         case 6656:  {
          break;
         }
         default: {
          break L16;
         }
         }
         $28 = (__ZN3osg5Image20computeNumComponentsEj($0)|0);
         $$0 = $28;
         break L1;
        }
       } while(0);
       if ((label|0) == 36) {
        $31 = (__ZN3osg5Image20computeNumComponentsEj($0)|0);
        $32 = $31 << 4;
        $$0 = $32;
        break L1;
       }
       else if ((label|0) == 37) {
        $33 = (__ZN3osg5Image20computeNumComponentsEj($0)|0);
        $34 = $33 << 5;
        $$0 = $34;
        break L1;
       }
      } else {
       switch ($1|0) {
       case 33634:  {
        $$0 = 8;
        break L1;
        break;
       }
       case 33638: case 32820: case 33637: case 32819: case 33636: case 33635:  {
        $$0 = 16;
        break L1;
        break;
       }
       case 33640: case 32822: case 33639: case 32821:  {
        $$0 = 32;
        break L1;
        break;
       }
       default: {
        break L16;
       }
       }
      }
     } while(0);
     $35 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
     if (!($35)) {
      $$0 = 0;
      break L1;
     }
     $36 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
     $37 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($36,144064,13)|0);
     $38 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($37,$1)|0);
     $39 = HEAP32[$38>>2]|0;
     $40 = ((($39)) + -12|0);
     $41 = HEAP32[$40>>2]|0;
     $42 = (($38) + ($41)|0);
     __ZNKSt3__28ios_base6getlocEv($2,$42);
     __THREW__ = 0;
     $43 = (invoke_iii(3255,($2|0),(215188|0))|0);
     $44 = __THREW__; __THREW__ = 0;
     $45 = $44&1;
     if (!($45)) {
      $46 = HEAP32[$43>>2]|0;
      $47 = ((($46)) + 28|0);
      $48 = HEAP32[$47>>2]|0;
      __THREW__ = 0;
      $49 = (invoke_iii($48|0,($43|0),10)|0);
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if (!($51)) {
       __ZNSt3__26localeD2Ev($2);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($38,$49)|0);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($38)|0);
       $$0 = 0;
       break L1;
      }
     }
     $52 = ___cxa_find_matching_catch_2()|0;
     $53 = tempRet0;
     __THREW__ = 0;
     invoke_vi(3263,($2|0));
     $54 = __THREW__; __THREW__ = 0;
     $55 = $54&1;
     if ($55) {
      $56 = ___cxa_find_matching_catch_3(0|0)|0;
      $57 = tempRet0;
      ___clang_call_terminate($56);
      // unreachable;
     } else {
      ___resumeException($52|0);
      // unreachable;
     }
    }
    }
   } while(0);
  }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function __ZN3osg5Image20computeNumComponentsEj($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $switch$split102D = 0, $switch$split12D = 0, $switch$split132D = 0, $switch$split162D = 0, $switch$split2D = 0, $switch$split42D = 0, $switch$split72D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $switch$split2D = ($0|0)<(35843);
 L1: do {
  if ($switch$split2D) {
   $switch$split12D = ($0|0)<(33189);
   if (!($switch$split12D)) {
    do {
     switch ($0|0) {
     case 34550: case 34837: case 34843: case 35841: case 35840: case 33776:  {
      $$0 = 3;
      break L1;
      break;
     }
     case 33777:  {
      $$0 = 4;
      break L1;
      break;
     }
     case 33778:  {
      $$0 = 4;
      break L1;
      break;
     }
     case 33779:  {
      $$0 = 4;
      break L1;
      break;
     }
     case 35842:  {
      $$0 = 4;
      break L1;
      break;
     }
     case 33189:  {
      $$0 = 1;
      break L1;
      break;
     }
     case 33190:  {
      $$0 = 1;
      break L1;
      break;
     }
     case 33191:  {
      $$0 = 1;
      break L1;
      break;
     }
     case 34844:  {
      $$0 = 1;
      break L1;
      break;
     }
     case 34838:  {
      $$0 = 1;
      break L1;
      break;
     }
     case 33326:  {
      $$0 = 1;
      break L1;
      break;
     }
     case 33319:  {
      $$0 = 2;
      break L1;
      break;
     }
     case 33328:  {
      $$0 = 2;
      break L1;
      break;
     }
     case 34842:  {
      $$0 = 4;
      break L1;
      break;
     }
     case 34836:  {
      $$0 = 4;
      break L1;
      break;
     }
     case 34846:  {
      $$0 = 1;
      break L1;
      break;
     }
     case 34840:  {
      $$0 = 1;
      break L1;
      break;
     }
     case 34845:  {
      $$0 = 1;
      break L1;
      break;
     }
     case 34839:  {
      $$0 = 1;
      break L1;
      break;
     }
     case 34847:  {
      $$0 = 2;
      break L1;
      break;
     }
     case 34841:  {
      $$0 = 2;
      break L1;
      break;
     }
     case 34548:  {
      $$0 = 2;
      break L1;
      break;
     }
     case 34549:  {
      $$0 = 2;
      break L1;
      break;
     }
     case 34551:  {
      $$0 = 4;
      break L1;
      break;
     }
     default: {
      label = 99;
      break L1;
     }
     }
    } while(0);
   }
   $switch$split42D = ($0|0)<(32834);
   if (!($switch$split42D)) {
    do {
     switch ($0|0) {
     case 32992:  {
      $$0 = 3;
      break L1;
      break;
     }
     case 32993:  {
      $$0 = 4;
      break L1;
      break;
     }
     case 32856:  {
      $$0 = 4;
      break L1;
      break;
     }
     case 32834:  {
      $$0 = 1;
      break L1;
      break;
     }
     case 32835:  {
      $$0 = 2;
      break L1;
      break;
     }
     case 32836:  {
      $$0 = 2;
      break L1;
      break;
     }
     case 32837:  {
      $$0 = 2;
      break L1;
      break;
     }
     case 32838:  {
      $$0 = 2;
      break L1;
      break;
     }
     case 32839:  {
      $$0 = 2;
      break L1;
      break;
     }
     case 32840:  {
      $$0 = 2;
      break L1;
      break;
     }
     case 32841:  {
      $$0 = 1;
      break L1;
      break;
     }
     case 32842:  {
      $$0 = 1;
      break L1;
      break;
     }
     case 32843:  {
      $$0 = 1;
      break L1;
      break;
     }
     case 32844:  {
      $$0 = 1;
      break L1;
      break;
     }
     case 32845:  {
      $$0 = 1;
      break L1;
      break;
     }
     default: {
      label = 99;
      break L1;
     }
     }
    } while(0);
   }
   $switch$split72D = ($0|0)<(6407);
   if ($switch$split72D) {
    switch ($0|0) {
    case 6400:  {
     $$0 = 1;
     break L1;
     break;
    }
    case 6401:  {
     $$0 = 1;
     break L1;
     break;
    }
    case 6402:  {
     $$0 = 1;
     break L1;
     break;
    }
    case 6403:  {
     $$0 = 1;
     break L1;
     break;
    }
    case 6404:  {
     $$0 = 1;
     break L1;
     break;
    }
    case 6405:  {
     $$0 = 1;
     break L1;
     break;
    }
    case 6406:  {
     $$0 = 1;
     break L1;
     break;
    }
    default: {
     label = 99;
     break L1;
    }
    }
   }
   $switch$split102D = ($0|0)<(6410);
   if ($switch$split102D) {
    switch ($0|0) {
    case 6407:  {
     $$0 = 3;
     break L1;
     break;
    }
    case 6408:  {
     $$0 = 4;
     break L1;
     break;
    }
    case 6409:  {
     $$0 = 1;
     break L1;
     break;
    }
    default: {
     label = 99;
     break L1;
    }
    }
   }
   $switch$split132D = ($0|0)<(32832);
   if (!($switch$split132D)) {
    switch ($0|0) {
    case 32832:  {
     $$0 = 1;
     break L1;
     break;
    }
    case 32833:  {
     $$0 = 1;
     break L1;
     break;
    }
    default: {
     label = 99;
     break L1;
    }
    }
   }
   $switch$split162D = ($0|0)<(32831);
   if ($switch$split162D) {
    switch ($0|0) {
    case 6410:  {
     break;
    }
    default: {
     label = 99;
     break L1;
    }
    }
    $$0 = 2;
    break;
   } else {
    switch ($0|0) {
    case 32831:  {
     break;
    }
    default: {
     label = 99;
     break L1;
    }
    }
    $$0 = 1;
    break;
   }
  } else {
   do {
    switch ($0|0) {
    case 36250: case 36248: case 36209: case 36227: case 36215: case 36233: case 36221: case 36239: case 37493: case 37492: case 36196:  {
     $$0 = 3;
     break L1;
     break;
    }
    case 36284:  {
     $$0 = 1;
     break L1;
     break;
    }
    case 36283:  {
     $$0 = 1;
     break L1;
     break;
    }
    case 36286:  {
     $$0 = 2;
     break L1;
     break;
    }
    case 36285:  {
     $$0 = 2;
     break L1;
     break;
    }
    case 35843:  {
     $$0 = 4;
     break L1;
     break;
    }
    case 37494:  {
     $$0 = 4;
     break L1;
     break;
    }
    case 37495:  {
     $$0 = 4;
     break L1;
     break;
    }
    case 37496:  {
     $$0 = 4;
     break L1;
     break;
    }
    case 37497:  {
     $$0 = 4;
     break L1;
     break;
    }
    case 37488:  {
     $$0 = 1;
     break L1;
     break;
    }
    case 37489:  {
     $$0 = 1;
     break L1;
     break;
    }
    case 37490:  {
     $$0 = 2;
     break L1;
     break;
    }
    case 37491:  {
     $$0 = 2;
     break L1;
     break;
    }
    case 36012:  {
     $$0 = 1;
     break L1;
     break;
    }
    case 36267:  {
     $$0 = 1;
     break L1;
     break;
    }
    case 36240:  {
     $$0 = 1;
     break L1;
     break;
    }
    case 36222:  {
     $$0 = 1;
     break L1;
     break;
    }
    case 36234:  {
     $$0 = 1;
     break L1;
     break;
    }
    case 36216:  {
     $$0 = 1;
     break L1;
     break;
    }
    case 36228:  {
     $$0 = 1;
     break L1;
     break;
    }
    case 36210:  {
     $$0 = 1;
     break L1;
     break;
    }
    case 36242:  {
     $$0 = 1;
     break L1;
     break;
    }
    case 36224:  {
     $$0 = 1;
     break L1;
     break;
    }
    case 36236:  {
     $$0 = 1;
     break L1;
     break;
    }
    case 36218:  {
     $$0 = 1;
     break L1;
     break;
    }
    case 36230:  {
     $$0 = 1;
     break L1;
     break;
    }
    case 36212:  {
     $$0 = 1;
     break L1;
     break;
    }
    case 36223:  {
     $$0 = 1;
     break L1;
     break;
    }
    case 36241:  {
     $$0 = 1;
     break L1;
     break;
    }
    case 36235:  {
     $$0 = 1;
     break L1;
     break;
    }
    case 36217:  {
     $$0 = 1;
     break L1;
     break;
    }
    case 36229:  {
     $$0 = 1;
     break L1;
     break;
    }
    case 36211:  {
     $$0 = 1;
     break L1;
     break;
    }
    case 36243:  {
     $$0 = 2;
     break L1;
     break;
    }
    case 36225:  {
     $$0 = 2;
     break L1;
     break;
    }
    case 36237:  {
     $$0 = 2;
     break L1;
     break;
    }
    case 36219:  {
     $$0 = 2;
     break L1;
     break;
    }
    case 36231:  {
     $$0 = 2;
     break L1;
     break;
    }
    case 36213:  {
     $$0 = 2;
     break L1;
     break;
    }
    case 36244:  {
     $$0 = 1;
     break L1;
     break;
    }
    case 36245:  {
     $$0 = 1;
     break L1;
     break;
    }
    case 36246:  {
     $$0 = 1;
     break L1;
     break;
    }
    case 36247:  {
     $$0 = 1;
     break L1;
     break;
    }
    case 36249:  {
     $$0 = 4;
     break L1;
     break;
    }
    case 36251:  {
     $$0 = 4;
     break L1;
     break;
    }
    case 36252:  {
     $$0 = 1;
     break L1;
     break;
    }
    case 36253:  {
     $$0 = 2;
     break L1;
     break;
    }
    default: {
     label = 99;
     break L1;
    }
    }
   } while(0);
  }
 } while(0);
 do {
  if ((label|0) == 99) {
   $2 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
   if ($2) {
    $3 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
    $4 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($3,144078,20)|0);
    $5 = HEAP32[$4>>2]|0;
    $6 = ((($5)) + -12|0);
    $7 = HEAP32[$6>>2]|0;
    $8 = (($4) + ($7)|0);
    $9 = ((($8)) + 4|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = $10 & -75;
    $12 = $11 | 8;
    HEAP32[$9>>2] = $12;
    $13 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($4,$0)|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ((($14)) + -12|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = (($13) + ($16)|0);
    $18 = ((($17)) + 4|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = $19 & -75;
    $21 = $20 | 2;
    HEAP32[$18>>2] = $21;
    $22 = HEAP32[$13>>2]|0;
    $23 = ((($22)) + -12|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = (($13) + ($24)|0);
    __ZNKSt3__28ios_base6getlocEv($1,$25);
    __THREW__ = 0;
    $26 = (invoke_iii(3255,($1|0),(215188|0))|0);
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if (!($28)) {
     $29 = HEAP32[$26>>2]|0;
     $30 = ((($29)) + 28|0);
     $31 = HEAP32[$30>>2]|0;
     __THREW__ = 0;
     $32 = (invoke_iii($31|0,($26|0),10)|0);
     $33 = __THREW__; __THREW__ = 0;
     $34 = $33&1;
     if (!($34)) {
      __ZNSt3__26localeD2Ev($1);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($13,$32)|0);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($13)|0);
      $$0 = 0;
      break;
     }
    }
    $35 = ___cxa_find_matching_catch_2()|0;
    $36 = tempRet0;
    __THREW__ = 0;
    invoke_vi(3263,($1|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     $39 = ___cxa_find_matching_catch_3(0|0)|0;
     $40 = tempRet0;
     ___clang_call_terminate($39);
     // unreachable;
    } else {
     ___resumeException($35|0);
     // unreachable;
    }
   } else {
    $$0 = 0;
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function __ZNK3osg5Image35getTotalSizeInBytesIncludingMipmapsEv($0) {
 $0 = $0|0;
 var $$ = 0, $$$i = 0, $$0$i = 0, $$0$i$i = 0, $$02334 = 0, $$02433 = 0, $$02532 = 0, $$02731 = 0, $$029 = 0, $$035 = 0, $$1$i = 0, $$126 = 0, $$143$i = 0, $$30 = 0, $$44$i = 0, $$off$i = 0, $$pre = 0, $$pre36 = 0, $$sink$i$i = 0, $1 = 0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $or$cond$i = 0, $or$cond3$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 116|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 120|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2|0)==($4|0);
 $6 = ((($0)) + 72|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $4;
 $9 = $2;
 if ($5) {
  $10 = ((($0)) + 92|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ((($0)) + 96|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ((($0)) + 100|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (__ZN3osg5Image22computePixelSizeInBitsEjj($11,$13)|0);
  $17 = Math_imul($16, $7)|0;
  $18 = ($15|0)!=(0);
  $19 = $15 << 3;
  $20 = $18 ? $19 : 8;
  $21 = (($17|0) / ($20|0))&-1;
  $22 = (($17|0) % ($20|0))&-1;
  $23 = ($22|0)!=(0);
  $24 = $23&1;
  $25 = (($24) + ($21))|0;
  $26 = ((($0)) + 76|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = Math_imul($27, $15)|0;
  $29 = ((($0)) + 80|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = Math_imul($28, $30)|0;
  $32 = Math_imul($31, $25)|0;
  $$029 = $32;
  return ($$029|0);
 }
 $33 = (($8) - ($9))|0;
 $34 = ($33|0)==(-4);
 if ($34) {
  $$029 = 0;
  return ($$029|0);
 }
 $35 = ((($0)) + 80|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = ((($0)) + 76|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = ((($0)) + 92|0);
 $40 = ((($0)) + 100|0);
 $41 = ((($0)) + 96|0);
 $$02334 = 0;$$02433 = $36;$$02532 = $38;$$02731 = $7;$$035 = 0;$90 = $9;$91 = $8;
 while(1) {
  $42 = HEAP32[$39>>2]|0;
  $43 = HEAP32[$40>>2]|0;
  $44 = ($$02731|0)<(1);
  $45 = ($$02532|0)<(1);
  $or$cond$i = $44 | $45;
  $46 = ($$02433|0)<(1);
  $or$cond3$i = $or$cond$i | $46;
  if ($or$cond3$i) {
   $$0$i = 0;$85 = $90;$86 = $91;
  } else {
   $47 = HEAP32[$41>>2]|0;
   $48 = $42 & -4;
   $49 = ($48|0)==(33776);
   $50 = (($$02731) + 3)|0;
   $51 = $50 & -4;
   $52 = (($$02532) + 3)|0;
   $53 = $52 & -4;
   $$$i = $49 ? $53 : $$02532;
   $$44$i = $49 ? $51 : $$02731;
   $$off$i = (($42) + -36283)|0;
   $54 = ($$off$i>>>0)<(4);
   $55 = (($$44$i) + 3)|0;
   $56 = $55 & -4;
   $57 = (($$$i) + 3)|0;
   $58 = $57 & -4;
   $$143$i = $54 ? $58 : $$$i;
   $$1$i = $54 ? $56 : $$44$i;
   $59 = (__ZN3osg5Image22computePixelSizeInBitsEjj($42,$47)|0);
   $60 = Math_imul($59, $$1$i)|0;
   $61 = ($43|0)!=(0);
   $62 = $43 << 3;
   $63 = $61 ? $62 : 8;
   $64 = (($60|0) / ($63|0))&-1;
   $65 = (($60|0) % ($63|0))&-1;
   $66 = ($65|0)!=(0);
   $67 = $66&1;
   $68 = (($67) + ($64))|0;
   $69 = Math_imul($43, $$02433)|0;
   $70 = Math_imul($69, $$143$i)|0;
   $71 = Math_imul($70, $68)|0;
   switch ($42|0) {
   case 33777: case 33776:  {
    $$sink$i$i = 8;
    label = 10;
    break;
   }
   case 37491: case 37490: case 37497: case 37496: case 36285: case 36286: case 36196: case 35842: case 35840: case 35843: case 35841: case 33779: case 33778:  {
    $$sink$i$i = 16;
    label = 10;
    break;
   }
   case 36283: case 36284:  {
    $$sink$i$i = 8;
    label = 10;
    break;
   }
   case 37489: case 37488: case 37495: case 37494: case 37493: case 37492:  {
    $$sink$i$i = 8;
    label = 10;
    break;
   }
   default: {
    $$0$i$i = $43;
   }
   }
   if ((label|0) == 10) {
    label = 0;
    $72 = ($$sink$i$i>>>0)>($43>>>0);
    $73 = $72 ? $$sink$i$i : $43;
    $$0$i$i = $73;
   }
   $74 = ($71>>>0)>($$0$i$i>>>0);
   $75 = $74 ? $71 : $$0$i$i;
   $$pre = HEAP32[$3>>2]|0;
   $$pre36 = HEAP32[$1>>2]|0;
   $$0$i = $75;$85 = $$pre36;$86 = $$pre;
  }
  $76 = (($$0$i) + ($$02334))|0;
  $77 = $$02731 >> 1;
  $78 = $$02532 >> 1;
  $79 = $$02433 >> 1;
  $80 = ($77|0)>(1);
  $$ = $80 ? $77 : 1;
  $81 = ($78|0)>(1);
  $$126 = $81 ? $78 : 1;
  $82 = ($79|0)>(1);
  $$30 = $82 ? $79 : 1;
  $83 = (($$035) + 1)|0;
  $84 = (($86) - ($85))|0;
  $87 = $84 >> 2;
  $88 = (($87) + 1)|0;
  $89 = ($83>>>0)<($88>>>0);
  if ($89) {
   $$02334 = $76;$$02433 = $$30;$$02532 = $$126;$$02731 = $$;$$035 = $83;$90 = $85;$91 = $86;
  } else {
   $$029 = $76;
   break;
  }
 }
 return ($$029|0);
}
function __ZN3osg5ImageC2ERKS0_RKNS_6CopyOpE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$039 = 0, $$2 = 0, $$231 = 0, $$3 = 0, $$332 = 0, $$4 = 0, $$433 = 0, $$5 = 0, $$534 = 0, $$pre = 0, $$pre$i38 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0;
 var $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0;
 var $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $scevgep$i$i$i = 0;
 var $scevgep5$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $3 = sp;
 __ZN3osg6ObjectC2ERKS0_RKNS_6CopyOpE($0,$1,$2);
 HEAP32[$0>>2] = (55116);
 $4 = ((($0)) + 32|0);
 HEAP32[$4>>2] = 0;
 $5 = ((($0)) + 36|0);
 HEAP32[$5>>2] = 0;
 $6 = ((($0)) + 40|0);
 HEAP32[$6>>2] = 0;
 $7 = ((($0)) + 44|0);
 $8 = ((($1)) + 44|0);
 $9 = HEAP32[$8>>2]|0;
 HEAP32[$7>>2] = $9;
 $10 = ($9|0)==(0|0);
 if (!($10)) {
  $11 = HEAP32[$9>>2]|0;
  $12 = ((($11)) + -12|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($9) + ($13)|0);
  $15 = ((($14)) + 8|0);
  $16 = HEAP32[$15>>2]|0;HEAP32[$15>>2] = (($16+1)|0);
 }
 $17 = ((($0)) + 48|0);
 HEAP32[$17>>2] = 0;
 HEAP32[$0>>2] = (61368);
 $18 = ((($0)) + 52|0);
 $19 = ((($1)) + 52|0);
 __THREW__ = 0;
 invoke_vii(3457,($18|0),($19|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if ($21) {
  $98 = ___cxa_find_matching_catch_2()|0;
  $99 = tempRet0;
  $$5 = $98;$$534 = $99;
 } else {
  $22 = ((($0)) + 64|0);
  $23 = ((($1)) + 64|0);
  $24 = HEAP32[$23>>2]|0;
  HEAP32[$22>>2] = $24;
  $25 = ((($0)) + 68|0);
  $26 = ((($1)) + 68|0);
  $27 = HEAP32[$26>>2]|0;
  HEAP32[$25>>2] = $27;
  $28 = ((($0)) + 72|0);
  $29 = ((($1)) + 72|0);
  $30 = HEAP32[$29>>2]|0;
  HEAP32[$28>>2] = $30;
  $31 = ((($0)) + 76|0);
  $32 = ((($1)) + 76|0);
  $33 = HEAP32[$32>>2]|0;
  HEAP32[$31>>2] = $33;
  $34 = ((($0)) + 80|0);
  $35 = ((($1)) + 80|0);
  $36 = HEAP32[$35>>2]|0;
  HEAP32[$34>>2] = $36;
  $37 = ((($0)) + 84|0);
  HEAP32[$37>>2] = 0;
  $38 = ((($0)) + 88|0);
  $39 = ((($1)) + 88|0);
  $40 = HEAP32[$39>>2]|0;
  HEAP32[$38>>2] = $40;
  $41 = ((($0)) + 92|0);
  $42 = ((($1)) + 92|0);
  $43 = HEAP32[$42>>2]|0;
  HEAP32[$41>>2] = $43;
  $44 = ((($0)) + 96|0);
  $45 = ((($1)) + 96|0);
  $46 = HEAP32[$45>>2]|0;
  HEAP32[$44>>2] = $46;
  $47 = ((($0)) + 100|0);
  $48 = ((($1)) + 100|0);
  $49 = HEAP32[$48>>2]|0;
  HEAP32[$47>>2] = $49;
  $50 = ((($0)) + 104|0);
  $51 = ((($1)) + 104|0);
  $52 = HEAP32[$51>>2]|0;
  HEAP32[$50>>2] = $52;
  $53 = ((($0)) + 108|0);
  HEAP32[$53>>2] = 1;
  $54 = ((($0)) + 112|0);
  HEAP32[$54>>2] = 0;
  $55 = ((($0)) + 116|0);
  $56 = ((($1)) + 116|0);
  __THREW__ = 0;
  invoke_vii(3317,($55|0),($56|0));
  $57 = __THREW__; __THREW__ = 0;
  $58 = $57&1;
  if ($58) {
   $100 = ___cxa_find_matching_catch_2()|0;
   $101 = tempRet0;
   $$4 = $100;$$433 = $101;
  } else {
   $59 = ((($0)) + 128|0);
   $60 = ((($1)) + 128|0);
   __THREW__ = 0;
   invoke_vii(3818,($59|0),($60|0));
   $61 = __THREW__; __THREW__ = 0;
   $62 = $61&1;
   if ($62) {
    $102 = ___cxa_find_matching_catch_2()|0;
    $103 = tempRet0;
    $$3 = $102;$$332 = $103;
   } else {
    $63 = ((($1)) + 112|0);
    $64 = HEAP32[$63>>2]|0;
    $65 = ($64|0)==(0|0);
    if ($65) {
     STACKTOP = sp;return;
    }
    __THREW__ = 0;
    $66 = (invoke_ii(3819,($1|0))|0);
    $67 = __THREW__; __THREW__ = 0;
    $68 = $67&1;
    L16: do {
     if ($68) {
      $104 = ___cxa_find_matching_catch_2()|0;
      $105 = tempRet0;
      $$2 = $104;$$231 = $105;
     } else {
      __THREW__ = 0;
      $69 = (invoke_ii(3820,($66|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      do {
       if (!($71)) {
        $72 = HEAP32[$54>>2]|0;
        $73 = ($72|0)==(0|0);
        if (!($73)) {
         $74 = HEAP32[$53>>2]|0;
         switch ($74|0) {
         case 1:  {
          __ZdaPv($72);
          break;
         }
         case 2:  {
          _free($72);
          break;
         }
         default: {
         }
         }
         HEAP32[$54>>2] = 0;
        }
        HEAP32[$54>>2] = $69;
        HEAP32[$53>>2] = 1;
        $75 = HEAP32[$4>>2]|0;
        $76 = (($75) + 1)|0;
        HEAP32[$4>>2] = $76;
        $77 = HEAP32[$7>>2]|0;
        $78 = ($77|0)==(0|0);
        if (!($78)) {
         $79 = HEAP32[$77>>2]|0;
         $80 = ((($79)) + 20|0);
         $81 = HEAP32[$80>>2]|0;
         __THREW__ = 0;
         invoke_vii($81|0,($77|0),($0|0));
         $82 = __THREW__; __THREW__ = 0;
         $83 = $82&1;
         if ($83) {
          break;
         }
        }
        $84 = HEAP32[$6>>2]|0;
        $85 = ($84|0)==(0|0);
        if (!($85)) {
         __THREW__ = 0;
         invoke_vi(3821,($84|0));
         $86 = __THREW__; __THREW__ = 0;
         $87 = $86&1;
         if ($87) {
          break;
         }
        }
        $88 = HEAP32[$54>>2]|0;
        HEAP32[$3>>2] = $1;
        $89 = ((($3)) + 4|0);
        ;HEAP32[$89>>2]=0|0;HEAP32[$89+4>>2]=0|0;HEAP32[$89+8>>2]=0|0;HEAP32[$89+12>>2]=0|0;HEAP32[$89+16>>2]=0|0;
        __THREW__ = 0;
        invoke_vi(3822,($3|0));
        $90 = __THREW__; __THREW__ = 0;
        $91 = $90&1;
        if ($91) {
         $108 = ___cxa_find_matching_catch_2()|0;
         $109 = tempRet0;
         $$2 = $108;$$231 = $109;
         break L16;
        }
        $92 = ((($3)) + 16|0);
        $93 = HEAP32[$92>>2]|0;
        $94 = ($93|0)==(0|0);
        L37: do {
         if (!($94)) {
          $95 = ((($3)) + 20|0);
          $96 = ((($3)) + 8|0);
          $97 = ((($3)) + 12|0);
          $$039 = $88;$113 = $93;
          L39: while(1) {
           $112 = HEAP32[$95>>2]|0;
           _memcpy(($$039|0),($113|0),($112|0))|0;
           $114 = (($$039) + ($112)|0);
           $115 = HEAP32[$3>>2]|0;
           $116 = ($115|0)==(0|0);
           if ($116) {
            label = 32;
            break;
           }
           $117 = ((($115)) + 84|0);
           $118 = HEAP32[$117>>2]|0;
           $119 = ($118|0)==(0);
           if ($119) {
            label = 32;
            break;
           }
           $120 = ((($115)) + 72|0);
           $121 = HEAP32[$120>>2]|0;
           $122 = ($118|0)==($121|0);
           if ($122) {
            label = 32;
            break;
           }
           $123 = ((($115)) + 116|0);
           $124 = HEAP32[$123>>2]|0;
           $125 = ((($115)) + 120|0);
           $126 = HEAP32[$125>>2]|0;
           $127 = ($124|0)==($126|0);
           $128 = HEAP32[$89>>2]|0;
           $129 = (($128) + 1)|0;
           HEAP32[$89>>2] = $129;
           $130 = ((($115)) + 76|0);
           $131 = HEAP32[$130>>2]|0;
           $132 = ($129|0)>=($131|0);
           $133 = $126;
           $134 = $124;
           do {
            if ($127) {
             if (!($132)) {
              break;
             }
             HEAP32[$89>>2] = 0;
             $146 = HEAP32[$96>>2]|0;
             $147 = (($146) + 1)|0;
             HEAP32[$96>>2] = $147;
             $148 = ((($115)) + 80|0);
             $149 = HEAP32[$148>>2]|0;
             $150 = ($147|0)<($149|0);
             if (!($150)) {
              label = 40;
              break L39;
             }
            } else {
             if (!($132)) {
              break;
             }
             HEAP32[$89>>2] = 0;
             $135 = HEAP32[$96>>2]|0;
             $136 = (($135) + 1)|0;
             HEAP32[$96>>2] = $136;
             $137 = ((($115)) + 80|0);
             $138 = HEAP32[$137>>2]|0;
             $139 = ($136|0)<($138|0);
             if ($139) {
              break;
             }
             HEAP32[$96>>2] = 0;
             $140 = HEAP32[$97>>2]|0;
             $141 = (($140) + 1)|0;
             HEAP32[$97>>2] = $141;
             $142 = (($133) - ($134))|0;
             $143 = $142 >> 2;
             $144 = (($143) + 1)|0;
             $145 = ($141>>>0)<($144>>>0);
             if (!($145)) {
              label = 37;
              break L39;
             }
            }
           } while(0);
           __THREW__ = 0;
           invoke_vi(3822,($3|0));
           $151 = __THREW__; __THREW__ = 0;
           $152 = $151&1;
           if ($152) {
            label = 28;
            break;
           }
           $$pre = HEAP32[$92>>2]|0;
           $153 = ($$pre|0)==(0|0);
           if ($153) {
            break L37;
           } else {
            $$039 = $114;$113 = $$pre;
           }
          }
          if ((label|0) == 28) {
           $110 = ___cxa_find_matching_catch_2()|0;
           $111 = tempRet0;
           $$2 = $110;$$231 = $111;
           break L16;
          }
          else if ((label|0) == 32) {
           HEAP32[$92>>2] = 0;
           HEAP32[$95>>2] = 0;
           break;
          }
          else if ((label|0) == 37) {
           HEAP32[$92>>2] = 0;
           HEAP32[$95>>2] = 0;
           break;
          }
          else if ((label|0) == 40) {
           HEAP32[$92>>2] = 0;
           HEAP32[$95>>2] = 0;
           break;
          }
         }
        } while(0);
        STACKTOP = sp;return;
       }
      } while(0);
      $106 = ___cxa_find_matching_catch_2()|0;
      $107 = tempRet0;
      $$2 = $106;$$231 = $107;
     }
    } while(0);
    $154 = HEAP32[$59>>2]|0;
    $155 = ($154|0)==(0|0);
    if ($155) {
     $$3 = $$2;$$332 = $$231;
    } else {
     $156 = ((($0)) + 132|0);
     $157 = HEAP32[$156>>2]|0;
     $158 = ($157|0)==($154|0);
     do {
      if ($158) {
       $172 = $154;
      } else {
       $160 = $157;
       while(1) {
        $159 = ((($160)) + -4|0);
        HEAP32[$156>>2] = $159;
        $161 = HEAP32[$159>>2]|0;
        $162 = ($161|0)==(0|0);
        if (!($162)) {
         $163 = ((($161)) + 8|0);
         $164 = HEAP32[$163>>2]|0;HEAP32[$163>>2] = (($164-1)|0);
         $165 = ($164|0)==(1);
         if ($165) {
          __THREW__ = 0;
          invoke_viii(3262,($161|0),1,1);
          $166 = __THREW__; __THREW__ = 0;
          $167 = $166&1;
          if ($167) {
           label = 50;
           break;
          }
         }
        }
        HEAP32[$159>>2] = 0;
        $168 = HEAP32[$156>>2]|0;
        $169 = ($168|0)==($154|0);
        if ($169) {
         label = 51;
         break;
        } else {
         $160 = $168;
        }
       }
       if ((label|0) == 50) {
        $170 = ___cxa_find_matching_catch_2()|0;
        $171 = tempRet0;
        ___cxa_call_unexpected(($170|0));
        // unreachable;
       }
       else if ((label|0) == 51) {
        $$pre$i38 = HEAP32[$59>>2]|0;
        $172 = $$pre$i38;
        break;
       }
      }
     } while(0);
     __ZdlPv($172);
     $$3 = $$2;$$332 = $$231;
    }
   }
   $173 = HEAP32[$55>>2]|0;
   $174 = ($173|0)==(0|0);
   if ($174) {
    $$4 = $$3;$$433 = $$332;
   } else {
    $175 = ((($0)) + 120|0);
    $176 = HEAP32[$175>>2]|0;
    $177 = ($176|0)==($173|0);
    if (!($177)) {
     $scevgep$i$i$i = ((($176)) + -4|0);
     $178 = $scevgep$i$i$i;
     $179 = $173;
     $180 = (($178) - ($179))|0;
     $181 = $180 >>> 2;
     $182 = $181 ^ -1;
     $scevgep5$i$i$i = (($176) + ($182<<2)|0);
     HEAP32[$175>>2] = $scevgep5$i$i$i;
    }
    __ZdlPv($173);
    $$4 = $$3;$$433 = $$332;
   }
  }
  $183 = ((($18)) + 11|0);
  $184 = HEAP8[$183>>0]|0;
  $185 = ($184<<24>>24)<(0);
  if ($185) {
   $186 = HEAP32[$18>>2]|0;
   __ZdlPv($186);
   $$5 = $$4;$$534 = $$433;
  } else {
   $$5 = $$4;$$534 = $$433;
  }
 }
 __THREW__ = 0;
 invoke_vi(1265,($0|0));
 $187 = __THREW__; __THREW__ = 0;
 $188 = $187&1;
 if ($188) {
  $189 = ___cxa_find_matching_catch_3(0|0)|0;
  $190 = tempRet0;
  ___clang_call_terminate($189);
  // unreachable;
 } else {
  ___resumeException($$5|0);
  // unreachable;
 }
}
function __ZNSt3__26vectorIN3osg7ref_ptrINS1_5Image25DimensionsChangedCallbackEEENS_9allocatorIS5_EEEC2ERKS8_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$07$i$i = 0, $$pre$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = 0;
 $2 = ((($0)) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = ((($0)) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$1>>2]|0;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 2;
 $9 = ($8|0)==(0);
 if ($9) {
  return;
 }
 $10 = ($8>>>0)>(1073741823);
 if ($10) {
  __THREW__ = 0;
  invoke_vi(3307,($0|0));
  $11 = __THREW__; __THREW__ = 0;
 } else {
  __THREW__ = 0;
  $12 = (invoke_ii(3276,($7|0))|0);
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if (!($14)) {
   HEAP32[$2>>2] = $12;
   HEAP32[$0>>2] = $12;
   $15 = (($12) + ($8<<2)|0);
   $16 = ((($0)) + 8|0);
   HEAP32[$16>>2] = $15;
   $17 = HEAP32[$1>>2]|0;
   $18 = HEAP32[$4>>2]|0;
   $19 = ($17|0)==($18|0);
   if ($19) {
    return;
   }
   $$07$i$i = $17;$21 = $12;
   while(1) {
    $20 = HEAP32[$$07$i$i>>2]|0;
    HEAP32[$21>>2] = $20;
    $22 = ($20|0)==(0|0);
    if (!($22)) {
     $23 = ((($20)) + 8|0);
     $24 = HEAP32[$23>>2]|0;HEAP32[$23>>2] = (($24+1)|0);
    }
    $25 = ((($$07$i$i)) + 4|0);
    $26 = HEAP32[$2>>2]|0;
    $27 = ((($26)) + 4|0);
    HEAP32[$2>>2] = $27;
    $28 = ($25|0)==($18|0);
    if ($28) {
     break;
    } else {
     $$07$i$i = $25;$21 = $27;
    }
   }
   return;
  }
 }
 $29 = ___cxa_find_matching_catch_2()|0;
 $30 = tempRet0;
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)==(0|0);
 if ($32) {
  ___resumeException($29|0);
  // unreachable;
 }
 $33 = HEAP32[$2>>2]|0;
 $34 = ($33|0)==($31|0);
 do {
  if ($34) {
   $48 = $31;
  } else {
   $36 = $33;
   while(1) {
    $35 = ((($36)) + -4|0);
    HEAP32[$2>>2] = $35;
    $37 = HEAP32[$35>>2]|0;
    $38 = ($37|0)==(0|0);
    if (!($38)) {
     $39 = ((($37)) + 8|0);
     $40 = HEAP32[$39>>2]|0;HEAP32[$39>>2] = (($40-1)|0);
     $41 = ($40|0)==(1);
     if ($41) {
      __THREW__ = 0;
      invoke_viii(3262,($37|0),1,1);
      $42 = __THREW__; __THREW__ = 0;
      $43 = $42&1;
      if ($43) {
       label = 16;
       break;
      }
     }
    }
    HEAP32[$35>>2] = 0;
    $44 = HEAP32[$2>>2]|0;
    $45 = ($44|0)==($31|0);
    if ($45) {
     label = 17;
     break;
    } else {
     $36 = $44;
    }
   }
   if ((label|0) == 16) {
    $46 = ___cxa_find_matching_catch_2()|0;
    $47 = tempRet0;
    ___cxa_call_unexpected(($46|0));
    // unreachable;
   }
   else if ((label|0) == 17) {
    $$pre$i = HEAP32[$0>>2]|0;
    $48 = $$pre$i;
    break;
   }
  }
 } while(0);
 __ZdlPv($48);
 ___resumeException($29|0);
 // unreachable;
}
function __ZN3osg5Image12DataIterator6assignEv($0) {
 $0 = $0|0;
 var $$ = 0, $$0$i = 0, $$0$i$i = 0, $$1 = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre20 = 0, $$sink = 0, $$sink$i$i = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $3 = ((($0)) + 16|0);
  HEAP32[$3>>2] = 0;
  $$sink = 0;
  $145 = ((($0)) + 20|0);
  HEAP32[$145>>2] = $$sink;
  return;
 }
 $4 = ((($1)) + 84|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if (!($6)) {
  $7 = ((($1)) + 72|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($5|0)==($8|0);
  if (!($9)) {
   $14 = ((($1)) + 116|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = ((($1)) + 120|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = ($15|0)==($17|0);
   if (!($18)) {
    $19 = $15;
    $20 = $17;
    $21 = ((($0)) + 12|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = (($20) - ($19))|0;
    $24 = $23 >> 2;
    $25 = (($24) + 1)|0;
    $26 = ($22>>>0)<($25>>>0);
    if (!($26)) {
     $27 = ((($0)) + 16|0);
     HEAP32[$27>>2] = 0;
     $$sink = 0;
     $145 = ((($0)) + 20|0);
     HEAP32[$145>>2] = $$sink;
     return;
    }
    $28 = ((($1)) + 112|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = ($22|0)==(0);
    if ($30) {
     $$0$i$i = 0;
    } else {
     $31 = (($22) + -1)|0;
     $32 = (($15) + ($31<<2)|0);
     $33 = HEAP32[$32>>2]|0;
     $$0$i$i = $33;
    }
    $34 = (($29) + ($$0$i$i)|0);
    $35 = $5 >> $22;
    $36 = ($35|0)==(0);
    $$ = $36 ? 1 : $35;
    $37 = ((($1)) + 76|0);
    $38 = HEAP32[$37>>2]|0;
    $39 = $38 >> $22;
    $40 = ($39|0)==(0);
    $$1 = $40 ? 1 : $39;
    $41 = ((($1)) + 92|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = ((($1)) + 96|0);
    $44 = HEAP32[$43>>2]|0;
    $45 = ((($1)) + 100|0);
    $46 = HEAP32[$45>>2]|0;
    $47 = (__ZN3osg5Image22computePixelSizeInBitsEjj($42,$44)|0);
    $48 = Math_imul($47, $$)|0;
    $49 = ($46|0)!=(0);
    $50 = $46 << 3;
    $51 = $49 ? $50 : 8;
    $52 = (($48|0) / ($51|0))&-1;
    $53 = (($48|0) % ($51|0))&-1;
    $54 = ($53|0)!=(0);
    $55 = $54&1;
    $56 = (($55) + ($52))|0;
    $57 = Math_imul($56, $46)|0;
    $58 = ((($0)) + 4|0);
    $59 = HEAP32[$58>>2]|0;
    $60 = Math_imul($57, $59)|0;
    $61 = (($34) + ($60)|0);
    $62 = ((($0)) + 8|0);
    $63 = HEAP32[$62>>2]|0;
    $64 = Math_imul($63, $$1)|0;
    $65 = Math_imul($64, $57)|0;
    $66 = (($61) + ($65)|0);
    $67 = ((($0)) + 16|0);
    HEAP32[$67>>2] = $66;
    $$sink = $57;
    $145 = ((($0)) + 20|0);
    HEAP32[$145>>2] = $$sink;
    return;
   }
   $68 = ((($0)) + 8|0);
   $69 = HEAP32[$68>>2]|0;
   $70 = ((($1)) + 80|0);
   $71 = HEAP32[$70>>2]|0;
   $72 = ($69|0)<($71|0);
   if ($72) {
    $73 = ((($0)) + 4|0);
    $74 = HEAP32[$73>>2]|0;
    $75 = ((($1)) + 76|0);
    $76 = HEAP32[$75>>2]|0;
    $77 = ($74|0)<($76|0);
    if ($77) {
     $79 = ((($1)) + 112|0);
     $80 = HEAP32[$79>>2]|0;
     $81 = ($80|0)==(0|0);
     if ($81) {
      $$0$i = 0;$127 = $1;$135 = $8;
     } else {
      $82 = ((($1)) + 92|0);
      $83 = HEAP32[$82>>2]|0;
      $84 = ((($1)) + 96|0);
      $85 = HEAP32[$84>>2]|0;
      (__ZN3osg5Image22computePixelSizeInBitsEjj($83,$85)|0);
      $86 = HEAP32[$4>>2]|0;
      $87 = ($86|0)==(0);
      $$sink$i$i = $87 ? $7 : $4;
      $88 = HEAP32[$$sink$i$i>>2]|0;
      $89 = HEAP32[$82>>2]|0;
      $90 = HEAP32[$84>>2]|0;
      $91 = ((($1)) + 100|0);
      $92 = HEAP32[$91>>2]|0;
      $93 = (__ZN3osg5Image22computePixelSizeInBitsEjj($89,$90)|0);
      $94 = Math_imul($93, $88)|0;
      $95 = ($92|0)!=(0);
      $96 = $92 << 3;
      $97 = $95 ? $96 : 8;
      $98 = (($94|0) / ($97|0))&-1;
      $99 = (($94|0) % ($97|0))&-1;
      $100 = ($99|0)!=(0);
      $101 = $100&1;
      $102 = (($101) + ($98))|0;
      $103 = Math_imul($92, $74)|0;
      $104 = Math_imul($103, $102)|0;
      $105 = (($80) + ($104)|0);
      $106 = HEAP32[$7>>2]|0;
      $107 = HEAP32[$82>>2]|0;
      $108 = HEAP32[$84>>2]|0;
      $109 = HEAP32[$91>>2]|0;
      $110 = (__ZN3osg5Image22computePixelSizeInBitsEjj($107,$108)|0);
      $111 = Math_imul($110, $106)|0;
      $112 = ($109|0)!=(0);
      $113 = $109 << 3;
      $114 = $112 ? $113 : 8;
      $115 = (($111|0) / ($114|0))&-1;
      $116 = (($111|0) % ($114|0))&-1;
      $117 = ($116|0)!=(0);
      $118 = $117&1;
      $119 = (($118) + ($115))|0;
      $120 = HEAP32[$75>>2]|0;
      $121 = Math_imul($109, $69)|0;
      $122 = Math_imul($121, $120)|0;
      $123 = Math_imul($122, $119)|0;
      $124 = (($105) + ($123)|0);
      $$pre = HEAP32[$0>>2]|0;
      $$phi$trans$insert = ((($$pre)) + 72|0);
      $$pre20 = HEAP32[$$phi$trans$insert>>2]|0;
      $$0$i = $124;$127 = $$pre;$135 = $$pre20;
     }
     $125 = ((($0)) + 16|0);
     HEAP32[$125>>2] = $$0$i;
     $126 = ((($127)) + 92|0);
     $128 = HEAP32[$126>>2]|0;
     $129 = ((($127)) + 96|0);
     $130 = HEAP32[$129>>2]|0;
     $131 = ((($127)) + 100|0);
     $132 = HEAP32[$131>>2]|0;
     $133 = (__ZN3osg5Image22computePixelSizeInBitsEjj($128,$130)|0);
     $134 = Math_imul($133, $135)|0;
     $136 = ($132|0)!=(0);
     $137 = $132 << 3;
     $138 = $136 ? $137 : 8;
     $139 = (($134|0) / ($138|0))&-1;
     $140 = (($134|0) % ($138|0))&-1;
     $141 = ($140|0)!=(0);
     $142 = $141&1;
     $143 = (($142) + ($139))|0;
     $144 = Math_imul($143, $132)|0;
     $$sink = $144;
     $145 = ((($0)) + 20|0);
     HEAP32[$145>>2] = $$sink;
     return;
    }
   }
   $78 = ((($0)) + 16|0);
   HEAP32[$78>>2] = 0;
   $$sink = 0;
   $145 = ((($0)) + 20|0);
   HEAP32[$145>>2] = $$sink;
   return;
  }
 }
 $10 = ((($1)) + 112|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($0)) + 16|0);
 HEAP32[$12>>2] = $11;
 $13 = (__ZNK3osg5Image35getTotalSizeInBytesIncludingMipmapsEv($1)|0);
 $$sink = $13;
 $145 = ((($0)) + 20|0);
 HEAP32[$145>>2] = $$sink;
 return;
}
function __ZN3osg5Image14UpdateCallbackclEPNS_14StateAttributeEPNS_11NodeVisitorE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$012 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($1|0)==(0|0);
 if ($3) {
  return;
 }
 $4 = HEAP32[$1>>2]|0;
 $5 = ((($4)) + 140|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_ii[$6 & 8191]($1)|0);
 $8 = ($7|0)==(0|0);
 if ($8) {
  return;
 }
 $9 = HEAP32[$7>>2]|0;
 $10 = ((($9)) + 208|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (FUNCTION_TABLE_ii[$11 & 8191]($7)|0);
 $13 = ($12|0)==(0);
 if ($13) {
  return;
 }
 $$012 = 0;
 while(1) {
  $14 = HEAP32[$7>>2]|0;
  $15 = ((($14)) + 200|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (FUNCTION_TABLE_iii[$16 & 8191]($7,$$012)|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = ((($18)) + 208|0);
  $20 = HEAP32[$19>>2]|0;
  FUNCTION_TABLE_vii[$20 & 8191]($17,$2);
  $21 = (($$012) + 1)|0;
  $22 = HEAP32[$7>>2]|0;
  $23 = ((($22)) + 208|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = (FUNCTION_TABLE_ii[$24 & 8191]($7)|0);
  $26 = ($21>>>0)<($25>>>0);
  if ($26) {
   $$012 = $21;
  } else {
   break;
  }
 }
 return;
}
function __ZN3osg5Image14UpdateCallbackD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 4|0);
 HEAP32[$1>>2] = ((29984));
 $2 = ((($1)) + 8|0);
 HEAP32[$2>>2] = ((30232));
 $3 = ((($0)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  HEAP32[$3>>2] = 0;
  $15 = ((($0)) + 12|0);
  __ZN3osg6ObjectD2Ev($15);
  return;
 }
 $6 = HEAP32[$4>>2]|0;
 $7 = ((($6)) + -12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($4) + ($8)|0);
 $10 = ((($9)) + 8|0);
 $11 = HEAP32[$10>>2]|0;HEAP32[$10>>2] = (($11-1)|0);
 $12 = ($11|0)==(1);
 if (!($12)) {
  HEAP32[$3>>2] = 0;
  $15 = ((($0)) + 12|0);
  __ZN3osg6ObjectD2Ev($15);
  return;
 }
 __THREW__ = 0;
 invoke_viii(3262,($9|0),1,1);
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 if (!($14)) {
  HEAP32[$3>>2] = 0;
  $15 = ((($0)) + 12|0);
  __ZN3osg6ObjectD2Ev($15);
  return;
 }
 $16 = ___cxa_find_matching_catch_2()|0;
 $17 = tempRet0;
 $18 = ((($0)) + 12|0);
 __THREW__ = 0;
 invoke_vi(388,($18|0));
 $19 = __THREW__; __THREW__ = 0;
 $20 = $19&1;
 if ($20) {
  $21 = ___cxa_find_matching_catch_3(0|0)|0;
  $22 = tempRet0;
  ___clang_call_terminate($21);
  // unreachable;
 } else {
  ___resumeException($16|0);
  // unreachable;
 }
}
function __ZN3osg5Image14UpdateCallbackD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 4|0);
 HEAP32[$1>>2] = ((29984));
 $2 = ((($1)) + 8|0);
 HEAP32[$2>>2] = ((30232));
 $3 = ((($0)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if (!($5)) {
  $6 = HEAP32[$4>>2]|0;
  $7 = ((($6)) + -12|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($4) + ($8)|0);
  $10 = ((($9)) + 8|0);
  $11 = HEAP32[$10>>2]|0;HEAP32[$10>>2] = (($11-1)|0);
  $12 = ($11|0)==(1);
  if ($12) {
   __THREW__ = 0;
   invoke_viii(3262,($9|0),1,1);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if ($14) {
    $18 = ___cxa_find_matching_catch_2()|0;
    $19 = tempRet0;
    $20 = ((($0)) + 12|0);
    __THREW__ = 0;
    invoke_vi(388,($20|0));
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if ($22) {
     $23 = ___cxa_find_matching_catch_3(0|0)|0;
     $24 = tempRet0;
     ___clang_call_terminate($23);
     // unreachable;
    } else {
     $eh$lpad$body$index2Z2D = $19;$eh$lpad$body$indexZ2D = $18;
     __ZdlPv($0);
     ___resumeException($eh$lpad$body$indexZ2D|0);
     // unreachable;
    }
   }
  }
 }
 HEAP32[$3>>2] = 0;
 $15 = ((($0)) + 12|0);
 __THREW__ = 0;
 invoke_vi(388,($15|0));
 $16 = __THREW__; __THREW__ = 0;
 $17 = $16&1;
 if (!($17)) {
  __ZdlPv($0);
  return;
 }
 $25 = ___cxa_find_matching_catch_2()|0;
 $26 = tempRet0;
 $eh$lpad$body$index2Z2D = $26;$eh$lpad$body$indexZ2D = $25;
 __ZdlPv($0);
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
}
function __ZTv0_n112_N3osg5Image14UpdateCallbackD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -112|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 $5 = ((($4)) + 4|0);
 HEAP32[$5>>2] = ((29984));
 $6 = ((($5)) + 8|0);
 HEAP32[$6>>2] = ((30232));
 $7 = ((($4)) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if ($9) {
  HEAP32[$7>>2] = 0;
  $26 = ((($4)) + 12|0);
  __ZN3osg6ObjectD2Ev($26);
  return;
 }
 $10 = HEAP32[$8>>2]|0;
 $11 = ((($10)) + -12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($8) + ($12)|0);
 $14 = ((($13)) + 8|0);
 $15 = HEAP32[$14>>2]|0;HEAP32[$14>>2] = (($15-1)|0);
 $16 = ($15|0)==(1);
 if (!($16)) {
  HEAP32[$7>>2] = 0;
  $26 = ((($4)) + 12|0);
  __ZN3osg6ObjectD2Ev($26);
  return;
 }
 __THREW__ = 0;
 invoke_viii(3262,($13|0),1,1);
 $17 = __THREW__; __THREW__ = 0;
 $18 = $17&1;
 if (!($18)) {
  HEAP32[$7>>2] = 0;
  $26 = ((($4)) + 12|0);
  __ZN3osg6ObjectD2Ev($26);
  return;
 }
 $19 = ___cxa_find_matching_catch_2()|0;
 $20 = tempRet0;
 $21 = ((($4)) + 12|0);
 __THREW__ = 0;
 invoke_vi(388,($21|0));
 $22 = __THREW__; __THREW__ = 0;
 $23 = $22&1;
 if ($23) {
  $24 = ___cxa_find_matching_catch_3(0|0)|0;
  $25 = tempRet0;
  ___clang_call_terminate($24);
  // unreachable;
 } else {
  ___resumeException($19|0);
  // unreachable;
 }
}
function __ZTv0_n112_N3osg5Image14UpdateCallbackD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$i$index2Z2D = 0, $eh$lpad$body$i$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -112|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 $5 = ((($4)) + 4|0);
 HEAP32[$5>>2] = ((29984));
 $6 = ((($5)) + 8|0);
 HEAP32[$6>>2] = ((30232));
 $7 = ((($4)) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if (!($9)) {
  $10 = HEAP32[$8>>2]|0;
  $11 = ((($10)) + -12|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($8) + ($12)|0);
  $14 = ((($13)) + 8|0);
  $15 = HEAP32[$14>>2]|0;HEAP32[$14>>2] = (($15-1)|0);
  $16 = ($15|0)==(1);
  if ($16) {
   __THREW__ = 0;
   invoke_viii(3262,($13|0),1,1);
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if ($18) {
    $22 = ___cxa_find_matching_catch_2()|0;
    $23 = tempRet0;
    $24 = ((($4)) + 12|0);
    __THREW__ = 0;
    invoke_vi(388,($24|0));
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if ($26) {
     $27 = ___cxa_find_matching_catch_3(0|0)|0;
     $28 = tempRet0;
     ___clang_call_terminate($27);
     // unreachable;
    } else {
     $eh$lpad$body$i$index2Z2D = $23;$eh$lpad$body$i$indexZ2D = $22;
     __ZdlPv($4);
     ___resumeException($eh$lpad$body$i$indexZ2D|0);
     // unreachable;
    }
   }
  }
 }
 HEAP32[$7>>2] = 0;
 $19 = ((($4)) + 12|0);
 __THREW__ = 0;
 invoke_vi(388,($19|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if (!($21)) {
  __ZdlPv($4);
  return;
 }
 $29 = ___cxa_find_matching_catch_2()|0;
 $30 = tempRet0;
 $eh$lpad$body$i$index2Z2D = $30;$eh$lpad$body$i$indexZ2D = $29;
 __ZdlPv($4);
 ___resumeException($eh$lpad$body$i$indexZ2D|0);
 // unreachable;
}
function __ZTv0_n16_N3osg5Image14UpdateCallbackD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 $5 = ((($4)) + 4|0);
 HEAP32[$5>>2] = ((29984));
 $6 = ((($5)) + 8|0);
 HEAP32[$6>>2] = ((30232));
 $7 = ((($4)) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if ($9) {
  HEAP32[$7>>2] = 0;
  $26 = ((($4)) + 12|0);
  __ZN3osg6ObjectD2Ev($26);
  return;
 }
 $10 = HEAP32[$8>>2]|0;
 $11 = ((($10)) + -12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($8) + ($12)|0);
 $14 = ((($13)) + 8|0);
 $15 = HEAP32[$14>>2]|0;HEAP32[$14>>2] = (($15-1)|0);
 $16 = ($15|0)==(1);
 if (!($16)) {
  HEAP32[$7>>2] = 0;
  $26 = ((($4)) + 12|0);
  __ZN3osg6ObjectD2Ev($26);
  return;
 }
 __THREW__ = 0;
 invoke_viii(3262,($13|0),1,1);
 $17 = __THREW__; __THREW__ = 0;
 $18 = $17&1;
 if (!($18)) {
  HEAP32[$7>>2] = 0;
  $26 = ((($4)) + 12|0);
  __ZN3osg6ObjectD2Ev($26);
  return;
 }
 $19 = ___cxa_find_matching_catch_2()|0;
 $20 = tempRet0;
 $21 = ((($4)) + 12|0);
 __THREW__ = 0;
 invoke_vi(388,($21|0));
 $22 = __THREW__; __THREW__ = 0;
 $23 = $22&1;
 if ($23) {
  $24 = ___cxa_find_matching_catch_3(0|0)|0;
  $25 = tempRet0;
  ___clang_call_terminate($24);
  // unreachable;
 } else {
  ___resumeException($19|0);
  // unreachable;
 }
}
function __ZTv0_n16_N3osg5Image14UpdateCallbackD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$i$index2Z2D = 0, $eh$lpad$body$i$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 $5 = ((($4)) + 4|0);
 HEAP32[$5>>2] = ((29984));
 $6 = ((($5)) + 8|0);
 HEAP32[$6>>2] = ((30232));
 $7 = ((($4)) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if (!($9)) {
  $10 = HEAP32[$8>>2]|0;
  $11 = ((($10)) + -12|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($8) + ($12)|0);
  $14 = ((($13)) + 8|0);
  $15 = HEAP32[$14>>2]|0;HEAP32[$14>>2] = (($15-1)|0);
  $16 = ($15|0)==(1);
  if ($16) {
   __THREW__ = 0;
   invoke_viii(3262,($13|0),1,1);
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if ($18) {
    $22 = ___cxa_find_matching_catch_2()|0;
    $23 = tempRet0;
    $24 = ((($4)) + 12|0);
    __THREW__ = 0;
    invoke_vi(388,($24|0));
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if ($26) {
     $27 = ___cxa_find_matching_catch_3(0|0)|0;
     $28 = tempRet0;
     ___clang_call_terminate($27);
     // unreachable;
    } else {
     $eh$lpad$body$i$index2Z2D = $23;$eh$lpad$body$i$indexZ2D = $22;
     __ZdlPv($4);
     ___resumeException($eh$lpad$body$i$indexZ2D|0);
     // unreachable;
    }
   }
  }
 }
 HEAP32[$7>>2] = 0;
 $19 = ((($4)) + 12|0);
 __THREW__ = 0;
 invoke_vi(388,($19|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if (!($21)) {
  __ZdlPv($4);
  return;
 }
 $29 = ___cxa_find_matching_catch_2()|0;
 $30 = tempRet0;
 $eh$lpad$body$i$index2Z2D = $30;$eh$lpad$body$i$indexZ2D = $29;
 __ZdlPv($4);
 ___resumeException($eh$lpad$body$i$indexZ2D|0);
 // unreachable;
}
function __ZN3osg5Image12DataIteratorC2EPKS0_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = $1;
 $2 = ((($0)) + 4|0);
 ;HEAP32[$2>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;HEAP32[$2+12>>2]=0|0;HEAP32[$2+16>>2]=0|0;
 __ZN3osg5Image12DataIterator6assignEv($0);
 return;
}
function __ZN3osg5Image12DataIteratorppEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = ((($1)) + 84|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==(0);
  if (!($5)) {
   $6 = ((($1)) + 72|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($4|0)==($7|0);
   if (!($8)) {
    $11 = ((($1)) + 116|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ((($1)) + 120|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ($12|0)==($14|0);
    $16 = ((($0)) + 4|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = (($17) + 1)|0;
    HEAP32[$16>>2] = $18;
    $19 = ((($1)) + 76|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = ($18|0)>=($20|0);
    $22 = $14;
    $23 = $12;
    if ($15) {
     if ($21) {
      HEAP32[$16>>2] = 0;
      $39 = ((($0)) + 8|0);
      $40 = HEAP32[$39>>2]|0;
      $41 = (($40) + 1)|0;
      HEAP32[$39>>2] = $41;
      $42 = ((($1)) + 80|0);
      $43 = HEAP32[$42>>2]|0;
      $44 = ($41|0)<($43|0);
      if (!($44)) {
       $45 = ((($0)) + 16|0);
       HEAP32[$45>>2] = 0;
       $46 = ((($0)) + 20|0);
       HEAP32[$46>>2] = 0;
       return;
      }
     }
    } else {
     if ($21) {
      HEAP32[$16>>2] = 0;
      $24 = ((($0)) + 8|0);
      $25 = HEAP32[$24>>2]|0;
      $26 = (($25) + 1)|0;
      HEAP32[$24>>2] = $26;
      $27 = ((($1)) + 80|0);
      $28 = HEAP32[$27>>2]|0;
      $29 = ($26|0)<($28|0);
      if (!($29)) {
       HEAP32[$24>>2] = 0;
       $30 = ((($0)) + 12|0);
       $31 = HEAP32[$30>>2]|0;
       $32 = (($31) + 1)|0;
       HEAP32[$30>>2] = $32;
       $33 = (($22) - ($23))|0;
       $34 = $33 >> 2;
       $35 = (($34) + 1)|0;
       $36 = ($32>>>0)<($35>>>0);
       if (!($36)) {
        $37 = ((($0)) + 16|0);
        HEAP32[$37>>2] = 0;
        $38 = ((($0)) + 20|0);
        HEAP32[$38>>2] = 0;
        return;
       }
      }
     }
    }
    __ZN3osg5Image12DataIterator6assignEv($0);
    return;
   }
  }
 }
 $9 = ((($0)) + 16|0);
 HEAP32[$9>>2] = 0;
 $10 = ((($0)) + 20|0);
 HEAP32[$10>>2] = 0;
 return;
}
function __ZN3osg5Image22computeRowWidthInBytesEijji($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = (__ZN3osg5Image22computePixelSizeInBitsEjj($1,$2)|0);
 $5 = Math_imul($4, $0)|0;
 $6 = ($3|0)!=(0);
 $7 = $3 << 3;
 $8 = $6 ? $7 : 8;
 $9 = (($5|0) / ($8|0))&-1;
 $10 = (($5|0) % ($8|0))&-1;
 $11 = ($10|0)!=(0);
 $12 = $11&1;
 $13 = (($12) + ($9))|0;
 $14 = Math_imul($13, $3)|0;
 return ($14|0);
}
function __ZN3osg5ImageC2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 __ZN3osg10ReferencedC2Eb($0,1);
 $1 = ((($0)) + 12|0);
 ;HEAP32[$1>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;
 $2 = ((($0)) + 24|0);
 $3 = ((($0)) + 28|0);
 HEAP32[$3>>2] = 0;
 $4 = ((($0)) + 32|0);
 ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;HEAP32[$4+12>>2]=0|0;HEAP32[$4+16>>2]=0|0;
 HEAP32[$0>>2] = (61368);
 $5 = ((($0)) + 52|0);
 ;HEAP32[$5>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;
 $6 = ((($5)) + 11|0);
 HEAP8[$6>>0] = 0;
 HEAP8[$5>>0] = 0;
 $7 = ((($0)) + 64|0);
 $8 = ((($0)) + 100|0);
 dest=$7; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAP32[$8>>2] = 4;
 $9 = ((($0)) + 104|0);
 HEAPF32[$9>>2] = 1.0;
 $10 = ((($0)) + 108|0);
 HEAP32[$10>>2] = 1;
 $11 = ((($0)) + 112|0);
 ;HEAP32[$11>>2]=0|0;HEAP32[$11+4>>2]=0|0;HEAP32[$11+8>>2]=0|0;HEAP32[$11+12>>2]=0|0;HEAP32[$11+16>>2]=0|0;HEAP32[$11+20>>2]=0|0;HEAP32[$11+24>>2]=0|0;
 HEAP32[$2>>2] = 1;
 return;
}
function __ZN3osg5Image24computeNearestPowerOfTwoEif($0,$1) {
 $0 = $0|0;
 $1 = +$1;
 var $$0 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0.0, $6 = 0.0, $7 = 0.0, $8 = 0.0, $9 = 0.0, $exp2 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (($0) + -1)|0;
 $3 = $2 & $0;
 $4 = ($3|0)==(0);
 if ($4) {
  $$0 = $0;
  return ($$0|0);
 }
 $5 = (+($0|0));
 $6 = (+Math_log((+$5)));
 $7 = $6 / 0.69314718246459961;
 $8 = $7 + $1;
 $9 = (+Math_floor((+$8)));
 $exp2 = (+_llvm_exp2_f32((+$9)));
 $10 = (~~(($exp2)));
 $$0 = $10;
 return ($$0|0);
}
function __ZN3osg5Image27computeNumberOfMipmapLevelsEiii($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$09 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($0|0)>($1|0);
 $4 = $3 ? $0 : $1;
 $5 = ($4|0)>($2|0);
 $6 = $5 ? $4 : $2;
 $$0 = 0;$$09 = $6;
 while(1) {
  $7 = $$09 >> 1;
  $8 = ($7|0)==(0);
  $9 = (($$0) + 1)|0;
  if ($8) {
   break;
  } else {
   $$0 = $9;$$09 = $7;
  }
 }
 return ($9|0);
}
function __ZNK3osg5Image25supportsTextureSubloadingEv($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 88|0);
 $2 = HEAP32[$1>>2]|0;
 switch ($2|0) {
 case 37491: case 37490: case 37489: case 37488: case 37497: case 37496: case 37495: case 37494: case 37493: case 37492: case 36196:  {
  $$0 = 0;
  break;
 }
 default: {
  $$0 = 1;
 }
 }
 return ($$0|0);
}
function __ZN3osg5Image8setColorERKNS_5Vec4fEjjj($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0$i = 0, $$pre = 0, $$pre$phiZ2D = 0, $$sink$i = 0, $$sink$i$i = 0, $$sink54$i = 0, $$sink54$i21 = 0, $$sink54$i23 = 0, $$sink54$i26 = 0, $$sink54$i29 = 0, $$sink54$i32 = 0, $$sink54$i35 = 0, $$sink54$i38 = 0, $$sink56$i = 0, $$sink56$i20 = 0, $$sink56$i25 = 0, $$sink56$i28 = 0, $$sink56$i31 = 0, $$sink56$i34 = 0, $$sink56$i37 = 0;
 var $10 = 0, $100 = 0.0, $101 = 0, $102 = 0, $103 = 0, $104 = 0.0, $105 = 0.0, $106 = 0, $107 = 0, $108 = 0.0, $109 = 0.0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0.0, $114 = 0.0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0.0, $119 = 0.0, $12 = 0, $120 = 0, $121 = 0, $122 = 0.0, $123 = 0.0, $124 = 0, $125 = 0, $126 = 0, $127 = 0.0, $128 = 0.0, $129 = 0, $13 = 0, $130 = 0, $131 = 0.0, $132 = 0.0, $133 = 0, $134 = 0, $135 = 0;
 var $136 = 0.0, $137 = 0.0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0.0, $142 = 0.0, $143 = 0, $144 = 0, $145 = 0, $146 = 0.0, $147 = 0.0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0.0, $152 = 0.0, $153 = 0;
 var $154 = 0, $155 = 0, $156 = 0.0, $157 = 0.0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0.0, $162 = 0.0, $163 = 0, $164 = 0, $165 = 0.0, $166 = 0.0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0.0, $171 = 0.0;
 var $172 = 0, $173 = 0, $174 = 0, $175 = 0.0, $176 = 0.0, $177 = 0, $178 = 0, $179 = 0.0, $18 = 0, $180 = 0.0, $181 = 0, $182 = 0, $183 = 0, $184 = 0.0, $185 = 0.0, $186 = 0, $187 = 0, $188 = 0.0, $189 = 0.0, $19 = 0;
 var $190 = 0, $191 = 0, $192 = 0, $193 = 0.0, $194 = 0.0, $195 = 0, $196 = 0, $197 = 0, $198 = 0.0, $199 = 0.0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0.0, $204 = 0.0, $205 = 0, $206 = 0, $207 = 0, $208 = 0.0;
 var $209 = 0.0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0.0, $214 = 0.0, $215 = 0, $216 = 0, $217 = 0, $218 = 0.0, $219 = 0.0, $22 = 0, $220 = 0, $221 = 0, $222 = 0.0, $223 = 0.0, $224 = 0, $225 = 0, $226 = 0;
 var $227 = 0.0, $228 = 0.0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0.0, $233 = 0.0, $234 = 0, $235 = 0, $236 = 0.0, $237 = 0.0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0.0, $242 = 0.0, $243 = 0, $244 = 0;
 var $245 = 0.0, $246 = 0.0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0.0, $251 = 0.0, $252 = 0, $253 = 0, $254 = 0, $255 = 0.0, $256 = 0.0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0.0, $261 = 0.0, $262 = 0;
 var $263 = 0, $264 = 0, $265 = 0.0, $266 = 0.0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0.0, $271 = 0.0, $272 = 0, $273 = 0, $274 = 0, $275 = 0.0, $276 = 0.0, $277 = 0, $278 = 0, $279 = 0.0, $28 = 0, $280 = 0.0;
 var $281 = 0, $282 = 0, $283 = 0, $284 = 0.0, $285 = 0.0, $286 = 0, $287 = 0, $288 = 0, $289 = 0.0, $29 = 0, $290 = 0.0, $291 = 0, $292 = 0, $293 = 0.0, $294 = 0.0, $295 = 0, $296 = 0, $297 = 0, $298 = 0.0, $299 = 0.0;
 var $30 = 0, $300 = 0, $301 = 0, $302 = 0.0, $303 = 0.0, $304 = 0, $305 = 0, $306 = 0, $307 = 0.0, $308 = 0.0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0.0, $313 = 0.0, $314 = 0, $315 = 0, $316 = 0, $317 = 0.0;
 var $318 = 0.0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0.0, $323 = 0.0, $324 = 0, $325 = 0, $326 = 0, $327 = 0.0, $328 = 0.0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0.0, $333 = 0.0, $334 = 0, $335 = 0;
 var $336 = 0.0, $337 = 0.0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0.0, $342 = 0.0, $343 = 0, $344 = 0, $345 = 0, $346 = 0.0, $347 = 0.0, $348 = 0, $349 = 0, $35 = 0, $350 = 0.0, $351 = 0.0, $352 = 0, $353 = 0;
 var $354 = 0, $355 = 0.0, $356 = 0.0, $357 = 0, $358 = 0, $359 = 0.0, $36 = 0, $360 = 0.0, $361 = 0, $362 = 0, $363 = 0, $364 = 0.0, $365 = 0.0, $366 = 0, $367 = 0, $368 = 0, $369 = 0.0, $37 = 0, $370 = 0.0, $371 = 0;
 var $372 = 0, $373 = 0, $374 = 0.0, $375 = 0.0, $376 = 0, $377 = 0, $378 = 0, $379 = 0.0, $38 = 0, $380 = 0.0, $381 = 0, $382 = 0, $383 = 0, $384 = 0.0, $385 = 0.0, $386 = 0, $387 = 0, $388 = 0, $389 = 0.0, $39 = 0;
 var $390 = 0.0, $391 = 0, $392 = 0, $393 = 0.0, $394 = 0.0, $395 = 0, $396 = 0, $397 = 0, $398 = 0.0, $399 = 0.0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0;
 var $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0;
 var $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0.0, $437 = 0.0, $438 = 0, $439 = 0.0, $44 = 0, $440 = 0.0, $441 = 0, $442 = 0, $443 = 0.0, $444 = 0.0;
 var $445 = 0, $446 = 0.0, $447 = 0.0, $448 = 0, $449 = 0, $45 = 0, $450 = 0.0, $451 = 0.0, $452 = 0, $453 = 0, $454 = 0.0, $455 = 0.0, $456 = 0, $457 = 0, $458 = 0.0, $459 = 0.0, $46 = 0, $460 = 0, $461 = 0, $462 = 0.0;
 var $463 = 0.0, $464 = 0, $465 = 0, $466 = 0.0, $467 = 0.0, $468 = 0, $469 = 0, $47 = 0, $470 = 0.0, $471 = 0.0, $472 = 0, $473 = 0.0, $474 = 0.0, $475 = 0, $476 = 0, $477 = 0.0, $478 = 0.0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0.0, $62 = 0.0, $63 = 0, $64 = 0, $65 = 0.0, $66 = 0.0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0.0, $71 = 0.0, $72 = 0, $73 = 0, $74 = 0.0, $75 = 0.0, $76 = 0, $77 = 0, $78 = 0, $79 = 0.0, $8 = 0, $80 = 0.0, $81 = 0, $82 = 0, $83 = 0, $84 = 0.0, $85 = 0.0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0.0, $9 = 0, $90 = 0.0, $91 = 0, $92 = 0, $93 = 0, $94 = 0.0, $95 = 0.0, $96 = 0, $97 = 0, $98 = 0, $99 = 0.0, $switch$split102D = 0, $switch$split12D = 0, $switch$split132D = 0, $switch$split162D = 0, $switch$split192D = 0, $switch$split222D = 0;
 var $switch$split252D = 0, $switch$split282D = 0, $switch$split2D = 0, $switch$split312D = 0, $switch$split342D = 0, $switch$split372D = 0, $switch$split402D = 0, $switch$split42D = 0, $switch$split432D = 0, $switch$split72D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = ((($0)) + 112|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $$pre = ((($0)) + 96|0);
  $$0$i = 0;$$pre$phiZ2D = $$pre;
 } else {
  $8 = ((($0)) + 92|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ((($0)) + 96|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (__ZN3osg5Image22computePixelSizeInBitsEjj($9,$11)|0);
  $13 = Math_imul($12, $2)|0;
  $14 = $13 >>> 3;
  $15 = (($6) + ($14)|0);
  $16 = ((($0)) + 84|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = ($17|0)==(0);
  $19 = ((($0)) + 72|0);
  $$sink$i$i = $18 ? $19 : $16;
  $20 = HEAP32[$$sink$i$i>>2]|0;
  $21 = HEAP32[$8>>2]|0;
  $22 = HEAP32[$10>>2]|0;
  $23 = ((($0)) + 100|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = (__ZN3osg5Image22computePixelSizeInBitsEjj($21,$22)|0);
  $26 = Math_imul($25, $20)|0;
  $27 = ($24|0)!=(0);
  $28 = $24 << 3;
  $29 = $27 ? $28 : 8;
  $30 = (($26|0) / ($29|0))&-1;
  $31 = (($26|0) % ($29|0))&-1;
  $32 = ($31|0)!=(0);
  $33 = $32&1;
  $34 = (($33) + ($30))|0;
  $35 = Math_imul($24, $3)|0;
  $36 = Math_imul($35, $34)|0;
  $37 = (($15) + ($36)|0);
  $38 = HEAP32[$19>>2]|0;
  $39 = HEAP32[$8>>2]|0;
  $40 = HEAP32[$10>>2]|0;
  $41 = HEAP32[$23>>2]|0;
  $42 = (__ZN3osg5Image22computePixelSizeInBitsEjj($39,$40)|0);
  $43 = Math_imul($42, $38)|0;
  $44 = ($41|0)!=(0);
  $45 = $41 << 3;
  $46 = $44 ? $45 : 8;
  $47 = (($43|0) / ($46|0))&-1;
  $48 = (($43|0) % ($46|0))&-1;
  $49 = ($48|0)!=(0);
  $50 = $49&1;
  $51 = (($50) + ($47))|0;
  $52 = ((($0)) + 76|0);
  $53 = HEAP32[$52>>2]|0;
  $54 = Math_imul($41, $4)|0;
  $55 = Math_imul($54, $53)|0;
  $56 = Math_imul($55, $51)|0;
  $57 = (($37) + ($56)|0);
  $$0$i = $57;$$pre$phiZ2D = $10;
 }
 $58 = HEAP32[$$pre$phiZ2D>>2]|0;
 switch ($58|0) {
 case 5120:  {
  $59 = ((($0)) + 92|0);
  $60 = HEAP32[$59>>2]|0;
  $switch$split2D = ($60|0)<(6409);
  L7: do {
   if ($switch$split2D) {
    switch ($60|0) {
    case 6402:  {
     label = 6;
     break L7;
     break;
    }
    case 6406:  {
     $$sink54$i = $$0$i;$$sink56$i = 3;
     break L7;
     break;
    }
    case 6407:  {
     $65 = +HEAPF32[$1>>2];
     $66 = $65 * 128.0;
     $67 = (~~(($66)));
     $68 = ((($$0$i)) + 1|0);
     HEAP8[$$0$i>>0] = $67;
     $69 = ((($1)) + 4|0);
     $70 = +HEAPF32[$69>>2];
     $71 = $70 * 128.0;
     $72 = (~~(($71)));
     $73 = ((($$0$i)) + 2|0);
     HEAP8[$68>>0] = $72;
     $$sink54$i = $73;$$sink56$i = 2;
     break L7;
     break;
    }
    case 6408:  {
     $74 = +HEAPF32[$1>>2];
     $75 = $74 * 128.0;
     $76 = (~~(($75)));
     $77 = ((($$0$i)) + 1|0);
     HEAP8[$$0$i>>0] = $76;
     $78 = ((($1)) + 4|0);
     $79 = +HEAPF32[$78>>2];
     $80 = $79 * 128.0;
     $81 = (~~(($80)));
     $82 = ((($$0$i)) + 2|0);
     HEAP8[$77>>0] = $81;
     $83 = ((($1)) + 8|0);
     $84 = +HEAPF32[$83>>2];
     $85 = $84 * 128.0;
     $86 = (~~(($85)));
     $87 = ((($$0$i)) + 3|0);
     HEAP8[$82>>0] = $86;
     $$sink54$i = $87;$$sink56$i = 3;
     break L7;
     break;
    }
    default: {
     return;
    }
    }
   } else {
    $switch$split222D = ($60|0)<(32992);
    if ($switch$split222D) {
     switch ($60|0) {
     case 6409:  {
      label = 6;
      break L7;
      break;
     }
     case 6410:  {
      $61 = +HEAPF32[$1>>2];
      $62 = $61 * 128.0;
      $63 = (~~(($62)));
      $64 = ((($$0$i)) + 1|0);
      HEAP8[$$0$i>>0] = $63;
      $$sink54$i = $64;$$sink56$i = 3;
      break L7;
      break;
     }
     default: {
      return;
     }
     }
    }
    switch ($60|0) {
    case 32992:  {
     $88 = ((($1)) + 8|0);
     $89 = +HEAPF32[$88>>2];
     $90 = $89 * 128.0;
     $91 = (~~(($90)));
     $92 = ((($$0$i)) + 1|0);
     HEAP8[$$0$i>>0] = $91;
     $93 = ((($1)) + 4|0);
     $94 = +HEAPF32[$93>>2];
     $95 = $94 * 128.0;
     $96 = (~~(($95)));
     $97 = ((($$0$i)) + 2|0);
     HEAP8[$92>>0] = $96;
     $$sink54$i = $97;$$sink56$i = 0;
     break L7;
     break;
    }
    case 32993:  {
     $98 = ((($1)) + 8|0);
     $99 = +HEAPF32[$98>>2];
     $100 = $99 * 128.0;
     $101 = (~~(($100)));
     $102 = ((($$0$i)) + 1|0);
     HEAP8[$$0$i>>0] = $101;
     $103 = ((($1)) + 4|0);
     $104 = +HEAPF32[$103>>2];
     $105 = $104 * 128.0;
     $106 = (~~(($105)));
     $107 = ((($$0$i)) + 2|0);
     HEAP8[$102>>0] = $106;
     $108 = +HEAPF32[$1>>2];
     $109 = $108 * 128.0;
     $110 = (~~(($109)));
     $111 = ((($$0$i)) + 3|0);
     HEAP8[$107>>0] = $110;
     $$sink54$i = $111;$$sink56$i = 3;
     break L7;
     break;
    }
    default: {
     return;
    }
    }
   }
  } while(0);
  if ((label|0) == 6) {
   $$sink54$i = $$0$i;$$sink56$i = 0;
  }
  $112 = (($1) + ($$sink56$i<<2)|0);
  $113 = +HEAPF32[$112>>2];
  $114 = $113 * 128.0;
  $115 = (~~(($114)));
  HEAP8[$$sink54$i>>0] = $115;
  return;
  break;
 }
 case 5121:  {
  $116 = ((($0)) + 92|0);
  $117 = HEAP32[$116>>2]|0;
  $switch$split12D = ($117|0)<(6409);
  L29: do {
   if ($switch$split12D) {
    switch ($117|0) {
    case 6402:  {
     label = 14;
     break L29;
     break;
    }
    case 6406:  {
     $$sink54$i38 = $$0$i;$$sink56$i37 = 3;
     break L29;
     break;
    }
    case 6407:  {
     $122 = +HEAPF32[$1>>2];
     $123 = $122 * 255.0;
     $124 = (~~(($123))&255);
     $125 = ((($$0$i)) + 1|0);
     HEAP8[$$0$i>>0] = $124;
     $126 = ((($1)) + 4|0);
     $127 = +HEAPF32[$126>>2];
     $128 = $127 * 255.0;
     $129 = (~~(($128))&255);
     $130 = ((($$0$i)) + 2|0);
     HEAP8[$125>>0] = $129;
     $$sink54$i38 = $130;$$sink56$i37 = 2;
     break L29;
     break;
    }
    case 6408:  {
     $131 = +HEAPF32[$1>>2];
     $132 = $131 * 255.0;
     $133 = (~~(($132))&255);
     $134 = ((($$0$i)) + 1|0);
     HEAP8[$$0$i>>0] = $133;
     $135 = ((($1)) + 4|0);
     $136 = +HEAPF32[$135>>2];
     $137 = $136 * 255.0;
     $138 = (~~(($137))&255);
     $139 = ((($$0$i)) + 2|0);
     HEAP8[$134>>0] = $138;
     $140 = ((($1)) + 8|0);
     $141 = +HEAPF32[$140>>2];
     $142 = $141 * 255.0;
     $143 = (~~(($142))&255);
     $144 = ((($$0$i)) + 3|0);
     HEAP8[$139>>0] = $143;
     $$sink54$i38 = $144;$$sink56$i37 = 3;
     break L29;
     break;
    }
    default: {
     return;
    }
    }
   } else {
    $switch$split252D = ($117|0)<(32992);
    if ($switch$split252D) {
     switch ($117|0) {
     case 6409:  {
      label = 14;
      break L29;
      break;
     }
     case 6410:  {
      $118 = +HEAPF32[$1>>2];
      $119 = $118 * 255.0;
      $120 = (~~(($119))&255);
      $121 = ((($$0$i)) + 1|0);
      HEAP8[$$0$i>>0] = $120;
      $$sink54$i38 = $121;$$sink56$i37 = 3;
      break L29;
      break;
     }
     default: {
      return;
     }
     }
    }
    switch ($117|0) {
    case 32992:  {
     $145 = ((($1)) + 8|0);
     $146 = +HEAPF32[$145>>2];
     $147 = $146 * 255.0;
     $148 = (~~(($147))&255);
     $149 = ((($$0$i)) + 1|0);
     HEAP8[$$0$i>>0] = $148;
     $150 = ((($1)) + 4|0);
     $151 = +HEAPF32[$150>>2];
     $152 = $151 * 255.0;
     $153 = (~~(($152))&255);
     $154 = ((($$0$i)) + 2|0);
     HEAP8[$149>>0] = $153;
     $$sink54$i38 = $154;$$sink56$i37 = 0;
     break L29;
     break;
    }
    case 32993:  {
     $155 = ((($1)) + 8|0);
     $156 = +HEAPF32[$155>>2];
     $157 = $156 * 255.0;
     $158 = (~~(($157))&255);
     $159 = ((($$0$i)) + 1|0);
     HEAP8[$$0$i>>0] = $158;
     $160 = ((($1)) + 4|0);
     $161 = +HEAPF32[$160>>2];
     $162 = $161 * 255.0;
     $163 = (~~(($162))&255);
     $164 = ((($$0$i)) + 2|0);
     HEAP8[$159>>0] = $163;
     $165 = +HEAPF32[$1>>2];
     $166 = $165 * 255.0;
     $167 = (~~(($166))&255);
     $168 = ((($$0$i)) + 3|0);
     HEAP8[$164>>0] = $167;
     $$sink54$i38 = $168;$$sink56$i37 = 3;
     break L29;
     break;
    }
    default: {
     return;
    }
    }
   }
  } while(0);
  if ((label|0) == 14) {
   $$sink54$i38 = $$0$i;$$sink56$i37 = 0;
  }
  $169 = (($1) + ($$sink56$i37<<2)|0);
  $170 = +HEAPF32[$169>>2];
  $171 = $170 * 255.0;
  $172 = (~~(($171))&255);
  HEAP8[$$sink54$i38>>0] = $172;
  return;
  break;
 }
 case 5122:  {
  $173 = ((($0)) + 92|0);
  $174 = HEAP32[$173>>2]|0;
  $switch$split42D = ($174|0)<(6409);
  L51: do {
   if ($switch$split42D) {
    switch ($174|0) {
    case 6402:  {
     label = 22;
     break L51;
     break;
    }
    case 6406:  {
     $$sink54$i35 = $$0$i;$$sink56$i34 = 3;
     break L51;
     break;
    }
    case 6407:  {
     $179 = +HEAPF32[$1>>2];
     $180 = $179 * 32768.0;
     $181 = (~~(($180)));
     $182 = ((($$0$i)) + 2|0);
     HEAP16[$$0$i>>1] = $181;
     $183 = ((($1)) + 4|0);
     $184 = +HEAPF32[$183>>2];
     $185 = $184 * 32768.0;
     $186 = (~~(($185)));
     $187 = ((($$0$i)) + 4|0);
     HEAP16[$182>>1] = $186;
     $$sink54$i35 = $187;$$sink56$i34 = 2;
     break L51;
     break;
    }
    case 6408:  {
     $188 = +HEAPF32[$1>>2];
     $189 = $188 * 32768.0;
     $190 = (~~(($189)));
     $191 = ((($$0$i)) + 2|0);
     HEAP16[$$0$i>>1] = $190;
     $192 = ((($1)) + 4|0);
     $193 = +HEAPF32[$192>>2];
     $194 = $193 * 32768.0;
     $195 = (~~(($194)));
     $196 = ((($$0$i)) + 4|0);
     HEAP16[$191>>1] = $195;
     $197 = ((($1)) + 8|0);
     $198 = +HEAPF32[$197>>2];
     $199 = $198 * 32768.0;
     $200 = (~~(($199)));
     $201 = ((($$0$i)) + 6|0);
     HEAP16[$196>>1] = $200;
     $$sink54$i35 = $201;$$sink56$i34 = 3;
     break L51;
     break;
    }
    default: {
     return;
    }
    }
   } else {
    $switch$split282D = ($174|0)<(32992);
    if ($switch$split282D) {
     switch ($174|0) {
     case 6409:  {
      label = 22;
      break L51;
      break;
     }
     case 6410:  {
      $175 = +HEAPF32[$1>>2];
      $176 = $175 * 32768.0;
      $177 = (~~(($176)));
      $178 = ((($$0$i)) + 2|0);
      HEAP16[$$0$i>>1] = $177;
      $$sink54$i35 = $178;$$sink56$i34 = 3;
      break L51;
      break;
     }
     default: {
      return;
     }
     }
    }
    switch ($174|0) {
    case 32992:  {
     $202 = ((($1)) + 8|0);
     $203 = +HEAPF32[$202>>2];
     $204 = $203 * 32768.0;
     $205 = (~~(($204)));
     $206 = ((($$0$i)) + 2|0);
     HEAP16[$$0$i>>1] = $205;
     $207 = ((($1)) + 4|0);
     $208 = +HEAPF32[$207>>2];
     $209 = $208 * 32768.0;
     $210 = (~~(($209)));
     $211 = ((($$0$i)) + 4|0);
     HEAP16[$206>>1] = $210;
     $$sink54$i35 = $211;$$sink56$i34 = 0;
     break L51;
     break;
    }
    case 32993:  {
     $212 = ((($1)) + 8|0);
     $213 = +HEAPF32[$212>>2];
     $214 = $213 * 32768.0;
     $215 = (~~(($214)));
     $216 = ((($$0$i)) + 2|0);
     HEAP16[$$0$i>>1] = $215;
     $217 = ((($1)) + 4|0);
     $218 = +HEAPF32[$217>>2];
     $219 = $218 * 32768.0;
     $220 = (~~(($219)));
     $221 = ((($$0$i)) + 4|0);
     HEAP16[$216>>1] = $220;
     $222 = +HEAPF32[$1>>2];
     $223 = $222 * 32768.0;
     $224 = (~~(($223)));
     $225 = ((($$0$i)) + 6|0);
     HEAP16[$221>>1] = $224;
     $$sink54$i35 = $225;$$sink56$i34 = 3;
     break L51;
     break;
    }
    default: {
     return;
    }
    }
   }
  } while(0);
  if ((label|0) == 22) {
   $$sink54$i35 = $$0$i;$$sink56$i34 = 0;
  }
  $226 = (($1) + ($$sink56$i34<<2)|0);
  $227 = +HEAPF32[$226>>2];
  $228 = $227 * 32768.0;
  $229 = (~~(($228)));
  HEAP16[$$sink54$i35>>1] = $229;
  return;
  break;
 }
 case 5123:  {
  $230 = ((($0)) + 92|0);
  $231 = HEAP32[$230>>2]|0;
  $switch$split72D = ($231|0)<(6409);
  L73: do {
   if ($switch$split72D) {
    switch ($231|0) {
    case 6402:  {
     label = 30;
     break L73;
     break;
    }
    case 6406:  {
     $$sink54$i32 = $$0$i;$$sink56$i31 = 3;
     break L73;
     break;
    }
    case 6407:  {
     $236 = +HEAPF32[$1>>2];
     $237 = $236 * 65535.0;
     $238 = (~~(($237))&65535);
     $239 = ((($$0$i)) + 2|0);
     HEAP16[$$0$i>>1] = $238;
     $240 = ((($1)) + 4|0);
     $241 = +HEAPF32[$240>>2];
     $242 = $241 * 65535.0;
     $243 = (~~(($242))&65535);
     $244 = ((($$0$i)) + 4|0);
     HEAP16[$239>>1] = $243;
     $$sink54$i32 = $244;$$sink56$i31 = 2;
     break L73;
     break;
    }
    case 6408:  {
     $245 = +HEAPF32[$1>>2];
     $246 = $245 * 65535.0;
     $247 = (~~(($246))&65535);
     $248 = ((($$0$i)) + 2|0);
     HEAP16[$$0$i>>1] = $247;
     $249 = ((($1)) + 4|0);
     $250 = +HEAPF32[$249>>2];
     $251 = $250 * 65535.0;
     $252 = (~~(($251))&65535);
     $253 = ((($$0$i)) + 4|0);
     HEAP16[$248>>1] = $252;
     $254 = ((($1)) + 8|0);
     $255 = +HEAPF32[$254>>2];
     $256 = $255 * 65535.0;
     $257 = (~~(($256))&65535);
     $258 = ((($$0$i)) + 6|0);
     HEAP16[$253>>1] = $257;
     $$sink54$i32 = $258;$$sink56$i31 = 3;
     break L73;
     break;
    }
    default: {
     return;
    }
    }
   } else {
    $switch$split312D = ($231|0)<(32992);
    if ($switch$split312D) {
     switch ($231|0) {
     case 6409:  {
      label = 30;
      break L73;
      break;
     }
     case 6410:  {
      $232 = +HEAPF32[$1>>2];
      $233 = $232 * 65535.0;
      $234 = (~~(($233))&65535);
      $235 = ((($$0$i)) + 2|0);
      HEAP16[$$0$i>>1] = $234;
      $$sink54$i32 = $235;$$sink56$i31 = 3;
      break L73;
      break;
     }
     default: {
      return;
     }
     }
    }
    switch ($231|0) {
    case 32992:  {
     $259 = ((($1)) + 8|0);
     $260 = +HEAPF32[$259>>2];
     $261 = $260 * 65535.0;
     $262 = (~~(($261))&65535);
     $263 = ((($$0$i)) + 2|0);
     HEAP16[$$0$i>>1] = $262;
     $264 = ((($1)) + 4|0);
     $265 = +HEAPF32[$264>>2];
     $266 = $265 * 65535.0;
     $267 = (~~(($266))&65535);
     $268 = ((($$0$i)) + 4|0);
     HEAP16[$263>>1] = $267;
     $$sink54$i32 = $268;$$sink56$i31 = 0;
     break L73;
     break;
    }
    case 32993:  {
     $269 = ((($1)) + 8|0);
     $270 = +HEAPF32[$269>>2];
     $271 = $270 * 65535.0;
     $272 = (~~(($271))&65535);
     $273 = ((($$0$i)) + 2|0);
     HEAP16[$$0$i>>1] = $272;
     $274 = ((($1)) + 4|0);
     $275 = +HEAPF32[$274>>2];
     $276 = $275 * 65535.0;
     $277 = (~~(($276))&65535);
     $278 = ((($$0$i)) + 4|0);
     HEAP16[$273>>1] = $277;
     $279 = +HEAPF32[$1>>2];
     $280 = $279 * 65535.0;
     $281 = (~~(($280))&65535);
     $282 = ((($$0$i)) + 6|0);
     HEAP16[$278>>1] = $281;
     $$sink54$i32 = $282;$$sink56$i31 = 3;
     break L73;
     break;
    }
    default: {
     return;
    }
    }
   }
  } while(0);
  if ((label|0) == 30) {
   $$sink54$i32 = $$0$i;$$sink56$i31 = 0;
  }
  $283 = (($1) + ($$sink56$i31<<2)|0);
  $284 = +HEAPF32[$283>>2];
  $285 = $284 * 65535.0;
  $286 = (~~(($285))&65535);
  HEAP16[$$sink54$i32>>1] = $286;
  return;
  break;
 }
 case 5124:  {
  $287 = ((($0)) + 92|0);
  $288 = HEAP32[$287>>2]|0;
  $switch$split102D = ($288|0)<(6409);
  L95: do {
   if ($switch$split102D) {
    switch ($288|0) {
    case 6402:  {
     label = 38;
     break L95;
     break;
    }
    case 6406:  {
     $$sink54$i29 = $$0$i;$$sink56$i28 = 3;
     break L95;
     break;
    }
    case 6407:  {
     $293 = +HEAPF32[$1>>2];
     $294 = $293 * 2147483648.0;
     $295 = (~~(($294)));
     $296 = ((($$0$i)) + 4|0);
     HEAP32[$$0$i>>2] = $295;
     $297 = ((($1)) + 4|0);
     $298 = +HEAPF32[$297>>2];
     $299 = $298 * 2147483648.0;
     $300 = (~~(($299)));
     $301 = ((($$0$i)) + 8|0);
     HEAP32[$296>>2] = $300;
     $$sink54$i29 = $301;$$sink56$i28 = 2;
     break L95;
     break;
    }
    case 6408:  {
     $302 = +HEAPF32[$1>>2];
     $303 = $302 * 2147483648.0;
     $304 = (~~(($303)));
     $305 = ((($$0$i)) + 4|0);
     HEAP32[$$0$i>>2] = $304;
     $306 = ((($1)) + 4|0);
     $307 = +HEAPF32[$306>>2];
     $308 = $307 * 2147483648.0;
     $309 = (~~(($308)));
     $310 = ((($$0$i)) + 8|0);
     HEAP32[$305>>2] = $309;
     $311 = ((($1)) + 8|0);
     $312 = +HEAPF32[$311>>2];
     $313 = $312 * 2147483648.0;
     $314 = (~~(($313)));
     $315 = ((($$0$i)) + 12|0);
     HEAP32[$310>>2] = $314;
     $$sink54$i29 = $315;$$sink56$i28 = 3;
     break L95;
     break;
    }
    default: {
     return;
    }
    }
   } else {
    $switch$split342D = ($288|0)<(32992);
    if ($switch$split342D) {
     switch ($288|0) {
     case 6409:  {
      label = 38;
      break L95;
      break;
     }
     case 6410:  {
      $289 = +HEAPF32[$1>>2];
      $290 = $289 * 2147483648.0;
      $291 = (~~(($290)));
      $292 = ((($$0$i)) + 4|0);
      HEAP32[$$0$i>>2] = $291;
      $$sink54$i29 = $292;$$sink56$i28 = 3;
      break L95;
      break;
     }
     default: {
      return;
     }
     }
    }
    switch ($288|0) {
    case 32992:  {
     $316 = ((($1)) + 8|0);
     $317 = +HEAPF32[$316>>2];
     $318 = $317 * 2147483648.0;
     $319 = (~~(($318)));
     $320 = ((($$0$i)) + 4|0);
     HEAP32[$$0$i>>2] = $319;
     $321 = ((($1)) + 4|0);
     $322 = +HEAPF32[$321>>2];
     $323 = $322 * 2147483648.0;
     $324 = (~~(($323)));
     $325 = ((($$0$i)) + 8|0);
     HEAP32[$320>>2] = $324;
     $$sink54$i29 = $325;$$sink56$i28 = 0;
     break L95;
     break;
    }
    case 32993:  {
     $326 = ((($1)) + 8|0);
     $327 = +HEAPF32[$326>>2];
     $328 = $327 * 2147483648.0;
     $329 = (~~(($328)));
     $330 = ((($$0$i)) + 4|0);
     HEAP32[$$0$i>>2] = $329;
     $331 = ((($1)) + 4|0);
     $332 = +HEAPF32[$331>>2];
     $333 = $332 * 2147483648.0;
     $334 = (~~(($333)));
     $335 = ((($$0$i)) + 8|0);
     HEAP32[$330>>2] = $334;
     $336 = +HEAPF32[$1>>2];
     $337 = $336 * 2147483648.0;
     $338 = (~~(($337)));
     $339 = ((($$0$i)) + 12|0);
     HEAP32[$335>>2] = $338;
     $$sink54$i29 = $339;$$sink56$i28 = 3;
     break L95;
     break;
    }
    default: {
     return;
    }
    }
   }
  } while(0);
  if ((label|0) == 38) {
   $$sink54$i29 = $$0$i;$$sink56$i28 = 0;
  }
  $340 = (($1) + ($$sink56$i28<<2)|0);
  $341 = +HEAPF32[$340>>2];
  $342 = $341 * 2147483648.0;
  $343 = (~~(($342)));
  HEAP32[$$sink54$i29>>2] = $343;
  return;
  break;
 }
 case 5125:  {
  $344 = ((($0)) + 92|0);
  $345 = HEAP32[$344>>2]|0;
  $switch$split132D = ($345|0)<(6409);
  L117: do {
   if ($switch$split132D) {
    switch ($345|0) {
    case 6402:  {
     label = 46;
     break L117;
     break;
    }
    case 6406:  {
     $$sink54$i26 = $$0$i;$$sink56$i25 = 3;
     break L117;
     break;
    }
    case 6407:  {
     $350 = +HEAPF32[$1>>2];
     $351 = $350 * 4294967296.0;
     $352 = (~~(($351))>>>0);
     $353 = ((($$0$i)) + 4|0);
     HEAP32[$$0$i>>2] = $352;
     $354 = ((($1)) + 4|0);
     $355 = +HEAPF32[$354>>2];
     $356 = $355 * 4294967296.0;
     $357 = (~~(($356))>>>0);
     $358 = ((($$0$i)) + 8|0);
     HEAP32[$353>>2] = $357;
     $$sink54$i26 = $358;$$sink56$i25 = 2;
     break L117;
     break;
    }
    case 6408:  {
     $359 = +HEAPF32[$1>>2];
     $360 = $359 * 4294967296.0;
     $361 = (~~(($360))>>>0);
     $362 = ((($$0$i)) + 4|0);
     HEAP32[$$0$i>>2] = $361;
     $363 = ((($1)) + 4|0);
     $364 = +HEAPF32[$363>>2];
     $365 = $364 * 4294967296.0;
     $366 = (~~(($365))>>>0);
     $367 = ((($$0$i)) + 8|0);
     HEAP32[$362>>2] = $366;
     $368 = ((($1)) + 8|0);
     $369 = +HEAPF32[$368>>2];
     $370 = $369 * 4294967296.0;
     $371 = (~~(($370))>>>0);
     $372 = ((($$0$i)) + 12|0);
     HEAP32[$367>>2] = $371;
     $$sink54$i26 = $372;$$sink56$i25 = 3;
     break L117;
     break;
    }
    default: {
     return;
    }
    }
   } else {
    $switch$split372D = ($345|0)<(32992);
    if ($switch$split372D) {
     switch ($345|0) {
     case 6409:  {
      label = 46;
      break L117;
      break;
     }
     case 6410:  {
      $346 = +HEAPF32[$1>>2];
      $347 = $346 * 4294967296.0;
      $348 = (~~(($347))>>>0);
      $349 = ((($$0$i)) + 4|0);
      HEAP32[$$0$i>>2] = $348;
      $$sink54$i26 = $349;$$sink56$i25 = 3;
      break L117;
      break;
     }
     default: {
      return;
     }
     }
    }
    switch ($345|0) {
    case 32992:  {
     $373 = ((($1)) + 8|0);
     $374 = +HEAPF32[$373>>2];
     $375 = $374 * 4294967296.0;
     $376 = (~~(($375))>>>0);
     $377 = ((($$0$i)) + 4|0);
     HEAP32[$$0$i>>2] = $376;
     $378 = ((($1)) + 4|0);
     $379 = +HEAPF32[$378>>2];
     $380 = $379 * 4294967296.0;
     $381 = (~~(($380))>>>0);
     $382 = ((($$0$i)) + 8|0);
     HEAP32[$377>>2] = $381;
     $$sink54$i26 = $382;$$sink56$i25 = 0;
     break L117;
     break;
    }
    case 32993:  {
     $383 = ((($1)) + 8|0);
     $384 = +HEAPF32[$383>>2];
     $385 = $384 * 4294967296.0;
     $386 = (~~(($385))>>>0);
     $387 = ((($$0$i)) + 4|0);
     HEAP32[$$0$i>>2] = $386;
     $388 = ((($1)) + 4|0);
     $389 = +HEAPF32[$388>>2];
     $390 = $389 * 4294967296.0;
     $391 = (~~(($390))>>>0);
     $392 = ((($$0$i)) + 8|0);
     HEAP32[$387>>2] = $391;
     $393 = +HEAPF32[$1>>2];
     $394 = $393 * 4294967296.0;
     $395 = (~~(($394))>>>0);
     $396 = ((($$0$i)) + 12|0);
     HEAP32[$392>>2] = $395;
     $$sink54$i26 = $396;$$sink56$i25 = 3;
     break L117;
     break;
    }
    default: {
     return;
    }
    }
   }
  } while(0);
  if ((label|0) == 46) {
   $$sink54$i26 = $$0$i;$$sink56$i25 = 0;
  }
  $397 = (($1) + ($$sink56$i25<<2)|0);
  $398 = +HEAPF32[$397>>2];
  $399 = $398 * 4294967296.0;
  $400 = (~~(($399))>>>0);
  HEAP32[$$sink54$i26>>2] = $400;
  return;
  break;
 }
 case 5126:  {
  $401 = ((($0)) + 92|0);
  $402 = HEAP32[$401>>2]|0;
  $switch$split162D = ($402|0)<(6409);
  L139: do {
   if ($switch$split162D) {
    switch ($402|0) {
    case 6402:  {
     label = 54;
     break L139;
     break;
    }
    case 6406:  {
     $$sink$i = 3;$$sink54$i23 = $$0$i;
     break L139;
     break;
    }
    case 6407:  {
     $405 = HEAP32[$1>>2]|0;
     $406 = ((($$0$i)) + 4|0);
     HEAP32[$$0$i>>2] = $405;
     $407 = ((($1)) + 4|0);
     $408 = HEAP32[$407>>2]|0;
     $409 = ((($$0$i)) + 8|0);
     HEAP32[$406>>2] = $408;
     $$sink$i = 2;$$sink54$i23 = $409;
     break L139;
     break;
    }
    case 6408:  {
     $410 = HEAP32[$1>>2]|0;
     $411 = ((($$0$i)) + 4|0);
     HEAP32[$$0$i>>2] = $410;
     $412 = ((($1)) + 4|0);
     $413 = HEAP32[$412>>2]|0;
     $414 = ((($$0$i)) + 8|0);
     HEAP32[$411>>2] = $413;
     $415 = ((($1)) + 8|0);
     $416 = HEAP32[$415>>2]|0;
     $417 = ((($$0$i)) + 12|0);
     HEAP32[$414>>2] = $416;
     $$sink$i = 3;$$sink54$i23 = $417;
     break L139;
     break;
    }
    default: {
     return;
    }
    }
   } else {
    $switch$split402D = ($402|0)<(32992);
    if ($switch$split402D) {
     switch ($402|0) {
     case 6409:  {
      label = 54;
      break L139;
      break;
     }
     case 6410:  {
      $403 = HEAP32[$1>>2]|0;
      $404 = ((($$0$i)) + 4|0);
      HEAP32[$$0$i>>2] = $403;
      $$sink$i = 3;$$sink54$i23 = $404;
      break L139;
      break;
     }
     default: {
      return;
     }
     }
    }
    switch ($402|0) {
    case 32992:  {
     $418 = ((($1)) + 8|0);
     $419 = HEAP32[$418>>2]|0;
     $420 = ((($$0$i)) + 4|0);
     HEAP32[$$0$i>>2] = $419;
     $421 = ((($1)) + 4|0);
     $422 = HEAP32[$421>>2]|0;
     $423 = ((($$0$i)) + 8|0);
     HEAP32[$420>>2] = $422;
     $$sink$i = 0;$$sink54$i23 = $423;
     break L139;
     break;
    }
    case 32993:  {
     $424 = ((($1)) + 8|0);
     $425 = HEAP32[$424>>2]|0;
     $426 = ((($$0$i)) + 4|0);
     HEAP32[$$0$i>>2] = $425;
     $427 = ((($1)) + 4|0);
     $428 = HEAP32[$427>>2]|0;
     $429 = ((($$0$i)) + 8|0);
     HEAP32[$426>>2] = $428;
     $430 = HEAP32[$1>>2]|0;
     $431 = ((($$0$i)) + 12|0);
     HEAP32[$429>>2] = $430;
     $$sink$i = 3;$$sink54$i23 = $431;
     break L139;
     break;
    }
    default: {
     return;
    }
    }
   }
  } while(0);
  if ((label|0) == 54) {
   $$sink$i = 0;$$sink54$i23 = $$0$i;
  }
  $432 = (($1) + ($$sink$i<<2)|0);
  $433 = HEAP32[$432>>2]|0;
  HEAP32[$$sink54$i23>>2] = $433;
  return;
  break;
 }
 case 5130:  {
  $434 = ((($0)) + 92|0);
  $435 = HEAP32[$434>>2]|0;
  $switch$split192D = ($435|0)<(6409);
  L161: do {
   if ($switch$split192D) {
    switch ($435|0) {
    case 6402:  {
     label = 62;
     break L161;
     break;
    }
    case 6406:  {
     $$sink54$i21 = $$0$i;$$sink56$i20 = 3;
     break L161;
     break;
    }
    case 6407:  {
     $439 = +HEAPF32[$1>>2];
     $440 = $439;
     $441 = ((($$0$i)) + 8|0);
     HEAPF64[$$0$i>>3] = $440;
     $442 = ((($1)) + 4|0);
     $443 = +HEAPF32[$442>>2];
     $444 = $443;
     $445 = ((($$0$i)) + 16|0);
     HEAPF64[$441>>3] = $444;
     $$sink54$i21 = $445;$$sink56$i20 = 2;
     break L161;
     break;
    }
    case 6408:  {
     $446 = +HEAPF32[$1>>2];
     $447 = $446;
     $448 = ((($$0$i)) + 8|0);
     HEAPF64[$$0$i>>3] = $447;
     $449 = ((($1)) + 4|0);
     $450 = +HEAPF32[$449>>2];
     $451 = $450;
     $452 = ((($$0$i)) + 16|0);
     HEAPF64[$448>>3] = $451;
     $453 = ((($1)) + 8|0);
     $454 = +HEAPF32[$453>>2];
     $455 = $454;
     $456 = ((($$0$i)) + 24|0);
     HEAPF64[$452>>3] = $455;
     $$sink54$i21 = $456;$$sink56$i20 = 3;
     break L161;
     break;
    }
    default: {
     return;
    }
    }
   } else {
    $switch$split432D = ($435|0)<(32992);
    if ($switch$split432D) {
     switch ($435|0) {
     case 6409:  {
      label = 62;
      break L161;
      break;
     }
     case 6410:  {
      $436 = +HEAPF32[$1>>2];
      $437 = $436;
      $438 = ((($$0$i)) + 8|0);
      HEAPF64[$$0$i>>3] = $437;
      $$sink54$i21 = $438;$$sink56$i20 = 3;
      break L161;
      break;
     }
     default: {
      return;
     }
     }
    }
    switch ($435|0) {
    case 32992:  {
     $457 = ((($1)) + 8|0);
     $458 = +HEAPF32[$457>>2];
     $459 = $458;
     $460 = ((($$0$i)) + 8|0);
     HEAPF64[$$0$i>>3] = $459;
     $461 = ((($1)) + 4|0);
     $462 = +HEAPF32[$461>>2];
     $463 = $462;
     $464 = ((($$0$i)) + 16|0);
     HEAPF64[$460>>3] = $463;
     $$sink54$i21 = $464;$$sink56$i20 = 0;
     break L161;
     break;
    }
    case 32993:  {
     $465 = ((($1)) + 8|0);
     $466 = +HEAPF32[$465>>2];
     $467 = $466;
     $468 = ((($$0$i)) + 8|0);
     HEAPF64[$$0$i>>3] = $467;
     $469 = ((($1)) + 4|0);
     $470 = +HEAPF32[$469>>2];
     $471 = $470;
     $472 = ((($$0$i)) + 16|0);
     HEAPF64[$468>>3] = $471;
     $473 = +HEAPF32[$1>>2];
     $474 = $473;
     $475 = ((($$0$i)) + 24|0);
     HEAPF64[$472>>3] = $474;
     $$sink54$i21 = $475;$$sink56$i20 = 3;
     break L161;
     break;
    }
    default: {
     return;
    }
    }
   }
  } while(0);
  if ((label|0) == 62) {
   $$sink54$i21 = $$0$i;$$sink56$i20 = 0;
  }
  $476 = (($1) + ($$sink56$i20<<2)|0);
  $477 = +HEAPF32[$476>>2];
  $478 = $477;
  HEAPF64[$$sink54$i21>>3] = $478;
  return;
  break;
 }
 default: {
  return;
 }
 }
}
function __ZN3osg6KdTreeD2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i5 = 0, $scevgep$i$i$i8 = 0, $scevgep5$i$i$i = 0, $scevgep5$i$i$i6 = 0, $scevgep5$i$i$i9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (62196);
 $1 = ((($0)) + 64|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = ((($0)) + 68|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==($2|0);
  if (!($6)) {
   $scevgep$i$i$i = ((($5)) + -32|0);
   $7 = $scevgep$i$i$i;
   $8 = $2;
   $9 = (($7) - ($8))|0;
   $10 = $9 >>> 5;
   $11 = $10 ^ -1;
   $scevgep5$i$i$i = (($5) + ($11<<5)|0);
   HEAP32[$4>>2] = $scevgep5$i$i$i;
  }
  __ZdlPv($2);
 }
 $12 = ((($0)) + 52|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0|0);
 if (!($14)) {
  $15 = ((($0)) + 56|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($16|0)==($13|0);
  if (!($17)) {
   $scevgep$i$i$i5 = ((($16)) + -4|0);
   $18 = $scevgep$i$i$i5;
   $19 = $13;
   $20 = (($18) - ($19))|0;
   $21 = $20 >>> 2;
   $22 = $21 ^ -1;
   $scevgep5$i$i$i6 = (($16) + ($22<<2)|0);
   HEAP32[$15>>2] = $scevgep5$i$i$i6;
  }
  __ZdlPv($13);
 }
 $23 = ((($0)) + 40|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)==(0|0);
 if (!($25)) {
  $26 = ((($0)) + 44|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = ($27|0)==($24|0);
  if (!($28)) {
   $scevgep$i$i$i8 = ((($27)) + -4|0);
   $29 = $scevgep$i$i$i8;
   $30 = $24;
   $31 = (($29) - ($30))|0;
   $32 = $31 >>> 2;
   $33 = $32 ^ -1;
   $scevgep5$i$i$i9 = (($27) + ($33<<2)|0);
   HEAP32[$26>>2] = $scevgep5$i$i$i9;
  }
  __ZdlPv($24);
 }
 $34 = ((($0)) + 36|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = ($35|0)==(0|0);
 if ($36) {
  HEAP32[$34>>2] = 0;
  __ZN3osg5ShapeD2Ev($0);
  return;
 }
 $37 = ((($35)) + 8|0);
 $38 = HEAP32[$37>>2]|0;HEAP32[$37>>2] = (($38-1)|0);
 $39 = ($38|0)==(1);
 if (!($39)) {
  HEAP32[$34>>2] = 0;
  __ZN3osg5ShapeD2Ev($0);
  return;
 }
 __THREW__ = 0;
 invoke_viii(3262,($35|0),1,1);
 $40 = __THREW__; __THREW__ = 0;
 $41 = $40&1;
 if (!($41)) {
  HEAP32[$34>>2] = 0;
  __ZN3osg5ShapeD2Ev($0);
  return;
 }
 $42 = ___cxa_find_matching_catch_2()|0;
 $43 = tempRet0;
 __THREW__ = 0;
 invoke_vi(2239,($0|0));
 $44 = __THREW__; __THREW__ = 0;
 $45 = $44&1;
 if ($45) {
  $46 = ___cxa_find_matching_catch_3(0|0)|0;
  $47 = tempRet0;
  ___clang_call_terminate($46);
  // unreachable;
 } else {
  ___resumeException($42|0);
  // unreachable;
 }
}
function __ZN3osg6KdTreeD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1993,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK3osg6KdTree9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $1 = (__Znwj(76)|0);
 __THREW__ = 0;
 invoke_vi(3282,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $8 = ___cxa_find_matching_catch_2()|0;
  $9 = tempRet0;
  __ZdlPv($1);
  ___resumeException($8|0);
  // unreachable;
 } else {
  $4 = ((($1)) + 12|0);
  ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;
  $5 = ((($1)) + 24|0);
  HEAP32[$5>>2] = 2;
  $6 = ((($1)) + 28|0);
  HEAP32[$6>>2] = 0;
  HEAP32[$1>>2] = (62196);
  $7 = ((($1)) + 32|0);
  dest=$7; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
  return ($1|0);
 }
 return (0)|0;
}
function __ZNK3osg6KdTree5cloneERKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(76)|0);
 __THREW__ = 0;
 invoke_viii(3823,($2|0),($0|0),($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch_2()|0;
  $6 = tempRet0;
  __ZdlPv($2);
  ___resumeException($5|0);
  // unreachable;
 } else {
  return ($2|0);
 }
 return (0)|0;
}
function __ZNK3osg6KdTree12isSameKindAsEPKNS_6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,25368,0)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK3osg6KdTree11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175113|0);
}
function __ZNK3osg6KdTree9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (145172|0);
}
function __ZN3osg6KdTree6acceptERNS_12ShapeVisitorE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 8191]($1,$0);
 return;
}
function __ZNK3osg6KdTree6acceptERNS_17ConstShapeVisitorE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 8191]($1,$0);
 return;
}
function __ZN3osg6KdTree5buildERNS0_12BuildOptionsEPNS_8GeometryE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i$i$i4 = 0, $scevgep$i$i$i3$i = 0;
 var $scevgep$i$i$i3$i9 = 0, $scevgep$i$i$i6$i = 0, $scevgep$i$i$i6$i14 = 0, $scevgep5$i$i$i$i = 0, $scevgep5$i$i$i$i5 = 0, $scevgep5$i$i$i4$i = 0, $scevgep5$i$i$i4$i10 = 0, $scevgep5$i$i$i7$i = 0, $scevgep5$i$i$i7$i15 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(64|0);
 $3 = sp;
 HEAP32[$3>>2] = $0;
 $4 = ((($3)) + 4|0);
 HEAPF32[$4>>2] = 3.4028234663852886E+38;
 $5 = ((($3)) + 8|0);
 HEAPF32[$5>>2] = 3.4028234663852886E+38;
 $6 = ((($3)) + 12|0);
 HEAPF32[$6>>2] = 3.4028234663852886E+38;
 $7 = ((($3)) + 16|0);
 HEAPF32[$7>>2] = -3.4028234663852886E+38;
 $8 = ((($3)) + 20|0);
 HEAPF32[$8>>2] = -3.4028234663852886E+38;
 $9 = ((($3)) + 24|0);
 HEAPF32[$9>>2] = -3.4028234663852886E+38;
 $10 = ((($3)) + 28|0);
 dest=$10; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 __THREW__ = 0;
 $11 = (invoke_iiii(3824,($3|0),($1|0),($2|0))|0);
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $46 = ___cxa_find_matching_catch_2()|0;
  $47 = tempRet0;
  $48 = ((($3)) + 52|0);
  $49 = HEAP32[$48>>2]|0;
  $50 = ($49|0)==(0|0);
  if (!($50)) {
   $51 = ((($3)) + 56|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = ($52|0)==($49|0);
   if (!($53)) {
    $scevgep$i$i$i$i4 = ((($52)) + -12|0);
    $54 = $scevgep$i$i$i$i4;
    $55 = $49;
    $56 = (($54) - ($55))|0;
    $57 = (($56>>>0) / 12)&-1;
    $58 = $57 ^ -1;
    $scevgep5$i$i$i$i5 = (($52) + (($58*12)|0)|0);
    HEAP32[$51>>2] = $scevgep5$i$i$i$i5;
   }
   __ZdlPv($49);
  }
  $59 = ((($3)) + 40|0);
  $60 = HEAP32[$59>>2]|0;
  $61 = ($60|0)==(0|0);
  if (!($61)) {
   $62 = ((($3)) + 44|0);
   $63 = HEAP32[$62>>2]|0;
   $64 = ($63|0)==($60|0);
   if (!($64)) {
    $scevgep$i$i$i3$i9 = ((($63)) + -4|0);
    $65 = $scevgep$i$i$i3$i9;
    $66 = $60;
    $67 = (($65) - ($66))|0;
    $68 = $67 >>> 2;
    $69 = $68 ^ -1;
    $scevgep5$i$i$i4$i10 = (($63) + ($69<<2)|0);
    HEAP32[$62>>2] = $scevgep5$i$i$i4$i10;
   }
   __ZdlPv($60);
  }
  $70 = HEAP32[$10>>2]|0;
  $71 = ($70|0)==(0|0);
  if ($71) {
   ___resumeException($46|0);
   // unreachable;
  }
  $72 = ((($3)) + 32|0);
  $73 = HEAP32[$72>>2]|0;
  $74 = ($73|0)==($70|0);
  if (!($74)) {
   $scevgep$i$i$i6$i14 = ((($73)) + -4|0);
   $75 = $scevgep$i$i$i6$i14;
   $76 = $70;
   $77 = (($75) - ($76))|0;
   $78 = $77 >>> 2;
   $79 = $78 ^ -1;
   $scevgep5$i$i$i7$i15 = (($73) + ($79<<2)|0);
   HEAP32[$72>>2] = $scevgep5$i$i$i7$i15;
  }
  __ZdlPv($70);
  ___resumeException($46|0);
  // unreachable;
 } else {
  $14 = ((($3)) + 52|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = ($15|0)==(0|0);
  if (!($16)) {
   $17 = ((($3)) + 56|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = ($18|0)==($15|0);
   if (!($19)) {
    $scevgep$i$i$i$i = ((($18)) + -12|0);
    $20 = $scevgep$i$i$i$i;
    $21 = $15;
    $22 = (($20) - ($21))|0;
    $23 = (($22>>>0) / 12)&-1;
    $24 = $23 ^ -1;
    $scevgep5$i$i$i$i = (($18) + (($24*12)|0)|0);
    HEAP32[$17>>2] = $scevgep5$i$i$i$i;
   }
   __ZdlPv($15);
  }
  $25 = ((($3)) + 40|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = ($26|0)==(0|0);
  if (!($27)) {
   $28 = ((($3)) + 44|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = ($29|0)==($26|0);
   if (!($30)) {
    $scevgep$i$i$i3$i = ((($29)) + -4|0);
    $31 = $scevgep$i$i$i3$i;
    $32 = $26;
    $33 = (($31) - ($32))|0;
    $34 = $33 >>> 2;
    $35 = $34 ^ -1;
    $scevgep5$i$i$i4$i = (($29) + ($35<<2)|0);
    HEAP32[$28>>2] = $scevgep5$i$i$i4$i;
   }
   __ZdlPv($26);
  }
  $36 = HEAP32[$10>>2]|0;
  $37 = ($36|0)==(0|0);
  if ($37) {
   STACKTOP = sp;return ($11|0);
  }
  $38 = ((($3)) + 32|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = ($39|0)==($36|0);
  if (!($40)) {
   $scevgep$i$i$i6$i = ((($39)) + -4|0);
   $41 = $scevgep$i$i$i6$i;
   $42 = $36;
   $43 = (($41) - ($42))|0;
   $44 = $43 >>> 2;
   $45 = $44 ^ -1;
   $scevgep5$i$i$i7$i = (($39) + ($45<<2)|0);
   HEAP32[$38>>2] = $scevgep5$i$i$i7$i;
  }
  __ZdlPv($36);
  STACKTOP = sp;return ($11|0);
 }
 return (0)|0;
}
function __ZN11BuildKdTree5buildERN3osg6KdTree12BuildOptionsEPNS0_8GeometryE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$0915$i = 0, $$10$i = 0, $$3 = 0, $$342 = 0, $$4 = 0, $$443 = 0, $$5 = 0, $$544 = 0, $$cast$i = 0, $$pre = 0, $$pre$i = 0.0, $$pre$phiZ2D = 0, $$pre16$i = 0.0, $$pre17$i = 0.0, $$pre59 = 0, $$sink14$i = 0, $$sroa$052$058 = 0, $10 = 0, $100 = 0;
 var $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0;
 var $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0;
 var $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0;
 var $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0;
 var $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0;
 var $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0.0, $4 = 0, $40 = 0.0, $41 = 0.0, $42 = 0, $43 = 0.0, $44 = 0.0, $45 = 0.0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0.0, $52 = 0, $53 = 0.0, $54 = 0.0, $55 = 0, $56 = 0.0, $57 = 0, $58 = 0.0, $59 = 0.0, $6 = 0, $60 = 0, $61 = 0.0, $62 = 0, $63 = 0.0;
 var $64 = 0.0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0.0, $76 = 0.0, $77 = 0, $78 = 0.0, $79 = 0, $8 = 0, $80 = 0.0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0.0, $87 = 0.0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $scevgep$i$i$i = 0;
 var $scevgep$i$i$i45 = 0, $scevgep5$i$i$i = 0, $scevgep5$i$i$i46 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(96|0);
 $3 = sp + 84|0;
 $4 = sp + 80|0;
 $5 = sp + 72|0;
 $6 = sp + 40|0;
 $7 = sp + 16|0;
 $8 = sp;
 $9 = ((($2)) + 228|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $12 = (___dynamic_cast($10,23016,5496,0)|0);
 $13 = ($12|0)==(0|0);
 if ($13) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $14 = ((($12)) + 76|0);
 $15 = ((($12)) + 80|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = HEAP32[$14>>2]|0;
 $18 = (($16) - ($17))|0;
 $19 = (($18|0) / 12)&-1;
 $20 = ((($1)) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($19>>>0)>($21>>>0);
 if (!($22)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $23 = (__ZNK3osg8Drawable14getBoundingBoxEv($2)|0);
 $24 = ((($0)) + 4|0);
 ;HEAP32[$24>>2]=HEAP32[$23>>2]|0;HEAP32[$24+4>>2]=HEAP32[$23+4>>2]|0;HEAP32[$24+8>>2]=HEAP32[$23+8>>2]|0;HEAP32[$24+12>>2]=HEAP32[$23+12>>2]|0;HEAP32[$24+16>>2]=HEAP32[$23+16>>2]|0;HEAP32[$24+20>>2]=HEAP32[$23+20>>2]|0;
 $25 = HEAP32[$0>>2]|0;
 $26 = ((($25)) + 36|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ($27|0)==($12|0);
 if (!($28)) {
  HEAP32[$26>>2] = $12;
  $29 = ((($12)) + 8|0);
  $30 = HEAP32[$29>>2]|0;HEAP32[$29>>2] = (($30+1)|0);
  $31 = ($27|0)==(0|0);
  if (!($31)) {
   $32 = ((($27)) + 8|0);
   $33 = HEAP32[$32>>2]|0;HEAP32[$32>>2] = (($33-1)|0);
   $34 = ($33|0)==(1);
   if ($34) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($27,1,1);
   }
  }
 }
 $35 = HEAP32[$15>>2]|0;
 $36 = HEAP32[$14>>2]|0;
 $37 = (($35) - ($36))|0;
 $38 = (($37|0) / 12)&-1;
 $39 = (+($38>>>0));
 $40 = $39;
 $41 = $40 * 2.0;
 $42 = HEAP32[$20>>2]|0;
 $43 = (+($42>>>0));
 $44 = $43;
 $45 = $41 / $44;
 $46 = (~~(($45))>>>0);
 $47 = HEAP32[$0>>2]|0;
 $48 = ((($47)) + 64|0);
 $49 = ($46*5)|0;
 __ZNSt3__26vectorIN3osg6KdTree6KdNodeENS_9allocatorIS3_EEE7reserveEj($48,$49);
 $50 = ((($0)) + 16|0);
 $51 = +HEAPF32[$50>>2];
 $52 = ((($0)) + 4|0);
 $53 = +HEAPF32[$52>>2];
 $54 = $51 - $53;
 $55 = ((($0)) + 20|0);
 $56 = +HEAPF32[$55>>2];
 $57 = ((($0)) + 8|0);
 $58 = +HEAPF32[$57>>2];
 $59 = $56 - $58;
 $60 = ((($0)) + 24|0);
 $61 = +HEAPF32[$60>>2];
 $62 = ((($0)) + 12|0);
 $63 = +HEAPF32[$62>>2];
 $64 = $61 - $63;
 HEAPF32[$3>>2] = $54;
 $65 = ((($3)) + 4|0);
 HEAPF32[$65>>2] = $59;
 $66 = ((($3)) + 8|0);
 HEAPF32[$66>>2] = $64;
 $67 = ((($0)) + 28|0);
 $68 = ((($1)) + 8|0);
 $69 = HEAP32[$68>>2]|0;
 __ZNSt3__26vectorIjNS_9allocatorIjEEE7reserveEj($67,$69);
 $70 = HEAP32[$68>>2]|0;
 $71 = ($70|0)==(0);
 L15: do {
  if (!($71)) {
   $72 = ((($0)) + 32|0);
   $73 = ((($0)) + 36|0);
   $$0915$i = 0;$75 = $59;$76 = $54;$80 = $64;
   while(1) {
    $74 = !($76 >= $75);
    $$sink14$i = $74&1;
    $77 = (($3) + ($$sink14$i<<2)|0);
    $78 = +HEAPF32[$77>>2];
    $79 = !($78 >= $80);
    $$10$i = $79 ? 2 : $$sink14$i;
    HEAP32[$4>>2] = $$10$i;
    $81 = HEAP32[$72>>2]|0;
    $82 = HEAP32[$73>>2]|0;
    $83 = ($81|0)==($82|0);
    if ($83) {
     __ZNSt3__26vectorIjNS_9allocatorIjEEE21__push_back_slow_pathIKjEEvRT_($67,$4);
    } else {
     HEAP32[$81>>2] = $$10$i;
     $84 = ((($81)) + 4|0);
     HEAP32[$72>>2] = $84;
    }
    $85 = (($3) + ($$10$i<<2)|0);
    $86 = +HEAPF32[$85>>2];
    $87 = $86 * 0.5;
    HEAPF32[$85>>2] = $87;
    $88 = (($$0915$i) + 1)|0;
    $89 = HEAP32[$68>>2]|0;
    $90 = ($88>>>0)<($89>>>0);
    if (!($90)) {
     break L15;
    }
    $$pre$i = +HEAPF32[$3>>2];
    $$pre16$i = +HEAPF32[$65>>2];
    $$pre17$i = +HEAPF32[$66>>2];
    $$0915$i = $88;$75 = $$pre16$i;$76 = $$pre$i;$80 = $$pre17$i;
   }
  }
 } while(0);
 $91 = HEAP32[$15>>2]|0;
 $92 = HEAP32[$14>>2]|0;
 $93 = (($91) - ($92))|0;
 $94 = (($93|0) / 12)&-1;
 $95 = HEAP32[$1>>2]|0;
 $96 = (($94) + ($95))|0;
 HEAP32[$1>>2] = $96;
 $97 = $94 << 1;
 $98 = ((($0)) + 40|0);
 __ZNSt3__26vectorIjNS_9allocatorIjEEE7reserveEj($98,$97);
 $99 = ((($0)) + 52|0);
 __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE7reserveEj($99,$97);
 $100 = ((($5)) + 4|0);
 HEAP32[$5>>2] = (62356);
 HEAP32[$100>>2] = $0;
 $101 = HEAP32[$2>>2]|0;
 $102 = ((($101)) + 272|0);
 $103 = HEAP32[$102>>2]|0;
 __THREW__ = 0;
 invoke_vii($103|0,($2|0),($5|0));
 $104 = __THREW__; __THREW__ = 0;
 $105 = $104&1;
 if (!($105)) {
  $106 = HEAP32[$15>>2]|0;
  $107 = HEAP32[$14>>2]|0;
  $108 = (($106) - ($107))|0;
  $109 = (($108|0) / 12)&-1;
  __THREW__ = 0;
  invoke_vii(3825,($98|0),($109|0));
  $110 = __THREW__; __THREW__ = 0;
  $111 = $110&1;
  if (!($111)) {
   $112 = ((($0)) + 44|0);
   $113 = HEAP32[$112>>2]|0;
   $114 = HEAP32[$98>>2]|0;
   $115 = (($113) - ($114))|0;
   $116 = $115 >> 2;
   $117 = ((($6)) + 24|0);
   HEAP32[$117>>2] = -1;
   $118 = ((($6)) + 28|0);
   HEAP32[$118>>2] = $116;
   ;HEAP32[$6>>2]=HEAP32[$24>>2]|0;HEAP32[$6+4>>2]=HEAP32[$24+4>>2]|0;HEAP32[$6+8>>2]=HEAP32[$24+8>>2]|0;HEAP32[$6+12>>2]=HEAP32[$24+12>>2]|0;HEAP32[$6+16>>2]=HEAP32[$24+16>>2]|0;HEAP32[$6+20>>2]=HEAP32[$24+20>>2]|0;
   $119 = HEAP32[$0>>2]|0;
   $120 = ((($119)) + 64|0);
   $121 = ((($119)) + 68|0);
   $122 = HEAP32[$121>>2]|0;
   $123 = HEAP32[$120>>2]|0;
   $124 = (($122) - ($123))|0;
   $125 = $124 >> 5;
   $$cast$i = $122;
   $126 = ((($119)) + 72|0);
   $127 = HEAP32[$126>>2]|0;
   $128 = ($$cast$i|0)==($127|0);
   if ($128) {
    __THREW__ = 0;
    invoke_vii(3826,($120|0),($6|0));
    $132 = __THREW__; __THREW__ = 0;
    $133 = $132&1;
    if ($133) {
     $152 = ___cxa_find_matching_catch_2()|0;
     $153 = tempRet0;
     $$4 = $153;$$443 = $152;
    } else {
     label = 20;
    }
   } else {
    $129 = $122;
    ;HEAP32[$129>>2]=HEAP32[$6>>2]|0;HEAP32[$129+4>>2]=HEAP32[$6+4>>2]|0;HEAP32[$129+8>>2]=HEAP32[$6+8>>2]|0;HEAP32[$129+12>>2]=HEAP32[$6+12>>2]|0;HEAP32[$129+16>>2]=HEAP32[$6+16>>2]|0;HEAP32[$129+20>>2]=HEAP32[$6+20>>2]|0;HEAP32[$129+24>>2]=HEAP32[$6+24>>2]|0;HEAP32[$129+28>>2]=HEAP32[$6+28>>2]|0;
    $130 = HEAP32[$121>>2]|0;
    $131 = ((($130)) + 32|0);
    HEAP32[$121>>2] = $131;
    label = 20;
   }
   if ((label|0) == 20) {
    ;HEAP32[$7>>2]=HEAP32[$24>>2]|0;HEAP32[$7+4>>2]=HEAP32[$24+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[$24+8>>2]|0;HEAP32[$7+12>>2]=HEAP32[$24+12>>2]|0;HEAP32[$7+16>>2]=HEAP32[$24+16>>2]|0;HEAP32[$7+20>>2]=HEAP32[$24+20>>2]|0;
    __THREW__ = 0;
    (invoke_iiiiii(3827,($0|0),($1|0),($7|0),($125|0),0)|0);
    $134 = __THREW__; __THREW__ = 0;
    $135 = $134&1;
    if ($135) {
     $154 = ___cxa_find_matching_catch_2()|0;
     $155 = tempRet0;
     $$3 = $155;$$342 = $154;
    } else {
     $136 = HEAP32[$0>>2]|0;
     $137 = ((($136)) + 40|0);
     HEAP32[$8>>2] = 0;
     $138 = ((($8)) + 4|0);
     HEAP32[$138>>2] = 0;
     $139 = ((($8)) + 8|0);
     HEAP32[$139>>2] = 0;
     $140 = HEAP32[$112>>2]|0;
     $141 = HEAP32[$98>>2]|0;
     $142 = (($140) - ($141))|0;
     $143 = $142 >> 2;
     __THREW__ = 0;
     invoke_vii(3825,($8|0),($143|0));
     $144 = __THREW__; __THREW__ = 0;
     $145 = $144&1;
     L37: do {
      if (!($145)) {
       $146 = HEAP32[$98>>2]|0;
       $147 = HEAP32[$112>>2]|0;
       $148 = ($146|0)==($147|0);
       if ($148) {
        $$pre59 = ((($8)) + 8|0);
        $$pre$phiZ2D = $$pre59;
       } else {
        $149 = ((($8)) + 8|0);
        $$sroa$052$058 = $146;$203 = $147;
        while(1) {
         $156 = HEAP32[$$sroa$052$058>>2]|0;
         $157 = HEAP32[$137>>2]|0;
         $158 = (($157) + ($156<<2)|0);
         $159 = HEAP32[$138>>2]|0;
         $160 = HEAP32[$149>>2]|0;
         $161 = ($159|0)==($160|0);
         if ($161) {
          __THREW__ = 0;
          invoke_vii(3437,($8|0),($158|0));
          $164 = __THREW__; __THREW__ = 0;
          $165 = $164&1;
          if ($165) {
           break L37;
          }
          $$pre = HEAP32[$112>>2]|0;
          $168 = $$pre;
         } else {
          $162 = HEAP32[$158>>2]|0;
          HEAP32[$159>>2] = $162;
          $163 = ((($159)) + 4|0);
          HEAP32[$138>>2] = $163;
          $168 = $203;
         }
         $166 = ((($$sroa$052$058)) + 4|0);
         $167 = ($166|0)==($168|0);
         if ($167) {
          $$pre$phiZ2D = $149;
          break;
         } else {
          $$sroa$052$058 = $166;$203 = $168;
         }
        }
       }
       $169 = HEAP32[$137>>2]|0;
       $170 = HEAP32[$8>>2]|0;
       HEAP32[$137>>2] = $170;
       HEAP32[$8>>2] = $169;
       $171 = ((($136)) + 44|0);
       $172 = HEAP32[$171>>2]|0;
       $173 = HEAP32[$138>>2]|0;
       HEAP32[$171>>2] = $173;
       HEAP32[$138>>2] = $172;
       $174 = ((($136)) + 48|0);
       $175 = HEAP32[$174>>2]|0;
       $176 = HEAP32[$$pre$phiZ2D>>2]|0;
       HEAP32[$174>>2] = $176;
       HEAP32[$$pre$phiZ2D>>2] = $175;
       $177 = HEAP32[$0>>2]|0;
       $178 = ((($177)) + 64|0);
       $179 = HEAP32[$178>>2]|0;
       $180 = ((($177)) + 68|0);
       $181 = HEAP32[$180>>2]|0;
       $182 = ($169|0)==(0);
       $183 = $169;
       $184 = $172;
       if (!($182)) {
        $185 = $169;
        $186 = ($184|0)==($185|0);
        if (!($186)) {
         $scevgep$i$i$i45 = ((($184)) + -4|0);
         $187 = $scevgep$i$i$i45;
         $188 = (($187) - ($169))|0;
         $189 = $188 >>> 2;
         $190 = $189 ^ -1;
         $scevgep5$i$i$i46 = (($184) + ($190<<2)|0);
         HEAP32[$138>>2] = $scevgep5$i$i$i46;
        }
        __ZdlPv($183);
       }
       $191 = ($179|0)!=($181|0);
       $$0 = $191;
       STACKTOP = sp;return ($$0|0);
      }
     } while(0);
     $192 = ___cxa_find_matching_catch_2()|0;
     $193 = tempRet0;
     $194 = HEAP32[$8>>2]|0;
     $195 = ($194|0)==(0|0);
     if (!($195)) {
      $196 = HEAP32[$138>>2]|0;
      $197 = ($196|0)==($194|0);
      if (!($197)) {
       $scevgep$i$i$i = ((($196)) + -4|0);
       $198 = $scevgep$i$i$i;
       $199 = $194;
       $200 = (($198) - ($199))|0;
       $201 = $200 >>> 2;
       $202 = $201 ^ -1;
       $scevgep5$i$i$i = (($196) + ($202<<2)|0);
       HEAP32[$138>>2] = $scevgep5$i$i$i;
      }
      __ZdlPv($194);
     }
     $$3 = $193;$$342 = $192;
    }
    $$4 = $$3;$$443 = $$342;
   }
   $$5 = $$4;$$544 = $$443;
   ___resumeException($$544|0);
   // unreachable;
  }
 }
 $150 = ___cxa_find_matching_catch_2()|0;
 $151 = tempRet0;
 $$5 = $151;$$544 = $150;
 ___resumeException($$544|0);
 // unreachable;
 return (0)|0;
}
function __ZNSt3__26vectorIN3osg6KdTree6KdNodeENS_9allocatorIS3_EEE7reserveEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 5;
 $7 = ($6>>>0)<($1>>>0);
 if (!($7)) {
  return;
 }
 $8 = ((($0)) + 4|0);
 $9 = ($1>>>0)>(134217727);
 if ($9) {
  $10 = (___cxa_allocate_exception(8)|0);
  __THREW__ = 0;
  invoke_vii(3366,($10|0),(204840|0));
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if ($12) {
   $13 = ___cxa_find_matching_catch_2()|0;
   $14 = tempRet0;
   ___cxa_free_exception(($10|0));
   ___resumeException($13|0);
   // unreachable;
  } else {
   HEAP32[$10>>2] = (99824);
   ___cxa_throw(($10|0),(34608|0),(3230|0));
   // unreachable;
  }
 }
 $15 = HEAP32[$8>>2]|0;
 $16 = (($15) - ($4))|0;
 $17 = $16 >> 5;
 $18 = $1 << 5;
 $19 = (__Znwj($18)|0);
 $20 = (($19) + ($17<<5)|0);
 $21 = $20;
 $22 = (($19) + ($1<<5)|0);
 $23 = $22;
 $24 = (0 - ($17))|0;
 $25 = (($20) + ($24<<5)|0);
 $26 = $25;
 $27 = ($16|0)>(0);
 if ($27) {
  $28 = $4;
  _memcpy(($25|0),($28|0),($16|0))|0;
 }
 HEAP32[$0>>2] = $26;
 HEAP32[$8>>2] = $21;
 HEAP32[$2>>2] = $23;
 $29 = ($4|0)==(0);
 if ($29) {
  return;
 }
 $30 = $4;
 __ZdlPv($30);
 return;
}
function __ZNSt3__26vectorIN3osg6KdTree6KdNodeENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 5;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(134217727);
 if ($8) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $9 = ((($0)) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) - ($4))|0;
 $12 = $11 >> 5;
 $13 = ($12>>>0)<(67108863);
 $14 = $11 >> 4;
 $15 = ($14>>>0)<($7>>>0);
 $$sroa$speculated$i = $15 ? $7 : $14;
 $$sroa$speculated$$i = $13 ? $$sroa$speculated$i : 134217727;
 $16 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($16) {
   $26 = 0;
  } else {
   $17 = ($$sroa$speculated$$i>>>0)>(134217727);
   if (!($17)) {
    $23 = $$sroa$speculated$$i << 5;
    $24 = (__Znwj($23)|0);
    $26 = $24;
    break;
   }
   $18 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($18|0),(204840|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if ($20) {
    $21 = ___cxa_find_matching_catch_2()|0;
    $22 = tempRet0;
    ___cxa_free_exception(($18|0));
    ___resumeException($21|0);
    // unreachable;
   } else {
    HEAP32[$18>>2] = (99824);
    ___cxa_throw(($18|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $25 = (($26) + ($6<<5)|0);
 $27 = (($26) + ($$sroa$speculated$$i<<5)|0);
 $28 = $27;
 ;HEAP32[$25>>2]=HEAP32[$1>>2]|0;HEAP32[$25+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$25+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$25+12>>2]=HEAP32[$1+12>>2]|0;HEAP32[$25+16>>2]=HEAP32[$1+16>>2]|0;HEAP32[$25+20>>2]=HEAP32[$1+20>>2]|0;HEAP32[$25+24>>2]=HEAP32[$1+24>>2]|0;HEAP32[$25+28>>2]=HEAP32[$1+28>>2]|0;
 $29 = ((($25)) + 32|0);
 $30 = $29;
 $31 = (0 - ($6))|0;
 $32 = (($25) + ($31<<5)|0);
 $33 = $32;
 $34 = ($5|0)>(0);
 if ($34) {
  $35 = $4;
  _memcpy(($32|0),($35|0),($5|0))|0;
 }
 HEAP32[$0>>2] = $33;
 HEAP32[$2>>2] = $30;
 HEAP32[$9>>2] = $28;
 $36 = ($4|0)==(0);
 if ($36) {
  return;
 }
 $37 = $4;
 __ZdlPv($37);
 return;
}
function __ZN11BuildKdTree6divideERN3osg6KdTree12BuildOptionsERNS0_15BoundingBoxImplINS0_5Vec3fEEEij($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0188233 = 0, $$0189231 = 0, $$0190$be = 0, $$0190$lcssa = 0, $$0190227 = 0, $$0191$be = 0, $$0191$lcssa = 0, $$0191226 = 0, $$0194$off0 = 0, $$0195 = 0, $$0196 = 0, $$0197230 = 0, $$1192$lcssa = 0, $$1192220 = 0, $$1223 = 0, $$2 = 0, $$2193 = 0, $$cast$i = 0, $$cast$i203 = 0, $$phi$trans$insert244 = 0;
 var $$pre$i = 0.0, $$pre$i206 = 0.0, $$pre$i208 = 0.0, $$pre13$i = 0.0, $$pre14$i = 0.0, $$pre242 = 0, $$pre243 = 0, $$pre245 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0.0, $105 = 0.0, $106 = 0.0, $107 = 0.0, $108 = 0.0, $109 = 0.0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0.0, $117 = 0, $118 = 0.0, $119 = 0.0, $12 = 0, $120 = 0.0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0.0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0.0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0.0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0;
 var $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0;
 var $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0;
 var $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0;
 var $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0.0, $235 = 0, $236 = 0.0, $237 = 0;
 var $238 = 0, $239 = 0.0, $24 = 0, $240 = 0, $241 = 0.0, $242 = 0, $243 = 0, $244 = 0.0, $245 = 0, $246 = 0.0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0.0, $251 = 0.0, $252 = 0, $253 = 0.0, $254 = 0, $255 = 0.0;
 var $256 = 0, $257 = 0.0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0.0, $265 = 0, $266 = 0.0, $267 = 0, $268 = 0, $269 = 0.0, $27 = 0, $270 = 0, $271 = 0.0, $272 = 0, $273 = 0;
 var $274 = 0.0, $275 = 0, $276 = 0.0, $277 = 0, $278 = 0, $279 = 0.0, $28 = 0, $280 = 0, $281 = 0.0, $282 = 0.0, $283 = 0.0, $284 = 0, $285 = 0.0, $286 = 0.0, $287 = 0, $288 = 0.0, $289 = 0.0, $29 = 0, $290 = 0, $291 = 0.0;
 var $292 = 0.0, $293 = 0, $294 = 0.0, $295 = 0, $296 = 0.0, $297 = 0.0, $298 = 0, $299 = 0.0, $30 = 0, $300 = 0.0, $301 = 0, $302 = 0.0, $303 = 0.0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0;
 var $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0;
 var $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0;
 var $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0;
 var $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0.0;
 var $383 = 0, $384 = 0, $385 = 0.0, $386 = 0, $387 = 0, $388 = 0.0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $40 = 0, $400 = 0;
 var $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0.0, $413 = 0, $414 = 0, $415 = 0.0, $416 = 0, $417 = 0, $418 = 0.0, $419 = 0;
 var $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0;
 var $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0.0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0.0, $451 = 0, $452 = 0, $453 = 0, $454 = 0.0, $455 = 0;
 var $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0;
 var $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0.0, $480 = 0, $481 = 0.0, $482 = 0, $483 = 0, $484 = 0, $485 = 0.0, $486 = 0, $487 = 0, $488 = 0, $489 = 0.0, $49 = 0.0, $490 = 0, $491 = 0;
 var $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0;
 var $51 = 0.0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0.0, $517 = 0, $518 = 0, $519 = 0, $52 = 0.0, $520 = 0.0, $521 = 0, $522 = 0, $523 = 0, $524 = 0.0, $525 = 0, $526 = 0, $527 = 0;
 var $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0.0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0;
 var $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0.0, $550 = 0, $551 = 0.0, $552 = 0, $553 = 0, $554 = 0, $555 = 0.0, $556 = 0, $557 = 0, $558 = 0, $559 = 0.0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0;
 var $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0.0, $58 = 0, $580 = 0.0, $581 = 0.0;
 var $582 = 0.0, $583 = 0.0, $584 = 0.0, $585 = 0.0, $586 = 0.0, $587 = 0.0, $588 = 0.0, $589 = 0.0, $59 = 0, $590 = 0.0, $591 = 0.0, $592 = 0.0, $593 = 0.0, $594 = 0.0, $595 = 0.0, $596 = 0.0, $597 = 0.0, $598 = 0.0, $599 = 0.0, $6 = 0;
 var $60 = 0, $600 = 0.0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0.0, $81 = 0, $82 = 0.0, $83 = 0, $84 = 0.0, $85 = 0.0, $86 = 0, $87 = 0.0, $88 = 0, $89 = 0.0, $9 = 0, $90 = 0, $91 = 0.0, $92 = 0.0, $93 = 0, $94 = 0.0, $95 = 0;
 var $96 = 0.0, $97 = 0, $98 = 0.0, $99 = 0.0, $or$cond = 0, $or$cond264 = 0, $or$cond265 = 0, $or$cond266 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(112|0);
 $5 = sp + 96|0;
 $6 = sp + 92|0;
 $7 = sp + 88|0;
 $8 = sp + 84|0;
 $9 = sp + 80|0;
 $10 = sp + 76|0;
 $11 = sp + 72|0;
 $12 = sp + 68|0;
 $13 = sp + 64|0;
 $14 = sp + 32|0;
 $15 = sp;
 $16 = HEAP32[$0>>2]|0;
 $17 = ((($16)) + 64|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ((($0)) + 28|0);
 $20 = ((($0)) + 32|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = HEAP32[$19>>2]|0;
 $23 = (($21) - ($22))|0;
 $24 = $23 >> 2;
 $25 = ($24>>>0)>($4>>>0);
 $26 = $22;
 $27 = (((($18) + ($3<<5)|0)) + 24|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = ($28|0)<(0);
 if ($25) {
  if (!($29)) {
   STACKTOP = sp;return ($3|0);
  }
  $30 = (((($18) + ($3<<5)|0)) + 28|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = ((($1)) + 4|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = ($31>>>0)>($33>>>0);
  if ($34) {
   $110 = (($26) + ($4<<2)|0);
   $111 = HEAP32[$110>>2]|0;
   $112 = $28 ^ -1;
   $113 = (-2 - ($28))|0;
   $114 = (($113) + ($31))|0;
   $115 = (($2) + ($111<<2)|0);
   $116 = +HEAPF32[$115>>2];
   $117 = (((($2)) + 12|0) + ($111<<2)|0);
   $118 = +HEAPF32[$117>>2];
   $119 = $116 + $118;
   $120 = $119 * 0.5;
   $121 = ($114|0)>($112|0);
   if ($121) {
    $122 = ((($0)) + 40|0);
    $123 = ((($0)) + 52|0);
    $$0190227 = $114;$$0191226 = $112;
    while(1) {
     $124 = ($$0191226|0)<($$0190227|0);
     L11: do {
      if ($124) {
       $125 = HEAP32[$122>>2]|0;
       $126 = HEAP32[$123>>2]|0;
       $$1192220 = $$0191226;
       while(1) {
        $127 = (($125) + ($$1192220<<2)|0);
        $128 = HEAP32[$127>>2]|0;
        $129 = ((($126) + (($128*12)|0)|0) + ($111<<2)|0);
        $130 = +HEAPF32[$129>>2];
        $131 = !($130 <= $120);
        if ($131) {
         $$1192$lcssa = $$1192220;
         break L11;
        }
        $135 = (($$1192220) + 1)|0;
        $136 = ($135|0)<($$0190227|0);
        if ($136) {
         $$1192220 = $135;
        } else {
         $$1192$lcssa = $135;
         break;
        }
       }
      } else {
       $$1192$lcssa = $$0191226;
      }
     } while(0);
     $132 = ($$1192$lcssa|0)<($$0190227|0);
     L17: do {
      if ($132) {
       $133 = HEAP32[$122>>2]|0;
       $134 = HEAP32[$123>>2]|0;
       $$1223 = $$0190227;
       while(1) {
        $137 = (($133) + ($$1223<<2)|0);
        $138 = HEAP32[$137>>2]|0;
        $139 = ((($134) + (($138*12)|0)|0) + ($111<<2)|0);
        $140 = +HEAPF32[$139>>2];
        $141 = $140 > $120;
        if (!($141)) {
         break;
        }
        $142 = (($$1223) + -1)|0;
        $143 = ($$1192$lcssa|0)<($142|0);
        if ($143) {
         $$1223 = $142;
        } else {
         $$0190$be = $142;$$0191$be = $$1192$lcssa;
         break L17;
        }
       }
       $144 = (($133) + ($$1192$lcssa<<2)|0);
       $145 = (($$1192$lcssa) + 1)|0;
       $146 = (($$1223) + -1)|0;
       $147 = HEAP32[$144>>2]|0;
       HEAP32[$144>>2] = $138;
       HEAP32[$137>>2] = $147;
       $$0190$be = $146;$$0191$be = $145;
      } else {
       $$0190$be = $$0190227;$$0191$be = $$1192$lcssa;
      }
     } while(0);
     $148 = ($$0191$be|0)<($$0190$be|0);
     if ($148) {
      $$0190227 = $$0190$be;$$0191226 = $$0191$be;
     } else {
      $$0190$lcssa = $$0190$be;$$0191$lcssa = $$0191$be;
      break;
     }
    }
   } else {
    $$0190$lcssa = $114;$$0191$lcssa = $112;
   }
   $149 = ($$0191$lcssa|0)==($$0190$lcssa|0);
   do {
    if ($149) {
     $150 = ((($0)) + 40|0);
     $151 = HEAP32[$150>>2]|0;
     $152 = (($151) + ($$0191$lcssa<<2)|0);
     $153 = HEAP32[$152>>2]|0;
     $154 = ((($0)) + 52|0);
     $155 = HEAP32[$154>>2]|0;
     $156 = ((($155) + (($153*12)|0)|0) + ($111<<2)|0);
     $157 = +HEAPF32[$156>>2];
     $158 = !($157 <= $120);
     if ($158) {
      $160 = (($$0191$lcssa) + -1)|0;
      $$2 = $160;$$2193 = $$0191$lcssa;
      break;
     } else {
      $159 = (($$0191$lcssa) + 1)|0;
      $$2 = $$0191$lcssa;$$2193 = $159;
      break;
     }
    } else {
     $$2 = $$0190$lcssa;$$2193 = $$0191$lcssa;
    }
   } while(0);
   $161 = (($28) + 2)|0;
   $162 = (($161) + ($$2))|0;
   HEAPF32[$14>>2] = 3.4028234663852886E+38;
   $163 = ((($14)) + 4|0);
   HEAPF32[$163>>2] = 3.4028234663852886E+38;
   $164 = ((($14)) + 8|0);
   HEAPF32[$164>>2] = 3.4028234663852886E+38;
   $165 = ((($14)) + 12|0);
   HEAPF32[$165>>2] = -3.4028234663852886E+38;
   $166 = ((($14)) + 16|0);
   HEAPF32[$166>>2] = -3.4028234663852886E+38;
   $167 = ((($14)) + 20|0);
   HEAPF32[$167>>2] = -3.4028234663852886E+38;
   $168 = ((($14)) + 24|0);
   HEAP32[$168>>2] = $28;
   $169 = ((($14)) + 28|0);
   HEAP32[$169>>2] = $162;
   $170 = $$2193 ^ -1;
   $171 = (($114) - ($$2193))|0;
   $172 = (($171) + 1)|0;
   HEAPF32[$15>>2] = 3.4028234663852886E+38;
   $173 = ((($15)) + 4|0);
   HEAPF32[$173>>2] = 3.4028234663852886E+38;
   $174 = ((($15)) + 8|0);
   HEAPF32[$174>>2] = 3.4028234663852886E+38;
   $175 = ((($15)) + 12|0);
   HEAPF32[$175>>2] = -3.4028234663852886E+38;
   $176 = ((($15)) + 16|0);
   HEAPF32[$176>>2] = -3.4028234663852886E+38;
   $177 = ((($15)) + 20|0);
   HEAPF32[$177>>2] = -3.4028234663852886E+38;
   $178 = ((($15)) + 24|0);
   HEAP32[$178>>2] = $170;
   $179 = ((($15)) + 28|0);
   HEAP32[$179>>2] = $172;
   $180 = ($162|0)<(1);
   do {
    if ($180) {
     $$0194$off0 = 1;$$0195 = $3;$$0196 = 0;
    } else {
     $181 = ($171|0)<(0);
     if ($181) {
      $$0194$off0 = 1;$$0195 = 0;$$0196 = $3;
     } else {
      $182 = HEAP32[$0>>2]|0;
      $183 = ((($182)) + 64|0);
      $184 = ((($182)) + 68|0);
      $185 = HEAP32[$184>>2]|0;
      $186 = HEAP32[$183>>2]|0;
      $187 = (($185) - ($186))|0;
      $188 = $187 >> 5;
      $$cast$i = $185;
      $189 = ((($182)) + 72|0);
      $190 = HEAP32[$189>>2]|0;
      $191 = ($$cast$i|0)==($190|0);
      if ($191) {
       __ZNSt3__26vectorIN3osg6KdTree6KdNodeENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_($183,$14);
      } else {
       $192 = $185;
       ;HEAP32[$192>>2]=HEAP32[$14>>2]|0;HEAP32[$192+4>>2]=HEAP32[$14+4>>2]|0;HEAP32[$192+8>>2]=HEAP32[$14+8>>2]|0;HEAP32[$192+12>>2]=HEAP32[$14+12>>2]|0;HEAP32[$192+16>>2]=HEAP32[$14+16>>2]|0;HEAP32[$192+20>>2]=HEAP32[$14+20>>2]|0;HEAP32[$192+24>>2]=HEAP32[$14+24>>2]|0;HEAP32[$192+28>>2]=HEAP32[$14+28>>2]|0;
       $193 = HEAP32[$184>>2]|0;
       $194 = ((($193)) + 32|0);
       HEAP32[$184>>2] = $194;
      }
      $195 = HEAP32[$0>>2]|0;
      $196 = ((($195)) + 64|0);
      $197 = ((($195)) + 68|0);
      $198 = HEAP32[$197>>2]|0;
      $199 = HEAP32[$196>>2]|0;
      $200 = (($198) - ($199))|0;
      $201 = $200 >> 5;
      $$cast$i203 = $198;
      $202 = ((($195)) + 72|0);
      $203 = HEAP32[$202>>2]|0;
      $204 = ($$cast$i203|0)==($203|0);
      if ($204) {
       __ZNSt3__26vectorIN3osg6KdTree6KdNodeENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_($196,$15);
       $$0194$off0 = 0;$$0195 = $201;$$0196 = $188;
       break;
      } else {
       $205 = $198;
       ;HEAP32[$205>>2]=HEAP32[$15>>2]|0;HEAP32[$205+4>>2]=HEAP32[$15+4>>2]|0;HEAP32[$205+8>>2]=HEAP32[$15+8>>2]|0;HEAP32[$205+12>>2]=HEAP32[$15+12>>2]|0;HEAP32[$205+16>>2]=HEAP32[$15+16>>2]|0;HEAP32[$205+20>>2]=HEAP32[$15+20>>2]|0;HEAP32[$205+24>>2]=HEAP32[$15+24>>2]|0;HEAP32[$205+28>>2]=HEAP32[$15+28>>2]|0;
       $206 = HEAP32[$197>>2]|0;
       $207 = ((($206)) + 32|0);
       HEAP32[$197>>2] = $207;
       $$0194$off0 = 0;$$0195 = $201;$$0196 = $188;
       break;
      }
     }
    }
   } while(0);
   $208 = HEAP32[$117>>2]|0;
   HEAPF32[$117>>2] = $120;
   $209 = ($$0196|0)==(0);
   if ($209) {
    $220 = 0;
   } else {
    $210 = (($4) + 1)|0;
    $211 = (__ZN11BuildKdTree6divideERN3osg6KdTree12BuildOptionsERNS0_15BoundingBoxImplINS0_5Vec3fEEEij($0,$1,$2,$$0196,$210)|0);
    $220 = $211;
   }
   HEAP32[$117>>2] = $208;
   $212 = HEAP32[$115>>2]|0;
   HEAPF32[$115>>2] = $120;
   $213 = ($$0195|0)==(0);
   if ($213) {
    $222 = 0;
   } else {
    $214 = (($4) + 1)|0;
    $215 = (__ZN11BuildKdTree6divideERN3osg6KdTree12BuildOptionsERNS0_15BoundingBoxImplINS0_5Vec3fEEEij($0,$1,$2,$$0195,$214)|0);
    $222 = $215;
   }
   HEAP32[$115>>2] = $212;
   if ($$0194$off0) {
    STACKTOP = sp;return ($3|0);
   }
   $216 = HEAP32[$0>>2]|0;
   $217 = ((($216)) + 64|0);
   $218 = HEAP32[$217>>2]|0;
   $219 = (((($218) + ($3<<5)|0)) + 24|0);
   HEAP32[$219>>2] = $220;
   $221 = (((($218) + ($3<<5)|0)) + 28|0);
   HEAP32[$221>>2] = $222;
   $223 = (($218) + ($3<<5)|0);
   HEAPF32[$223>>2] = 3.4028234663852886E+38;
   $224 = (((($218) + ($3<<5)|0)) + 4|0);
   HEAPF32[$224>>2] = 3.4028234663852886E+38;
   $225 = (((($218) + ($3<<5)|0)) + 8|0);
   HEAPF32[$225>>2] = 3.4028234663852886E+38;
   $226 = (((($218) + ($3<<5)|0)) + 12|0);
   HEAPF32[$226>>2] = -3.4028234663852886E+38;
   $227 = (((($218) + ($3<<5)|0)) + 16|0);
   HEAPF32[$227>>2] = -3.4028234663852886E+38;
   $228 = (((($218) + ($3<<5)|0)) + 20|0);
   HEAPF32[$228>>2] = -3.4028234663852886E+38;
   $229 = ($220|0)!=(0);
   do {
    if ($229) {
     $230 = HEAP32[$0>>2]|0;
     $231 = ((($230)) + 64|0);
     $232 = HEAP32[$231>>2]|0;
     $233 = (((($232) + ($220<<5)|0)) + 12|0);
     $234 = +HEAPF32[$233>>2];
     $235 = (($232) + ($220<<5)|0);
     $236 = +HEAPF32[$235>>2];
     $237 = !($234 >= $236);
     if ($237) {
      $279 = 3.4028234663852886E+38;$281 = -3.4028234663852886E+38;$285 = 3.4028234663852886E+38;$288 = -3.4028234663852886E+38;$291 = 3.4028234663852886E+38;$294 = -3.4028234663852886E+38;
     } else {
      $238 = (((($232) + ($220<<5)|0)) + 16|0);
      $239 = +HEAPF32[$238>>2];
      $240 = (((($232) + ($220<<5)|0)) + 4|0);
      $241 = +HEAPF32[$240>>2];
      $242 = !($239 >= $241);
      if ($242) {
       $279 = 3.4028234663852886E+38;$281 = -3.4028234663852886E+38;$285 = 3.4028234663852886E+38;$288 = -3.4028234663852886E+38;$291 = 3.4028234663852886E+38;$294 = -3.4028234663852886E+38;
      } else {
       $243 = (((($232) + ($220<<5)|0)) + 20|0);
       $244 = +HEAPF32[$243>>2];
       $245 = (((($232) + ($220<<5)|0)) + 8|0);
       $246 = +HEAPF32[$245>>2];
       $247 = !($244 >= $246);
       if ($247) {
        $279 = 3.4028234663852886E+38;$281 = -3.4028234663852886E+38;$285 = 3.4028234663852886E+38;$288 = -3.4028234663852886E+38;$291 = 3.4028234663852886E+38;$294 = -3.4028234663852886E+38;
       } else {
        $248 = $236 < 3.4028234663852886E+38;
        if ($248) {
         HEAPF32[$223>>2] = $236;
         $$pre$i206 = +HEAPF32[$233>>2];
         $250 = $$pre$i206;$591 = $236;
        } else {
         $250 = $234;$591 = 3.4028234663852886E+38;
        }
        $249 = $250 > -3.4028234663852886E+38;
        if ($249) {
         HEAPF32[$226>>2] = $250;
         $592 = $250;
        } else {
         $592 = -3.4028234663852886E+38;
        }
        $251 = +HEAPF32[$240>>2];
        $252 = $251 < 3.4028234663852886E+38;
        if ($252) {
         HEAPF32[$224>>2] = $251;
         $593 = $251;
        } else {
         $593 = 3.4028234663852886E+38;
        }
        $253 = +HEAPF32[$238>>2];
        $254 = $253 > -3.4028234663852886E+38;
        if ($254) {
         HEAPF32[$227>>2] = $253;
         $594 = $253;
        } else {
         $594 = -3.4028234663852886E+38;
        }
        $255 = +HEAPF32[$245>>2];
        $256 = $255 < 3.4028234663852886E+38;
        if ($256) {
         HEAPF32[$225>>2] = $255;
         $595 = $255;
        } else {
         $595 = 3.4028234663852886E+38;
        }
        $257 = +HEAPF32[$243>>2];
        $258 = $257 > -3.4028234663852886E+38;
        if (!($258)) {
         $279 = $591;$281 = $592;$285 = $593;$288 = $594;$291 = $595;$294 = -3.4028234663852886E+38;
         break;
        }
        HEAPF32[$228>>2] = $257;
        $279 = $591;$281 = $592;$285 = $593;$288 = $594;$291 = $595;$294 = $257;
       }
      }
     }
    } else {
     $279 = 3.4028234663852886E+38;$281 = -3.4028234663852886E+38;$285 = 3.4028234663852886E+38;$288 = -3.4028234663852886E+38;$291 = 3.4028234663852886E+38;$294 = -3.4028234663852886E+38;
    }
   } while(0);
   $259 = ($222|0)!=(0);
   do {
    if ($259) {
     $260 = HEAP32[$0>>2]|0;
     $261 = ((($260)) + 64|0);
     $262 = HEAP32[$261>>2]|0;
     $263 = (((($262) + ($222<<5)|0)) + 12|0);
     $264 = +HEAPF32[$263>>2];
     $265 = (($262) + ($222<<5)|0);
     $266 = +HEAPF32[$265>>2];
     $267 = !($264 >= $266);
     if ($267) {
      $296 = $279;$297 = $281;$299 = $285;$300 = $288;$302 = $291;$303 = $294;
     } else {
      $268 = (((($262) + ($222<<5)|0)) + 16|0);
      $269 = +HEAPF32[$268>>2];
      $270 = (((($262) + ($222<<5)|0)) + 4|0);
      $271 = +HEAPF32[$270>>2];
      $272 = !($269 >= $271);
      if ($272) {
       $296 = $279;$297 = $281;$299 = $285;$300 = $288;$302 = $291;$303 = $294;
      } else {
       $273 = (((($262) + ($222<<5)|0)) + 20|0);
       $274 = +HEAPF32[$273>>2];
       $275 = (((($262) + ($222<<5)|0)) + 8|0);
       $276 = +HEAPF32[$275>>2];
       $277 = !($274 >= $276);
       if ($277) {
        $296 = $279;$297 = $281;$299 = $285;$300 = $288;$302 = $291;$303 = $294;
       } else {
        $278 = $266 < $279;
        if ($278) {
         HEAPF32[$223>>2] = $266;
         $$pre$i208 = +HEAPF32[$263>>2];
         $282 = $$pre$i208;$596 = $266;
        } else {
         $282 = $264;$596 = $279;
        }
        $280 = $282 > $281;
        if ($280) {
         HEAPF32[$226>>2] = $282;
         $597 = $282;
        } else {
         $597 = $281;
        }
        $283 = +HEAPF32[$270>>2];
        $284 = $283 < $285;
        if ($284) {
         HEAPF32[$224>>2] = $283;
         $598 = $283;
        } else {
         $598 = $285;
        }
        $286 = +HEAPF32[$268>>2];
        $287 = $286 > $288;
        if ($287) {
         HEAPF32[$227>>2] = $286;
         $599 = $286;
        } else {
         $599 = $288;
        }
        $289 = +HEAPF32[$275>>2];
        $290 = $289 < $291;
        if ($290) {
         HEAPF32[$225>>2] = $289;
         $600 = $289;
        } else {
         $600 = $291;
        }
        $292 = +HEAPF32[$273>>2];
        $293 = $292 > $294;
        if (!($293)) {
         $296 = $596;$297 = $597;$299 = $598;$300 = $599;$302 = $600;$303 = $294;
         break;
        }
        HEAPF32[$228>>2] = $292;
        $296 = $596;$297 = $597;$299 = $598;$300 = $599;$302 = $600;$303 = $292;
       }
      }
     }
    } else {
     $296 = $279;$297 = $281;$299 = $285;$300 = $288;$302 = $291;$303 = $294;
    }
   } while(0);
   $295 = !($297 >= $296);
   $298 = !($300 >= $299);
   $or$cond265 = $295 | $298;
   $301 = !($303 >= $302);
   $or$cond266 = $or$cond265 | $301;
   if (!($or$cond266)) {
    STACKTOP = sp;return ($3|0);
   }
   $304 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
   do {
    if ($304) {
     $305 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
     $306 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($305,144786,15)|0);
     $307 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi($306,$220)|0);
     $308 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($307,144802,27)|0);
     $309 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi($308,$$0196)|0);
     $310 = HEAP32[$309>>2]|0;
     $311 = ((($310)) + -12|0);
     $312 = HEAP32[$311>>2]|0;
     $313 = (($309) + ($312)|0);
     __ZNKSt3__28ios_base6getlocEv($10,$313);
     __THREW__ = 0;
     $314 = (invoke_iii(3255,($10|0),(215188|0))|0);
     $315 = __THREW__; __THREW__ = 0;
     $316 = $315&1;
     if (!($316)) {
      $317 = HEAP32[$314>>2]|0;
      $318 = ((($317)) + 28|0);
      $319 = HEAP32[$318>>2]|0;
      __THREW__ = 0;
      $320 = (invoke_iii($319|0,($314|0),10)|0);
      $321 = __THREW__; __THREW__ = 0;
      $322 = $321&1;
      if (!($322)) {
       __ZNSt3__26localeD2Ev($10);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($309,$320)|0);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($309)|0);
       break;
      }
     }
     $323 = ___cxa_find_matching_catch_2()|0;
     $324 = tempRet0;
     __THREW__ = 0;
     invoke_vi(3263,($10|0));
     $325 = __THREW__; __THREW__ = 0;
     $326 = $325&1;
     if ($326) {
      $327 = ___cxa_find_matching_catch_3(0|0)|0;
      $328 = tempRet0;
      ___clang_call_terminate($327);
      // unreachable;
     } else {
      ___resumeException($323|0);
      // unreachable;
     }
    }
   } while(0);
   $329 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
   do {
    if ($329) {
     $330 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
     $331 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($330,144830,16)|0);
     $332 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi($331,$222)|0);
     $333 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($332,144847,28)|0);
     $334 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi($333,$$0195)|0);
     $335 = HEAP32[$334>>2]|0;
     $336 = ((($335)) + -12|0);
     $337 = HEAP32[$336>>2]|0;
     $338 = (($334) + ($337)|0);
     __ZNKSt3__28ios_base6getlocEv($9,$338);
     __THREW__ = 0;
     $339 = (invoke_iii(3255,($9|0),(215188|0))|0);
     $340 = __THREW__; __THREW__ = 0;
     $341 = $340&1;
     if (!($341)) {
      $342 = HEAP32[$339>>2]|0;
      $343 = ((($342)) + 28|0);
      $344 = HEAP32[$343>>2]|0;
      __THREW__ = 0;
      $345 = (invoke_iii($344|0,($339|0),10)|0);
      $346 = __THREW__; __THREW__ = 0;
      $347 = $346&1;
      if (!($347)) {
       __ZNSt3__26localeD2Ev($9);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($334,$345)|0);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($334)|0);
       break;
      }
     }
     $348 = ___cxa_find_matching_catch_2()|0;
     $349 = tempRet0;
     __THREW__ = 0;
     invoke_vi(3263,($9|0));
     $350 = __THREW__; __THREW__ = 0;
     $351 = $350&1;
     if ($351) {
      $352 = ___cxa_find_matching_catch_3(0|0)|0;
      $353 = tempRet0;
      ___clang_call_terminate($352);
      // unreachable;
     } else {
      ___resumeException($348|0);
      // unreachable;
     }
    }
   } while(0);
   $354 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
   do {
    if ($354) {
     $355 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
     $356 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($355,144876,26)|0);
     $357 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi($356,$220)|0);
     $358 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($357,146554,2)|0);
     $359 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi($358,$222)|0);
     $360 = HEAP32[$359>>2]|0;
     $361 = ((($360)) + -12|0);
     $362 = HEAP32[$361>>2]|0;
     $363 = (($359) + ($362)|0);
     __ZNKSt3__28ios_base6getlocEv($8,$363);
     __THREW__ = 0;
     $364 = (invoke_iii(3255,($8|0),(215188|0))|0);
     $365 = __THREW__; __THREW__ = 0;
     $366 = $365&1;
     if (!($366)) {
      $367 = HEAP32[$364>>2]|0;
      $368 = ((($367)) + 28|0);
      $369 = HEAP32[$368>>2]|0;
      __THREW__ = 0;
      $370 = (invoke_iii($369|0,($364|0),10)|0);
      $371 = __THREW__; __THREW__ = 0;
      $372 = $371&1;
      if (!($372)) {
       __ZNSt3__26localeD2Ev($8);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($359,$370)|0);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($359)|0);
       break;
      }
     }
     $373 = ___cxa_find_matching_catch_2()|0;
     $374 = tempRet0;
     __THREW__ = 0;
     invoke_vi(3263,($8|0));
     $375 = __THREW__; __THREW__ = 0;
     $376 = $375&1;
     if ($376) {
      $377 = ___cxa_find_matching_catch_3(0|0)|0;
      $378 = tempRet0;
      ___clang_call_terminate($377);
      // unreachable;
     } else {
      ___resumeException($373|0);
      // unreachable;
     }
    }
   } while(0);
   $379 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
   L128: do {
    if ($379) {
     $380 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
     $381 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($380,144903,11)|0);
     $382 = +HEAPF32[$223>>2];
     $383 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEf($381,$382)|0);
     $384 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($383,159071,1)|0);
     $385 = +HEAPF32[$224>>2];
     $386 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEf($384,$385)|0);
     $387 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($386,159071,1)|0);
     $388 = +HEAPF32[$225>>2];
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEf($387,$388)|0);
     $389 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($381,174996,1)|0);
     $390 = HEAP32[$389>>2]|0;
     $391 = ((($390)) + -12|0);
     $392 = HEAP32[$391>>2]|0;
     $393 = (($389) + ($392)|0);
     __ZNKSt3__28ios_base6getlocEv($7,$393);
     __THREW__ = 0;
     $394 = (invoke_iii(3255,($7|0),(215188|0))|0);
     $395 = __THREW__; __THREW__ = 0;
     $396 = $395&1;
     do {
      if (!($396)) {
       $397 = HEAP32[$394>>2]|0;
       $398 = ((($397)) + 28|0);
       $399 = HEAP32[$398>>2]|0;
       __THREW__ = 0;
       $400 = (invoke_iii($399|0,($394|0),10)|0);
       $401 = __THREW__; __THREW__ = 0;
       $402 = $401&1;
       if ($402) {
        break;
       }
       __ZNSt3__26localeD2Ev($7);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($389,$400)|0);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($389)|0);
       break L128;
      }
     } while(0);
     $403 = ___cxa_find_matching_catch_2()|0;
     $404 = tempRet0;
     __THREW__ = 0;
     invoke_vi(3263,($7|0));
     $405 = __THREW__; __THREW__ = 0;
     $406 = $405&1;
     if ($406) {
      $407 = ___cxa_find_matching_catch_3(0|0)|0;
      $408 = tempRet0;
      ___clang_call_terminate($407);
      // unreachable;
     } else {
      ___resumeException($403|0);
      // unreachable;
     }
    }
   } while(0);
   $409 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
   L138: do {
    if ($409) {
     $410 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
     $411 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($410,144915,11)|0);
     $412 = +HEAPF32[$226>>2];
     $413 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEf($411,$412)|0);
     $414 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($413,159071,1)|0);
     $415 = +HEAPF32[$227>>2];
     $416 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEf($414,$415)|0);
     $417 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($416,159071,1)|0);
     $418 = +HEAPF32[$228>>2];
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEf($417,$418)|0);
     $419 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($411,174996,1)|0);
     $420 = HEAP32[$419>>2]|0;
     $421 = ((($420)) + -12|0);
     $422 = HEAP32[$421>>2]|0;
     $423 = (($419) + ($422)|0);
     __ZNKSt3__28ios_base6getlocEv($6,$423);
     __THREW__ = 0;
     $424 = (invoke_iii(3255,($6|0),(215188|0))|0);
     $425 = __THREW__; __THREW__ = 0;
     $426 = $425&1;
     do {
      if (!($426)) {
       $427 = HEAP32[$424>>2]|0;
       $428 = ((($427)) + 28|0);
       $429 = HEAP32[$428>>2]|0;
       __THREW__ = 0;
       $430 = (invoke_iii($429|0,($424|0),10)|0);
       $431 = __THREW__; __THREW__ = 0;
       $432 = $431&1;
       if ($432) {
        break;
       }
       __ZNSt3__26localeD2Ev($6);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($419,$430)|0);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($419)|0);
       break L138;
      }
     } while(0);
     $433 = ___cxa_find_matching_catch_2()|0;
     $434 = tempRet0;
     __THREW__ = 0;
     invoke_vi(3263,($6|0));
     $435 = __THREW__; __THREW__ = 0;
     $436 = $435&1;
     if ($436) {
      $437 = ___cxa_find_matching_catch_3(0|0)|0;
      $438 = tempRet0;
      ___clang_call_terminate($437);
      // unreachable;
     } else {
      ___resumeException($433|0);
      // unreachable;
     }
    }
   } while(0);
   L148: do {
    if ($229) {
     $439 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
     L150: do {
      if ($439) {
       $440 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
       $441 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($440,144927,35)|0);
       $442 = HEAP32[$0>>2]|0;
       $443 = ((($442)) + 64|0);
       $444 = HEAP32[$443>>2]|0;
       $445 = (($444) + ($220<<5)|0);
       $446 = +HEAPF32[$445>>2];
       $447 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEf($441,$446)|0);
       $448 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($447,159071,1)|0);
       $449 = (((($444) + ($220<<5)|0)) + 4|0);
       $450 = +HEAPF32[$449>>2];
       $451 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEf($448,$450)|0);
       $452 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($451,159071,1)|0);
       $453 = (((($444) + ($220<<5)|0)) + 8|0);
       $454 = +HEAPF32[$453>>2];
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEf($452,$454)|0);
       $455 = HEAP32[$441>>2]|0;
       $456 = ((($455)) + -12|0);
       $457 = HEAP32[$456>>2]|0;
       $458 = (($441) + ($457)|0);
       __ZNKSt3__28ios_base6getlocEv($5,$458);
       __THREW__ = 0;
       $459 = (invoke_iii(3255,($5|0),(215188|0))|0);
       $460 = __THREW__; __THREW__ = 0;
       $461 = $460&1;
       do {
        if (!($461)) {
         $462 = HEAP32[$459>>2]|0;
         $463 = ((($462)) + 28|0);
         $464 = HEAP32[$463>>2]|0;
         __THREW__ = 0;
         $465 = (invoke_iii($464|0,($459|0),10)|0);
         $466 = __THREW__; __THREW__ = 0;
         $467 = $466&1;
         if ($467) {
          break;
         }
         __ZNSt3__26localeD2Ev($5);
         (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($441,$465)|0);
         (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($441)|0);
         break L150;
        }
       } while(0);
       $468 = ___cxa_find_matching_catch_2()|0;
       $469 = tempRet0;
       __THREW__ = 0;
       invoke_vi(3263,($5|0));
       $470 = __THREW__; __THREW__ = 0;
       $471 = $470&1;
       if ($471) {
        $472 = ___cxa_find_matching_catch_3(0|0)|0;
        $473 = tempRet0;
        ___clang_call_terminate($472);
        // unreachable;
       } else {
        ___resumeException($468|0);
        // unreachable;
       }
      }
     } while(0);
     $474 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
     if (!($474)) {
      break;
     }
     $475 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
     $476 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($475,144963,39)|0);
     $477 = HEAP32[$0>>2]|0;
     $478 = ((($477)) + 64|0);
     $479 = HEAP32[$478>>2]|0;
     $480 = (((($479) + ($220<<5)|0)) + 12|0);
     $481 = +HEAPF32[$480>>2];
     $482 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEf($476,$481)|0);
     $483 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($482,159071,1)|0);
     $484 = (((($479) + ($220<<5)|0)) + 16|0);
     $485 = +HEAPF32[$484>>2];
     $486 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEf($483,$485)|0);
     $487 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($486,159071,1)|0);
     $488 = (((($479) + ($220<<5)|0)) + 20|0);
     $489 = +HEAPF32[$488>>2];
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEf($487,$489)|0);
     $490 = HEAP32[$476>>2]|0;
     $491 = ((($490)) + -12|0);
     $492 = HEAP32[$491>>2]|0;
     $493 = (($476) + ($492)|0);
     __ZNKSt3__28ios_base6getlocEv($11,$493);
     __THREW__ = 0;
     $494 = (invoke_iii(3255,($11|0),(215188|0))|0);
     $495 = __THREW__; __THREW__ = 0;
     $496 = $495&1;
     do {
      if (!($496)) {
       $497 = HEAP32[$494>>2]|0;
       $498 = ((($497)) + 28|0);
       $499 = HEAP32[$498>>2]|0;
       __THREW__ = 0;
       $500 = (invoke_iii($499|0,($494|0),10)|0);
       $501 = __THREW__; __THREW__ = 0;
       $502 = $501&1;
       if ($502) {
        break;
       }
       __ZNSt3__26localeD2Ev($11);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($476,$500)|0);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($476)|0);
       break L148;
      }
     } while(0);
     $503 = ___cxa_find_matching_catch_2()|0;
     $504 = tempRet0;
     __THREW__ = 0;
     invoke_vi(3263,($11|0));
     $505 = __THREW__; __THREW__ = 0;
     $506 = $505&1;
     if ($506) {
      $507 = ___cxa_find_matching_catch_3(0|0)|0;
      $508 = tempRet0;
      ___clang_call_terminate($507);
      // unreachable;
     } else {
      ___resumeException($503|0);
      // unreachable;
     }
    }
   } while(0);
   if (!($259)) {
    STACKTOP = sp;return ($3|0);
   }
   $509 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
   L172: do {
    if ($509) {
     $510 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
     $511 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($510,145003,36)|0);
     $512 = HEAP32[$0>>2]|0;
     $513 = ((($512)) + 64|0);
     $514 = HEAP32[$513>>2]|0;
     $515 = (($514) + ($222<<5)|0);
     $516 = +HEAPF32[$515>>2];
     $517 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEf($511,$516)|0);
     $518 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($517,159071,1)|0);
     $519 = (((($514) + ($222<<5)|0)) + 4|0);
     $520 = +HEAPF32[$519>>2];
     $521 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEf($518,$520)|0);
     $522 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($521,159071,1)|0);
     $523 = (((($514) + ($222<<5)|0)) + 8|0);
     $524 = +HEAPF32[$523>>2];
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEf($522,$524)|0);
     $525 = HEAP32[$511>>2]|0;
     $526 = ((($525)) + -12|0);
     $527 = HEAP32[$526>>2]|0;
     $528 = (($511) + ($527)|0);
     __ZNKSt3__28ios_base6getlocEv($12,$528);
     __THREW__ = 0;
     $529 = (invoke_iii(3255,($12|0),(215188|0))|0);
     $530 = __THREW__; __THREW__ = 0;
     $531 = $530&1;
     do {
      if (!($531)) {
       $532 = HEAP32[$529>>2]|0;
       $533 = ((($532)) + 28|0);
       $534 = HEAP32[$533>>2]|0;
       __THREW__ = 0;
       $535 = (invoke_iii($534|0,($529|0),10)|0);
       $536 = __THREW__; __THREW__ = 0;
       $537 = $536&1;
       if ($537) {
        break;
       }
       __ZNSt3__26localeD2Ev($12);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($511,$535)|0);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($511)|0);
       break L172;
      }
     } while(0);
     $538 = ___cxa_find_matching_catch_2()|0;
     $539 = tempRet0;
     __THREW__ = 0;
     invoke_vi(3263,($12|0));
     $540 = __THREW__; __THREW__ = 0;
     $541 = $540&1;
     if ($541) {
      $542 = ___cxa_find_matching_catch_3(0|0)|0;
      $543 = tempRet0;
      ___clang_call_terminate($542);
      // unreachable;
     } else {
      ___resumeException($538|0);
      // unreachable;
     }
    }
   } while(0);
   $544 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
   if (!($544)) {
    STACKTOP = sp;return ($3|0);
   }
   $545 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
   $546 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($545,145040,36)|0);
   $547 = HEAP32[$0>>2]|0;
   $548 = ((($547)) + 64|0);
   $549 = HEAP32[$548>>2]|0;
   $550 = (((($549) + ($222<<5)|0)) + 12|0);
   $551 = +HEAPF32[$550>>2];
   $552 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEf($546,$551)|0);
   $553 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($552,159071,1)|0);
   $554 = (((($549) + ($222<<5)|0)) + 16|0);
   $555 = +HEAPF32[$554>>2];
   $556 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEf($553,$555)|0);
   $557 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($556,159071,1)|0);
   $558 = (((($549) + ($222<<5)|0)) + 20|0);
   $559 = +HEAPF32[$558>>2];
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEf($557,$559)|0);
   $560 = HEAP32[$546>>2]|0;
   $561 = ((($560)) + -12|0);
   $562 = HEAP32[$561>>2]|0;
   $563 = (($546) + ($562)|0);
   __ZNKSt3__28ios_base6getlocEv($13,$563);
   __THREW__ = 0;
   $564 = (invoke_iii(3255,($13|0),(215188|0))|0);
   $565 = __THREW__; __THREW__ = 0;
   $566 = $565&1;
   do {
    if (!($566)) {
     $567 = HEAP32[$564>>2]|0;
     $568 = ((($567)) + 28|0);
     $569 = HEAP32[$568>>2]|0;
     __THREW__ = 0;
     $570 = (invoke_iii($569|0,($564|0),10)|0);
     $571 = __THREW__; __THREW__ = 0;
     $572 = $571&1;
     if ($572) {
      break;
     }
     __ZNSt3__26localeD2Ev($13);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($546,$570)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($546)|0);
     STACKTOP = sp;return ($3|0);
    }
   } while(0);
   $573 = ___cxa_find_matching_catch_2()|0;
   $574 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($13|0));
   $575 = __THREW__; __THREW__ = 0;
   $576 = $575&1;
   if ($576) {
    $577 = ___cxa_find_matching_catch_3(0|0)|0;
    $578 = tempRet0;
    ___clang_call_terminate($577);
    // unreachable;
   } else {
    ___resumeException($573|0);
    // unreachable;
   }
  }
 } else {
  if (!($29)) {
   STACKTOP = sp;return ($3|0);
  }
 }
 $35 = $28 ^ -1;
 $36 = (((($18) + ($3<<5)|0)) + 28|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (($37) + ($35))|0;
 $39 = (($18) + ($3<<5)|0);
 HEAPF32[$39>>2] = 3.4028234663852886E+38;
 $40 = (((($18) + ($3<<5)|0)) + 4|0);
 HEAPF32[$40>>2] = 3.4028234663852886E+38;
 $41 = (((($18) + ($3<<5)|0)) + 8|0);
 HEAPF32[$41>>2] = 3.4028234663852886E+38;
 $42 = (((($18) + ($3<<5)|0)) + 12|0);
 HEAPF32[$42>>2] = -3.4028234663852886E+38;
 $43 = (((($18) + ($3<<5)|0)) + 16|0);
 HEAPF32[$43>>2] = -3.4028234663852886E+38;
 $44 = (((($18) + ($3<<5)|0)) + 20|0);
 HEAPF32[$44>>2] = -3.4028234663852886E+38;
 $45 = ($37|0)>(0);
 if (!($45)) {
  STACKTOP = sp;return ($3|0);
 }
 $46 = ((($0)) + 40|0);
 $$pre242 = HEAP32[$46>>2]|0;
 $$0188233 = $35;$579 = -3.4028234663852886E+38;$580 = 3.4028234663852886E+38;$581 = -3.4028234663852886E+38;$582 = 3.4028234663852886E+38;$583 = -3.4028234663852886E+38;$584 = 3.4028234663852886E+38;
 while(1) {
  $56 = HEAP32[$0>>2]|0;
  $57 = (($$pre242) + ($$0188233<<2)|0);
  $58 = HEAP32[$57>>2]|0;
  $59 = ((($56)) + 40|0);
  $60 = HEAP32[$59>>2]|0;
  $61 = (($60) + ($58<<2)|0);
  $62 = HEAP32[$61>>2]|0;
  $63 = (($62) + 1)|0;
  $64 = ((($56)) + 52|0);
  $65 = HEAP32[$64>>2]|0;
  $66 = (($65) + ($63<<2)|0);
  $67 = HEAP32[$66>>2]|0;
  $68 = ($67|0)==(0);
  L201: do {
   if ($68) {
    $48 = $584;$49 = $583;$51 = $582;$52 = $581;$54 = $580;$55 = $579;
   } else {
    $69 = (($62) + 2)|0;
    $$0189231 = $69;$$0197230 = $67;$72 = $65;$75 = $56;$82 = $584;$84 = $583;$89 = $582;$91 = $581;$96 = $580;$98 = $579;
    while(1) {
     $70 = (($$0189231) + 1)|0;
     $71 = (($72) + ($$0189231<<2)|0);
     $73 = HEAP32[$71>>2]|0;
     $74 = ((($75)) + 36|0);
     $76 = HEAP32[$74>>2]|0;
     $77 = ((($76)) + 76|0);
     $78 = HEAP32[$77>>2]|0;
     $79 = (($78) + (($73*12)|0)|0);
     $80 = +HEAPF32[$79>>2];
     $81 = $80 < $82;
     if ($81) {
      HEAPF32[$39>>2] = $80;
      $$pre$i = +HEAPF32[$79>>2];
      $585 = $80;$85 = $$pre$i;
     } else {
      $585 = $82;$85 = $80;
     }
     $83 = $85 > $84;
     if ($83) {
      HEAPF32[$42>>2] = $85;
      $586 = $85;
     } else {
      $586 = $84;
     }
     $86 = (((($78) + (($73*12)|0)|0)) + 4|0);
     $87 = +HEAPF32[$86>>2];
     $88 = $87 < $89;
     if ($88) {
      HEAPF32[$40>>2] = $87;
      $$pre13$i = +HEAPF32[$86>>2];
      $587 = $87;$92 = $$pre13$i;
     } else {
      $587 = $89;$92 = $87;
     }
     $90 = $92 > $91;
     if ($90) {
      HEAPF32[$43>>2] = $92;
      $588 = $92;
     } else {
      $588 = $91;
     }
     $93 = (((($78) + (($73*12)|0)|0)) + 8|0);
     $94 = +HEAPF32[$93>>2];
     $95 = $94 < $96;
     if ($95) {
      HEAPF32[$41>>2] = $94;
      $$pre14$i = +HEAPF32[$93>>2];
      $589 = $94;$99 = $$pre14$i;
     } else {
      $589 = $96;$99 = $94;
     }
     $97 = $99 > $98;
     if ($97) {
      HEAPF32[$44>>2] = $99;
      $590 = $99;
     } else {
      $590 = $98;
     }
     $100 = (($$0197230) + -1)|0;
     $101 = ($100|0)==(0);
     if ($101) {
      $48 = $585;$49 = $586;$51 = $587;$52 = $588;$54 = $589;$55 = $590;
      break L201;
     }
     $$pre243 = HEAP32[$0>>2]|0;
     $$phi$trans$insert244 = ((($$pre243)) + 52|0);
     $$pre245 = HEAP32[$$phi$trans$insert244>>2]|0;
     $$0189231 = $70;$$0197230 = $100;$72 = $$pre245;$75 = $$pre243;$82 = $585;$84 = $586;$89 = $587;$91 = $588;$96 = $589;$98 = $590;
    }
   }
  } while(0);
  $102 = (($$0188233) + 1)|0;
  $103 = ($102|0)<($38|0);
  if ($103) {
   $$0188233 = $102;$579 = $55;$580 = $54;$581 = $52;$582 = $51;$583 = $49;$584 = $48;
  } else {
   break;
  }
 }
 $47 = !($49 >= $48);
 $50 = !($52 >= $51);
 $or$cond = $47 | $50;
 $53 = !($55 >= $54);
 $or$cond264 = $or$cond | $53;
 if ($or$cond264) {
  STACKTOP = sp;return ($3|0);
 }
 $104 = $48 + -9.9999999747524271E-7;
 HEAPF32[$39>>2] = $104;
 $105 = $51 + -9.9999999747524271E-7;
 HEAPF32[$40>>2] = $105;
 $106 = $54 + -9.9999999747524271E-7;
 HEAPF32[$41>>2] = $106;
 $107 = $49 + 9.9999999747524271E-7;
 HEAPF32[$42>>2] = $107;
 $108 = $52 + 9.9999999747524271E-7;
 HEAPF32[$43>>2] = $108;
 $109 = $55 + 9.9999999747524271E-7;
 HEAPF32[$44>>2] = $109;
 STACKTOP = sp;return ($3|0);
}
function __ZN3osg29TemplatePrimitiveIndexFunctorI25PrimitiveIndicesCollectorED0Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($0);
 return;
}
function __ZN3osg29TemplatePrimitiveIndexFunctorI25PrimitiveIndicesCollectorE14setVertexArrayEjPKNS_5Vec2fE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN3osg29TemplatePrimitiveIndexFunctorI25PrimitiveIndicesCollectorE14setVertexArrayEjPKNS_5Vec3fE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN3osg29TemplatePrimitiveIndexFunctorI25PrimitiveIndicesCollectorE14setVertexArrayEjPKNS_5Vec4fE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN3osg29TemplatePrimitiveIndexFunctorI25PrimitiveIndicesCollectorE14setVertexArrayEjPKNS_5Vec2dE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN3osg29TemplatePrimitiveIndexFunctorI25PrimitiveIndicesCollectorE14setVertexArrayEjPKNS_5Vec3dE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN3osg29TemplatePrimitiveIndexFunctorI25PrimitiveIndicesCollectorE14setVertexArrayEjPKNS_5Vec4dE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN3osg29TemplatePrimitiveIndexFunctorI25PrimitiveIndicesCollectorE10drawArraysEjii($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0110164 = 0, $$0111162 = 0, $$0112161 = 0, $$0113159 = 0, $$0114158 = 0, $$0115156 = 0, $$0116155 = 0, $$0117153 = 0, $$0118152 = 0, $$0119150 = 0, $$0120149 = 0, $$0121147 = 0, $$0122146 = 0, $$0123144 = 0, $$0124143 = 0, $$0125142 = 0, $$0126141 = 0, $$0165 = 0, $10 = 0, $11 = 0;
 var $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $exitcond174 = 0, $exitcond175 = 0, $exitcond176 = 0, $exitcond177 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 do {
  switch ($1|0) {
  case 4:  {
   $18 = ($3|0)>(2);
   if (!($18)) {
    return;
   }
   $19 = ((($0)) + 4|0);
   $$0125142 = 2;$$0126141 = $2;
   while(1) {
    $20 = (($$0126141) + 1)|0;
    $21 = (($$0126141) + 2)|0;
    __ZN25PrimitiveIndicesCollectorclEjjj($19,$$0126141,$20,$21);
    $22 = (($$0125142) + 3)|0;
    $23 = (($$0126141) + 3)|0;
    $24 = ($22|0)<($3|0);
    if ($24) {
     $$0125142 = $22;$$0126141 = $23;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 5:  {
   $16 = ($3|0)>(2);
   if (!($16)) {
    return;
   }
   $17 = ((($0)) + 4|0);
   $$0123144 = 2;$$0124143 = $2;
   while(1) {
    $25 = $$0123144 & 1;
    $26 = ($25|0)==(0);
    $27 = (($$0124143) + 1)|0;
    $28 = (($$0124143) + 2)|0;
    if ($26) {
     __ZN25PrimitiveIndicesCollectorclEjjj($17,$$0124143,$27,$28);
    } else {
     __ZN25PrimitiveIndicesCollectorclEjjj($17,$$0124143,$28,$27);
    }
    $29 = (($$0123144) + 1)|0;
    $exitcond = ($29|0)==($3|0);
    if ($exitcond) {
     break;
    } else {
     $$0123144 = $29;$$0124143 = $27;
    }
   }
   return;
   break;
  }
  case 7:  {
   $14 = ($3|0)>(3);
   if (!($14)) {
    return;
   }
   $15 = ((($0)) + 4|0);
   $$0121147 = 3;$$0122146 = $2;
   while(1) {
    $30 = (($$0122146) + 1)|0;
    $31 = (($$0122146) + 2)|0;
    $32 = (($$0122146) + 3)|0;
    __ZN25PrimitiveIndicesCollectorclEjjjj($15,$$0122146,$30,$31,$32);
    $33 = (($$0121147) + 4)|0;
    $34 = (($$0122146) + 4)|0;
    $35 = ($33|0)<($3|0);
    if ($35) {
     $$0121147 = $33;$$0122146 = $34;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 8:  {
   $12 = ($3|0)>(3);
   if (!($12)) {
    return;
   }
   $13 = ((($0)) + 4|0);
   $$0119150 = 3;$$0120149 = $2;
   while(1) {
    $36 = (($$0120149) + 1)|0;
    $37 = (($$0120149) + 2)|0;
    $38 = (($$0120149) + 3)|0;
    __ZN25PrimitiveIndicesCollectorclEjjjj($13,$$0120149,$36,$37,$38);
    $39 = (($$0119150) + 2)|0;
    $40 = ($39|0)<($3|0);
    if ($40) {
     $$0119150 = $39;$$0120149 = $37;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 6: case 9:  {
   $41 = ($3|0)>(2);
   if (!($41)) {
    return;
   }
   $42 = (($2) + 1)|0;
   $43 = ((($0)) + 4|0);
   $$0117153 = 2;$$0118152 = $42;
   while(1) {
    $44 = (($$0118152) + 1)|0;
    __ZN25PrimitiveIndicesCollectorclEjjj($43,$2,$$0118152,$44);
    $45 = (($$0117153) + 1)|0;
    $exitcond174 = ($45|0)==($3|0);
    if ($exitcond174) {
     break;
    } else {
     $$0117153 = $45;$$0118152 = $44;
    }
   }
   return;
   break;
  }
  case 0:  {
   $10 = ($3|0)>(0);
   if (!($10)) {
    return;
   }
   $11 = ((($0)) + 4|0);
   $$0115156 = 0;$$0116155 = $2;
   while(1) {
    __ZN25PrimitiveIndicesCollectorclEj($11,$$0116155);
    $46 = (($$0115156) + 1)|0;
    $47 = (($$0116155) + 1)|0;
    $exitcond175 = ($46|0)==($3|0);
    if ($exitcond175) {
     break;
    } else {
     $$0115156 = $46;$$0116155 = $47;
    }
   }
   return;
   break;
  }
  case 1:  {
   $8 = ($3|0)>(1);
   if (!($8)) {
    return;
   }
   $9 = ((($0)) + 4|0);
   $$0113159 = 1;$$0114158 = $2;
   while(1) {
    $48 = (($$0114158) + 1)|0;
    __ZN25PrimitiveIndicesCollectorclEjj($9,$$0114158,$48);
    $49 = (($$0113159) + 2)|0;
    $50 = (($$0114158) + 2)|0;
    $51 = ($49|0)<($3|0);
    if ($51) {
     $$0113159 = $49;$$0114158 = $50;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 3:  {
   $6 = ($3|0)>(1);
   if (!($6)) {
    return;
   }
   $7 = ((($0)) + 4|0);
   $$0111162 = 1;$$0112161 = $2;
   while(1) {
    $52 = (($$0112161) + 1)|0;
    __ZN25PrimitiveIndicesCollectorclEjj($7,$$0112161,$52);
    $53 = (($$0111162) + 1)|0;
    $exitcond176 = ($53|0)==($3|0);
    if ($exitcond176) {
     break;
    } else {
     $$0111162 = $53;$$0112161 = $52;
    }
   }
   return;
   break;
  }
  case 2:  {
   $4 = ($3|0)>(1);
   $5 = ((($0)) + 4|0);
   if ($4) {
    $$0110164 = $2;$$0165 = 1;
    while(1) {
     $56 = (($$0110164) + 1)|0;
     __ZN25PrimitiveIndicesCollectorclEjj($5,$$0110164,$56);
     $57 = (($$0165) + 1)|0;
     $exitcond177 = ($57|0)==($3|0);
     if ($exitcond177) {
      break;
     } else {
      $$0110164 = $56;$$0165 = $57;
     }
    }
   }
   $54 = (($2) + -1)|0;
   $55 = (($54) + ($3))|0;
   __ZN25PrimitiveIndicesCollectorclEjj($5,$55,$2);
   return;
   break;
  }
  default: {
   return;
  }
  }
 } while(0);
}
function __ZN3osg29TemplatePrimitiveIndexFunctorI25PrimitiveIndicesCollectorE12drawElementsEjiPKh($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0117163 = 0, $$0118161 = 0, $$0119160 = 0, $$0120158 = 0, $$0121143 = 0, $$0122156 = 0, $$0123145 = 0, $$0124154 = 0, $$0125144 = 0, $$0126153 = 0, $$0127151 = 0, $$0128150 = 0, $$0129148 = 0, $$0130147 = 0, $$0164 = 0, $$lcssa142 = 0, $$pre = 0, $10 = 0, $100 = 0, $101 = 0;
 var $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $exitcond174 = 0, $exitcond175 = 0, $exitcond176 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ($3|0)==(0|0);
 $5 = ($2|0)==(0);
 $or$cond = $5 | $4;
 if ($or$cond) {
  return;
 }
 do {
  switch ($1|0) {
  case 4:  {
   $18 = (($3) + ($2)|0);
   $19 = ($2|0)>(0);
   if (!($19)) {
    return;
   }
   $20 = ((($0)) + 4|0);
   $$0121143 = $3;
   while(1) {
    $21 = HEAP8[$$0121143>>0]|0;
    $22 = $21&255;
    $23 = ((($$0121143)) + 1|0);
    $24 = HEAP8[$23>>0]|0;
    $25 = $24&255;
    $26 = ((($$0121143)) + 2|0);
    $27 = HEAP8[$26>>0]|0;
    $28 = $27&255;
    __ZN25PrimitiveIndicesCollectorclEjjj($20,$22,$25,$28);
    $29 = ((($$0121143)) + 3|0);
    $30 = ($29>>>0)<($18>>>0);
    if ($30) {
     $$0121143 = $29;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 5:  {
   $16 = ($2|0)>(2);
   if (!($16)) {
    return;
   }
   $17 = ((($0)) + 4|0);
   $$0123145 = $3;$$0125144 = 2;
   while(1) {
    $31 = $$0125144 & 1;
    $32 = ($31|0)==(0);
    $33 = HEAP8[$$0123145>>0]|0;
    $34 = $33&255;
    $35 = ((($$0123145)) + 2|0);
    $36 = HEAP8[$35>>0]|0;
    $37 = ((($$0123145)) + 1|0);
    $38 = HEAP8[$37>>0]|0;
    $39 = $38&255;
    $40 = $36&255;
    if ($32) {
     __ZN25PrimitiveIndicesCollectorclEjjj($17,$34,$39,$40);
    } else {
     __ZN25PrimitiveIndicesCollectorclEjjj($17,$34,$40,$39);
    }
    $41 = (($$0125144) + 1)|0;
    $exitcond = ($41|0)==($2|0);
    if ($exitcond) {
     break;
    } else {
     $$0123145 = $37;$$0125144 = $41;
    }
   }
   return;
   break;
  }
  case 7:  {
   $14 = ($2|0)>(3);
   if (!($14)) {
    return;
   }
   $15 = ((($0)) + 4|0);
   $$0129148 = 3;$$0130147 = $3;
   while(1) {
    $42 = HEAP8[$$0130147>>0]|0;
    $43 = $42&255;
    $44 = ((($$0130147)) + 1|0);
    $45 = HEAP8[$44>>0]|0;
    $46 = $45&255;
    $47 = ((($$0130147)) + 2|0);
    $48 = HEAP8[$47>>0]|0;
    $49 = $48&255;
    $50 = ((($$0130147)) + 3|0);
    $51 = HEAP8[$50>>0]|0;
    $52 = $51&255;
    __ZN25PrimitiveIndicesCollectorclEjjjj($15,$43,$46,$49,$52);
    $53 = (($$0129148) + 4)|0;
    $54 = ((($$0130147)) + 4|0);
    $55 = ($53|0)<($2|0);
    if ($55) {
     $$0129148 = $53;$$0130147 = $54;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 8:  {
   $12 = ($2|0)>(3);
   if (!($12)) {
    return;
   }
   $13 = ((($0)) + 4|0);
   $$0127151 = 3;$$0128150 = $3;
   while(1) {
    $56 = HEAP8[$$0128150>>0]|0;
    $57 = $56&255;
    $58 = ((($$0128150)) + 1|0);
    $59 = HEAP8[$58>>0]|0;
    $60 = $59&255;
    $61 = ((($$0128150)) + 2|0);
    $62 = HEAP8[$61>>0]|0;
    $63 = $62&255;
    $64 = ((($$0128150)) + 3|0);
    $65 = HEAP8[$64>>0]|0;
    $66 = $65&255;
    __ZN25PrimitiveIndicesCollectorclEjjjj($13,$57,$60,$63,$66);
    $67 = (($$0127151) + 2)|0;
    $68 = ($67|0)<($2|0);
    if ($68) {
     $$0127151 = $67;$$0128150 = $61;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 6: case 9:  {
   $69 = ($2|0)>(2);
   if (!($69)) {
    return;
   }
   $70 = ((($3)) + 1|0);
   $71 = HEAP8[$3>>0]|0;
   $72 = ((($0)) + 4|0);
   $73 = $71&255;
   $$0124154 = 2;$$0126153 = $70;
   while(1) {
    $74 = HEAP8[$$0126153>>0]|0;
    $75 = $74&255;
    $76 = ((($$0126153)) + 1|0);
    $77 = HEAP8[$76>>0]|0;
    $78 = $77&255;
    __ZN25PrimitiveIndicesCollectorclEjjj($72,$73,$75,$78);
    $79 = (($$0124154) + 1)|0;
    $exitcond174 = ($79|0)==($2|0);
    if ($exitcond174) {
     break;
    } else {
     $$0124154 = $79;$$0126153 = $76;
    }
   }
   return;
   break;
  }
  case 0:  {
   $80 = (($3) + ($2)|0);
   $81 = ($2|0)>(0);
   if (!($81)) {
    return;
   }
   $82 = ((($0)) + 4|0);
   $$0122156 = $3;
   while(1) {
    $83 = HEAP8[$$0122156>>0]|0;
    $84 = $83&255;
    __ZN25PrimitiveIndicesCollectorclEj($82,$84);
    $85 = ((($$0122156)) + 1|0);
    $86 = ($85>>>0)<($80>>>0);
    if ($86) {
     $$0122156 = $85;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 1:  {
   $87 = (($3) + ($2)|0);
   $88 = ($2|0)>(0);
   if (!($88)) {
    return;
   }
   $89 = ((($0)) + 4|0);
   $$0120158 = $3;
   while(1) {
    $90 = HEAP8[$$0120158>>0]|0;
    $91 = $90&255;
    $92 = ((($$0120158)) + 1|0);
    $93 = HEAP8[$92>>0]|0;
    $94 = $93&255;
    __ZN25PrimitiveIndicesCollectorclEjj($89,$91,$94);
    $95 = ((($$0120158)) + 2|0);
    $96 = ($95>>>0)<($87>>>0);
    if ($96) {
     $$0120158 = $95;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 3:  {
   $10 = ($2|0)>(1);
   if (!($10)) {
    return;
   }
   $11 = ((($0)) + 4|0);
   $$0118161 = 1;$$0119160 = $3;
   while(1) {
    $97 = HEAP8[$$0119160>>0]|0;
    $98 = $97&255;
    $99 = ((($$0119160)) + 1|0);
    $100 = HEAP8[$99>>0]|0;
    $101 = $100&255;
    __ZN25PrimitiveIndicesCollectorclEjj($11,$98,$101);
    $102 = (($$0118161) + 1)|0;
    $exitcond175 = ($102|0)==($2|0);
    if ($exitcond175) {
     break;
    } else {
     $$0118161 = $102;$$0119160 = $99;
    }
   }
   return;
   break;
  }
  case 2:  {
   $6 = ($2|0)>(1);
   $7 = HEAP8[$3>>0]|0;
   $8 = $7&255;
   $9 = ((($0)) + 4|0);
   if ($6) {
    $$0117163 = $3;$$0164 = 1;$108 = $8;
    while(1) {
     $105 = ((($$0117163)) + 1|0);
     $106 = HEAP8[$105>>0]|0;
     $107 = $106&255;
     __ZN25PrimitiveIndicesCollectorclEjj($9,$108,$107);
     $109 = (($$0164) + 1)|0;
     $110 = HEAP8[$105>>0]|0;
     $111 = $110&255;
     $exitcond176 = ($109|0)==($2|0);
     if ($exitcond176) {
      break;
     } else {
      $$0117163 = $105;$$0164 = $109;$108 = $111;
     }
    }
    $$pre = HEAP8[$3>>0]|0;
    $$lcssa142 = $111;$104 = $$pre;
   } else {
    $$lcssa142 = $8;$104 = $7;
   }
   $103 = $104&255;
   __ZN25PrimitiveIndicesCollectorclEjj($9,$$lcssa142,$103);
   return;
   break;
  }
  default: {
   return;
  }
  }
 } while(0);
}
function __ZN3osg29TemplatePrimitiveIndexFunctorI25PrimitiveIndicesCollectorE12drawElementsEjiPKt($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0119165 = 0, $$0120163 = 0, $$0121162 = 0, $$0122160 = 0, $$0123145 = 0, $$0124158 = 0, $$0125147 = 0, $$0126156 = 0, $$0127146 = 0, $$0128155 = 0, $$0129153 = 0, $$0130152 = 0, $$0131150 = 0, $$0132149 = 0, $$0166 = 0, $$lcssa144 = 0, $$pre = 0, $10 = 0, $100 = 0, $101 = 0;
 var $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $exitcond176 = 0, $exitcond177 = 0, $exitcond178 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ($3|0)==(0|0);
 $5 = ($2|0)==(0);
 $or$cond = $5 | $4;
 if ($or$cond) {
  return;
 }
 do {
  switch ($1|0) {
  case 4:  {
   $18 = (($3) + ($2<<1)|0);
   $19 = ($2|0)>(0);
   if (!($19)) {
    return;
   }
   $20 = ((($0)) + 4|0);
   $$0123145 = $3;
   while(1) {
    $21 = HEAP16[$$0123145>>1]|0;
    $22 = $21&65535;
    $23 = ((($$0123145)) + 2|0);
    $24 = HEAP16[$23>>1]|0;
    $25 = $24&65535;
    $26 = ((($$0123145)) + 4|0);
    $27 = HEAP16[$26>>1]|0;
    $28 = $27&65535;
    __ZN25PrimitiveIndicesCollectorclEjjj($20,$22,$25,$28);
    $29 = ((($$0123145)) + 6|0);
    $30 = ($29>>>0)<($18>>>0);
    if ($30) {
     $$0123145 = $29;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 5:  {
   $16 = ($2|0)>(2);
   if (!($16)) {
    return;
   }
   $17 = ((($0)) + 4|0);
   $$0125147 = $3;$$0127146 = 2;
   while(1) {
    $31 = $$0127146 & 1;
    $32 = ($31|0)==(0);
    $33 = HEAP16[$$0125147>>1]|0;
    $34 = $33&65535;
    $35 = ((($$0125147)) + 4|0);
    $36 = HEAP16[$35>>1]|0;
    $37 = ((($$0125147)) + 2|0);
    $38 = HEAP16[$37>>1]|0;
    $39 = $38&65535;
    $40 = $36&65535;
    if ($32) {
     __ZN25PrimitiveIndicesCollectorclEjjj($17,$34,$39,$40);
    } else {
     __ZN25PrimitiveIndicesCollectorclEjjj($17,$34,$40,$39);
    }
    $41 = (($$0127146) + 1)|0;
    $exitcond = ($41|0)==($2|0);
    if ($exitcond) {
     break;
    } else {
     $$0125147 = $37;$$0127146 = $41;
    }
   }
   return;
   break;
  }
  case 7:  {
   $14 = ($2|0)>(3);
   if (!($14)) {
    return;
   }
   $15 = ((($0)) + 4|0);
   $$0131150 = 3;$$0132149 = $3;
   while(1) {
    $42 = HEAP16[$$0132149>>1]|0;
    $43 = $42&65535;
    $44 = ((($$0132149)) + 2|0);
    $45 = HEAP16[$44>>1]|0;
    $46 = $45&65535;
    $47 = ((($$0132149)) + 4|0);
    $48 = HEAP16[$47>>1]|0;
    $49 = $48&65535;
    $50 = ((($$0132149)) + 6|0);
    $51 = HEAP16[$50>>1]|0;
    $52 = $51&65535;
    __ZN25PrimitiveIndicesCollectorclEjjjj($15,$43,$46,$49,$52);
    $53 = (($$0131150) + 4)|0;
    $54 = ((($$0132149)) + 8|0);
    $55 = ($53|0)<($2|0);
    if ($55) {
     $$0131150 = $53;$$0132149 = $54;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 8:  {
   $12 = ($2|0)>(3);
   if (!($12)) {
    return;
   }
   $13 = ((($0)) + 4|0);
   $$0129153 = 3;$$0130152 = $3;
   while(1) {
    $56 = HEAP16[$$0130152>>1]|0;
    $57 = $56&65535;
    $58 = ((($$0130152)) + 2|0);
    $59 = HEAP16[$58>>1]|0;
    $60 = $59&65535;
    $61 = ((($$0130152)) + 4|0);
    $62 = HEAP16[$61>>1]|0;
    $63 = $62&65535;
    $64 = ((($$0130152)) + 6|0);
    $65 = HEAP16[$64>>1]|0;
    $66 = $65&65535;
    __ZN25PrimitiveIndicesCollectorclEjjjj($13,$57,$60,$63,$66);
    $67 = (($$0129153) + 2)|0;
    $68 = ($67|0)<($2|0);
    if ($68) {
     $$0129153 = $67;$$0130152 = $61;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 6: case 9:  {
   $69 = ($2|0)>(2);
   if (!($69)) {
    return;
   }
   $70 = ((($3)) + 2|0);
   $71 = HEAP16[$3>>1]|0;
   $72 = ((($0)) + 4|0);
   $73 = $71&65535;
   $$0126156 = 2;$$0128155 = $70;
   while(1) {
    $74 = HEAP16[$$0128155>>1]|0;
    $75 = $74&65535;
    $76 = ((($$0128155)) + 2|0);
    $77 = HEAP16[$76>>1]|0;
    $78 = $77&65535;
    __ZN25PrimitiveIndicesCollectorclEjjj($72,$73,$75,$78);
    $79 = (($$0126156) + 1)|0;
    $exitcond176 = ($79|0)==($2|0);
    if ($exitcond176) {
     break;
    } else {
     $$0126156 = $79;$$0128155 = $76;
    }
   }
   return;
   break;
  }
  case 0:  {
   $80 = (($3) + ($2<<1)|0);
   $81 = ($2|0)>(0);
   if (!($81)) {
    return;
   }
   $82 = ((($0)) + 4|0);
   $$0124158 = $3;
   while(1) {
    $83 = HEAP16[$$0124158>>1]|0;
    $84 = $83&65535;
    __ZN25PrimitiveIndicesCollectorclEj($82,$84);
    $85 = ((($$0124158)) + 2|0);
    $86 = ($85>>>0)<($80>>>0);
    if ($86) {
     $$0124158 = $85;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 1:  {
   $87 = (($3) + ($2<<1)|0);
   $88 = ($2|0)>(0);
   if (!($88)) {
    return;
   }
   $89 = ((($0)) + 4|0);
   $$0122160 = $3;
   while(1) {
    $90 = HEAP16[$$0122160>>1]|0;
    $91 = $90&65535;
    $92 = ((($$0122160)) + 2|0);
    $93 = HEAP16[$92>>1]|0;
    $94 = $93&65535;
    __ZN25PrimitiveIndicesCollectorclEjj($89,$91,$94);
    $95 = ((($$0122160)) + 4|0);
    $96 = ($95>>>0)<($87>>>0);
    if ($96) {
     $$0122160 = $95;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 3:  {
   $10 = ($2|0)>(1);
   if (!($10)) {
    return;
   }
   $11 = ((($0)) + 4|0);
   $$0120163 = 1;$$0121162 = $3;
   while(1) {
    $97 = HEAP16[$$0121162>>1]|0;
    $98 = $97&65535;
    $99 = ((($$0121162)) + 2|0);
    $100 = HEAP16[$99>>1]|0;
    $101 = $100&65535;
    __ZN25PrimitiveIndicesCollectorclEjj($11,$98,$101);
    $102 = (($$0120163) + 1)|0;
    $exitcond177 = ($102|0)==($2|0);
    if ($exitcond177) {
     break;
    } else {
     $$0120163 = $102;$$0121162 = $99;
    }
   }
   return;
   break;
  }
  case 2:  {
   $6 = ($2|0)>(1);
   $7 = HEAP16[$3>>1]|0;
   $8 = $7&65535;
   $9 = ((($0)) + 4|0);
   if ($6) {
    $$0119165 = $3;$$0166 = 1;$108 = $8;
    while(1) {
     $105 = ((($$0119165)) + 2|0);
     $106 = HEAP16[$105>>1]|0;
     $107 = $106&65535;
     __ZN25PrimitiveIndicesCollectorclEjj($9,$108,$107);
     $109 = (($$0166) + 1)|0;
     $110 = HEAP16[$105>>1]|0;
     $111 = $110&65535;
     $exitcond178 = ($109|0)==($2|0);
     if ($exitcond178) {
      break;
     } else {
      $$0119165 = $105;$$0166 = $109;$108 = $111;
     }
    }
    $$pre = HEAP16[$3>>1]|0;
    $$lcssa144 = $111;$104 = $$pre;
   } else {
    $$lcssa144 = $8;$104 = $7;
   }
   $103 = $104&65535;
   __ZN25PrimitiveIndicesCollectorclEjj($9,$$lcssa144,$103);
   return;
   break;
  }
  default: {
   return;
  }
  }
 } while(0);
}
function __ZN3osg29TemplatePrimitiveIndexFunctorI25PrimitiveIndicesCollectorE12drawElementsEjiPKj($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0119165 = 0, $$0120163 = 0, $$0121162 = 0, $$0122160 = 0, $$0123145 = 0, $$0124158 = 0, $$0125147 = 0, $$0126156 = 0, $$0127146 = 0, $$0128155 = 0, $$0129153 = 0, $$0130152 = 0, $$0131150 = 0, $$0132149 = 0, $$0166 = 0, $$lcssa144 = 0, $$pre = 0, $10 = 0, $11 = 0, $12 = 0;
 var $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $exitcond = 0;
 var $exitcond176 = 0, $exitcond177 = 0, $exitcond178 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ($3|0)==(0|0);
 $5 = ($2|0)==(0);
 $or$cond = $5 | $4;
 if ($or$cond) {
  return;
 }
 do {
  switch ($1|0) {
  case 4:  {
   $17 = (($3) + ($2<<2)|0);
   $18 = ($2|0)>(0);
   if (!($18)) {
    return;
   }
   $19 = ((($0)) + 4|0);
   $$0123145 = $3;
   while(1) {
    $20 = HEAP32[$$0123145>>2]|0;
    $21 = ((($$0123145)) + 4|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = ((($$0123145)) + 8|0);
    $24 = HEAP32[$23>>2]|0;
    __ZN25PrimitiveIndicesCollectorclEjjj($19,$20,$22,$24);
    $25 = ((($$0123145)) + 12|0);
    $26 = ($25>>>0)<($17>>>0);
    if ($26) {
     $$0123145 = $25;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 5:  {
   $15 = ($2|0)>(2);
   if (!($15)) {
    return;
   }
   $16 = ((($0)) + 4|0);
   $$0125147 = $3;$$0127146 = 2;
   while(1) {
    $27 = $$0127146 & 1;
    $28 = ($27|0)==(0);
    $29 = HEAP32[$$0125147>>2]|0;
    $30 = ((($$0125147)) + 8|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = ((($$0125147)) + 4|0);
    $33 = HEAP32[$32>>2]|0;
    if ($28) {
     __ZN25PrimitiveIndicesCollectorclEjjj($16,$29,$33,$31);
    } else {
     __ZN25PrimitiveIndicesCollectorclEjjj($16,$29,$31,$33);
    }
    $34 = (($$0127146) + 1)|0;
    $exitcond = ($34|0)==($2|0);
    if ($exitcond) {
     break;
    } else {
     $$0125147 = $32;$$0127146 = $34;
    }
   }
   return;
   break;
  }
  case 7:  {
   $13 = ($2|0)>(3);
   if (!($13)) {
    return;
   }
   $14 = ((($0)) + 4|0);
   $$0131150 = 3;$$0132149 = $3;
   while(1) {
    $35 = HEAP32[$$0132149>>2]|0;
    $36 = ((($$0132149)) + 4|0);
    $37 = HEAP32[$36>>2]|0;
    $38 = ((($$0132149)) + 8|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = ((($$0132149)) + 12|0);
    $41 = HEAP32[$40>>2]|0;
    __ZN25PrimitiveIndicesCollectorclEjjjj($14,$35,$37,$39,$41);
    $42 = (($$0131150) + 4)|0;
    $43 = ((($$0132149)) + 16|0);
    $44 = ($42|0)<($2|0);
    if ($44) {
     $$0131150 = $42;$$0132149 = $43;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 8:  {
   $11 = ($2|0)>(3);
   if (!($11)) {
    return;
   }
   $12 = ((($0)) + 4|0);
   $$0129153 = 3;$$0130152 = $3;
   while(1) {
    $45 = HEAP32[$$0130152>>2]|0;
    $46 = ((($$0130152)) + 4|0);
    $47 = HEAP32[$46>>2]|0;
    $48 = ((($$0130152)) + 8|0);
    $49 = HEAP32[$48>>2]|0;
    $50 = ((($$0130152)) + 12|0);
    $51 = HEAP32[$50>>2]|0;
    __ZN25PrimitiveIndicesCollectorclEjjjj($12,$45,$47,$49,$51);
    $52 = (($$0129153) + 2)|0;
    $53 = ($52|0)<($2|0);
    if ($53) {
     $$0129153 = $52;$$0130152 = $48;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 6: case 9:  {
   $54 = HEAP32[$3>>2]|0;
   $55 = ($2|0)>(2);
   if (!($55)) {
    return;
   }
   $56 = ((($3)) + 4|0);
   $57 = ((($0)) + 4|0);
   $$0126156 = 2;$$0128155 = $56;
   while(1) {
    $58 = HEAP32[$$0128155>>2]|0;
    $59 = ((($$0128155)) + 4|0);
    $60 = HEAP32[$59>>2]|0;
    __ZN25PrimitiveIndicesCollectorclEjjj($57,$54,$58,$60);
    $61 = (($$0126156) + 1)|0;
    $exitcond176 = ($61|0)==($2|0);
    if ($exitcond176) {
     break;
    } else {
     $$0126156 = $61;$$0128155 = $59;
    }
   }
   return;
   break;
  }
  case 0:  {
   $62 = (($3) + ($2<<2)|0);
   $63 = ($2|0)>(0);
   if (!($63)) {
    return;
   }
   $64 = ((($0)) + 4|0);
   $$0124158 = $3;
   while(1) {
    $65 = HEAP32[$$0124158>>2]|0;
    __ZN25PrimitiveIndicesCollectorclEj($64,$65);
    $66 = ((($$0124158)) + 4|0);
    $67 = ($66>>>0)<($62>>>0);
    if ($67) {
     $$0124158 = $66;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 1:  {
   $68 = (($3) + ($2<<2)|0);
   $69 = ($2|0)>(0);
   if (!($69)) {
    return;
   }
   $70 = ((($0)) + 4|0);
   $$0122160 = $3;
   while(1) {
    $71 = HEAP32[$$0122160>>2]|0;
    $72 = ((($$0122160)) + 4|0);
    $73 = HEAP32[$72>>2]|0;
    __ZN25PrimitiveIndicesCollectorclEjj($70,$71,$73);
    $74 = ((($$0122160)) + 8|0);
    $75 = ($74>>>0)<($68>>>0);
    if ($75) {
     $$0122160 = $74;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 3:  {
   $9 = ($2|0)>(1);
   if (!($9)) {
    return;
   }
   $10 = ((($0)) + 4|0);
   $$0120163 = 1;$$0121162 = $3;
   while(1) {
    $76 = HEAP32[$$0121162>>2]|0;
    $77 = ((($$0121162)) + 4|0);
    $78 = HEAP32[$77>>2]|0;
    __ZN25PrimitiveIndicesCollectorclEjj($10,$76,$78);
    $79 = (($$0120163) + 1)|0;
    $exitcond177 = ($79|0)==($2|0);
    if ($exitcond177) {
     break;
    } else {
     $$0120163 = $79;$$0121162 = $77;
    }
   }
   return;
   break;
  }
  case 2:  {
   $6 = ($2|0)>(1);
   $7 = HEAP32[$3>>2]|0;
   $8 = ((($0)) + 4|0);
   if ($6) {
    $$0119165 = $3;$$0166 = 1;$83 = $7;
    while(1) {
     $81 = ((($$0119165)) + 4|0);
     $82 = HEAP32[$81>>2]|0;
     __ZN25PrimitiveIndicesCollectorclEjj($8,$83,$82);
     $84 = (($$0166) + 1)|0;
     $85 = HEAP32[$81>>2]|0;
     $exitcond178 = ($84|0)==($2|0);
     if ($exitcond178) {
      break;
     } else {
      $$0119165 = $81;$$0166 = $84;$83 = $85;
     }
    }
    $$pre = HEAP32[$3>>2]|0;
    $$lcssa144 = $85;$80 = $$pre;
   } else {
    $$lcssa144 = $7;$80 = $7;
   }
   __ZN25PrimitiveIndicesCollectorclEjj($8,$$lcssa144,$80);
   return;
   break;
  }
  default: {
   return;
  }
  }
 } while(0);
}
function __ZN25PrimitiveIndicesCollectorclEjjj($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$phi$trans$insert = 0, $$pre = 0, $$pre$phi57Z2D = 0, $$pre$phiZ2D = 0, $$pre54 = 0, $$pre55 = 0, $$pre56 = 0, $$sroa$0$0 = 0.0, $$sroa$0$1 = 0.0, $$sroa$0$2 = 0.0, $$sroa$10$0 = 0.0, $$sroa$10$1 = 0.0, $$sroa$10$2 = 0.0, $$sroa$18$0 = 0.0, $$sroa$18$1 = 0.0, $$sroa$18$2 = 0.0, $$sroa$26$0 = 0.0, $$sroa$26$1 = 0.0, $$sroa$26$2 = 0.0, $$sroa$34$0 = 0.0;
 var $$sroa$34$1 = 0.0, $$sroa$34$2 = 0.0, $$sroa$42$0 = 0.0, $$sroa$42$1 = 0.0, $$sroa$42$2 = 0.0, $10 = 0, $100 = 0.0, $101 = 0.0, $102 = 0.0, $103 = 0.0, $104 = 0.0, $105 = 0.0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $12 = 0, $13 = 0.0, $14 = 0, $15 = 0.0, $16 = 0, $17 = 0, $18 = 0.0, $19 = 0, $20 = 0.0, $21 = 0, $22 = 0, $23 = 0.0, $24 = 0, $25 = 0.0, $26 = 0, $27 = 0;
 var $28 = 0.0, $29 = 0, $30 = 0, $31 = 0.0, $32 = 0, $33 = 0.0, $34 = 0, $35 = 0, $36 = 0.0, $37 = 0, $38 = 0.0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0.0, $43 = 0, $44 = 0.0, $45 = 0, $46 = 0;
 var $47 = 0.0, $48 = 0, $49 = 0.0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0.0, $55 = 0, $56 = 0, $57 = 0.0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0.0, $62 = 0, $63 = 0, $64 = 0.0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0.0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0.0, $73 = 0, $74 = 0, $75 = 0.0, $76 = 0, $77 = 0, $78 = 0.0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0.0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $4 = sp + 12|0;
 $5 = sp;
 $6 = HEAP32[$0>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($7)) + 36|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($9)) + 76|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($11) + (($1*12)|0)|0);
 $13 = +HEAPF32[$12>>2];
 $14 = (($11) + (($2*12)|0)|0);
 $15 = +HEAPF32[$14>>2];
 $16 = $13 == $15;
 if ($16) {
  $17 = (((($11) + (($1*12)|0)|0)) + 4|0);
  $18 = +HEAPF32[$17>>2];
  $19 = (((($11) + (($2*12)|0)|0)) + 4|0);
  $20 = +HEAPF32[$19>>2];
  $21 = $18 == $20;
  if ($21) {
   $22 = (((($11) + (($1*12)|0)|0)) + 8|0);
   $23 = +HEAPF32[$22>>2];
   $24 = (((($11) + (($2*12)|0)|0)) + 8|0);
   $25 = +HEAPF32[$24>>2];
   $26 = $23 == $25;
   if (!($26)) {
    label = 4;
   }
  } else {
   label = 4;
  }
 } else {
  label = 4;
 }
 do {
  if ((label|0) == 4) {
   $27 = (($11) + (($3*12)|0)|0);
   $28 = +HEAPF32[$27>>2];
   $29 = $15 == $28;
   if ($29) {
    $30 = (((($11) + (($2*12)|0)|0)) + 4|0);
    $31 = +HEAPF32[$30>>2];
    $32 = (((($11) + (($3*12)|0)|0)) + 4|0);
    $33 = +HEAPF32[$32>>2];
    $34 = $31 == $33;
    if ($34) {
     $35 = (((($11) + (($2*12)|0)|0)) + 8|0);
     $36 = +HEAPF32[$35>>2];
     $37 = (((($11) + (($3*12)|0)|0)) + 8|0);
     $38 = +HEAPF32[$37>>2];
     $39 = $36 == $38;
     if ($39) {
      break;
     }
    }
   }
   $40 = $28 == $13;
   if ($40) {
    $41 = (((($11) + (($3*12)|0)|0)) + 4|0);
    $42 = +HEAPF32[$41>>2];
    $43 = (((($11) + (($1*12)|0)|0)) + 4|0);
    $44 = +HEAPF32[$43>>2];
    $45 = $42 == $44;
    if ($45) {
     $46 = (((($11) + (($3*12)|0)|0)) + 8|0);
     $47 = +HEAPF32[$46>>2];
     $48 = (((($11) + (($1*12)|0)|0)) + 8|0);
     $49 = +HEAPF32[$48>>2];
     $50 = $47 == $49;
     if ($50) {
      break;
     } else {
      $$pre$phi57Z2D = $41;$$pre$phiZ2D = $43;
     }
    } else {
     $$pre$phi57Z2D = $41;$$pre$phiZ2D = $43;
    }
   } else {
    $$pre55 = (((($11) + (($1*12)|0)|0)) + 4|0);
    $$pre56 = (((($11) + (($3*12)|0)|0)) + 4|0);
    $$pre$phi57Z2D = $$pre56;$$pre$phiZ2D = $$pre55;
   }
   (__ZN3osg6KdTree11addTriangleEjjj($7,$1,$2,$3)|0);
   $54 = +HEAPF32[$12>>2];
   $55 = $54 < 3.4028234663852886E+38;
   $$sroa$0$0 = $55 ? $54 : 3.4028234663852886E+38;
   $56 = $54 > -3.4028234663852886E+38;
   $$sroa$26$0 = $56 ? $54 : -3.4028234663852886E+38;
   $57 = +HEAPF32[$$pre$phiZ2D>>2];
   $58 = $57 < 3.4028234663852886E+38;
   $$sroa$10$0 = $58 ? $57 : 3.4028234663852886E+38;
   $59 = $57 > -3.4028234663852886E+38;
   $$sroa$34$0 = $59 ? $57 : -3.4028234663852886E+38;
   $60 = (((($11) + (($1*12)|0)|0)) + 8|0);
   $61 = +HEAPF32[$60>>2];
   $62 = $61 < 3.4028234663852886E+38;
   $$sroa$18$0 = $62 ? $61 : 3.4028234663852886E+38;
   $63 = $61 > -3.4028234663852886E+38;
   $$sroa$42$0 = $63 ? $61 : -3.4028234663852886E+38;
   $64 = +HEAPF32[$14>>2];
   $65 = $64 < $$sroa$0$0;
   $$sroa$0$1 = $65 ? $64 : $$sroa$0$0;
   $66 = $64 > $$sroa$26$0;
   $$sroa$26$1 = $66 ? $64 : $$sroa$26$0;
   $67 = (((($11) + (($2*12)|0)|0)) + 4|0);
   $68 = +HEAPF32[$67>>2];
   $69 = $68 < $$sroa$10$0;
   $$sroa$10$1 = $69 ? $68 : $$sroa$10$0;
   $70 = $68 > $$sroa$34$0;
   $$sroa$34$1 = $70 ? $68 : $$sroa$34$0;
   $71 = (((($11) + (($2*12)|0)|0)) + 8|0);
   $72 = +HEAPF32[$71>>2];
   $73 = $72 < $$sroa$18$0;
   $$sroa$18$1 = $73 ? $72 : $$sroa$18$0;
   $74 = $72 > $$sroa$42$0;
   $$sroa$42$1 = $74 ? $72 : $$sroa$42$0;
   $75 = +HEAPF32[$27>>2];
   $76 = $75 < $$sroa$0$1;
   $$sroa$0$2 = $76 ? $75 : $$sroa$0$1;
   $77 = $75 > $$sroa$26$1;
   $$sroa$26$2 = $77 ? $75 : $$sroa$26$1;
   $78 = +HEAPF32[$$pre$phi57Z2D>>2];
   $79 = $78 < $$sroa$10$1;
   $$sroa$10$2 = $79 ? $78 : $$sroa$10$1;
   $80 = $78 > $$sroa$34$1;
   $$sroa$34$2 = $80 ? $78 : $$sroa$34$1;
   $81 = (((($11) + (($3*12)|0)|0)) + 8|0);
   $82 = +HEAPF32[$81>>2];
   $83 = $82 < $$sroa$18$1;
   $$sroa$18$2 = $83 ? $82 : $$sroa$18$1;
   $84 = $82 > $$sroa$42$1;
   $$sroa$42$2 = $84 ? $82 : $$sroa$42$1;
   $85 = HEAP32[$0>>2]|0;
   $86 = ((($85)) + 52|0);
   $87 = ((($85)) + 56|0);
   $88 = HEAP32[$87>>2]|0;
   $89 = HEAP32[$86>>2]|0;
   $90 = (($88) - ($89))|0;
   $91 = (($90|0) / 12)&-1;
   HEAP32[$4>>2] = $91;
   $92 = ((($85)) + 44|0);
   $93 = HEAP32[$92>>2]|0;
   $94 = ((($85)) + 48|0);
   $95 = HEAP32[$94>>2]|0;
   $96 = ($93|0)==($95|0);
   if ($96) {
    $99 = ((($85)) + 40|0);
    __ZNSt3__26vectorIjNS_9allocatorIjEEE21__push_back_slow_pathIKjEEvRT_($99,$4);
    $$pre = HEAP32[$0>>2]|0;
    $$phi$trans$insert = ((($$pre)) + 56|0);
    $$pre54 = HEAP32[$$phi$trans$insert>>2]|0;
    $109 = $$pre;$112 = $$pre54;
   } else {
    $97 = $88;
    HEAP32[$93>>2] = $91;
    $98 = ((($93)) + 4|0);
    HEAP32[$92>>2] = $98;
    $109 = $85;$112 = $97;
   }
   $100 = $$sroa$0$2 + $$sroa$26$2;
   $101 = $$sroa$10$2 + $$sroa$34$2;
   $102 = $$sroa$18$2 + $$sroa$42$2;
   $103 = $100 * 0.5;
   $104 = $101 * 0.5;
   $105 = $102 * 0.5;
   HEAPF32[$5>>2] = $103;
   $106 = ((($5)) + 4|0);
   HEAPF32[$106>>2] = $104;
   $107 = ((($5)) + 8|0);
   HEAPF32[$107>>2] = $105;
   $108 = ((($109)) + 56|0);
   $110 = ((($109)) + 60|0);
   $111 = HEAP32[$110>>2]|0;
   $113 = ($112|0)==($111|0);
   if ($113) {
    $116 = ((($109)) + 52|0);
    __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($116,$5);
   } else {
    ;HEAP32[$112>>2]=HEAP32[$5>>2]|0;HEAP32[$112+4>>2]=HEAP32[$5+4>>2]|0;HEAP32[$112+8>>2]=HEAP32[$5+8>>2]|0;
    $114 = HEAP32[$108>>2]|0;
    $115 = ((($114)) + 12|0);
    HEAP32[$108>>2] = $115;
   }
   STACKTOP = sp;return;
  }
 } while(0);
 $51 = ((($7)) + 32|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = (($52) + 1)|0;
 HEAP32[$51>>2] = $53;
 STACKTOP = sp;return;
}
function __ZN25PrimitiveIndicesCollectorclEjjjj($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$phi$trans$insert = 0, $$pre = 0, $$pre$phi81Z2D = 0, $$pre$phiZ2D = 0, $$pre78 = 0, $$pre79 = 0, $$pre80 = 0, $$sroa$0$0 = 0.0, $$sroa$0$1 = 0.0, $$sroa$0$2 = 0.0, $$sroa$0$3 = 0.0, $$sroa$12$0 = 0.0, $$sroa$12$1 = 0.0, $$sroa$12$2 = 0.0, $$sroa$12$3 = 0.0, $$sroa$22$0 = 0.0, $$sroa$22$1 = 0.0, $$sroa$22$2 = 0.0, $$sroa$22$3 = 0.0, $$sroa$32$0 = 0.0;
 var $$sroa$32$1 = 0.0, $$sroa$32$2 = 0.0, $$sroa$32$3 = 0.0, $$sroa$42$0 = 0.0, $$sroa$42$1 = 0.0, $$sroa$42$2 = 0.0, $$sroa$42$3 = 0.0, $$sroa$52$0 = 0.0, $$sroa$52$1 = 0.0, $$sroa$52$2 = 0.0, $$sroa$52$3 = 0.0, $10 = 0, $100 = 0, $101 = 0.0, $102 = 0, $103 = 0, $104 = 0, $105 = 0.0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0.0, $11 = 0, $110 = 0, $111 = 0, $112 = 0.0, $113 = 0, $114 = 0, $115 = 0.0, $116 = 0, $117 = 0, $118 = 0, $119 = 0.0, $12 = 0, $120 = 0, $121 = 0, $122 = 0.0, $123 = 0, $124 = 0, $125 = 0.0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0.0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0.0, $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $147 = 0.0, $148 = 0.0, $149 = 0.0, $15 = 0, $150 = 0.0, $151 = 0.0, $152 = 0.0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0.0, $160 = 0, $161 = 0;
 var $162 = 0, $163 = 0, $17 = 0, $18 = 0, $19 = 0.0, $20 = 0, $21 = 0.0, $22 = 0, $23 = 0, $24 = 0.0, $25 = 0, $26 = 0.0, $27 = 0, $28 = 0, $29 = 0.0, $30 = 0, $31 = 0, $32 = 0.0, $33 = 0, $34 = 0.0;
 var $35 = 0, $36 = 0, $37 = 0.0, $38 = 0, $39 = 0.0, $40 = 0, $41 = 0, $42 = 0, $43 = 0.0, $44 = 0, $45 = 0.0, $46 = 0, $47 = 0, $48 = 0.0, $49 = 0, $5 = 0, $50 = 0.0, $51 = 0, $52 = 0, $53 = 0.0;
 var $54 = 0, $55 = 0, $56 = 0.0, $57 = 0, $58 = 0.0, $59 = 0, $6 = 0, $60 = 0, $61 = 0.0, $62 = 0, $63 = 0.0, $64 = 0, $65 = 0, $66 = 0, $67 = 0.0, $68 = 0, $69 = 0.0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0.0, $73 = 0, $74 = 0.0, $75 = 0, $76 = 0, $77 = 0, $78 = 0.0, $79 = 0, $8 = 0, $80 = 0.0, $81 = 0, $82 = 0, $83 = 0.0, $84 = 0, $85 = 0.0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0.0, $91 = 0, $92 = 0, $93 = 0, $94 = 0.0, $95 = 0, $96 = 0, $97 = 0, $98 = 0.0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $5 = sp + 12|0;
 $6 = sp;
 $7 = HEAP32[$0>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($8)) + 36|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ((($10)) + 76|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + (($1*12)|0)|0);
 $14 = +HEAPF32[$13>>2];
 $15 = (($12) + (($2*12)|0)|0);
 $16 = +HEAPF32[$15>>2];
 $17 = $14 == $16;
 if ($17) {
  $18 = (((($12) + (($1*12)|0)|0)) + 4|0);
  $19 = +HEAPF32[$18>>2];
  $20 = (((($12) + (($2*12)|0)|0)) + 4|0);
  $21 = +HEAPF32[$20>>2];
  $22 = $19 == $21;
  if ($22) {
   $23 = (((($12) + (($1*12)|0)|0)) + 8|0);
   $24 = +HEAPF32[$23>>2];
   $25 = (((($12) + (($2*12)|0)|0)) + 8|0);
   $26 = +HEAPF32[$25>>2];
   $27 = $24 == $26;
   if (!($27)) {
    label = 4;
   }
  } else {
   label = 4;
  }
 } else {
  label = 4;
 }
 do {
  if ((label|0) == 4) {
   $28 = (($12) + (($3*12)|0)|0);
   $29 = +HEAPF32[$28>>2];
   $30 = $16 == $29;
   if ($30) {
    $31 = (((($12) + (($2*12)|0)|0)) + 4|0);
    $32 = +HEAPF32[$31>>2];
    $33 = (((($12) + (($3*12)|0)|0)) + 4|0);
    $34 = +HEAPF32[$33>>2];
    $35 = $32 == $34;
    if ($35) {
     $36 = (((($12) + (($2*12)|0)|0)) + 8|0);
     $37 = +HEAPF32[$36>>2];
     $38 = (((($12) + (($3*12)|0)|0)) + 8|0);
     $39 = +HEAPF32[$38>>2];
     $40 = $37 == $39;
     if ($40) {
      break;
     }
    }
   }
   $41 = $29 == $14;
   if ($41) {
    $42 = (((($12) + (($3*12)|0)|0)) + 4|0);
    $43 = +HEAPF32[$42>>2];
    $44 = (((($12) + (($1*12)|0)|0)) + 4|0);
    $45 = +HEAPF32[$44>>2];
    $46 = $43 == $45;
    if ($46) {
     $47 = (((($12) + (($3*12)|0)|0)) + 8|0);
     $48 = +HEAPF32[$47>>2];
     $49 = (((($12) + (($1*12)|0)|0)) + 8|0);
     $50 = +HEAPF32[$49>>2];
     $51 = $48 == $50;
     if ($51) {
      break;
     }
    }
   }
   $52 = (($12) + (($4*12)|0)|0);
   $53 = +HEAPF32[$52>>2];
   $54 = $53 == $14;
   if ($54) {
    $55 = (((($12) + (($4*12)|0)|0)) + 4|0);
    $56 = +HEAPF32[$55>>2];
    $57 = (((($12) + (($1*12)|0)|0)) + 4|0);
    $58 = +HEAPF32[$57>>2];
    $59 = $56 == $58;
    if ($59) {
     $60 = (((($12) + (($4*12)|0)|0)) + 8|0);
     $61 = +HEAPF32[$60>>2];
     $62 = (((($12) + (($1*12)|0)|0)) + 8|0);
     $63 = +HEAPF32[$62>>2];
     $64 = $61 == $63;
     if ($64) {
      break;
     }
    }
   }
   $65 = $53 == $16;
   if ($65) {
    $66 = (((($12) + (($4*12)|0)|0)) + 4|0);
    $67 = +HEAPF32[$66>>2];
    $68 = (((($12) + (($2*12)|0)|0)) + 4|0);
    $69 = +HEAPF32[$68>>2];
    $70 = $67 == $69;
    if ($70) {
     $71 = (((($12) + (($4*12)|0)|0)) + 8|0);
     $72 = +HEAPF32[$71>>2];
     $73 = (((($12) + (($2*12)|0)|0)) + 8|0);
     $74 = +HEAPF32[$73>>2];
     $75 = $72 == $74;
     if ($75) {
      break;
     }
    }
   }
   $76 = $53 == $29;
   if ($76) {
    $77 = (((($12) + (($4*12)|0)|0)) + 4|0);
    $78 = +HEAPF32[$77>>2];
    $79 = (((($12) + (($3*12)|0)|0)) + 4|0);
    $80 = +HEAPF32[$79>>2];
    $81 = $78 == $80;
    if ($81) {
     $82 = (((($12) + (($4*12)|0)|0)) + 8|0);
     $83 = +HEAPF32[$82>>2];
     $84 = (((($12) + (($3*12)|0)|0)) + 8|0);
     $85 = +HEAPF32[$84>>2];
     $86 = $83 == $85;
     if ($86) {
      break;
     } else {
      $$pre$phi81Z2D = $77;$$pre$phiZ2D = $79;
     }
    } else {
     $$pre$phi81Z2D = $77;$$pre$phiZ2D = $79;
    }
   } else {
    $$pre79 = (((($12) + (($3*12)|0)|0)) + 4|0);
    $$pre80 = (((($12) + (($4*12)|0)|0)) + 4|0);
    $$pre$phi81Z2D = $$pre80;$$pre$phiZ2D = $$pre79;
   }
   (__ZN3osg6KdTree7addQuadEjjjj($8,$1,$2,$3,$4)|0);
   $90 = +HEAPF32[$13>>2];
   $91 = $90 < 3.4028234663852886E+38;
   $$sroa$0$0 = $91 ? $90 : 3.4028234663852886E+38;
   $92 = $90 > -3.4028234663852886E+38;
   $$sroa$32$0 = $92 ? $90 : -3.4028234663852886E+38;
   $93 = (((($12) + (($1*12)|0)|0)) + 4|0);
   $94 = +HEAPF32[$93>>2];
   $95 = $94 < 3.4028234663852886E+38;
   $$sroa$12$0 = $95 ? $94 : 3.4028234663852886E+38;
   $96 = $94 > -3.4028234663852886E+38;
   $$sroa$42$0 = $96 ? $94 : -3.4028234663852886E+38;
   $97 = (((($12) + (($1*12)|0)|0)) + 8|0);
   $98 = +HEAPF32[$97>>2];
   $99 = $98 < 3.4028234663852886E+38;
   $$sroa$22$0 = $99 ? $98 : 3.4028234663852886E+38;
   $100 = $98 > -3.4028234663852886E+38;
   $$sroa$52$0 = $100 ? $98 : -3.4028234663852886E+38;
   $101 = +HEAPF32[$15>>2];
   $102 = $101 < $$sroa$0$0;
   $$sroa$0$1 = $102 ? $101 : $$sroa$0$0;
   $103 = $101 > $$sroa$32$0;
   $$sroa$32$1 = $103 ? $101 : $$sroa$32$0;
   $104 = (((($12) + (($2*12)|0)|0)) + 4|0);
   $105 = +HEAPF32[$104>>2];
   $106 = $105 < $$sroa$12$0;
   $$sroa$12$1 = $106 ? $105 : $$sroa$12$0;
   $107 = $105 > $$sroa$42$0;
   $$sroa$42$1 = $107 ? $105 : $$sroa$42$0;
   $108 = (((($12) + (($2*12)|0)|0)) + 8|0);
   $109 = +HEAPF32[$108>>2];
   $110 = $109 < $$sroa$22$0;
   $$sroa$22$1 = $110 ? $109 : $$sroa$22$0;
   $111 = $109 > $$sroa$52$0;
   $$sroa$52$1 = $111 ? $109 : $$sroa$52$0;
   $112 = +HEAPF32[$28>>2];
   $113 = $112 < $$sroa$0$1;
   $$sroa$0$2 = $113 ? $112 : $$sroa$0$1;
   $114 = $112 > $$sroa$32$1;
   $$sroa$32$2 = $114 ? $112 : $$sroa$32$1;
   $115 = +HEAPF32[$$pre$phiZ2D>>2];
   $116 = $115 < $$sroa$12$1;
   $$sroa$12$2 = $116 ? $115 : $$sroa$12$1;
   $117 = $115 > $$sroa$42$1;
   $$sroa$42$2 = $117 ? $115 : $$sroa$42$1;
   $118 = (((($12) + (($3*12)|0)|0)) + 8|0);
   $119 = +HEAPF32[$118>>2];
   $120 = $119 < $$sroa$22$1;
   $$sroa$22$2 = $120 ? $119 : $$sroa$22$1;
   $121 = $119 > $$sroa$52$1;
   $$sroa$52$2 = $121 ? $119 : $$sroa$52$1;
   $122 = +HEAPF32[$52>>2];
   $123 = $122 < $$sroa$0$2;
   $$sroa$0$3 = $123 ? $122 : $$sroa$0$2;
   $124 = $122 > $$sroa$32$2;
   $$sroa$32$3 = $124 ? $122 : $$sroa$32$2;
   $125 = +HEAPF32[$$pre$phi81Z2D>>2];
   $126 = $125 < $$sroa$12$2;
   $$sroa$12$3 = $126 ? $125 : $$sroa$12$2;
   $127 = $125 > $$sroa$42$2;
   $$sroa$42$3 = $127 ? $125 : $$sroa$42$2;
   $128 = (((($12) + (($4*12)|0)|0)) + 8|0);
   $129 = +HEAPF32[$128>>2];
   $130 = $129 < $$sroa$22$2;
   $$sroa$22$3 = $130 ? $129 : $$sroa$22$2;
   $131 = $129 > $$sroa$52$2;
   $$sroa$52$3 = $131 ? $129 : $$sroa$52$2;
   $132 = HEAP32[$0>>2]|0;
   $133 = ((($132)) + 52|0);
   $134 = ((($132)) + 56|0);
   $135 = HEAP32[$134>>2]|0;
   $136 = HEAP32[$133>>2]|0;
   $137 = (($135) - ($136))|0;
   $138 = (($137|0) / 12)&-1;
   HEAP32[$5>>2] = $138;
   $139 = ((($132)) + 44|0);
   $140 = HEAP32[$139>>2]|0;
   $141 = ((($132)) + 48|0);
   $142 = HEAP32[$141>>2]|0;
   $143 = ($140|0)==($142|0);
   if ($143) {
    $146 = ((($132)) + 40|0);
    __ZNSt3__26vectorIjNS_9allocatorIjEEE21__push_back_slow_pathIKjEEvRT_($146,$5);
    $$pre = HEAP32[$0>>2]|0;
    $$phi$trans$insert = ((($$pre)) + 56|0);
    $$pre78 = HEAP32[$$phi$trans$insert>>2]|0;
    $156 = $$pre;$159 = $$pre78;
   } else {
    $144 = $135;
    HEAP32[$140>>2] = $138;
    $145 = ((($140)) + 4|0);
    HEAP32[$139>>2] = $145;
    $156 = $132;$159 = $144;
   }
   $147 = $$sroa$0$3 + $$sroa$32$3;
   $148 = $$sroa$12$3 + $$sroa$42$3;
   $149 = $$sroa$22$3 + $$sroa$52$3;
   $150 = $147 * 0.5;
   $151 = $148 * 0.5;
   $152 = $149 * 0.5;
   HEAPF32[$6>>2] = $150;
   $153 = ((($6)) + 4|0);
   HEAPF32[$153>>2] = $151;
   $154 = ((($6)) + 8|0);
   HEAPF32[$154>>2] = $152;
   $155 = ((($156)) + 56|0);
   $157 = ((($156)) + 60|0);
   $158 = HEAP32[$157>>2]|0;
   $160 = ($159|0)==($158|0);
   if ($160) {
    $163 = ((($156)) + 52|0);
    __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($163,$6);
   } else {
    ;HEAP32[$159>>2]=HEAP32[$6>>2]|0;HEAP32[$159+4>>2]=HEAP32[$6+4>>2]|0;HEAP32[$159+8>>2]=HEAP32[$6+8>>2]|0;
    $161 = HEAP32[$155>>2]|0;
    $162 = ((($161)) + 12|0);
    HEAP32[$155>>2] = $162;
   }
   STACKTOP = sp;return;
  }
 } while(0);
 $87 = ((($8)) + 32|0);
 $88 = HEAP32[$87>>2]|0;
 $89 = (($88) + 1)|0;
 HEAP32[$87>>2] = $89;
 STACKTOP = sp;return;
}
function __ZN25PrimitiveIndicesCollectorclEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$phi$trans$insert = 0, $$pre = 0, $$pre16 = 0, $$sroa$0$0 = 0.0, $$sroa$10$0 = 0.0, $$sroa$14$0 = 0.0, $$sroa$18$0 = 0.0, $$sroa$22$0 = 0.0, $$sroa$6$0 = 0.0, $10 = 0, $11 = 0.0, $12 = 0, $13 = 0, $14 = 0, $15 = 0.0, $16 = 0, $17 = 0, $18 = 0, $19 = 0.0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0.0, $38 = 0.0;
 var $39 = 0.0, $4 = 0, $40 = 0.0, $41 = 0.0, $42 = 0.0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp + 12|0;
 $3 = sp;
 $4 = HEAP32[$0>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($5)) + 36|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($7)) + 76|0);
 $9 = HEAP32[$8>>2]|0;
 (__ZN3osg6KdTree8addPointEj($5,$1)|0);
 $10 = (($9) + (($1*12)|0)|0);
 $11 = +HEAPF32[$10>>2];
 $12 = $11 < 3.4028234663852886E+38;
 $$sroa$0$0 = $12 ? $11 : 3.4028234663852886E+38;
 $13 = $11 > -3.4028234663852886E+38;
 $$sroa$14$0 = $13 ? $11 : -3.4028234663852886E+38;
 $14 = (((($9) + (($1*12)|0)|0)) + 4|0);
 $15 = +HEAPF32[$14>>2];
 $16 = $15 < 3.4028234663852886E+38;
 $$sroa$6$0 = $16 ? $15 : 3.4028234663852886E+38;
 $17 = $15 > -3.4028234663852886E+38;
 $$sroa$18$0 = $17 ? $15 : -3.4028234663852886E+38;
 $18 = (((($9) + (($1*12)|0)|0)) + 8|0);
 $19 = +HEAPF32[$18>>2];
 $20 = $19 < 3.4028234663852886E+38;
 $$sroa$10$0 = $20 ? $19 : 3.4028234663852886E+38;
 $21 = $19 > -3.4028234663852886E+38;
 $$sroa$22$0 = $21 ? $19 : -3.4028234663852886E+38;
 $22 = HEAP32[$0>>2]|0;
 $23 = ((($22)) + 52|0);
 $24 = ((($22)) + 56|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = HEAP32[$23>>2]|0;
 $27 = (($25) - ($26))|0;
 $28 = (($27|0) / 12)&-1;
 HEAP32[$2>>2] = $28;
 $29 = ((($22)) + 44|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ((($22)) + 48|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = ($30|0)==($32|0);
 if ($33) {
  $36 = ((($22)) + 40|0);
  __ZNSt3__26vectorIjNS_9allocatorIjEEE21__push_back_slow_pathIKjEEvRT_($36,$2);
  $$pre = HEAP32[$0>>2]|0;
  $$phi$trans$insert = ((($$pre)) + 56|0);
  $$pre16 = HEAP32[$$phi$trans$insert>>2]|0;
  $46 = $$pre;$49 = $$pre16;
 } else {
  $34 = $25;
  HEAP32[$30>>2] = $28;
  $35 = ((($30)) + 4|0);
  HEAP32[$29>>2] = $35;
  $46 = $22;$49 = $34;
 }
 $37 = $$sroa$0$0 + $$sroa$14$0;
 $38 = $$sroa$6$0 + $$sroa$18$0;
 $39 = $$sroa$10$0 + $$sroa$22$0;
 $40 = $37 * 0.5;
 $41 = $38 * 0.5;
 $42 = $39 * 0.5;
 HEAPF32[$3>>2] = $40;
 $43 = ((($3)) + 4|0);
 HEAPF32[$43>>2] = $41;
 $44 = ((($3)) + 8|0);
 HEAPF32[$44>>2] = $42;
 $45 = ((($46)) + 56|0);
 $47 = ((($46)) + 60|0);
 $48 = HEAP32[$47>>2]|0;
 $50 = ($49|0)==($48|0);
 if ($50) {
  $53 = ((($46)) + 52|0);
  __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($53,$3);
  STACKTOP = sp;return;
 } else {
  ;HEAP32[$49>>2]=HEAP32[$3>>2]|0;HEAP32[$49+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$49+8>>2]=HEAP32[$3+8>>2]|0;
  $51 = HEAP32[$45>>2]|0;
  $52 = ((($51)) + 12|0);
  HEAP32[$45>>2] = $52;
  STACKTOP = sp;return;
 }
}
function __ZN25PrimitiveIndicesCollectorclEjj($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$phi$trans$insert = 0, $$pre = 0, $$pre$phi36Z2D = 0, $$pre$phi38Z2D = 0, $$pre$phi40Z2D = 0, $$pre33 = 0, $$pre35 = 0, $$pre37$pre$phiZZ2D = 0, $$pre39 = 0, $$pre42 = 0, $$sroa$0$0 = 0.0, $$sroa$0$1 = 0.0, $$sroa$14$0 = 0.0, $$sroa$14$1 = 0.0, $$sroa$20$0 = 0.0, $$sroa$20$1 = 0.0, $$sroa$26$0 = 0.0, $$sroa$26$1 = 0.0, $$sroa$32$0 = 0.0, $$sroa$32$1 = 0.0;
 var $$sroa$8$0 = 0.0, $$sroa$8$1 = 0.0, $10 = 0, $11 = 0, $12 = 0.0, $13 = 0, $14 = 0.0, $15 = 0, $16 = 0, $17 = 0.0, $18 = 0, $19 = 0.0, $20 = 0, $21 = 0, $22 = 0.0, $23 = 0, $24 = 0.0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0, $32 = 0.0, $33 = 0, $34 = 0, $35 = 0.0, $36 = 0, $37 = 0, $38 = 0.0, $39 = 0, $4 = 0, $40 = 0, $41 = 0.0, $42 = 0, $43 = 0, $44 = 0.0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0.0, $63 = 0.0;
 var $64 = 0.0, $65 = 0.0, $66 = 0.0, $67 = 0.0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp + 12|0;
 $4 = sp;
 $5 = HEAP32[$0>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($6)) + 36|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($8)) + 76|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + (($1*12)|0)|0);
 $12 = +HEAPF32[$11>>2];
 $13 = (($10) + (($2*12)|0)|0);
 $14 = +HEAPF32[$13>>2];
 $15 = $12 == $14;
 $16 = (((($10) + (($1*12)|0)|0)) + 4|0);
 if ($15) {
  $17 = +HEAPF32[$16>>2];
  $18 = (((($10) + (($2*12)|0)|0)) + 4|0);
  $19 = +HEAPF32[$18>>2];
  $20 = $17 == $19;
  if ($20) {
   $21 = (((($10) + (($1*12)|0)|0)) + 8|0);
   $22 = +HEAPF32[$21>>2];
   $23 = (((($10) + (($2*12)|0)|0)) + 8|0);
   $24 = +HEAPF32[$23>>2];
   $25 = $22 == $24;
   if ($25) {
    $26 = ((($6)) + 32|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = (($27) + 1)|0;
    HEAP32[$26>>2] = $28;
    STACKTOP = sp;return;
   } else {
    $$pre$phi36Z2D = $21;$$pre$phi38Z2D = $18;$$pre$phi40Z2D = $23;
   }
  } else {
   $$pre37$pre$phiZZ2D = $18;
   label = 4;
  }
 } else {
  $$pre42 = (((($10) + (($2*12)|0)|0)) + 4|0);
  $$pre37$pre$phiZZ2D = $$pre42;
  label = 4;
 }
 if ((label|0) == 4) {
  $$pre35 = (((($10) + (($1*12)|0)|0)) + 8|0);
  $$pre39 = (((($10) + (($2*12)|0)|0)) + 8|0);
  $$pre$phi36Z2D = $$pre35;$$pre$phi38Z2D = $$pre37$pre$phiZZ2D;$$pre$phi40Z2D = $$pre39;
 }
 (__ZN3osg6KdTree7addLineEjj($6,$1,$2)|0);
 $29 = +HEAPF32[$11>>2];
 $30 = $29 < 3.4028234663852886E+38;
 $$sroa$0$0 = $30 ? $29 : 3.4028234663852886E+38;
 $31 = $29 > -3.4028234663852886E+38;
 $$sroa$20$0 = $31 ? $29 : -3.4028234663852886E+38;
 $32 = +HEAPF32[$16>>2];
 $33 = $32 < 3.4028234663852886E+38;
 $$sroa$8$0 = $33 ? $32 : 3.4028234663852886E+38;
 $34 = $32 > -3.4028234663852886E+38;
 $$sroa$26$0 = $34 ? $32 : -3.4028234663852886E+38;
 $35 = +HEAPF32[$$pre$phi36Z2D>>2];
 $36 = $35 < 3.4028234663852886E+38;
 $$sroa$14$0 = $36 ? $35 : 3.4028234663852886E+38;
 $37 = $35 > -3.4028234663852886E+38;
 $$sroa$32$0 = $37 ? $35 : -3.4028234663852886E+38;
 $38 = +HEAPF32[$13>>2];
 $39 = $38 < $$sroa$0$0;
 $$sroa$0$1 = $39 ? $38 : $$sroa$0$0;
 $40 = $38 > $$sroa$20$0;
 $$sroa$20$1 = $40 ? $38 : $$sroa$20$0;
 $41 = +HEAPF32[$$pre$phi38Z2D>>2];
 $42 = $41 < $$sroa$8$0;
 $$sroa$8$1 = $42 ? $41 : $$sroa$8$0;
 $43 = $41 > $$sroa$26$0;
 $$sroa$26$1 = $43 ? $41 : $$sroa$26$0;
 $44 = +HEAPF32[$$pre$phi40Z2D>>2];
 $45 = $44 < $$sroa$14$0;
 $$sroa$14$1 = $45 ? $44 : $$sroa$14$0;
 $46 = $44 > $$sroa$32$0;
 $$sroa$32$1 = $46 ? $44 : $$sroa$32$0;
 $47 = HEAP32[$0>>2]|0;
 $48 = ((($47)) + 52|0);
 $49 = ((($47)) + 56|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = HEAP32[$48>>2]|0;
 $52 = (($50) - ($51))|0;
 $53 = (($52|0) / 12)&-1;
 HEAP32[$3>>2] = $53;
 $54 = ((($47)) + 44|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = ((($47)) + 48|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = ($55|0)==($57|0);
 if ($58) {
  $61 = ((($47)) + 40|0);
  __ZNSt3__26vectorIjNS_9allocatorIjEEE21__push_back_slow_pathIKjEEvRT_($61,$3);
  $$pre = HEAP32[$0>>2]|0;
  $$phi$trans$insert = ((($$pre)) + 56|0);
  $$pre33 = HEAP32[$$phi$trans$insert>>2]|0;
  $71 = $$pre;$74 = $$pre33;
 } else {
  $59 = $50;
  HEAP32[$55>>2] = $53;
  $60 = ((($55)) + 4|0);
  HEAP32[$54>>2] = $60;
  $71 = $47;$74 = $59;
 }
 $62 = $$sroa$0$1 + $$sroa$20$1;
 $63 = $$sroa$8$1 + $$sroa$26$1;
 $64 = $$sroa$14$1 + $$sroa$32$1;
 $65 = $62 * 0.5;
 $66 = $63 * 0.5;
 $67 = $64 * 0.5;
 HEAPF32[$4>>2] = $65;
 $68 = ((($4)) + 4|0);
 HEAPF32[$68>>2] = $66;
 $69 = ((($4)) + 8|0);
 HEAPF32[$69>>2] = $67;
 $70 = ((($71)) + 56|0);
 $72 = ((($71)) + 60|0);
 $73 = HEAP32[$72>>2]|0;
 $75 = ($74|0)==($73|0);
 if ($75) {
  $78 = ((($71)) + 52|0);
  __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($78,$4);
 } else {
  ;HEAP32[$74>>2]=HEAP32[$4>>2]|0;HEAP32[$74+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$74+8>>2]=HEAP32[$4+8>>2]|0;
  $76 = HEAP32[$70>>2]|0;
  $77 = ((($76)) + 12|0);
  HEAP32[$70>>2] = $77;
 }
 STACKTOP = sp;return;
}
function __ZN3osg6KdTree7addLineEjj($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $$pre8 = 0, $$pre9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $3 = sp + 16|0;
 $4 = sp + 12|0;
 $5 = sp + 8|0;
 $6 = sp + 4|0;
 $7 = sp;
 HEAP32[$3>>2] = $1;
 HEAP32[$4>>2] = $2;
 $8 = ((($0)) + 52|0);
 $9 = ((($0)) + 56|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$8>>2]|0;
 $12 = (($10) - ($11))|0;
 $13 = $12 >> 2;
 HEAP32[$5>>2] = $13;
 $14 = ((($0)) + 40|0);
 $15 = ((($0)) + 44|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = HEAP32[$14>>2]|0;
 $18 = (($16) - ($17))|0;
 $19 = $18 >> 2;
 $20 = ((($0)) + 32|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($19) + ($21))|0;
 HEAP32[$6>>2] = $22;
 $23 = $10;
 $24 = ((($0)) + 60|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($23|0)==($25|0);
 if ($26) {
  __ZNSt3__26vectorIjNS_9allocatorIjEEE21__push_back_slow_pathIKjEEvRT_($8,$6);
  $$pre = HEAP32[$9>>2]|0;
  $$pre5 = HEAP32[$24>>2]|0;
  $28 = $$pre;$30 = $$pre5;
 } else {
  HEAP32[$23>>2] = $22;
  $27 = ((($23)) + 4|0);
  HEAP32[$9>>2] = $27;
  $28 = $27;$30 = $25;
 }
 HEAP32[$7>>2] = 2;
 $29 = ($28|0)==($30|0);
 if ($29) {
  __ZNSt3__26vectorIjNS_9allocatorIjEEE21__push_back_slow_pathIKjEEvRT_($8,$7);
  $$pre6 = HEAP32[$9>>2]|0;
  $$pre7 = HEAP32[$24>>2]|0;
  $32 = $$pre6;$34 = $$pre7;
 } else {
  HEAP32[$28>>2] = 2;
  $31 = ((($28)) + 4|0);
  HEAP32[$9>>2] = $31;
  $32 = $31;$34 = $30;
 }
 $33 = ($32|0)==($34|0);
 if ($33) {
  __ZNSt3__26vectorIjNS_9allocatorIjEEE21__push_back_slow_pathIKjEEvRT_($8,$3);
  $$pre8 = HEAP32[$9>>2]|0;
  $$pre9 = HEAP32[$24>>2]|0;
  $37 = $$pre8;$39 = $$pre9;
 } else {
  $35 = HEAP32[$3>>2]|0;
  HEAP32[$32>>2] = $35;
  $36 = ((($32)) + 4|0);
  HEAP32[$9>>2] = $36;
  $37 = $36;$39 = $34;
 }
 $38 = ($37|0)==($39|0);
 if ($38) {
  __ZNSt3__26vectorIjNS_9allocatorIjEEE21__push_back_slow_pathIKjEEvRT_($8,$4);
 } else {
  $40 = HEAP32[$4>>2]|0;
  HEAP32[$37>>2] = $40;
  $41 = ((($37)) + 4|0);
  HEAP32[$9>>2] = $41;
 }
 $42 = HEAP32[$15>>2]|0;
 $43 = ((($0)) + 48|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = ($42|0)==($44|0);
 if ($45) {
  __ZNSt3__26vectorIjNS_9allocatorIjEEE21__push_back_slow_pathIKjEEvRT_($14,$5);
  $48 = HEAP32[$5>>2]|0;
  STACKTOP = sp;return ($48|0);
 } else {
  $46 = HEAP32[$5>>2]|0;
  HEAP32[$42>>2] = $46;
  $47 = ((($42)) + 4|0);
  HEAP32[$15>>2] = $47;
  $48 = HEAP32[$5>>2]|0;
  STACKTOP = sp;return ($48|0);
 }
 return (0)|0;
}
function __ZN3osg6KdTree8addPointEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$pre = 0, $$pre4 = 0, $$pre5 = 0, $$pre6 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp + 12|0;
 $3 = sp + 8|0;
 $4 = sp + 4|0;
 $5 = sp;
 HEAP32[$2>>2] = $1;
 $6 = ((($0)) + 52|0);
 $7 = ((($0)) + 56|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$6>>2]|0;
 $10 = (($8) - ($9))|0;
 $11 = $10 >> 2;
 HEAP32[$3>>2] = $11;
 $12 = ((($0)) + 40|0);
 $13 = ((($0)) + 44|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP32[$12>>2]|0;
 $16 = (($14) - ($15))|0;
 $17 = $16 >> 2;
 $18 = ((($0)) + 32|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($17) + ($19))|0;
 HEAP32[$4>>2] = $20;
 $21 = $8;
 $22 = ((($0)) + 60|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($21|0)==($23|0);
 if ($24) {
  __ZNSt3__26vectorIjNS_9allocatorIjEEE21__push_back_slow_pathIKjEEvRT_($6,$4);
  $$pre = HEAP32[$7>>2]|0;
  $$pre4 = HEAP32[$22>>2]|0;
  $26 = $$pre;$28 = $$pre4;
 } else {
  HEAP32[$21>>2] = $20;
  $25 = ((($21)) + 4|0);
  HEAP32[$7>>2] = $25;
  $26 = $25;$28 = $23;
 }
 HEAP32[$5>>2] = 1;
 $27 = ($26|0)==($28|0);
 if ($27) {
  __ZNSt3__26vectorIjNS_9allocatorIjEEE21__push_back_slow_pathIKjEEvRT_($6,$5);
  $$pre5 = HEAP32[$7>>2]|0;
  $$pre6 = HEAP32[$22>>2]|0;
  $30 = $$pre5;$32 = $$pre6;
 } else {
  HEAP32[$26>>2] = 1;
  $29 = ((($26)) + 4|0);
  HEAP32[$7>>2] = $29;
  $30 = $29;$32 = $28;
 }
 $31 = ($30|0)==($32|0);
 if ($31) {
  __ZNSt3__26vectorIjNS_9allocatorIjEEE21__push_back_slow_pathIKjEEvRT_($6,$2);
 } else {
  $33 = HEAP32[$2>>2]|0;
  HEAP32[$30>>2] = $33;
  $34 = ((($30)) + 4|0);
  HEAP32[$7>>2] = $34;
 }
 $35 = HEAP32[$13>>2]|0;
 $36 = ((($0)) + 48|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = ($35|0)==($37|0);
 if ($38) {
  __ZNSt3__26vectorIjNS_9allocatorIjEEE21__push_back_slow_pathIKjEEvRT_($12,$3);
  $41 = HEAP32[$3>>2]|0;
  STACKTOP = sp;return ($41|0);
 } else {
  $39 = HEAP32[$3>>2]|0;
  HEAP32[$35>>2] = $39;
  $40 = ((($35)) + 4|0);
  HEAP32[$13>>2] = $40;
  $41 = HEAP32[$3>>2]|0;
  STACKTOP = sp;return ($41|0);
 }
 return (0)|0;
}
function __ZN3osg6KdTree7addQuadEjjjj($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$pre = 0, $$pre10 = 0, $$pre11 = 0, $$pre12 = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre7 = 0, $$pre8 = 0, $$pre9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $5 = sp + 24|0;
 $6 = sp + 20|0;
 $7 = sp + 16|0;
 $8 = sp + 12|0;
 $9 = sp + 8|0;
 $10 = sp + 4|0;
 $11 = sp;
 HEAP32[$5>>2] = $1;
 HEAP32[$6>>2] = $2;
 HEAP32[$7>>2] = $3;
 HEAP32[$8>>2] = $4;
 $12 = ((($0)) + 52|0);
 $13 = ((($0)) + 56|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP32[$12>>2]|0;
 $16 = (($14) - ($15))|0;
 $17 = $16 >> 2;
 HEAP32[$9>>2] = $17;
 $18 = ((($0)) + 40|0);
 $19 = ((($0)) + 44|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = HEAP32[$18>>2]|0;
 $22 = (($20) - ($21))|0;
 $23 = $22 >> 2;
 $24 = ((($0)) + 32|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($23) + ($25))|0;
 HEAP32[$10>>2] = $26;
 $27 = $14;
 $28 = ((($0)) + 60|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ($27|0)==($29|0);
 if ($30) {
  __ZNSt3__26vectorIjNS_9allocatorIjEEE21__push_back_slow_pathIKjEEvRT_($12,$10);
  $$pre = HEAP32[$13>>2]|0;
  $$pre7 = HEAP32[$28>>2]|0;
  $32 = $$pre;$34 = $$pre7;
 } else {
  HEAP32[$27>>2] = $26;
  $31 = ((($27)) + 4|0);
  HEAP32[$13>>2] = $31;
  $32 = $31;$34 = $29;
 }
 HEAP32[$11>>2] = 4;
 $33 = ($32|0)==($34|0);
 if ($33) {
  __ZNSt3__26vectorIjNS_9allocatorIjEEE21__push_back_slow_pathIKjEEvRT_($12,$11);
  $$pre8 = HEAP32[$13>>2]|0;
  $$pre9 = HEAP32[$28>>2]|0;
  $36 = $$pre8;$38 = $$pre9;
 } else {
  HEAP32[$32>>2] = 4;
  $35 = ((($32)) + 4|0);
  HEAP32[$13>>2] = $35;
  $36 = $35;$38 = $34;
 }
 $37 = ($36|0)==($38|0);
 if ($37) {
  __ZNSt3__26vectorIjNS_9allocatorIjEEE21__push_back_slow_pathIKjEEvRT_($12,$5);
  $$pre10 = HEAP32[$13>>2]|0;
  $$pre11 = HEAP32[$28>>2]|0;
  $41 = $$pre10;$43 = $$pre11;
 } else {
  $39 = HEAP32[$5>>2]|0;
  HEAP32[$36>>2] = $39;
  $40 = ((($36)) + 4|0);
  HEAP32[$13>>2] = $40;
  $41 = $40;$43 = $38;
 }
 $42 = ($41|0)==($43|0);
 if ($42) {
  __ZNSt3__26vectorIjNS_9allocatorIjEEE21__push_back_slow_pathIKjEEvRT_($12,$6);
  $$pre12 = HEAP32[$13>>2]|0;
  $$pre13 = HEAP32[$28>>2]|0;
  $46 = $$pre12;$48 = $$pre13;
 } else {
  $44 = HEAP32[$6>>2]|0;
  HEAP32[$41>>2] = $44;
  $45 = ((($41)) + 4|0);
  HEAP32[$13>>2] = $45;
  $46 = $45;$48 = $43;
 }
 $47 = ($46|0)==($48|0);
 if ($47) {
  __ZNSt3__26vectorIjNS_9allocatorIjEEE21__push_back_slow_pathIKjEEvRT_($12,$7);
  $$pre14 = HEAP32[$13>>2]|0;
  $$pre15 = HEAP32[$28>>2]|0;
  $51 = $$pre14;$53 = $$pre15;
 } else {
  $49 = HEAP32[$7>>2]|0;
  HEAP32[$46>>2] = $49;
  $50 = ((($46)) + 4|0);
  HEAP32[$13>>2] = $50;
  $51 = $50;$53 = $48;
 }
 $52 = ($51|0)==($53|0);
 if ($52) {
  __ZNSt3__26vectorIjNS_9allocatorIjEEE21__push_back_slow_pathIKjEEvRT_($12,$8);
 } else {
  $54 = HEAP32[$8>>2]|0;
  HEAP32[$51>>2] = $54;
  $55 = ((($51)) + 4|0);
  HEAP32[$13>>2] = $55;
 }
 $56 = HEAP32[$19>>2]|0;
 $57 = ((($0)) + 48|0);
 $58 = HEAP32[$57>>2]|0;
 $59 = ($56|0)==($58|0);
 if ($59) {
  __ZNSt3__26vectorIjNS_9allocatorIjEEE21__push_back_slow_pathIKjEEvRT_($18,$9);
  $62 = HEAP32[$9>>2]|0;
  STACKTOP = sp;return ($62|0);
 } else {
  $60 = HEAP32[$9>>2]|0;
  HEAP32[$56>>2] = $60;
  $61 = ((($56)) + 4|0);
  HEAP32[$19>>2] = $61;
  $62 = HEAP32[$9>>2]|0;
  STACKTOP = sp;return ($62|0);
 }
 return (0)|0;
}
function __ZN3osg6KdTree11addTriangleEjjj($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$pre = 0, $$pre10 = 0, $$pre11 = 0, $$pre12 = 0, $$pre6 = 0, $$pre7 = 0, $$pre8 = 0, $$pre9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $4 = sp + 20|0;
 $5 = sp + 16|0;
 $6 = sp + 12|0;
 $7 = sp + 8|0;
 $8 = sp + 4|0;
 $9 = sp;
 HEAP32[$4>>2] = $1;
 HEAP32[$5>>2] = $2;
 HEAP32[$6>>2] = $3;
 $10 = ((($0)) + 52|0);
 $11 = ((($0)) + 56|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = HEAP32[$10>>2]|0;
 $14 = (($12) - ($13))|0;
 $15 = $14 >> 2;
 HEAP32[$7>>2] = $15;
 $16 = ((($0)) + 40|0);
 $17 = ((($0)) + 44|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = HEAP32[$16>>2]|0;
 $20 = (($18) - ($19))|0;
 $21 = $20 >> 2;
 $22 = ((($0)) + 32|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($21) + ($23))|0;
 HEAP32[$8>>2] = $24;
 $25 = $12;
 $26 = ((($0)) + 60|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ($25|0)==($27|0);
 if ($28) {
  __ZNSt3__26vectorIjNS_9allocatorIjEEE21__push_back_slow_pathIKjEEvRT_($10,$8);
  $$pre = HEAP32[$11>>2]|0;
  $$pre6 = HEAP32[$26>>2]|0;
  $30 = $$pre;$32 = $$pre6;
 } else {
  HEAP32[$25>>2] = $24;
  $29 = ((($25)) + 4|0);
  HEAP32[$11>>2] = $29;
  $30 = $29;$32 = $27;
 }
 HEAP32[$9>>2] = 3;
 $31 = ($30|0)==($32|0);
 if ($31) {
  __ZNSt3__26vectorIjNS_9allocatorIjEEE21__push_back_slow_pathIKjEEvRT_($10,$9);
  $$pre7 = HEAP32[$11>>2]|0;
  $$pre8 = HEAP32[$26>>2]|0;
  $34 = $$pre7;$36 = $$pre8;
 } else {
  HEAP32[$30>>2] = 3;
  $33 = ((($30)) + 4|0);
  HEAP32[$11>>2] = $33;
  $34 = $33;$36 = $32;
 }
 $35 = ($34|0)==($36|0);
 if ($35) {
  __ZNSt3__26vectorIjNS_9allocatorIjEEE21__push_back_slow_pathIKjEEvRT_($10,$4);
  $$pre9 = HEAP32[$11>>2]|0;
  $$pre10 = HEAP32[$26>>2]|0;
  $39 = $$pre9;$41 = $$pre10;
 } else {
  $37 = HEAP32[$4>>2]|0;
  HEAP32[$34>>2] = $37;
  $38 = ((($34)) + 4|0);
  HEAP32[$11>>2] = $38;
  $39 = $38;$41 = $36;
 }
 $40 = ($39|0)==($41|0);
 if ($40) {
  __ZNSt3__26vectorIjNS_9allocatorIjEEE21__push_back_slow_pathIKjEEvRT_($10,$5);
  $$pre11 = HEAP32[$11>>2]|0;
  $$pre12 = HEAP32[$26>>2]|0;
  $44 = $$pre11;$46 = $$pre12;
 } else {
  $42 = HEAP32[$5>>2]|0;
  HEAP32[$39>>2] = $42;
  $43 = ((($39)) + 4|0);
  HEAP32[$11>>2] = $43;
  $44 = $43;$46 = $41;
 }
 $45 = ($44|0)==($46|0);
 if ($45) {
  __ZNSt3__26vectorIjNS_9allocatorIjEEE21__push_back_slow_pathIKjEEvRT_($10,$6);
 } else {
  $47 = HEAP32[$6>>2]|0;
  HEAP32[$44>>2] = $47;
  $48 = ((($44)) + 4|0);
  HEAP32[$11>>2] = $48;
 }
 $49 = HEAP32[$17>>2]|0;
 $50 = ((($0)) + 48|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = ($49|0)==($51|0);
 if ($52) {
  __ZNSt3__26vectorIjNS_9allocatorIjEEE21__push_back_slow_pathIKjEEvRT_($16,$7);
  $55 = HEAP32[$7>>2]|0;
  STACKTOP = sp;return ($55|0);
 } else {
  $53 = HEAP32[$7>>2]|0;
  HEAP32[$49>>2] = $53;
  $54 = ((($49)) + 4|0);
  HEAP32[$17>>2] = $54;
  $55 = HEAP32[$7>>2]|0;
  STACKTOP = sp;return ($55|0);
 }
 return (0)|0;
}
function __ZN3osg6KdTreeC2ERKS0_RKNS_6CopyOpE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i10 = 0, $scevgep5$i$i$i = 0, $scevgep5$i$i$i11 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg6ObjectC2ERKS0_RKNS_6CopyOpE($0,$1,$2);
 HEAP32[$0>>2] = (62196);
 $3 = ((($0)) + 32|0);
 $4 = ((($1)) + 32|0);
 $5 = HEAP32[$4>>2]|0;
 HEAP32[$3>>2] = $5;
 $6 = ((($0)) + 36|0);
 $7 = ((($1)) + 36|0);
 $8 = HEAP32[$7>>2]|0;
 HEAP32[$6>>2] = $8;
 $9 = ($8|0)==(0|0);
 if (!($9)) {
  $10 = ((($8)) + 8|0);
  $11 = HEAP32[$10>>2]|0;HEAP32[$10>>2] = (($11+1)|0);
 }
 $12 = ((($0)) + 40|0);
 $13 = ((($0)) + 44|0);
 $14 = ((($0)) + 56|0);
 $15 = ((($0)) + 64|0);
 $16 = ((($1)) + 64|0);
 ;HEAP32[$12>>2]=0|0;HEAP32[$12+4>>2]=0|0;HEAP32[$12+8>>2]=0|0;HEAP32[$12+12>>2]=0|0;HEAP32[$12+16>>2]=0|0;HEAP32[$12+20>>2]=0|0;
 __THREW__ = 0;
 invoke_vii(3828,($15|0),($16|0));
 $17 = __THREW__; __THREW__ = 0;
 $18 = $17&1;
 if (!($18)) {
  return;
 }
 $19 = ___cxa_find_matching_catch_2()|0;
 $20 = tempRet0;
 $21 = ((($0)) + 52|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0|0);
 if (!($23)) {
  $24 = HEAP32[$14>>2]|0;
  $25 = ($24|0)==($22|0);
  if (!($25)) {
   $scevgep$i$i$i10 = ((($24)) + -4|0);
   $26 = $scevgep$i$i$i10;
   $27 = $22;
   $28 = (($26) - ($27))|0;
   $29 = $28 >>> 2;
   $30 = $29 ^ -1;
   $scevgep5$i$i$i11 = (($24) + ($30<<2)|0);
   HEAP32[$14>>2] = $scevgep5$i$i$i11;
  }
  __ZdlPv($22);
 }
 $31 = HEAP32[$12>>2]|0;
 $32 = ($31|0)==(0|0);
 if (!($32)) {
  $33 = HEAP32[$13>>2]|0;
  $34 = ($33|0)==($31|0);
  if (!($34)) {
   $scevgep$i$i$i = ((($33)) + -4|0);
   $35 = $scevgep$i$i$i;
   $36 = $31;
   $37 = (($35) - ($36))|0;
   $38 = $37 >>> 2;
   $39 = $38 ^ -1;
   $scevgep5$i$i$i = (($33) + ($39<<2)|0);
   HEAP32[$13>>2] = $scevgep5$i$i$i;
  }
  __ZdlPv($31);
 }
 $40 = HEAP32[$6>>2]|0;
 $41 = ($40|0)==(0|0);
 if (!($41)) {
  $42 = ((($40)) + 8|0);
  $43 = HEAP32[$42>>2]|0;HEAP32[$42>>2] = (($43-1)|0);
  $44 = ($43|0)==(1);
  if ($44) {
   __THREW__ = 0;
   invoke_viii(3262,($40|0),1,1);
   $45 = __THREW__; __THREW__ = 0;
   $46 = $45&1;
   if ($46) {
    $49 = ___cxa_find_matching_catch_3(0|0)|0;
    $50 = tempRet0;
    ___clang_call_terminate($49);
    // unreachable;
   }
  }
 }
 HEAP32[$6>>2] = 0;
 __THREW__ = 0;
 invoke_vi(2239,($0|0));
 $47 = __THREW__; __THREW__ = 0;
 $48 = $47&1;
 if ($48) {
  $49 = ___cxa_find_matching_catch_3(0|0)|0;
  $50 = tempRet0;
  ___clang_call_terminate($49);
  // unreachable;
 } else {
  ___resumeException($19|0);
  // unreachable;
 }
}
function __ZNSt3__26vectorIN3osg6KdTree6KdNodeENS_9allocatorIS3_EEEC2ERKS6_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i = 0, $scevgep5$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = 0;
 $2 = ((($0)) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = ((($0)) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$1>>2]|0;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 5;
 $9 = ($8|0)==(0);
 if ($9) {
  return;
 }
 $10 = ($8>>>0)>(134217727);
 if ($10) {
  __THREW__ = 0;
  invoke_vi(3307,($0|0));
  $11 = __THREW__; __THREW__ = 0;
 } else {
  __THREW__ = 0;
  $12 = (invoke_ii(3276,($7|0))|0);
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if (!($14)) {
   HEAP32[$2>>2] = $12;
   HEAP32[$0>>2] = $12;
   $15 = (($12) + ($8<<5)|0);
   $16 = ((($0)) + 8|0);
   HEAP32[$16>>2] = $15;
   $17 = HEAP32[$1>>2]|0;
   $18 = HEAP32[$4>>2]|0;
   $19 = $17;
   $20 = (($18) - ($19))|0;
   $21 = ($20|0)>(0);
   if (!($21)) {
    return;
   }
   $22 = $20 >>> 5;
   _memcpy(($12|0),($17|0),($20|0))|0;
   $23 = (($12) + ($22<<5)|0);
   HEAP32[$2>>2] = $23;
   return;
  }
 }
 $24 = ___cxa_find_matching_catch_2()|0;
 $25 = tempRet0;
 $26 = HEAP32[$0>>2]|0;
 $27 = ($26|0)==(0|0);
 if ($27) {
  ___resumeException($24|0);
  // unreachable;
 }
 $28 = HEAP32[$2>>2]|0;
 $29 = ($28|0)==($26|0);
 if (!($29)) {
  $scevgep$i$i$i = ((($28)) + -32|0);
  $30 = $scevgep$i$i$i;
  $31 = $26;
  $32 = (($30) - ($31))|0;
  $33 = $32 >>> 5;
  $34 = $33 ^ -1;
  $scevgep5$i$i$i = (($28) + ($34<<5)|0);
  HEAP32[$2>>2] = $scevgep5$i$i$i;
 }
 __ZdlPv($26);
 ___resumeException($24|0);
 // unreachable;
}
function __ZN3osg13KdTreeBuilderD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = ((62416));
 $1 = ((($0)) + 72|0);
 HEAP32[$1>>2] = ((62764));
 $2 = ((($0)) + 68|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  label = 4;
 } else {
  $5 = ((($3)) + 8|0);
  $6 = HEAP32[$5>>2]|0;HEAP32[$5>>2] = (($6-1)|0);
  $7 = ($6|0)==(1);
  if ($7) {
   __THREW__ = 0;
   invoke_viii(3262,($3|0),1,1);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if ($9) {
    $12 = ___cxa_find_matching_catch_2()|0;
    $13 = tempRet0;
    __THREW__ = 0;
    invoke_vii(3284,($0|0),((62908)|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     $16 = ___cxa_find_matching_catch_3(0|0)|0;
     $17 = tempRet0;
     ___clang_call_terminate($16);
     // unreachable;
    } else {
     $eh$lpad$body$index2Z2D = $13;$eh$lpad$body$indexZ2D = $12;
    }
   } else {
    label = 4;
   }
  } else {
   label = 4;
  }
 }
 do {
  if ((label|0) == 4) {
   HEAP32[$2>>2] = 0;
   __THREW__ = 0;
   invoke_vii(3284,($0|0),((62908)|0));
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if ($11) {
    $18 = ___cxa_find_matching_catch_2()|0;
    $19 = tempRet0;
    $eh$lpad$body$index2Z2D = $19;$eh$lpad$body$indexZ2D = $18;
    break;
   } else {
    __ZN3osg6ObjectD2Ev($1);
    return;
   }
  }
 } while(0);
 __THREW__ = 0;
 invoke_vi(388,($1|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if ($21) {
  $22 = ___cxa_find_matching_catch_3(0|0)|0;
  $23 = tempRet0;
  ___clang_call_terminate($22);
  // unreachable;
 } else {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
}
function __ZN3osg13KdTreeBuilderD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(2015,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK3osg13KdTreeBuilder11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175113|0);
}
function __ZNK3osg13KdTreeBuilder9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (145193|0);
}
function __ZN3osg13KdTreeBuilder5applyERNS_8GeometryE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$08 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = ((($1)) + 176|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if (!($5)) {
  $6 = (___dynamic_cast($4,26560,25368,0)|0);
  $phitmp = ($6|0)==(0|0);
  if (!($phitmp)) {
   STACKTOP = sp;return;
  }
 }
 $7 = ((($0)) + 68|0);
 $8 = HEAP32[$7>>2]|0;
 HEAP32[$2>>2] = (58136);
 $9 = ((($2)) + 4|0);
 HEAP32[$9>>2] = 0;
 __THREW__ = 0;
 $10 = (invoke_iii(3829,($8|0),($2|0))|0);
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if ($12) {
  $28 = ___cxa_find_matching_catch_2()|0;
  $29 = tempRet0;
  $$0 = $29;$$08 = $28;
  ___resumeException($$08|0);
  // unreachable;
 }
 $13 = ($10|0)==(0|0);
 if (!($13)) {
  $14 = ((($10)) + 8|0);
  $15 = HEAP32[$14>>2]|0;HEAP32[$14>>2] = (($15+1)|0);
 }
 $16 = HEAP32[$10>>2]|0;
 $17 = ((($16)) + 148|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ((($0)) + 56|0);
 __THREW__ = 0;
 $20 = (invoke_iiii($18|0,($10|0),($19|0),($1|0))|0);
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 do {
  if (!($22)) {
   if ($20) {
    $23 = HEAP32[$1>>2]|0;
    $24 = ((($23)) + 208|0);
    $25 = HEAP32[$24>>2]|0;
    __THREW__ = 0;
    invoke_vii($25|0,($1|0),($10|0));
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if ($27) {
     break;
    }
   }
   $37 = ((($10)) + 8|0);
   $38 = HEAP32[$37>>2]|0;HEAP32[$37>>2] = (($38-1)|0);
   $39 = ($38|0)==(1);
   if (!($39)) {
    STACKTOP = sp;return;
   }
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($10,1,1);
   STACKTOP = sp;return;
  }
 } while(0);
 $30 = ___cxa_find_matching_catch_2()|0;
 $31 = tempRet0;
 $32 = ((($10)) + 8|0);
 $33 = HEAP32[$32>>2]|0;HEAP32[$32>>2] = (($33-1)|0);
 $34 = ($33|0)==(1);
 if ($34) {
  __THREW__ = 0;
  invoke_viii(3262,($10|0),1,1);
  $35 = __THREW__; __THREW__ = 0;
  $36 = $35&1;
  if ($36) {
   $40 = ___cxa_find_matching_catch_3(0|0)|0;
   $41 = tempRet0;
   ___clang_call_terminate($40);
   // unreachable;
  }
 }
 $$0 = $31;$$08 = $30;
 ___resumeException($$08|0);
 // unreachable;
}
function __ZN3osg13KdTreeBuilder5cloneEv($0) {
 $0 = $0|0;
 var $$1$i = 0, $$16$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $2 = (__Znwj(104)|0);
 $3 = ((($2)) + 72|0);
 $4 = HEAP32[$0>>2]|0;
 $5 = ((($4)) + -12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($0) + ($6)|0);
 HEAP32[$1>>2] = (58136);
 $8 = ((($1)) + 4|0);
 HEAP32[$8>>2] = 0;
 __THREW__ = 0;
 invoke_viii(3468,($3|0),($7|0),($1|0));
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if ($10) {
  $21 = ___cxa_find_matching_catch_2()|0;
  $22 = tempRet0;
  $$1$i = $22;$$16$i = $21;
  __ZdlPv($2);
  ___resumeException($$16$i|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(3283,($2|0),((62908)|0),2);
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if ($12) {
  $23 = ___cxa_find_matching_catch_2()|0;
  $24 = tempRet0;
  __THREW__ = 0;
  invoke_vi(388,($3|0));
  $25 = __THREW__; __THREW__ = 0;
  $26 = $25&1;
  if ($26) {
   $27 = ___cxa_find_matching_catch_3(0|0)|0;
   $28 = tempRet0;
   ___clang_call_terminate($27);
   // unreachable;
  } else {
   $$1$i = $24;$$16$i = $23;
   __ZdlPv($2);
   ___resumeException($$16$i|0);
   // unreachable;
  }
 }
 HEAP32[$2>>2] = (62416);
 HEAP32[$3>>2] = (62764);
 $13 = ((($2)) + 56|0);
 $14 = ((($0)) + 56|0);
 ;HEAP32[$13>>2]=HEAP32[$14>>2]|0;HEAP32[$13+4>>2]=HEAP32[$14+4>>2]|0;HEAP32[$13+8>>2]=HEAP32[$14+8>>2]|0;
 $15 = ((($2)) + 68|0);
 $16 = ((($0)) + 68|0);
 $17 = HEAP32[$16>>2]|0;
 HEAP32[$15>>2] = $17;
 $18 = ($17|0)==(0|0);
 if ($18) {
  STACKTOP = sp;return ($2|0);
 }
 $19 = ((($17)) + 8|0);
 $20 = HEAP32[$19>>2]|0;HEAP32[$19>>2] = (($20+1)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZTv0_n16_N3osg13KdTreeBuilderD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __ZN3osg13KdTreeBuilderD1Ev($4);
 return;
}
function __ZTv0_n16_N3osg13KdTreeBuilderD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __THREW__ = 0;
 invoke_vi(2015,($4|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $7 = ___cxa_find_matching_catch_2()|0;
  $8 = tempRet0;
  __ZdlPv($4);
  ___resumeException($7|0);
  // unreachable;
 } else {
  __ZdlPv($4);
  return;
 }
}
function __ZTv0_n32_NK3osg13KdTreeBuilder11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175113|0);
}
function __ZTv0_n36_NK3osg13KdTreeBuilder9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (145193|0);
}
function __ZN3osg5cloneINS_6KdTreeEEEPT_PKS2_RKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp + 4|0;
 $3 = sp;
 $4 = ($0|0)==(0|0);
 if ($4) {
  $62 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
  if (!($62)) {
   $$1 = 0;
   STACKTOP = sp;return ($$1|0);
  }
  $63 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
  $64 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($63,166509,88)|0);
  $65 = HEAP32[$64>>2]|0;
  $66 = ((($65)) + -12|0);
  $67 = HEAP32[$66>>2]|0;
  $68 = (($64) + ($67)|0);
  __ZNKSt3__28ios_base6getlocEv($3,$68);
  __THREW__ = 0;
  $69 = (invoke_iii(3255,($3|0),(215188|0))|0);
  $70 = __THREW__; __THREW__ = 0;
  $71 = $70&1;
  if (!($71)) {
   $72 = HEAP32[$69>>2]|0;
   $73 = ((($72)) + 28|0);
   $74 = HEAP32[$73>>2]|0;
   __THREW__ = 0;
   $75 = (invoke_iii($74|0,($69|0),10)|0);
   $76 = __THREW__; __THREW__ = 0;
   $77 = $76&1;
   if (!($77)) {
    __ZNSt3__26localeD2Ev($3);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($64,$75)|0);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($64)|0);
    $$1 = 0;
    STACKTOP = sp;return ($$1|0);
   }
  }
  $78 = ___cxa_find_matching_catch_2()|0;
  $79 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3263,($3|0));
  $80 = __THREW__; __THREW__ = 0;
  $81 = $80&1;
  if ($81) {
   $82 = ___cxa_find_matching_catch_3(0|0)|0;
   $83 = tempRet0;
   ___clang_call_terminate($82);
   // unreachable;
  } else {
   ___resumeException($78|0);
   // unreachable;
  }
 }
 $5 = HEAP32[$0>>2]|0;
 $6 = ((($5)) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_iii[$7 & 8191]($0,$1)|0);
 $9 = ($8|0)==(0|0);
 if ($9) {
  label = 9;
 } else {
  $10 = ((($8)) + 8|0);
  $11 = HEAP32[$10>>2]|0;HEAP32[$10>>2] = (($11+1)|0);
  $12 = (___dynamic_cast($8,26112,25368,0)|0);
  $13 = ($12|0)==(0|0);
  if ($13) {
   label = 9;
  } else {
   __THREW__ = 0;
   (invoke_ii(3335,($8|0))|0);
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if ($15) {
    label = 5;
   } else {
    $$1 = $12;
    STACKTOP = sp;return ($$1|0);
   }
  }
 }
 L19: do {
  if ((label|0) == 9) {
   __THREW__ = 0;
   $23 = (invoke_ii(3265,2)|0);
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   if ($25) {
    label = 5;
   } else {
    do {
     if ($23) {
      __THREW__ = 0;
      $26 = (invoke_ii(3266,2)|0);
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       label = 5;
       break L19;
      }
      __THREW__ = 0;
      $29 = (invoke_iiii(3267,($26|0),(166420|0),88)|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 5;
       break L19;
      }
      $32 = HEAP32[$29>>2]|0;
      $33 = ((($32)) + -12|0);
      $34 = HEAP32[$33>>2]|0;
      $35 = (($29) + ($34)|0);
      __THREW__ = 0;
      invoke_vii(3257,($2|0),($35|0));
      $36 = __THREW__; __THREW__ = 0;
      $37 = $36&1;
      if ($37) {
       label = 5;
       break L19;
      }
      __THREW__ = 0;
      $38 = (invoke_iii(3255,($2|0),(215188|0))|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       $41 = HEAP32[$38>>2]|0;
       $42 = ((($41)) + 28|0);
       $43 = HEAP32[$42>>2]|0;
       __THREW__ = 0;
       $44 = (invoke_iii($43|0,($38|0),10)|0);
       $45 = __THREW__; __THREW__ = 0;
       $46 = $45&1;
       if (!($46)) {
        __THREW__ = 0;
        invoke_vi(3263,($2|0));
        $53 = __THREW__; __THREW__ = 0;
        $54 = $53&1;
        if ($54) {
         label = 5;
         break L19;
        }
        __THREW__ = 0;
        (invoke_iii(3268,($29|0),($44|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 5;
         break L19;
        }
        __THREW__ = 0;
        (invoke_ii(3269,($29|0))|0);
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 5;
         break L19;
        } else {
         break;
        }
       }
      }
      $47 = ___cxa_find_matching_catch_2()|0;
      $48 = tempRet0;
      __THREW__ = 0;
      invoke_vi(3263,($2|0));
      $49 = __THREW__; __THREW__ = 0;
      $50 = $49&1;
      if ($50) {
       $51 = ___cxa_find_matching_catch_3(0|0)|0;
       $52 = tempRet0;
       ___clang_call_terminate($51);
       // unreachable;
      } else {
       $eh$lpad$body$index2Z2D = $48;$eh$lpad$body$indexZ2D = $47;
       break L19;
      }
     }
    } while(0);
    if ($9) {
     $$1 = 0;
     STACKTOP = sp;return ($$1|0);
    }
    $59 = ((($8)) + 8|0);
    $60 = HEAP32[$59>>2]|0;HEAP32[$59>>2] = (($60-1)|0);
    $61 = ($60|0)==(1);
    if (!($61)) {
     $$1 = 0;
     STACKTOP = sp;return ($$1|0);
    }
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($8,1,1);
    $$1 = 0;
    STACKTOP = sp;return ($$1|0);
   }
  }
 } while(0);
 if ((label|0) == 5) {
  $16 = ___cxa_find_matching_catch_2()|0;
  $17 = tempRet0;
  $eh$lpad$body$index2Z2D = $17;$eh$lpad$body$indexZ2D = $16;
 }
 if ($9) {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 $18 = ((($8)) + 8|0);
 $19 = HEAP32[$18>>2]|0;HEAP32[$18>>2] = (($19-1)|0);
 $20 = ($19|0)==(1);
 if (!($20)) {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(3262,($8|0),1,1);
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if ($22) {
  $84 = ___cxa_find_matching_catch_3(0|0)|0;
  $85 = tempRet0;
  ___clang_call_terminate($84);
  // unreachable;
 } else {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 return (0)|0;
}
function __ZN3osg13KdTreeBuilderC1Ev($0) {
 $0 = $0|0;
 var $$0 = 0, $$02 = 0, $$2 = 0, $$24 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 72|0);
 __ZN3osg10ReferencedC2Ev($1);
 HEAP32[$1>>2] = (63412);
 $2 = ((($0)) + 84|0);
 ;HEAP32[$2>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;
 $3 = ((($0)) + 96|0);
 HEAP32[$3>>2] = 2;
 $4 = ((($0)) + 100|0);
 HEAP32[$4>>2] = 0;
 __THREW__ = 0;
 invoke_viii(3283,($0|0),((62908)|0),2);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $30 = ___cxa_find_matching_catch_2()|0;
  $31 = tempRet0;
  $$2 = $31;$$24 = $30;
 } else {
  HEAP32[$0>>2] = (62416);
  HEAP32[$1>>2] = (62764);
  $7 = ((($0)) + 56|0);
  HEAP32[$7>>2] = 0;
  $8 = ((($0)) + 60|0);
  HEAP32[$8>>2] = 4;
  $9 = ((($0)) + 64|0);
  HEAP32[$9>>2] = 32;
  $10 = ((($0)) + 68|0);
  HEAP32[$10>>2] = 0;
  __THREW__ = 0;
  $11 = (invoke_ii(3276,76)|0);
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  do {
   if ($13) {
    label = 10;
   } else {
    __THREW__ = 0;
    invoke_vi(3282,($11|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     $34 = ___cxa_find_matching_catch_2()|0;
     $35 = tempRet0;
     __ZdlPv($11);
     $$0 = $35;$$02 = $34;
     break;
    }
    $16 = ((($11)) + 12|0);
    ;HEAP32[$16>>2]=0|0;HEAP32[$16+4>>2]=0|0;HEAP32[$16+8>>2]=0|0;
    $17 = ((($11)) + 24|0);
    HEAP32[$17>>2] = 2;
    $18 = ((($11)) + 28|0);
    HEAP32[$18>>2] = 0;
    HEAP32[$11>>2] = (62196);
    $19 = ((($11)) + 32|0);
    dest=$19; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
    $20 = HEAP32[$10>>2]|0;
    $21 = ($20|0)==($11|0);
    if ($21) {
     return;
    }
    HEAP32[$10>>2] = $11;
    $22 = ((($11)) + 8|0);
    $23 = HEAP32[$22>>2]|0;HEAP32[$22>>2] = (($23+1)|0);
    $24 = ($20|0)==(0|0);
    if ($24) {
     return;
    }
    $25 = ((($20)) + 8|0);
    $26 = HEAP32[$25>>2]|0;HEAP32[$25>>2] = (($26-1)|0);
    $27 = ($26|0)==(1);
    if (!($27)) {
     return;
    }
    __THREW__ = 0;
    invoke_viii(3262,($20|0),1,1);
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if ($29) {
     label = 10;
    } else {
     return;
    }
   }
  } while(0);
  if ((label|0) == 10) {
   $32 = ___cxa_find_matching_catch_2()|0;
   $33 = tempRet0;
   $$0 = $33;$$02 = $32;
  }
  $36 = HEAP32[$10>>2]|0;
  $37 = ($36|0)==(0|0);
  if (!($37)) {
   $38 = ((($36)) + 8|0);
   $39 = HEAP32[$38>>2]|0;HEAP32[$38>>2] = (($39-1)|0);
   $40 = ($39|0)==(1);
   if ($40) {
    __THREW__ = 0;
    invoke_viii(3262,($36|0),1,1);
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     $47 = ___cxa_find_matching_catch_3(0|0)|0;
     $48 = tempRet0;
     ___clang_call_terminate($47);
     // unreachable;
    }
   }
  }
  HEAP32[$10>>2] = 0;
  __THREW__ = 0;
  invoke_vii(3284,($0|0),((62908)|0));
  $43 = __THREW__; __THREW__ = 0;
  $44 = $43&1;
  if ($44) {
   $47 = ___cxa_find_matching_catch_3(0|0)|0;
   $48 = tempRet0;
   ___clang_call_terminate($47);
   // unreachable;
  } else {
   $$2 = $$0;$$24 = $$02;
  }
 }
 __THREW__ = 0;
 invoke_vi(388,($1|0));
 $45 = __THREW__; __THREW__ = 0;
 $46 = $45&1;
 if ($46) {
  $47 = ___cxa_find_matching_catch_3(0|0)|0;
  $48 = tempRet0;
  ___clang_call_terminate($47);
  // unreachable;
 } else {
  ___resumeException($$24|0);
  // unreachable;
 }
}
function __ZN3osg13asciiToDoubleEPKc($0) {
 $0 = $0|0;
 var $$$068 = 0.0, $$0 = 0.0, $$06489 = 0, $$066$lcssa$ph = 0, $$06691 = 0, $$06888 = 0.0, $$1 = 0.0, $$16592 = 0, $$167 = 0, $$169 = 0.0, $$off = 0, $$off77 = 0, $$off81 = 0, $$off82 = 0, $$old4 = 0, $$pre = 0.0, $$pre97 = 0.0, $1 = 0, $10 = 0, $11 = 0;
 var $12 = 0, $13 = 0.0, $14 = 0, $15 = 0.0, $16 = 0.0, $17 = 0, $18 = 0, $19 = 0.0, $2 = 0, $20 = 0, $21 = 0.0, $22 = 0.0, $23 = 0, $24 = 0.0, $25 = 0, $26 = 0.0, $27 = 0.0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0.0, $47 = 0, $48 = 0;
 var $49 = 0.0, $5 = 0, $50 = 0.0, $51 = 0.0, $52 = 0, $53 = 0.0, $54 = 0.0, $55 = 0.0, $56 = 0.0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0.0, $62 = 0.0, $63 = 0.0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0.0, $72 = 0.0, $73 = 0.0, $74 = 0.0, $75 = 0.0, $76 = 0.0, $77 = 0.0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(64|0);
 $1 = sp + 48|0;
 $2 = sp + 32|0;
 $3 = sp + 16|0;
 $4 = sp;
 $5 = (_strncmp($0,145240,2)|0);
 $6 = ($5|0)==(0);
 if ($6) {
  $7 = ((($0)) + 2|0);
  $8 = HEAP8[$7>>0]|0;
  $9 = ($8<<24>>24)==(0);
  if ($9) {
   $$1 = 0.0;
   STACKTOP = sp;return (+$$1);
  } else {
   $$06489 = $7;$$06888 = 0.0;$10 = $8;
  }
  L5: while(1) {
   $$off77 = (($10) + -48)<<24>>24;
   $11 = ($$off77&255)<(10);
   do {
    if ($11) {
     $12 = $10 << 24 >> 24;
     $13 = $$06888 * 16.0;
     $14 = (($12) + -48)|0;
     $15 = (+($14|0));
     $16 = $13 + $15;
     $$169 = $16;
    } else {
     switch ($10<<24>>24) {
     case 65: case 66: case 67: case 68: case 69: case 70: case 97: case 98: case 99: case 100: case 101: case 102:  {
      break;
     }
     default: {
      $$1 = $$06888;
      label = 29;
      break L5;
     }
     }
     $17 = $10 << 24 >> 24;
     $$off81 = (($10) + -97)<<24>>24;
     $18 = ($$off81&255)<(6);
     if ($18) {
      $19 = $$06888 * 16.0;
      $20 = (($17) + -87)|0;
      $21 = (+($20|0));
      $22 = $19 + $21;
      $$169 = $22;
      break;
     } else {
      $$off82 = (($10) + -65)<<24>>24;
      $23 = ($$off82&255)<(6);
      $24 = $$06888 * 16.0;
      $25 = (($17) + -55)|0;
      $26 = (+($25|0));
      $27 = $24 + $26;
      $$$068 = $23 ? $27 : $$06888;
      $$169 = $$$068;
      break;
     }
    }
   } while(0);
   $28 = ((($$06489)) + 1|0);
   $29 = HEAP8[$28>>0]|0;
   $30 = ($29<<24>>24)==(0);
   if ($30) {
    $$1 = $$169;
    label = 29;
    break;
   } else {
    $$06489 = $28;$$06888 = $$169;$10 = $29;
   }
  }
  if ((label|0) == 29) {
   STACKTOP = sp;return (+$$1);
  }
 }
 $31 = ((($1)) + 1|0);
 HEAP8[$31>>0] = 0;
 HEAP8[$1>>0] = 0;
 $32 = ((($3)) + 8|0);
 HEAPF64[$32>>3] = 1.0;
 HEAPF64[$3>>3] = 1.0;
 $33 = ((($2)) + 8|0);
 $34 = ((($4)) + 8|0);
 ;HEAP32[$2>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;HEAP32[$2+12>>2]=0|0;
 HEAPF64[$34>>3] = 0.10000000000000001;
 HEAPF64[$4>>3] = 0.10000000000000001;
 $35 = HEAP8[$0>>0]|0;
 $36 = ($35<<24>>24)==(0);
 do {
  if ($36) {
   $$0 = 0.0;
  } else {
   $37 = $35 << 24 >> 24;
   $$06691 = 0;$$16592 = $0;$38 = $35;$48 = $37;
   L21: while(1) {
    L23: do {
     switch ($38<<24>>24) {
     case 43:  {
      $39 = (($3) + ($$06691<<3)|0);
      HEAPF64[$39>>3] = 1.0;
      $$167 = $$06691;
      break;
     }
     case 45:  {
      $40 = (($3) + ($$06691<<3)|0);
      HEAPF64[$40>>3] = -1.0;
      $$167 = $$06691;
      break;
     }
     default: {
      $$off = (($38) + -48)<<24>>24;
      $41 = ($$off&255)<(10);
      if ($41) {
       $42 = (($1) + ($$06691)|0);
       $43 = HEAP8[$42>>0]|0;
       $44 = ($43<<24>>24)==(0);
       $45 = (($2) + ($$06691<<3)|0);
       $46 = +HEAPF64[$45>>3];
       $47 = (($48) + -48)|0;
       $49 = (+($47|0));
       if ($44) {
        $50 = $46 * 10.0;
        $51 = $49 + $50;
        HEAPF64[$45>>3] = $51;
        $$167 = $$06691;
        break L23;
       } else {
        $52 = (($4) + ($$06691<<3)|0);
        $53 = +HEAPF64[$52>>3];
        $54 = $49 * $53;
        $55 = $46 + $54;
        HEAPF64[$45>>3] = $55;
        $56 = $53 * 0.10000000000000001;
        HEAPF64[$52>>3] = $56;
        $$167 = $$06691;
        break L23;
       }
      }
      $57 = ($38<<24>>24)==(46);
      if ($57) {
       $58 = (($1) + ($$06691)|0);
       HEAP8[$58>>0] = 1;
       $$167 = $$06691;
       break L23;
      }
      $59 = ($38<<24>>24)==(101);
      $$old4 = ($$06691|0)==(1);
      if ($59) {
       if ($$old4) {
        label = 24;
        break L21;
       } else {
        $$167 = 1;
        break L23;
       }
      } else {
       $60 = ($38<<24>>24)!=(69);
       $or$cond = $$old4 | $60;
       if ($or$cond) {
        $$066$lcssa$ph = $$06691;
        label = 26;
        break L21;
       } else {
        $$167 = 1;
        break L23;
       }
      }
     }
     }
    } while(0);
    $64 = ((($$16592)) + 1|0);
    $65 = HEAP8[$64>>0]|0;
    $66 = $65 << 24 >> 24;
    $67 = ($65<<24>>24)!=(0);
    $68 = ($$167|0)<(2);
    $69 = $68 & $67;
    if ($69) {
     $$06691 = $$167;$$16592 = $64;$38 = $65;$48 = $66;
    } else {
     $$066$lcssa$ph = $$167;
     label = 26;
     break;
    }
   }
   if ((label|0) == 24) {
    $61 = +HEAPF64[$2>>3];
    $62 = +HEAPF64[$3>>3];
    $63 = $61 * $62;
    $77 = $63;
   }
   else if ((label|0) == 26) {
    $$pre = +HEAPF64[$2>>3];
    $$pre97 = +HEAPF64[$3>>3];
    $70 = ($$066$lcssa$ph|0)==(0);
    $71 = $$pre * $$pre97;
    if ($70) {
     $$0 = $71;
     break;
    } else {
     $77 = $71;
    }
   }
   $72 = +HEAPF64[$33>>3];
   $73 = +HEAPF64[$32>>3];
   $74 = $72 * $73;
   $75 = (+Math_pow(10.0,(+$74)));
   $76 = $77 * $75;
   $$0 = $76;
  }
 } while(0);
 $$1 = $$0;
 STACKTOP = sp;return (+$$1);
}
function __ZN3osg17findAsciiToDoubleEPKc($0) {
 $0 = $0|0;
 var $$011 = 0.0, $$013 = 0, $$off = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0.0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $$011 = 0.0;
  return (+$$011);
 } else {
  $$013 = $0;$3 = $1;
 }
 while(1) {
  $$off = (($3) + -48)<<24>>24;
  $4 = ($$off&255)<(10);
  if ($4) {
   break;
  }
  $6 = ((($$013)) + 1|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = ($7<<24>>24)==(0);
  if ($8) {
   $$011 = 0.0;
   label = 5;
   break;
  } else {
   $$013 = $6;$3 = $7;
  }
 }
 if ((label|0) == 5) {
  return (+$$011);
 }
 $5 = (+__ZN3osg13asciiToDoubleEPKc($$013));
 $$011 = $5;
 return (+$$011);
}
function __ZN3osg7MatrixdC2Edddddddddddddddd($0,$1,$2,$3,$4,$5,$6,$7,$8,$9,$10,$11,$12,$13,$14,$15,$16) {
 $0 = $0|0;
 $1 = +$1;
 $2 = +$2;
 $3 = +$3;
 $4 = +$4;
 $5 = +$5;
 $6 = +$6;
 $7 = +$7;
 $8 = +$8;
 $9 = +$9;
 $10 = +$10;
 $11 = +$11;
 $12 = +$12;
 $13 = +$13;
 $14 = +$14;
 $15 = +$15;
 $16 = +$16;
 var $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF64[$0>>3] = $1;
 $17 = ((($0)) + 8|0);
 HEAPF64[$17>>3] = $2;
 $18 = ((($0)) + 16|0);
 HEAPF64[$18>>3] = $3;
 $19 = ((($0)) + 24|0);
 HEAPF64[$19>>3] = $4;
 $20 = ((($0)) + 32|0);
 HEAPF64[$20>>3] = $5;
 $21 = ((($0)) + 40|0);
 HEAPF64[$21>>3] = $6;
 $22 = ((($0)) + 48|0);
 HEAPF64[$22>>3] = $7;
 $23 = ((($0)) + 56|0);
 HEAPF64[$23>>3] = $8;
 $24 = ((($0)) + 64|0);
 HEAPF64[$24>>3] = $9;
 $25 = ((($0)) + 72|0);
 HEAPF64[$25>>3] = $10;
 $26 = ((($0)) + 80|0);
 HEAPF64[$26>>3] = $11;
 $27 = ((($0)) + 88|0);
 HEAPF64[$27>>3] = $12;
 $28 = ((($0)) + 96|0);
 HEAPF64[$28>>3] = $13;
 $29 = ((($0)) + 104|0);
 HEAPF64[$29>>3] = $14;
 $30 = ((($0)) + 112|0);
 HEAPF64[$30>>3] = $15;
 $31 = ((($0)) + 120|0);
 HEAPF64[$31>>3] = $16;
 return;
}
function __ZNK3osg7Matrixd9getRotateEv($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$pre$phi28Z2D = 0, $$pre$phiZ2D = 0, $$sink$sink$sink = 0.0, $10 = 0.0, $11 = 0.0, $12 = 0.0, $13 = 0.0, $14 = 0, $15 = 0.0, $16 = 0.0, $17 = 0.0, $18 = 0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0.0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0.0, $34 = 0, $35 = 0.0, $36 = 0, $37 = 0.0, $38 = 0, $39 = 0.0, $4 = 0.0, $40 = 0, $41 = 0.0, $42 = 0, $43 = 0.0;
 var $44 = 0.0, $45 = 0.0, $46 = 0, $47 = 0.0, $48 = 0.0, $49 = 0.0, $5 = 0.0, $50 = 0, $51 = 0.0, $52 = 0, $53 = 0.0, $54 = 0.0, $55 = 0.0, $56 = 0, $57 = 0.0, $58 = 0.0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0.0, $63 = 0.0, $64 = 0.0, $65 = 0.0, $66 = 0.0, $67 = 0.0, $68 = 0.0, $69 = 0.0, $7 = 0.0, $70 = 0.0, $71 = 0.0, $8 = 0.0, $9 = 0, $trunc = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $2 = sp;
 $3 = ((($0)) + 24|0);
 ;HEAP32[$0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;HEAP32[$0+16>>2]=0|0;HEAP32[$0+20>>2]=0|0;
 HEAPF64[$3>>3] = 1.0;
 $4 = +HEAPF64[$1>>3];
 $5 = $4 + 1.0;
 $6 = ((($1)) + 40|0);
 $7 = +HEAPF64[$6>>3];
 $8 = $5 + $7;
 $9 = ((($1)) + 80|0);
 $10 = +HEAPF64[$9>>3];
 $11 = $8 + $10;
 HEAPF64[$2>>3] = $11;
 $12 = $5 - $7;
 $13 = $12 - $10;
 $14 = ((($2)) + 8|0);
 HEAPF64[$14>>3] = $13;
 $15 = 1.0 - $4;
 $16 = $15 + $7;
 $17 = $16 - $10;
 $18 = ((($2)) + 16|0);
 HEAPF64[$18>>3] = $17;
 $19 = $15 - $7;
 $20 = $19 + $10;
 $21 = ((($2)) + 24|0);
 HEAPF64[$21>>3] = $20;
 $22 = $13 > $11;
 $23 = $22&1;
 $24 = (($2) + ($23<<3)|0);
 $25 = +HEAPF64[$24>>3];
 $26 = $17 > $25;
 $27 = $26 ? 2 : $23;
 $28 = (($2) + ($27<<3)|0);
 $29 = +HEAPF64[$28>>3];
 $30 = $20 > $29;
 $31 = $30 ? 3 : $27;
 $32 = ((($1)) + 8|0);
 $33 = +HEAPF64[$32>>3];
 $34 = ((($1)) + 64|0);
 $35 = +HEAPF64[$34>>3];
 $36 = ((($1)) + 16|0);
 $37 = +HEAPF64[$36>>3];
 $38 = ((($1)) + 72|0);
 $39 = +HEAPF64[$38>>3];
 $40 = ((($1)) + 48|0);
 $41 = +HEAPF64[$40>>3];
 $42 = ((($1)) + 32|0);
 $43 = +HEAPF64[$42>>3];
 $trunc = $31&255;
 $trunc$clear = $trunc & 3;
 L1: do {
  switch ($trunc$clear<<24>>24) {
  case 0:  {
   HEAPF64[$3>>3] = $11;
   $44 = $41 - $39;
   HEAPF64[$0>>3] = $44;
   $45 = $35 - $37;
   $46 = ((($0)) + 8|0);
   HEAPF64[$46>>3] = $45;
   $47 = $33 - $43;
   $$pre$phi28Z2D = $46;$$pre$phiZ2D = $0;$$sink$sink$sink = $47;$66 = $11;$68 = $44;$70 = $45;
   break;
  }
  case 1:  {
   $48 = $41 - $39;
   HEAPF64[$3>>3] = $48;
   HEAPF64[$0>>3] = $13;
   $49 = $33 + $43;
   $50 = ((($0)) + 8|0);
   HEAPF64[$50>>3] = $49;
   $51 = $35 + $37;
   $$pre$phi28Z2D = $50;$$pre$phiZ2D = $0;$$sink$sink$sink = $51;$66 = $48;$68 = $13;$70 = $49;
   break;
  }
  default: {
   $52 = ($31|0)==(2);
   $53 = $39 + $41;
   if ($52) {
    $54 = $35 - $37;
    HEAPF64[$3>>3] = $54;
    $55 = $33 + $43;
    HEAPF64[$0>>3] = $55;
    $56 = ((($0)) + 8|0);
    HEAPF64[$56>>3] = $17;
    $$pre$phi28Z2D = $56;$$pre$phiZ2D = $0;$$sink$sink$sink = $53;$66 = $54;$68 = $55;$70 = $17;
    break L1;
   } else {
    $57 = $33 - $43;
    HEAPF64[$3>>3] = $57;
    $58 = $35 + $37;
    HEAPF64[$0>>3] = $58;
    $59 = ((($0)) + 8|0);
    HEAPF64[$59>>3] = $53;
    $$pre$phi28Z2D = $59;$$pre$phiZ2D = $0;$$sink$sink$sink = $20;$66 = $57;$68 = $58;$70 = $53;
    break L1;
   }
  }
  }
 } while(0);
 $60 = ((($0)) + 16|0);
 $61 = (($2) + ($31<<3)|0);
 $62 = +HEAPF64[$61>>3];
 $63 = 0.25 / $62;
 $64 = (+Math_sqrt((+$63)));
 $65 = $64 * $66;
 HEAPF64[$3>>3] = $65;
 $67 = $64 * $68;
 HEAPF64[$$pre$phiZ2D>>3] = $67;
 $69 = $64 * $70;
 HEAPF64[$$pre$phi28Z2D>>3] = $69;
 $71 = $64 * $$sink$sink$sink;
 HEAPF64[$60>>3] = $71;
 STACKTOP = sp;return;
}
function __ZNK3osg7Matrixd7compareERKS0_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$016 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0.0, $15 = 0.0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0.0, $20 = 0.0, $21 = 0.0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0.0, $27 = 0.0;
 var $28 = 0, $29 = 0, $3 = 0.0, $30 = 0, $31 = 0, $32 = 0.0, $33 = 0.0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0.0, $39 = 0.0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0.0, $45 = 0.0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0.0, $51 = 0.0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0.0, $57 = 0.0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0.0, $63 = 0.0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0.0, $69 = 0.0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0.0, $75 = 0.0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0.0, $80 = 0.0, $81 = 0.0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0.0, $87 = 0.0, $88 = 0, $89 = 0, $9 = 0.0, $90 = 0, $91 = 0, $92 = 0.0, $93 = 0.0, $94 = 0, $95 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = +HEAPF64[$0>>3];
 $3 = +HEAPF64[$1>>3];
 $4 = $2 < $3;
 do {
  if ($4) {
   $$016 = -1;
  } else {
   $5 = $3 < $2;
   if ($5) {
    $$016 = 1;
   } else {
    $6 = ((($0)) + 8|0);
    $7 = ((($1)) + 8|0);
    $8 = +HEAPF64[$6>>3];
    $9 = +HEAPF64[$7>>3];
    $10 = $8 < $9;
    if ($10) {
     $$016 = -1;
    } else {
     $11 = $9 < $8;
     if ($11) {
      $$016 = 1;
     } else {
      $12 = ((($0)) + 16|0);
      $13 = ((($1)) + 16|0);
      $14 = +HEAPF64[$12>>3];
      $15 = +HEAPF64[$13>>3];
      $16 = $14 < $15;
      if ($16) {
       $$016 = -1;
      } else {
       $17 = $15 < $14;
       if ($17) {
        $$016 = 1;
       } else {
        $18 = ((($0)) + 24|0);
        $19 = ((($1)) + 24|0);
        $20 = +HEAPF64[$18>>3];
        $21 = +HEAPF64[$19>>3];
        $22 = $20 < $21;
        if ($22) {
         $$016 = -1;
        } else {
         $23 = $21 < $20;
         if ($23) {
          $$016 = 1;
         } else {
          $24 = ((($0)) + 32|0);
          $25 = ((($1)) + 32|0);
          $26 = +HEAPF64[$24>>3];
          $27 = +HEAPF64[$25>>3];
          $28 = $26 < $27;
          if ($28) {
           $$016 = -1;
          } else {
           $29 = $27 < $26;
           if ($29) {
            $$016 = 1;
           } else {
            $30 = ((($0)) + 40|0);
            $31 = ((($1)) + 40|0);
            $32 = +HEAPF64[$30>>3];
            $33 = +HEAPF64[$31>>3];
            $34 = $32 < $33;
            if ($34) {
             $$016 = -1;
            } else {
             $35 = $33 < $32;
             if ($35) {
              $$016 = 1;
             } else {
              $36 = ((($0)) + 48|0);
              $37 = ((($1)) + 48|0);
              $38 = +HEAPF64[$36>>3];
              $39 = +HEAPF64[$37>>3];
              $40 = $38 < $39;
              if ($40) {
               $$016 = -1;
              } else {
               $41 = $39 < $38;
               if ($41) {
                $$016 = 1;
               } else {
                $42 = ((($0)) + 56|0);
                $43 = ((($1)) + 56|0);
                $44 = +HEAPF64[$42>>3];
                $45 = +HEAPF64[$43>>3];
                $46 = $44 < $45;
                if ($46) {
                 $$016 = -1;
                } else {
                 $47 = $45 < $44;
                 if ($47) {
                  $$016 = 1;
                 } else {
                  $48 = ((($0)) + 64|0);
                  $49 = ((($1)) + 64|0);
                  $50 = +HEAPF64[$48>>3];
                  $51 = +HEAPF64[$49>>3];
                  $52 = $50 < $51;
                  if ($52) {
                   $$016 = -1;
                  } else {
                   $53 = $51 < $50;
                   if ($53) {
                    $$016 = 1;
                   } else {
                    $54 = ((($0)) + 72|0);
                    $55 = ((($1)) + 72|0);
                    $56 = +HEAPF64[$54>>3];
                    $57 = +HEAPF64[$55>>3];
                    $58 = $56 < $57;
                    if ($58) {
                     $$016 = -1;
                    } else {
                     $59 = $57 < $56;
                     if ($59) {
                      $$016 = 1;
                      break;
                     }
                     $60 = ((($0)) + 80|0);
                     $61 = ((($1)) + 80|0);
                     $62 = +HEAPF64[$60>>3];
                     $63 = +HEAPF64[$61>>3];
                     $64 = $62 < $63;
                     if ($64) {
                      $$016 = -1;
                      break;
                     }
                     $65 = $63 < $62;
                     if ($65) {
                      $$016 = 1;
                      break;
                     }
                     $66 = ((($0)) + 88|0);
                     $67 = ((($1)) + 88|0);
                     $68 = +HEAPF64[$66>>3];
                     $69 = +HEAPF64[$67>>3];
                     $70 = $68 < $69;
                     if ($70) {
                      $$016 = -1;
                      break;
                     }
                     $71 = $69 < $68;
                     if ($71) {
                      $$016 = 1;
                      break;
                     }
                     $72 = ((($0)) + 96|0);
                     $73 = ((($1)) + 96|0);
                     $74 = +HEAPF64[$72>>3];
                     $75 = +HEAPF64[$73>>3];
                     $76 = $74 < $75;
                     if ($76) {
                      $$016 = -1;
                      break;
                     }
                     $77 = $75 < $74;
                     if ($77) {
                      $$016 = 1;
                      break;
                     }
                     $78 = ((($0)) + 104|0);
                     $79 = ((($1)) + 104|0);
                     $80 = +HEAPF64[$78>>3];
                     $81 = +HEAPF64[$79>>3];
                     $82 = $80 < $81;
                     if ($82) {
                      $$016 = -1;
                      break;
                     }
                     $83 = $81 < $80;
                     if ($83) {
                      $$016 = 1;
                      break;
                     }
                     $84 = ((($0)) + 112|0);
                     $85 = ((($1)) + 112|0);
                     $86 = +HEAPF64[$84>>3];
                     $87 = +HEAPF64[$85>>3];
                     $88 = $86 < $87;
                     if ($88) {
                      $$016 = -1;
                      break;
                     }
                     $89 = $87 < $86;
                     if ($89) {
                      $$016 = 1;
                      break;
                     }
                     $90 = ((($0)) + 120|0);
                     $91 = ((($1)) + 120|0);
                     $92 = +HEAPF64[$90>>3];
                     $93 = +HEAPF64[$91>>3];
                     $94 = $92 < $93;
                     if ($94) {
                      $$016 = -1;
                      break;
                     }
                     $95 = $93 < $92;
                     if ($95) {
                      $$016 = 1;
                      break;
                     }
                     $$016 = 0;
                    }
                   }
                  }
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 return ($$016|0);
}
function __ZN3osg7Matrixd8setTransEddd($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = +$1;
 $2 = +$2;
 $3 = +$3;
 var $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ((($0)) + 96|0);
 HEAPF64[$4>>3] = $1;
 $5 = ((($0)) + 104|0);
 HEAPF64[$5>>3] = $2;
 $6 = ((($0)) + 112|0);
 HEAPF64[$6>>3] = $3;
 return;
}
function __ZN3osg7Matrixd8setTransERKNS_5Vec3fE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0.0, $11 = 0.0, $12 = 0, $2 = 0.0, $3 = 0.0, $4 = 0, $5 = 0, $6 = 0.0, $7 = 0.0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = +HEAPF32[$1>>2];
 $3 = $2;
 $4 = ((($0)) + 96|0);
 HEAPF64[$4>>3] = $3;
 $5 = ((($1)) + 4|0);
 $6 = +HEAPF32[$5>>2];
 $7 = $6;
 $8 = ((($0)) + 104|0);
 HEAPF64[$8>>3] = $7;
 $9 = ((($1)) + 8|0);
 $10 = +HEAPF32[$9>>2];
 $11 = $10;
 $12 = ((($0)) + 112|0);
 HEAPF64[$12>>3] = $11;
 return;
}
function __ZN3osg7Matrixd8setTransERKNS_5Vec3dE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0.0, $3 = 0, $4 = 0, $5 = 0.0, $6 = 0, $7 = 0, $8 = 0.0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = +HEAPF64[$1>>3];
 $3 = ((($0)) + 96|0);
 HEAPF64[$3>>3] = $2;
 $4 = ((($1)) + 8|0);
 $5 = +HEAPF64[$4>>3];
 $6 = ((($0)) + 104|0);
 HEAPF64[$6>>3] = $5;
 $7 = ((($1)) + 16|0);
 $8 = +HEAPF64[$7>>3];
 $9 = ((($0)) + 112|0);
 HEAPF64[$9>>3] = $8;
 return;
}
function __ZN3osg7Matrixd12makeIdentityEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF64[$0>>3] = 1.0;
 $1 = ((($0)) + 8|0);
 $2 = ((($0)) + 40|0);
 ;HEAP32[$1>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;HEAP32[$1+12>>2]=0|0;HEAP32[$1+16>>2]=0|0;HEAP32[$1+20>>2]=0|0;HEAP32[$1+24>>2]=0|0;HEAP32[$1+28>>2]=0|0;
 HEAPF64[$2>>3] = 1.0;
 $3 = ((($0)) + 48|0);
 $4 = ((($0)) + 80|0);
 ;HEAP32[$3>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;HEAP32[$3+12>>2]=0|0;HEAP32[$3+16>>2]=0|0;HEAP32[$3+20>>2]=0|0;HEAP32[$3+24>>2]=0|0;HEAP32[$3+28>>2]=0|0;
 HEAPF64[$4>>3] = 1.0;
 $5 = ((($0)) + 88|0);
 $6 = ((($0)) + 120|0);
 ;HEAP32[$5>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;HEAP32[$5+12>>2]=0|0;HEAP32[$5+16>>2]=0|0;HEAP32[$5+20>>2]=0|0;HEAP32[$5+24>>2]=0|0;HEAP32[$5+28>>2]=0|0;
 HEAPF64[$6>>3] = 1.0;
 return;
}
function __ZN3osg7Matrixd9makeScaleEddd($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = +$1;
 $2 = +$2;
 $3 = +$3;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF64[$0>>3] = $1;
 $4 = ((($0)) + 8|0);
 $5 = ((($0)) + 40|0);
 ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;HEAP32[$4+12>>2]=0|0;HEAP32[$4+16>>2]=0|0;HEAP32[$4+20>>2]=0|0;HEAP32[$4+24>>2]=0|0;HEAP32[$4+28>>2]=0|0;
 HEAPF64[$5>>3] = $2;
 $6 = ((($0)) + 48|0);
 $7 = ((($0)) + 80|0);
 ;HEAP32[$6>>2]=0|0;HEAP32[$6+4>>2]=0|0;HEAP32[$6+8>>2]=0|0;HEAP32[$6+12>>2]=0|0;HEAP32[$6+16>>2]=0|0;HEAP32[$6+20>>2]=0|0;HEAP32[$6+24>>2]=0|0;HEAP32[$6+28>>2]=0|0;
 HEAPF64[$7>>3] = $3;
 $8 = ((($0)) + 88|0);
 $9 = ((($0)) + 120|0);
 ;HEAP32[$8>>2]=0|0;HEAP32[$8+4>>2]=0|0;HEAP32[$8+8>>2]=0|0;HEAP32[$8+12>>2]=0|0;HEAP32[$8+16>>2]=0|0;HEAP32[$8+20>>2]=0|0;HEAP32[$8+24>>2]=0|0;HEAP32[$8+28>>2]=0|0;
 HEAPF64[$9>>3] = 1.0;
 return;
}
function __ZN3osg7Matrixd13makeTranslateEddd($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = +$1;
 $2 = +$2;
 $3 = +$3;
 var $10 = 0, $11 = 0, $12 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF64[$0>>3] = 1.0;
 $4 = ((($0)) + 8|0);
 $5 = ((($0)) + 40|0);
 ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;HEAP32[$4+12>>2]=0|0;HEAP32[$4+16>>2]=0|0;HEAP32[$4+20>>2]=0|0;HEAP32[$4+24>>2]=0|0;HEAP32[$4+28>>2]=0|0;
 HEAPF64[$5>>3] = 1.0;
 $6 = ((($0)) + 48|0);
 $7 = ((($0)) + 80|0);
 ;HEAP32[$6>>2]=0|0;HEAP32[$6+4>>2]=0|0;HEAP32[$6+8>>2]=0|0;HEAP32[$6+12>>2]=0|0;HEAP32[$6+16>>2]=0|0;HEAP32[$6+20>>2]=0|0;HEAP32[$6+24>>2]=0|0;HEAP32[$6+28>>2]=0|0;
 HEAPF64[$7>>3] = 1.0;
 $8 = ((($0)) + 88|0);
 HEAPF64[$8>>3] = 0.0;
 $9 = ((($0)) + 96|0);
 HEAPF64[$9>>3] = $1;
 $10 = ((($0)) + 104|0);
 HEAPF64[$10>>3] = $2;
 $11 = ((($0)) + 112|0);
 HEAPF64[$11>>3] = $3;
 $12 = ((($0)) + 120|0);
 HEAPF64[$12>>3] = 1.0;
 return;
}
function __ZN3osg7Matrixd10makeRotateEdRKNS_5Vec3fE($0,$1,$2) {
 $0 = $0|0;
 $1 = +$1;
 $2 = $2|0;
 var $$0$i = 0.0, $$sink$i = 0.0, $$sink75$i = 0.0, $$sink76$i = 0.0, $$sink77$i = 0.0, $$sink78$i = 0.0, $$sink79$i = 0.0, $$sink80$i = 0.0, $$sink81$i = 0.0, $$sink82$i = 0.0, $10 = 0, $11 = 0.0, $12 = 0.0, $13 = 0, $14 = 0.0, $15 = 0.0, $16 = 0.0, $17 = 0, $18 = 0.0, $19 = 0.0;
 var $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0.0, $25 = 0, $26 = 0, $27 = 0.0, $28 = 0.0, $29 = 0.0, $3 = 0, $30 = 0.0, $31 = 0.0, $32 = 0.0, $33 = 0.0, $34 = 0.0, $35 = 0.0, $36 = 0.0, $37 = 0.0, $38 = 0.0;
 var $39 = 0.0, $4 = 0, $40 = 0.0, $41 = 0.0, $42 = 0.0, $43 = 0.0, $44 = 0.0, $45 = 0.0, $46 = 0.0, $47 = 0.0, $48 = 0.0, $49 = 0.0, $5 = 0, $50 = 0.0, $51 = 0.0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $3 = sp;
 HEAPF64[$0>>3] = 1.0;
 $4 = ((($0)) + 8|0);
 $5 = ((($0)) + 40|0);
 ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;HEAP32[$4+12>>2]=0|0;HEAP32[$4+16>>2]=0|0;HEAP32[$4+20>>2]=0|0;HEAP32[$4+24>>2]=0|0;HEAP32[$4+28>>2]=0|0;
 HEAPF64[$5>>3] = 1.0;
 $6 = ((($0)) + 48|0);
 $7 = ((($0)) + 80|0);
 ;HEAP32[$6>>2]=0|0;HEAP32[$6+4>>2]=0|0;HEAP32[$6+8>>2]=0|0;HEAP32[$6+12>>2]=0|0;HEAP32[$6+16>>2]=0|0;HEAP32[$6+20>>2]=0|0;HEAP32[$6+24>>2]=0|0;HEAP32[$6+28>>2]=0|0;
 HEAPF64[$7>>3] = 1.0;
 $8 = ((($0)) + 88|0);
 $9 = ((($0)) + 120|0);
 ;HEAP32[$8>>2]=0|0;HEAP32[$8+4>>2]=0|0;HEAP32[$8+8>>2]=0|0;HEAP32[$8+12>>2]=0|0;HEAP32[$8+16>>2]=0|0;HEAP32[$8+20>>2]=0|0;HEAP32[$8+24>>2]=0|0;HEAP32[$8+28>>2]=0|0;
 HEAPF64[$9>>3] = 1.0;
 $10 = ((($3)) + 24|0);
 ;HEAP32[$3>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;HEAP32[$3+12>>2]=0|0;HEAP32[$3+16>>2]=0|0;HEAP32[$3+20>>2]=0|0;
 HEAPF64[$10>>3] = 1.0;
 __ZN3osg4Quat10makeRotateEdRKNS_5Vec3fE($3,$1,$2);
 $11 = +HEAPF64[$3>>3];
 $12 = $11 * $11;
 $13 = ((($3)) + 8|0);
 $14 = +HEAPF64[$13>>3];
 $15 = $14 * $14;
 $16 = $12 + $15;
 $17 = ((($3)) + 16|0);
 $18 = +HEAPF64[$17>>3];
 $19 = $18 * $18;
 $20 = $16 + $19;
 $21 = +HEAPF64[$10>>3];
 $22 = $21 * $21;
 $23 = $20 + $22;
 $24 = (+Math_abs((+$23)));
 $25 = !($24 <= 2.2250738585072014E-308);
 if (!($25)) {
  $$sink$i = 0.0;$$sink75$i = 0.0;$$sink76$i = 0.0;$$sink77$i = 0.0;$$sink78$i = 0.0;$$sink79$i = 0.0;$$sink80$i = 0.0;$$sink81$i = 0.0;$$sink82$i = 0.0;
  HEAPF64[$0>>3] = $$sink82$i;
  $52 = ((($0)) + 32|0);
  HEAPF64[$52>>3] = $$sink81$i;
  $53 = ((($0)) + 64|0);
  HEAPF64[$53>>3] = $$sink80$i;
  HEAPF64[$4>>3] = $$sink79$i;
  HEAPF64[$5>>3] = $$sink78$i;
  $54 = ((($0)) + 72|0);
  HEAPF64[$54>>3] = $$sink77$i;
  $55 = ((($0)) + 16|0);
  HEAPF64[$55>>3] = $$sink76$i;
  HEAPF64[$6>>3] = $$sink75$i;
  HEAPF64[$7>>3] = $$sink$i;
  STACKTOP = sp;return;
 }
 $26 = $23 != 1.0;
 $27 = 2.0 / $23;
 $$0$i = $26 ? $27 : 2.0;
 $28 = $11 * $$0$i;
 $29 = $14 * $$0$i;
 $30 = $18 * $$0$i;
 $31 = $11 * $28;
 $32 = $11 * $29;
 $33 = $11 * $30;
 $34 = $14 * $29;
 $35 = $14 * $30;
 $36 = $18 * $30;
 $37 = $21 * $28;
 $38 = $21 * $29;
 $39 = $21 * $30;
 $40 = $34 + $36;
 $41 = 1.0 - $40;
 $42 = $32 - $39;
 $43 = $33 + $38;
 $44 = $32 + $39;
 $45 = $31 + $36;
 $46 = 1.0 - $45;
 $47 = $35 - $37;
 $48 = $33 - $38;
 $49 = $35 + $37;
 $50 = $31 + $34;
 $51 = 1.0 - $50;
 $$sink$i = $51;$$sink75$i = $49;$$sink76$i = $48;$$sink77$i = $47;$$sink78$i = $46;$$sink79$i = $44;$$sink80$i = $43;$$sink81$i = $42;$$sink82$i = $41;
 HEAPF64[$0>>3] = $$sink82$i;
 $52 = ((($0)) + 32|0);
 HEAPF64[$52>>3] = $$sink81$i;
 $53 = ((($0)) + 64|0);
 HEAPF64[$53>>3] = $$sink80$i;
 HEAPF64[$4>>3] = $$sink79$i;
 HEAPF64[$5>>3] = $$sink78$i;
 $54 = ((($0)) + 72|0);
 HEAPF64[$54>>3] = $$sink77$i;
 $55 = ((($0)) + 16|0);
 HEAPF64[$55>>3] = $$sink76$i;
 HEAPF64[$6>>3] = $$sink75$i;
 HEAPF64[$7>>3] = $$sink$i;
 STACKTOP = sp;return;
}
function __ZN3osg7Matrixd10makeRotateEdddd($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = +$1;
 $2 = +$2;
 $3 = +$3;
 $4 = +$4;
 var $$0$i = 0.0, $$sink$i = 0.0, $$sink75$i = 0.0, $$sink76$i = 0.0, $$sink77$i = 0.0, $$sink78$i = 0.0, $$sink79$i = 0.0, $$sink80$i = 0.0, $$sink81$i = 0.0, $$sink82$i = 0.0, $10 = 0, $11 = 0, $12 = 0, $13 = 0.0, $14 = 0.0, $15 = 0, $16 = 0.0, $17 = 0.0, $18 = 0.0, $19 = 0;
 var $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0.0, $25 = 0.0, $26 = 0.0, $27 = 0, $28 = 0, $29 = 0.0, $30 = 0.0, $31 = 0.0, $32 = 0.0, $33 = 0.0, $34 = 0.0, $35 = 0.0, $36 = 0.0, $37 = 0.0, $38 = 0.0, $39 = 0.0;
 var $40 = 0.0, $41 = 0.0, $42 = 0.0, $43 = 0.0, $44 = 0.0, $45 = 0.0, $46 = 0.0, $47 = 0.0, $48 = 0.0, $49 = 0.0, $5 = 0, $50 = 0.0, $51 = 0.0, $52 = 0.0, $53 = 0.0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $5 = sp;
 HEAPF64[$0>>3] = 1.0;
 $6 = ((($0)) + 8|0);
 $7 = ((($0)) + 40|0);
 ;HEAP32[$6>>2]=0|0;HEAP32[$6+4>>2]=0|0;HEAP32[$6+8>>2]=0|0;HEAP32[$6+12>>2]=0|0;HEAP32[$6+16>>2]=0|0;HEAP32[$6+20>>2]=0|0;HEAP32[$6+24>>2]=0|0;HEAP32[$6+28>>2]=0|0;
 HEAPF64[$7>>3] = 1.0;
 $8 = ((($0)) + 48|0);
 $9 = ((($0)) + 80|0);
 ;HEAP32[$8>>2]=0|0;HEAP32[$8+4>>2]=0|0;HEAP32[$8+8>>2]=0|0;HEAP32[$8+12>>2]=0|0;HEAP32[$8+16>>2]=0|0;HEAP32[$8+20>>2]=0|0;HEAP32[$8+24>>2]=0|0;HEAP32[$8+28>>2]=0|0;
 HEAPF64[$9>>3] = 1.0;
 $10 = ((($0)) + 88|0);
 $11 = ((($0)) + 120|0);
 ;HEAP32[$10>>2]=0|0;HEAP32[$10+4>>2]=0|0;HEAP32[$10+8>>2]=0|0;HEAP32[$10+12>>2]=0|0;HEAP32[$10+16>>2]=0|0;HEAP32[$10+20>>2]=0|0;HEAP32[$10+24>>2]=0|0;HEAP32[$10+28>>2]=0|0;
 HEAPF64[$11>>3] = 1.0;
 $12 = ((($5)) + 24|0);
 ;HEAP32[$5>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;HEAP32[$5+12>>2]=0|0;HEAP32[$5+16>>2]=0|0;HEAP32[$5+20>>2]=0|0;
 HEAPF64[$12>>3] = 1.0;
 __ZN3osg4Quat10makeRotateEdddd($5,$1,$2,$3,$4);
 $13 = +HEAPF64[$5>>3];
 $14 = $13 * $13;
 $15 = ((($5)) + 8|0);
 $16 = +HEAPF64[$15>>3];
 $17 = $16 * $16;
 $18 = $14 + $17;
 $19 = ((($5)) + 16|0);
 $20 = +HEAPF64[$19>>3];
 $21 = $20 * $20;
 $22 = $18 + $21;
 $23 = +HEAPF64[$12>>3];
 $24 = $23 * $23;
 $25 = $22 + $24;
 $26 = (+Math_abs((+$25)));
 $27 = !($26 <= 2.2250738585072014E-308);
 if (!($27)) {
  $$sink$i = 0.0;$$sink75$i = 0.0;$$sink76$i = 0.0;$$sink77$i = 0.0;$$sink78$i = 0.0;$$sink79$i = 0.0;$$sink80$i = 0.0;$$sink81$i = 0.0;$$sink82$i = 0.0;
  HEAPF64[$0>>3] = $$sink82$i;
  $54 = ((($0)) + 32|0);
  HEAPF64[$54>>3] = $$sink81$i;
  $55 = ((($0)) + 64|0);
  HEAPF64[$55>>3] = $$sink80$i;
  HEAPF64[$6>>3] = $$sink79$i;
  HEAPF64[$7>>3] = $$sink78$i;
  $56 = ((($0)) + 72|0);
  HEAPF64[$56>>3] = $$sink77$i;
  $57 = ((($0)) + 16|0);
  HEAPF64[$57>>3] = $$sink76$i;
  HEAPF64[$8>>3] = $$sink75$i;
  HEAPF64[$9>>3] = $$sink$i;
  STACKTOP = sp;return;
 }
 $28 = $25 != 1.0;
 $29 = 2.0 / $25;
 $$0$i = $28 ? $29 : 2.0;
 $30 = $13 * $$0$i;
 $31 = $16 * $$0$i;
 $32 = $20 * $$0$i;
 $33 = $13 * $30;
 $34 = $13 * $31;
 $35 = $13 * $32;
 $36 = $16 * $31;
 $37 = $16 * $32;
 $38 = $20 * $32;
 $39 = $23 * $30;
 $40 = $23 * $31;
 $41 = $23 * $32;
 $42 = $36 + $38;
 $43 = 1.0 - $42;
 $44 = $34 - $41;
 $45 = $35 + $40;
 $46 = $34 + $41;
 $47 = $33 + $38;
 $48 = 1.0 - $47;
 $49 = $37 - $39;
 $50 = $35 - $40;
 $51 = $37 + $39;
 $52 = $33 + $36;
 $53 = 1.0 - $52;
 $$sink$i = $53;$$sink75$i = $51;$$sink76$i = $50;$$sink77$i = $49;$$sink78$i = $48;$$sink79$i = $46;$$sink80$i = $45;$$sink81$i = $44;$$sink82$i = $43;
 HEAPF64[$0>>3] = $$sink82$i;
 $54 = ((($0)) + 32|0);
 HEAPF64[$54>>3] = $$sink81$i;
 $55 = ((($0)) + 64|0);
 HEAPF64[$55>>3] = $$sink80$i;
 HEAPF64[$6>>3] = $$sink79$i;
 HEAPF64[$7>>3] = $$sink78$i;
 $56 = ((($0)) + 72|0);
 HEAPF64[$56>>3] = $$sink77$i;
 $57 = ((($0)) + 16|0);
 HEAPF64[$57>>3] = $$sink76$i;
 HEAPF64[$8>>3] = $$sink75$i;
 HEAPF64[$9>>3] = $$sink$i;
 STACKTOP = sp;return;
}
function __ZN3osg7Matrixd10makeRotateERKNS_4QuatE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i = 0.0, $$sink$i = 0.0, $$sink75$i = 0.0, $$sink76$i = 0.0, $$sink77$i = 0.0, $$sink78$i = 0.0, $$sink79$i = 0.0, $$sink80$i = 0.0, $$sink81$i = 0.0, $$sink82$i = 0.0, $10 = 0, $11 = 0.0, $12 = 0.0, $13 = 0.0, $14 = 0, $15 = 0.0, $16 = 0.0, $17 = 0.0, $18 = 0, $19 = 0.0;
 var $2 = 0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0, $24 = 0, $25 = 0.0, $26 = 0.0, $27 = 0.0, $28 = 0.0, $29 = 0.0, $3 = 0, $30 = 0.0, $31 = 0.0, $32 = 0.0, $33 = 0.0, $34 = 0.0, $35 = 0.0, $36 = 0.0, $37 = 0.0;
 var $38 = 0.0, $39 = 0.0, $4 = 0, $40 = 0.0, $41 = 0.0, $42 = 0.0, $43 = 0.0, $44 = 0.0, $45 = 0.0, $46 = 0.0, $47 = 0.0, $48 = 0.0, $49 = 0.0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0;
 var $8 = 0.0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF64[$0>>3] = 1.0;
 $2 = ((($0)) + 8|0);
 $3 = ((($0)) + 40|0);
 ;HEAP32[$2>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;HEAP32[$2+12>>2]=0|0;HEAP32[$2+16>>2]=0|0;HEAP32[$2+20>>2]=0|0;HEAP32[$2+24>>2]=0|0;HEAP32[$2+28>>2]=0|0;
 HEAPF64[$3>>3] = 1.0;
 $4 = ((($0)) + 48|0);
 $5 = ((($0)) + 80|0);
 ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;HEAP32[$4+12>>2]=0|0;HEAP32[$4+16>>2]=0|0;HEAP32[$4+20>>2]=0|0;HEAP32[$4+24>>2]=0|0;HEAP32[$4+28>>2]=0|0;
 HEAPF64[$5>>3] = 1.0;
 $6 = ((($0)) + 88|0);
 $7 = ((($0)) + 120|0);
 ;HEAP32[$6>>2]=0|0;HEAP32[$6+4>>2]=0|0;HEAP32[$6+8>>2]=0|0;HEAP32[$6+12>>2]=0|0;HEAP32[$6+16>>2]=0|0;HEAP32[$6+20>>2]=0|0;HEAP32[$6+24>>2]=0|0;HEAP32[$6+28>>2]=0|0;
 HEAPF64[$7>>3] = 1.0;
 $8 = +HEAPF64[$1>>3];
 $9 = $8 * $8;
 $10 = ((($1)) + 8|0);
 $11 = +HEAPF64[$10>>3];
 $12 = $11 * $11;
 $13 = $9 + $12;
 $14 = ((($1)) + 16|0);
 $15 = +HEAPF64[$14>>3];
 $16 = $15 * $15;
 $17 = $13 + $16;
 $18 = ((($1)) + 24|0);
 $19 = +HEAPF64[$18>>3];
 $20 = $19 * $19;
 $21 = $17 + $20;
 $22 = (+Math_abs((+$21)));
 $23 = !($22 <= 2.2250738585072014E-308);
 if (!($23)) {
  $$sink$i = 0.0;$$sink75$i = 0.0;$$sink76$i = 0.0;$$sink77$i = 0.0;$$sink78$i = 0.0;$$sink79$i = 0.0;$$sink80$i = 0.0;$$sink81$i = 0.0;$$sink82$i = 0.0;
  HEAPF64[$0>>3] = $$sink82$i;
  $50 = ((($0)) + 32|0);
  HEAPF64[$50>>3] = $$sink81$i;
  $51 = ((($0)) + 64|0);
  HEAPF64[$51>>3] = $$sink80$i;
  HEAPF64[$2>>3] = $$sink79$i;
  HEAPF64[$3>>3] = $$sink78$i;
  $52 = ((($0)) + 72|0);
  HEAPF64[$52>>3] = $$sink77$i;
  $53 = ((($0)) + 16|0);
  HEAPF64[$53>>3] = $$sink76$i;
  HEAPF64[$4>>3] = $$sink75$i;
  HEAPF64[$5>>3] = $$sink$i;
  return;
 }
 $24 = $21 != 1.0;
 $25 = 2.0 / $21;
 $$0$i = $24 ? $25 : 2.0;
 $26 = $8 * $$0$i;
 $27 = $11 * $$0$i;
 $28 = $15 * $$0$i;
 $29 = $8 * $26;
 $30 = $8 * $27;
 $31 = $8 * $28;
 $32 = $11 * $27;
 $33 = $11 * $28;
 $34 = $15 * $28;
 $35 = $19 * $26;
 $36 = $19 * $27;
 $37 = $19 * $28;
 $38 = $32 + $34;
 $39 = 1.0 - $38;
 $40 = $30 - $37;
 $41 = $31 + $36;
 $42 = $30 + $37;
 $43 = $29 + $34;
 $44 = 1.0 - $43;
 $45 = $33 - $35;
 $46 = $31 - $36;
 $47 = $33 + $35;
 $48 = $29 + $32;
 $49 = 1.0 - $48;
 $$sink$i = $49;$$sink75$i = $47;$$sink76$i = $46;$$sink77$i = $45;$$sink78$i = $44;$$sink79$i = $42;$$sink80$i = $41;$$sink81$i = $40;$$sink82$i = $39;
 HEAPF64[$0>>3] = $$sink82$i;
 $50 = ((($0)) + 32|0);
 HEAPF64[$50>>3] = $$sink81$i;
 $51 = ((($0)) + 64|0);
 HEAPF64[$51>>3] = $$sink80$i;
 HEAPF64[$2>>3] = $$sink79$i;
 HEAPF64[$3>>3] = $$sink78$i;
 $52 = ((($0)) + 72|0);
 HEAPF64[$52>>3] = $$sink77$i;
 $53 = ((($0)) + 16|0);
 HEAPF64[$53>>3] = $$sink76$i;
 HEAPF64[$4>>3] = $$sink75$i;
 HEAPF64[$5>>3] = $$sink$i;
 return;
}
function __ZN3osg7Matrixd4multERKS0_S2_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $100 = 0, $101 = 0.0, $102 = 0.0, $103 = 0.0, $104 = 0.0, $105 = 0, $106 = 0.0, $107 = 0.0, $108 = 0.0, $109 = 0.0, $11 = 0.0, $110 = 0.0, $111 = 0.0, $112 = 0.0, $113 = 0.0, $114 = 0.0, $115 = 0.0, $116 = 0.0, $117 = 0.0;
 var $118 = 0.0, $119 = 0.0, $12 = 0.0, $120 = 0.0, $121 = 0, $122 = 0.0, $123 = 0.0, $124 = 0.0, $125 = 0.0, $126 = 0.0, $127 = 0.0, $128 = 0.0, $129 = 0.0, $13 = 0.0, $130 = 0.0, $131 = 0.0, $132 = 0.0, $133 = 0.0, $134 = 0.0, $135 = 0.0;
 var $136 = 0.0, $137 = 0, $138 = 0.0, $139 = 0.0, $14 = 0, $140 = 0.0, $141 = 0.0, $142 = 0.0, $143 = 0.0, $144 = 0.0, $145 = 0.0, $146 = 0.0, $147 = 0.0, $148 = 0.0, $149 = 0.0, $15 = 0.0, $150 = 0.0, $151 = 0.0, $152 = 0.0, $153 = 0;
 var $154 = 0, $155 = 0.0, $156 = 0.0, $157 = 0.0, $158 = 0, $159 = 0.0, $16 = 0, $160 = 0.0, $161 = 0.0, $162 = 0.0, $163 = 0, $164 = 0.0, $165 = 0.0, $166 = 0.0, $167 = 0.0, $168 = 0, $169 = 0.0, $17 = 0.0, $170 = 0.0, $171 = 0.0;
 var $172 = 0.0, $173 = 0, $174 = 0.0, $175 = 0.0, $176 = 0.0, $177 = 0.0, $178 = 0.0, $179 = 0.0, $18 = 0.0, $180 = 0.0, $181 = 0.0, $182 = 0.0, $183 = 0.0, $184 = 0.0, $185 = 0.0, $186 = 0.0, $187 = 0.0, $188 = 0.0, $189 = 0, $19 = 0.0;
 var $190 = 0.0, $191 = 0.0, $192 = 0.0, $193 = 0.0, $194 = 0.0, $195 = 0.0, $196 = 0.0, $197 = 0.0, $198 = 0.0, $199 = 0.0, $20 = 0, $200 = 0.0, $201 = 0.0, $202 = 0.0, $203 = 0.0, $204 = 0.0, $205 = 0, $206 = 0.0, $207 = 0.0, $208 = 0.0;
 var $209 = 0.0, $21 = 0.0, $210 = 0.0, $211 = 0.0, $212 = 0.0, $213 = 0.0, $214 = 0.0, $215 = 0.0, $216 = 0.0, $217 = 0.0, $218 = 0.0, $219 = 0.0, $22 = 0, $220 = 0.0, $221 = 0, $222 = 0, $223 = 0.0, $224 = 0.0, $225 = 0.0, $226 = 0;
 var $227 = 0.0, $228 = 0.0, $229 = 0.0, $23 = 0.0, $230 = 0.0, $231 = 0, $232 = 0.0, $233 = 0.0, $234 = 0.0, $235 = 0.0, $236 = 0, $237 = 0.0, $238 = 0.0, $239 = 0.0, $24 = 0.0, $240 = 0.0, $241 = 0, $242 = 0.0, $243 = 0.0, $244 = 0.0;
 var $245 = 0.0, $246 = 0.0, $247 = 0.0, $248 = 0.0, $249 = 0.0, $25 = 0.0, $250 = 0.0, $251 = 0.0, $252 = 0.0, $253 = 0.0, $254 = 0.0, $255 = 0.0, $256 = 0.0, $257 = 0, $258 = 0.0, $259 = 0.0, $26 = 0.0, $260 = 0.0, $261 = 0.0, $262 = 0.0;
 var $263 = 0.0, $264 = 0.0, $265 = 0.0, $266 = 0.0, $267 = 0.0, $268 = 0.0, $269 = 0.0, $27 = 0, $270 = 0.0, $271 = 0.0, $272 = 0.0, $273 = 0, $274 = 0.0, $275 = 0.0, $276 = 0.0, $277 = 0.0, $278 = 0.0, $279 = 0.0, $28 = 0.0, $280 = 0.0;
 var $281 = 0.0, $282 = 0.0, $283 = 0.0, $284 = 0.0, $285 = 0.0, $286 = 0.0, $287 = 0.0, $288 = 0.0, $289 = 0, $29 = 0.0, $3 = 0, $30 = 0.0, $31 = 0, $32 = 0.0, $33 = 0.0, $34 = 0.0, $35 = 0.0, $36 = 0, $37 = 0.0, $38 = 0.0;
 var $39 = 0.0, $4 = 0, $40 = 0.0, $41 = 0, $42 = 0.0, $43 = 0.0, $44 = 0.0, $45 = 0, $46 = 0.0, $47 = 0, $48 = 0.0, $49 = 0.0, $5 = 0.0, $50 = 0.0, $51 = 0, $52 = 0.0, $53 = 0.0, $54 = 0.0, $55 = 0.0, $56 = 0;
 var $57 = 0.0, $58 = 0.0, $59 = 0.0, $6 = 0.0, $60 = 0.0, $61 = 0, $62 = 0.0, $63 = 0.0, $64 = 0.0, $65 = 0, $66 = 0.0, $67 = 0, $68 = 0.0, $69 = 0.0, $7 = 0.0, $70 = 0.0, $71 = 0, $72 = 0.0, $73 = 0.0, $74 = 0.0;
 var $75 = 0.0, $76 = 0, $77 = 0.0, $78 = 0.0, $79 = 0.0, $8 = 0, $80 = 0.0, $81 = 0, $82 = 0.0, $83 = 0.0, $84 = 0.0, $85 = 0, $86 = 0, $87 = 0.0, $88 = 0.0, $89 = 0.0, $9 = 0.0, $90 = 0, $91 = 0.0, $92 = 0.0;
 var $93 = 0.0, $94 = 0.0, $95 = 0, $96 = 0.0, $97 = 0.0, $98 = 0.0, $99 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($1|0)==($0|0);
 if ($3) {
  __ZN3osg7Matrixd8postMultERKS0_($1,$2);
  return;
 }
 $4 = ($2|0)==($0|0);
 if ($4) {
  __ZN3osg7Matrixd7preMultERKS0_($0,$1);
  return;
 } else {
  $5 = +HEAPF64[$1>>3];
  $6 = +HEAPF64[$2>>3];
  $7 = $5 * $6;
  $8 = ((($1)) + 8|0);
  $9 = +HEAPF64[$8>>3];
  $10 = ((($2)) + 32|0);
  $11 = +HEAPF64[$10>>3];
  $12 = $9 * $11;
  $13 = $7 + $12;
  $14 = ((($1)) + 16|0);
  $15 = +HEAPF64[$14>>3];
  $16 = ((($2)) + 64|0);
  $17 = +HEAPF64[$16>>3];
  $18 = $15 * $17;
  $19 = $13 + $18;
  $20 = ((($1)) + 24|0);
  $21 = +HEAPF64[$20>>3];
  $22 = ((($2)) + 96|0);
  $23 = +HEAPF64[$22>>3];
  $24 = $21 * $23;
  $25 = $19 + $24;
  HEAPF64[$0>>3] = $25;
  $26 = +HEAPF64[$1>>3];
  $27 = ((($2)) + 8|0);
  $28 = +HEAPF64[$27>>3];
  $29 = $26 * $28;
  $30 = +HEAPF64[$8>>3];
  $31 = ((($2)) + 40|0);
  $32 = +HEAPF64[$31>>3];
  $33 = $30 * $32;
  $34 = $29 + $33;
  $35 = +HEAPF64[$14>>3];
  $36 = ((($2)) + 72|0);
  $37 = +HEAPF64[$36>>3];
  $38 = $35 * $37;
  $39 = $34 + $38;
  $40 = +HEAPF64[$20>>3];
  $41 = ((($2)) + 104|0);
  $42 = +HEAPF64[$41>>3];
  $43 = $40 * $42;
  $44 = $39 + $43;
  $45 = ((($0)) + 8|0);
  HEAPF64[$45>>3] = $44;
  $46 = +HEAPF64[$1>>3];
  $47 = ((($2)) + 16|0);
  $48 = +HEAPF64[$47>>3];
  $49 = $46 * $48;
  $50 = +HEAPF64[$8>>3];
  $51 = ((($2)) + 48|0);
  $52 = +HEAPF64[$51>>3];
  $53 = $50 * $52;
  $54 = $49 + $53;
  $55 = +HEAPF64[$14>>3];
  $56 = ((($2)) + 80|0);
  $57 = +HEAPF64[$56>>3];
  $58 = $55 * $57;
  $59 = $54 + $58;
  $60 = +HEAPF64[$20>>3];
  $61 = ((($2)) + 112|0);
  $62 = +HEAPF64[$61>>3];
  $63 = $60 * $62;
  $64 = $59 + $63;
  $65 = ((($0)) + 16|0);
  HEAPF64[$65>>3] = $64;
  $66 = +HEAPF64[$1>>3];
  $67 = ((($2)) + 24|0);
  $68 = +HEAPF64[$67>>3];
  $69 = $66 * $68;
  $70 = +HEAPF64[$8>>3];
  $71 = ((($2)) + 56|0);
  $72 = +HEAPF64[$71>>3];
  $73 = $70 * $72;
  $74 = $69 + $73;
  $75 = +HEAPF64[$14>>3];
  $76 = ((($2)) + 88|0);
  $77 = +HEAPF64[$76>>3];
  $78 = $75 * $77;
  $79 = $74 + $78;
  $80 = +HEAPF64[$20>>3];
  $81 = ((($2)) + 120|0);
  $82 = +HEAPF64[$81>>3];
  $83 = $80 * $82;
  $84 = $79 + $83;
  $85 = ((($0)) + 24|0);
  HEAPF64[$85>>3] = $84;
  $86 = ((($1)) + 32|0);
  $87 = +HEAPF64[$86>>3];
  $88 = +HEAPF64[$2>>3];
  $89 = $87 * $88;
  $90 = ((($1)) + 40|0);
  $91 = +HEAPF64[$90>>3];
  $92 = +HEAPF64[$10>>3];
  $93 = $91 * $92;
  $94 = $89 + $93;
  $95 = ((($1)) + 48|0);
  $96 = +HEAPF64[$95>>3];
  $97 = +HEAPF64[$16>>3];
  $98 = $96 * $97;
  $99 = $94 + $98;
  $100 = ((($1)) + 56|0);
  $101 = +HEAPF64[$100>>3];
  $102 = +HEAPF64[$22>>3];
  $103 = $101 * $102;
  $104 = $99 + $103;
  $105 = ((($0)) + 32|0);
  HEAPF64[$105>>3] = $104;
  $106 = +HEAPF64[$86>>3];
  $107 = +HEAPF64[$27>>3];
  $108 = $106 * $107;
  $109 = +HEAPF64[$90>>3];
  $110 = +HEAPF64[$31>>3];
  $111 = $109 * $110;
  $112 = $108 + $111;
  $113 = +HEAPF64[$95>>3];
  $114 = +HEAPF64[$36>>3];
  $115 = $113 * $114;
  $116 = $112 + $115;
  $117 = +HEAPF64[$100>>3];
  $118 = +HEAPF64[$41>>3];
  $119 = $117 * $118;
  $120 = $116 + $119;
  $121 = ((($0)) + 40|0);
  HEAPF64[$121>>3] = $120;
  $122 = +HEAPF64[$86>>3];
  $123 = +HEAPF64[$47>>3];
  $124 = $122 * $123;
  $125 = +HEAPF64[$90>>3];
  $126 = +HEAPF64[$51>>3];
  $127 = $125 * $126;
  $128 = $124 + $127;
  $129 = +HEAPF64[$95>>3];
  $130 = +HEAPF64[$56>>3];
  $131 = $129 * $130;
  $132 = $128 + $131;
  $133 = +HEAPF64[$100>>3];
  $134 = +HEAPF64[$61>>3];
  $135 = $133 * $134;
  $136 = $132 + $135;
  $137 = ((($0)) + 48|0);
  HEAPF64[$137>>3] = $136;
  $138 = +HEAPF64[$86>>3];
  $139 = +HEAPF64[$67>>3];
  $140 = $138 * $139;
  $141 = +HEAPF64[$90>>3];
  $142 = +HEAPF64[$71>>3];
  $143 = $141 * $142;
  $144 = $140 + $143;
  $145 = +HEAPF64[$95>>3];
  $146 = +HEAPF64[$76>>3];
  $147 = $145 * $146;
  $148 = $144 + $147;
  $149 = +HEAPF64[$100>>3];
  $150 = +HEAPF64[$81>>3];
  $151 = $149 * $150;
  $152 = $148 + $151;
  $153 = ((($0)) + 56|0);
  HEAPF64[$153>>3] = $152;
  $154 = ((($1)) + 64|0);
  $155 = +HEAPF64[$154>>3];
  $156 = +HEAPF64[$2>>3];
  $157 = $155 * $156;
  $158 = ((($1)) + 72|0);
  $159 = +HEAPF64[$158>>3];
  $160 = +HEAPF64[$10>>3];
  $161 = $159 * $160;
  $162 = $157 + $161;
  $163 = ((($1)) + 80|0);
  $164 = +HEAPF64[$163>>3];
  $165 = +HEAPF64[$16>>3];
  $166 = $164 * $165;
  $167 = $162 + $166;
  $168 = ((($1)) + 88|0);
  $169 = +HEAPF64[$168>>3];
  $170 = +HEAPF64[$22>>3];
  $171 = $169 * $170;
  $172 = $167 + $171;
  $173 = ((($0)) + 64|0);
  HEAPF64[$173>>3] = $172;
  $174 = +HEAPF64[$154>>3];
  $175 = +HEAPF64[$27>>3];
  $176 = $174 * $175;
  $177 = +HEAPF64[$158>>3];
  $178 = +HEAPF64[$31>>3];
  $179 = $177 * $178;
  $180 = $176 + $179;
  $181 = +HEAPF64[$163>>3];
  $182 = +HEAPF64[$36>>3];
  $183 = $181 * $182;
  $184 = $180 + $183;
  $185 = +HEAPF64[$168>>3];
  $186 = +HEAPF64[$41>>3];
  $187 = $185 * $186;
  $188 = $184 + $187;
  $189 = ((($0)) + 72|0);
  HEAPF64[$189>>3] = $188;
  $190 = +HEAPF64[$154>>3];
  $191 = +HEAPF64[$47>>3];
  $192 = $190 * $191;
  $193 = +HEAPF64[$158>>3];
  $194 = +HEAPF64[$51>>3];
  $195 = $193 * $194;
  $196 = $192 + $195;
  $197 = +HEAPF64[$163>>3];
  $198 = +HEAPF64[$56>>3];
  $199 = $197 * $198;
  $200 = $196 + $199;
  $201 = +HEAPF64[$168>>3];
  $202 = +HEAPF64[$61>>3];
  $203 = $201 * $202;
  $204 = $200 + $203;
  $205 = ((($0)) + 80|0);
  HEAPF64[$205>>3] = $204;
  $206 = +HEAPF64[$154>>3];
  $207 = +HEAPF64[$67>>3];
  $208 = $206 * $207;
  $209 = +HEAPF64[$158>>3];
  $210 = +HEAPF64[$71>>3];
  $211 = $209 * $210;
  $212 = $208 + $211;
  $213 = +HEAPF64[$163>>3];
  $214 = +HEAPF64[$76>>3];
  $215 = $213 * $214;
  $216 = $212 + $215;
  $217 = +HEAPF64[$168>>3];
  $218 = +HEAPF64[$81>>3];
  $219 = $217 * $218;
  $220 = $216 + $219;
  $221 = ((($0)) + 88|0);
  HEAPF64[$221>>3] = $220;
  $222 = ((($1)) + 96|0);
  $223 = +HEAPF64[$222>>3];
  $224 = +HEAPF64[$2>>3];
  $225 = $223 * $224;
  $226 = ((($1)) + 104|0);
  $227 = +HEAPF64[$226>>3];
  $228 = +HEAPF64[$10>>3];
  $229 = $227 * $228;
  $230 = $225 + $229;
  $231 = ((($1)) + 112|0);
  $232 = +HEAPF64[$231>>3];
  $233 = +HEAPF64[$16>>3];
  $234 = $232 * $233;
  $235 = $230 + $234;
  $236 = ((($1)) + 120|0);
  $237 = +HEAPF64[$236>>3];
  $238 = +HEAPF64[$22>>3];
  $239 = $237 * $238;
  $240 = $235 + $239;
  $241 = ((($0)) + 96|0);
  HEAPF64[$241>>3] = $240;
  $242 = +HEAPF64[$222>>3];
  $243 = +HEAPF64[$27>>3];
  $244 = $242 * $243;
  $245 = +HEAPF64[$226>>3];
  $246 = +HEAPF64[$31>>3];
  $247 = $245 * $246;
  $248 = $244 + $247;
  $249 = +HEAPF64[$231>>3];
  $250 = +HEAPF64[$36>>3];
  $251 = $249 * $250;
  $252 = $248 + $251;
  $253 = +HEAPF64[$236>>3];
  $254 = +HEAPF64[$41>>3];
  $255 = $253 * $254;
  $256 = $252 + $255;
  $257 = ((($0)) + 104|0);
  HEAPF64[$257>>3] = $256;
  $258 = +HEAPF64[$222>>3];
  $259 = +HEAPF64[$47>>3];
  $260 = $258 * $259;
  $261 = +HEAPF64[$226>>3];
  $262 = +HEAPF64[$51>>3];
  $263 = $261 * $262;
  $264 = $260 + $263;
  $265 = +HEAPF64[$231>>3];
  $266 = +HEAPF64[$56>>3];
  $267 = $265 * $266;
  $268 = $264 + $267;
  $269 = +HEAPF64[$236>>3];
  $270 = +HEAPF64[$61>>3];
  $271 = $269 * $270;
  $272 = $268 + $271;
  $273 = ((($0)) + 112|0);
  HEAPF64[$273>>3] = $272;
  $274 = +HEAPF64[$222>>3];
  $275 = +HEAPF64[$67>>3];
  $276 = $274 * $275;
  $277 = +HEAPF64[$226>>3];
  $278 = +HEAPF64[$71>>3];
  $279 = $277 * $278;
  $280 = $276 + $279;
  $281 = +HEAPF64[$231>>3];
  $282 = +HEAPF64[$76>>3];
  $283 = $281 * $282;
  $284 = $280 + $283;
  $285 = +HEAPF64[$236>>3];
  $286 = +HEAPF64[$81>>3];
  $287 = $285 * $286;
  $288 = $284 + $287;
  $289 = ((($0)) + 120|0);
  HEAPF64[$289>>3] = $288;
  return;
 }
}
function __ZN3osg7Matrixd8postMultERKS0_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$043 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0.0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0, $22 = 0.0, $23 = 0.0, $24 = 0.0, $25 = 0.0, $26 = 0, $27 = 0.0;
 var $28 = 0.0, $29 = 0.0, $3 = 0, $30 = 0.0, $31 = 0, $32 = 0.0, $33 = 0.0, $34 = 0.0, $35 = 0.0, $36 = 0.0, $37 = 0.0, $38 = 0.0, $39 = 0.0, $4 = 0, $40 = 0.0, $41 = 0.0, $42 = 0.0, $43 = 0.0, $44 = 0.0, $45 = 0.0;
 var $46 = 0.0, $47 = 0.0, $48 = 0.0, $49 = 0.0, $5 = 0, $50 = 0.0, $51 = 0.0, $52 = 0.0, $53 = 0.0, $54 = 0.0, $55 = 0.0, $56 = 0.0, $57 = 0.0, $58 = 0.0, $59 = 0.0, $6 = 0, $60 = 0.0, $61 = 0.0, $62 = 0.0, $63 = 0.0;
 var $64 = 0.0, $65 = 0.0, $66 = 0.0, $67 = 0.0, $68 = 0.0, $69 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 32|0);
 $3 = ((($1)) + 64|0);
 $4 = ((($1)) + 96|0);
 $5 = ((($1)) + 8|0);
 $6 = ((($1)) + 40|0);
 $7 = ((($1)) + 72|0);
 $8 = ((($1)) + 104|0);
 $9 = ((($1)) + 16|0);
 $10 = ((($1)) + 48|0);
 $11 = ((($1)) + 80|0);
 $12 = ((($1)) + 112|0);
 $13 = ((($1)) + 24|0);
 $14 = ((($1)) + 56|0);
 $15 = ((($1)) + 88|0);
 $16 = ((($1)) + 120|0);
 $$043 = 0;
 while(1) {
  $17 = (($0) + ($$043<<5)|0);
  $18 = +HEAPF64[$17>>3];
  $19 = +HEAPF64[$1>>3];
  $20 = $18 * $19;
  $21 = (((($0) + ($$043<<5)|0)) + 8|0);
  $22 = +HEAPF64[$21>>3];
  $23 = +HEAPF64[$2>>3];
  $24 = $22 * $23;
  $25 = $20 + $24;
  $26 = (((($0) + ($$043<<5)|0)) + 16|0);
  $27 = +HEAPF64[$26>>3];
  $28 = +HEAPF64[$3>>3];
  $29 = $27 * $28;
  $30 = $25 + $29;
  $31 = (((($0) + ($$043<<5)|0)) + 24|0);
  $32 = +HEAPF64[$31>>3];
  $33 = +HEAPF64[$4>>3];
  $34 = $32 * $33;
  $35 = $30 + $34;
  $36 = +HEAPF64[$5>>3];
  $37 = $18 * $36;
  $38 = +HEAPF64[$6>>3];
  $39 = $22 * $38;
  $40 = $37 + $39;
  $41 = +HEAPF64[$7>>3];
  $42 = $27 * $41;
  $43 = $40 + $42;
  $44 = +HEAPF64[$8>>3];
  $45 = $32 * $44;
  $46 = $43 + $45;
  $47 = +HEAPF64[$9>>3];
  $48 = $18 * $47;
  $49 = +HEAPF64[$10>>3];
  $50 = $22 * $49;
  $51 = $48 + $50;
  $52 = +HEAPF64[$11>>3];
  $53 = $27 * $52;
  $54 = $51 + $53;
  $55 = +HEAPF64[$12>>3];
  $56 = $32 * $55;
  $57 = $54 + $56;
  $58 = +HEAPF64[$13>>3];
  $59 = $18 * $58;
  $60 = +HEAPF64[$14>>3];
  $61 = $22 * $60;
  $62 = $59 + $61;
  $63 = +HEAPF64[$15>>3];
  $64 = $27 * $63;
  $65 = $62 + $64;
  $66 = +HEAPF64[$16>>3];
  $67 = $32 * $66;
  $68 = $65 + $67;
  HEAPF64[$17>>3] = $35;
  HEAPF64[$21>>3] = $46;
  HEAPF64[$26>>3] = $57;
  HEAPF64[$31>>3] = $68;
  $69 = (($$043) + 1)|0;
  $exitcond = ($69|0)==(4);
  if ($exitcond) {
   break;
  } else {
   $$043 = $69;
  }
 }
 return;
}
function __ZN3osg7Matrixd7preMultERKS0_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$043 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0.0, $18 = 0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0.0, $22 = 0, $23 = 0.0, $24 = 0.0, $25 = 0.0, $26 = 0.0, $27 = 0;
 var $28 = 0.0, $29 = 0.0, $3 = 0, $30 = 0.0, $31 = 0.0, $32 = 0, $33 = 0.0, $34 = 0.0, $35 = 0.0, $36 = 0.0, $37 = 0.0, $38 = 0.0, $39 = 0.0, $4 = 0, $40 = 0.0, $41 = 0.0, $42 = 0.0, $43 = 0.0, $44 = 0.0, $45 = 0.0;
 var $46 = 0.0, $47 = 0.0, $48 = 0.0, $49 = 0.0, $5 = 0, $50 = 0.0, $51 = 0.0, $52 = 0.0, $53 = 0.0, $54 = 0.0, $55 = 0.0, $56 = 0.0, $57 = 0.0, $58 = 0.0, $59 = 0.0, $6 = 0, $60 = 0.0, $61 = 0.0, $62 = 0.0, $63 = 0.0;
 var $64 = 0.0, $65 = 0.0, $66 = 0.0, $67 = 0.0, $68 = 0.0, $69 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 8|0);
 $3 = ((($1)) + 16|0);
 $4 = ((($1)) + 24|0);
 $5 = ((($1)) + 32|0);
 $6 = ((($1)) + 40|0);
 $7 = ((($1)) + 48|0);
 $8 = ((($1)) + 56|0);
 $9 = ((($1)) + 64|0);
 $10 = ((($1)) + 72|0);
 $11 = ((($1)) + 80|0);
 $12 = ((($1)) + 88|0);
 $13 = ((($1)) + 96|0);
 $14 = ((($1)) + 104|0);
 $15 = ((($1)) + 112|0);
 $16 = ((($1)) + 120|0);
 $$043 = 0;
 while(1) {
  $17 = +HEAPF64[$1>>3];
  $18 = (($0) + ($$043<<3)|0);
  $19 = +HEAPF64[$18>>3];
  $20 = $17 * $19;
  $21 = +HEAPF64[$2>>3];
  $22 = (((($0)) + 32|0) + ($$043<<3)|0);
  $23 = +HEAPF64[$22>>3];
  $24 = $21 * $23;
  $25 = $20 + $24;
  $26 = +HEAPF64[$3>>3];
  $27 = (((($0)) + 64|0) + ($$043<<3)|0);
  $28 = +HEAPF64[$27>>3];
  $29 = $26 * $28;
  $30 = $25 + $29;
  $31 = +HEAPF64[$4>>3];
  $32 = (((($0)) + 96|0) + ($$043<<3)|0);
  $33 = +HEAPF64[$32>>3];
  $34 = $31 * $33;
  $35 = $30 + $34;
  $36 = +HEAPF64[$5>>3];
  $37 = $19 * $36;
  $38 = +HEAPF64[$6>>3];
  $39 = $23 * $38;
  $40 = $37 + $39;
  $41 = +HEAPF64[$7>>3];
  $42 = $28 * $41;
  $43 = $40 + $42;
  $44 = +HEAPF64[$8>>3];
  $45 = $33 * $44;
  $46 = $43 + $45;
  $47 = +HEAPF64[$9>>3];
  $48 = $19 * $47;
  $49 = +HEAPF64[$10>>3];
  $50 = $23 * $49;
  $51 = $48 + $50;
  $52 = +HEAPF64[$11>>3];
  $53 = $28 * $52;
  $54 = $51 + $53;
  $55 = +HEAPF64[$12>>3];
  $56 = $33 * $55;
  $57 = $54 + $56;
  $58 = +HEAPF64[$13>>3];
  $59 = $19 * $58;
  $60 = +HEAPF64[$14>>3];
  $61 = $23 * $60;
  $62 = $59 + $61;
  $63 = +HEAPF64[$15>>3];
  $64 = $28 * $63;
  $65 = $62 + $64;
  $66 = +HEAPF64[$16>>3];
  $67 = $33 * $66;
  $68 = $65 + $67;
  HEAPF64[$18>>3] = $35;
  HEAPF64[$22>>3] = $46;
  HEAPF64[$27>>3] = $57;
  HEAPF64[$32>>3] = $68;
  $69 = (($$043) + 1)|0;
  $exitcond = ($69|0)==(4);
  if ($exitcond) {
   break;
  } else {
   $$043 = $69;
  }
 }
 return;
}
function __ZN3osg7Matrixd10invert_4x3ERKS0_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$043$i = 0, $$phi$trans$insert = 0, $$phi$trans$insert191 = 0, $$phi$trans$insert193 = 0, $$pre = 0.0, $$pre192 = 0.0, $$pre194 = 0.0, $10 = 0, $100 = 0.0, $101 = 0.0, $102 = 0, $103 = 0.0, $104 = 0.0, $105 = 0.0, $106 = 0, $107 = 0, $108 = 0.0, $109 = 0.0, $11 = 0, $110 = 0.0;
 var $111 = 0, $112 = 0.0, $113 = 0.0, $114 = 0.0, $115 = 0, $116 = 0.0, $117 = 0.0, $118 = 0.0, $119 = 0, $12 = 0.0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0.0, $126 = 0.0, $127 = 0.0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0.0, $131 = 0, $132 = 0.0, $133 = 0, $134 = 0.0, $135 = 0.0, $136 = 0.0, $137 = 0.0, $138 = 0.0, $139 = 0.0, $14 = 0, $140 = 0.0, $141 = 0.0, $142 = 0.0, $143 = 0.0, $144 = 0.0, $145 = 0.0, $146 = 0.0, $147 = 0.0;
 var $148 = 0.0, $149 = 0.0, $15 = 0.0, $150 = 0.0, $151 = 0, $152 = 0.0, $153 = 0, $154 = 0.0, $155 = 0.0, $156 = 0.0, $157 = 0.0, $158 = 0.0, $159 = 0.0, $16 = 0, $160 = 0.0, $161 = 0.0, $162 = 0.0, $163 = 0.0, $164 = 0.0, $165 = 0.0;
 var $166 = 0.0, $167 = 0.0, $168 = 0.0, $169 = 0.0, $17 = 0, $170 = 0.0, $171 = 0.0, $172 = 0.0, $173 = 0.0, $174 = 0.0, $175 = 0.0, $176 = 0.0, $177 = 0.0, $178 = 0.0, $179 = 0.0, $18 = 0.0, $180 = 0, $181 = 0.0, $182 = 0.0, $183 = 0;
 var $184 = 0.0, $185 = 0.0, $186 = 0.0, $187 = 0, $188 = 0.0, $189 = 0.0, $19 = 0, $190 = 0.0, $191 = 0, $192 = 0.0, $193 = 0.0, $194 = 0.0, $195 = 0.0, $196 = 0.0, $197 = 0.0, $198 = 0.0, $199 = 0.0, $2 = 0, $20 = 0, $200 = 0.0;
 var $201 = 0.0, $202 = 0.0, $203 = 0.0, $204 = 0.0, $205 = 0.0, $206 = 0.0, $207 = 0.0, $208 = 0.0, $209 = 0.0, $21 = 0.0, $210 = 0.0, $211 = 0.0, $212 = 0.0, $213 = 0.0, $214 = 0.0, $215 = 0.0, $216 = 0.0, $217 = 0, $218 = 0.0, $219 = 0;
 var $22 = 0, $220 = 0.0, $221 = 0, $222 = 0.0, $223 = 0.0, $224 = 0.0, $225 = 0.0, $226 = 0.0, $227 = 0.0, $228 = 0.0, $229 = 0.0, $23 = 0, $230 = 0.0, $231 = 0.0, $232 = 0.0, $233 = 0.0, $234 = 0.0, $235 = 0, $236 = 0.0, $237 = 0.0;
 var $238 = 0.0, $239 = 0.0, $24 = 0.0, $240 = 0.0, $241 = 0.0, $242 = 0, $25 = 0, $26 = 0, $27 = 0.0, $28 = 0, $29 = 0, $3 = 0, $30 = 0.0, $31 = 0, $32 = 0, $33 = 0.0, $34 = 0, $35 = 0, $36 = 0.0, $37 = 0;
 var $38 = 0, $39 = 0.0, $4 = 0.0, $40 = 0, $41 = 0, $42 = 0.0, $43 = 0, $44 = 0, $45 = 0.0, $46 = 0, $47 = 0, $48 = 0.0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0.0, $55 = 0;
 var $56 = 0.0, $57 = 0, $58 = 0.0, $59 = 0, $6 = 0.0, $60 = 0.0, $61 = 0, $62 = 0.0, $63 = 0, $64 = 0.0, $65 = 0, $66 = 0.0, $67 = 0, $68 = 0.0, $69 = 0, $7 = 0, $70 = 0.0, $71 = 0.0, $72 = 0.0, $73 = 0.0;
 var $74 = 0.0, $75 = 0.0, $76 = 0.0, $77 = 0, $78 = 0.0, $79 = 0.0, $8 = 0, $80 = 0.0, $81 = 0, $82 = 0.0, $83 = 0.0, $84 = 0.0, $85 = 0.0, $86 = 0.0, $87 = 0.0, $88 = 0.0, $89 = 0.0, $9 = 0.0, $90 = 0.0, $91 = 0.0;
 var $92 = 0.0, $93 = 0.0, $94 = 0, $95 = 0.0, $96 = 0.0, $97 = 0.0, $98 = 0, $99 = 0.0, $exitcond$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(128|0);
 $2 = sp;
 $3 = ($1|0)==($0|0);
 if ($3) {
  $4 = +HEAPF64[$1>>3];
  HEAPF64[$2>>3] = $4;
  $5 = ((($1)) + 8|0);
  $6 = +HEAPF64[$5>>3];
  $7 = ((($2)) + 8|0);
  HEAPF64[$7>>3] = $6;
  $8 = ((($1)) + 16|0);
  $9 = +HEAPF64[$8>>3];
  $10 = ((($2)) + 16|0);
  HEAPF64[$10>>3] = $9;
  $11 = ((($1)) + 24|0);
  $12 = +HEAPF64[$11>>3];
  $13 = ((($2)) + 24|0);
  HEAPF64[$13>>3] = $12;
  $14 = ((($1)) + 32|0);
  $15 = +HEAPF64[$14>>3];
  $16 = ((($2)) + 32|0);
  HEAPF64[$16>>3] = $15;
  $17 = ((($1)) + 40|0);
  $18 = +HEAPF64[$17>>3];
  $19 = ((($2)) + 40|0);
  HEAPF64[$19>>3] = $18;
  $20 = ((($1)) + 48|0);
  $21 = +HEAPF64[$20>>3];
  $22 = ((($2)) + 48|0);
  HEAPF64[$22>>3] = $21;
  $23 = ((($1)) + 56|0);
  $24 = +HEAPF64[$23>>3];
  $25 = ((($2)) + 56|0);
  HEAPF64[$25>>3] = $24;
  $26 = ((($1)) + 64|0);
  $27 = +HEAPF64[$26>>3];
  $28 = ((($2)) + 64|0);
  HEAPF64[$28>>3] = $27;
  $29 = ((($1)) + 72|0);
  $30 = +HEAPF64[$29>>3];
  $31 = ((($2)) + 72|0);
  HEAPF64[$31>>3] = $30;
  $32 = ((($1)) + 80|0);
  $33 = +HEAPF64[$32>>3];
  $34 = ((($2)) + 80|0);
  HEAPF64[$34>>3] = $33;
  $35 = ((($1)) + 88|0);
  $36 = +HEAPF64[$35>>3];
  $37 = ((($2)) + 88|0);
  HEAPF64[$37>>3] = $36;
  $38 = ((($1)) + 96|0);
  $39 = +HEAPF64[$38>>3];
  $40 = ((($2)) + 96|0);
  HEAPF64[$40>>3] = $39;
  $41 = ((($1)) + 104|0);
  $42 = +HEAPF64[$41>>3];
  $43 = ((($2)) + 104|0);
  HEAPF64[$43>>3] = $42;
  $44 = ((($1)) + 112|0);
  $45 = +HEAPF64[$44>>3];
  $46 = ((($2)) + 112|0);
  HEAPF64[$46>>3] = $45;
  $47 = ((($1)) + 120|0);
  $48 = +HEAPF64[$47>>3];
  $49 = ((($2)) + 120|0);
  HEAPF64[$49>>3] = $48;
  __THREW__ = 0;
  (invoke_iii(3303,($1|0),($2|0))|0);
  $50 = __THREW__; __THREW__ = 0;
  $51 = $50&1;
  if ($51) {
   $52 = ___cxa_find_matching_catch_2()|0;
   $53 = tempRet0;
   ___resumeException($52|0);
   // unreachable;
  }
  STACKTOP = sp;return 1;
 }
 $54 = +HEAPF64[$1>>3];
 $55 = ((($1)) + 8|0);
 $56 = +HEAPF64[$55>>3];
 $57 = ((($1)) + 16|0);
 $58 = +HEAPF64[$57>>3];
 $59 = ((($1)) + 32|0);
 $60 = +HEAPF64[$59>>3];
 $61 = ((($1)) + 40|0);
 $62 = +HEAPF64[$61>>3];
 $63 = ((($1)) + 48|0);
 $64 = +HEAPF64[$63>>3];
 $65 = ((($1)) + 64|0);
 $66 = +HEAPF64[$65>>3];
 $67 = ((($1)) + 72|0);
 $68 = +HEAPF64[$67>>3];
 $69 = ((($1)) + 80|0);
 $70 = +HEAPF64[$69>>3];
 $71 = $62 * $70;
 $72 = $64 * $68;
 $73 = $71 - $72;
 $74 = $58 * $68;
 $75 = $56 * $70;
 $76 = $74 - $75;
 $77 = ((($0)) + 8|0);
 $78 = $56 * $64;
 $79 = $58 * $62;
 $80 = $78 - $79;
 $81 = ((($0)) + 16|0);
 $82 = $54 * $73;
 $83 = $60 * $76;
 $84 = $82 + $83;
 $85 = $66 * $80;
 $86 = $85 + $84;
 $87 = 1.0 / $86;
 $88 = $54 * $87;
 $89 = $60 * $87;
 $90 = $66 * $87;
 $91 = $73 * $87;
 HEAPF64[$0>>3] = $91;
 $92 = $76 * $87;
 HEAPF64[$77>>3] = $92;
 $93 = $80 * $87;
 HEAPF64[$81>>3] = $93;
 $94 = ((($0)) + 24|0);
 HEAPF64[$94>>3] = 0.0;
 $95 = $64 * $90;
 $96 = $70 * $89;
 $97 = $95 - $96;
 $98 = ((($0)) + 32|0);
 HEAPF64[$98>>3] = $97;
 $99 = $70 * $88;
 $100 = $58 * $90;
 $101 = $99 - $100;
 $102 = ((($0)) + 40|0);
 HEAPF64[$102>>3] = $101;
 $103 = $58 * $89;
 $104 = $64 * $88;
 $105 = $103 - $104;
 $106 = ((($0)) + 48|0);
 HEAPF64[$106>>3] = $105;
 $107 = ((($0)) + 56|0);
 HEAPF64[$107>>3] = 0.0;
 $108 = $68 * $89;
 $109 = $62 * $90;
 $110 = $108 - $109;
 $111 = ((($0)) + 64|0);
 HEAPF64[$111>>3] = $110;
 $112 = $56 * $90;
 $113 = $68 * $88;
 $114 = $112 - $113;
 $115 = ((($0)) + 72|0);
 HEAPF64[$115>>3] = $114;
 $116 = $62 * $88;
 $117 = $56 * $89;
 $118 = $116 - $117;
 $119 = ((($0)) + 80|0);
 HEAPF64[$119>>3] = $118;
 $120 = ((($0)) + 88|0);
 HEAPF64[$120>>3] = 0.0;
 $121 = ((($0)) + 96|0);
 $122 = ((($0)) + 120|0);
 HEAPF64[$122>>3] = 1.0;
 $123 = ((($1)) + 96|0);
 $124 = ((($1)) + 120|0);
 $125 = +HEAPF64[$124>>3];
 $126 = $125 + -1.0;
 $127 = $126 * $126;
 $128 = $127 > 9.9999999999999995E-7;
 if (!($128)) {
  $218 = +HEAPF64[$123>>3];
  $219 = ((($1)) + 104|0);
  $220 = +HEAPF64[$219>>3];
  $221 = ((($1)) + 112|0);
  $222 = +HEAPF64[$221>>3];
  $223 = $218 * $91;
  $224 = $220 * $97;
  $225 = $223 + $224;
  $226 = $222 * $110;
  $227 = $225 + $226;
  $228 = -$227;
  HEAPF64[$121>>3] = $228;
  $229 = $218 * $92;
  $230 = $220 * $101;
  $231 = $229 + $230;
  $232 = $222 * $114;
  $233 = $231 + $232;
  $234 = -$233;
  $235 = ((($0)) + 104|0);
  HEAPF64[$235>>3] = $234;
  $236 = $218 * $93;
  $237 = $220 * $105;
  $238 = $236 + $237;
  $239 = $222 * $118;
  $240 = $238 + $239;
  $241 = -$240;
  $242 = ((($0)) + 112|0);
  HEAPF64[$242>>3] = $241;
  STACKTOP = sp;return 1;
 }
 $129 = ((($1)) + 24|0);
 ;HEAP32[$121>>2]=0|0;HEAP32[$121+4>>2]=0|0;HEAP32[$121+8>>2]=0|0;HEAP32[$121+12>>2]=0|0;HEAP32[$121+16>>2]=0|0;HEAP32[$121+20>>2]=0|0;
 $130 = +HEAPF64[$129>>3];
 $131 = ((($1)) + 56|0);
 $132 = +HEAPF64[$131>>3];
 $133 = ((($1)) + 88|0);
 $134 = +HEAPF64[$133>>3];
 $135 = $130 * $91;
 $136 = $132 * $92;
 $137 = $135 + $136;
 $138 = $134 * $93;
 $139 = $137 + $138;
 $140 = $130 * $97;
 $141 = $132 * $101;
 $142 = $140 + $141;
 $143 = $134 * $105;
 $144 = $142 + $143;
 $145 = $130 * $110;
 $146 = $132 * $114;
 $147 = $145 + $146;
 $148 = $134 * $118;
 $149 = $147 + $148;
 $150 = +HEAPF64[$123>>3];
 $151 = ((($1)) + 104|0);
 $152 = +HEAPF64[$151>>3];
 $153 = ((($1)) + 112|0);
 $154 = +HEAPF64[$153>>3];
 $155 = $139 * $150;
 $156 = $144 * $152;
 $157 = $155 + $156;
 $158 = $149 * $154;
 $159 = $157 + $158;
 $160 = $125 - $159;
 $161 = 1.0 / $160;
 $162 = $150 * $161;
 $163 = $152 * $161;
 $164 = $154 * $161;
 $165 = $139 * $162;
 $166 = $165 + 1.0;
 $167 = $139 * $163;
 $168 = $139 * $164;
 $169 = $139 * $161;
 $170 = $144 * $162;
 $171 = $144 * $163;
 $172 = $171 + 1.0;
 $173 = $144 * $164;
 $174 = $144 * $161;
 $175 = $149 * $162;
 $176 = $149 * $163;
 $177 = $149 * $164;
 $178 = $177 + 1.0;
 $179 = $149 * $161;
 $$043$i = 0;$182 = $91;$185 = $97;$189 = $110;
 while(1) {
  $180 = (($0) + ($$043$i<<3)|0);
  $181 = $166 * $182;
  $183 = (((($0)) + 32|0) + ($$043$i<<3)|0);
  $184 = $167 * $185;
  $186 = $181 + $184;
  $187 = (((($0)) + 64|0) + ($$043$i<<3)|0);
  $188 = $168 * $189;
  $190 = $186 + $188;
  $191 = (((($0)) + 96|0) + ($$043$i<<3)|0);
  $192 = +HEAPF64[$191>>3];
  $193 = $169 * $192;
  $194 = $190 - $193;
  $195 = $170 * $182;
  $196 = $172 * $185;
  $197 = $195 + $196;
  $198 = $173 * $189;
  $199 = $197 + $198;
  $200 = $174 * $192;
  $201 = $199 - $200;
  $202 = $175 * $182;
  $203 = $176 * $185;
  $204 = $202 + $203;
  $205 = $178 * $189;
  $206 = $204 + $205;
  $207 = $179 * $192;
  $208 = $206 - $207;
  $209 = $162 * $182;
  $210 = $163 * $185;
  $211 = -$210;
  $212 = $211 - $209;
  $213 = $164 * $189;
  $214 = $212 - $213;
  $215 = $161 * $192;
  $216 = $214 + $215;
  HEAPF64[$180>>3] = $194;
  HEAPF64[$183>>3] = $201;
  HEAPF64[$187>>3] = $208;
  HEAPF64[$191>>3] = $216;
  $217 = (($$043$i) + 1)|0;
  $exitcond$i = ($217|0)==(4);
  if ($exitcond$i) {
   break;
  }
  $$phi$trans$insert = (($0) + ($217<<3)|0);
  $$pre = +HEAPF64[$$phi$trans$insert>>3];
  $$phi$trans$insert191 = (((($0)) + 32|0) + ($217<<3)|0);
  $$pre192 = +HEAPF64[$$phi$trans$insert191>>3];
  $$phi$trans$insert193 = (((($0)) + 64|0) + ($217<<3)|0);
  $$pre194 = +HEAPF64[$$phi$trans$insert193>>3];
  $$043$i = $217;$182 = $$pre;$185 = $$pre192;$189 = $$pre194;
 }
 STACKTOP = sp;return 1;
}
function __ZN3osg7Matrixd10invert_4x4ERKS0_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0107157 = 0.0, $$0108 = 0, $$0110165 = 0, $$0111164 = 0, $$0115163 = 0, $$1109 = 0, $$1112156 = 0, $$1116155 = 0, $$1127153 = 0, $$2 = 0.0, $$2$1 = 0.0, $$2$2 = 0.0, $$3 = 0.0, $$3114 = 0, $$3114$1 = 0, $$3114$2 = 0, $$3118 = 0, $$3118$1 = 0, $$3118$2 = 0, $$4 = 0;
 var $$4119 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0.0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0;
 var $117 = 0, $118 = 0, $119 = 0, $12 = 0.0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0.0, $128 = 0, $129 = 0.0, $13 = 0, $130 = 0.0, $131 = 0, $132 = 0, $133 = 0, $134 = 0;
 var $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0.0, $14 = 0, $140 = 0, $141 = 0.0, $142 = 0, $143 = 0.0, $144 = 0, $145 = 0.0, $146 = 0, $147 = 0.0, $148 = 0, $149 = 0.0, $15 = 0.0, $150 = 0, $151 = 0.0, $152 = 0;
 var $153 = 0.0, $154 = 0, $155 = 0, $156 = 0, $157 = 0.0, $158 = 0, $159 = 0.0, $16 = 0, $160 = 0, $161 = 0.0, $162 = 0.0, $163 = 0, $164 = 0.0, $165 = 0.0, $166 = 0, $167 = 0.0, $168 = 0.0, $169 = 0, $17 = 0, $170 = 0.0;
 var $171 = 0.0, $172 = 0, $173 = 0, $174 = 0.0, $175 = 0.0, $176 = 0.0, $177 = 0.0, $178 = 0.0, $179 = 0.0, $18 = 0.0, $180 = 0.0, $181 = 0.0, $182 = 0.0, $183 = 0.0, $184 = 0.0, $185 = 0.0, $186 = 0.0, $187 = 0.0, $188 = 0.0, $189 = 0.0;
 var $19 = 0, $190 = 0.0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0.0, $204 = 0, $205 = 0.0, $206 = 0;
 var $207 = 0.0, $208 = 0, $209 = 0.0, $21 = 0.0, $210 = 0, $211 = 0.0, $212 = 0, $213 = 0.0, $214 = 0, $215 = 0.0, $216 = 0, $217 = 0.0, $218 = 0, $219 = 0.0, $22 = 0, $220 = 0, $221 = 0.0, $222 = 0, $223 = 0.0, $224 = 0;
 var $225 = 0.0, $226 = 0, $227 = 0.0, $228 = 0, $229 = 0.0, $23 = 0, $230 = 0, $231 = 0.0, $232 = 0, $233 = 0.0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0.0, $240 = 0.0, $241 = 0, $242 = 0.0;
 var $243 = 0, $244 = 0.0, $245 = 0, $246 = 0.0, $247 = 0, $248 = 0.0, $249 = 0, $25 = 0, $250 = 0.0, $251 = 0, $252 = 0.0, $253 = 0, $254 = 0.0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0.0, $26 = 0, $260 = 0;
 var $261 = 0.0, $262 = 0, $263 = 0.0, $264 = 0, $265 = 0.0, $266 = 0, $267 = 0.0, $268 = 0, $269 = 0.0, $27 = 0.0, $270 = 0, $271 = 0.0, $272 = 0, $273 = 0.0, $274 = 0, $275 = 0.0, $276 = 0, $277 = 0.0, $278 = 0.0, $279 = 0;
 var $28 = 0, $280 = 0, $281 = 0.0, $282 = 0, $283 = 0.0, $284 = 0.0, $285 = 0, $286 = 0, $287 = 0.0, $288 = 0, $289 = 0.0, $29 = 0, $290 = 0.0, $291 = 0, $292 = 0, $293 = 0.0, $294 = 0.0, $295 = 0.0, $296 = 0.0, $297 = 0.0;
 var $298 = 0.0, $299 = 0.0, $3 = 0, $30 = 0.0, $300 = 0.0, $301 = 0.0, $302 = 0.0, $303 = 0.0, $304 = 0.0, $305 = 0.0, $306 = 0.0, $307 = 0.0, $308 = 0.0, $309 = 0.0, $31 = 0, $310 = 0, $311 = 0, $312 = 0.0, $313 = 0.0, $314 = 0.0;
 var $315 = 0.0, $316 = 0.0, $317 = 0.0, $318 = 0.0, $319 = 0.0, $32 = 0, $320 = 0.0, $321 = 0.0, $322 = 0.0, $323 = 0.0, $324 = 0.0, $325 = 0.0, $326 = 0.0, $327 = 0.0, $328 = 0.0, $329 = 0, $33 = 0.0, $330 = 0, $331 = 0.0, $332 = 0.0;
 var $333 = 0.0, $334 = 0.0, $335 = 0.0, $336 = 0.0, $337 = 0.0, $338 = 0.0, $339 = 0.0, $34 = 0, $340 = 0.0, $341 = 0.0, $342 = 0.0, $343 = 0.0, $344 = 0.0, $345 = 0.0, $346 = 0.0, $347 = 0.0, $348 = 0, $349 = 0, $35 = 0, $36 = 0.0;
 var $37 = 0, $38 = 0, $39 = 0.0, $4 = 0, $40 = 0, $41 = 0, $42 = 0.0, $43 = 0, $44 = 0, $45 = 0.0, $46 = 0, $47 = 0, $48 = 0.0, $49 = 0, $5 = 0, $50 = 0, $51 = 0.0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0.0, $59 = 0, $6 = 0, $60 = 0.0, $61 = 0, $62 = 0, $63 = 0.0, $64 = 0, $65 = 0, $66 = 0.0, $67 = 0, $68 = 0, $69 = 0.0, $7 = 0.0, $70 = 0, $71 = 0, $72 = 0.0;
 var $73 = 0, $74 = 0, $75 = 0.0, $76 = 0, $77 = 0, $78 = 0.0, $79 = 0, $8 = 0, $80 = 0, $81 = 0.0, $82 = 0, $83 = 0, $84 = 0.0, $85 = 0, $86 = 0, $87 = 0.0, $88 = 0, $89 = 0, $9 = 0.0, $90 = 0.0;
 var $91 = 0, $92 = 0, $93 = 0.0, $94 = 0, $95 = 0, $96 = 0.0, $97 = 0, $98 = 0, $99 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(176|0);
 $2 = sp;
 $3 = sp + 160|0;
 $4 = sp + 144|0;
 $5 = sp + 128|0;
 $6 = ($1|0)==($0|0);
 if ($6) {
  $7 = +HEAPF64[$1>>3];
  HEAPF64[$2>>3] = $7;
  $8 = ((($1)) + 8|0);
  $9 = +HEAPF64[$8>>3];
  $10 = ((($2)) + 8|0);
  HEAPF64[$10>>3] = $9;
  $11 = ((($1)) + 16|0);
  $12 = +HEAPF64[$11>>3];
  $13 = ((($2)) + 16|0);
  HEAPF64[$13>>3] = $12;
  $14 = ((($1)) + 24|0);
  $15 = +HEAPF64[$14>>3];
  $16 = ((($2)) + 24|0);
  HEAPF64[$16>>3] = $15;
  $17 = ((($1)) + 32|0);
  $18 = +HEAPF64[$17>>3];
  $19 = ((($2)) + 32|0);
  HEAPF64[$19>>3] = $18;
  $20 = ((($1)) + 40|0);
  $21 = +HEAPF64[$20>>3];
  $22 = ((($2)) + 40|0);
  HEAPF64[$22>>3] = $21;
  $23 = ((($1)) + 48|0);
  $24 = +HEAPF64[$23>>3];
  $25 = ((($2)) + 48|0);
  HEAPF64[$25>>3] = $24;
  $26 = ((($1)) + 56|0);
  $27 = +HEAPF64[$26>>3];
  $28 = ((($2)) + 56|0);
  HEAPF64[$28>>3] = $27;
  $29 = ((($1)) + 64|0);
  $30 = +HEAPF64[$29>>3];
  $31 = ((($2)) + 64|0);
  HEAPF64[$31>>3] = $30;
  $32 = ((($1)) + 72|0);
  $33 = +HEAPF64[$32>>3];
  $34 = ((($2)) + 72|0);
  HEAPF64[$34>>3] = $33;
  $35 = ((($1)) + 80|0);
  $36 = +HEAPF64[$35>>3];
  $37 = ((($2)) + 80|0);
  HEAPF64[$37>>3] = $36;
  $38 = ((($1)) + 88|0);
  $39 = +HEAPF64[$38>>3];
  $40 = ((($2)) + 88|0);
  HEAPF64[$40>>3] = $39;
  $41 = ((($1)) + 96|0);
  $42 = +HEAPF64[$41>>3];
  $43 = ((($2)) + 96|0);
  HEAPF64[$43>>3] = $42;
  $44 = ((($1)) + 104|0);
  $45 = +HEAPF64[$44>>3];
  $46 = ((($2)) + 104|0);
  HEAPF64[$46>>3] = $45;
  $47 = ((($1)) + 112|0);
  $48 = +HEAPF64[$47>>3];
  $49 = ((($2)) + 112|0);
  HEAPF64[$49>>3] = $48;
  $50 = ((($1)) + 120|0);
  $51 = +HEAPF64[$50>>3];
  $52 = ((($2)) + 120|0);
  HEAPF64[$52>>3] = $51;
  __THREW__ = 0;
  $53 = (invoke_iii(3304,($1|0),($2|0))|0);
  $54 = __THREW__; __THREW__ = 0;
  $55 = $54&1;
  if ($55) {
   $56 = ___cxa_find_matching_catch_2()|0;
   $57 = tempRet0;
   ___resumeException($56|0);
   // unreachable;
  }
  $$1109 = $53;
  STACKTOP = sp;return ($$1109|0);
 }
 $58 = +HEAPF64[$1>>3];
 HEAPF64[$0>>3] = $58;
 $59 = ((($1)) + 8|0);
 $60 = +HEAPF64[$59>>3];
 $61 = ((($0)) + 8|0);
 HEAPF64[$61>>3] = $60;
 $62 = ((($1)) + 16|0);
 $63 = +HEAPF64[$62>>3];
 $64 = ((($0)) + 16|0);
 HEAPF64[$64>>3] = $63;
 $65 = ((($1)) + 24|0);
 $66 = +HEAPF64[$65>>3];
 $67 = ((($0)) + 24|0);
 HEAPF64[$67>>3] = $66;
 $68 = ((($1)) + 32|0);
 $69 = +HEAPF64[$68>>3];
 $70 = ((($0)) + 32|0);
 HEAPF64[$70>>3] = $69;
 $71 = ((($1)) + 40|0);
 $72 = +HEAPF64[$71>>3];
 $73 = ((($0)) + 40|0);
 HEAPF64[$73>>3] = $72;
 $74 = ((($1)) + 48|0);
 $75 = +HEAPF64[$74>>3];
 $76 = ((($0)) + 48|0);
 HEAPF64[$76>>3] = $75;
 $77 = ((($1)) + 56|0);
 $78 = +HEAPF64[$77>>3];
 $79 = ((($0)) + 56|0);
 HEAPF64[$79>>3] = $78;
 $80 = ((($1)) + 64|0);
 $81 = +HEAPF64[$80>>3];
 $82 = ((($0)) + 64|0);
 HEAPF64[$82>>3] = $81;
 $83 = ((($1)) + 72|0);
 $84 = +HEAPF64[$83>>3];
 $85 = ((($0)) + 72|0);
 HEAPF64[$85>>3] = $84;
 $86 = ((($1)) + 80|0);
 $87 = +HEAPF64[$86>>3];
 $88 = ((($0)) + 80|0);
 HEAPF64[$88>>3] = $87;
 $89 = ((($1)) + 88|0);
 $90 = +HEAPF64[$89>>3];
 $91 = ((($0)) + 88|0);
 HEAPF64[$91>>3] = $90;
 $92 = ((($1)) + 96|0);
 $93 = +HEAPF64[$92>>3];
 $94 = ((($0)) + 96|0);
 HEAPF64[$94>>3] = $93;
 $95 = ((($1)) + 104|0);
 $96 = +HEAPF64[$95>>3];
 $97 = ((($0)) + 104|0);
 HEAPF64[$97>>3] = $96;
 $98 = ((($1)) + 112|0);
 $99 = +HEAPF64[$98>>3];
 $100 = ((($0)) + 112|0);
 HEAPF64[$100>>3] = $99;
 $101 = ((($1)) + 120|0);
 $102 = +HEAPF64[$101>>3];
 $103 = ((($0)) + 120|0);
 HEAPF64[$103>>3] = $102;
 ;HEAP32[$5>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;HEAP32[$5+12>>2]=0|0;
 $104 = ((($5)) + 4|0);
 $105 = ((($5)) + 8|0);
 $106 = ((($5)) + 12|0);
 $107 = ((($0)) + 32|0);
 $108 = ((($0)) + 40|0);
 $109 = ((($0)) + 48|0);
 $110 = ((($0)) + 56|0);
 $111 = ((($0)) + 96|0);
 $112 = ((($0)) + 104|0);
 $113 = ((($0)) + 112|0);
 $114 = ((($0)) + 120|0);
 $115 = ((($0)) + 64|0);
 $116 = ((($0)) + 72|0);
 $117 = ((($0)) + 80|0);
 $118 = ((($0)) + 88|0);
 $$0110165 = 0;$$0111164 = 0;$$0115163 = 0;
 L8: while(1) {
  $119 = HEAP32[$5>>2]|0;
  $120 = HEAP32[$104>>2]|0;
  $121 = HEAP32[$105>>2]|0;
  $122 = HEAP32[$106>>2]|0;
  $$0107157 = 0.0;$$1112156 = $$0111164;$$1116155 = $$0115163;$$1127153 = 0;
  while(1) {
   $123 = (($5) + ($$1127153<<2)|0);
   $124 = HEAP32[$123>>2]|0;
   $125 = ($124|0)==(1);
   L12: do {
    if ($125) {
     $$3 = $$0107157;$$4 = $$1112156;$$4119 = $$1116155;
    } else {
     switch ($119|0) {
     case 0:  {
      $126 = (($0) + ($$1127153<<5)|0);
      $127 = +HEAPF64[$126>>3];
      $128 = $127 >= 0.0;
      $129 = -$127;
      $130 = $128 ? $127 : $129;
      $131 = !($130 >= $$0107157);
      if ($131) {
       $$2 = $$0107157;$$3114 = $$1112156;$$3118 = $$1116155;
      } else {
       $$2 = $130;$$3114 = $$1127153;$$3118 = 0;
      }
      break;
     }
     case 1:  {
      $$2 = $$0107157;$$3114 = $$1112156;$$3118 = $$1116155;
      break;
     }
     default: {
      $$0108 = 0;
      break L8;
     }
     }
     switch ($120|0) {
     case 0:  {
      $274 = (((($0) + ($$1127153<<5)|0)) + 8|0);
      $275 = +HEAPF64[$274>>3];
      $276 = $275 >= 0.0;
      $277 = -$275;
      $278 = $276 ? $275 : $277;
      $279 = !($278 >= $$2);
      if ($279) {
       $$2$1 = $$2;$$3114$1 = $$3114;$$3118$1 = $$3118;
      } else {
       $$2$1 = $278;$$3114$1 = $$1127153;$$3118$1 = 1;
      }
      break;
     }
     case 1:  {
      $$2$1 = $$2;$$3114$1 = $$3114;$$3118$1 = $$3118;
      break;
     }
     default: {
      $$0108 = 0;
      break L8;
     }
     }
     switch ($121|0) {
     case 0:  {
      $280 = (((($0) + ($$1127153<<5)|0)) + 16|0);
      $281 = +HEAPF64[$280>>3];
      $282 = $281 >= 0.0;
      $283 = -$281;
      $284 = $282 ? $281 : $283;
      $285 = !($284 >= $$2$1);
      if ($285) {
       $$2$2 = $$2$1;$$3114$2 = $$3114$1;$$3118$2 = $$3118$1;
      } else {
       $$2$2 = $284;$$3114$2 = $$1127153;$$3118$2 = 2;
      }
      break;
     }
     case 1:  {
      $$2$2 = $$2$1;$$3114$2 = $$3114$1;$$3118$2 = $$3118$1;
      break;
     }
     default: {
      $$0108 = 0;
      break L8;
     }
     }
     switch ($122|0) {
     case 1:  {
      $$3 = $$2$2;$$4 = $$3114$2;$$4119 = $$3118$2;
      break L12;
      break;
     }
     case 0:  {
      break;
     }
     default: {
      $$0108 = 0;
      break L8;
     }
     }
     $286 = (((($0) + ($$1127153<<5)|0)) + 24|0);
     $287 = +HEAPF64[$286>>3];
     $288 = $287 >= 0.0;
     $289 = -$287;
     $290 = $288 ? $287 : $289;
     $291 = !($290 >= $$2$2);
     if ($291) {
      $$3 = $$2$2;$$4 = $$3114$2;$$4119 = $$3118$2;
     } else {
      $$3 = $290;$$4 = $$1127153;$$4119 = 3;
     }
    }
   } while(0);
   $132 = (($$1127153) + 1)|0;
   $133 = ($132>>>0)<(4);
   if ($133) {
    $$0107157 = $$3;$$1112156 = $$4;$$1116155 = $$4119;$$1127153 = $132;
   } else {
    break;
   }
  }
  $134 = (($5) + ($$4119<<2)|0);
  $135 = HEAP32[$134>>2]|0;
  $136 = (($135) + 1)|0;
  HEAP32[$134>>2] = $136;
  $137 = ($$4|0)==($$4119|0);
  if (!($137)) {
   $138 = (($0) + ($$4<<5)|0);
   $139 = +HEAPF64[$138>>3];
   $140 = (($0) + ($$4119<<5)|0);
   $141 = +HEAPF64[$140>>3];
   HEAPF64[$138>>3] = $141;
   HEAPF64[$140>>3] = $139;
   $142 = (((($0) + ($$4<<5)|0)) + 8|0);
   $143 = +HEAPF64[$142>>3];
   $144 = (((($0) + ($$4119<<5)|0)) + 8|0);
   $145 = +HEAPF64[$144>>3];
   HEAPF64[$142>>3] = $145;
   HEAPF64[$144>>3] = $143;
   $146 = (((($0) + ($$4<<5)|0)) + 16|0);
   $147 = +HEAPF64[$146>>3];
   $148 = (((($0) + ($$4119<<5)|0)) + 16|0);
   $149 = +HEAPF64[$148>>3];
   HEAPF64[$146>>3] = $149;
   HEAPF64[$148>>3] = $147;
   $150 = (((($0) + ($$4<<5)|0)) + 24|0);
   $151 = +HEAPF64[$150>>3];
   $152 = (((($0) + ($$4119<<5)|0)) + 24|0);
   $153 = +HEAPF64[$152>>3];
   HEAPF64[$150>>3] = $153;
   HEAPF64[$152>>3] = $151;
  }
  $154 = (($4) + ($$0110165<<2)|0);
  HEAP32[$154>>2] = $$4;
  $155 = (($3) + ($$0110165<<2)|0);
  HEAP32[$155>>2] = $$4119;
  $156 = ((($0) + ($$4119<<5)|0) + ($$4119<<3)|0);
  $157 = +HEAPF64[$156>>3];
  $158 = $157 == 0.0;
  if ($158) {
   $$0108 = 0;
   break;
  }
  $159 = 1.0 / $157;
  HEAPF64[$156>>3] = 1.0;
  $160 = (($0) + ($$4119<<5)|0);
  $161 = +HEAPF64[$160>>3];
  $162 = $159 * $161;
  HEAPF64[$160>>3] = $162;
  $163 = (((($0) + ($$4119<<5)|0)) + 8|0);
  $164 = +HEAPF64[$163>>3];
  $165 = $159 * $164;
  HEAPF64[$163>>3] = $165;
  $166 = (((($0) + ($$4119<<5)|0)) + 16|0);
  $167 = +HEAPF64[$166>>3];
  $168 = $159 * $167;
  HEAPF64[$166>>3] = $168;
  $169 = (((($0) + ($$4119<<5)|0)) + 24|0);
  $170 = +HEAPF64[$169>>3];
  $171 = $159 * $170;
  HEAPF64[$169>>3] = $171;
  $172 = ($$4119|0)==(0);
  if ($172) {
   label = 36;
  } else {
   $173 = (($0) + ($$4119<<3)|0);
   $174 = +HEAPF64[$173>>3];
   HEAPF64[$173>>3] = 0.0;
   $175 = +HEAPF64[$160>>3];
   $176 = $174 * $175;
   $177 = +HEAPF64[$0>>3];
   $178 = $177 - $176;
   HEAPF64[$0>>3] = $178;
   $179 = +HEAPF64[$163>>3];
   $180 = $174 * $179;
   $181 = +HEAPF64[$61>>3];
   $182 = $181 - $180;
   HEAPF64[$61>>3] = $182;
   $183 = +HEAPF64[$166>>3];
   $184 = $174 * $183;
   $185 = +HEAPF64[$64>>3];
   $186 = $185 - $184;
   HEAPF64[$64>>3] = $186;
   $187 = +HEAPF64[$169>>3];
   $188 = $174 * $187;
   $189 = +HEAPF64[$67>>3];
   $190 = $189 - $188;
   HEAPF64[$67>>3] = $190;
   $191 = ($$4119|0)==(1);
   if ($191) {
    label = 37;
   } else {
    label = 36;
   }
  }
  if ((label|0) == 36) {
   label = 0;
   $292 = (((($0)) + 32|0) + ($$4119<<3)|0);
   $293 = +HEAPF64[$292>>3];
   HEAPF64[$292>>3] = 0.0;
   $294 = +HEAPF64[$160>>3];
   $295 = $293 * $294;
   $296 = +HEAPF64[$107>>3];
   $297 = $296 - $295;
   HEAPF64[$107>>3] = $297;
   $298 = +HEAPF64[$163>>3];
   $299 = $293 * $298;
   $300 = +HEAPF64[$108>>3];
   $301 = $300 - $299;
   HEAPF64[$108>>3] = $301;
   $302 = +HEAPF64[$166>>3];
   $303 = $293 * $302;
   $304 = +HEAPF64[$109>>3];
   $305 = $304 - $303;
   HEAPF64[$109>>3] = $305;
   $306 = +HEAPF64[$169>>3];
   $307 = $293 * $306;
   $308 = +HEAPF64[$110>>3];
   $309 = $308 - $307;
   HEAPF64[$110>>3] = $309;
   $310 = ($$4119|0)==(2);
   if ($310) {
    label = 38;
   } else {
    label = 37;
   }
  }
  if ((label|0) == 37) {
   label = 0;
   $311 = (((($0)) + 64|0) + ($$4119<<3)|0);
   $312 = +HEAPF64[$311>>3];
   HEAPF64[$311>>3] = 0.0;
   $313 = +HEAPF64[$160>>3];
   $314 = $312 * $313;
   $315 = +HEAPF64[$115>>3];
   $316 = $315 - $314;
   HEAPF64[$115>>3] = $316;
   $317 = +HEAPF64[$163>>3];
   $318 = $312 * $317;
   $319 = +HEAPF64[$116>>3];
   $320 = $319 - $318;
   HEAPF64[$116>>3] = $320;
   $321 = +HEAPF64[$166>>3];
   $322 = $312 * $321;
   $323 = +HEAPF64[$117>>3];
   $324 = $323 - $322;
   HEAPF64[$117>>3] = $324;
   $325 = +HEAPF64[$169>>3];
   $326 = $312 * $325;
   $327 = +HEAPF64[$118>>3];
   $328 = $327 - $326;
   HEAPF64[$118>>3] = $328;
   $329 = ($$4119|0)==(3);
   if (!($329)) {
    label = 38;
   }
  }
  if ((label|0) == 38) {
   label = 0;
   $330 = (((($0)) + 96|0) + ($$4119<<3)|0);
   $331 = +HEAPF64[$330>>3];
   HEAPF64[$330>>3] = 0.0;
   $332 = +HEAPF64[$160>>3];
   $333 = $331 * $332;
   $334 = +HEAPF64[$111>>3];
   $335 = $334 - $333;
   HEAPF64[$111>>3] = $335;
   $336 = +HEAPF64[$163>>3];
   $337 = $331 * $336;
   $338 = +HEAPF64[$112>>3];
   $339 = $338 - $337;
   HEAPF64[$112>>3] = $339;
   $340 = +HEAPF64[$166>>3];
   $341 = $331 * $340;
   $342 = +HEAPF64[$113>>3];
   $343 = $342 - $341;
   HEAPF64[$113>>3] = $343;
   $344 = +HEAPF64[$169>>3];
   $345 = $331 * $344;
   $346 = +HEAPF64[$114>>3];
   $347 = $346 - $345;
   HEAPF64[$114>>3] = $347;
  }
  $348 = (($$0110165) + 1)|0;
  $349 = ($348>>>0)<(4);
  if ($349) {
   $$0110165 = $348;$$0111164 = $$4;$$0115163 = $$4119;
  } else {
   label = 18;
   break;
  }
 }
 if ((label|0) == 18) {
  $192 = ((($4)) + 12|0);
  $193 = HEAP32[$192>>2]|0;
  $194 = ((($3)) + 12|0);
  $195 = HEAP32[$194>>2]|0;
  $196 = ($193|0)==($195|0);
  if (!($196)) {
   $202 = (($0) + ($193<<3)|0);
   $203 = +HEAPF64[$202>>3];
   $204 = (($0) + ($195<<3)|0);
   $205 = +HEAPF64[$204>>3];
   HEAPF64[$202>>3] = $205;
   HEAPF64[$204>>3] = $203;
   $206 = (((($0)) + 32|0) + ($193<<3)|0);
   $207 = +HEAPF64[$206>>3];
   $208 = (((($0)) + 32|0) + ($195<<3)|0);
   $209 = +HEAPF64[$208>>3];
   HEAPF64[$206>>3] = $209;
   HEAPF64[$208>>3] = $207;
   $210 = (((($0)) + 64|0) + ($193<<3)|0);
   $211 = +HEAPF64[$210>>3];
   $212 = (((($0)) + 64|0) + ($195<<3)|0);
   $213 = +HEAPF64[$212>>3];
   HEAPF64[$210>>3] = $213;
   HEAPF64[$212>>3] = $211;
   $214 = (((($0)) + 96|0) + ($193<<3)|0);
   $215 = +HEAPF64[$214>>3];
   $216 = (((($0)) + 96|0) + ($195<<3)|0);
   $217 = +HEAPF64[$216>>3];
   HEAPF64[$214>>3] = $217;
   HEAPF64[$216>>3] = $215;
  }
  $197 = ((($4)) + 8|0);
  $198 = HEAP32[$197>>2]|0;
  $199 = ((($3)) + 8|0);
  $200 = HEAP32[$199>>2]|0;
  $201 = ($198|0)==($200|0);
  if (!($201)) {
   $218 = (($0) + ($198<<3)|0);
   $219 = +HEAPF64[$218>>3];
   $220 = (($0) + ($200<<3)|0);
   $221 = +HEAPF64[$220>>3];
   HEAPF64[$218>>3] = $221;
   HEAPF64[$220>>3] = $219;
   $222 = (((($0)) + 32|0) + ($198<<3)|0);
   $223 = +HEAPF64[$222>>3];
   $224 = (((($0)) + 32|0) + ($200<<3)|0);
   $225 = +HEAPF64[$224>>3];
   HEAPF64[$222>>3] = $225;
   HEAPF64[$224>>3] = $223;
   $226 = (((($0)) + 64|0) + ($198<<3)|0);
   $227 = +HEAPF64[$226>>3];
   $228 = (((($0)) + 64|0) + ($200<<3)|0);
   $229 = +HEAPF64[$228>>3];
   HEAPF64[$226>>3] = $229;
   HEAPF64[$228>>3] = $227;
   $230 = (((($0)) + 96|0) + ($198<<3)|0);
   $231 = +HEAPF64[$230>>3];
   $232 = (((($0)) + 96|0) + ($200<<3)|0);
   $233 = +HEAPF64[$232>>3];
   HEAPF64[$230>>3] = $233;
   HEAPF64[$232>>3] = $231;
  }
  $234 = ((($4)) + 4|0);
  $235 = HEAP32[$234>>2]|0;
  $236 = ((($3)) + 4|0);
  $237 = HEAP32[$236>>2]|0;
  $238 = ($235|0)==($237|0);
  if (!($238)) {
   $239 = (($0) + ($235<<3)|0);
   $240 = +HEAPF64[$239>>3];
   $241 = (($0) + ($237<<3)|0);
   $242 = +HEAPF64[$241>>3];
   HEAPF64[$239>>3] = $242;
   HEAPF64[$241>>3] = $240;
   $243 = (((($0)) + 32|0) + ($235<<3)|0);
   $244 = +HEAPF64[$243>>3];
   $245 = (((($0)) + 32|0) + ($237<<3)|0);
   $246 = +HEAPF64[$245>>3];
   HEAPF64[$243>>3] = $246;
   HEAPF64[$245>>3] = $244;
   $247 = (((($0)) + 64|0) + ($235<<3)|0);
   $248 = +HEAPF64[$247>>3];
   $249 = (((($0)) + 64|0) + ($237<<3)|0);
   $250 = +HEAPF64[$249>>3];
   HEAPF64[$247>>3] = $250;
   HEAPF64[$249>>3] = $248;
   $251 = (((($0)) + 96|0) + ($235<<3)|0);
   $252 = +HEAPF64[$251>>3];
   $253 = (((($0)) + 96|0) + ($237<<3)|0);
   $254 = +HEAPF64[$253>>3];
   HEAPF64[$251>>3] = $254;
   HEAPF64[$253>>3] = $252;
  }
  $255 = HEAP32[$4>>2]|0;
  $256 = HEAP32[$3>>2]|0;
  $257 = ($255|0)==($256|0);
  if ($257) {
   $$0108 = 1;
  } else {
   $258 = (($0) + ($255<<3)|0);
   $259 = +HEAPF64[$258>>3];
   $260 = (($0) + ($256<<3)|0);
   $261 = +HEAPF64[$260>>3];
   HEAPF64[$258>>3] = $261;
   HEAPF64[$260>>3] = $259;
   $262 = (((($0)) + 32|0) + ($255<<3)|0);
   $263 = +HEAPF64[$262>>3];
   $264 = (((($0)) + 32|0) + ($256<<3)|0);
   $265 = +HEAPF64[$264>>3];
   HEAPF64[$262>>3] = $265;
   HEAPF64[$264>>3] = $263;
   $266 = (((($0)) + 64|0) + ($255<<3)|0);
   $267 = +HEAPF64[$266>>3];
   $268 = (((($0)) + 64|0) + ($256<<3)|0);
   $269 = +HEAPF64[$268>>3];
   HEAPF64[$266>>3] = $269;
   HEAPF64[$268>>3] = $267;
   $270 = (((($0)) + 96|0) + ($255<<3)|0);
   $271 = +HEAPF64[$270>>3];
   $272 = (((($0)) + 96|0) + ($256<<3)|0);
   $273 = +HEAPF64[$272>>3];
   HEAPF64[$270>>3] = $273;
   HEAPF64[$272>>3] = $271;
   $$0108 = 1;
  }
 }
 $$1109 = $$0108;
 STACKTOP = sp;return ($$1109|0);
}
function __ZNK3osg7Matrixd8getOrthoERdS1_S1_S1_S1_S1_($0,$1,$2,$3,$4,$5,$6) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 var $$0 = 0, $10 = 0, $11 = 0.0, $12 = 0, $13 = 0, $14 = 0.0, $15 = 0, $16 = 0, $17 = 0.0, $18 = 0, $19 = 0, $20 = 0.0, $21 = 0.0, $22 = 0, $23 = 0.0, $24 = 0.0, $25 = 0.0, $26 = 0.0, $27 = 0.0, $28 = 0.0;
 var $29 = 0, $30 = 0.0, $31 = 0.0, $32 = 0.0, $33 = 0.0, $34 = 0.0, $35 = 0.0, $36 = 0.0, $37 = 0.0, $38 = 0.0, $39 = 0, $40 = 0.0, $41 = 0.0, $42 = 0.0, $43 = 0, $44 = 0.0, $45 = 0.0, $46 = 0.0, $47 = 0.0, $48 = 0.0;
 var $49 = 0.0, $7 = 0, $8 = 0.0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $7 = ((($0)) + 24|0);
 $8 = +HEAPF64[$7>>3];
 $9 = $8 != 0.0;
 if ($9) {
  $$0 = 0;
  return ($$0|0);
 }
 $10 = ((($0)) + 56|0);
 $11 = +HEAPF64[$10>>3];
 $12 = $11 != 0.0;
 if ($12) {
  $$0 = 0;
  return ($$0|0);
 }
 $13 = ((($0)) + 88|0);
 $14 = +HEAPF64[$13>>3];
 $15 = $14 != 0.0;
 if ($15) {
  $$0 = 0;
  return ($$0|0);
 }
 $16 = ((($0)) + 120|0);
 $17 = +HEAPF64[$16>>3];
 $18 = $17 != 1.0;
 if ($18) {
  $$0 = 0;
  return ($$0|0);
 }
 $19 = ((($0)) + 112|0);
 $20 = +HEAPF64[$19>>3];
 $21 = $20 + 1.0;
 $22 = ((($0)) + 80|0);
 $23 = +HEAPF64[$22>>3];
 $24 = $21 / $23;
 HEAPF64[$5>>3] = $24;
 $25 = +HEAPF64[$19>>3];
 $26 = $25 + -1.0;
 $27 = +HEAPF64[$22>>3];
 $28 = $26 / $27;
 HEAPF64[$6>>3] = $28;
 $29 = ((($0)) + 96|0);
 $30 = +HEAPF64[$29>>3];
 $31 = $30 + 1.0;
 $32 = -$31;
 $33 = +HEAPF64[$0>>3];
 $34 = $32 / $33;
 HEAPF64[$1>>3] = $34;
 $35 = +HEAPF64[$29>>3];
 $36 = 1.0 - $35;
 $37 = +HEAPF64[$0>>3];
 $38 = $36 / $37;
 HEAPF64[$2>>3] = $38;
 $39 = ((($0)) + 104|0);
 $40 = +HEAPF64[$39>>3];
 $41 = $40 + 1.0;
 $42 = -$41;
 $43 = ((($0)) + 40|0);
 $44 = +HEAPF64[$43>>3];
 $45 = $42 / $44;
 HEAPF64[$3>>3] = $45;
 $46 = +HEAPF64[$39>>3];
 $47 = 1.0 - $46;
 $48 = +HEAPF64[$43>>3];
 $49 = $47 / $48;
 HEAPF64[$4>>3] = $49;
 $$0 = 1;
 return ($$0|0);
}
function __ZNK3osg7Matrixd10getFrustumERdS1_S1_S1_S1_S1_($0,$1,$2,$3,$4,$5,$6) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 var $$0 = 0, $10 = 0, $11 = 0.0, $12 = 0, $13 = 0, $14 = 0.0, $15 = 0, $16 = 0, $17 = 0.0, $18 = 0, $19 = 0, $20 = 0.0, $21 = 0, $22 = 0.0, $23 = 0.0, $24 = 0.0, $25 = 0.0, $26 = 0.0, $27 = 0, $28 = 0.0;
 var $29 = 0.0, $30 = 0.0, $31 = 0.0, $32 = 0.0, $33 = 0.0, $34 = 0.0, $35 = 0.0, $36 = 0.0, $37 = 0.0, $38 = 0, $39 = 0.0, $40 = 0.0, $41 = 0.0, $42 = 0, $43 = 0.0, $44 = 0.0, $45 = 0.0, $46 = 0.0, $47 = 0.0, $48 = 0.0;
 var $49 = 0.0, $7 = 0, $8 = 0.0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $7 = ((($0)) + 24|0);
 $8 = +HEAPF64[$7>>3];
 $9 = $8 != 0.0;
 if ($9) {
  $$0 = 0;
  return ($$0|0);
 }
 $10 = ((($0)) + 56|0);
 $11 = +HEAPF64[$10>>3];
 $12 = $11 != 0.0;
 if ($12) {
  $$0 = 0;
  return ($$0|0);
 }
 $13 = ((($0)) + 88|0);
 $14 = +HEAPF64[$13>>3];
 $15 = $14 != -1.0;
 if ($15) {
  $$0 = 0;
  return ($$0|0);
 }
 $16 = ((($0)) + 120|0);
 $17 = +HEAPF64[$16>>3];
 $18 = $17 != 0.0;
 if ($18) {
  $$0 = 0;
  return ($$0|0);
 }
 $19 = ((($0)) + 112|0);
 $20 = +HEAPF64[$19>>3];
 $21 = ((($0)) + 80|0);
 $22 = +HEAPF64[$21>>3];
 $23 = $22 + -1.0;
 $24 = $20 / $23;
 $25 = $22 + 1.0;
 $26 = $20 / $25;
 $27 = ((($0)) + 64|0);
 $28 = +HEAPF64[$27>>3];
 $29 = $28 + -1.0;
 $30 = $24 * $29;
 $31 = +HEAPF64[$0>>3];
 $32 = $30 / $31;
 HEAPF64[$1>>3] = $32;
 $33 = +HEAPF64[$27>>3];
 $34 = $33 + 1.0;
 $35 = $24 * $34;
 $36 = +HEAPF64[$0>>3];
 $37 = $35 / $36;
 HEAPF64[$2>>3] = $37;
 $38 = ((($0)) + 72|0);
 $39 = +HEAPF64[$38>>3];
 $40 = $39 + 1.0;
 $41 = $24 * $40;
 $42 = ((($0)) + 40|0);
 $43 = +HEAPF64[$42>>3];
 $44 = $41 / $43;
 HEAPF64[$4>>3] = $44;
 $45 = +HEAPF64[$38>>3];
 $46 = $45 + -1.0;
 $47 = $24 * $46;
 $48 = +HEAPF64[$42>>3];
 $49 = $47 / $48;
 HEAPF64[$3>>3] = $49;
 HEAPF64[$5>>3] = $24;
 HEAPF64[$6>>3] = $26;
 $$0 = 1;
 return ($$0|0);
}
function __ZN3osg7Matrixd15makePerspectiveEdddd($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = +$1;
 $2 = +$2;
 $3 = +$3;
 $4 = +$4;
 var $10 = 0.0, $11 = 0.0, $12 = 0.0, $13 = 0.0, $14 = 0.0, $15 = 0.0, $16 = 0.0, $17 = 0.0, $18 = 0.0, $19 = 0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0.0, $25 = 0.0, $26 = 0.0, $27 = 0.0, $28 = 0.0, $29 = 0.0;
 var $30 = 0, $31 = 0.0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0.0, $38 = 0, $39 = 0, $40 = 0, $41 = 0.0, $42 = 0, $5 = 0.0, $6 = 0.0, $7 = 0.0, $8 = 0.0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = $1 * 0.5;
 $6 = $5 * 3.1415926535897931;
 $7 = $6 / 180.0;
 $8 = (+Math_tan((+$7)));
 $9 = $8 * $2;
 $10 = $9 * $3;
 $11 = $8 * $3;
 $12 = $10 - $10;
 $13 = $10 + $10;
 $14 = $12 / $13;
 $15 = $11 - $11;
 $16 = $11 + $11;
 $17 = $15 / $16;
 $18 = (+Math_abs((+$4)));
 $19 = $18 > 1.7976931348623157E+308;
 if ($19) {
  $20 = $3 * -2.0;
  $37 = -1.0;$41 = $20;
 } else {
  $21 = $3 + $4;
  $22 = -$21;
  $23 = $4 - $3;
  $24 = $22 / $23;
  $25 = $4 * -2.0;
  $26 = $25 * $3;
  $27 = $26 / $23;
  $37 = $24;$41 = $27;
 }
 $28 = $3 * 2.0;
 $29 = $28 / $13;
 HEAPF64[$0>>3] = $29;
 $30 = ((($0)) + 8|0);
 $31 = $28 / $16;
 $32 = ((($0)) + 40|0);
 ;HEAP32[$30>>2]=0|0;HEAP32[$30+4>>2]=0|0;HEAP32[$30+8>>2]=0|0;HEAP32[$30+12>>2]=0|0;HEAP32[$30+16>>2]=0|0;HEAP32[$30+20>>2]=0|0;HEAP32[$30+24>>2]=0|0;HEAP32[$30+28>>2]=0|0;
 HEAPF64[$32>>3] = $31;
 $33 = ((($0)) + 48|0);
 $34 = ((($0)) + 64|0);
 ;HEAP32[$33>>2]=0|0;HEAP32[$33+4>>2]=0|0;HEAP32[$33+8>>2]=0|0;HEAP32[$33+12>>2]=0|0;
 HEAPF64[$34>>3] = $14;
 $35 = ((($0)) + 72|0);
 HEAPF64[$35>>3] = $17;
 $36 = ((($0)) + 80|0);
 HEAPF64[$36>>3] = $37;
 $38 = ((($0)) + 88|0);
 HEAPF64[$38>>3] = -1.0;
 $39 = ((($0)) + 96|0);
 $40 = ((($0)) + 112|0);
 ;HEAP32[$39>>2]=0|0;HEAP32[$39+4>>2]=0|0;HEAP32[$39+8>>2]=0|0;HEAP32[$39+12>>2]=0|0;
 HEAPF64[$40>>3] = $41;
 $42 = ((($0)) + 120|0);
 HEAPF64[$42>>3] = 0.0;
 return;
}
function __ZNK3osg7Matrixd14getPerspectiveERdS1_S1_S1_($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0$i32 = 0, $$02530 = 0.0, $$031 = 0.0, $10 = 0, $11 = 0, $12 = 0.0, $13 = 0, $14 = 0, $15 = 0.0, $16 = 0, $17 = 0, $18 = 0.0, $19 = 0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0.0, $25 = 0, $26 = 0.0;
 var $27 = 0.0, $28 = 0.0, $29 = 0.0, $30 = 0.0, $31 = 0.0, $32 = 0.0, $33 = 0.0, $34 = 0, $35 = 0.0, $36 = 0.0, $37 = 0.0, $38 = 0, $39 = 0.0, $40 = 0.0, $41 = 0.0, $42 = 0.0, $43 = 0.0, $44 = 0.0, $45 = 0.0, $46 = 0.0;
 var $47 = 0.0, $48 = 0.0, $49 = 0.0, $5 = 0, $50 = 0.0, $51 = 0.0, $52 = 0.0, $53 = 0.0, $6 = 0.0, $7 = 0, $8 = 0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = ((($0)) + 24|0);
 $6 = +HEAPF64[$5>>3];
 $7 = $6 != 0.0;
 if ($7) {
  $$0$i32 = 0;$$02530 = 0.0;$$031 = 0.0;
 } else {
  $8 = ((($0)) + 56|0);
  $9 = +HEAPF64[$8>>3];
  $10 = $9 != 0.0;
  if ($10) {
   $$0$i32 = 0;$$02530 = 0.0;$$031 = 0.0;
  } else {
   $11 = ((($0)) + 88|0);
   $12 = +HEAPF64[$11>>3];
   $13 = $12 != -1.0;
   if ($13) {
    $$0$i32 = 0;$$02530 = 0.0;$$031 = 0.0;
   } else {
    $14 = ((($0)) + 120|0);
    $15 = +HEAPF64[$14>>3];
    $16 = $15 != 0.0;
    if ($16) {
     $$0$i32 = 0;$$02530 = 0.0;$$031 = 0.0;
    } else {
     $17 = ((($0)) + 112|0);
     $18 = +HEAPF64[$17>>3];
     $19 = ((($0)) + 80|0);
     $20 = +HEAPF64[$19>>3];
     $21 = $20 + -1.0;
     $22 = $18 / $21;
     $23 = $20 + 1.0;
     $24 = $18 / $23;
     $25 = ((($0)) + 64|0);
     $26 = +HEAPF64[$25>>3];
     $27 = $26 + -1.0;
     $28 = $22 * $27;
     $29 = +HEAPF64[$0>>3];
     $30 = $28 / $29;
     $31 = $26 + 1.0;
     $32 = $22 * $31;
     $33 = $32 / $29;
     $34 = ((($0)) + 72|0);
     $35 = +HEAPF64[$34>>3];
     $36 = $35 + 1.0;
     $37 = $22 * $36;
     $38 = ((($0)) + 40|0);
     $39 = +HEAPF64[$38>>3];
     $40 = $37 / $39;
     $41 = $35 + -1.0;
     $42 = $22 * $41;
     $43 = $42 / $39;
     $44 = $40 / $22;
     $45 = (+Math_atan((+$44)));
     $46 = $43 / $22;
     $47 = (+Math_atan((+$46)));
     $48 = $45 - $47;
     $49 = $48 * 180.0;
     $50 = $49 / 3.1415926535897931;
     HEAPF64[$1>>3] = $50;
     $51 = $33 - $30;
     $52 = $40 - $43;
     $53 = $51 / $52;
     HEAPF64[$2>>3] = $53;
     $$0$i32 = 1;$$02530 = $22;$$031 = $24;
    }
   }
  }
 }
 HEAPF64[$3>>3] = $$02530;
 HEAPF64[$4>>3] = $$031;
 return ($$0$i32|0);
}
function __ZN3osg7MatrixfC2ERKNS_7MatrixdE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0.0, $11 = 0, $12 = 0, $13 = 0.0, $14 = 0.0, $15 = 0, $16 = 0, $17 = 0.0, $18 = 0.0, $19 = 0, $2 = 0.0, $20 = 0, $21 = 0.0, $22 = 0.0, $23 = 0, $24 = 0, $25 = 0.0, $26 = 0.0, $27 = 0, $28 = 0;
 var $29 = 0.0, $3 = 0.0, $30 = 0.0, $31 = 0, $32 = 0, $33 = 0.0, $34 = 0.0, $35 = 0, $36 = 0, $37 = 0.0, $38 = 0.0, $39 = 0, $4 = 0, $40 = 0, $41 = 0.0, $42 = 0.0, $43 = 0, $44 = 0, $45 = 0.0, $46 = 0.0;
 var $47 = 0, $48 = 0, $49 = 0.0, $5 = 0.0, $50 = 0.0, $51 = 0, $52 = 0, $53 = 0.0, $54 = 0.0, $55 = 0, $56 = 0, $57 = 0.0, $58 = 0.0, $59 = 0, $6 = 0.0, $60 = 0, $61 = 0.0, $62 = 0.0, $63 = 0, $7 = 0;
 var $8 = 0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = +HEAPF64[$1>>3];
 $3 = $2;
 HEAPF32[$0>>2] = $3;
 $4 = ((($1)) + 8|0);
 $5 = +HEAPF64[$4>>3];
 $6 = $5;
 $7 = ((($0)) + 4|0);
 HEAPF32[$7>>2] = $6;
 $8 = ((($1)) + 16|0);
 $9 = +HEAPF64[$8>>3];
 $10 = $9;
 $11 = ((($0)) + 8|0);
 HEAPF32[$11>>2] = $10;
 $12 = ((($1)) + 24|0);
 $13 = +HEAPF64[$12>>3];
 $14 = $13;
 $15 = ((($0)) + 12|0);
 HEAPF32[$15>>2] = $14;
 $16 = ((($1)) + 32|0);
 $17 = +HEAPF64[$16>>3];
 $18 = $17;
 $19 = ((($0)) + 16|0);
 HEAPF32[$19>>2] = $18;
 $20 = ((($1)) + 40|0);
 $21 = +HEAPF64[$20>>3];
 $22 = $21;
 $23 = ((($0)) + 20|0);
 HEAPF32[$23>>2] = $22;
 $24 = ((($1)) + 48|0);
 $25 = +HEAPF64[$24>>3];
 $26 = $25;
 $27 = ((($0)) + 24|0);
 HEAPF32[$27>>2] = $26;
 $28 = ((($1)) + 56|0);
 $29 = +HEAPF64[$28>>3];
 $30 = $29;
 $31 = ((($0)) + 28|0);
 HEAPF32[$31>>2] = $30;
 $32 = ((($1)) + 64|0);
 $33 = +HEAPF64[$32>>3];
 $34 = $33;
 $35 = ((($0)) + 32|0);
 HEAPF32[$35>>2] = $34;
 $36 = ((($1)) + 72|0);
 $37 = +HEAPF64[$36>>3];
 $38 = $37;
 $39 = ((($0)) + 36|0);
 HEAPF32[$39>>2] = $38;
 $40 = ((($1)) + 80|0);
 $41 = +HEAPF64[$40>>3];
 $42 = $41;
 $43 = ((($0)) + 40|0);
 HEAPF32[$43>>2] = $42;
 $44 = ((($1)) + 88|0);
 $45 = +HEAPF64[$44>>3];
 $46 = $45;
 $47 = ((($0)) + 44|0);
 HEAPF32[$47>>2] = $46;
 $48 = ((($1)) + 96|0);
 $49 = +HEAPF64[$48>>3];
 $50 = $49;
 $51 = ((($0)) + 48|0);
 HEAPF32[$51>>2] = $50;
 $52 = ((($1)) + 104|0);
 $53 = +HEAPF64[$52>>3];
 $54 = $53;
 $55 = ((($0)) + 52|0);
 HEAPF32[$55>>2] = $54;
 $56 = ((($1)) + 112|0);
 $57 = +HEAPF64[$56>>3];
 $58 = $57;
 $59 = ((($0)) + 56|0);
 HEAPF32[$59>>2] = $58;
 $60 = ((($1)) + 120|0);
 $61 = +HEAPF64[$60>>3];
 $62 = $61;
 $63 = ((($0)) + 60|0);
 HEAPF32[$63>>2] = $62;
 return;
}
function __ZN3osg7Matrixf8postMultERKS0_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$043 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0.0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0, $22 = 0.0, $23 = 0.0, $24 = 0.0, $25 = 0.0, $26 = 0, $27 = 0.0;
 var $28 = 0.0, $29 = 0.0, $3 = 0, $30 = 0.0, $31 = 0, $32 = 0.0, $33 = 0.0, $34 = 0.0, $35 = 0.0, $36 = 0.0, $37 = 0.0, $38 = 0.0, $39 = 0.0, $4 = 0, $40 = 0.0, $41 = 0.0, $42 = 0.0, $43 = 0.0, $44 = 0.0, $45 = 0.0;
 var $46 = 0.0, $47 = 0.0, $48 = 0.0, $49 = 0.0, $5 = 0, $50 = 0.0, $51 = 0.0, $52 = 0.0, $53 = 0.0, $54 = 0.0, $55 = 0.0, $56 = 0.0, $57 = 0.0, $58 = 0.0, $59 = 0.0, $6 = 0, $60 = 0.0, $61 = 0.0, $62 = 0.0, $63 = 0.0;
 var $64 = 0.0, $65 = 0.0, $66 = 0.0, $67 = 0.0, $68 = 0.0, $69 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 16|0);
 $3 = ((($1)) + 32|0);
 $4 = ((($1)) + 48|0);
 $5 = ((($1)) + 4|0);
 $6 = ((($1)) + 20|0);
 $7 = ((($1)) + 36|0);
 $8 = ((($1)) + 52|0);
 $9 = ((($1)) + 8|0);
 $10 = ((($1)) + 24|0);
 $11 = ((($1)) + 40|0);
 $12 = ((($1)) + 56|0);
 $13 = ((($1)) + 12|0);
 $14 = ((($1)) + 28|0);
 $15 = ((($1)) + 44|0);
 $16 = ((($1)) + 60|0);
 $$043 = 0;
 while(1) {
  $17 = (($0) + ($$043<<4)|0);
  $18 = +HEAPF32[$17>>2];
  $19 = +HEAPF32[$1>>2];
  $20 = $18 * $19;
  $21 = (((($0) + ($$043<<4)|0)) + 4|0);
  $22 = +HEAPF32[$21>>2];
  $23 = +HEAPF32[$2>>2];
  $24 = $22 * $23;
  $25 = $20 + $24;
  $26 = (((($0) + ($$043<<4)|0)) + 8|0);
  $27 = +HEAPF32[$26>>2];
  $28 = +HEAPF32[$3>>2];
  $29 = $27 * $28;
  $30 = $25 + $29;
  $31 = (((($0) + ($$043<<4)|0)) + 12|0);
  $32 = +HEAPF32[$31>>2];
  $33 = +HEAPF32[$4>>2];
  $34 = $32 * $33;
  $35 = $30 + $34;
  $36 = +HEAPF32[$5>>2];
  $37 = $18 * $36;
  $38 = +HEAPF32[$6>>2];
  $39 = $22 * $38;
  $40 = $37 + $39;
  $41 = +HEAPF32[$7>>2];
  $42 = $27 * $41;
  $43 = $40 + $42;
  $44 = +HEAPF32[$8>>2];
  $45 = $32 * $44;
  $46 = $43 + $45;
  $47 = +HEAPF32[$9>>2];
  $48 = $18 * $47;
  $49 = +HEAPF32[$10>>2];
  $50 = $22 * $49;
  $51 = $48 + $50;
  $52 = +HEAPF32[$11>>2];
  $53 = $27 * $52;
  $54 = $51 + $53;
  $55 = +HEAPF32[$12>>2];
  $56 = $32 * $55;
  $57 = $54 + $56;
  $58 = +HEAPF32[$13>>2];
  $59 = $18 * $58;
  $60 = +HEAPF32[$14>>2];
  $61 = $22 * $60;
  $62 = $59 + $61;
  $63 = +HEAPF32[$15>>2];
  $64 = $27 * $63;
  $65 = $62 + $64;
  $66 = +HEAPF32[$16>>2];
  $67 = $32 * $66;
  $68 = $65 + $67;
  HEAPF32[$17>>2] = $35;
  HEAPF32[$21>>2] = $46;
  HEAPF32[$26>>2] = $57;
  HEAPF32[$31>>2] = $68;
  $69 = (($$043) + 1)|0;
  $exitcond = ($69|0)==(4);
  if ($exitcond) {
   break;
  } else {
   $$043 = $69;
  }
 }
 return;
}
function __ZN3osg4Node21setThreadSafeRefUnrefEb($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg6Object21setThreadSafeRefUnrefEb($0,$1);
 $2 = ((($0)) + 120|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = HEAP32[$3>>2]|0;
  $6 = HEAP32[$5>>2]|0;
  FUNCTION_TABLE_vii[$6 & 8191]($3,$1);
 }
 $7 = ((($0)) + 84|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if (!($9)) {
  $10 = HEAP32[$8>>2]|0;
  $11 = ((($10)) + -12|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($8) + ($12)|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = HEAP32[$14>>2]|0;
  FUNCTION_TABLE_vii[$15 & 8191]($13,$1);
 }
 $16 = ((($0)) + 92|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==(0|0);
 if (!($18)) {
  $19 = HEAP32[$17>>2]|0;
  $20 = ((($19)) + -12|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = (($17) + ($21)|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = HEAP32[$23>>2]|0;
  FUNCTION_TABLE_vii[$24 & 8191]($22,$1);
 }
 $25 = ((($0)) + 100|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($26|0)==(0|0);
 if ($27) {
  return;
 }
 $28 = HEAP32[$26>>2]|0;
 $29 = ((($28)) + -12|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($26) + ($30)|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = HEAP32[$32>>2]|0;
 FUNCTION_TABLE_vii[$33 & 8191]($31,$1);
 return;
}
function __ZN3osg4NodeD2Ev($0) {
 $0 = $0|0;
 var $$0 = 0, $$02 = 0, $$1 = 0, $$13 = 0, $$2 = 0, $$24 = 0, $$3 = 0, $$35 = 0, $$5 = 0, $$57 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i22 = 0, $scevgep5$i$i$i = 0, $scevgep5$i$i$i23 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (62928);
 __THREW__ = 0;
 invoke_vii(3726,($0|0),(0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if ($2) {
   $66 = ___cxa_find_matching_catch_2()|0;
   $67 = tempRet0;
   $68 = ((($0)) + 120|0);
   $69 = HEAP32[$68>>2]|0;
   $70 = ($69|0)==(0|0);
   if (!($70)) {
    $71 = ((($69)) + 8|0);
    $72 = HEAP32[$71>>2]|0;HEAP32[$71>>2] = (($72-1)|0);
    $73 = ($72|0)==(1);
    if ($73) {
     __THREW__ = 0;
     invoke_viii(3262,($69|0),1,1);
     $74 = __THREW__; __THREW__ = 0;
     $75 = $74&1;
     if ($75) {
      $143 = ___cxa_find_matching_catch_3(0|0)|0;
      $144 = tempRet0;
      ___clang_call_terminate($143);
      // unreachable;
     }
    }
   }
   HEAP32[$68>>2] = 0;
   $$0 = $67;$$02 = $66;
   label = 28;
  } else {
   $3 = ((($0)) + 120|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = ($4|0)==(0|0);
   if (!($5)) {
    $6 = ((($4)) + 8|0);
    $7 = HEAP32[$6>>2]|0;HEAP32[$6>>2] = (($7-1)|0);
    $8 = ($7|0)==(1);
    if ($8) {
     __THREW__ = 0;
     invoke_viii(3262,($4|0),1,1);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      $76 = ___cxa_find_matching_catch_2()|0;
      $77 = tempRet0;
      $$0 = $77;$$02 = $76;
      label = 28;
      break;
     }
    }
   }
   HEAP32[$3>>2] = 0;
   $11 = ((($0)) + 100|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = ($12|0)==(0|0);
   if (!($13)) {
    $14 = HEAP32[$12>>2]|0;
    $15 = ((($14)) + -12|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = (($12) + ($16)|0);
    $18 = ((($17)) + 8|0);
    $19 = HEAP32[$18>>2]|0;HEAP32[$18>>2] = (($19-1)|0);
    $20 = ($19|0)==(1);
    if ($20) {
     __THREW__ = 0;
     invoke_viii(3262,($17|0),1,1);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      $78 = ___cxa_find_matching_catch_2()|0;
      $79 = tempRet0;
      $$1 = $79;$$13 = $78;
      label = 33;
      break;
     }
    }
   }
   HEAP32[$11>>2] = 0;
   $23 = ((($0)) + 92|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = ($24|0)==(0|0);
   if (!($25)) {
    $26 = HEAP32[$24>>2]|0;
    $27 = ((($26)) + -12|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = (($24) + ($28)|0);
    $30 = ((($29)) + 8|0);
    $31 = HEAP32[$30>>2]|0;HEAP32[$30>>2] = (($31-1)|0);
    $32 = ($31|0)==(1);
    if ($32) {
     __THREW__ = 0;
     invoke_viii(3262,($29|0),1,1);
     $33 = __THREW__; __THREW__ = 0;
     $34 = $33&1;
     if ($34) {
      $92 = ___cxa_find_matching_catch_2()|0;
      $93 = tempRet0;
      $$2 = $93;$$24 = $92;
      label = 38;
      break;
     }
    }
   }
   HEAP32[$23>>2] = 0;
   $35 = ((($0)) + 84|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = ($36|0)==(0|0);
   if (!($37)) {
    $38 = HEAP32[$36>>2]|0;
    $39 = ((($38)) + -12|0);
    $40 = HEAP32[$39>>2]|0;
    $41 = (($36) + ($40)|0);
    $42 = ((($41)) + 8|0);
    $43 = HEAP32[$42>>2]|0;HEAP32[$42>>2] = (($43-1)|0);
    $44 = ($43|0)==(1);
    if ($44) {
     __THREW__ = 0;
     invoke_viii(3262,($41|0),1,1);
     $45 = __THREW__; __THREW__ = 0;
     $46 = $45&1;
     if ($46) {
      $106 = ___cxa_find_matching_catch_2()|0;
      $107 = tempRet0;
      $$3 = $107;$$35 = $106;
      label = 42;
      break;
     }
    }
   }
   HEAP32[$35>>2] = 0;
   $47 = ((($0)) + 72|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = ($48|0)==(0|0);
   if (!($49)) {
    $50 = ((($0)) + 76|0);
    $51 = HEAP32[$50>>2]|0;
    $52 = ($51|0)==($48|0);
    if (!($52)) {
     $scevgep$i$i$i = ((($51)) + -4|0);
     $53 = $scevgep$i$i$i;
     $54 = $48;
     $55 = (($53) - ($54))|0;
     $56 = $55 >>> 2;
     $57 = $56 ^ -1;
     $scevgep5$i$i$i = (($51) + ($57<<2)|0);
     HEAP32[$50>>2] = $scevgep5$i$i$i;
    }
    __ZdlPv($48);
   }
   $58 = ((($0)) + 48|0);
   $59 = HEAP32[$58>>2]|0;
   $60 = ($59|0)==(0|0);
   if ($60) {
    HEAP32[$58>>2] = 0;
    __ZN3osg6ObjectD2Ev($0);
    return;
   }
   $61 = ((($59)) + 8|0);
   $62 = HEAP32[$61>>2]|0;HEAP32[$61>>2] = (($62-1)|0);
   $63 = ($62|0)==(1);
   if (!($63)) {
    HEAP32[$58>>2] = 0;
    __ZN3osg6ObjectD2Ev($0);
    return;
   }
   __THREW__ = 0;
   invoke_viii(3262,($59|0),1,1);
   $64 = __THREW__; __THREW__ = 0;
   $65 = $64&1;
   if ($65) {
    $131 = ___cxa_find_matching_catch_2()|0;
    $132 = tempRet0;
    $$5 = $132;$$57 = $131;
    break;
   } else {
    HEAP32[$58>>2] = 0;
    __ZN3osg6ObjectD2Ev($0);
    return;
   }
  }
 } while(0);
 if ((label|0) == 28) {
  $80 = ((($0)) + 100|0);
  $81 = HEAP32[$80>>2]|0;
  $82 = ($81|0)==(0|0);
  if (!($82)) {
   $83 = HEAP32[$81>>2]|0;
   $84 = ((($83)) + -12|0);
   $85 = HEAP32[$84>>2]|0;
   $86 = (($81) + ($85)|0);
   $87 = ((($86)) + 8|0);
   $88 = HEAP32[$87>>2]|0;HEAP32[$87>>2] = (($88-1)|0);
   $89 = ($88|0)==(1);
   if ($89) {
    __THREW__ = 0;
    invoke_viii(3262,($86|0),1,1);
    $90 = __THREW__; __THREW__ = 0;
    $91 = $90&1;
    if ($91) {
     $143 = ___cxa_find_matching_catch_3(0|0)|0;
     $144 = tempRet0;
     ___clang_call_terminate($143);
     // unreachable;
    }
   }
  }
  HEAP32[$80>>2] = 0;
  $$1 = $$0;$$13 = $$02;
  label = 33;
 }
 if ((label|0) == 33) {
  $94 = ((($0)) + 92|0);
  $95 = HEAP32[$94>>2]|0;
  $96 = ($95|0)==(0|0);
  if (!($96)) {
   $97 = HEAP32[$95>>2]|0;
   $98 = ((($97)) + -12|0);
   $99 = HEAP32[$98>>2]|0;
   $100 = (($95) + ($99)|0);
   $101 = ((($100)) + 8|0);
   $102 = HEAP32[$101>>2]|0;HEAP32[$101>>2] = (($102-1)|0);
   $103 = ($102|0)==(1);
   if ($103) {
    __THREW__ = 0;
    invoke_viii(3262,($100|0),1,1);
    $104 = __THREW__; __THREW__ = 0;
    $105 = $104&1;
    if ($105) {
     $143 = ___cxa_find_matching_catch_3(0|0)|0;
     $144 = tempRet0;
     ___clang_call_terminate($143);
     // unreachable;
    }
   }
  }
  HEAP32[$94>>2] = 0;
  $$2 = $$1;$$24 = $$13;
  label = 38;
 }
 if ((label|0) == 38) {
  $108 = ((($0)) + 84|0);
  $109 = HEAP32[$108>>2]|0;
  $110 = ($109|0)==(0|0);
  if (!($110)) {
   $111 = HEAP32[$109>>2]|0;
   $112 = ((($111)) + -12|0);
   $113 = HEAP32[$112>>2]|0;
   $114 = (($109) + ($113)|0);
   $115 = ((($114)) + 8|0);
   $116 = HEAP32[$115>>2]|0;HEAP32[$115>>2] = (($116-1)|0);
   $117 = ($116|0)==(1);
   if ($117) {
    __THREW__ = 0;
    invoke_viii(3262,($114|0),1,1);
    $118 = __THREW__; __THREW__ = 0;
    $119 = $118&1;
    if ($119) {
     $143 = ___cxa_find_matching_catch_3(0|0)|0;
     $144 = tempRet0;
     ___clang_call_terminate($143);
     // unreachable;
    }
   }
  }
  HEAP32[$108>>2] = 0;
  $$3 = $$2;$$35 = $$24;
  label = 42;
 }
 if ((label|0) == 42) {
  $120 = ((($0)) + 72|0);
  $121 = HEAP32[$120>>2]|0;
  $122 = ($121|0)==(0|0);
  if (!($122)) {
   $123 = ((($0)) + 76|0);
   $124 = HEAP32[$123>>2]|0;
   $125 = ($124|0)==($121|0);
   if (!($125)) {
    $scevgep$i$i$i22 = ((($124)) + -4|0);
    $126 = $scevgep$i$i$i22;
    $127 = $121;
    $128 = (($126) - ($127))|0;
    $129 = $128 >>> 2;
    $130 = $129 ^ -1;
    $scevgep5$i$i$i23 = (($124) + ($130<<2)|0);
    HEAP32[$123>>2] = $scevgep5$i$i$i23;
   }
   __ZdlPv($121);
  }
  $133 = ((($0)) + 48|0);
  $134 = HEAP32[$133>>2]|0;
  $135 = ($134|0)==(0|0);
  if (!($135)) {
   $136 = ((($134)) + 8|0);
   $137 = HEAP32[$136>>2]|0;HEAP32[$136>>2] = (($137-1)|0);
   $138 = ($137|0)==(1);
   if ($138) {
    __THREW__ = 0;
    invoke_viii(3262,($134|0),1,1);
    $139 = __THREW__; __THREW__ = 0;
    $140 = $139&1;
    if ($140) {
     $143 = ___cxa_find_matching_catch_3(0|0)|0;
     $144 = tempRet0;
     ___clang_call_terminate($143);
     // unreachable;
    }
   }
  }
  HEAP32[$133>>2] = 0;
  $$5 = $$3;$$57 = $$35;
 }
 __THREW__ = 0;
 invoke_vi(388,($0|0));
 $141 = __THREW__; __THREW__ = 0;
 $142 = $141&1;
 if ($142) {
  $143 = ___cxa_find_matching_catch_3(0|0)|0;
  $144 = tempRet0;
  ___clang_call_terminate($143);
  // unreachable;
 } else {
  ___resumeException($$57|0);
  // unreachable;
 }
}
function __ZN3osg4NodeD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(2026,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK3osg4Node9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(124)|0);
 __THREW__ = 0;
 invoke_vii(3435,($1|0),1);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $24 = ___cxa_find_matching_catch_2()|0;
  $25 = tempRet0;
  __ZdlPv($1);
  ___resumeException($24|0);
  // unreachable;
 } else {
  $4 = ((($1)) + 12|0);
  ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;
  $5 = ((($1)) + 24|0);
  HEAP32[$5>>2] = 2;
  $6 = ((($1)) + 28|0);
  HEAP32[$6>>2] = 0;
  HEAP32[$1>>2] = (62928);
  $7 = ((($1)) + 32|0);
  HEAPF32[$7>>2] = 0.0;
  $8 = ((($1)) + 36|0);
  HEAPF32[$8>>2] = 0.0;
  $9 = ((($1)) + 40|0);
  HEAPF32[$9>>2] = 0.0;
  $10 = ((($1)) + 44|0);
  HEAPF32[$10>>2] = -1.0;
  $11 = ((($1)) + 48|0);
  $12 = ((($1)) + 64|0);
  ;HEAP32[$11>>2]=0|0;HEAP32[$11+4>>2]=0|0;HEAP32[$11+8>>2]=0|0;HEAP32[$11+12>>2]=0|0;
  HEAPF32[$12>>2] = -1.0;
  $13 = ((($1)) + 72|0);
  $14 = ((($1)) + 92|0);
  HEAP32[$14>>2] = 0;
  $15 = ((($1)) + 100|0);
  HEAP32[$15>>2] = 0;
  $16 = ((($1)) + 120|0);
  HEAP32[$16>>2] = 0;
  $17 = ((($1)) + 68|0);
  HEAP8[$17>>0] = 0;
  $18 = ((($1)) + 116|0);
  ;HEAP32[$13>>2]=0|0;HEAP32[$13+4>>2]=0|0;HEAP32[$13+8>>2]=0|0;HEAP32[$13+12>>2]=0|0;
  HEAP32[$18>>2] = -1;
  $19 = ((($1)) + 88|0);
  HEAP32[$19>>2] = 0;
  $20 = ((($1)) + 96|0);
  HEAP32[$20>>2] = 0;
  $21 = ((($1)) + 104|0);
  HEAP8[$21>>0] = 1;
  $22 = ((($1)) + 108|0);
  HEAP32[$22>>2] = 0;
  $23 = ((($1)) + 112|0);
  HEAP32[$23>>2] = 0;
  return ($1|0);
 }
 return (0)|0;
}
function __ZNK3osg4Node5cloneERKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(124)|0);
 __THREW__ = 0;
 invoke_viii(3830,($2|0),($0|0),($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch_2()|0;
  $6 = tempRet0;
  __ZdlPv($2);
  ___resumeException($5|0);
  // unreachable;
 } else {
  return ($2|0);
 }
 return (0)|0;
}
function __ZNK3osg4Node12isSameKindAsEPKNS_6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,25952,0)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK3osg4Node11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175113|0);
}
function __ZNK3osg4Node9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (145243|0);
}
function __ZN3osg4Node21resizeGLObjectBuffersEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 120|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = HEAP32[$3>>2]|0;
  $6 = ((($5)) + 132|0);
  $7 = HEAP32[$6>>2]|0;
  FUNCTION_TABLE_vii[$7 & 8191]($3,$1);
 }
 $8 = ((($0)) + 84|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if (!($10)) {
  $11 = HEAP32[$9>>2]|0;
  $12 = ((($11)) + -12|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($9) + ($13)|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = ((($15)) + 132|0);
  $17 = HEAP32[$16>>2]|0;
  FUNCTION_TABLE_vii[$17 & 8191]($14,$1);
 }
 $18 = ((($0)) + 92|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)==(0|0);
 if (!($20)) {
  $21 = HEAP32[$19>>2]|0;
  $22 = ((($21)) + -12|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (($19) + ($23)|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = ((($25)) + 132|0);
  $27 = HEAP32[$26>>2]|0;
  FUNCTION_TABLE_vii[$27 & 8191]($24,$1);
 }
 $28 = ((($0)) + 100|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ($29|0)==(0|0);
 if ($30) {
  return;
 }
 $31 = HEAP32[$29>>2]|0;
 $32 = ((($31)) + -12|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = (($29) + ($33)|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = ((($35)) + 132|0);
 $37 = HEAP32[$36>>2]|0;
 FUNCTION_TABLE_vii[$37 & 8191]($34,$1);
 return;
}
function __ZNK3osg4Node16releaseGLObjectsEPNS_5StateE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 120|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = HEAP32[$3>>2]|0;
  $6 = ((($5)) + 136|0);
  $7 = HEAP32[$6>>2]|0;
  FUNCTION_TABLE_vii[$7 & 8191]($3,$1);
 }
 $8 = ((($0)) + 84|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if (!($10)) {
  $11 = HEAP32[$9>>2]|0;
  $12 = ((($11)) + -12|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($9) + ($13)|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = ((($15)) + 136|0);
  $17 = HEAP32[$16>>2]|0;
  FUNCTION_TABLE_vii[$17 & 8191]($14,$1);
 }
 $18 = ((($0)) + 92|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)==(0|0);
 if (!($20)) {
  $21 = HEAP32[$19>>2]|0;
  $22 = ((($21)) + -12|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (($19) + ($23)|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = ((($25)) + 136|0);
  $27 = HEAP32[$26>>2]|0;
  FUNCTION_TABLE_vii[$27 & 8191]($24,$1);
 }
 $28 = ((($0)) + 100|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ($29|0)==(0|0);
 if ($30) {
  return;
 }
 $31 = HEAP32[$29>>2]|0;
 $32 = ((($31)) + -12|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = (($29) + ($33)|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = ((($35)) + 136|0);
 $37 = HEAP32[$36>>2]|0;
 FUNCTION_TABLE_vii[$37 & 8191]($34,$1);
 return;
}
function __ZN3osg4Node6acceptERNS_11NodeVisitorE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$byval_copy = 0, $$pre$i$i = 0, $$sink$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i = 0, $scevgep5$i$i$i$i = 0, $scevgep5$i$i$i$sink$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy = sp + 8|0;
 $2 = sp + 4|0;
 $3 = sp;
 $4 = ((($1)) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($1)) + 24|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($0)) + 116|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $9 | $7;
 $11 = $10 & $5;
 $12 = ($11|0)==(0);
 if ($12) {
  STACKTOP = sp;return;
 }
 HEAP32[$2>>2] = $0;
 $13 = ((($1)) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(1);
 $16 = ((($1)) + 28|0);
 $17 = $0;
 do {
  if ($15) {
   $25 = HEAP32[$16>>2]|0;
   HEAP32[$3>>2] = $25;
   ;HEAP32[$$byval_copy>>2]=HEAP32[$3>>2]|0;
   (__ZNSt3__26vectorIPN3osg4NodeENS_9allocatorIS3_EEE6insertENS_11__wrap_iterIPKS3_EERS8_($16,$$byval_copy,$2)|0);
  } else {
   $18 = ((($1)) + 32|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ((($1)) + 36|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = ($19|0)==($21|0);
   if ($22) {
    __ZNSt3__26vectorIPN3osg4NodeENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_($16,$2);
    break;
   } else {
    HEAP32[$19>>2] = $17;
    $23 = HEAP32[$18>>2]|0;
    $24 = ((($23)) + 4|0);
    HEAP32[$18>>2] = $24;
    break;
   }
  }
 } while(0);
 $26 = HEAP32[$1>>2]|0;
 $27 = ((($26)) + 108|0);
 $28 = HEAP32[$27>>2]|0;
 FUNCTION_TABLE_vii[$28 & 8191]($1,$0);
 $29 = HEAP32[$13>>2]|0;
 $30 = ($29|0)==(1);
 do {
  if ($30) {
   $34 = ((($1)) + 28|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ((($35)) + 4|0);
   $37 = ((($1)) + 32|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = $36;
   $40 = (($38) - ($39))|0;
   $41 = $40 >> 2;
   $42 = ($41|0)==(0);
   $43 = $38;
   if ($42) {
    $45 = $43;
   } else {
    _memmove(($35|0),($36|0),($40|0))|0;
    $$pre$i$i = HEAP32[$37>>2]|0;
    $45 = $$pre$i$i;
   }
   $44 = (($35) + ($41<<2)|0);
   $46 = ($45|0)==($44|0);
   if ($46) {
    STACKTOP = sp;return;
   } else {
    $scevgep$i$i$i$i = ((($45)) + -4|0);
    $47 = $scevgep$i$i$i$i;
    $48 = $44;
    $49 = (($47) - ($48))|0;
    $50 = $49 >>> 2;
    $51 = $50 ^ -1;
    $scevgep5$i$i$i$i = (($45) + ($51<<2)|0);
    $$sink$i = $37;$scevgep5$i$i$i$sink$i = $scevgep5$i$i$i$i;
    break;
   }
  } else {
   $31 = ((($1)) + 32|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ((($32)) + -4|0);
   $$sink$i = $31;$scevgep5$i$i$i$sink$i = $33;
  }
 } while(0);
 HEAP32[$$sink$i>>2] = $scevgep5$i$i$i$sink$i;
 STACKTOP = sp;return;
}
function __ZN3osg4Node6ascendERNS_11NodeVisitorE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 72|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 76|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if ($6) {
  return;
 } else {
  $8 = $3;
 }
 while(1) {
  $7 = HEAP32[$8>>2]|0;
  $9 = HEAP32[$7>>2]|0;
  $10 = ((($9)) + 188|0);
  $11 = HEAP32[$10>>2]|0;
  FUNCTION_TABLE_vii[$11 & 8191]($7,$1);
  $12 = ((($8)) + 4|0);
  $13 = ($12|0)==($5|0);
  if ($13) {
   break;
  } else {
   $8 = $12;
  }
 }
 return;
}
function __ZNK3osg4Node12computeBoundEv($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF32[$0>>2] = 0.0;
 $2 = ((($0)) + 4|0);
 HEAPF32[$2>>2] = 0.0;
 $3 = ((($0)) + 8|0);
 HEAPF32[$3>>2] = 0.0;
 $4 = ((($0)) + 12|0);
 HEAPF32[$4>>2] = -1.0;
 return;
}
function __ZN3osg4NodeC2ERKS0_RKNS_6CopyOpE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$015 = 0, $$1 = 0, $$116 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $scevgep$i$i$i = 0, $scevgep5$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg6ObjectC2ERKS0_RKNS_6CopyOpE($0,$1,$2);
 HEAP32[$0>>2] = (62928);
 $3 = ((($0)) + 32|0);
 $4 = ((($1)) + 32|0);
 ;HEAP32[$3>>2]=HEAP32[$4>>2]|0;HEAP32[$3+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$4+8>>2]|0;
 $5 = ((($0)) + 44|0);
 $6 = ((($1)) + 44|0);
 $7 = HEAP32[$6>>2]|0;
 HEAP32[$5>>2] = $7;
 $8 = ((($0)) + 48|0);
 HEAP32[$8>>2] = 0;
 $9 = ((($0)) + 52|0);
 $10 = ((($1)) + 52|0);
 ;HEAP32[$9>>2]=HEAP32[$10>>2]|0;HEAP32[$9+4>>2]=HEAP32[$10+4>>2]|0;HEAP32[$9+8>>2]=HEAP32[$10+8>>2]|0;
 $11 = ((($0)) + 64|0);
 $12 = ((($1)) + 64|0);
 $13 = HEAP32[$12>>2]|0;
 HEAP32[$11>>2] = $13;
 $14 = ((($0)) + 68|0);
 $15 = ((($1)) + 68|0);
 $16 = HEAP8[$15>>0]|0;
 HEAP8[$14>>0] = $16;
 $17 = ((($0)) + 72|0);
 HEAP32[$17>>2] = 0;
 $18 = ((($0)) + 76|0);
 HEAP32[$18>>2] = 0;
 $19 = ((($0)) + 80|0);
 HEAP32[$19>>2] = 0;
 $20 = HEAP32[$2>>2]|0;
 $21 = ((($20)) + 56|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ((($1)) + 84|0);
 $24 = HEAP32[$23>>2]|0;
 __THREW__ = 0;
 $25 = (invoke_iii($22|0,($2|0),($24|0))|0);
 $26 = __THREW__; __THREW__ = 0;
 $27 = $26&1;
 if ($27) {
  $74 = ___cxa_find_matching_catch_2()|0;
  $75 = tempRet0;
  $$1 = $75;$$116 = $74;
 } else {
  $28 = ((($0)) + 84|0);
  HEAP32[$28>>2] = $25;
  $29 = ($25|0)==(0|0);
  if (!($29)) {
   $30 = HEAP32[$25>>2]|0;
   $31 = ((($30)) + -12|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = (($25) + ($32)|0);
   $34 = ((($33)) + 8|0);
   $35 = HEAP32[$34>>2]|0;HEAP32[$34>>2] = (($35+1)|0);
  }
  $36 = ((($0)) + 88|0);
  HEAP32[$36>>2] = 0;
  $37 = ((($0)) + 92|0);
  HEAP32[$37>>2] = 0;
  $38 = ((($0)) + 96|0);
  HEAP32[$38>>2] = 0;
  $39 = HEAP32[$2>>2]|0;
  $40 = ((($39)) + 56|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = ((($1)) + 100|0);
  $43 = HEAP32[$42>>2]|0;
  __THREW__ = 0;
  $44 = (invoke_iii($41|0,($2|0),($43|0))|0);
  $45 = __THREW__; __THREW__ = 0;
  $46 = $45&1;
  if ($46) {
   $76 = ___cxa_find_matching_catch_2()|0;
   $77 = tempRet0;
   $$0 = $77;$$015 = $76;
  } else {
   $47 = ((($0)) + 100|0);
   HEAP32[$47>>2] = $44;
   $48 = ($44|0)==(0|0);
   if (!($48)) {
    $49 = HEAP32[$44>>2]|0;
    $50 = ((($49)) + -12|0);
    $51 = HEAP32[$50>>2]|0;
    $52 = (($44) + ($51)|0);
    $53 = ((($52)) + 8|0);
    $54 = HEAP32[$53>>2]|0;HEAP32[$53>>2] = (($54+1)|0);
   }
   $55 = ((($0)) + 104|0);
   $56 = ((($1)) + 104|0);
   $57 = HEAP8[$56>>0]|0;
   HEAP8[$55>>0] = $57;
   $58 = ((($0)) + 108|0);
   HEAP32[$58>>2] = 0;
   $59 = ((($0)) + 112|0);
   HEAP32[$59>>2] = 0;
   $60 = ((($0)) + 116|0);
   $61 = ((($1)) + 116|0);
   $62 = HEAP32[$61>>2]|0;
   HEAP32[$60>>2] = $62;
   $63 = ((($0)) + 120|0);
   HEAP32[$63>>2] = 0;
   $64 = HEAP32[$2>>2]|0;
   $65 = ((($64)) + 24|0);
   $66 = HEAP32[$65>>2]|0;
   $67 = ((($1)) + 120|0);
   $68 = HEAP32[$67>>2]|0;
   __THREW__ = 0;
   $69 = (invoke_iii($66|0,($2|0),($68|0))|0);
   $70 = __THREW__; __THREW__ = 0;
   $71 = $70&1;
   if (!($71)) {
    __THREW__ = 0;
    invoke_vii(3726,($0|0),($69|0));
    $72 = __THREW__; __THREW__ = 0;
    $73 = $72&1;
    if (!($73)) {
     return;
    }
   }
   $78 = ___cxa_find_matching_catch_2()|0;
   $79 = tempRet0;
   $80 = HEAP32[$63>>2]|0;
   $81 = ($80|0)==(0|0);
   if (!($81)) {
    $82 = ((($80)) + 8|0);
    $83 = HEAP32[$82>>2]|0;HEAP32[$82>>2] = (($83-1)|0);
    $84 = ($83|0)==(1);
    if ($84) {
     __THREW__ = 0;
     invoke_viii(3262,($80|0),1,1);
     $85 = __THREW__; __THREW__ = 0;
     $86 = $85&1;
     if ($86) {
      $138 = ___cxa_find_matching_catch_3(0|0)|0;
      $139 = tempRet0;
      ___clang_call_terminate($138);
      // unreachable;
     }
    }
   }
   HEAP32[$63>>2] = 0;
   $87 = HEAP32[$47>>2]|0;
   $88 = ($87|0)==(0|0);
   if (!($88)) {
    $89 = HEAP32[$87>>2]|0;
    $90 = ((($89)) + -12|0);
    $91 = HEAP32[$90>>2]|0;
    $92 = (($87) + ($91)|0);
    $93 = ((($92)) + 8|0);
    $94 = HEAP32[$93>>2]|0;HEAP32[$93>>2] = (($94-1)|0);
    $95 = ($94|0)==(1);
    if ($95) {
     __THREW__ = 0;
     invoke_viii(3262,($92|0),1,1);
     $96 = __THREW__; __THREW__ = 0;
     $97 = $96&1;
     if ($97) {
      $138 = ___cxa_find_matching_catch_3(0|0)|0;
      $139 = tempRet0;
      ___clang_call_terminate($138);
      // unreachable;
     }
    }
   }
   HEAP32[$47>>2] = 0;
   $$0 = $79;$$015 = $78;
  }
  $98 = HEAP32[$37>>2]|0;
  $99 = ($98|0)==(0|0);
  if (!($99)) {
   $100 = HEAP32[$98>>2]|0;
   $101 = ((($100)) + -12|0);
   $102 = HEAP32[$101>>2]|0;
   $103 = (($98) + ($102)|0);
   $104 = ((($103)) + 8|0);
   $105 = HEAP32[$104>>2]|0;HEAP32[$104>>2] = (($105-1)|0);
   $106 = ($105|0)==(1);
   if ($106) {
    __THREW__ = 0;
    invoke_viii(3262,($103|0),1,1);
    $107 = __THREW__; __THREW__ = 0;
    $108 = $107&1;
    if ($108) {
     $138 = ___cxa_find_matching_catch_3(0|0)|0;
     $139 = tempRet0;
     ___clang_call_terminate($138);
     // unreachable;
    }
   }
  }
  HEAP32[$37>>2] = 0;
  $109 = HEAP32[$28>>2]|0;
  $110 = ($109|0)==(0|0);
  if (!($110)) {
   $111 = HEAP32[$109>>2]|0;
   $112 = ((($111)) + -12|0);
   $113 = HEAP32[$112>>2]|0;
   $114 = (($109) + ($113)|0);
   $115 = ((($114)) + 8|0);
   $116 = HEAP32[$115>>2]|0;HEAP32[$115>>2] = (($116-1)|0);
   $117 = ($116|0)==(1);
   if ($117) {
    __THREW__ = 0;
    invoke_viii(3262,($114|0),1,1);
    $118 = __THREW__; __THREW__ = 0;
    $119 = $118&1;
    if ($119) {
     $138 = ___cxa_find_matching_catch_3(0|0)|0;
     $139 = tempRet0;
     ___clang_call_terminate($138);
     // unreachable;
    }
   }
  }
  HEAP32[$28>>2] = 0;
  $$1 = $$0;$$116 = $$015;
 }
 $120 = HEAP32[$17>>2]|0;
 $121 = ($120|0)==(0|0);
 if (!($121)) {
  $122 = HEAP32[$18>>2]|0;
  $123 = ($122|0)==($120|0);
  if (!($123)) {
   $scevgep$i$i$i = ((($122)) + -4|0);
   $124 = $scevgep$i$i$i;
   $125 = $120;
   $126 = (($124) - ($125))|0;
   $127 = $126 >>> 2;
   $128 = $127 ^ -1;
   $scevgep5$i$i$i = (($122) + ($128<<2)|0);
   HEAP32[$18>>2] = $scevgep5$i$i$i;
  }
  __ZdlPv($120);
 }
 $129 = HEAP32[$8>>2]|0;
 $130 = ($129|0)==(0|0);
 if (!($130)) {
  $131 = ((($129)) + 8|0);
  $132 = HEAP32[$131>>2]|0;HEAP32[$131>>2] = (($132-1)|0);
  $133 = ($132|0)==(1);
  if ($133) {
   __THREW__ = 0;
   invoke_viii(3262,($129|0),1,1);
   $134 = __THREW__; __THREW__ = 0;
   $135 = $134&1;
   if ($135) {
    $138 = ___cxa_find_matching_catch_3(0|0)|0;
    $139 = tempRet0;
    ___clang_call_terminate($138);
    // unreachable;
   }
  }
 }
 HEAP32[$8>>2] = 0;
 __THREW__ = 0;
 invoke_vi(388,($0|0));
 $136 = __THREW__; __THREW__ = 0;
 $137 = $136&1;
 if ($137) {
  $138 = ___cxa_find_matching_catch_3(0|0)|0;
  $139 = tempRet0;
  ___clang_call_terminate($138);
  // unreachable;
 } else {
  ___resumeException($$116|0);
  // unreachable;
 }
}
function __ZN3osg4Node11setStateSetEPNS_8StateSetE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$1 = 0, $$114 = 0, $$3 = 0, $$pr = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 120|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==($1|0);
 if ($4) {
  return;
 }
 $5 = ($3|0)==(0|0);
 do {
  if ($5) {
   $$0 = 0;$$114 = 0;$19 = 0;
  } else {
   __ZN3osg8StateSet12removeParentEPNS_4NodeE($3,$0);
   $6 = HEAP32[$2>>2]|0;
   $7 = ((($6)) + 144|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ($8|0)==(0|0);
   if ($9) {
    $10 = ((($6)) + 148|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)==(0);
    if ($12) {
     $53 = 0;
    } else {
     label = 5;
    }
   } else {
    label = 5;
   }
   if ((label|0) == 5) {
    $53 = -1;
   }
   $13 = ((($6)) + 152|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = ($14|0)==(0|0);
   if ($15) {
    $16 = ((($6)) + 156|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = ($17|0)==(0);
    if ($18) {
     $$0 = 0;$$114 = $53;$19 = $6;
     break;
    }
   }
   $$0 = -1;$$114 = $53;$19 = $6;
  }
 } while(0);
 $20 = ($19|0)==($1|0);
 if ($20) {
  $28 = $1;
 } else {
  HEAP32[$2>>2] = $1;
  $21 = ($1|0)==(0|0);
  if (!($21)) {
   $22 = ((($1)) + 8|0);
   $23 = HEAP32[$22>>2]|0;HEAP32[$22>>2] = (($23+1)|0);
  }
  $24 = ($19|0)==(0|0);
  if (!($24)) {
   $25 = ((($19)) + 8|0);
   $26 = HEAP32[$25>>2]|0;HEAP32[$25>>2] = (($26-1)|0);
   $27 = ($26|0)==(1);
   if ($27) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($19,1,1);
   }
  }
  $$pr = HEAP32[$2>>2]|0;
  $28 = $$pr;
 }
 $29 = ($28|0)==(0|0);
 do {
  if ($29) {
   $$1 = $$0;$$3 = $$114;
  } else {
   __ZN3osg8StateSet9addParentEPNS_4NodeE($28,$0);
   $30 = HEAP32[$2>>2]|0;
   $31 = ((($30)) + 144|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ($32|0)==(0|0);
   if ($33) {
    $34 = ((($30)) + 148|0);
    $35 = HEAP32[$34>>2]|0;
    $36 = ($35|0)==(0);
    if ($36) {
     $54 = $$114;
    } else {
     label = 19;
    }
   } else {
    label = 19;
   }
   if ((label|0) == 19) {
    $37 = (($$114) + 1)|0;
    $54 = $37;
   }
   $38 = ((($30)) + 152|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = ($39|0)==(0|0);
   if ($40) {
    $41 = ((($30)) + 156|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = ($42|0)==(0);
    if ($43) {
     $$1 = $$0;$$3 = $54;
     break;
    }
   }
   $44 = (($$0) + 1)|0;
   $$1 = $44;$$3 = $54;
  }
 } while(0);
 $45 = ($$3|0)==(0);
 if (!($45)) {
  $46 = ((($0)) + 88|0);
  $47 = HEAP32[$46>>2]|0;
  $48 = (($47) + ($$3))|0;
  __ZN3osg4Node38setNumChildrenRequiringUpdateTraversalEj($0,$48);
 }
 $49 = ($$1|0)==(0);
 if ($49) {
  return;
 }
 $50 = ((($0)) + 96|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = (($51) + ($$1))|0;
 __ZN3osg4Node37setNumChildrenRequiringEventTraversalEj($0,$52);
 return;
}
function __ZN3osg4Node38setNumChildrenRequiringUpdateTraversalEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$ = 0, $$1 = 0, $$sroa$09$015 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $not$ = 0, $not$14 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 88|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==($1|0);
 if ($4) {
  return;
 }
 $5 = ((($0)) + 84|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $8 = ((($0)) + 72|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ((($0)) + 76|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($9|0)==($11|0);
  if (!($12)) {
   $not$ = ($3|0)!=(0);
   $$ = $not$ << 31 >> 31;
   $not$14 = ($1|0)!=(0);
   $13 = $not$14&1;
   $$1 = (($$) + ($13))|0;
   $14 = ($$1|0)==(0);
   if (!($14)) {
    $$sroa$09$015 = $9;
    while(1) {
     $15 = HEAP32[$$sroa$09$015>>2]|0;
     $16 = ((($15)) + 88|0);
     $17 = HEAP32[$16>>2]|0;
     $18 = (($17) + ($$1))|0;
     __ZN3osg4Node38setNumChildrenRequiringUpdateTraversalEj($15,$18);
     $19 = ((($$sroa$09$015)) + 4|0);
     $20 = HEAP32[$10>>2]|0;
     $21 = ($19|0)==($20|0);
     if ($21) {
      break;
     } else {
      $$sroa$09$015 = $19;
     }
    }
   }
  }
 }
 HEAP32[$2>>2] = $1;
 return;
}
function __ZN3osg4Node37setNumChildrenRequiringEventTraversalEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$ = 0, $$1 = 0, $$sroa$09$015 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $not$ = 0, $not$14 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 96|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==($1|0);
 if ($4) {
  return;
 }
 $5 = ((($0)) + 92|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $8 = ((($0)) + 72|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ((($0)) + 76|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($9|0)==($11|0);
  if (!($12)) {
   $not$ = ($3|0)!=(0);
   $$ = $not$ << 31 >> 31;
   $not$14 = ($1|0)!=(0);
   $13 = $not$14&1;
   $$1 = (($$) + ($13))|0;
   $14 = ($$1|0)==(0);
   if (!($14)) {
    $$sroa$09$015 = $9;
    while(1) {
     $15 = HEAP32[$$sroa$09$015>>2]|0;
     $16 = ((($15)) + 96|0);
     $17 = HEAP32[$16>>2]|0;
     $18 = (($17) + ($$1))|0;
     __ZN3osg4Node37setNumChildrenRequiringEventTraversalEj($15,$18);
     $19 = ((($$sroa$09$015)) + 4|0);
     $20 = HEAP32[$10>>2]|0;
     $21 = ($19|0)==($20|0);
     if ($21) {
      break;
     } else {
      $$sroa$09$015 = $19;
     }
    }
   }
  }
 }
 HEAP32[$2>>2] = $1;
 return;
}
function __GLOBAL__sub_I_Node_cpp() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF32[52105] = 1.0;
 HEAPF32[(208424)>>2] = 0.0;
 HEAPF32[(208428)>>2] = 0.0;
 HEAPF32[52108] = 0.0;
 HEAPF32[(208436)>>2] = 1.0;
 HEAPF32[(208440)>>2] = 0.0;
 HEAPF32[52111] = 0.0;
 HEAPF32[(208448)>>2] = 0.0;
 HEAPF32[(208452)>>2] = 1.0;
 __ZN11OpenThreads5MutexC2ENS0_9MutexTypeE(208456,0);
 (___cxa_atexit((707|0),(208456|0),(___dso_handle|0))|0);
 return;
}
function __ZN3osg4NodeC2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg10ReferencedC2Eb($0,1);
 $1 = ((($0)) + 12|0);
 ;HEAP32[$1>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;
 $2 = ((($0)) + 24|0);
 HEAP32[$2>>2] = 2;
 $3 = ((($0)) + 28|0);
 HEAP32[$3>>2] = 0;
 HEAP32[$0>>2] = (62928);
 $4 = ((($0)) + 32|0);
 HEAPF32[$4>>2] = 0.0;
 $5 = ((($0)) + 36|0);
 HEAPF32[$5>>2] = 0.0;
 $6 = ((($0)) + 40|0);
 HEAPF32[$6>>2] = 0.0;
 $7 = ((($0)) + 44|0);
 HEAPF32[$7>>2] = -1.0;
 $8 = ((($0)) + 48|0);
 $9 = ((($0)) + 64|0);
 ;HEAP32[$8>>2]=0|0;HEAP32[$8+4>>2]=0|0;HEAP32[$8+8>>2]=0|0;HEAP32[$8+12>>2]=0|0;
 HEAPF32[$9>>2] = -1.0;
 $10 = ((($0)) + 72|0);
 $11 = ((($0)) + 92|0);
 HEAP32[$11>>2] = 0;
 $12 = ((($0)) + 100|0);
 HEAP32[$12>>2] = 0;
 $13 = ((($0)) + 120|0);
 HEAP32[$13>>2] = 0;
 $14 = ((($0)) + 68|0);
 HEAP8[$14>>0] = 0;
 $15 = ((($0)) + 116|0);
 ;HEAP32[$10>>2]=0|0;HEAP32[$10+4>>2]=0|0;HEAP32[$10+8>>2]=0|0;HEAP32[$10+12>>2]=0|0;
 HEAP32[$15>>2] = -1;
 $16 = ((($0)) + 88|0);
 HEAP32[$16>>2] = 0;
 $17 = ((($0)) + 96|0);
 HEAP32[$17>>2] = 0;
 $18 = ((($0)) + 104|0);
 HEAP8[$18>>0] = 1;
 $19 = ((($0)) + 108|0);
 HEAP32[$19>>2] = 0;
 $20 = ((($0)) + 112|0);
 HEAP32[$20>>2] = 0;
 return;
}
function __ZN3osg4Node9addParentEPNS_5GroupE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 HEAP32[$2>>2] = $1;
 $3 = (__ZN3osg10Referenced24getGlobalReferencedMutexEv()|0);
 $4 = ($3|0)==(0|0);
 $5 = $1;
 if (!($4)) {
  $6 = HEAP32[$3>>2]|0;
  $7 = ((($6)) + 8|0);
  $8 = HEAP32[$7>>2]|0;
  (FUNCTION_TABLE_ii[$8 & 8191]($3)|0);
 }
 $9 = ((($0)) + 76|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ((($0)) + 80|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($10|0)==($12|0);
 if ($13) {
  $16 = ((($0)) + 72|0);
  __THREW__ = 0;
  invoke_vii(3831,($16|0),($2|0));
  $17 = __THREW__; __THREW__ = 0;
  $18 = $17&1;
  if ($18) {
   $22 = ___cxa_find_matching_catch_2()|0;
   $23 = tempRet0;
   if ($4) {
    ___resumeException($22|0);
    // unreachable;
   }
   $24 = HEAP32[$3>>2]|0;
   $25 = ((($24)) + 12|0);
   $26 = HEAP32[$25>>2]|0;
   __THREW__ = 0;
   (invoke_ii($26|0,($3|0))|0);
   $27 = __THREW__; __THREW__ = 0;
   $28 = $27&1;
   if ($28) {
    $29 = ___cxa_find_matching_catch_3(0|0)|0;
    $30 = tempRet0;
    ___clang_call_terminate($29);
    // unreachable;
   } else {
    ___resumeException($22|0);
    // unreachable;
   }
  }
 } else {
  HEAP32[$10>>2] = $5;
  $14 = HEAP32[$9>>2]|0;
  $15 = ((($14)) + 4|0);
  HEAP32[$9>>2] = $15;
 }
 if ($4) {
  STACKTOP = sp;return;
 }
 $19 = HEAP32[$3>>2]|0;
 $20 = ((($19)) + 12|0);
 $21 = HEAP32[$20>>2]|0;
 (FUNCTION_TABLE_ii[$21 & 8191]($3)|0);
 STACKTOP = sp;return;
}
function __ZNSt3__26vectorIPN3osg5GroupENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(1073741823);
 if ($8) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $9 = ((($0)) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) - ($4))|0;
 $12 = $11 >> 2;
 $13 = ($12>>>0)<(536870911);
 $14 = $11 >> 1;
 $15 = ($14>>>0)<($7>>>0);
 $$sroa$speculated$i = $15 ? $7 : $14;
 $$sroa$speculated$$i = $13 ? $$sroa$speculated$i : 1073741823;
 $16 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($16) {
   $26 = 0;
  } else {
   $17 = ($$sroa$speculated$$i>>>0)>(1073741823);
   if (!($17)) {
    $23 = $$sroa$speculated$$i << 2;
    $24 = (__Znwj($23)|0);
    $26 = $24;
    break;
   }
   $18 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($18|0),(204840|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if ($20) {
    $21 = ___cxa_find_matching_catch_2()|0;
    $22 = tempRet0;
    ___cxa_free_exception(($18|0));
    ___resumeException($21|0);
    // unreachable;
   } else {
    HEAP32[$18>>2] = (99824);
    ___cxa_throw(($18|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $25 = (($26) + ($6<<2)|0);
 $27 = (($26) + ($$sroa$speculated$$i<<2)|0);
 $28 = $27;
 $29 = HEAP32[$1>>2]|0;
 HEAP32[$25>>2] = $29;
 $30 = ((($25)) + 4|0);
 $31 = $30;
 $32 = (0 - ($6))|0;
 $33 = (($25) + ($32<<2)|0);
 $34 = $33;
 $35 = ($5|0)>(0);
 if ($35) {
  $36 = $4;
  _memcpy(($33|0),($36|0),($5|0))|0;
 }
 HEAP32[$0>>2] = $34;
 HEAP32[$2>>2] = $31;
 HEAP32[$9>>2] = $28;
 $37 = ($4|0)==(0);
 if ($37) {
  return;
 }
 $38 = $4;
 __ZdlPv($38);
 return;
}
function __ZN3osg4Node12removeParentEPNS_5GroupE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$pre$i = 0, $$sroa$0$0$copyload$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i = 0, $scevgep5$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__ZN3osg10Referenced24getGlobalReferencedMutexEv()|0);
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = HEAP32[$2>>2]|0;
  $5 = ((($4)) + 8|0);
  $6 = HEAP32[$5>>2]|0;
  (FUNCTION_TABLE_ii[$6 & 8191]($2)|0);
 }
 $7 = ((($0)) + 72|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($0)) + 76|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8|0)==($10|0);
 $12 = $10;
 L4: do {
  if ($11) {
   $$sroa$0$0$copyload$i = $8;
   label = 6;
  } else {
   $14 = $8;
   while(1) {
    $13 = HEAP32[$14>>2]|0;
    $15 = ($13|0)==($1|0);
    if ($15) {
     $$sroa$0$0$copyload$i = $14;
     label = 6;
     break L4;
    }
    $16 = ((($14)) + 4|0);
    $17 = ($16|0)==($10|0);
    if ($17) {
     break;
    } else {
     $14 = $16;
    }
   }
  }
 } while(0);
 if ((label|0) == 6) {
  $18 = ($$sroa$0$0$copyload$i|0)==($10|0);
  if (!($18)) {
   $19 = ((($$sroa$0$0$copyload$i)) + 4|0);
   $20 = $19;
   $21 = (($12) - ($20))|0;
   $22 = $21 >> 2;
   $23 = ($22|0)==(0);
   if ($23) {
    $25 = $10;
   } else {
    _memmove(($$sroa$0$0$copyload$i|0),($19|0),($21|0))|0;
    $$pre$i = HEAP32[$9>>2]|0;
    $25 = $$pre$i;
   }
   $24 = (($$sroa$0$0$copyload$i) + ($22<<2)|0);
   $26 = ($25|0)==($24|0);
   if (!($26)) {
    $scevgep$i$i$i = ((($25)) + -4|0);
    $27 = $scevgep$i$i$i;
    $28 = $24;
    $29 = (($27) - ($28))|0;
    $30 = $29 >>> 2;
    $31 = $30 ^ -1;
    $scevgep5$i$i$i = (($25) + ($31<<2)|0);
    HEAP32[$9>>2] = $scevgep5$i$i$i;
   }
  }
 }
 if ($3) {
  return;
 }
 $32 = HEAP32[$2>>2]|0;
 $33 = ((($32)) + 12|0);
 $34 = HEAP32[$33>>2]|0;
 (FUNCTION_TABLE_ii[$34 & 8191]($2)|0);
 return;
}
function __ZN3osg4Node19getOrCreateStateSetEv($0) {
 $0 = $0|0;
 var $$pre = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 120|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $9 = $2;
  return ($9|0);
 }
 $4 = (__Znwj(160)|0);
 __THREW__ = 0;
 invoke_vi(3572,($4|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $7 = ___cxa_find_matching_catch_2()|0;
  $8 = tempRet0;
  __ZdlPv($4);
  ___resumeException($7|0);
  // unreachable;
 }
 __ZN3osg4Node11setStateSetEPNS_8StateSetE($0,$4);
 $$pre = HEAP32[$1>>2]|0;
 $9 = $$pre;
 return ($9|0);
}
function __ZN3osg4Node17setUpdateCallbackEPNS_8CallbackE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$ = 0, $$1 = 0, $$pre = 0, $$sroa$09$014 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $not$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 84|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==($1|0);
 if ($4) {
  return;
 }
 $5 = ((($0)) + 88|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  $8 = ((($0)) + 72|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ((($0)) + 76|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($9|0)==($11|0);
  if ($12) {
   $23 = $3;
  } else {
   $13 = ($3|0)!=(0|0);
   $$ = $13 << 31 >> 31;
   $not$ = ($1|0)!=(0|0);
   $14 = $not$&1;
   $$1 = (($$) + ($14))|0;
   $15 = ($$1|0)==(0);
   if ($15) {
    $23 = $3;
   } else {
    $$sroa$09$014 = $9;
    while(1) {
     $16 = HEAP32[$$sroa$09$014>>2]|0;
     $17 = ((($16)) + 88|0);
     $18 = HEAP32[$17>>2]|0;
     $19 = (($18) + ($$1))|0;
     __ZN3osg4Node38setNumChildrenRequiringUpdateTraversalEj($16,$19);
     $20 = ((($$sroa$09$014)) + 4|0);
     $21 = HEAP32[$10>>2]|0;
     $22 = ($20|0)==($21|0);
     if ($22) {
      break;
     } else {
      $$sroa$09$014 = $20;
     }
    }
    $$pre = HEAP32[$2>>2]|0;
    $23 = $$pre;
   }
  }
 } else {
  $23 = $3;
 }
 $24 = ($23|0)==($1|0);
 if ($24) {
  return;
 }
 HEAP32[$2>>2] = $1;
 $25 = ($1|0)==(0|0);
 if (!($25)) {
  $26 = HEAP32[$1>>2]|0;
  $27 = ((($26)) + -12|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (($1) + ($28)|0);
  $30 = ((($29)) + 8|0);
  $31 = HEAP32[$30>>2]|0;HEAP32[$30>>2] = (($31+1)|0);
 }
 $32 = ($23|0)==(0|0);
 if ($32) {
  return;
 }
 $33 = HEAP32[$23>>2]|0;
 $34 = ((($33)) + -12|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (($23) + ($35)|0);
 $37 = ((($36)) + 8|0);
 $38 = HEAP32[$37>>2]|0;HEAP32[$37>>2] = (($38-1)|0);
 $39 = ($38|0)==(1);
 if (!($39)) {
  return;
 }
 __ZNK3osg10Referenced24signalObserversAndDeleteEbb($36,1,1);
 return;
}
function __ZN3osg4Node16setEventCallbackEPNS_8CallbackE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$ = 0, $$1 = 0, $$pre = 0, $$sroa$09$014 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $not$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 92|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==($1|0);
 if ($4) {
  return;
 }
 $5 = ((($0)) + 96|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  $8 = ((($0)) + 72|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ((($0)) + 76|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($9|0)==($11|0);
  if ($12) {
   $23 = $3;
  } else {
   $13 = ($3|0)!=(0|0);
   $$ = $13 << 31 >> 31;
   $not$ = ($1|0)!=(0|0);
   $14 = $not$&1;
   $$1 = (($$) + ($14))|0;
   $15 = ($$1|0)==(0);
   if ($15) {
    $23 = $3;
   } else {
    $$sroa$09$014 = $9;
    while(1) {
     $16 = HEAP32[$$sroa$09$014>>2]|0;
     $17 = ((($16)) + 96|0);
     $18 = HEAP32[$17>>2]|0;
     $19 = (($18) + ($$1))|0;
     __ZN3osg4Node37setNumChildrenRequiringEventTraversalEj($16,$19);
     $20 = ((($$sroa$09$014)) + 4|0);
     $21 = HEAP32[$10>>2]|0;
     $22 = ($20|0)==($21|0);
     if ($22) {
      break;
     } else {
      $$sroa$09$014 = $20;
     }
    }
    $$pre = HEAP32[$2>>2]|0;
    $23 = $$pre;
   }
  }
 } else {
  $23 = $3;
 }
 $24 = ($23|0)==($1|0);
 if ($24) {
  return;
 }
 HEAP32[$2>>2] = $1;
 $25 = ($1|0)==(0|0);
 if (!($25)) {
  $26 = HEAP32[$1>>2]|0;
  $27 = ((($26)) + -12|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (($1) + ($28)|0);
  $30 = ((($29)) + 8|0);
  $31 = HEAP32[$30>>2]|0;HEAP32[$30>>2] = (($31+1)|0);
 }
 $32 = ($23|0)==(0|0);
 if ($32) {
  return;
 }
 $33 = HEAP32[$23>>2]|0;
 $34 = ((($33)) + -12|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (($23) + ($35)|0);
 $37 = ((($36)) + 8|0);
 $38 = HEAP32[$37>>2]|0;HEAP32[$37>>2] = (($38-1)|0);
 $39 = ($38|0)==(1);
 if (!($39)) {
  return;
 }
 __ZNK3osg10Referenced24signalObserversAndDeleteEbb($36,1,1);
 return;
}
function __ZN3osg4Node16setCullingActiveEb($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$ = 0, $$1 = 0, $$sroa$09$014 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $not$ = 0, $sext = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = $1&1;
 $3 = ((($0)) + 104|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = $1&1;
 $7 = ($5|0)==($6|0);
 if ($7) {
  return;
 }
 $8 = ((($0)) + 108|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0);
 if ($10) {
  $11 = ((($0)) + 72|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ((($0)) + 76|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = ($12|0)==($14|0);
  if (!($15)) {
   $sext = (($4) + -1)<<24>>24;
   $$ = $sext << 24 >> 24;
   $not$ = $1 ^ 1;
   $16 = $not$&1;
   $$1 = (($$) + ($16))|0;
   $17 = ($$1|0)==(0);
   if (!($17)) {
    $$sroa$09$014 = $12;
    while(1) {
     $18 = HEAP32[$$sroa$09$014>>2]|0;
     $19 = ((($18)) + 108|0);
     $20 = HEAP32[$19>>2]|0;
     $21 = (($20) + ($$1))|0;
     __ZN3osg4Node33setNumChildrenWithCullingDisabledEj($18,$21);
     $22 = ((($$sroa$09$014)) + 4|0);
     $23 = HEAP32[$13>>2]|0;
     $24 = ($22|0)==($23|0);
     if ($24) {
      break;
     } else {
      $$sroa$09$014 = $22;
     }
    }
   }
  }
 }
 HEAP8[$3>>0] = $2;
 return;
}
function __ZN3osg4Node33setNumChildrenWithCullingDisabledEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$ = 0, $$1 = 0, $$sroa$09$015 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $not$ = 0, $not$14 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 108|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==($1|0);
 if ($4) {
  return;
 }
 $5 = ((($0)) + 104|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = ($6<<24>>24)==(0);
 if (!($7)) {
  $8 = ((($0)) + 72|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ((($0)) + 76|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($9|0)==($11|0);
  if (!($12)) {
   $not$ = ($3|0)!=(0);
   $$ = $not$ << 31 >> 31;
   $not$14 = ($1|0)!=(0);
   $13 = $not$14&1;
   $$1 = (($$) + ($13))|0;
   $14 = ($$1|0)==(0);
   if (!($14)) {
    $$sroa$09$015 = $9;
    while(1) {
     $15 = HEAP32[$$sroa$09$015>>2]|0;
     $16 = ((($15)) + 108|0);
     $17 = HEAP32[$16>>2]|0;
     $18 = (($17) + ($$1))|0;
     __ZN3osg4Node33setNumChildrenWithCullingDisabledEj($15,$18);
     $19 = ((($$sroa$09$015)) + 4|0);
     $20 = HEAP32[$10>>2]|0;
     $21 = ($19|0)==($20|0);
     if ($21) {
      break;
     } else {
      $$sroa$09$015 = $19;
     }
    }
   }
  }
 }
 HEAP32[$2>>2] = $1;
 return;
}
function __ZN3osg4Node31setNumChildrenWithOccluderNodesEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$ = 0, $$1 = 0, $$sroa$09$015 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $not$ = 0, $not$14 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 112|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==($1|0);
 if ($4) {
  return;
 }
 $5 = (___dynamic_cast($0,25952,26152,0)|0);
 $phitmp = ($5|0)==(0|0);
 if ($phitmp) {
  $6 = ((($0)) + 72|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ((($0)) + 76|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($7|0)==($9|0);
  if (!($10)) {
   $not$ = ($3|0)!=(0);
   $$ = $not$ << 31 >> 31;
   $not$14 = ($1|0)!=(0);
   $11 = $not$14&1;
   $$1 = (($$) + ($11))|0;
   $12 = ($$1|0)==(0);
   if (!($12)) {
    $$sroa$09$015 = $7;
    while(1) {
     $13 = HEAP32[$$sroa$09$015>>2]|0;
     $14 = ((($13)) + 112|0);
     $15 = HEAP32[$14>>2]|0;
     $16 = (($15) + ($$1))|0;
     __ZN3osg4Node31setNumChildrenWithOccluderNodesEj($13,$16);
     $17 = ((($$sroa$09$015)) + 4|0);
     $18 = HEAP32[$8>>2]|0;
     $19 = ($17|0)==($18|0);
     if ($19) {
      break;
     } else {
      $$sroa$09$015 = $17;
     }
    }
   }
  }
 }
 HEAP32[$2>>2] = $1;
 return;
}
function __ZNK3osg4Node21containsOccluderNodesEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 112|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if (!($3)) {
  $5 = 1;
  return ($5|0);
 }
 $4 = (___dynamic_cast($0,25952,26152,0)|0);
 $phitmp = ($4|0)!=(0|0);
 $5 = $phitmp;
 return ($5|0);
}
function __ZN3osg4Node10dirtyBoundEv($0) {
 $0 = $0|0;
 var $$sroa$02$06 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 68|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  return;
 }
 HEAP8[$1>>0] = 0;
 $4 = ((($0)) + 72|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($0)) + 76|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5|0)==($7|0);
 if ($8) {
  return;
 } else {
  $$sroa$02$06 = $5;
 }
 while(1) {
  $9 = HEAP32[$$sroa$02$06>>2]|0;
  __ZN3osg4Node10dirtyBoundEv($9);
  $10 = ((($$sroa$02$06)) + 4|0);
  $11 = HEAP32[$6>>2]|0;
  $12 = ($10|0)==($11|0);
  if ($12) {
   break;
  } else {
   $$sroa$02$06 = $10;
  }
 }
 return;
}
function __ZN3osg11NodeVisitorD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vii(3284,($0|0),(63132|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  $3 = ((($0)) + 56|0);
  __ZN3osg6ObjectD2Ev($3);
  return;
 }
 $4 = ___cxa_find_matching_catch_2()|0;
 $5 = tempRet0;
 $6 = ((($0)) + 56|0);
 __THREW__ = 0;
 invoke_vi(388,($6|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch_3(0|0)|0;
  $10 = tempRet0;
  ___clang_call_terminate($9);
  // unreachable;
 } else {
  ___resumeException($4|0);
  // unreachable;
 }
}
function __ZN3osg11NodeVisitorD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vii(3284,($0|0),(63132|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $6 = ___cxa_find_matching_catch_2()|0;
  $7 = tempRet0;
  $8 = ((($0)) + 56|0);
  __THREW__ = 0;
  invoke_vi(388,($8|0));
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if ($10) {
   $11 = ___cxa_find_matching_catch_3(0|0)|0;
   $12 = tempRet0;
   ___clang_call_terminate($11);
   // unreachable;
  } else {
   $eh$lpad$body$index2Z2D = $7;$eh$lpad$body$indexZ2D = $6;
   __ZdlPv($0);
   ___resumeException($eh$lpad$body$indexZ2D|0);
   // unreachable;
  }
 }
 $3 = ((($0)) + 56|0);
 __THREW__ = 0;
 invoke_vi(388,($3|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  __ZdlPv($0);
  return;
 }
 $13 = ___cxa_find_matching_catch_2()|0;
 $14 = tempRet0;
 $eh$lpad$body$index2Z2D = $14;$eh$lpad$body$indexZ2D = $13;
 __ZdlPv($0);
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
}
function __ZN3osg11NodeVisitor5applyERNS_8DrawableE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $3 = ((($2)) + 108|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 8191]($0,$1);
 return;
}
function __ZN3osg11NodeVisitor5applyERNS_8GeometryE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $3 = ((($2)) + 100|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 8191]($0,$1);
 return;
}
function __ZN3osg11NodeVisitor5applyERNS_4NodeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 switch ($3|0) {
 case 1:  {
  $4 = HEAP32[$1>>2]|0;
  $5 = ((($4)) + 192|0);
  $6 = HEAP32[$5>>2]|0;
  FUNCTION_TABLE_vii[$6 & 8191]($1,$0);
  return;
  break;
 }
 case 0:  {
  return;
  break;
 }
 default: {
  $7 = HEAP32[$1>>2]|0;
  $8 = ((($7)) + 196|0);
  $9 = HEAP32[$8>>2]|0;
  FUNCTION_TABLE_vii[$9 & 8191]($1,$0);
  return;
 }
 }
}
function __ZN3osg11NodeVisitor5applyERNS_5GeodeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $3 = ((($2)) + 120|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 8191]($0,$1);
 return;
}
function __ZN3osg11NodeVisitor5applyERNS_9BillboardE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $3 = ((($2)) + 112|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 8191]($0,$1);
 return;
}
function __ZN3osg11NodeVisitor5applyERNS_5GroupE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $3 = ((($2)) + 108|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 8191]($0,$1);
 return;
}
function __ZN3osg11NodeVisitor5applyERNS_9ProxyNodeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $3 = ((($2)) + 120|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 8191]($0,$1);
 return;
}
function __ZN3osg11NodeVisitor5applyERNS_10ProjectionE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $3 = ((($2)) + 120|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 8191]($0,$1);
 return;
}
function __ZN3osg11NodeVisitor5applyERNS_20CoordinateSystemNodeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $3 = ((($2)) + 120|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 8191]($0,$1);
 return;
}
function __ZN3osg11NodeVisitor5applyERNS_8ClipNodeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $3 = ((($2)) + 120|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 8191]($0,$1);
 return;
}
function __ZN3osg11NodeVisitor5applyERNS_10TexGenNodeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $3 = ((($2)) + 120|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 8191]($0,$1);
 return;
}
function __ZN3osg11NodeVisitor5applyERNS_11LightSourceE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $3 = ((($2)) + 120|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 8191]($0,$1);
 return;
}
function __ZN3osg11NodeVisitor5applyERNS_9TransformE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $3 = ((($2)) + 120|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 8191]($0,$1);
 return;
}
function __ZN3osg11NodeVisitor5applyERNS_6CameraE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $3 = ((($2)) + 148|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 8191]($0,$1);
 return;
}
function __ZN3osg11NodeVisitor5applyERNS_10CameraViewE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $3 = ((($2)) + 148|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 8191]($0,$1);
 return;
}
function __ZN3osg11NodeVisitor5applyERNS_15MatrixTransformE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $3 = ((($2)) + 148|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 8191]($0,$1);
 return;
}
function __ZN3osg11NodeVisitor5applyERNS_25PositionAttitudeTransformE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $3 = ((($2)) + 148|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 8191]($0,$1);
 return;
}
function __ZN3osg11NodeVisitor5applyERNS_13AutoTransformE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $3 = ((($2)) + 148|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 8191]($0,$1);
 return;
}
function __ZN3osg11NodeVisitor5applyERNS_6SwitchE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $3 = ((($2)) + 120|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 8191]($0,$1);
 return;
}
function __ZN3osg11NodeVisitor5applyERNS_8SequenceE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $3 = ((($2)) + 120|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 8191]($0,$1);
 return;
}
function __ZN3osg11NodeVisitor5applyERNS_3LODE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $3 = ((($2)) + 120|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 8191]($0,$1);
 return;
}
function __ZN3osg11NodeVisitor5applyERNS_8PagedLODE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $3 = ((($2)) + 180|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 8191]($0,$1);
 return;
}
function __ZN3osg11NodeVisitor5applyERNS_9ClearNodeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $3 = ((($2)) + 120|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 8191]($0,$1);
 return;
}
function __ZN3osg11NodeVisitor5applyERNS_12OccluderNodeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $3 = ((($2)) + 120|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 8191]($0,$1);
 return;
}
function __ZN3osg11NodeVisitor5applyERNS_18OcclusionQueryNodeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $3 = ((($2)) + 120|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 8191]($0,$1);
 return;
}
function __ZTv0_n16_N3osg11NodeVisitorD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __THREW__ = 0;
 invoke_vii(3284,($4|0),(63132|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if (!($6)) {
  $14 = ((($4)) + 56|0);
  __ZN3osg6ObjectD2Ev($14);
  return;
 }
 $7 = ___cxa_find_matching_catch_2()|0;
 $8 = tempRet0;
 $9 = ((($4)) + 56|0);
 __THREW__ = 0;
 invoke_vi(388,($9|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if ($11) {
  $12 = ___cxa_find_matching_catch_3(0|0)|0;
  $13 = tempRet0;
  ___clang_call_terminate($12);
  // unreachable;
 } else {
  ___resumeException($7|0);
  // unreachable;
 }
}
function __ZTv0_n16_N3osg11NodeVisitorD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$i$index2Z2D = 0, $eh$lpad$body$i$indexZ2D = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __THREW__ = 0;
 invoke_vii(3284,($4|0),(63132|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $10 = ___cxa_find_matching_catch_2()|0;
  $11 = tempRet0;
  $12 = ((($4)) + 56|0);
  __THREW__ = 0;
  invoke_vi(388,($12|0));
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if ($14) {
   $15 = ___cxa_find_matching_catch_3(0|0)|0;
   $16 = tempRet0;
   ___clang_call_terminate($15);
   // unreachable;
  } else {
   $eh$lpad$body$i$index2Z2D = $11;$eh$lpad$body$i$indexZ2D = $10;
   __ZdlPv($4);
   ___resumeException($eh$lpad$body$i$indexZ2D|0);
   // unreachable;
  }
 }
 $7 = ((($4)) + 56|0);
 __THREW__ = 0;
 invoke_vi(388,($7|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if (!($9)) {
  __ZdlPv($4);
  return;
 }
 $17 = ___cxa_find_matching_catch_2()|0;
 $18 = tempRet0;
 $eh$lpad$body$i$index2Z2D = $18;$eh$lpad$body$i$indexZ2D = $17;
 __ZdlPv($4);
 ___resumeException($eh$lpad$body$i$indexZ2D|0);
 // unreachable;
}
function __ZN3osg11NodeVisitorD2Ev($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$03 = 0, $$1 = 0, $$14 = 0, $$2 = 0, $$25 = 0, $$cast = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $12 = 0;
 var $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i16 = 0, $scevgep5$i$i$i = 0, $scevgep5$i$i$i17 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $2;
 $3 = ((($1)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $$cast = $2;
 $5 = ((($$cast)) + -12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($0) + ($6)|0);
 HEAP32[$7>>2] = $4;
 $8 = ((($0)) + 52|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if ($10) {
  label = 4;
 } else {
  $11 = ((($9)) + 8|0);
  $12 = HEAP32[$11>>2]|0;HEAP32[$11>>2] = (($12-1)|0);
  $13 = ($12|0)==(1);
  if ($13) {
   __THREW__ = 0;
   invoke_viii(3262,($9|0),1,1);
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if ($15) {
    $57 = ___cxa_find_matching_catch_2()|0;
    $58 = tempRet0;
    $59 = ((($0)) + 48|0);
    $60 = HEAP32[$59>>2]|0;
    $61 = ($60|0)==(0|0);
    if (!($61)) {
     $62 = ((($60)) + 8|0);
     $63 = HEAP32[$62>>2]|0;HEAP32[$62>>2] = (($63-1)|0);
     $64 = ($63|0)==(1);
     if ($64) {
      __THREW__ = 0;
      invoke_viii(3262,($60|0),1,1);
      $65 = __THREW__; __THREW__ = 0;
      $66 = $65&1;
      if ($66) {
       $108 = ___cxa_find_matching_catch_3(0|0)|0;
       $109 = tempRet0;
       ___clang_call_terminate($108);
       // unreachable;
      }
     }
    }
    HEAP32[$59>>2] = 0;
    $$0 = $58;$$03 = $57;
    label = 27;
   } else {
    label = 4;
   }
  } else {
   label = 4;
  }
 }
 do {
  if ((label|0) == 4) {
   HEAP32[$8>>2] = 0;
   $16 = ((($0)) + 48|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = ($17|0)==(0|0);
   if (!($18)) {
    $19 = ((($17)) + 8|0);
    $20 = HEAP32[$19>>2]|0;HEAP32[$19>>2] = (($20-1)|0);
    $21 = ($20|0)==(1);
    if ($21) {
     __THREW__ = 0;
     invoke_viii(3262,($17|0),1,1);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      $67 = ___cxa_find_matching_catch_2()|0;
      $68 = tempRet0;
      $$0 = $68;$$03 = $67;
      label = 27;
      break;
     }
    }
   }
   HEAP32[$16>>2] = 0;
   $24 = ((($0)) + 44|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = ($25|0)==(0|0);
   if (!($26)) {
    $27 = ((($25)) + 8|0);
    $28 = HEAP32[$27>>2]|0;HEAP32[$27>>2] = (($28-1)|0);
    $29 = ($28|0)==(1);
    if ($29) {
     __THREW__ = 0;
     invoke_viii(3262,($25|0),1,1);
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      $69 = ___cxa_find_matching_catch_2()|0;
      $70 = tempRet0;
      $$1 = $70;$$14 = $69;
      label = 32;
      break;
     }
    }
   }
   HEAP32[$24>>2] = 0;
   $32 = ((($0)) + 40|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = ($33|0)==(0|0);
   if (!($34)) {
    $35 = ((($33)) + 8|0);
    $36 = HEAP32[$35>>2]|0;HEAP32[$35>>2] = (($36-1)|0);
    $37 = ($36|0)==(1);
    if ($37) {
     __THREW__ = 0;
     invoke_viii(3262,($33|0),1,1);
     $38 = __THREW__; __THREW__ = 0;
     $39 = $38&1;
     if ($39) {
      $79 = ___cxa_find_matching_catch_2()|0;
      $80 = tempRet0;
      $$2 = $80;$$25 = $79;
      break;
     }
    }
   }
   HEAP32[$32>>2] = 0;
   $40 = ((($0)) + 28|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = ($41|0)==(0|0);
   if (!($42)) {
    $43 = ((($0)) + 32|0);
    $44 = HEAP32[$43>>2]|0;
    $45 = ($44|0)==($41|0);
    if (!($45)) {
     $scevgep$i$i$i = ((($44)) + -4|0);
     $46 = $scevgep$i$i$i;
     $47 = $41;
     $48 = (($46) - ($47))|0;
     $49 = $48 >>> 2;
     $50 = $49 ^ -1;
     $scevgep5$i$i$i = (($44) + ($50<<2)|0);
     HEAP32[$43>>2] = $scevgep5$i$i$i;
    }
    __ZdlPv($41);
   }
   $51 = ((($0)) + 12|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = ($52|0)==(0|0);
   if ($53) {
    HEAP32[$51>>2] = 0;
    return;
   }
   $54 = ((($52)) + 8|0);
   $55 = HEAP32[$54>>2]|0;HEAP32[$54>>2] = (($55-1)|0);
   $56 = ($55|0)==(1);
   if (!($56)) {
    HEAP32[$51>>2] = 0;
    return;
   }
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($52,1,1);
   HEAP32[$51>>2] = 0;
   return;
  }
 } while(0);
 if ((label|0) == 27) {
  $71 = ((($0)) + 44|0);
  $72 = HEAP32[$71>>2]|0;
  $73 = ($72|0)==(0|0);
  if (!($73)) {
   $74 = ((($72)) + 8|0);
   $75 = HEAP32[$74>>2]|0;HEAP32[$74>>2] = (($75-1)|0);
   $76 = ($75|0)==(1);
   if ($76) {
    __THREW__ = 0;
    invoke_viii(3262,($72|0),1,1);
    $77 = __THREW__; __THREW__ = 0;
    $78 = $77&1;
    if ($78) {
     $108 = ___cxa_find_matching_catch_3(0|0)|0;
     $109 = tempRet0;
     ___clang_call_terminate($108);
     // unreachable;
    }
   }
  }
  HEAP32[$71>>2] = 0;
  $$1 = $$0;$$14 = $$03;
  label = 32;
 }
 if ((label|0) == 32) {
  $81 = ((($0)) + 40|0);
  $82 = HEAP32[$81>>2]|0;
  $83 = ($82|0)==(0|0);
  if (!($83)) {
   $84 = ((($82)) + 8|0);
   $85 = HEAP32[$84>>2]|0;HEAP32[$84>>2] = (($85-1)|0);
   $86 = ($85|0)==(1);
   if ($86) {
    __THREW__ = 0;
    invoke_viii(3262,($82|0),1,1);
    $87 = __THREW__; __THREW__ = 0;
    $88 = $87&1;
    if ($88) {
     $108 = ___cxa_find_matching_catch_3(0|0)|0;
     $109 = tempRet0;
     ___clang_call_terminate($108);
     // unreachable;
    }
   }
  }
  HEAP32[$81>>2] = 0;
  $$2 = $$1;$$25 = $$14;
 }
 $89 = ((($0)) + 28|0);
 $90 = HEAP32[$89>>2]|0;
 $91 = ($90|0)==(0|0);
 if (!($91)) {
  $92 = ((($0)) + 32|0);
  $93 = HEAP32[$92>>2]|0;
  $94 = ($93|0)==($90|0);
  if (!($94)) {
   $scevgep$i$i$i16 = ((($93)) + -4|0);
   $95 = $scevgep$i$i$i16;
   $96 = $90;
   $97 = (($95) - ($96))|0;
   $98 = $97 >>> 2;
   $99 = $98 ^ -1;
   $scevgep5$i$i$i17 = (($93) + ($99<<2)|0);
   HEAP32[$92>>2] = $scevgep5$i$i$i17;
  }
  __ZdlPv($90);
 }
 $100 = ((($0)) + 12|0);
 $101 = HEAP32[$100>>2]|0;
 $102 = ($101|0)==(0|0);
 if ($102) {
  HEAP32[$100>>2] = 0;
  ___resumeException($$25|0);
  // unreachable;
 }
 $103 = ((($101)) + 8|0);
 $104 = HEAP32[$103>>2]|0;HEAP32[$103>>2] = (($104-1)|0);
 $105 = ($104|0)==(1);
 if (!($105)) {
  HEAP32[$100>>2] = 0;
  ___resumeException($$25|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(3262,($101|0),1,1);
 $106 = __THREW__; __THREW__ = 0;
 $107 = $106&1;
 if ($107) {
  $108 = ___cxa_find_matching_catch_3(0|0)|0;
  $109 = tempRet0;
  ___clang_call_terminate($108);
  // unreachable;
 } else {
  HEAP32[$100>>2] = 0;
  ___resumeException($$25|0);
  // unreachable;
 }
}
function __ZN3osg11NodeVisitorC2ENS0_13TraversalModeE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$cast = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $3;
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $$cast = $3;
 $6 = ((($$cast)) + -12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($0) + ($7)|0);
 HEAP32[$8>>2] = $5;
 $9 = ((($0)) + 12|0);
 HEAP32[$9>>2] = 0;
 $10 = ((($0)) + 28|0);
 $11 = ((($0)) + 4|0);
 HEAP32[$11>>2] = 0;
 $12 = ((($0)) + 8|0);
 ;HEAP32[$10>>2]=0|0;HEAP32[$10+4>>2]=0|0;HEAP32[$10+8>>2]=0|0;HEAP32[$10+12>>2]=0|0;HEAP32[$10+16>>2]=0|0;HEAP32[$10+20>>2]=0|0;HEAP32[$10+24>>2]=0|0;
 HEAP32[$12>>2] = -1;
 $13 = ((($0)) + 16|0);
 HEAP32[$13>>2] = $2;
 $14 = ((($0)) + 20|0);
 HEAP32[$14>>2] = -1;
 $15 = ((($0)) + 24|0);
 HEAP32[$15>>2] = 0;
 return;
}
function __ZN3osg11NodeVisitorC1ENS0_13TraversalModeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 56|0);
 __ZN3osg10ReferencedC2Eb($2,1);
 $3 = ((($0)) + 68|0);
 ;HEAP32[$3>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;
 $4 = ((($0)) + 80|0);
 HEAP32[$4>>2] = 2;
 $5 = ((($0)) + 84|0);
 HEAP32[$5>>2] = 0;
 HEAP32[$0>>2] = (3324);
 HEAP32[$2>>2] = (3668);
 $6 = ((($0)) + 12|0);
 HEAP32[$6>>2] = 0;
 $7 = ((($0)) + 28|0);
 $8 = ((($0)) + 4|0);
 HEAP32[$8>>2] = 0;
 $9 = ((($0)) + 8|0);
 ;HEAP32[$7>>2]=0|0;HEAP32[$7+4>>2]=0|0;HEAP32[$7+8>>2]=0|0;HEAP32[$7+12>>2]=0|0;HEAP32[$7+16>>2]=0|0;HEAP32[$7+20>>2]=0|0;HEAP32[$7+24>>2]=0|0;
 HEAP32[$9>>2] = -1;
 $10 = ((($0)) + 16|0);
 HEAP32[$10>>2] = $1;
 $11 = ((($0)) + 20|0);
 HEAP32[$11>>2] = -1;
 $12 = ((($0)) + 24|0);
 HEAP32[$12>>2] = 0;
 return;
}
function __ZN3osg11NodeVisitorC2ENS0_11VisitorTypeENS0_13TraversalModeE($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$cast = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $4;
 $5 = ((($1)) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $$cast = $4;
 $7 = ((($$cast)) + -12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($0) + ($8)|0);
 HEAP32[$9>>2] = $6;
 $10 = ((($0)) + 12|0);
 HEAP32[$10>>2] = 0;
 $11 = ((($0)) + 28|0);
 $12 = ((($0)) + 4|0);
 ;HEAP32[$11>>2]=0|0;HEAP32[$11+4>>2]=0|0;HEAP32[$11+8>>2]=0|0;HEAP32[$11+12>>2]=0|0;HEAP32[$11+16>>2]=0|0;HEAP32[$11+20>>2]=0|0;HEAP32[$11+24>>2]=0|0;
 HEAP32[$12>>2] = $2;
 $13 = ((($0)) + 8|0);
 HEAP32[$13>>2] = -1;
 $14 = ((($0)) + 16|0);
 HEAP32[$14>>2] = $3;
 $15 = ((($0)) + 20|0);
 HEAP32[$15>>2] = -1;
 $16 = ((($0)) + 24|0);
 HEAP32[$16>>2] = 0;
 return;
}
function __ZN3osg11NodeVisitorC2ERKS0_RKNS_6CopyOpE($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$cast = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $4;
 $5 = ((($1)) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $$cast = $4;
 $7 = ((($$cast)) + -12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($0) + ($8)|0);
 HEAP32[$9>>2] = $6;
 $10 = ((($0)) + 4|0);
 $11 = ((($2)) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 HEAP32[$10>>2] = $12;
 $13 = ((($0)) + 8|0);
 $14 = ((($2)) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 HEAP32[$13>>2] = $15;
 $16 = ((($0)) + 12|0);
 HEAP32[$16>>2] = 0;
 $17 = ((($0)) + 16|0);
 $18 = ((($2)) + 16|0);
 $19 = HEAP32[$18>>2]|0;
 HEAP32[$17>>2] = $19;
 $20 = ((($0)) + 20|0);
 $21 = ((($2)) + 20|0);
 $22 = HEAP32[$21>>2]|0;
 HEAP32[$20>>2] = $22;
 $23 = ((($0)) + 24|0);
 $24 = ((($2)) + 24|0);
 $25 = HEAP32[$24>>2]|0;
 HEAP32[$23>>2] = $25;
 $26 = ((($0)) + 28|0);
 ;HEAP32[$26>>2]=0|0;HEAP32[$26+4>>2]=0|0;HEAP32[$26+8>>2]=0|0;HEAP32[$26+12>>2]=0|0;HEAP32[$26+16>>2]=0|0;HEAP32[$26+20>>2]=0|0;HEAP32[$26+24>>2]=0|0;
 return;
}
function __ZN3osg11NodeVisitorC1ERKS0_RKNS_6CopyOpE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 56|0);
 $4 = HEAP32[$1>>2]|0;
 $5 = ((($4)) + -12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($1) + ($6)|0);
 __ZN3osg6ObjectC2ERKS0_RKNS_6CopyOpE($3,$7,$2);
 HEAP32[$0>>2] = (3324);
 HEAP32[$3>>2] = (3668);
 $8 = ((($0)) + 4|0);
 $9 = ((($1)) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 HEAP32[$8>>2] = $10;
 $11 = ((($0)) + 8|0);
 $12 = ((($1)) + 8|0);
 $13 = HEAP32[$12>>2]|0;
 HEAP32[$11>>2] = $13;
 $14 = ((($0)) + 12|0);
 HEAP32[$14>>2] = 0;
 $15 = ((($0)) + 16|0);
 $16 = ((($1)) + 16|0);
 $17 = HEAP32[$16>>2]|0;
 HEAP32[$15>>2] = $17;
 $18 = ((($0)) + 20|0);
 $19 = ((($1)) + 20|0);
 $20 = HEAP32[$19>>2]|0;
 HEAP32[$18>>2] = $20;
 $21 = ((($0)) + 24|0);
 $22 = ((($1)) + 24|0);
 $23 = HEAP32[$22>>2]|0;
 HEAP32[$21>>2] = $23;
 $24 = ((($0)) + 28|0);
 ;HEAP32[$24>>2]=0|0;HEAP32[$24+4>>2]=0|0;HEAP32[$24+8>>2]=0|0;HEAP32[$24+12>>2]=0|0;HEAP32[$24+16>>2]=0|0;HEAP32[$24+20>>2]=0|0;HEAP32[$24+24>>2]=0|0;
 return;
}
function __ZN3osg21StandardNotifyHandlerD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZN3osg21StandardNotifyHandler6notifyENS_14NotifySeverityEPKc($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($1|0)<(3);
 if ($3) {
  $4 = HEAP32[23152]|0;
  (_fputs($2,$4)|0);
  return;
 } else {
  $5 = HEAP32[23026]|0;
  (_fputs($2,$5)|0);
  return;
 }
}
function __GLOBAL__sub_I_Notify_cpp() {
 var $$0$i = 0, $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $0 = sp + 12|0;
 $1 = sp;
 $2 = (__Znwj(32)|0);
 HEAP32[$0>>2] = $2;
 $3 = ((($0)) + 8|0);
 HEAP32[$3>>2] = -2147483616;
 $4 = ((($0)) + 4|0);
 HEAP32[$4>>2] = 23;
 dest=$2; src=145310; stop=dest+23|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $5 = ((($2)) + 23|0);
 HEAP8[$5>>0] = 0;
 ;HEAP32[$1>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;
 __THREW__ = 0;
 $6 = (invoke_ii(3276,80)|0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $25 = ___cxa_find_matching_catch_2()|0;
  $26 = tempRet0;
  $$0$i = $26;$$01$i = $25;
 } else {
  HEAP32[$1>>2] = $6;
  $9 = ((($1)) + 8|0);
  HEAP32[$9>>2] = -2147483568;
  $10 = ((($1)) + 4|0);
  HEAP32[$10>>2] = 69;
  dest=$6; src=145334; stop=dest+69|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
  $11 = ((($6)) + 69|0);
  HEAP8[$11>>0] = 0;
  __THREW__ = 0;
  $12 = (invoke_i(3459)|0);
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if (!($14)) {
   __THREW__ = 0;
   invoke_viiii(3460,($12|0),2,($0|0),($1|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    $17 = ((($1)) + 11|0);
    $18 = HEAP8[$17>>0]|0;
    $19 = ($18<<24>>24)<(0);
    if ($19) {
     $20 = HEAP32[$1>>2]|0;
     __ZdlPv($20);
    }
    $21 = ((($0)) + 11|0);
    $22 = HEAP8[$21>>0]|0;
    $23 = ($22<<24>>24)<(0);
    if ($23) {
     $24 = HEAP32[$0>>2]|0;
     __ZdlPv($24);
    }
    $37 = HEAP8[206072]|0;
    $38 = ($37<<24>>24)==(0);
    if (!($38)) {
     STACKTOP = sp;return;
    }
    $39 = (___cxa_guard_acquire(206072)|0);
    $40 = ($39|0)==(0);
    if ($40) {
     STACKTOP = sp;return;
    }
    __THREW__ = 0;
    invoke_vi(3832,(208468|0));
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     $43 = ___cxa_find_matching_catch_2()|0;
     $44 = tempRet0;
     ___resumeException($43|0);
     // unreachable;
    }
    (___cxa_atexit((3833|0),(208468|0),(___dso_handle|0))|0);
    STACKTOP = sp;return;
   }
  }
  $27 = ___cxa_find_matching_catch_2()|0;
  $28 = tempRet0;
  $29 = ((($1)) + 11|0);
  $30 = HEAP8[$29>>0]|0;
  $31 = ($30<<24>>24)<(0);
  if ($31) {
   $32 = HEAP32[$1>>2]|0;
   __ZdlPv($32);
   $$0$i = $28;$$01$i = $27;
  } else {
   $$0$i = $28;$$01$i = $27;
  }
 }
 $33 = ((($0)) + 11|0);
 $34 = HEAP8[$33>>0]|0;
 $35 = ($34<<24>>24)<(0);
 if (!($35)) {
  ___resumeException($$01$i|0);
  // unreachable;
 }
 $36 = HEAP32[$0>>2]|0;
 __ZdlPv($36);
 ___resumeException($$01$i|0);
 // unreachable;
}
function __ZN15NotifySingletonC2Ev($0) {
 $0 = $0|0;
 var $$013115 = 0, $$016$i$i = 0, $$017$i$i = 0, $$02729$i$i$i = 0, $$02729$i$i$i21 = 0, $$02729$i$i$i32 = 0, $$02729$i$i$i43 = 0, $$02729$i$i$i54 = 0, $$02729$i$i$i65 = 0, $$02729$i$i$i76 = 0, $$02729$i$i$i87 = 0, $$1 = 0, $$115 = 0, $$3 = 0, $$317 = 0, $$pr = 0, $$pr$pre = 0, $$pre = 0, $$pre$phi156Z2D = 0, $$pre155$pre$phiZZ2D = 0;
 var $$pre158 = 0, $$sroa$0110$0 = 0, $$sroa$0110$0$ph = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0;
 var $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0;
 var $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0;
 var $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, $or$cond = 0, $or$cond132 = 0, $or$cond133 = 0, $or$cond134 = 0, $or$cond135 = 0, $or$cond136 = 0, $or$cond137 = 0, $or$cond138 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp + 12|0;
 $2 = sp;
 $3 = ((($0)) + 4|0);
 __ZN3osg10NullStreamC1Ev($3);
 $4 = ((($0)) + 92|0);
 __THREW__ = 0;
 invoke_vi(3834,($4|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $9 = ___cxa_find_matching_catch_2()|0;
  $10 = tempRet0;
  $$3 = $9;$$317 = $10;
 } else {
  HEAP32[$0>>2] = 3;
  $7 = (_getenv((145444|0))|0);
  $8 = ($7|0)==(0|0);
  if ($8) {
   $13 = (_getenv((145461|0))|0);
   $14 = ($13|0)==(0|0);
   if ($14) {
    label = 94;
   } else {
    $$013115 = $13;
    label = 6;
   }
  } else {
   $$013115 = $7;
   label = 6;
  }
  L6: do {
   if ((label|0) == 6) {
    ;HEAP32[$2>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;
    $15 = (_strlen($$013115)|0);
    $16 = ($15>>>0)>(4294967279);
    do {
     if ($16) {
      __THREW__ = 0;
      invoke_vi(3367,($2|0));
      $17 = __THREW__; __THREW__ = 0;
     } else {
      $18 = ($15>>>0)<(11);
      if ($18) {
       $27 = $15&255;
       $28 = ((($2)) + 11|0);
       HEAP8[$28>>0] = $27;
       $29 = ($15|0)==(0);
       if ($29) {
        $$017$i$i = $2;$$pre$phi156Z2D = $28;
       } else {
        $$016$i$i = $2;$$pre155$pre$phiZZ2D = $28;
        label = 12;
       }
      } else {
       $19 = (($15) + 16)|0;
       $20 = $19 & -16;
       __THREW__ = 0;
       $21 = (invoke_ii(3276,($20|0))|0);
       $22 = __THREW__; __THREW__ = 0;
       $23 = $22&1;
       if ($23) {
        break;
       }
       HEAP32[$2>>2] = $21;
       $24 = $20 | -2147483648;
       $25 = ((($2)) + 8|0);
       HEAP32[$25>>2] = $24;
       $26 = ((($2)) + 4|0);
       HEAP32[$26>>2] = $15;
       $$pre158 = ((($2)) + 11|0);
       $$016$i$i = $21;$$pre155$pre$phiZZ2D = $$pre158;
       label = 12;
      }
      if ((label|0) == 12) {
       _memcpy(($$016$i$i|0),($$013115|0),($15|0))|0;
       $$017$i$i = $$016$i$i;$$pre$phi156Z2D = $$pre155$pre$phiZZ2D;
      }
      $30 = (($$017$i$i) + ($15)|0);
      HEAP8[$30>>0] = 0;
      $31 = HEAP8[$$pre$phi156Z2D>>0]|0;
      $32 = ($31<<24>>24)<(0);
      if ($32) {
       $33 = HEAP32[$2>>2]|0;
       $$pr = $31;$$sroa$0110$0$ph = $33;
       label = 15;
      } else {
       $$sroa$0110$0 = $2;$34 = $31;
      }
      while(1) {
       if ((label|0) == 15) {
        label = 0;
        $$sroa$0110$0 = $$sroa$0110$0$ph;$34 = $$pr;
       }
       $35 = ($34<<24>>24)<(0);
       $36 = HEAP32[$2>>2]|0;
       $37 = ((($2)) + 4|0);
       $38 = HEAP32[$37>>2]|0;
       $39 = $34&255;
       $40 = $35 ? $36 : $2;
       $41 = $35 ? $38 : $39;
       $42 = (($40) + ($41)|0);
       $43 = ($$sroa$0110$0|0)==($42|0);
       if ($43) {
        break;
       }
       $62 = HEAP8[$$sroa$0110$0>>0]|0;
       $63 = $62 << 24 >> 24;
       $64 = (_toupper($63)|0);
       $65 = $64&255;
       HEAP8[$$sroa$0110$0>>0] = $65;
       $66 = ((($$sroa$0110$0)) + 1|0);
       $$pr$pre = HEAP8[$$pre$phi156Z2D>>0]|0;
       $$pr = $$pr$pre;$$sroa$0110$0$ph = $66;
       label = 15;
      }
      $44 = $$sroa$0110$0;
      $45 = $40;
      $46 = ($41|0)<(6);
      L26: do {
       if ($46) {
        label = 25;
       } else {
        $$02729$i$i$i = $40;$48 = $41;
        while(1) {
         $47 = (($48) + -5)|0;
         $49 = ($47|0)==(0);
         if ($49) {
          label = 25;
          break L26;
         }
         $50 = (_memchr($$02729$i$i$i,65,$47)|0);
         $51 = ($50|0)==(0|0);
         if ($51) {
          label = 25;
          break L26;
         }
         $52 = (_memcmp($50,169258,6)|0);
         $53 = ($52|0)==(0);
         if ($53) {
          break;
         }
         $54 = ((($50)) + 1|0);
         $55 = $54;
         $56 = (($44) - ($55))|0;
         $57 = ($56|0)<(6);
         if ($57) {
          label = 25;
          break L26;
         } else {
          $$02729$i$i$i = $54;$48 = $56;
         }
        }
        $58 = ($50|0)==($$sroa$0110$0|0);
        $59 = $50;
        $60 = (($59) - ($45))|0;
        $61 = ($60|0)==(-1);
        $or$cond = $58 | $61;
        if ($or$cond) {
         label = 25;
        } else {
         HEAP32[$0>>2] = 0;
         $224 = $34;
        }
       }
      } while(0);
      L34: do {
       if ((label|0) == 25) {
        $67 = ($41|0)<(5);
        L36: do {
         if (!($67)) {
          $$02729$i$i$i21 = $40;$69 = $41;
          while(1) {
           $68 = (($69) + -4)|0;
           $70 = ($68|0)==(0);
           if ($70) {
            break L36;
           }
           $71 = (_memchr($$02729$i$i$i21,70,$68)|0);
           $72 = ($71|0)==(0|0);
           if ($72) {
            break L36;
           }
           $73 = (_memcmp($71,145476,5)|0);
           $74 = ($73|0)==(0);
           if ($74) {
            break;
           }
           $75 = ((($71)) + 1|0);
           $76 = $75;
           $77 = (($44) - ($76))|0;
           $78 = ($77|0)<(5);
           if ($78) {
            break L36;
           } else {
            $$02729$i$i$i21 = $75;$69 = $77;
           }
          }
          $79 = ($71|0)==($$sroa$0110$0|0);
          $80 = $71;
          $81 = (($80) - ($45))|0;
          $82 = ($81|0)==(-1);
          $or$cond132 = $79 | $82;
          if (!($or$cond132)) {
           HEAP32[$0>>2] = 1;
           $224 = $34;
           break L34;
          }
         }
        } while(0);
        $83 = ($41|0)<(4);
        L45: do {
         if (!($83)) {
          $$02729$i$i$i32 = $40;$85 = $41;
          while(1) {
           $84 = (($85) + -3)|0;
           $86 = ($84|0)==(0);
           if ($86) {
            break L45;
           }
           $87 = (_memchr($$02729$i$i$i32,87,$84)|0);
           $88 = ($87|0)==(0|0);
           if ($88) {
            break L45;
           }
           $89 = (_memcmp($87,181670,4)|0);
           $90 = ($89|0)==(0);
           if ($90) {
            break;
           }
           $91 = ((($87)) + 1|0);
           $92 = $91;
           $93 = (($44) - ($92))|0;
           $94 = ($93|0)<(4);
           if ($94) {
            break L45;
           } else {
            $$02729$i$i$i32 = $91;$85 = $93;
           }
          }
          $95 = ($87|0)==($$sroa$0110$0|0);
          $96 = $87;
          $97 = (($96) - ($45))|0;
          $98 = ($97|0)==(-1);
          $or$cond133 = $95 | $98;
          if (!($or$cond133)) {
           HEAP32[$0>>2] = 2;
           $224 = $34;
           break L34;
          }
         }
        } while(0);
        L54: do {
         if (!($46)) {
          $$02729$i$i$i43 = $40;$100 = $41;
          while(1) {
           $99 = (($100) + -5)|0;
           $101 = ($99|0)==(0);
           if ($101) {
            break;
           }
           $102 = (_memchr($$02729$i$i$i43,78,$99)|0);
           $103 = ($102|0)==(0|0);
           if ($103) {
            break;
           }
           $104 = (_memcmp($102,145482,6)|0);
           $105 = ($104|0)==(0);
           if ($105) {
            label = 44;
            break;
           }
           $106 = ((($102)) + 1|0);
           $107 = $106;
           $108 = (($44) - ($107))|0;
           $109 = ($108|0)<(6);
           if ($109) {
            break;
           } else {
            $$02729$i$i$i43 = $106;$100 = $108;
           }
          }
          if ((label|0) == 44) {
           $110 = ($102|0)==($$sroa$0110$0|0);
           $111 = $102;
           $112 = (($111) - ($45))|0;
           $113 = ($112|0)==(-1);
           $or$cond134 = $110 | $113;
           if (!($or$cond134)) {
            HEAP32[$0>>2] = 3;
            $224 = $34;
            break L34;
           }
          }
          $114 = ($41|0)<(10);
          L64: do {
           if (!($114)) {
            $$02729$i$i$i54 = $40;$116 = $41;
            while(1) {
             $115 = (($116) + -9)|0;
             $117 = ($115|0)==(0);
             if ($117) {
              break L64;
             }
             $118 = (_memchr($$02729$i$i$i54,68,$115)|0);
             $119 = ($118|0)==(0|0);
             if ($119) {
              break L64;
             }
             $120 = (_memcmp($118,145489,10)|0);
             $121 = ($120|0)==(0);
             if ($121) {
              break;
             }
             $122 = ((($118)) + 1|0);
             $123 = $122;
             $124 = (($44) - ($123))|0;
             $125 = ($124|0)<(10);
             if ($125) {
              break L64;
             } else {
              $$02729$i$i$i54 = $122;$116 = $124;
             }
            }
            $126 = ($118|0)==($$sroa$0110$0|0);
            $127 = $118;
            $128 = (($127) - ($45))|0;
            $129 = ($128|0)==(-1);
            $or$cond135 = $126 | $129;
            if (!($or$cond135)) {
             HEAP32[$0>>2] = 5;
             $224 = $34;
             break L34;
            }
           }
          } while(0);
          $130 = ($41|0)<(8);
          if (!($130)) {
           $$02729$i$i$i65 = $40;$132 = $41;
           while(1) {
            $131 = (($132) + -7)|0;
            $133 = ($131|0)==(0);
            if ($133) {
             break L54;
            }
            $134 = (_memchr($$02729$i$i$i65,68,$131)|0);
            $135 = ($134|0)==(0|0);
            if ($135) {
             break L54;
            }
            $136 = (_memcmp($134,145500,8)|0);
            $137 = ($136|0)==(0);
            if ($137) {
             break;
            }
            $138 = ((($134)) + 1|0);
            $139 = $138;
            $140 = (($44) - ($139))|0;
            $141 = ($140|0)<(8);
            if ($141) {
             break L54;
            } else {
             $$02729$i$i$i65 = $138;$132 = $140;
            }
           }
           $142 = ($134|0)==($$sroa$0110$0|0);
           $143 = $134;
           $144 = (($143) - ($45))|0;
           $145 = ($144|0)==(-1);
           $or$cond136 = $142 | $145;
           if (!($or$cond136)) {
            HEAP32[$0>>2] = 6;
            $224 = $34;
            break L34;
           }
          }
         }
        } while(0);
        L81: do {
         if (!($67)) {
          $$02729$i$i$i76 = $40;$147 = $41;
          while(1) {
           $146 = (($147) + -4)|0;
           $148 = ($146|0)==(0);
           if ($148) {
            break L81;
           }
           $149 = (_memchr($$02729$i$i$i76,68,$146)|0);
           $150 = ($149|0)==(0|0);
           if ($150) {
            break L81;
           }
           $151 = (_memcmp($149,181659,5)|0);
           $152 = ($151|0)==(0);
           if ($152) {
            break;
           }
           $153 = ((($149)) + 1|0);
           $154 = $153;
           $155 = (($44) - ($154))|0;
           $156 = ($155|0)<(5);
           if ($156) {
            break L81;
           } else {
            $$02729$i$i$i76 = $153;$147 = $155;
           }
          }
          $157 = ($149|0)==($$sroa$0110$0|0);
          $158 = $149;
          $159 = (($158) - ($45))|0;
          $160 = ($159|0)==(-1);
          $or$cond137 = $157 | $160;
          if (!($or$cond137)) {
           HEAP32[$0>>2] = 5;
           $224 = $34;
           break L34;
          }
         }
        } while(0);
        L90: do {
         if (!($83)) {
          $$02729$i$i$i87 = $40;$162 = $41;
          while(1) {
           $161 = (($162) + -3)|0;
           $163 = ($161|0)==(0);
           if ($163) {
            break L90;
           }
           $164 = (_memchr($$02729$i$i$i87,73,$161)|0);
           $165 = ($164|0)==(0|0);
           if ($165) {
            break L90;
           }
           $166 = (_memcmp($164,181665,4)|0);
           $167 = ($166|0)==(0);
           if ($167) {
            break;
           }
           $168 = ((($164)) + 1|0);
           $169 = $168;
           $170 = (($44) - ($169))|0;
           $171 = ($170|0)<(4);
           if ($171) {
            break L90;
           } else {
            $$02729$i$i$i87 = $168;$162 = $170;
           }
          }
          $172 = ($164|0)==($$sroa$0110$0|0);
          $173 = $164;
          $174 = (($173) - ($45))|0;
          $175 = ($174|0)==(-1);
          $or$cond138 = $172 | $175;
          if (!($or$cond138)) {
           HEAP32[$0>>2] = 4;
           $224 = $34;
           break L34;
          }
         }
        } while(0);
        __THREW__ = 0;
        $176 = (invoke_iiii(3267,(214316|0),(145509|0),39)|0);
        $177 = __THREW__; __THREW__ = 0;
        $178 = $177&1;
        L99: do {
         if ($178) {
          label = 87;
         } else {
          $179 = HEAP8[$$pre$phi156Z2D>>0]|0;
          $180 = ($179<<24>>24)<(0);
          $181 = HEAP32[$2>>2]|0;
          $182 = $180 ? $181 : $2;
          $183 = HEAP32[$37>>2]|0;
          $184 = $179&255;
          $185 = $180 ? $183 : $184;
          __THREW__ = 0;
          $186 = (invoke_iiii(3267,($176|0),($182|0),($185|0))|0);
          $187 = __THREW__; __THREW__ = 0;
          $188 = $187&1;
          if ($188) {
           label = 87;
          } else {
           __THREW__ = 0;
           $189 = (invoke_iiii(3267,($186|0),(174996|0),1)|0);
           $190 = __THREW__; __THREW__ = 0;
           $191 = $190&1;
           if ($191) {
            label = 87;
           } else {
            $192 = HEAP32[$189>>2]|0;
            $193 = ((($192)) + -12|0);
            $194 = HEAP32[$193>>2]|0;
            $195 = (($189) + ($194)|0);
            __THREW__ = 0;
            invoke_vii(3257,($1|0),($195|0));
            $196 = __THREW__; __THREW__ = 0;
            $197 = $196&1;
            if ($197) {
             label = 87;
            } else {
             __THREW__ = 0;
             $198 = (invoke_iii(3255,($1|0),(215188|0))|0);
             $199 = __THREW__; __THREW__ = 0;
             $200 = $199&1;
             do {
              if (!($200)) {
               $201 = HEAP32[$198>>2]|0;
               $202 = ((($201)) + 28|0);
               $203 = HEAP32[$202>>2]|0;
               __THREW__ = 0;
               $204 = (invoke_iii($203|0,($198|0),10)|0);
               $205 = __THREW__; __THREW__ = 0;
               $206 = $205&1;
               if ($206) {
                break;
               }
               __THREW__ = 0;
               invoke_vi(3263,($1|0));
               $207 = __THREW__; __THREW__ = 0;
               $208 = $207&1;
               if ($208) {
                label = 87;
                break L99;
               }
               __THREW__ = 0;
               (invoke_iii(3268,($189|0),($204|0))|0);
               $215 = __THREW__; __THREW__ = 0;
               $216 = $215&1;
               if ($216) {
                label = 87;
                break L99;
               }
               __THREW__ = 0;
               (invoke_ii(3269,($189|0))|0);
               $217 = __THREW__; __THREW__ = 0;
               $218 = $217&1;
               if ($218) {
                label = 87;
                break L99;
               }
               $$pre = HEAP8[$$pre$phi156Z2D>>0]|0;
               $224 = $$pre;
               break L34;
              }
             } while(0);
             $209 = ___cxa_find_matching_catch_2()|0;
             $210 = tempRet0;
             __THREW__ = 0;
             invoke_vi(3263,($1|0));
             $211 = __THREW__; __THREW__ = 0;
             $212 = $211&1;
             if ($212) {
              $213 = ___cxa_find_matching_catch_3(0|0)|0;
              $214 = tempRet0;
              ___clang_call_terminate($213);
              // unreachable;
             } else {
              $eh$lpad$body$index2Z2D = $210;$eh$lpad$body$indexZ2D = $209;
              break;
             }
            }
           }
          }
         }
        } while(0);
        if ((label|0) == 87) {
         $219 = ___cxa_find_matching_catch_2()|0;
         $220 = tempRet0;
         $eh$lpad$body$index2Z2D = $220;$eh$lpad$body$indexZ2D = $219;
        }
        $221 = HEAP8[$$pre$phi156Z2D>>0]|0;
        $222 = ($221<<24>>24)<(0);
        if ($222) {
         $223 = HEAP32[$2>>2]|0;
         __ZdlPv($223);
        }
        $$1 = $eh$lpad$body$indexZ2D;$$115 = $eh$lpad$body$index2Z2D;
        break L6;
       }
      } while(0);
      $225 = ($224<<24>>24)<(0);
      if ($225) {
       $226 = HEAP32[$2>>2]|0;
       __ZdlPv($226);
      }
      label = 94;
      break L6;
     }
    } while(0);
    $11 = ___cxa_find_matching_catch_2()|0;
    $12 = tempRet0;
    $$1 = $11;$$115 = $12;
   }
  } while(0);
  do {
   if ((label|0) == 94) {
    $227 = HEAP32[$4>>2]|0;
    $228 = ((($227)) + -12|0);
    $229 = HEAP32[$228>>2]|0;
    $230 = (($4) + ($229)|0);
    $231 = ((($230)) + 24|0);
    $232 = HEAP32[$231>>2]|0;
    $233 = ($232|0)==(0|0);
    if ($233) {
     STACKTOP = sp;return;
    }
    $234 = (___dynamic_cast($232,33032,26080,0)|0);
    $235 = ($234|0)==(0|0);
    if ($235) {
     STACKTOP = sp;return;
    }
    $236 = ((($234)) + 52|0);
    $237 = HEAP32[$236>>2]|0;
    $238 = ($237|0)==(0|0);
    if (!($238)) {
     STACKTOP = sp;return;
    }
    __THREW__ = 0;
    $239 = (invoke_ii(3276,12)|0);
    $240 = __THREW__; __THREW__ = 0;
    $241 = $240&1;
    if (!($241)) {
     __THREW__ = 0;
     invoke_vi(3282,($239|0));
     $242 = __THREW__; __THREW__ = 0;
     $243 = $242&1;
     if ($243) {
      $256 = ___cxa_find_matching_catch_2()|0;
      $257 = tempRet0;
      __ZdlPv($239);
      $$1 = $256;$$115 = $257;
      break;
     }
     HEAP32[$239>>2] = (63148);
     $244 = HEAP32[$236>>2]|0;
     $245 = ($244|0)==($239|0);
     if ($245) {
      STACKTOP = sp;return;
     }
     HEAP32[$236>>2] = $239;
     $246 = ((($239)) + 8|0);
     $247 = HEAP32[$246>>2]|0;HEAP32[$246>>2] = (($247+1)|0);
     $248 = ($244|0)==(0|0);
     if ($248) {
      STACKTOP = sp;return;
     }
     $249 = ((($244)) + 8|0);
     $250 = HEAP32[$249>>2]|0;HEAP32[$249>>2] = (($250-1)|0);
     $251 = ($250|0)==(1);
     if (!($251)) {
      STACKTOP = sp;return;
     }
     __THREW__ = 0;
     invoke_viii(3262,($244|0),1,1);
     $252 = __THREW__; __THREW__ = 0;
     $253 = $252&1;
     if (!($253)) {
      STACKTOP = sp;return;
     }
    }
    $254 = ___cxa_find_matching_catch_2()|0;
    $255 = tempRet0;
    $$1 = $254;$$115 = $255;
   }
  } while(0);
  __THREW__ = 0;
  invoke_vi(2043,($4|0));
  $258 = __THREW__; __THREW__ = 0;
  $259 = $258&1;
  if ($259) {
   $262 = ___cxa_find_matching_catch_3(0|0)|0;
   $263 = tempRet0;
   ___clang_call_terminate($262);
   // unreachable;
  } else {
   $$3 = $$1;$$317 = $$115;
  }
 }
 __THREW__ = 0;
 invoke_vi(2039,($3|0));
 $260 = __THREW__; __THREW__ = 0;
 $261 = $260&1;
 if ($261) {
  $262 = ___cxa_find_matching_catch_3(0|0)|0;
  $263 = tempRet0;
  ___clang_call_terminate($262);
  // unreachable;
 } else {
  ___resumeException($$3|0);
  // unreachable;
 }
}
function __ZN15NotifySingletonD2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 92|0);
 __THREW__ = 0;
 invoke_vi(2043,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  $4 = ((($0)) + 4|0);
  __ZN3osg10NullStreamD1Ev($4);
  return;
 }
 $5 = ___cxa_find_matching_catch_2()|0;
 $6 = tempRet0;
 $7 = ((($0)) + 4|0);
 __THREW__ = 0;
 invoke_vi(2039,($7|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $10 = ___cxa_find_matching_catch_3(0|0)|0;
  $11 = tempRet0;
  ___clang_call_terminate($10);
  // unreachable;
 } else {
  ___resumeException($5|0);
  // unreachable;
 }
}
function __ZN3osg12NotifyStreamD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = ((63232));
 $1 = ((($0)) + 8|0);
 HEAP32[$1>>2] = ((63252));
 $2 = ((($0)) + 32|0);
 $3 = ((($0)) + 8|0);
 HEAP32[$2>>2] = 0;
 __THREW__ = 0;
 invoke_vii(3259,($3|0),0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 do {
  if ($5) {
   label = 5;
  } else {
   $6 = ((($0)) + 4|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($7|0)==(0|0);
   if (!($8)) {
    $9 = HEAP32[$7>>2]|0;
    $10 = ((($9)) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    __THREW__ = 0;
    invoke_vi($11|0,($7|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     label = 5;
     break;
    }
   }
   __THREW__ = 0;
   invoke_vii(3614,($0|0),((63264)|0));
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if ($15) {
    $22 = ___cxa_find_matching_catch_2()|0;
    $23 = tempRet0;
    $eh$lpad$body$index2Z2D = $23;$eh$lpad$body$indexZ2D = $22;
    break;
   } else {
    __ZNSt3__29basic_iosIcNS_11char_traitsIcEEED2Ev($1);
    return;
   }
  }
 } while(0);
 if ((label|0) == 5) {
  $16 = ___cxa_find_matching_catch_2()|0;
  $17 = tempRet0;
  __THREW__ = 0;
  invoke_vii(3614,($0|0),((63264)|0));
  $18 = __THREW__; __THREW__ = 0;
  $19 = $18&1;
  if ($19) {
   $20 = ___cxa_find_matching_catch_3(0|0)|0;
   $21 = tempRet0;
   ___clang_call_terminate($20);
   // unreachable;
  } else {
   $eh$lpad$body$index2Z2D = $17;$eh$lpad$body$indexZ2D = $16;
  }
 }
 __THREW__ = 0;
 invoke_vi(2907,($1|0));
 $24 = __THREW__; __THREW__ = 0;
 $25 = $24&1;
 if ($25) {
  $26 = ___cxa_find_matching_catch_3(0|0)|0;
  $27 = tempRet0;
  ___clang_call_terminate($26);
  // unreachable;
 } else {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
}
function __ZN3osg10NullStreamD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = ((63176));
 $1 = ((($0)) + 8|0);
 HEAP32[$1>>2] = ((63196));
 $2 = ((($0)) + 32|0);
 $3 = ((($0)) + 8|0);
 HEAP32[$2>>2] = 0;
 __THREW__ = 0;
 invoke_vii(3259,($3|0),0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 do {
  if ($5) {
   label = 5;
  } else {
   $6 = ((($0)) + 4|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($7|0)==(0|0);
   if (!($8)) {
    $9 = HEAP32[$7>>2]|0;
    $10 = ((($9)) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    __THREW__ = 0;
    invoke_vi($11|0,($7|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     label = 5;
     break;
    }
   }
   __THREW__ = 0;
   invoke_vii(3614,($0|0),((63208)|0));
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if ($15) {
    $22 = ___cxa_find_matching_catch_2()|0;
    $23 = tempRet0;
    $eh$lpad$body$index2Z2D = $23;$eh$lpad$body$indexZ2D = $22;
    break;
   } else {
    __ZNSt3__29basic_iosIcNS_11char_traitsIcEEED2Ev($1);
    return;
   }
  }
 } while(0);
 if ((label|0) == 5) {
  $16 = ___cxa_find_matching_catch_2()|0;
  $17 = tempRet0;
  __THREW__ = 0;
  invoke_vii(3614,($0|0),((63208)|0));
  $18 = __THREW__; __THREW__ = 0;
  $19 = $18&1;
  if ($19) {
   $20 = ___cxa_find_matching_catch_3(0|0)|0;
   $21 = tempRet0;
   ___clang_call_terminate($20);
   // unreachable;
  } else {
   $eh$lpad$body$index2Z2D = $17;$eh$lpad$body$indexZ2D = $16;
  }
 }
 __THREW__ = 0;
 invoke_vi(2907,($1|0));
 $24 = __THREW__; __THREW__ = 0;
 $25 = $24&1;
 if ($25) {
  $26 = ___cxa_find_matching_catch_3(0|0)|0;
  $27 = tempRet0;
  ___clang_call_terminate($26);
  // unreachable;
 } else {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
}
function __ZN3osg10NullStreamD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(2039,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZTv0_n12_N3osg10NullStreamD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __ZN3osg10NullStreamD1Ev($4);
 return;
}
function __ZTv0_n12_N3osg10NullStreamD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __THREW__ = 0;
 invoke_vi(2039,($4|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $7 = ___cxa_find_matching_catch_2()|0;
  $8 = tempRet0;
  __ZdlPv($4);
  ___resumeException($7|0);
  // unreachable;
 } else {
  __ZdlPv($4);
  return;
 }
}
function __ZN3osg12NotifyStreamD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(2043,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZTv0_n12_N3osg12NotifyStreamD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __ZN3osg12NotifyStreamD1Ev($4);
 return;
}
function __ZTv0_n12_N3osg12NotifyStreamD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __THREW__ = 0;
 invoke_vi(2043,($4|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $7 = ___cxa_find_matching_catch_2()|0;
  $8 = tempRet0;
  __ZdlPv($4);
  ___resumeException($7|0);
  // unreachable;
 } else {
  __ZdlPv($4);
  return;
 }
}
function __ZN3osg10NullStreamC1Ev($0) {
 $0 = $0|0;
 var $$0 = 0, $$02 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 8|0);
 HEAP32[$1>>2] = (96064);
 __THREW__ = 0;
 $2 = (invoke_ii(3276,32)|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 do {
  if ($4) {
   label = 5;
  } else {
   __THREW__ = 0;
   invoke_vi(3369,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if ($6) {
    $17 = ___cxa_find_matching_catch_2()|0;
    $18 = tempRet0;
    __ZdlPv($2);
    $$0 = $18;$$02 = $17;
    break;
   }
   HEAP32[$2>>2] = (63348);
   HEAP32[$0>>2] = ((26036));
   HEAP32[$1>>2] = ((26056));
   $7 = ((($0)) + 8|0);
   __THREW__ = 0;
   invoke_vii(3368,($7|0),($2|0));
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if ($9) {
    label = 5;
   } else {
    $10 = ((($0)) + 80|0);
    HEAP32[$10>>2] = 0;
    $11 = ((($0)) + 84|0);
    HEAP32[$11>>2] = -1;
    HEAP32[$0>>2] = (63176);
    HEAP32[$1>>2] = (63196);
    $12 = ((($0)) + 32|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = ((($0)) + 4|0);
    HEAP32[$14>>2] = $13;
    return;
   }
  }
 } while(0);
 if ((label|0) == 5) {
  $15 = ___cxa_find_matching_catch_2()|0;
  $16 = tempRet0;
  $$0 = $16;$$02 = $15;
 }
 __THREW__ = 0;
 invoke_vi(2907,($1|0));
 $19 = __THREW__; __THREW__ = 0;
 $20 = $19&1;
 if ($20) {
  $21 = ___cxa_find_matching_catch_3(0|0)|0;
  $22 = tempRet0;
  ___clang_call_terminate($21);
  // unreachable;
 } else {
  ___resumeException($$02|0);
  // unreachable;
 }
}
function __ZN3osg12NotifyStreamC1Ev($0) {
 $0 = $0|0;
 var $$0 = 0, $$02 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 8|0);
 HEAP32[$1>>2] = (96064);
 __THREW__ = 0;
 $2 = (invoke_ii(3276,60)|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 do {
  if ($4) {
   label = 5;
  } else {
   __THREW__ = 0;
   invoke_vi(3835,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if ($6) {
    $17 = ___cxa_find_matching_catch_2()|0;
    $18 = tempRet0;
    __ZdlPv($2);
    $$0 = $18;$$02 = $17;
    break;
   }
   HEAP32[$0>>2] = ((26036));
   HEAP32[$1>>2] = ((26056));
   $7 = ((($0)) + 8|0);
   __THREW__ = 0;
   invoke_vii(3368,($7|0),($2|0));
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if ($9) {
    label = 5;
   } else {
    $10 = ((($0)) + 80|0);
    HEAP32[$10>>2] = 0;
    $11 = ((($0)) + 84|0);
    HEAP32[$11>>2] = -1;
    HEAP32[$0>>2] = (63232);
    HEAP32[$1>>2] = (63252);
    $12 = ((($0)) + 32|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = ((($0)) + 4|0);
    HEAP32[$14>>2] = $13;
    return;
   }
  }
 } while(0);
 if ((label|0) == 5) {
  $15 = ___cxa_find_matching_catch_2()|0;
  $16 = tempRet0;
  $$0 = $16;$$02 = $15;
 }
 __THREW__ = 0;
 invoke_vi(2907,($1|0));
 $19 = __THREW__; __THREW__ = 0;
 $20 = $19&1;
 if ($20) {
  $21 = ___cxa_find_matching_catch_3(0|0)|0;
  $22 = tempRet0;
  ___clang_call_terminate($21);
  // unreachable;
 } else {
  ___resumeException($$02|0);
  // unreachable;
 }
}
function __ZN3osg18NotifyStreamBufferC2Ev($0) {
 $0 = $0|0;
 var $$0 = 0, $$02 = 0, $$1 = 0, $$13 = 0, $$byval_copy = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(80|0);
 $$byval_copy = sp + 32|0;
 $1 = sp + 16|0;
 $2 = sp + 60|0;
 $3 = sp + 48|0;
 $4 = sp;
 __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEEC2Ev($0);
 HEAP32[$0>>2] = (37132);
 $5 = ((($0)) + 32|0);
 $6 = ((($0)) + 48|0);
 ;HEAP32[$5>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;HEAP32[$5+12>>2]=0|0;
 HEAP32[$6>>2] = 24;
 ;HEAP32[$2>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;
 __THREW__ = 0;
 invoke_vii(3370,($0|0),($2|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $13 = ___cxa_find_matching_catch_2()|0;
  $14 = tempRet0;
  $15 = ((($2)) + 11|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = ($16<<24>>24)<(0);
  if ($17) {
   $18 = HEAP32[$2>>2]|0;
   __ZdlPv($18);
  }
  $19 = ((($5)) + 11|0);
  $20 = HEAP8[$19>>0]|0;
  $21 = ($20<<24>>24)<(0);
  if ($21) {
   $22 = HEAP32[$5>>2]|0;
   __ZdlPv($22);
  }
  __THREW__ = 0;
  invoke_vi(2911,($0|0));
  $23 = __THREW__; __THREW__ = 0;
  $24 = $23&1;
  if ($24) {
   $25 = ___cxa_find_matching_catch_3(0|0)|0;
   $26 = tempRet0;
   ___clang_call_terminate($25);
   // unreachable;
  } else {
   ___resumeException($13|0);
   // unreachable;
  }
 }
 $9 = ((($2)) + 11|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = ($10<<24>>24)<(0);
 if ($11) {
  $12 = HEAP32[$2>>2]|0;
  __ZdlPv($12);
 }
 HEAP32[$0>>2] = (63284);
 $27 = ((($0)) + 52|0);
 HEAP32[$27>>2] = 0;
 $28 = ((($0)) + 56|0);
 HEAP32[$28>>2] = 3;
 ;HEAP32[$3>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;
 __THREW__ = 0;
 $29 = (invoke_ii(3276,4096)|0);
 $30 = __THREW__; __THREW__ = 0;
 $31 = $30&1;
 do {
  if ($31) {
   $45 = ___cxa_find_matching_catch_2()|0;
   $46 = tempRet0;
   $$0 = $46;$$02 = $45;
   label = 20;
  } else {
   HEAP32[$3>>2] = $29;
   $32 = ((($3)) + 8|0);
   HEAP32[$32>>2] = -2147479552;
   $33 = ((($3)) + 4|0);
   HEAP32[$33>>2] = 4095;
   _memset(($29|0),0,4096)|0;
   __THREW__ = 0;
   invoke_vii(3370,($0|0),($3|0));
   $34 = __THREW__; __THREW__ = 0;
   $35 = $34&1;
   if ($35) {
    $47 = ___cxa_find_matching_catch_2()|0;
    $48 = tempRet0;
    $49 = ((($3)) + 11|0);
    $50 = HEAP8[$49>>0]|0;
    $51 = ($50<<24>>24)<(0);
    if (!($51)) {
     $$0 = $48;$$02 = $47;
     label = 20;
     break;
    }
    $52 = HEAP32[$3>>2]|0;
    __ZdlPv($52);
    $$0 = $48;$$02 = $47;
    label = 20;
    break;
   }
   $36 = ((($3)) + 11|0);
   $37 = HEAP8[$36>>0]|0;
   $38 = ($37<<24>>24)<(0);
   if ($38) {
    $39 = HEAP32[$3>>2]|0;
    __ZdlPv($39);
   }
   ;HEAP32[$1>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;HEAP32[$1+12>>2]=0|0;
   $40 = HEAP32[$0>>2]|0;
   $41 = ((($40)) + 20|0);
   $42 = HEAP32[$41>>2]|0;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy>>2]=HEAP32[$1>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$1+12>>2]|0;
   invoke_viiii($42|0,($4|0),($0|0),($$byval_copy|0),16);
   $43 = __THREW__; __THREW__ = 0;
   $44 = $43&1;
   if ($44) {
    $53 = ___cxa_find_matching_catch_2()|0;
    $54 = tempRet0;
    $$1 = $54;$$13 = $53;
    break;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 20) {
  $$1 = $$0;$$13 = $$02;
 }
 $55 = HEAP32[$27>>2]|0;
 $56 = ($55|0)==(0|0);
 if (!($56)) {
  $57 = ((($55)) + 8|0);
  $58 = HEAP32[$57>>2]|0;HEAP32[$57>>2] = (($58-1)|0);
  $59 = ($58|0)==(1);
  if ($59) {
   __THREW__ = 0;
   invoke_viii(3262,($55|0),1,1);
   $60 = __THREW__; __THREW__ = 0;
   $61 = $60&1;
   if ($61) {
    $68 = ___cxa_find_matching_catch_3(0|0)|0;
    $69 = tempRet0;
    ___clang_call_terminate($68);
    // unreachable;
   }
  }
 }
 HEAP32[$27>>2] = 0;
 HEAP32[$0>>2] = (37132);
 $62 = ((($5)) + 11|0);
 $63 = HEAP8[$62>>0]|0;
 $64 = ($63<<24>>24)<(0);
 if ($64) {
  $65 = HEAP32[$5>>2]|0;
  __ZdlPv($65);
 }
 __THREW__ = 0;
 invoke_vi(2911,($0|0));
 $66 = __THREW__; __THREW__ = 0;
 $67 = $66&1;
 if ($67) {
  $68 = ___cxa_find_matching_catch_3(0|0)|0;
  $69 = tempRet0;
  ___clang_call_terminate($68);
  // unreachable;
 } else {
  ___resumeException($$13|0);
  // unreachable;
 }
}
function __ZN3osg18NotifyStreamBufferD2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (63284);
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = ((($2)) + 8|0);
  $5 = HEAP32[$4>>2]|0;HEAP32[$4>>2] = (($5-1)|0);
  $6 = ($5|0)==(1);
  if ($6) {
   __THREW__ = 0;
   invoke_viii(3262,($2|0),1,1);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $14 = ___cxa_find_matching_catch_2()|0;
    $15 = tempRet0;
    HEAP32[$0>>2] = (37132);
    $16 = ((($0)) + 32|0);
    $17 = ((($16)) + 11|0);
    $18 = HEAP8[$17>>0]|0;
    $19 = ($18<<24>>24)<(0);
    if ($19) {
     $20 = HEAP32[$16>>2]|0;
     __ZdlPv($20);
    }
    __THREW__ = 0;
    invoke_vi(2911,($0|0));
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if ($22) {
     $23 = ___cxa_find_matching_catch_3(0|0)|0;
     $24 = tempRet0;
     ___clang_call_terminate($23);
     // unreachable;
    } else {
     ___resumeException($14|0);
     // unreachable;
    }
   }
  }
 }
 HEAP32[$1>>2] = 0;
 HEAP32[$0>>2] = (37132);
 $9 = ((($0)) + 32|0);
 $10 = ((($9)) + 11|0);
 $11 = HEAP8[$10>>0]|0;
 $12 = ($11<<24>>24)<(0);
 if (!($12)) {
  __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEED2Ev($0);
  return;
 }
 $13 = HEAP32[$9>>2]|0;
 __ZdlPv($13);
 __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEED2Ev($0);
 return;
}
function __ZN3osg18NotifyStreamBufferD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (63284);
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = ((($2)) + 8|0);
  $5 = HEAP32[$4>>2]|0;HEAP32[$4>>2] = (($5-1)|0);
  $6 = ($5|0)==(1);
  if ($6) {
   __THREW__ = 0;
   invoke_viii(3262,($2|0),1,1);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $16 = ___cxa_find_matching_catch_2()|0;
    $17 = tempRet0;
    HEAP32[$0>>2] = (37132);
    $18 = ((($0)) + 32|0);
    $19 = ((($18)) + 11|0);
    $20 = HEAP8[$19>>0]|0;
    $21 = ($20<<24>>24)<(0);
    if ($21) {
     $22 = HEAP32[$18>>2]|0;
     __ZdlPv($22);
    }
    __THREW__ = 0;
    invoke_vi(2911,($0|0));
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if ($24) {
     $25 = ___cxa_find_matching_catch_3(0|0)|0;
     $26 = tempRet0;
     ___clang_call_terminate($25);
     // unreachable;
    } else {
     $eh$lpad$body$index2Z2D = $17;$eh$lpad$body$indexZ2D = $16;
     __ZdlPv($0);
     ___resumeException($eh$lpad$body$indexZ2D|0);
     // unreachable;
    }
   }
  }
 }
 HEAP32[$1>>2] = 0;
 HEAP32[$0>>2] = (37132);
 $9 = ((($0)) + 32|0);
 $10 = ((($9)) + 11|0);
 $11 = HEAP8[$10>>0]|0;
 $12 = ($11<<24>>24)<(0);
 if ($12) {
  $13 = HEAP32[$9>>2]|0;
  __ZdlPv($13);
 }
 __THREW__ = 0;
 invoke_vi(2911,($0|0));
 $14 = __THREW__; __THREW__ = 0;
 $15 = $14&1;
 if (!($15)) {
  __ZdlPv($0);
  return;
 }
 $27 = ___cxa_find_matching_catch_2()|0;
 $28 = tempRet0;
 $eh$lpad$body$index2Z2D = $28;$eh$lpad$body$indexZ2D = $27;
 __ZdlPv($0);
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
}
function __ZN3osg18NotifyStreamBuffer4syncEv($0) {
 $0 = $0|0;
 var $$byval_copy = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $$byval_copy = sp + 32|0;
 $1 = sp + 16|0;
 $2 = sp;
 $3 = ((($0)) + 24|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 28|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4|0)==($6|0);
 if ($7) {
  $8 = HEAP32[$0>>2]|0;
  $9 = ((($8)) + 52|0);
  $10 = HEAP32[$9>>2]|0;
  (FUNCTION_TABLE_iii[$10 & 8191]($0,0)|0);
 } else {
  $11 = ((($4)) + 1|0);
  HEAP32[$3>>2] = $11;
  HEAP8[$4>>0] = 0;
 }
 $12 = ((($0)) + 52|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0|0);
 if (!($14)) {
  $15 = HEAP32[$13>>2]|0;
  $16 = ((($15)) + 12|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = ((($0)) + 56|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = ((($0)) + 20|0);
  $21 = HEAP32[$20>>2]|0;
  FUNCTION_TABLE_viii[$17 & 8191]($13,$19,$21);
 }
 ;HEAP32[$1>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;HEAP32[$1+12>>2]=0|0;
 $22 = HEAP32[$0>>2]|0;
 $23 = ((($22)) + 20|0);
 $24 = HEAP32[$23>>2]|0;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$1>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$1+12>>2]|0;
 FUNCTION_TABLE_viiii[$24 & 8191]($2,$0,$$byval_copy,16);
 STACKTOP = sp;return 0;
}
function __ZN3osg16NullStreamBufferD2Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEED2Ev($0);
 return;
}
function __ZN3osg16NullStreamBufferD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(2911,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZN3osg16NullStreamBuffer6xsputnEPKci($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ($2|0);
}
function __ZN3osg14setNotifyLevelENS_14NotifySeverityE($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP8[206072]|0;
 $2 = ($1<<24>>24)==(0);
 if (!($2)) {
  HEAP32[52117] = $0;
  return;
 }
 $3 = (___cxa_guard_acquire(206072)|0);
 $4 = ($3|0)==(0);
 if ($4) {
  HEAP32[52117] = $0;
  return;
 }
 __THREW__ = 0;
 invoke_vi(3832,(208468|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $7 = ___cxa_find_matching_catch_2()|0;
  $8 = tempRet0;
  ___resumeException($7|0);
  // unreachable;
 }
 (___cxa_atexit((3833|0),(208468|0),(___dso_handle|0))|0);
 HEAP32[52117] = $0;
 return;
}
function __ZN3osg14getNotifyLevelEv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[206072]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  $8 = HEAP32[52117]|0;
  return ($8|0);
 }
 $2 = (___cxa_guard_acquire(206072)|0);
 $3 = ($2|0)==(0);
 if ($3) {
  $8 = HEAP32[52117]|0;
  return ($8|0);
 }
 __THREW__ = 0;
 invoke_vi(3832,(208468|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch_2()|0;
  $7 = tempRet0;
  ___resumeException($6|0);
  // unreachable;
 }
 (___cxa_atexit((3833|0),(208468|0),(___dso_handle|0))|0);
 $8 = HEAP32[52117]|0;
 return ($8|0);
}
function __ZN3osg16setNotifyHandlerEPNS_13NotifyHandlerE($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP8[206072]|0;
 $2 = ($1<<24>>24)==(0);
 do {
  if ($2) {
   $3 = (___cxa_guard_acquire(206072)|0);
   $4 = ($3|0)==(0);
   if (!($4)) {
    __THREW__ = 0;
    invoke_vi(3832,(208468|0));
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     $7 = ___cxa_find_matching_catch_2()|0;
     $8 = tempRet0;
     ___resumeException($7|0);
     // unreachable;
    } else {
     (___cxa_atexit((3833|0),(208468|0),(___dso_handle|0))|0);
     break;
    }
   }
  }
 } while(0);
 $9 = HEAP32[(208560)>>2]|0;
 $10 = ((($9)) + -12|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((208560) + ($11)|0);
 $13 = ((($12)) + 24|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(0|0);
 if ($15) {
  return;
 }
 $16 = ((($14)) + 52|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==($0|0);
 if ($18) {
  return;
 }
 HEAP32[$16>>2] = $0;
 $19 = ($0|0)==(0|0);
 if (!($19)) {
  $20 = ((($0)) + 8|0);
  $21 = HEAP32[$20>>2]|0;HEAP32[$20>>2] = (($21+1)|0);
 }
 $22 = ($17|0)==(0|0);
 if ($22) {
  return;
 }
 $23 = ((($17)) + 8|0);
 $24 = HEAP32[$23>>2]|0;HEAP32[$23>>2] = (($24-1)|0);
 $25 = ($24|0)==(1);
 if (!($25)) {
  return;
 }
 __ZNK3osg10Referenced24signalObserversAndDeleteEbb($17,1,1);
 return;
}
function __ZN3osg15isNotifyEnabledENS_14NotifySeverityE($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP8[206072]|0;
 $2 = ($1<<24>>24)==(0);
 do {
  if ($2) {
   $3 = (___cxa_guard_acquire(206072)|0);
   $4 = ($3|0)==(0);
   if (!($4)) {
    __THREW__ = 0;
    invoke_vi(3832,(208468|0));
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     $7 = ___cxa_find_matching_catch_2()|0;
     $8 = tempRet0;
     ___resumeException($7|0);
     // unreachable;
    } else {
     (___cxa_atexit((3833|0),(208468|0),(___dso_handle|0))|0);
     break;
    }
   }
  }
 } while(0);
 $9 = HEAP32[52117]|0;
 $10 = ($9|0)>=($0|0);
 return ($10|0);
}
function __ZN3osg6notifyENS_14NotifySeverityE($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP8[206072]|0;
 $2 = ($1<<24>>24)==(0);
 do {
  if ($2) {
   $3 = (___cxa_guard_acquire(206072)|0);
   $4 = ($3|0)==(0);
   if (!($4)) {
    __THREW__ = 0;
    invoke_vi(3832,(208468|0));
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     $7 = ___cxa_find_matching_catch_2()|0;
     $8 = tempRet0;
     ___resumeException($7|0);
     // unreachable;
    } else {
     (___cxa_atexit((3833|0),(208468|0),(___dso_handle|0))|0);
     break;
    }
   }
  }
 } while(0);
 $9 = HEAP32[52117]|0;
 $10 = ($9|0)<($0|0);
 $11 = HEAP8[206072]|0;
 $12 = ($11<<24>>24)==(0);
 do {
  if ($12) {
   $13 = (___cxa_guard_acquire(206072)|0);
   $14 = ($13|0)==(0);
   if (!($14)) {
    __THREW__ = 0;
    invoke_vi(3832,(208468|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     $17 = ___cxa_find_matching_catch_2()|0;
     $18 = tempRet0;
     ___resumeException($17|0);
     // unreachable;
    } else {
     (___cxa_atexit((3833|0),(208468|0),(___dso_handle|0))|0);
     break;
    }
   }
  }
 } while(0);
 if ($10) {
  $$0 = (208472);
  return ($$0|0);
 }
 $19 = HEAP32[(208564)>>2]|0;
 $20 = ((($19)) + 56|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==($0|0);
 if (!($22)) {
  $23 = HEAP32[$19>>2]|0;
  $24 = ((($23)) + 24|0);
  $25 = HEAP32[$24>>2]|0;
  (FUNCTION_TABLE_ii[$25 & 8191]($19)|0);
  HEAP32[$20>>2] = $0;
 }
 $26 = HEAP8[206072]|0;
 $27 = ($26<<24>>24)==(0);
 if (!($27)) {
  $$0 = (208560);
  return ($$0|0);
 }
 $28 = (___cxa_guard_acquire(206072)|0);
 $29 = ($28|0)==(0);
 if ($29) {
  $$0 = (208560);
  return ($$0|0);
 }
 __THREW__ = 0;
 invoke_vi(3832,(208468|0));
 $30 = __THREW__; __THREW__ = 0;
 $31 = $30&1;
 if ($31) {
  $32 = ___cxa_find_matching_catch_2()|0;
  $33 = tempRet0;
  ___resumeException($32|0);
  // unreachable;
 }
 (___cxa_atexit((3833|0),(208468|0),(___dso_handle|0))|0);
 $$0 = (208560);
 return ($$0|0);
}
function __ZN3osg6Object21setThreadSafeRefUnrefEb($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  return;
 }
 $5 = HEAP32[$3>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 FUNCTION_TABLE_vii[$6 & 8191]($3,$1);
 return;
}
function __ZN3osg6ObjectD2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (63412);
 $1 = ((($0)) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = ((($2)) + 8|0);
  $5 = HEAP32[$4>>2]|0;HEAP32[$4>>2] = (($5-1)|0);
  $6 = ($5|0)==(1);
  if ($6) {
   __THREW__ = 0;
   invoke_viii(3262,($2|0),1,1);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $9 = ___cxa_find_matching_catch_2()|0;
    $10 = tempRet0;
    $11 = ((($0)) + 12|0);
    $12 = ((($11)) + 11|0);
    $13 = HEAP8[$12>>0]|0;
    $14 = ($13<<24>>24)<(0);
    if ($14) {
     $15 = HEAP32[$11>>2]|0;
     __ZdlPv($15);
    }
    __THREW__ = 0;
    invoke_vi(712,($0|0));
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     $23 = ___cxa_find_matching_catch_3(0|0)|0;
     $24 = tempRet0;
     ___clang_call_terminate($23);
     // unreachable;
    } else {
     ___resumeException($9|0);
     // unreachable;
    }
   }
  }
 }
 $18 = ((($0)) + 12|0);
 $19 = ((($18)) + 11|0);
 $20 = HEAP8[$19>>0]|0;
 $21 = ($20<<24>>24)<(0);
 if (!($21)) {
  __ZN3osg10ReferencedD2Ev($0);
  return;
 }
 $22 = HEAP32[$18>>2]|0;
 __ZdlPv($22);
 __ZN3osg10ReferencedD2Ev($0);
 return;
}
function __ZN3osg6ObjectD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(388,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZN3osg6Object11setUserDataEPNS_10ReferencedE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$pre$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $3 = ((($2)) + 124|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_ii[$4 & 8191]($0)|0);
 $6 = ($5|0)==($1|0);
 if ($6) {
  return;
 }
 $7 = ((($0)) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if ($9) {
  $10 = (__Znwj(60)|0);
  __THREW__ = 0;
  invoke_vi(3836,($10|0));
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if ($12) {
   $21 = ___cxa_find_matching_catch_2()|0;
   $22 = tempRet0;
   __ZdlPv($10);
   ___resumeException($21|0);
   // unreachable;
  }
  $13 = HEAP32[$7>>2]|0;
  $14 = ($13|0)==($10|0);
  if ($14) {
   $24 = $10;
  } else {
   $15 = ($13|0)==(0|0);
   if (!($15)) {
    $16 = ((($13)) + 8|0);
    $17 = HEAP32[$16>>2]|0;HEAP32[$16>>2] = (($17-1)|0);
    $18 = ($17|0)==(1);
    if ($18) {
     __ZNK3osg10Referenced24signalObserversAndDeleteEbb($13,1,1);
    }
   }
   HEAP32[$7>>2] = $10;
   $19 = ((($10)) + 8|0);
   $20 = HEAP32[$19>>2]|0;HEAP32[$19>>2] = (($20+1)|0);
   $$pre$i = HEAP32[$7>>2]|0;
   $24 = $$pre$i;
  }
 } else {
  $24 = $8;
 }
 $23 = HEAP32[$24>>2]|0;
 $25 = ((($23)) + 120|0);
 $26 = HEAP32[$25>>2]|0;
 FUNCTION_TABLE_vii[$26 & 8191]($24,$1);
 return;
}
function __ZN3osg6Object11getUserDataEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  $8 = 0;
  return ($8|0);
 }
 $4 = HEAP32[$2>>2]|0;
 $5 = ((($4)) + 124|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_ii[$6 & 8191]($2)|0);
 $8 = $7;
 return ($8|0);
}
function __ZNK3osg6Object11getUserDataEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  $8 = 0;
  return ($8|0);
 }
 $4 = HEAP32[$2>>2]|0;
 $5 = ((($4)) + 124|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_ii[$6 & 8191]($2)|0);
 $8 = $7;
 return ($8|0);
}
function __ZN3osg6ObjectC2ERKS0_RKNS_6CopyOpE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$08 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg10ReferencedC2Ev($0);
 HEAP32[$0>>2] = (63412);
 $3 = ((($0)) + 12|0);
 $4 = ((($1)) + 12|0);
 __THREW__ = 0;
 invoke_vii(3457,($3|0),($4|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $32 = ___cxa_find_matching_catch_2()|0;
  $33 = tempRet0;
  $$0 = $33;$$08 = $32;
 } else {
  $7 = ((($0)) + 24|0);
  $8 = ((($1)) + 24|0);
  $9 = HEAP32[$8>>2]|0;
  HEAP32[$7>>2] = $9;
  $10 = ((($0)) + 28|0);
  HEAP32[$10>>2] = 0;
  $11 = ((($1)) + 28|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($12|0)==(0|0);
  if ($13) {
   return;
  }
  $14 = ((($2)) + 4|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = $15 & 4096;
  $17 = ($16|0)==(0);
  if ($17) {
   HEAP32[$10>>2] = $12;
   $40 = ((($12)) + 8|0);
   $41 = HEAP32[$40>>2]|0;HEAP32[$40>>2] = (($41+1)|0);
   return;
  }
  __THREW__ = 0;
  $18 = (invoke_iii(3837,($12|0),($2|0))|0);
  $19 = __THREW__; __THREW__ = 0;
  $20 = $19&1;
  do {
   if (!($20)) {
    $21 = HEAP32[$10>>2]|0;
    $22 = ($21|0)==($18|0);
    if ($22) {
     return;
    }
    $23 = ($21|0)==(0|0);
    if (!($23)) {
     $24 = ((($21)) + 8|0);
     $25 = HEAP32[$24>>2]|0;HEAP32[$24>>2] = (($25-1)|0);
     $26 = ($25|0)==(1);
     if ($26) {
      __THREW__ = 0;
      invoke_viii(3262,($21|0),1,1);
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       break;
      }
     }
    }
    HEAP32[$10>>2] = $18;
    $29 = ($18|0)==(0|0);
    if ($29) {
     return;
    }
    $30 = ((($18)) + 8|0);
    $31 = HEAP32[$30>>2]|0;HEAP32[$30>>2] = (($31+1)|0);
    return;
   }
  } while(0);
  $34 = ___cxa_find_matching_catch_2()|0;
  $35 = tempRet0;
  $36 = ((($3)) + 11|0);
  $37 = HEAP8[$36>>0]|0;
  $38 = ($37<<24>>24)<(0);
  if ($38) {
   $39 = HEAP32[$3>>2]|0;
   __ZdlPv($39);
   $$0 = $35;$$08 = $34;
  } else {
   $$0 = $35;$$08 = $34;
  }
 }
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $42 = __THREW__; __THREW__ = 0;
 $43 = $42&1;
 if ($43) {
  $44 = ___cxa_find_matching_catch_3(0|0)|0;
  $45 = tempRet0;
  ___clang_call_terminate($44);
  // unreachable;
 } else {
  ___resumeException($$08|0);
  // unreachable;
 }
}
function __ZN3osg5cloneINS_17UserDataContainerEEEPT_PKS2_RKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp + 4|0;
 $3 = sp;
 $4 = ($0|0)==(0|0);
 if ($4) {
  $62 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
  if (!($62)) {
   $$1 = 0;
   STACKTOP = sp;return ($$1|0);
  }
  $63 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
  $64 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($63,166509,88)|0);
  $65 = HEAP32[$64>>2]|0;
  $66 = ((($65)) + -12|0);
  $67 = HEAP32[$66>>2]|0;
  $68 = (($64) + ($67)|0);
  __ZNKSt3__28ios_base6getlocEv($3,$68);
  __THREW__ = 0;
  $69 = (invoke_iii(3255,($3|0),(215188|0))|0);
  $70 = __THREW__; __THREW__ = 0;
  $71 = $70&1;
  if (!($71)) {
   $72 = HEAP32[$69>>2]|0;
   $73 = ((($72)) + 28|0);
   $74 = HEAP32[$73>>2]|0;
   __THREW__ = 0;
   $75 = (invoke_iii($74|0,($69|0),10)|0);
   $76 = __THREW__; __THREW__ = 0;
   $77 = $76&1;
   if (!($77)) {
    __ZNSt3__26localeD2Ev($3);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($64,$75)|0);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($64)|0);
    $$1 = 0;
    STACKTOP = sp;return ($$1|0);
   }
  }
  $78 = ___cxa_find_matching_catch_2()|0;
  $79 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3263,($3|0));
  $80 = __THREW__; __THREW__ = 0;
  $81 = $80&1;
  if ($81) {
   $82 = ___cxa_find_matching_catch_3(0|0)|0;
   $83 = tempRet0;
   ___clang_call_terminate($82);
   // unreachable;
  } else {
   ___resumeException($78|0);
   // unreachable;
  }
 }
 $5 = HEAP32[$0>>2]|0;
 $6 = ((($5)) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_iii[$7 & 8191]($0,$1)|0);
 $9 = ($8|0)==(0|0);
 if ($9) {
  label = 9;
 } else {
  $10 = ((($8)) + 8|0);
  $11 = HEAP32[$10>>2]|0;HEAP32[$10>>2] = (($11+1)|0);
  $12 = (___dynamic_cast($8,26112,26976,0)|0);
  $13 = ($12|0)==(0|0);
  if ($13) {
   label = 9;
  } else {
   __THREW__ = 0;
   (invoke_ii(3335,($8|0))|0);
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if ($15) {
    label = 5;
   } else {
    $$1 = $12;
    STACKTOP = sp;return ($$1|0);
   }
  }
 }
 L19: do {
  if ((label|0) == 9) {
   __THREW__ = 0;
   $23 = (invoke_ii(3265,2)|0);
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   if ($25) {
    label = 5;
   } else {
    do {
     if ($23) {
      __THREW__ = 0;
      $26 = (invoke_ii(3266,2)|0);
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       label = 5;
       break L19;
      }
      __THREW__ = 0;
      $29 = (invoke_iiii(3267,($26|0),(166420|0),88)|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 5;
       break L19;
      }
      $32 = HEAP32[$29>>2]|0;
      $33 = ((($32)) + -12|0);
      $34 = HEAP32[$33>>2]|0;
      $35 = (($29) + ($34)|0);
      __THREW__ = 0;
      invoke_vii(3257,($2|0),($35|0));
      $36 = __THREW__; __THREW__ = 0;
      $37 = $36&1;
      if ($37) {
       label = 5;
       break L19;
      }
      __THREW__ = 0;
      $38 = (invoke_iii(3255,($2|0),(215188|0))|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       $41 = HEAP32[$38>>2]|0;
       $42 = ((($41)) + 28|0);
       $43 = HEAP32[$42>>2]|0;
       __THREW__ = 0;
       $44 = (invoke_iii($43|0,($38|0),10)|0);
       $45 = __THREW__; __THREW__ = 0;
       $46 = $45&1;
       if (!($46)) {
        __THREW__ = 0;
        invoke_vi(3263,($2|0));
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 5;
         break L19;
        }
        __THREW__ = 0;
        (invoke_iii(3268,($29|0),($44|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 5;
         break L19;
        }
        __THREW__ = 0;
        (invoke_ii(3269,($29|0))|0);
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 5;
         break L19;
        } else {
         break;
        }
       }
      }
      $49 = ___cxa_find_matching_catch_2()|0;
      $50 = tempRet0;
      __THREW__ = 0;
      invoke_vi(3263,($2|0));
      $51 = __THREW__; __THREW__ = 0;
      $52 = $51&1;
      if ($52) {
       $53 = ___cxa_find_matching_catch_3(0|0)|0;
       $54 = tempRet0;
       ___clang_call_terminate($53);
       // unreachable;
      } else {
       $eh$lpad$body$index2Z2D = $50;$eh$lpad$body$indexZ2D = $49;
       break L19;
      }
     }
    } while(0);
    if ($9) {
     $$1 = 0;
     STACKTOP = sp;return ($$1|0);
    }
    $59 = ((($8)) + 8|0);
    $60 = HEAP32[$59>>2]|0;HEAP32[$59>>2] = (($60-1)|0);
    $61 = ($60|0)==(1);
    if (!($61)) {
     $$1 = 0;
     STACKTOP = sp;return ($$1|0);
    }
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($8,1,1);
    $$1 = 0;
    STACKTOP = sp;return ($$1|0);
   }
  }
 } while(0);
 if ((label|0) == 5) {
  $16 = ___cxa_find_matching_catch_2()|0;
  $17 = tempRet0;
  $eh$lpad$body$index2Z2D = $17;$eh$lpad$body$indexZ2D = $16;
 }
 if ($9) {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 $18 = ((($8)) + 8|0);
 $19 = HEAP32[$18>>2]|0;HEAP32[$18>>2] = (($19-1)|0);
 $20 = ($19|0)==(1);
 if (!($20)) {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(3262,($8|0),1,1);
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if ($22) {
  $84 = ___cxa_find_matching_catch_3(0|0)|0;
  $85 = tempRet0;
  ___clang_call_terminate($84);
  // unreachable;
 } else {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 return (0)|0;
}
function __ZN3osg6Object20setUserDataContainerEPNS_17UserDataContainerE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==($1|0);
 if ($4) {
  return;
 }
 $5 = ($3|0)==(0|0);
 if (!($5)) {
  $6 = ((($3)) + 8|0);
  $7 = HEAP32[$6>>2]|0;HEAP32[$6>>2] = (($7-1)|0);
  $8 = ($7|0)==(1);
  if ($8) {
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($3,1,1);
  }
 }
 HEAP32[$2>>2] = $1;
 $9 = ($1|0)==(0|0);
 if ($9) {
  return;
 }
 $10 = ((($1)) + 8|0);
 $11 = HEAP32[$10>>2]|0;HEAP32[$10>>2] = (($11+1)|0);
 return;
}
function __ZN3osg6Object28getOrCreateUserDataContainerEv($0) {
 $0 = $0|0;
 var $$pre = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $17 = $2;
  return ($17|0);
 }
 $4 = (__Znwj(60)|0);
 __THREW__ = 0;
 invoke_vi(3836,($4|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $15 = ___cxa_find_matching_catch_2()|0;
  $16 = tempRet0;
  __ZdlPv($4);
  ___resumeException($15|0);
  // unreachable;
 }
 $7 = HEAP32[$1>>2]|0;
 $8 = ($7|0)==($4|0);
 if ($8) {
  $17 = $4;
  return ($17|0);
 }
 $9 = ($7|0)==(0|0);
 if (!($9)) {
  $10 = ((($7)) + 8|0);
  $11 = HEAP32[$10>>2]|0;HEAP32[$10>>2] = (($11-1)|0);
  $12 = ($11|0)==(1);
  if ($12) {
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($7,1,1);
  }
 }
 HEAP32[$1>>2] = $4;
 $13 = ((($4)) + 8|0);
 $14 = HEAP32[$13>>2]|0;HEAP32[$13>>2] = (($14+1)|0);
 $$pre = HEAP32[$1>>2]|0;
 $17 = $$pre;
 return ($17|0);
}
function __ZN3osg8ObserverD2Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN3osg8ObserverD0Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($0);
 return;
}
function __ZN3osg8Observer13objectDeletedEPv($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN3osg11ObserverSetD2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (63580);
 $1 = ((($0)) + 28|0);
 $2 = ((($0)) + 32|0);
 $3 = HEAP32[$2>>2]|0;
 __ZNSt3__26__treeIPN3osg8ObserverENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($1,$3);
 $4 = ((($0)) + 12|0);
 __THREW__ = 0;
 invoke_vi(707,($4|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if (!($6)) {
  __ZN3osg10ReferencedD2Ev($0);
  return;
 }
 $7 = ___cxa_find_matching_catch_2()|0;
 $8 = tempRet0;
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if ($10) {
  $11 = ___cxa_find_matching_catch_3(0|0)|0;
  $12 = tempRet0;
  ___clang_call_terminate($11);
  // unreachable;
 } else {
  ___resumeException($7|0);
  // unreachable;
 }
}
function __ZN3osg11ObserverSetD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (63580);
 $1 = ((($0)) + 28|0);
 $2 = ((($0)) + 32|0);
 $3 = HEAP32[$2>>2]|0;
 __ZNSt3__26__treeIPN3osg8ObserverENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($1,$3);
 $4 = ((($0)) + 12|0);
 __THREW__ = 0;
 invoke_vi(707,($4|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $9 = ___cxa_find_matching_catch_2()|0;
  $10 = tempRet0;
  __THREW__ = 0;
  invoke_vi(712,($0|0));
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if ($12) {
   $13 = ___cxa_find_matching_catch_3(0|0)|0;
   $14 = tempRet0;
   ___clang_call_terminate($13);
   // unreachable;
  } else {
   $eh$lpad$body$index2Z2D = $10;$eh$lpad$body$indexZ2D = $9;
   __ZdlPv($0);
   ___resumeException($eh$lpad$body$indexZ2D|0);
   // unreachable;
  }
 }
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if (!($8)) {
  __ZdlPv($0);
  return;
 }
 $15 = ___cxa_find_matching_catch_2()|0;
 $16 = tempRet0;
 $eh$lpad$body$index2Z2D = $16;$eh$lpad$body$indexZ2D = $15;
 __ZdlPv($0);
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
}
function __ZNSt3__26__treeIPN3osg8ObserverENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 } else {
  $3 = HEAP32[$1>>2]|0;
  __ZNSt3__26__treeIPN3osg8ObserverENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($0,$3);
  $4 = ((($1)) + 4|0);
  $5 = HEAP32[$4>>2]|0;
  __ZNSt3__26__treeIPN3osg8ObserverENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($0,$5);
  __ZdlPv($1);
  return;
 }
}
function __ZN3osg8ObserverC2Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (63560);
 return;
}
function __ZN3osg11ObserverSetC2EPKNS_10ReferencedE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg10ReferencedC2Ev($0);
 HEAP32[$0>>2] = (63580);
 $2 = ((($0)) + 12|0);
 __THREW__ = 0;
 invoke_vii(3507,($2|0),0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if (!($4)) {
  $5 = ((($0)) + 24|0);
  HEAP32[$5>>2] = $1;
  $6 = ((($0)) + 32|0);
  HEAP32[$6>>2] = 0;
  $7 = ((($0)) + 36|0);
  HEAP32[$7>>2] = 0;
  $8 = ((($0)) + 32|0);
  $9 = ((($0)) + 28|0);
  HEAP32[$9>>2] = $8;
  return;
 }
 $10 = ___cxa_find_matching_catch_2()|0;
 $11 = tempRet0;
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $14 = ___cxa_find_matching_catch_3(0|0)|0;
  $15 = tempRet0;
  ___clang_call_terminate($14);
  // unreachable;
 } else {
  ___resumeException($10|0);
  // unreachable;
 }
}
function __ZN3osg11ObserverSet11addObserverEPNS_8ObserverE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i$i$i = 0, $$0$ph$i$i$i$i = 0, $$024$i$i$i$i = 0, $$025$i$i$i$i = 0, $$036$i$i$i = 0, $$in$i$i$i$i = 0, $$pre$i$i$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = $1;
 $3 = ((($0)) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($4)) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 (FUNCTION_TABLE_ii[$6 & 8191]($3)|0);
 $7 = ((($0)) + 28|0);
 $8 = ((($0)) + 32|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 do {
  if ($10) {
   $$025$i$i$i$i = $8;$$036$i$i$i = $8;
  } else {
   $11 = ((($0)) + 32|0);
   $$0$i$i$i$i = $11;$$024$i$i$i$i = $9;
   while(1) {
    $12 = ((($$024$i$i$i$i)) + 16|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = ($13>>>0)>($1>>>0);
    if ($14) {
     $15 = HEAP32[$$024$i$i$i$i>>2]|0;
     $16 = ($15|0)==(0|0);
     if ($16) {
      label = 6;
      break;
     } else {
      $$0$ph$i$i$i$i = $$024$i$i$i$i;$$in$i$i$i$i = $15;
     }
    } else {
     $17 = ($13>>>0)<($1>>>0);
     if (!($17)) {
      label = 10;
      break;
     }
     $18 = ((($$024$i$i$i$i)) + 4|0);
     $19 = HEAP32[$18>>2]|0;
     $20 = ($19|0)==(0|0);
     if ($20) {
      label = 9;
      break;
     } else {
      $$0$ph$i$i$i$i = $18;$$in$i$i$i$i = $19;
     }
    }
    $$0$i$i$i$i = $$0$ph$i$i$i$i;$$024$i$i$i$i = $$in$i$i$i$i;
   }
   if ((label|0) == 6) {
    $$025$i$i$i$i = $$024$i$i$i$i;$$036$i$i$i = $$024$i$i$i$i;
    break;
   }
   else if ((label|0) == 9) {
    $$025$i$i$i$i = $18;$$036$i$i$i = $$024$i$i$i$i;
    break;
   }
   else if ((label|0) == 10) {
    $$025$i$i$i$i = $$0$i$i$i$i;$$036$i$i$i = $$024$i$i$i$i;
    break;
   }
  }
 } while(0);
 $21 = HEAP32[$$025$i$i$i$i>>2]|0;
 $22 = ($21|0)==(0|0);
 if (!($22)) {
  $39 = HEAP32[$3>>2]|0;
  $40 = ((($39)) + 12|0);
  $41 = HEAP32[$40>>2]|0;
  (FUNCTION_TABLE_ii[$41 & 8191]($3)|0);
  return;
 }
 __THREW__ = 0;
 $23 = (invoke_ii(3276,20)|0);
 $24 = __THREW__; __THREW__ = 0;
 $25 = $24&1;
 if ($25) {
  $42 = ___cxa_find_matching_catch_2()|0;
  $43 = tempRet0;
  $44 = HEAP32[$3>>2]|0;
  $45 = ((($44)) + 12|0);
  $46 = HEAP32[$45>>2]|0;
  __THREW__ = 0;
  (invoke_ii($46|0,($3|0))|0);
  $47 = __THREW__; __THREW__ = 0;
  $48 = $47&1;
  if ($48) {
   $49 = ___cxa_find_matching_catch_3(0|0)|0;
   $50 = tempRet0;
   ___clang_call_terminate($49);
   // unreachable;
  } else {
   ___resumeException($42|0);
   // unreachable;
  }
 }
 $26 = ((($23)) + 16|0);
 HEAP32[$26>>2] = $2;
 HEAP32[$23>>2] = 0;
 $27 = ((($23)) + 4|0);
 HEAP32[$27>>2] = 0;
 $28 = ((($23)) + 8|0);
 HEAP32[$28>>2] = $$036$i$i$i;
 HEAP32[$$025$i$i$i$i>>2] = $23;
 $29 = HEAP32[$7>>2]|0;
 $30 = HEAP32[$29>>2]|0;
 $31 = ($30|0)==(0|0);
 if ($31) {
  $35 = $23;
 } else {
  $32 = $30;
  HEAP32[$7>>2] = $32;
  $$pre$i$i$i$i = HEAP32[$$025$i$i$i$i>>2]|0;
  $35 = $$pre$i$i$i$i;
 }
 $33 = ((($0)) + 32|0);
 $34 = HEAP32[$33>>2]|0;
 __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($34,$35);
 $36 = ((($0)) + 36|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (($37) + 1)|0;
 HEAP32[$36>>2] = $38;
 $39 = HEAP32[$3>>2]|0;
 $40 = ((($39)) + 12|0);
 $41 = HEAP32[$40>>2]|0;
 (FUNCTION_TABLE_ii[$41 & 8191]($3)|0);
 return;
}
function __ZN3osg11ObserverSet14removeObserverEPNS_8ObserverE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i$i = 0, $$0$ph$lcssa$i$i$i$i = 0, $$0$ph13$i$i$i$i = 0, $$07$ph12$i$i$i$i = 0, $$0710$i$i$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 (FUNCTION_TABLE_ii[$5 & 8191]($2)|0);
 $6 = ((($0)) + 28|0);
 $7 = ((($0)) + 32|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if (!($9)) {
  $$0$ph13$i$i$i$i = $7;$$07$ph12$i$i$i$i = $8;
  L2: while(1) {
   $$0710$i$i$i$i = $$07$ph12$i$i$i$i;
   while(1) {
    $10 = ((($$0710$i$i$i$i)) + 16|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11>>>0)<($1>>>0);
    if (!($12)) {
     break;
    }
    $15 = ((($$0710$i$i$i$i)) + 4|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = ($16|0)==(0|0);
    if ($17) {
     $$0$ph$lcssa$i$i$i$i = $$0$ph13$i$i$i$i;
     break L2;
    } else {
     $$0710$i$i$i$i = $16;
    }
   }
   $13 = HEAP32[$$0710$i$i$i$i>>2]|0;
   $14 = ($13|0)==(0|0);
   if ($14) {
    $$0$ph$lcssa$i$i$i$i = $$0710$i$i$i$i;
    break;
   } else {
    $$0$ph13$i$i$i$i = $$0710$i$i$i$i;$$07$ph12$i$i$i$i = $13;
   }
  }
  $18 = ($$0$ph$lcssa$i$i$i$i|0)==($7|0);
  if (!($18)) {
   $19 = ((($$0$ph$lcssa$i$i$i$i)) + 16|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = ($20>>>0)>($1>>>0);
   if (!($21)) {
    $22 = ((($$0$ph$lcssa$i$i$i$i)) + 4|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = ($23|0)==(0|0);
    if ($24) {
     $25 = ((($$0$ph$lcssa$i$i$i$i)) + 8|0);
     $26 = HEAP32[$25>>2]|0;
     $27 = HEAP32[$26>>2]|0;
     $28 = ($27|0)==($$0$ph$lcssa$i$i$i$i|0);
     if ($28) {
      $$0$i$i$i$i$i = $26;
     } else {
      $32 = $25;
      while(1) {
       $31 = HEAP32[$32>>2]|0;
       $33 = ((($31)) + 8|0);
       $34 = HEAP32[$33>>2]|0;
       $35 = HEAP32[$34>>2]|0;
       $36 = ($35|0)==($31|0);
       if ($36) {
        $$0$i$i$i$i$i = $34;
        break;
       } else {
        $32 = $33;
       }
      }
     }
    } else {
     $$0$i$i$i$i$i$i = $23;
     while(1) {
      $29 = HEAP32[$$0$i$i$i$i$i$i>>2]|0;
      $30 = ($29|0)==(0|0);
      if ($30) {
       break;
      } else {
       $$0$i$i$i$i$i$i = $29;
      }
     }
     $$0$i$i$i$i$i = $$0$i$i$i$i$i$i;
    }
    $37 = HEAP32[$6>>2]|0;
    $38 = ($37|0)==($$0$ph$lcssa$i$i$i$i|0);
    if ($38) {
     $39 = $$0$i$i$i$i$i;
     HEAP32[$6>>2] = $39;
    }
    $40 = ((($0)) + 36|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = (($41) + -1)|0;
    HEAP32[$40>>2] = $42;
    __ZNSt3__213__tree_removeIPNS_16__tree_node_baseIPvEEEEvT_S5_($8,$$0$ph$lcssa$i$i$i$i);
    __ZdlPv($$0$ph$lcssa$i$i$i$i);
   }
  }
 }
 $43 = HEAP32[$2>>2]|0;
 $44 = ((($43)) + 12|0);
 $45 = HEAP32[$44>>2]|0;
 (FUNCTION_TABLE_ii[$45 & 8191]($2)|0);
 return;
}
function __ZN3osg11ObserverSet10addRefLockEv($0) {
 $0 = $0|0;
 var $$1 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 (FUNCTION_TABLE_ii[$4 & 8191]($1)|0);
 $5 = ((($0)) + 24|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $$1 = 0;
 } else {
  $8 = ((($6)) + 8|0);
  $9 = HEAP32[$8>>2]|0;HEAP32[$8>>2] = (($9+1)|0);
  $10 = ($9|0)==(0);
  $11 = HEAP32[$5>>2]|0;
  if ($10) {
   __THREW__ = 0;
   (invoke_ii(3335,($11|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if ($13) {
    $17 = ___cxa_find_matching_catch_2()|0;
    $18 = tempRet0;
    $19 = HEAP32[$1>>2]|0;
    $20 = ((($19)) + 12|0);
    $21 = HEAP32[$20>>2]|0;
    __THREW__ = 0;
    (invoke_ii($21|0,($1|0))|0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     $24 = ___cxa_find_matching_catch_3(0|0)|0;
     $25 = tempRet0;
     ___clang_call_terminate($24);
     // unreachable;
    } else {
     ___resumeException($17|0);
     // unreachable;
    }
   } else {
    $$1 = 0;
   }
  } else {
   $$1 = $11;
  }
 }
 $14 = HEAP32[$1>>2]|0;
 $15 = ((($14)) + 12|0);
 $16 = HEAP32[$15>>2]|0;
 (FUNCTION_TABLE_ii[$16 & 8191]($1)|0);
 return ($$1|0);
}
function __ZN3osg11ObserverSet19signalObjectDeletedEPv($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i$i = 0, $$sroa$06$0$be = 0, $$sroa$06$017 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 (FUNCTION_TABLE_ii[$5 & 8191]($2)|0);
 $6 = ((($0)) + 28|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($0)) + 32|0);
 $9 = ($7|0)==($8|0);
 L1: do {
  if (!($9)) {
   $$sroa$06$017 = $7;
   while(1) {
    $16 = ((($$sroa$06$017)) + 16|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = HEAP32[$17>>2]|0;
    $19 = ((($18)) + 8|0);
    $20 = HEAP32[$19>>2]|0;
    __THREW__ = 0;
    invoke_vii($20|0,($17|0),($1|0));
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if ($22) {
     break;
    }
    $23 = ((($$sroa$06$017)) + 4|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = ($24|0)==(0|0);
    if ($25) {
     $26 = ((($$sroa$06$017)) + 8|0);
     $27 = HEAP32[$26>>2]|0;
     $28 = HEAP32[$27>>2]|0;
     $29 = ($28|0)==($$sroa$06$017|0);
     if ($29) {
      $$sroa$06$0$be = $27;
     } else {
      $34 = $26;
      while(1) {
       $33 = HEAP32[$34>>2]|0;
       $35 = ((($33)) + 8|0);
       $36 = HEAP32[$35>>2]|0;
       $37 = HEAP32[$36>>2]|0;
       $38 = ($37|0)==($33|0);
       if ($38) {
        $$sroa$06$0$be = $36;
        break;
       } else {
        $34 = $35;
       }
      }
     }
    } else {
     $$0$i$i$i = $24;
     while(1) {
      $31 = HEAP32[$$0$i$i$i>>2]|0;
      $32 = ($31|0)==(0|0);
      if ($32) {
       break;
      } else {
       $$0$i$i$i = $31;
      }
     }
     $$sroa$06$0$be = $$0$i$i$i;
    }
    $30 = ($$sroa$06$0$be|0)==($8|0);
    if ($30) {
     break L1;
    } else {
     $$sroa$06$017 = $$sroa$06$0$be;
    }
   }
   $39 = ___cxa_find_matching_catch_2()|0;
   $40 = tempRet0;
   $41 = HEAP32[$2>>2]|0;
   $42 = ((($41)) + 12|0);
   $43 = HEAP32[$42>>2]|0;
   __THREW__ = 0;
   (invoke_ii($43|0,($2|0))|0);
   $44 = __THREW__; __THREW__ = 0;
   $45 = $44&1;
   if ($45) {
    $46 = ___cxa_find_matching_catch_3(0|0)|0;
    $47 = tempRet0;
    ___clang_call_terminate($46);
    // unreachable;
   } else {
    ___resumeException($39|0);
    // unreachable;
   }
  }
 } while(0);
 $10 = HEAP32[$8>>2]|0;
 __ZNSt3__26__treeIPN3osg8ObserverENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($6,$10);
 $11 = ((($0)) + 36|0);
 HEAP32[$11>>2] = 0;
 HEAP32[$6>>2] = $8;
 HEAP32[$8>>2] = 0;
 $12 = ((($0)) + 24|0);
 HEAP32[$12>>2] = 0;
 $13 = HEAP32[$2>>2]|0;
 $14 = ((($13)) + 12|0);
 $15 = HEAP32[$14>>2]|0;
 (FUNCTION_TABLE_ii[$15 & 8191]($2)|0);
 return;
}
function __ZN3osg16ObserverNodePathC2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN11OpenThreads5MutexC2ENS0_9MutexTypeE($0,0);
 $1 = ((($0)) + 12|0);
 HEAP32[$1>>2] = 0;
 $2 = ((($0)) + 16|0);
 HEAP32[$2>>2] = 0;
 $3 = ((($0)) + 20|0);
 HEAP32[$3>>2] = 0;
 return;
}
function __ZNSt3__26vectorIN3osg12observer_ptrINS1_4NodeEEENS_9allocatorIS4_EEE6assignIPS4_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS4_NS_15iterator_traitsISB_E9referenceEEE5valueEvE4typeESB_SB_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$ = 0, $$0$lcssa$i$i = 0, $$010$i$i = 0, $$07$i$i = 0, $$07$i$i21 = 0, $$078$i$i = 0, $$pre$i = 0, $$pre$i$i19 = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = $2;
 $4 = $1;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 3;
 $7 = ((($0)) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$0>>2]|0;
 $10 = (($8) - ($9))|0;
 $11 = $10 >> 3;
 $12 = ($6>>>0)>($11>>>0);
 $13 = $9;
 if ($12) {
  $66 = ($9|0)==(0);
  if ($66) {
   $87 = $8;
  } else {
   $67 = $9;
   $68 = ((($0)) + 4|0);
   $69 = HEAP32[$68>>2]|0;
   $70 = ($69|0)==($13|0);
   do {
    if ($70) {
     $84 = $67;
    } else {
     $72 = $69;
     while(1) {
      $71 = ((($72)) + -8|0);
      HEAP32[$68>>2] = $71;
      $73 = HEAP32[$71>>2]|0;
      $74 = ($73|0)==(0|0);
      if (!($74)) {
       $75 = ((($73)) + 8|0);
       $76 = HEAP32[$75>>2]|0;HEAP32[$75>>2] = (($76-1)|0);
       $77 = ($76|0)==(1);
       if ($77) {
        __THREW__ = 0;
        invoke_viii(3262,($73|0),1,1);
        $78 = __THREW__; __THREW__ = 0;
        $79 = $78&1;
        if ($79) {
         label = 30;
         break;
        }
       }
      }
      HEAP32[$71>>2] = 0;
      $80 = HEAP32[$68>>2]|0;
      $81 = ($80|0)==($13|0);
      if ($81) {
       label = 31;
       break;
      } else {
       $72 = $80;
      }
     }
     if ((label|0) == 30) {
      $82 = ___cxa_find_matching_catch_2()|0;
      $83 = tempRet0;
      ___cxa_call_unexpected(($82|0));
      // unreachable;
     }
     else if ((label|0) == 31) {
      $$pre$i = HEAP32[$0>>2]|0;
      $84 = $$pre$i;
      break;
     }
    }
   } while(0);
   __ZdlPv($84);
   HEAP32[$7>>2] = 0;
   HEAP32[$68>>2] = 0;
   HEAP32[$0>>2] = 0;
   $87 = 0;
  }
  $85 = ($6>>>0)>(536870911);
  if ($85) {
   __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
   // unreachable;
  }
  $86 = $87 >> 3;
  $88 = ($86>>>0)<(268435455);
  $89 = $87 >> 2;
  $90 = ($89>>>0)<($6>>>0);
  $$sroa$speculated$i = $90 ? $6 : $89;
  $$sroa$speculated$$i = $88 ? $$sroa$speculated$i : 536870911;
  $91 = ($$sroa$speculated$$i>>>0)>(536870911);
  if ($91) {
   __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
   // unreachable;
  }
  $92 = $$sroa$speculated$$i << 3;
  $93 = (__Znwj($92)|0);
  $94 = ((($0)) + 4|0);
  HEAP32[$94>>2] = $93;
  HEAP32[$0>>2] = $93;
  $95 = (($93) + ($$sroa$speculated$$i<<3)|0);
  HEAP32[$7>>2] = $95;
  $96 = ($1|0)==($2|0);
  if ($96) {
   return;
  }
  $$07$i$i = $1;$98 = $93;
  while(1) {
   $97 = HEAP32[$$07$i$i>>2]|0;
   HEAP32[$98>>2] = $97;
   $99 = ($97|0)==(0|0);
   if (!($99)) {
    $100 = ((($97)) + 8|0);
    $101 = HEAP32[$100>>2]|0;HEAP32[$100>>2] = (($101+1)|0);
   }
   $102 = ((($98)) + 4|0);
   $103 = ((($$07$i$i)) + 4|0);
   $104 = HEAP32[$103>>2]|0;
   HEAP32[$102>>2] = $104;
   $105 = ((($$07$i$i)) + 8|0);
   $106 = HEAP32[$94>>2]|0;
   $107 = ((($106)) + 8|0);
   HEAP32[$94>>2] = $107;
   $108 = ($105|0)==($2|0);
   if ($108) {
    break;
   } else {
    $$07$i$i = $105;$98 = $107;
   }
  }
  return;
 }
 $14 = ((($0)) + 4|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($15) - ($9))|0;
 $17 = $16 >> 3;
 $18 = ($6>>>0)>($17>>>0);
 $19 = (($1) + ($17<<3)|0);
 $$ = $18 ? $19 : $2;
 $20 = ($$|0)==($1|0);
 if ($20) {
  $$0$lcssa$i$i = $13;
 } else {
  $$010$i$i = $13;$$078$i$i = $1;
  while(1) {
   $21 = ($$078$i$i|0)==($$010$i$i|0);
   if (!($21)) {
    $22 = HEAP32[$$010$i$i>>2]|0;
    $23 = HEAP32[$$078$i$i>>2]|0;
    $24 = ($22|0)==($23|0);
    if (!($24)) {
     HEAP32[$$010$i$i>>2] = $23;
     $25 = ($23|0)==(0|0);
     if (!($25)) {
      $26 = ((($23)) + 8|0);
      $27 = HEAP32[$26>>2]|0;HEAP32[$26>>2] = (($27+1)|0);
     }
     $28 = ($22|0)==(0|0);
     if (!($28)) {
      $29 = ((($22)) + 8|0);
      $30 = HEAP32[$29>>2]|0;HEAP32[$29>>2] = (($30-1)|0);
      $31 = ($30|0)==(1);
      if ($31) {
       __ZNK3osg10Referenced24signalObserversAndDeleteEbb($22,1,1);
      }
     }
    }
    $32 = ((($$078$i$i)) + 4|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = ((($$010$i$i)) + 4|0);
    HEAP32[$34>>2] = $33;
   }
   $35 = ((($$078$i$i)) + 8|0);
   $36 = ((($$010$i$i)) + 8|0);
   $37 = ($35|0)==($$|0);
   if ($37) {
    $$0$lcssa$i$i = $36;
    break;
   } else {
    $$010$i$i = $36;$$078$i$i = $35;
   }
  }
 }
 if ($18) {
  $38 = ($$|0)==($2|0);
  if ($38) {
   return;
  }
  $$pre$i$i19 = HEAP32[$14>>2]|0;
  $$07$i$i21 = $19;$40 = $$pre$i$i19;
  while(1) {
   $39 = HEAP32[$$07$i$i21>>2]|0;
   HEAP32[$40>>2] = $39;
   $41 = ($39|0)==(0|0);
   if (!($41)) {
    $42 = ((($39)) + 8|0);
    $43 = HEAP32[$42>>2]|0;HEAP32[$42>>2] = (($43+1)|0);
   }
   $44 = ((($40)) + 4|0);
   $45 = ((($$07$i$i21)) + 4|0);
   $46 = HEAP32[$45>>2]|0;
   HEAP32[$44>>2] = $46;
   $47 = ((($$07$i$i21)) + 8|0);
   $48 = HEAP32[$14>>2]|0;
   $49 = ((($48)) + 8|0);
   HEAP32[$14>>2] = $49;
   $50 = ($47|0)==($2|0);
   if ($50) {
    break;
   } else {
    $$07$i$i21 = $47;$40 = $49;
   }
  }
  return;
 }
 $51 = HEAP32[$14>>2]|0;
 $52 = ($51|0)==($$0$lcssa$i$i|0);
 if ($52) {
  return;
 } else {
  $54 = $51;
 }
 while(1) {
  $53 = ((($54)) + -8|0);
  HEAP32[$14>>2] = $53;
  $55 = HEAP32[$53>>2]|0;
  $56 = ($55|0)==(0|0);
  if (!($56)) {
   $57 = ((($55)) + 8|0);
   $58 = HEAP32[$57>>2]|0;HEAP32[$57>>2] = (($58-1)|0);
   $59 = ($58|0)==(1);
   if ($59) {
    __THREW__ = 0;
    invoke_viii(3262,($55|0),1,1);
    $60 = __THREW__; __THREW__ = 0;
    $61 = $60&1;
    if ($61) {
     label = 23;
     break;
    }
   }
  }
  HEAP32[$53>>2] = 0;
  $62 = HEAP32[$14>>2]|0;
  $63 = ($62|0)==($$0$lcssa$i$i|0);
  if ($63) {
   label = 42;
   break;
  } else {
   $54 = $62;
  }
 }
 if ((label|0) == 23) {
  $64 = ___cxa_find_matching_catch_2()|0;
  $65 = tempRet0;
  ___cxa_call_unexpected(($64|0));
  // unreachable;
 }
 else if ((label|0) == 42) {
  return;
 }
}
function __ZN3osg16ObserverNodePath12_setNodePathERKNSt3__26vectorIPNS_4NodeENS1_9allocatorIS4_EEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$$i = 0, $$08 = 0, $$in = 0, $$in13 = 0, $$phi$trans$insert = 0, $$pr$i = 0, $$pre = 0, $$pre$phiZ2D = 0, $$pre10 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 16|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==($3|0);
 do {
  if ($6) {
   $7 = $3;
   $$pre10 = ((($0)) + 12|0);
   $$in = $5;$$pre$phiZ2D = $$pre10;$28 = $7;
  } else {
   $9 = $5;
   while(1) {
    $8 = ((($9)) + -8|0);
    HEAP32[$4>>2] = $8;
    $10 = HEAP32[$8>>2]|0;
    $11 = ($10|0)==(0|0);
    if (!($11)) {
     $12 = ((($10)) + 8|0);
     $13 = HEAP32[$12>>2]|0;HEAP32[$12>>2] = (($13-1)|0);
     $14 = ($13|0)==(1);
     if ($14) {
      __THREW__ = 0;
      invoke_viii(3262,($10|0),1,1);
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if ($16) {
       label = 7;
       break;
      }
     }
    }
    HEAP32[$8>>2] = 0;
    $17 = HEAP32[$4>>2]|0;
    $18 = ($17|0)==($3|0);
    if ($18) {
     label = 8;
     break;
    } else {
     $9 = $17;
    }
   }
   if ((label|0) == 7) {
    $19 = ___cxa_find_matching_catch_2()|0;
    $20 = tempRet0;
    ___cxa_call_unexpected(($19|0));
    // unreachable;
   }
   else if ((label|0) == 8) {
    $$phi$trans$insert = ((($0)) + 12|0);
    $$pre = HEAP32[$$phi$trans$insert>>2]|0;
    $$in = $17;$$pre$phiZ2D = $$phi$trans$insert;$28 = $$pre;
    break;
   }
  }
 } while(0);
 $21 = $$in;
 $22 = ((($1)) + 4|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = HEAP32[$1>>2]|0;
 $25 = (($23) - ($24))|0;
 $26 = $25 >> 2;
 $27 = (($21) - ($28))|0;
 $29 = $27 >> 3;
 $30 = ($26>>>0)>($29>>>0);
 $31 = $28;
 L13: do {
  if ($30) {
   $32 = (($26) - ($29))|0;
   __ZNSt3__26vectorIN3osg12observer_ptrINS1_4NodeEEENS_9allocatorIS4_EEE8__appendEj($$pre$phiZ2D,$32);
  } else {
   $33 = ($26>>>0)<($29>>>0);
   if ($33) {
    $34 = (($31) + ($26<<3)|0);
    $35 = ($$in|0)==($34|0);
    if (!($35)) {
     $37 = $$in;
     while(1) {
      $36 = ((($37)) + -8|0);
      HEAP32[$4>>2] = $36;
      $38 = HEAP32[$36>>2]|0;
      $39 = ($38|0)==(0|0);
      if (!($39)) {
       $40 = ((($38)) + 8|0);
       $41 = HEAP32[$40>>2]|0;HEAP32[$40>>2] = (($41-1)|0);
       $42 = ($41|0)==(1);
       if ($42) {
        __THREW__ = 0;
        invoke_viii(3262,($38|0),1,1);
        $43 = __THREW__; __THREW__ = 0;
        $44 = $43&1;
        if ($44) {
         break;
        }
       }
      }
      HEAP32[$36>>2] = 0;
      $45 = HEAP32[$4>>2]|0;
      $46 = ($45|0)==($34|0);
      if ($46) {
       break L13;
      } else {
       $37 = $45;
      }
     }
     $51 = ___cxa_find_matching_catch_2()|0;
     $52 = tempRet0;
     ___cxa_call_unexpected(($51|0));
     // unreachable;
    }
   }
  }
 } while(0);
 $47 = HEAP32[$22>>2]|0;
 $48 = HEAP32[$1>>2]|0;
 $49 = ($47|0)==($48|0);
 if ($49) {
  return;
 }
 $50 = ((($0)) + 12|0);
 $$08 = 0;$$in13 = $48;
 while(1) {
  $53 = $$in13;
  $54 = (($53) + ($$08<<2)|0);
  $55 = HEAP32[$54>>2]|0;
  $56 = HEAP32[$50>>2]|0;
  $57 = ($55|0)==(0|0);
  if ($57) {
   $62 = 0;
  } else {
   $58 = (__ZNK3osg10Referenced22getOrCreateObserverSetEv($55)|0);
   $62 = $58;
  }
  $59 = (($56) + ($$08<<3)|0);
  $60 = HEAP32[$59>>2]|0;
  $61 = ($60|0)==($62|0);
  if ($61) {
   $70 = $62;
  } else {
   HEAP32[$59>>2] = $62;
   $63 = ($62|0)==(0|0);
   if (!($63)) {
    $64 = ((($62)) + 8|0);
    $65 = HEAP32[$64>>2]|0;HEAP32[$64>>2] = (($65+1)|0);
   }
   $66 = ($60|0)==(0|0);
   if (!($66)) {
    $67 = ((($60)) + 8|0);
    $68 = HEAP32[$67>>2]|0;HEAP32[$67>>2] = (($68-1)|0);
    $69 = ($68|0)==(1);
    if ($69) {
     __ZNK3osg10Referenced24signalObserversAndDeleteEbb($60,1,1);
    }
   }
   $$pr$i = HEAP32[$59>>2]|0;
   $70 = $$pr$i;
  }
  $71 = ($70|0)==(0|0);
  if ($71) {
   $76 = 0;
  } else {
   $72 = ((($70)) + 24|0);
   $73 = HEAP32[$72>>2]|0;
   $74 = ($73|0)!=(0|0);
   $$$i = $74 ? $55 : 0;
   $76 = $$$i;
  }
  $75 = (((($56) + ($$08<<3)|0)) + 4|0);
  HEAP32[$75>>2] = $76;
  $77 = (($$08) + 1)|0;
  $78 = HEAP32[$22>>2]|0;
  $79 = HEAP32[$1>>2]|0;
  $80 = (($78) - ($79))|0;
  $81 = $80 >> 2;
  $82 = ($77>>>0)<($81>>>0);
  if ($82) {
   $$08 = $77;$$in13 = $79;
  } else {
   break;
  }
 }
 return;
}
function __ZNSt3__26vectorIN3osg12observer_ptrINS1_4NodeEEENS_9allocatorIS4_EEE8__appendEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$06$i$i = 0, $$pre = 0, $$pre$i = 0, $$promoted4$i = 0, $$sroa$7$0 = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $scevgep$i = 0, $scevgep$i15 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) - ($5))|0;
 $7 = $6 >> 3;
 $8 = ($7>>>0)<($1>>>0);
 $9 = $5;
 if (!($8)) {
  $$promoted4$i = $5;
  $10 = $1 << 3;
  _memset(($$promoted4$i|0),0,($10|0))|0;
  $scevgep$i = (($9) + ($1<<3)|0);
  HEAP32[$4>>2] = $scevgep$i;
  return;
 }
 $11 = HEAP32[$0>>2]|0;
 $12 = (($5) - ($11))|0;
 $13 = $12 >> 3;
 $14 = (($13) + ($1))|0;
 $15 = ($14>>>0)>(536870911);
 $16 = $11;
 if ($15) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $17 = (($3) - ($11))|0;
 $18 = $17 >> 3;
 $19 = ($18>>>0)<(268435455);
 $20 = $17 >> 2;
 $21 = ($20>>>0)<($14>>>0);
 $$sroa$speculated$i = $21 ? $14 : $20;
 $$sroa$speculated$$i = $19 ? $$sroa$speculated$i : 536870911;
 $22 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($22) {
   $32 = 0;
  } else {
   $23 = ($$sroa$speculated$$i>>>0)>(536870911);
   if (!($23)) {
    $29 = $$sroa$speculated$$i << 3;
    $30 = (__Znwj($29)|0);
    $32 = $30;
    break;
   }
   $24 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($24|0),(204840|0));
   $25 = __THREW__; __THREW__ = 0;
   $26 = $25&1;
   if ($26) {
    $27 = ___cxa_find_matching_catch_2()|0;
    $28 = tempRet0;
    ___cxa_free_exception(($24|0));
    ___resumeException($27|0);
    // unreachable;
   } else {
    HEAP32[$24>>2] = (99824);
    ___cxa_throw(($24|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $31 = (($32) + ($13<<3)|0);
 $33 = $31;
 $34 = (($32) + ($$sroa$speculated$$i<<3)|0);
 $35 = $34;
 $36 = $1 << 3;
 _memset(($31|0),0,($36|0))|0;
 $scevgep$i15 = (($31) + ($1<<3)|0);
 $37 = $scevgep$i15;
 $38 = ($9|0)==($16|0);
 if ($38) {
  $53 = $33;$54 = $5;$56 = $9;
 } else {
  $$06$i$i = $9;$$sroa$7$0 = $33;$41 = $31;
  while(1) {
   $39 = ((($$06$i$i)) + -8|0);
   $40 = ((($41)) + -8|0);
   $42 = HEAP32[$39>>2]|0;
   HEAP32[$40>>2] = $42;
   $43 = ($42|0)==(0|0);
   if (!($43)) {
    $44 = ((($42)) + 8|0);
    $45 = HEAP32[$44>>2]|0;HEAP32[$44>>2] = (($45+1)|0);
   }
   $46 = ((($41)) + -4|0);
   $47 = ((($$06$i$i)) + -4|0);
   $48 = HEAP32[$47>>2]|0;
   HEAP32[$46>>2] = $48;
   $49 = $$sroa$7$0;
   $50 = ((($49)) + -8|0);
   $51 = $50;
   $52 = ($39|0)==($16|0);
   if ($52) {
    break;
   } else {
    $$06$i$i = $39;$$sroa$7$0 = $51;$41 = $50;
   }
  }
  $$pre$i = HEAP32[$0>>2]|0;
  $$pre = HEAP32[$4>>2]|0;
  $53 = $51;$54 = $$pre$i;$56 = $$pre;
 }
 HEAP32[$0>>2] = $53;
 HEAP32[$4>>2] = $37;
 HEAP32[$2>>2] = $35;
 $55 = $54;
 $57 = ($56|0)==($55|0);
 L25: do {
  if (!($57)) {
   $59 = $56;
   while(1) {
    $58 = ((($59)) + -8|0);
    $60 = HEAP32[$58>>2]|0;
    $61 = ($60|0)==(0|0);
    if (!($61)) {
     $62 = ((($60)) + 8|0);
     $63 = HEAP32[$62>>2]|0;HEAP32[$62>>2] = (($63-1)|0);
     $64 = ($63|0)==(1);
     if ($64) {
      __THREW__ = 0;
      invoke_viii(3262,($60|0),1,1);
      $65 = __THREW__; __THREW__ = 0;
      $66 = $65&1;
      if ($66) {
       break;
      }
     }
    }
    HEAP32[$58>>2] = 0;
    $67 = ($58|0)==($55|0);
    if ($67) {
     break L25;
    } else {
     $59 = $58;
    }
   }
   $68 = ___cxa_find_matching_catch_2()|0;
   $69 = tempRet0;
   ___cxa_call_unexpected(($68|0));
   // unreachable;
  }
 } while(0);
 $70 = ($54|0)==(0);
 if ($70) {
  return;
 }
 $71 = $54;
 __ZdlPv($71);
 return;
}
function __ZN3osg16ObserverNodePath11setNodePathERKNSt3__26vectorIPNS_4NodeENS1_9allocatorIS4_EEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $3 = ((($2)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 (FUNCTION_TABLE_ii[$4 & 8191]($0)|0);
 __THREW__ = 0;
 invoke_vii(3838,($0|0),($1|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if (!($6)) {
  $7 = HEAP32[$0>>2]|0;
  $8 = ((($7)) + 12|0);
  $9 = HEAP32[$8>>2]|0;
  (FUNCTION_TABLE_ii[$9 & 8191]($0)|0);
  return;
 }
 $10 = ___cxa_find_matching_catch_2()|0;
 $11 = tempRet0;
 $12 = HEAP32[$0>>2]|0;
 $13 = ((($12)) + 12|0);
 $14 = HEAP32[$13>>2]|0;
 __THREW__ = 0;
 (invoke_ii($14|0,($0|0))|0);
 $15 = __THREW__; __THREW__ = 0;
 $16 = $15&1;
 if ($16) {
  $17 = ___cxa_find_matching_catch_3(0|0)|0;
  $18 = tempRet0;
  ___clang_call_terminate($17);
  // unreachable;
 } else {
  ___resumeException($10|0);
  // unreachable;
 }
}
function __ZN3osg16ObserverNodePathD2Ev($0) {
 $0 = $0|0;
 var $$pre$i = 0, $$pre$i7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 __THREW__ = 0;
 (invoke_ii($3|0,($0|0))|0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = ((($0)) + 12|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ((($0)) + 16|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($9|0)==($7|0);
  L3: do {
   if (!($10)) {
    $12 = $9;
    while(1) {
     $11 = ((($12)) + -8|0);
     HEAP32[$8>>2] = $11;
     $13 = HEAP32[$11>>2]|0;
     $14 = ($13|0)==(0|0);
     if (!($14)) {
      $15 = ((($13)) + 8|0);
      $16 = HEAP32[$15>>2]|0;HEAP32[$15>>2] = (($16-1)|0);
      $17 = ($16|0)==(1);
      if ($17) {
       __THREW__ = 0;
       invoke_viii(3262,($13|0),1,1);
       $18 = __THREW__; __THREW__ = 0;
       $19 = $18&1;
       if ($19) {
        break;
       }
      }
     }
     HEAP32[$11>>2] = 0;
     $20 = HEAP32[$8>>2]|0;
     $21 = ($20|0)==($7|0);
     if ($21) {
      break L3;
     } else {
      $12 = $20;
     }
    }
    $22 = ___cxa_find_matching_catch_2()|0;
    $23 = tempRet0;
    ___cxa_call_unexpected(($22|0));
    // unreachable;
   }
  } while(0);
  $24 = HEAP32[$0>>2]|0;
  $25 = ((($24)) + 12|0);
  $26 = HEAP32[$25>>2]|0;
  __THREW__ = 0;
  (invoke_ii($26|0,($0|0))|0);
  $27 = __THREW__; __THREW__ = 0;
  $28 = $27&1;
  if (!($28)) {
   $29 = ((($0)) + 12|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = ($30|0)==(0|0);
   if ($31) {
    __ZN11OpenThreads5MutexD2Ev($0);
    return;
   }
   $32 = HEAP32[$8>>2]|0;
   $33 = ($32|0)==($30|0);
   do {
    if ($33) {
     $47 = $30;
    } else {
     $35 = $32;
     while(1) {
      $34 = ((($35)) + -8|0);
      HEAP32[$8>>2] = $34;
      $36 = HEAP32[$34>>2]|0;
      $37 = ($36|0)==(0|0);
      if (!($37)) {
       $38 = ((($36)) + 8|0);
       $39 = HEAP32[$38>>2]|0;HEAP32[$38>>2] = (($39-1)|0);
       $40 = ($39|0)==(1);
       if ($40) {
        __THREW__ = 0;
        invoke_viii(3262,($36|0),1,1);
        $41 = __THREW__; __THREW__ = 0;
        $42 = $41&1;
        if ($42) {
         label = 15;
         break;
        }
       }
      }
      HEAP32[$34>>2] = 0;
      $43 = HEAP32[$8>>2]|0;
      $44 = ($43|0)==($30|0);
      if ($44) {
       label = 16;
       break;
      } else {
       $35 = $43;
      }
     }
     if ((label|0) == 15) {
      $45 = ___cxa_find_matching_catch_2()|0;
      $46 = tempRet0;
      ___cxa_call_unexpected(($45|0));
      // unreachable;
     }
     else if ((label|0) == 16) {
      $$pre$i = HEAP32[$29>>2]|0;
      $47 = $$pre$i;
      break;
     }
    }
   } while(0);
   __ZdlPv($47);
   __ZN11OpenThreads5MutexD2Ev($0);
   return;
  }
 }
 $48 = ___cxa_find_matching_catch_2()|0;
 $49 = tempRet0;
 $50 = ((($0)) + 12|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = ($51|0)==(0|0);
 if (!($52)) {
  $53 = ((($0)) + 16|0);
  $54 = HEAP32[$53>>2]|0;
  $55 = ($54|0)==($51|0);
  do {
   if ($55) {
    $69 = $51;
   } else {
    $57 = $54;
    while(1) {
     $56 = ((($57)) + -8|0);
     HEAP32[$53>>2] = $56;
     $58 = HEAP32[$56>>2]|0;
     $59 = ($58|0)==(0|0);
     if (!($59)) {
      $60 = ((($58)) + 8|0);
      $61 = HEAP32[$60>>2]|0;HEAP32[$60>>2] = (($61-1)|0);
      $62 = ($61|0)==(1);
      if ($62) {
       __THREW__ = 0;
       invoke_viii(3262,($58|0),1,1);
       $63 = __THREW__; __THREW__ = 0;
       $64 = $63&1;
       if ($64) {
        label = 25;
        break;
       }
      }
     }
     HEAP32[$56>>2] = 0;
     $65 = HEAP32[$53>>2]|0;
     $66 = ($65|0)==($51|0);
     if ($66) {
      label = 26;
      break;
     } else {
      $57 = $65;
     }
    }
    if ((label|0) == 25) {
     $67 = ___cxa_find_matching_catch_2()|0;
     $68 = tempRet0;
     ___cxa_call_unexpected(($67|0));
     // unreachable;
    }
    else if ((label|0) == 26) {
     $$pre$i7 = HEAP32[$50>>2]|0;
     $69 = $$pre$i7;
     break;
    }
   }
  } while(0);
  __ZdlPv($69);
 }
 __THREW__ = 0;
 invoke_vi(707,($0|0));
 $70 = __THREW__; __THREW__ = 0;
 $71 = $70&1;
 if ($71) {
  $72 = ___cxa_find_matching_catch_3(0|0)|0;
  $73 = tempRet0;
  ___clang_call_terminate($72);
  // unreachable;
 } else {
  ___resumeException($48|0);
  // unreachable;
 }
}
function __ZN3osg16ObserverNodePath13clearNodePathEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 (FUNCTION_TABLE_ii[$3 & 8191]($0)|0);
 $4 = ((($0)) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($0)) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==($5|0);
 if ($8) {
  $22 = HEAP32[$0>>2]|0;
  $23 = ((($22)) + 12|0);
  $24 = HEAP32[$23>>2]|0;
  (FUNCTION_TABLE_ii[$24 & 8191]($0)|0);
  return;
 } else {
  $10 = $7;
 }
 while(1) {
  $9 = ((($10)) + -8|0);
  HEAP32[$6>>2] = $9;
  $11 = HEAP32[$9>>2]|0;
  $12 = ($11|0)==(0|0);
  if (!($12)) {
   $13 = ((($11)) + 8|0);
   $14 = HEAP32[$13>>2]|0;HEAP32[$13>>2] = (($14-1)|0);
   $15 = ($14|0)==(1);
   if ($15) {
    __THREW__ = 0;
    invoke_viii(3262,($11|0),1,1);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     label = 6;
     break;
    }
   }
  }
  HEAP32[$9>>2] = 0;
  $18 = HEAP32[$6>>2]|0;
  $19 = ($18|0)==($5|0);
  if ($19) {
   label = 7;
   break;
  } else {
   $10 = $18;
  }
 }
 if ((label|0) == 6) {
  $20 = ___cxa_find_matching_catch_2()|0;
  $21 = tempRet0;
  ___cxa_call_unexpected(($20|0));
  // unreachable;
 }
 else if ((label|0) == 7) {
  $22 = HEAP32[$0>>2]|0;
  $23 = ((($22)) + 12|0);
  $24 = HEAP32[$23>>2]|0;
  (FUNCTION_TABLE_ii[$24 & 8191]($0)|0);
  return;
 }
}
function __ZN3osg16ObserverNodePathaSERKS0_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$1 = 0, $$17 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==($0|0);
 if ($2) {
  return ($0|0);
 }
 $3 = HEAP32[$1>>2]|0;
 $4 = ((($3)) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 (FUNCTION_TABLE_ii[$5 & 8191]($1)|0);
 $6 = HEAP32[$0>>2]|0;
 $7 = ((($6)) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 __THREW__ = 0;
 (invoke_ii($8|0,($0|0))|0);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 do {
  if ($10) {
   $23 = ___cxa_find_matching_catch_2()|0;
   $24 = tempRet0;
   $$1 = $24;$$17 = $23;
  } else {
   $11 = ((($0)) + 12|0);
   $12 = ((($1)) + 12|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = ((($1)) + 16|0);
   $15 = HEAP32[$14>>2]|0;
   __THREW__ = 0;
   invoke_viii(3839,($11|0),($13|0),($15|0));
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if ($17) {
    $25 = ___cxa_find_matching_catch_2()|0;
    $26 = tempRet0;
    $27 = HEAP32[$0>>2]|0;
    $28 = ((($27)) + 12|0);
    $29 = HEAP32[$28>>2]|0;
    __THREW__ = 0;
    (invoke_ii($29|0,($0|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if (!($31)) {
     $$1 = $26;$$17 = $25;
     break;
    }
    $42 = ___cxa_find_matching_catch_3(0|0)|0;
    $43 = tempRet0;
    ___clang_call_terminate($42);
    // unreachable;
   }
   $18 = HEAP32[$0>>2]|0;
   $19 = ((($18)) + 12|0);
   $20 = HEAP32[$19>>2]|0;
   __THREW__ = 0;
   (invoke_ii($20|0,($0|0))|0);
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if ($22) {
    $35 = ___cxa_find_matching_catch_2()|0;
    $36 = tempRet0;
    $$1 = $36;$$17 = $35;
    break;
   }
   $32 = HEAP32[$1>>2]|0;
   $33 = ((($32)) + 12|0);
   $34 = HEAP32[$33>>2]|0;
   (FUNCTION_TABLE_ii[$34 & 8191]($1)|0);
   return ($0|0);
  }
 } while(0);
 $37 = HEAP32[$1>>2]|0;
 $38 = ((($37)) + 12|0);
 $39 = HEAP32[$38>>2]|0;
 __THREW__ = 0;
 (invoke_ii($39|0,($1|0))|0);
 $40 = __THREW__; __THREW__ = 0;
 $41 = $40&1;
 if ($41) {
  $42 = ___cxa_find_matching_catch_3(0|0)|0;
  $43 = tempRet0;
  ___clang_call_terminate($42);
  // unreachable;
 } else {
  ___resumeException($$17|0);
  // unreachable;
 }
 return (0)|0;
}
function __ZNK3osg16ObserverNodePath11getNodePathERNSt3__26vectorIPNS_4NodeENS1_9allocatorIS4_EEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$01432 = 0, $$pre = 0, $$pre33 = 0, $$sink18$index = 0, $$sink18$index3 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $phitmp$i = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i20 = 0, $scevgep5$i$i$i = 0, $scevgep5$i$i$i21 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = HEAP32[$0>>2]|0;
 $4 = ((($3)) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 (FUNCTION_TABLE_ii[$5 & 8191]($0)|0);
 $6 = ((($0)) + 12|0);
 $7 = ((($0)) + 16|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$6>>2]|0;
 $10 = (($8) - ($9))|0;
 $11 = $10 >> 3;
 $12 = ((($1)) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = HEAP32[$1>>2]|0;
 $15 = (($13) - ($14))|0;
 $16 = $15 >> 2;
 $17 = ($11>>>0)>($16>>>0);
 $18 = $14;
 $19 = $13;
 $20 = $9;
 do {
  if ($17) {
   $21 = (($11) - ($16))|0;
   __THREW__ = 0;
   invoke_vii(3840,($1|0),($21|0));
   $22 = __THREW__; __THREW__ = 0;
   $23 = $22&1;
   if ($23) {
    $36 = ___cxa_find_matching_catch_2()|0;
    $37 = tempRet0;
    $$sink18$index = $36;$$sink18$index3 = $37;
    break;
   } else {
    $$pre = HEAP32[$7>>2]|0;
    $$pre33 = HEAP32[$6>>2]|0;
    $24 = $$pre33;
    $122 = $24;$33 = $$pre;$35 = $$pre33;
    label = 7;
    break;
   }
  } else {
   $25 = ($11>>>0)<($16>>>0);
   if ($25) {
    $26 = (($18) + ($11<<2)|0);
    $27 = ($19|0)==($26|0);
    if ($27) {
     $122 = $20;$33 = $8;$35 = $9;
     label = 7;
    } else {
     $scevgep$i$i$i = ((($19)) + -4|0);
     $28 = $scevgep$i$i$i;
     $29 = $26;
     $30 = (($28) - ($29))|0;
     $31 = $30 >>> 2;
     $32 = $31 ^ -1;
     $scevgep5$i$i$i = (($19) + ($32<<2)|0);
     HEAP32[$12>>2] = $scevgep5$i$i$i;
     $122 = $20;$33 = $8;$35 = $9;
     label = 7;
    }
   } else {
    $122 = $20;$33 = $8;$35 = $9;
    label = 7;
   }
  }
 } while(0);
 L9: do {
  if ((label|0) == 7) {
   $34 = ($33|0)==($35|0);
   if ($34) {
    $114 = 1;
    $111 = HEAP32[$0>>2]|0;
    $112 = ((($111)) + 12|0);
    $113 = HEAP32[$112>>2]|0;
    (FUNCTION_TABLE_ii[$113 & 8191]($0)|0);
    STACKTOP = sp;return ($114|0);
   }
   $$01432 = 0;$39 = $122;
   while(1) {
    $38 = (($39) + ($$01432<<3)|0);
    $40 = HEAP32[$38>>2]|0;
    $41 = ($40|0)==(0|0);
    if ($41) {
     break;
    }
    $42 = ((($40)) + 24|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = ($43|0)==(0|0);
    if ($44) {
     break;
    }
    $45 = (((($39) + ($$01432<<3)|0)) + 4|0);
    $46 = HEAP32[$45>>2]|0;
    $phitmp$i = ($46|0)==(0|0);
    if ($phitmp$i) {
     break;
    }
    $47 = (($39) + ($$01432<<3)|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = ($48|0)==(0|0);
    if ($49) {
     $57 = 0;
    } else {
     $50 = ((($48)) + 24|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = ($51|0)==(0|0);
     if ($52) {
      $57 = 0;
     } else {
      $53 = (((($39) + ($$01432<<3)|0)) + 4|0);
      $54 = HEAP32[$53>>2]|0;
      $57 = $54;
     }
    }
    $55 = HEAP32[$1>>2]|0;
    $56 = (($55) + ($$01432<<2)|0);
    HEAP32[$56>>2] = $57;
    $58 = (($$01432) + 1)|0;
    $59 = HEAP32[$7>>2]|0;
    $60 = HEAP32[$6>>2]|0;
    $61 = (($59) - ($60))|0;
    $62 = $61 >> 3;
    $63 = ($58>>>0)<($62>>>0);
    $64 = $60;
    if ($63) {
     $$01432 = $58;$39 = $64;
    } else {
     $114 = 1;
     label = 33;
     break;
    }
   }
   if ((label|0) == 33) {
    $111 = HEAP32[$0>>2]|0;
    $112 = ((($111)) + 12|0);
    $113 = HEAP32[$112>>2]|0;
    (FUNCTION_TABLE_ii[$113 & 8191]($0)|0);
    STACKTOP = sp;return ($114|0);
   }
   __THREW__ = 0;
   $67 = (invoke_ii(3265,3)|0);
   $68 = __THREW__; __THREW__ = 0;
   $69 = $68&1;
   L26: do {
    if (!($69)) {
     do {
      if ($67) {
       __THREW__ = 0;
       $70 = (invoke_ii(3266,3)|0);
       $71 = __THREW__; __THREW__ = 0;
       $72 = $71&1;
       if ($72) {
        break L26;
       }
       __THREW__ = 0;
       $73 = (invoke_iiii(3267,($70|0),(145651|0),57)|0);
       $74 = __THREW__; __THREW__ = 0;
       $75 = $74&1;
       if ($75) {
        break L26;
       }
       $76 = HEAP32[$73>>2]|0;
       $77 = ((($76)) + -12|0);
       $78 = HEAP32[$77>>2]|0;
       $79 = (($73) + ($78)|0);
       __THREW__ = 0;
       invoke_vii(3257,($2|0),($79|0));
       $80 = __THREW__; __THREW__ = 0;
       $81 = $80&1;
       if ($81) {
        break L26;
       }
       __THREW__ = 0;
       $82 = (invoke_iii(3255,($2|0),(215188|0))|0);
       $83 = __THREW__; __THREW__ = 0;
       $84 = $83&1;
       if (!($84)) {
        $85 = HEAP32[$82>>2]|0;
        $86 = ((($85)) + 28|0);
        $87 = HEAP32[$86>>2]|0;
        __THREW__ = 0;
        $88 = (invoke_iii($87|0,($82|0),10)|0);
        $89 = __THREW__; __THREW__ = 0;
        $90 = $89&1;
        if (!($90)) {
         __THREW__ = 0;
         invoke_vi(3263,($2|0));
         $97 = __THREW__; __THREW__ = 0;
         $98 = $97&1;
         if ($98) {
          break L26;
         }
         __THREW__ = 0;
         (invoke_iii(3268,($73|0),($88|0))|0);
         $99 = __THREW__; __THREW__ = 0;
         $100 = $99&1;
         if ($100) {
          break L26;
         }
         __THREW__ = 0;
         (invoke_ii(3269,($73|0))|0);
         $101 = __THREW__; __THREW__ = 0;
         $102 = $101&1;
         if ($102) {
          break L26;
         } else {
          break;
         }
        }
       }
       $91 = ___cxa_find_matching_catch_2()|0;
       $92 = tempRet0;
       __THREW__ = 0;
       invoke_vi(3263,($2|0));
       $93 = __THREW__; __THREW__ = 0;
       $94 = $93&1;
       if ($94) {
        $95 = ___cxa_find_matching_catch_3(0|0)|0;
        $96 = tempRet0;
        ___clang_call_terminate($95);
        // unreachable;
       } else {
        $$sink18$index = $91;$$sink18$index3 = $92;
        break L9;
       }
      }
     } while(0);
     $103 = HEAP32[$1>>2]|0;
     $104 = HEAP32[$12>>2]|0;
     $105 = ($104|0)==($103|0);
     if ($105) {
      $114 = 0;
      $111 = HEAP32[$0>>2]|0;
      $112 = ((($111)) + 12|0);
      $113 = HEAP32[$112>>2]|0;
      (FUNCTION_TABLE_ii[$113 & 8191]($0)|0);
      STACKTOP = sp;return ($114|0);
     }
     $scevgep$i$i$i20 = ((($104)) + -4|0);
     $106 = $scevgep$i$i$i20;
     $107 = $103;
     $108 = (($106) - ($107))|0;
     $109 = $108 >>> 2;
     $110 = $109 ^ -1;
     $scevgep5$i$i$i21 = (($104) + ($110<<2)|0);
     HEAP32[$12>>2] = $scevgep5$i$i$i21;
     $114 = 0;
     $111 = HEAP32[$0>>2]|0;
     $112 = ((($111)) + 12|0);
     $113 = HEAP32[$112>>2]|0;
     (FUNCTION_TABLE_ii[$113 & 8191]($0)|0);
     STACKTOP = sp;return ($114|0);
    }
   } while(0);
   $65 = ___cxa_find_matching_catch_2()|0;
   $66 = tempRet0;
   $$sink18$index = $65;$$sink18$index3 = $66;
  }
 } while(0);
 $115 = HEAP32[$0>>2]|0;
 $116 = ((($115)) + 12|0);
 $117 = HEAP32[$116>>2]|0;
 __THREW__ = 0;
 (invoke_ii($117|0,($0|0))|0);
 $118 = __THREW__; __THREW__ = 0;
 $119 = $118&1;
 if ($119) {
  $120 = ___cxa_find_matching_catch_3(0|0)|0;
  $121 = tempRet0;
  ___clang_call_terminate($120);
  // unreachable;
 } else {
  ___resumeException($$sink18$index|0);
  // unreachable;
 }
 return (0)|0;
}
function __ZNSt3__26vectorIPN3osg4NodeENS_9allocatorIS3_EEE8__appendEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i = 0, $$0$i16 = 0, $$sroa$15$0 = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) - ($5))|0;
 $7 = $6 >> 2;
 $8 = ($7>>>0)<($1>>>0);
 if (!($8)) {
  $9 = $5;
  $$0$i = $1;$10 = $9;
  while(1) {
   HEAP32[$10>>2] = 0;
   $11 = HEAP32[$4>>2]|0;
   $12 = ((($11)) + 4|0);
   HEAP32[$4>>2] = $12;
   $13 = (($$0$i) + -1)|0;
   $14 = ($13|0)==(0);
   if ($14) {
    break;
   } else {
    $$0$i = $13;$10 = $12;
   }
  }
  return;
 }
 $15 = HEAP32[$0>>2]|0;
 $16 = (($5) - ($15))|0;
 $17 = $16 >> 2;
 $18 = (($17) + ($1))|0;
 $19 = ($18>>>0)>(1073741823);
 if ($19) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $20 = (($3) - ($15))|0;
 $21 = $20 >> 2;
 $22 = ($21>>>0)<(536870911);
 $23 = $20 >> 1;
 $24 = ($23>>>0)<($18>>>0);
 $$sroa$speculated$i = $24 ? $18 : $23;
 $$sroa$speculated$$i = $22 ? $$sroa$speculated$i : 1073741823;
 $25 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($25) {
   $35 = 0;
  } else {
   $26 = ($$sroa$speculated$$i>>>0)>(1073741823);
   if (!($26)) {
    $32 = $$sroa$speculated$$i << 2;
    $33 = (__Znwj($32)|0);
    $35 = $33;
    break;
   }
   $27 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($27|0),(204840|0));
   $28 = __THREW__; __THREW__ = 0;
   $29 = $28&1;
   if ($29) {
    $30 = ___cxa_find_matching_catch_2()|0;
    $31 = tempRet0;
    ___cxa_free_exception(($27|0));
    ___resumeException($30|0);
    // unreachable;
   } else {
    HEAP32[$27>>2] = (99824);
    ___cxa_throw(($27|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $34 = (($35) + ($17<<2)|0);
 $36 = $34;
 $37 = (($35) + ($$sroa$speculated$$i<<2)|0);
 $$0$i16 = $1;$$sroa$15$0 = $36;$38 = $34;
 while(1) {
  HEAP32[$38>>2] = 0;
  $39 = $$sroa$15$0;
  $40 = ((($39)) + 4|0);
  $41 = $40;
  $42 = (($$0$i16) + -1)|0;
  $43 = ($42|0)==(0);
  if ($43) {
   break;
  } else {
   $$0$i16 = $42;$$sroa$15$0 = $41;$38 = $40;
  }
 }
 $44 = $37;
 $45 = HEAP32[$0>>2]|0;
 $46 = HEAP32[$4>>2]|0;
 $47 = $45;
 $48 = (($46) - ($47))|0;
 $49 = $48 >> 2;
 $50 = (0 - ($49))|0;
 $51 = (($34) + ($50<<2)|0);
 $52 = $51;
 $53 = ($48|0)>(0);
 if ($53) {
  _memcpy(($51|0),($45|0),($48|0))|0;
 }
 HEAP32[$0>>2] = $52;
 HEAP32[$4>>2] = $41;
 HEAP32[$2>>2] = $44;
 $54 = ($45|0)==(0|0);
 if ($54) {
  return;
 }
 __ZdlPv($45);
 return;
}
function __ZN3osg18OcclusionQueryNode13traverseQueryEPKNS_6CameraERNS_11NodeVisitorE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$i$i = 0, $$0$ph$i$i = 0, $$014$i = 0, $$024$i$i = 0, $$025$i$i = 0, $$025$i47$i = 0, $$034$i = 0, $$03446$i = 0, $$in$i$i = 0, $$pre$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = $1;
 $4 = ((($2)) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($0)) + 160|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($7)) + 8|0);
 $9 = HEAP32[$8>>2]|0;
 (FUNCTION_TABLE_ii[$9 & 8191]($6)|0);
 $10 = ((($0)) + 148|0);
 $11 = ((($0)) + 152|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0|0);
 do {
  if ($13) {
   $$025$i$i = $11;$$034$i = $11;$24 = $12;
   label = 12;
  } else {
   $14 = ((($0)) + 152|0);
   $$0$i$i = $14;$$024$i$i = $12;$69 = $12;
   while(1) {
    $15 = ((($$024$i$i)) + 16|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = ($16>>>0)>($1>>>0);
    if ($17) {
     $18 = HEAP32[$$024$i$i>>2]|0;
     $19 = ($18|0)==(0|0);
     if ($19) {
      label = 6;
      break;
     } else {
      $$0$ph$i$i = $$024$i$i;$$in$i$i = $18;
     }
    } else {
     $20 = ($16>>>0)<($1>>>0);
     if (!($20)) {
      label = 10;
      break;
     }
     $21 = ((($$024$i$i)) + 4|0);
     $22 = HEAP32[$21>>2]|0;
     $23 = ($22|0)==(0|0);
     if ($23) {
      label = 9;
      break;
     } else {
      $$0$ph$i$i = $21;$$in$i$i = $22;
     }
    }
    $$0$i$i = $$0$ph$i$i;$$024$i$i = $$in$i$i;$69 = $$in$i$i;
   }
   if ((label|0) == 6) {
    $$025$i47$i = $$024$i$i;$$03446$i = $$024$i$i;
    label = 13;
    break;
   }
   else if ((label|0) == 9) {
    $$025$i47$i = $21;$$03446$i = $$024$i$i;
    label = 13;
    break;
   }
   else if ((label|0) == 10) {
    $$025$i$i = $$0$i$i;$$034$i = $$024$i$i;$24 = $69;
    label = 12;
    break;
   }
  }
 } while(0);
 if ((label|0) == 12) {
  $25 = ($24|0)==(0|0);
  if ($25) {
   $$025$i47$i = $$025$i$i;$$03446$i = $$034$i;
   label = 13;
  } else {
   $$014$i = $24;
  }
 }
 do {
  if ((label|0) == 13) {
   __THREW__ = 0;
   $26 = (invoke_ii(3276,24)|0);
   $27 = __THREW__; __THREW__ = 0;
   $28 = $27&1;
   if ($28) {
    $57 = ___cxa_find_matching_catch_2()|0;
    $58 = tempRet0;
    $59 = HEAP32[$6>>2]|0;
    $60 = ((($59)) + 12|0);
    $61 = HEAP32[$60>>2]|0;
    __THREW__ = 0;
    (invoke_ii($61|0,($6|0))|0);
    $62 = __THREW__; __THREW__ = 0;
    $63 = $62&1;
    if ($63) {
     $67 = ___cxa_find_matching_catch_3(0|0)|0;
     $68 = tempRet0;
     ___clang_call_terminate($67);
     // unreachable;
    } else {
     ___resumeException($57|0);
     // unreachable;
    }
   } else {
    $29 = ((($26)) + 16|0);
    HEAP32[$29>>2] = $3;
    $30 = ((($26)) + 20|0);
    HEAP32[$30>>2] = 0;
    HEAP32[$26>>2] = 0;
    $31 = ((($26)) + 4|0);
    HEAP32[$31>>2] = 0;
    $32 = ((($26)) + 8|0);
    HEAP32[$32>>2] = $$03446$i;
    HEAP32[$$025$i47$i>>2] = $26;
    $33 = HEAP32[$10>>2]|0;
    $34 = HEAP32[$33>>2]|0;
    $35 = ($34|0)==(0|0);
    if ($35) {
     $39 = $26;
    } else {
     $36 = $34;
     HEAP32[$10>>2] = $36;
     $$pre$i$i = HEAP32[$$025$i47$i>>2]|0;
     $39 = $$pre$i$i;
    }
    $37 = ((($0)) + 152|0);
    $38 = HEAP32[$37>>2]|0;
    __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($38,$39);
    $40 = ((($0)) + 156|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = (($41) + 1)|0;
    HEAP32[$40>>2] = $42;
    $$014$i = $26;
    break;
   }
  }
 } while(0);
 $43 = ((($$014$i)) + 20|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = (($5) - ($44))|0;
 $46 = ((($0)) + 180|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = ($45>>>0)<($47>>>0);
 if ($48) {
  $64 = HEAP32[$6>>2]|0;
  $65 = ((($64)) + 12|0);
  $66 = HEAP32[$65>>2]|0;
  (FUNCTION_TABLE_ii[$66 & 8191]($6)|0);
  return;
 } else {
  HEAP32[$43>>2] = $5;
  $49 = HEAP32[$6>>2]|0;
  $50 = ((($49)) + 12|0);
  $51 = HEAP32[$50>>2]|0;
  (FUNCTION_TABLE_ii[$51 & 8191]($6)|0);
  $52 = ((($0)) + 136|0);
  $53 = HEAP32[$52>>2]|0;
  $54 = HEAP32[$53>>2]|0;
  $55 = ((($54)) + 188|0);
  $56 = HEAP32[$55>>2]|0;
  FUNCTION_TABLE_vii[$56 & 8191]($53,$2);
  return;
 }
}
function __ZN3osg18OcclusionQueryNode13traverseDebugERNS_11NodeVisitorE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 184|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  return;
 }
 $5 = ((($0)) + 140|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($7)) + 188|0);
 $9 = HEAP32[$8>>2]|0;
 FUNCTION_TABLE_vii[$9 & 8191]($6,$1);
 return;
}
function __ZN3osg14OperationQueueD2Ev($0) {
 $0 = $0|0;
 var $$023$i$i = 0, $$2 = 0, $$24 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (63600);
 $1 = ((($0)) + 44|0);
 $2 = ((($0)) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 __ZNSt3__26__treeIPN3osg15OperationThreadENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($1,$3);
 $4 = ((($0)) + 28|0);
 $5 = ((($0)) + 36|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 L1: do {
  if (!($7)) {
   $8 = ((($0)) + 32|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = HEAP32[$4>>2]|0;
   $11 = ((($10)) + 4|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = HEAP32[$9>>2]|0;
   $14 = ((($13)) + 4|0);
   HEAP32[$14>>2] = $12;
   $15 = HEAP32[$11>>2]|0;
   HEAP32[$15>>2] = $13;
   HEAP32[$5>>2] = 0;
   $16 = ($9|0)==($4|0);
   if (!($16)) {
    $$023$i$i = $9;
    while(1) {
     $17 = ((($$023$i$i)) + 4|0);
     $18 = HEAP32[$17>>2]|0;
     $19 = ((($$023$i$i)) + 8|0);
     $20 = HEAP32[$19>>2]|0;
     $21 = ($20|0)==(0|0);
     if (!($21)) {
      $22 = HEAP32[$20>>2]|0;
      $23 = ((($22)) + -12|0);
      $24 = HEAP32[$23>>2]|0;
      $25 = (($20) + ($24)|0);
      $26 = ((($25)) + 8|0);
      $27 = HEAP32[$26>>2]|0;HEAP32[$26>>2] = (($27-1)|0);
      $28 = ($27|0)==(1);
      if ($28) {
       __THREW__ = 0;
       invoke_viii(3262,($25|0),1,1);
       $29 = __THREW__; __THREW__ = 0;
       $30 = $29&1;
       if ($30) {
        break;
       }
      }
     }
     __ZdlPv($$023$i$i);
     $31 = ($18|0)==($4|0);
     if ($31) {
      break L1;
     } else {
      $$023$i$i = $18;
     }
    }
    $32 = ___cxa_find_matching_catch_2()|0;
    $33 = tempRet0;
    ___cxa_call_unexpected(($32|0));
    // unreachable;
   }
  }
 } while(0);
 $34 = ((($0)) + 24|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = ($35|0)==(0|0);
 if ($36) {
  label = 11;
 } else {
  $37 = HEAP32[$35>>2]|0;
  $38 = ((($37)) + -12|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = (($35) + ($39)|0);
  $41 = ((($40)) + 8|0);
  $42 = HEAP32[$41>>2]|0;HEAP32[$41>>2] = (($42-1)|0);
  $43 = ($42|0)==(1);
  if ($43) {
   __THREW__ = 0;
   invoke_viii(3262,($40|0),1,1);
   $44 = __THREW__; __THREW__ = 0;
   $45 = $44&1;
   if ($45) {
    $51 = ___cxa_find_matching_catch_2()|0;
    $52 = tempRet0;
    $53 = ((($0)) + 12|0);
    __THREW__ = 0;
    invoke_vi(707,($53|0));
    $54 = __THREW__; __THREW__ = 0;
    $55 = $54&1;
    if ($55) {
     $58 = ___cxa_find_matching_catch_3(0|0)|0;
     $59 = tempRet0;
     ___clang_call_terminate($58);
     // unreachable;
    } else {
     $$2 = $52;$$24 = $51;
    }
   } else {
    label = 11;
   }
  } else {
   label = 11;
  }
 }
 do {
  if ((label|0) == 11) {
   HEAP32[$34>>2] = 0;
   $46 = ((($0)) + 12|0);
   __THREW__ = 0;
   invoke_vi(707,($46|0));
   $47 = __THREW__; __THREW__ = 0;
   $48 = $47&1;
   if ($48) {
    $49 = ___cxa_find_matching_catch_2()|0;
    $50 = tempRet0;
    $$2 = $50;$$24 = $49;
    break;
   } else {
    __ZN3osg10ReferencedD2Ev($0);
    return;
   }
  }
 } while(0);
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $56 = __THREW__; __THREW__ = 0;
 $57 = $56&1;
 if ($57) {
  $58 = ___cxa_find_matching_catch_3(0|0)|0;
  $59 = tempRet0;
  ___clang_call_terminate($58);
  // unreachable;
 } else {
  ___resumeException($$24|0);
  // unreachable;
 }
}
function __ZN3osg14OperationQueueD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(2064,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNSt3__26__treeIPN3osg15OperationThreadENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 } else {
  $3 = HEAP32[$1>>2]|0;
  __ZNSt3__26__treeIPN3osg15OperationThreadENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($0,$3);
  $4 = ((($1)) + 4|0);
  $5 = HEAP32[$4>>2]|0;
  __ZNSt3__26__treeIPN3osg15OperationThreadENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($0,$5);
  __ZdlPv($1);
  return;
 }
}
function __ZN3osg15OperationThreadD2Ev($0) {
 $0 = $0|0;
 var $$0 = 0, $$02 = 0, $$1 = 0, $$13 = 0, $$2 = 0, $$24 = 0, $$3 = 0, $$35 = 0, $$4 = 0, $$46 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (63620);
 $1 = ((($0)) + 12|0);
 HEAP32[$1>>2] = (63648);
 __THREW__ = 0;
 (invoke_ii(1887,($0|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if ($3) {
   $37 = ___cxa_find_matching_catch_2()|0;
   $38 = tempRet0;
   $39 = ((($0)) + 48|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = ($40|0)==(0|0);
   if (!($41)) {
    $42 = HEAP32[$40>>2]|0;
    $43 = ((($42)) + -12|0);
    $44 = HEAP32[$43>>2]|0;
    $45 = (($40) + ($44)|0);
    $46 = ((($45)) + 8|0);
    $47 = HEAP32[$46>>2]|0;HEAP32[$46>>2] = (($47-1)|0);
    $48 = ($47|0)==(1);
    if ($48) {
     __THREW__ = 0;
     invoke_viii(3262,($45|0),1,1);
     $49 = __THREW__; __THREW__ = 0;
     $50 = $49&1;
     if ($50) {
      $84 = ___cxa_find_matching_catch_3(0|0)|0;
      $85 = tempRet0;
      ___clang_call_terminate($84);
      // unreachable;
     }
    }
   }
   HEAP32[$39>>2] = 0;
   $$0 = $38;$$02 = $37;
   label = 20;
  } else {
   $4 = ((($0)) + 48|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = ($5|0)==(0|0);
   if (!($6)) {
    $7 = HEAP32[$5>>2]|0;
    $8 = ((($7)) + -12|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = (($5) + ($9)|0);
    $11 = ((($10)) + 8|0);
    $12 = HEAP32[$11>>2]|0;HEAP32[$11>>2] = (($12-1)|0);
    $13 = ($12|0)==(1);
    if ($13) {
     __THREW__ = 0;
     invoke_viii(3262,($10|0),1,1);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      $51 = ___cxa_find_matching_catch_2()|0;
      $52 = tempRet0;
      $$0 = $52;$$02 = $51;
      label = 20;
      break;
     }
    }
   }
   HEAP32[$4>>2] = 0;
   $16 = ((($0)) + 44|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = ($17|0)==(0|0);
   if (!($18)) {
    $19 = ((($17)) + 8|0);
    $20 = HEAP32[$19>>2]|0;HEAP32[$19>>2] = (($20-1)|0);
    $21 = ($20|0)==(1);
    if ($21) {
     __THREW__ = 0;
     invoke_viii(3262,($17|0),1,1);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      $53 = ___cxa_find_matching_catch_2()|0;
      $54 = tempRet0;
      $$1 = $54;$$13 = $53;
      label = 25;
      break;
     }
    }
   }
   HEAP32[$16>>2] = 0;
   $24 = ((($0)) + 32|0);
   __THREW__ = 0;
   invoke_vi(707,($24|0));
   $25 = __THREW__; __THREW__ = 0;
   $26 = $25&1;
   if ($26) {
    $63 = ___cxa_find_matching_catch_2()|0;
    $64 = tempRet0;
    $$2 = $64;$$24 = $63;
    label = 27;
    break;
   }
   $27 = ((($0)) + 20|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = ($28|0)==(0|0);
   if (!($29)) {
    $30 = ((($28)) + 8|0);
    $31 = HEAP32[$30>>2]|0;HEAP32[$30>>2] = (($31-1)|0);
    $32 = ($31|0)==(1);
    if ($32) {
     __THREW__ = 0;
     invoke_viii(3262,($28|0),1,1);
     $33 = __THREW__; __THREW__ = 0;
     $34 = $33&1;
     if ($34) {
      $68 = ___cxa_find_matching_catch_2()|0;
      $69 = tempRet0;
      $$3 = $69;$$35 = $68;
      label = 32;
      break;
     }
    }
   }
   HEAP32[$27>>2] = 0;
   __THREW__ = 0;
   invoke_vi(2489,($1|0));
   $35 = __THREW__; __THREW__ = 0;
   $36 = $35&1;
   if ($36) {
    $78 = ___cxa_find_matching_catch_2()|0;
    $79 = tempRet0;
    $$4 = $79;$$46 = $78;
    break;
   } else {
    __ZN3osg10ReferencedD2Ev($0);
    return;
   }
  }
 } while(0);
 if ((label|0) == 20) {
  $55 = ((($0)) + 44|0);
  $56 = HEAP32[$55>>2]|0;
  $57 = ($56|0)==(0|0);
  if (!($57)) {
   $58 = ((($56)) + 8|0);
   $59 = HEAP32[$58>>2]|0;HEAP32[$58>>2] = (($59-1)|0);
   $60 = ($59|0)==(1);
   if ($60) {
    __THREW__ = 0;
    invoke_viii(3262,($56|0),1,1);
    $61 = __THREW__; __THREW__ = 0;
    $62 = $61&1;
    if ($62) {
     $84 = ___cxa_find_matching_catch_3(0|0)|0;
     $85 = tempRet0;
     ___clang_call_terminate($84);
     // unreachable;
    }
   }
  }
  HEAP32[$55>>2] = 0;
  $$1 = $$0;$$13 = $$02;
  label = 25;
 }
 if ((label|0) == 25) {
  $65 = ((($0)) + 32|0);
  __THREW__ = 0;
  invoke_vi(707,($65|0));
  $66 = __THREW__; __THREW__ = 0;
  $67 = $66&1;
  if ($67) {
   $84 = ___cxa_find_matching_catch_3(0|0)|0;
   $85 = tempRet0;
   ___clang_call_terminate($84);
   // unreachable;
  } else {
   $$2 = $$1;$$24 = $$13;
   label = 27;
  }
 }
 if ((label|0) == 27) {
  $70 = ((($0)) + 20|0);
  $71 = HEAP32[$70>>2]|0;
  $72 = ($71|0)==(0|0);
  if (!($72)) {
   $73 = ((($71)) + 8|0);
   $74 = HEAP32[$73>>2]|0;HEAP32[$73>>2] = (($74-1)|0);
   $75 = ($74|0)==(1);
   if ($75) {
    __THREW__ = 0;
    invoke_viii(3262,($71|0),1,1);
    $76 = __THREW__; __THREW__ = 0;
    $77 = $76&1;
    if ($77) {
     $84 = ___cxa_find_matching_catch_3(0|0)|0;
     $85 = tempRet0;
     ___clang_call_terminate($84);
     // unreachable;
    }
   }
  }
  HEAP32[$70>>2] = 0;
  $$3 = $$2;$$35 = $$24;
  label = 32;
 }
 if ((label|0) == 32) {
  __THREW__ = 0;
  invoke_vi(2489,($1|0));
  $80 = __THREW__; __THREW__ = 0;
  $81 = $80&1;
  if ($81) {
   $84 = ___cxa_find_matching_catch_3(0|0)|0;
   $85 = tempRet0;
   ___clang_call_terminate($84);
   // unreachable;
  } else {
   $$4 = $$3;$$46 = $$35;
  }
 }
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $82 = __THREW__; __THREW__ = 0;
 $83 = $82&1;
 if ($83) {
  $84 = ___cxa_find_matching_catch_3(0|0)|0;
  $85 = tempRet0;
  ___clang_call_terminate($84);
  // unreachable;
 } else {
  ___resumeException($$46|0);
  // unreachable;
 }
}
function __ZN3osg15OperationThreadD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1884,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZN3osg15OperationThread3runEv($0) {
 $0 = $0|0;
 var $$0 = 0, $$011$off0 = 0, $$213$off0 = 0, $$4 = 0, $$49 = 0, $$5 = 0, $$510 = 0, $$pr = 0, $$pre = 0, $$pre$phiZ2D = 0, $$sroa$057$0 = 0, $$sroa$057$1 = 0, $$sroa$057$3 = 0, $$sroa$063$0119 = 0, $$sroa$063$0120 = 0, $$sroa$063$0121 = 0, $$sroa$063$1 = 0, $$sroa$063$2 = 0, $$sroa$063$4 = 0, $$sroa$063$5 = 0;
 var $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0;
 var $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0;
 var $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0;
 var $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0;
 var $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0;
 var $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0;
 var $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $switch = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp + 8|0;
 $2 = sp + 4|0;
 $3 = sp;
 $4 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
 do {
  if ($4) {
   $5 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
   $6 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($5,145900,10)|0);
   $7 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEPKv($6,$0)|0);
   $8 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($7,145781,13)|0);
   $9 = ((($0)) + 12|0);
   $10 = (__ZN11OpenThreads6Thread9isRunningEv($9)|0);
   $11 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEb($8,$10)|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = ((($12)) + -12|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = (($11) + ($14)|0);
   __ZNKSt3__28ios_base6getlocEv($2,$15);
   __THREW__ = 0;
   $16 = (invoke_iii(3255,($2|0),(215188|0))|0);
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if (!($18)) {
    $19 = HEAP32[$16>>2]|0;
    $20 = ((($19)) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    __THREW__ = 0;
    $22 = (invoke_iii($21|0,($16|0),10)|0);
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if (!($24)) {
     __ZNSt3__26localeD2Ev($2);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($11,$22)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($11)|0);
     $$pre$phiZ2D = $9;
     break;
    }
   }
   $25 = ___cxa_find_matching_catch_2()|0;
   $26 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($2|0));
   $27 = __THREW__; __THREW__ = 0;
   $28 = $27&1;
   if ($28) {
    $29 = ___cxa_find_matching_catch_3(0|0)|0;
    $30 = tempRet0;
    ___clang_call_terminate($29);
    // unreachable;
   } else {
    ___resumeException($25|0);
    // unreachable;
   }
  } else {
   $$pre = ((($0)) + 12|0);
   $$pre$phiZ2D = $$pre;
  }
 } while(0);
 $31 = ((($0)) + 32|0);
 $32 = ((($0)) + 44|0);
 $33 = ((($0)) + 28|0);
 $34 = ((($0)) + 48|0);
 $35 = ((($0)) + 20|0);
 $36 = ((($0)) + 24|0);
 $$011$off0 = 1;
 while(1) {
  $37 = HEAP32[$31>>2]|0;
  $38 = ((($37)) + 8|0);
  $39 = HEAP32[$38>>2]|0;
  __THREW__ = 0;
  (invoke_ii($39|0,($31|0))|0);
  $40 = __THREW__; __THREW__ = 0;
  $41 = $40&1;
  if ($41) {
   $$sroa$057$1 = 0;$$sroa$063$1 = 0;
   label = 20;
   break;
  }
  $42 = HEAP32[$32>>2]|0;
  $43 = ($42|0)==(0|0);
  if ($43) {
   $$sroa$057$0 = 0;
  } else {
   $44 = ((($42)) + 8|0);
   $45 = HEAP32[$44>>2]|0;HEAP32[$44>>2] = (($45+1)|0);
   $$sroa$057$0 = $42;
  }
  $46 = HEAP32[$31>>2]|0;
  $47 = ((($46)) + 12|0);
  $48 = HEAP32[$47>>2]|0;
  __THREW__ = 0;
  (invoke_ii($48|0,($31|0))|0);
  $49 = __THREW__; __THREW__ = 0;
  $50 = $49&1;
  if ($50) {
   label = 21;
   break;
  }
  __THREW__ = 0;
  invoke_viii(3841,($3|0),($$sroa$057$0|0),1);
  $51 = __THREW__; __THREW__ = 0;
  $52 = $51&1;
  if ($52) {
   $$sroa$063$2 = 0;
   label = 22;
   break;
  }
  $53 = HEAP32[$3>>2]|0;
  $54 = ($53|0)==(0|0);
  if ($54) {
   $$sroa$063$0119 = 0;
  } else {
   $55 = HEAP32[$53>>2]|0;
   $56 = ((($55)) + -12|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = (($53) + ($57)|0);
   $59 = ((($58)) + 8|0);
   $60 = HEAP32[$59>>2]|0;HEAP32[$59>>2] = (($60+1)|0);
   $$pr = HEAP32[$3>>2]|0;
   $61 = ($$pr|0)==(0|0);
   if ($61) {
    $$sroa$063$0119 = $53;
   } else {
    $62 = HEAP32[$$pr>>2]|0;
    $63 = ((($62)) + -12|0);
    $64 = HEAP32[$63>>2]|0;
    $65 = (($$pr) + ($64)|0);
    $66 = ((($65)) + 8|0);
    $67 = HEAP32[$66>>2]|0;HEAP32[$66>>2] = (($67-1)|0);
    $68 = ($67|0)==(1);
    if ($68) {
     __THREW__ = 0;
     invoke_viii(3262,($65|0),1,1);
     $69 = __THREW__; __THREW__ = 0;
     $70 = $69&1;
     if ($70) {
      $$sroa$063$2 = $53;
      label = 22;
      break;
     } else {
      $$sroa$063$0119 = $53;
     }
    } else {
     $$sroa$063$0119 = $53;
    }
   }
  }
  /* fence */;
  $71 = HEAP32[$33>>2]|0;
  $72 = ($71|0)==(0);
  if ($72) {
   $79 = ($$sroa$063$0119|0)==(0|0);
   if ($79) {
    $$sroa$063$0121 = 0;
   } else {
    $80 = HEAP32[$31>>2]|0;
    $81 = ((($80)) + 8|0);
    $82 = HEAP32[$81>>2]|0;
    __THREW__ = 0;
    (invoke_ii($82|0,($31|0))|0);
    $83 = __THREW__; __THREW__ = 0;
    $84 = $83&1;
    if ($84) {
     $$sroa$057$1 = $$sroa$057$0;$$sroa$063$1 = $$sroa$063$0119;
     label = 20;
     break;
    }
    $85 = HEAP32[$34>>2]|0;
    $86 = ($85|0)==($$sroa$063$0119|0);
    if (!($86)) {
     HEAP32[$34>>2] = $$sroa$063$0119;
     $87 = HEAP32[$$sroa$063$0119>>2]|0;
     $88 = ((($87)) + -12|0);
     $89 = HEAP32[$88>>2]|0;
     $90 = (($$sroa$063$0119) + ($89)|0);
     $91 = ((($90)) + 8|0);
     $92 = HEAP32[$91>>2]|0;HEAP32[$91>>2] = (($92+1)|0);
     $93 = ($85|0)==(0|0);
     if (!($93)) {
      $94 = HEAP32[$85>>2]|0;
      $95 = ((($94)) + -12|0);
      $96 = HEAP32[$95>>2]|0;
      $97 = (($85) + ($96)|0);
      $98 = ((($97)) + 8|0);
      $99 = HEAP32[$98>>2]|0;HEAP32[$98>>2] = (($99-1)|0);
      $100 = ($99|0)==(1);
      if ($100) {
       __THREW__ = 0;
       invoke_viii(3262,($97|0),1,1);
       $101 = __THREW__; __THREW__ = 0;
       $102 = $101&1;
       if ($102) {
        label = 39;
        break;
       }
      }
     }
    }
    $103 = HEAP32[$31>>2]|0;
    $104 = ((($103)) + 12|0);
    $105 = HEAP32[$104>>2]|0;
    __THREW__ = 0;
    (invoke_ii($105|0,($31|0))|0);
    $106 = __THREW__; __THREW__ = 0;
    $107 = $106&1;
    if ($107) {
     label = 40;
     break;
    }
    $108 = HEAP32[$$sroa$063$0119>>2]|0;
    $109 = ((($108)) + 4|0);
    $110 = HEAP32[$109>>2]|0;
    $111 = HEAP32[$35>>2]|0;
    $112 = ($111|0)==(0|0);
    if ($112) {
     $117 = 0;
    } else {
     $113 = ((($111)) + 24|0);
     $114 = HEAP32[$113>>2]|0;
     $115 = ($114|0)==(0|0);
     if ($115) {
      $117 = 0;
     } else {
      $116 = HEAP32[$36>>2]|0;
      $117 = $116;
     }
    }
    __THREW__ = 0;
    invoke_vii($110|0,($$sroa$063$0119|0),($117|0));
    $118 = __THREW__; __THREW__ = 0;
    $119 = $118&1;
    if ($119) {
     $$sroa$057$1 = $$sroa$057$0;$$sroa$063$1 = $$sroa$063$0119;
     label = 20;
     break;
    }
    $120 = HEAP32[$31>>2]|0;
    $121 = ((($120)) + 8|0);
    $122 = HEAP32[$121>>2]|0;
    __THREW__ = 0;
    (invoke_ii($122|0,($31|0))|0);
    $123 = __THREW__; __THREW__ = 0;
    $124 = $123&1;
    if ($124) {
     $$sroa$057$1 = $$sroa$057$0;$$sroa$063$1 = $$sroa$063$0119;
     label = 20;
     break;
    }
    $125 = HEAP32[$34>>2]|0;
    $126 = ($125|0)==(0|0);
    if (!($126)) {
     HEAP32[$34>>2] = 0;
     $127 = HEAP32[$125>>2]|0;
     $128 = ((($127)) + -12|0);
     $129 = HEAP32[$128>>2]|0;
     $130 = (($125) + ($129)|0);
     $131 = ((($130)) + 8|0);
     $132 = HEAP32[$131>>2]|0;HEAP32[$131>>2] = (($132-1)|0);
     $133 = ($132|0)==(1);
     if ($133) {
      __THREW__ = 0;
      invoke_viii(3262,($130|0),1,1);
      $134 = __THREW__; __THREW__ = 0;
      $135 = $134&1;
      if ($135) {
       label = 41;
       break;
      }
     }
    }
    $136 = HEAP32[$31>>2]|0;
    $137 = ((($136)) + 12|0);
    $138 = HEAP32[$137>>2]|0;
    __THREW__ = 0;
    (invoke_ii($138|0,($31|0))|0);
    $139 = __THREW__; __THREW__ = 0;
    $140 = $139&1;
    if ($140) {
     label = 42;
     break;
    } else {
     $$sroa$063$0121 = $$sroa$063$0119;
    }
   }
   if ($$011$off0) {
    __THREW__ = 0;
    (invoke_i(3842)|0);
    $159 = __THREW__; __THREW__ = 0;
    $160 = $159&1;
    if ($160) {
     $$sroa$057$1 = $$sroa$057$0;$$sroa$063$1 = $$sroa$063$0121;
     label = 20;
     break;
    } else {
     $$0 = 0;$$213$off0 = 0;$$sroa$063$0120 = $$sroa$063$0121;
    }
   } else {
    $$0 = 0;$$213$off0 = 0;$$sroa$063$0120 = $$sroa$063$0121;
   }
  } else {
   $$0 = 2;$$213$off0 = $$011$off0;$$sroa$063$0120 = $$sroa$063$0119;
  }
  $161 = ($$sroa$057$0|0)==(0|0);
  if (!($161)) {
   $162 = ((($$sroa$057$0)) + 8|0);
   $163 = HEAP32[$162>>2]|0;HEAP32[$162>>2] = (($163-1)|0);
   $164 = ($163|0)==(1);
   if ($164) {
    __THREW__ = 0;
    invoke_viii(3262,($$sroa$057$0|0),1,1);
    $165 = __THREW__; __THREW__ = 0;
    $166 = $165&1;
    if ($166) {
     label = 61;
     break;
    }
   }
  }
  $167 = ($$sroa$063$0120|0)==(0|0);
  if (!($167)) {
   $168 = HEAP32[$$sroa$063$0120>>2]|0;
   $169 = ((($168)) + -12|0);
   $170 = HEAP32[$169>>2]|0;
   $171 = (($$sroa$063$0120) + ($170)|0);
   $172 = ((($171)) + 8|0);
   $173 = HEAP32[$172>>2]|0;HEAP32[$172>>2] = (($173-1)|0);
   $174 = ($173|0)==(1);
   if ($174) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($171,1,1);
   }
  }
  $switch = ($$0|0)==(0);
  if (!($switch)) {
   label = 54;
   break;
  }
  $175 = (__ZN11OpenThreads6Thread10testCancelEv($$pre$phiZ2D)|0);
  $176 = ($175|0)==(0);
  if (!($176)) {
   label = 54;
   break;
  }
  /* fence */;
  $177 = HEAP32[$33>>2]|0;
  $178 = ($177|0)==(0);
  if ($178) {
   $$011$off0 = $$213$off0;
  } else {
   label = 54;
   break;
  }
 }
 if ((label|0) == 20) {
  $73 = ___cxa_find_matching_catch_2()|0;
  $74 = tempRet0;
  $$4 = $74;$$49 = $73;$$sroa$057$3 = $$sroa$057$1;$$sroa$063$4 = $$sroa$063$1;
  label = 62;
 }
 else if ((label|0) == 21) {
  $75 = ___cxa_find_matching_catch_2()|0;
  $76 = tempRet0;
  $$4 = $76;$$49 = $75;$$sroa$057$3 = $$sroa$057$0;$$sroa$063$4 = 0;
  label = 62;
 }
 else if ((label|0) == 22) {
  $77 = ___cxa_find_matching_catch_2()|0;
  $78 = tempRet0;
  $$4 = $78;$$49 = $77;$$sroa$057$3 = $$sroa$057$0;$$sroa$063$4 = $$sroa$063$2;
  label = 62;
 }
 else if ((label|0) == 39) {
  $141 = ___cxa_find_matching_catch_2()|0;
  $142 = tempRet0;
  $143 = HEAP32[$31>>2]|0;
  $144 = ((($143)) + 12|0);
  $145 = HEAP32[$144>>2]|0;
  __THREW__ = 0;
  (invoke_ii($145|0,($31|0))|0);
  $146 = __THREW__; __THREW__ = 0;
  $147 = $146&1;
  if ($147) {
   $223 = ___cxa_find_matching_catch_3(0|0)|0;
   $224 = tempRet0;
   ___clang_call_terminate($223);
   // unreachable;
  } else {
   $$4 = $142;$$49 = $141;$$sroa$057$3 = $$sroa$057$0;$$sroa$063$4 = $$sroa$063$0119;
   label = 62;
  }
 }
 else if ((label|0) == 40) {
  $148 = ___cxa_find_matching_catch_2()|0;
  $149 = tempRet0;
  $$4 = $149;$$49 = $148;$$sroa$057$3 = $$sroa$057$0;$$sroa$063$4 = $$sroa$063$0119;
  label = 62;
 }
 else if ((label|0) == 41) {
  $150 = ___cxa_find_matching_catch_2()|0;
  $151 = tempRet0;
  $152 = HEAP32[$31>>2]|0;
  $153 = ((($152)) + 12|0);
  $154 = HEAP32[$153>>2]|0;
  __THREW__ = 0;
  (invoke_ii($154|0,($31|0))|0);
  $155 = __THREW__; __THREW__ = 0;
  $156 = $155&1;
  if ($156) {
   $223 = ___cxa_find_matching_catch_3(0|0)|0;
   $224 = tempRet0;
   ___clang_call_terminate($223);
   // unreachable;
  } else {
   $$4 = $151;$$49 = $150;$$sroa$057$3 = $$sroa$057$0;$$sroa$063$4 = $$sroa$063$0119;
   label = 62;
  }
 }
 else if ((label|0) == 42) {
  $157 = ___cxa_find_matching_catch_2()|0;
  $158 = tempRet0;
  $$4 = $158;$$49 = $157;$$sroa$057$3 = $$sroa$057$0;$$sroa$063$4 = $$sroa$063$0119;
  label = 62;
 }
 else if ((label|0) == 54) {
  $179 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
  if (!($179)) {
   STACKTOP = sp;return;
  }
  $180 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
  $181 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($180,145911,10)|0);
  $182 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEPKv($181,$0)|0);
  $183 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($182,145781,13)|0);
  $184 = (__ZN11OpenThreads6Thread9isRunningEv($$pre$phiZ2D)|0);
  $185 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEb($183,$184)|0);
  $186 = HEAP32[$185>>2]|0;
  $187 = ((($186)) + -12|0);
  $188 = HEAP32[$187>>2]|0;
  $189 = (($185) + ($188)|0);
  __ZNKSt3__28ios_base6getlocEv($1,$189);
  __THREW__ = 0;
  $190 = (invoke_iii(3255,($1|0),(215188|0))|0);
  $191 = __THREW__; __THREW__ = 0;
  $192 = $191&1;
  if (!($192)) {
   $193 = HEAP32[$190>>2]|0;
   $194 = ((($193)) + 28|0);
   $195 = HEAP32[$194>>2]|0;
   __THREW__ = 0;
   $196 = (invoke_iii($195|0,($190|0),10)|0);
   $197 = __THREW__; __THREW__ = 0;
   $198 = $197&1;
   if (!($198)) {
    __ZNSt3__26localeD2Ev($1);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($185,$196)|0);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($185)|0);
    STACKTOP = sp;return;
   }
  }
  $199 = ___cxa_find_matching_catch_2()|0;
  $200 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3263,($1|0));
  $201 = __THREW__; __THREW__ = 0;
  $202 = $201&1;
  if ($202) {
   $203 = ___cxa_find_matching_catch_3(0|0)|0;
   $204 = tempRet0;
   ___clang_call_terminate($203);
   // unreachable;
  } else {
   ___resumeException($199|0);
   // unreachable;
  }
 }
 else if ((label|0) == 61) {
  $205 = ___cxa_find_matching_catch_2()|0;
  $206 = tempRet0;
  $$5 = $206;$$510 = $205;$$sroa$063$5 = $$sroa$063$0120;
 }
 if ((label|0) == 62) {
  $207 = ($$sroa$057$3|0)==(0|0);
  if ($207) {
   $$5 = $$4;$$510 = $$49;$$sroa$063$5 = $$sroa$063$4;
  } else {
   $208 = ((($$sroa$057$3)) + 8|0);
   $209 = HEAP32[$208>>2]|0;HEAP32[$208>>2] = (($209-1)|0);
   $210 = ($209|0)==(1);
   if ($210) {
    __THREW__ = 0;
    invoke_viii(3262,($$sroa$057$3|0),1,1);
    $211 = __THREW__; __THREW__ = 0;
    $212 = $211&1;
    if ($212) {
     $223 = ___cxa_find_matching_catch_3(0|0)|0;
     $224 = tempRet0;
     ___clang_call_terminate($223);
     // unreachable;
    } else {
     $$5 = $$4;$$510 = $$49;$$sroa$063$5 = $$sroa$063$4;
    }
   } else {
    $$5 = $$4;$$510 = $$49;$$sroa$063$5 = $$sroa$063$4;
   }
  }
 }
 $213 = ($$sroa$063$5|0)==(0|0);
 if ($213) {
  ___resumeException($$510|0);
  // unreachable;
 }
 $214 = HEAP32[$$sroa$063$5>>2]|0;
 $215 = ((($214)) + -12|0);
 $216 = HEAP32[$215>>2]|0;
 $217 = (($$sroa$063$5) + ($216)|0);
 $218 = ((($217)) + 8|0);
 $219 = HEAP32[$218>>2]|0;HEAP32[$218>>2] = (($219-1)|0);
 $220 = ($219|0)==(1);
 if (!($220)) {
  ___resumeException($$510|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(3262,($217|0),1,1);
 $221 = __THREW__; __THREW__ = 0;
 $222 = $221&1;
 if ($222) {
  $223 = ___cxa_find_matching_catch_3(0|0)|0;
  $224 = tempRet0;
  ___clang_call_terminate($223);
  // unreachable;
 } else {
  ___resumeException($$510|0);
  // unreachable;
 }
}
function __ZN3osg15OperationThread6cancelEv($0) {
 $0 = $0|0;
 var $$pre$phi33Z2D = 0, $$pre$phiZ2D = 0, $$pre32 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, $eh$lpad$body13$index7Z2D = 0, $eh$lpad$body13$indexZ2D = 0, $eh$lpad$body13$sink27$index12Z2D = 0, $eh$lpad$body13$sink27$indexZ2D = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp + 12|0;
 $2 = sp + 8|0;
 $3 = sp + 4|0;
 $4 = sp;
 $5 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
 do {
  if ($5) {
   $6 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
   $7 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($6,145753,27)|0);
   $8 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEPKv($7,$0)|0);
   $9 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($8,145781,13)|0);
   $10 = ((($0)) + 12|0);
   $11 = (__ZN11OpenThreads6Thread9isRunningEv($10)|0);
   $12 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEb($9,$11)|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = ((($13)) + -12|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (($12) + ($15)|0);
   __ZNKSt3__28ios_base6getlocEv($4,$16);
   __THREW__ = 0;
   $17 = (invoke_iii(3255,($4|0),(215188|0))|0);
   $18 = __THREW__; __THREW__ = 0;
   $19 = $18&1;
   if (!($19)) {
    $20 = HEAP32[$17>>2]|0;
    $21 = ((($20)) + 28|0);
    $22 = HEAP32[$21>>2]|0;
    __THREW__ = 0;
    $23 = (invoke_iii($22|0,($17|0),10)|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     __ZNSt3__26localeD2Ev($4);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($12,$23)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($12)|0);
     $$pre$phi33Z2D = $10;$$pre$phiZ2D = $0;
     break;
    }
   }
   $26 = ___cxa_find_matching_catch_2()|0;
   $27 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($4|0));
   $28 = __THREW__; __THREW__ = 0;
   $29 = $28&1;
   if ($29) {
    $30 = ___cxa_find_matching_catch_3(0|0)|0;
    $31 = tempRet0;
    ___clang_call_terminate($30);
    // unreachable;
   } else {
    ___resumeException($26|0);
    // unreachable;
   }
  } else {
   $$pre32 = ((($0)) + 12|0);
   $$pre$phi33Z2D = $$pre32;$$pre$phiZ2D = $0;
  }
 } while(0);
 $32 = (__ZN11OpenThreads6Thread9isRunningEv($$pre$phi33Z2D)|0);
 L12: do {
  if ($32) {
   $33 = ((($0)) + 28|0);
   $34 = HEAP32[$33>>2]|0;HEAP32[$33>>2] = 1;
   $35 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
   do {
    if ($35) {
     $36 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
     $37 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($36,145795,16)|0);
     $38 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEPKv($37,$$pre$phiZ2D)|0);
     $39 = HEAP32[$38>>2]|0;
     $40 = ((($39)) + -12|0);
     $41 = HEAP32[$40>>2]|0;
     $42 = (($38) + ($41)|0);
     __ZNKSt3__28ios_base6getlocEv($3,$42);
     __THREW__ = 0;
     $43 = (invoke_iii(3255,($3|0),(215188|0))|0);
     $44 = __THREW__; __THREW__ = 0;
     $45 = $44&1;
     if (!($45)) {
      $46 = HEAP32[$43>>2]|0;
      $47 = ((($46)) + 28|0);
      $48 = HEAP32[$47>>2]|0;
      __THREW__ = 0;
      $49 = (invoke_iii($48|0,($43|0),10)|0);
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if (!($51)) {
       __ZNSt3__26localeD2Ev($3);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($38,$49)|0);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($38)|0);
       break;
      }
     }
     $52 = ___cxa_find_matching_catch_2()|0;
     $53 = tempRet0;
     __THREW__ = 0;
     invoke_vi(3263,($3|0));
     $54 = __THREW__; __THREW__ = 0;
     $55 = $54&1;
     if ($55) {
      $56 = ___cxa_find_matching_catch_3(0|0)|0;
      $57 = tempRet0;
      ___clang_call_terminate($56);
      // unreachable;
     } else {
      ___resumeException($52|0);
      // unreachable;
     }
    }
   } while(0);
   $58 = ((($0)) + 32|0);
   $59 = HEAP32[$58>>2]|0;
   $60 = ((($59)) + 8|0);
   $61 = HEAP32[$60>>2]|0;
   (FUNCTION_TABLE_ii[$61 & 8191]($58)|0);
   $62 = ((($0)) + 44|0);
   $63 = HEAP32[$62>>2]|0;
   $64 = ($63|0)==(0|0);
   do {
    if ($64) {
     label = 26;
    } else {
     $65 = ((($63)) + 24|0);
     $66 = HEAP32[$65>>2]|0;
     $67 = ((($66)) + 4|0);
     $68 = HEAP32[$67>>2]|0;
     $69 = ((($68)) + 8|0);
     $70 = HEAP32[$69>>2]|0;
     __THREW__ = 0;
     (invoke_ii($70|0,($67|0))|0);
     $71 = __THREW__; __THREW__ = 0;
     $72 = $71&1;
     if ($72) {
      label = 24;
     } else {
      $73 = ((($66)) + 24|0);
      $74 = HEAP8[$73>>0]|0;
      $75 = ($74<<24>>24)==(0);
      if ($75) {
       HEAP8[$73>>0] = 1;
       $76 = ((($66)) + 16|0);
       __THREW__ = 0;
       (invoke_ii(2504,($76|0))|0);
       $77 = __THREW__; __THREW__ = 0;
       $78 = $77&1;
       if ($78) {
        $79 = ___cxa_find_matching_catch_2()|0;
        $80 = tempRet0;
        $81 = HEAP32[$67>>2]|0;
        $82 = ((($81)) + 12|0);
        $83 = HEAP32[$82>>2]|0;
        __THREW__ = 0;
        (invoke_ii($83|0,($67|0))|0);
        $84 = __THREW__; __THREW__ = 0;
        $85 = $84&1;
        if (!($85)) {
         $eh$lpad$body$index2Z2D = $80;$eh$lpad$body$indexZ2D = $79;
         break;
        }
        $86 = ___cxa_find_matching_catch_3(0|0)|0;
        $87 = tempRet0;
        ___clang_call_terminate($86);
        // unreachable;
       }
      }
      $88 = HEAP32[$67>>2]|0;
      $89 = ((($88)) + 12|0);
      $90 = HEAP32[$89>>2]|0;
      __THREW__ = 0;
      (invoke_ii($90|0,($67|0))|0);
      $91 = __THREW__; __THREW__ = 0;
      $92 = $91&1;
      if ($92) {
       label = 24;
      } else {
       label = 26;
      }
     }
    }
   } while(0);
   do {
    if ((label|0) == 26) {
     $100 = ((($0)) + 48|0);
     $101 = HEAP32[$100>>2]|0;
     $102 = ($101|0)==(0|0);
     if (!($102)) {
      $103 = HEAP32[$101>>2]|0;
      $104 = HEAP32[$103>>2]|0;
      __THREW__ = 0;
      invoke_vi($104|0,($101|0));
      $105 = __THREW__; __THREW__ = 0;
      $106 = $105&1;
      if ($106) {
       label = 24;
       break;
      }
     }
     $107 = HEAP32[$58>>2]|0;
     $108 = ((($107)) + 12|0);
     $109 = HEAP32[$108>>2]|0;
     (FUNCTION_TABLE_ii[$109 & 8191]($58)|0);
     $110 = (__ZN11OpenThreads6Thread9isRunningEv($$pre$phi33Z2D)|0);
     L37: do {
      if ($110) {
       while(1) {
        $111 = HEAP32[$58>>2]|0;
        $112 = ((($111)) + 8|0);
        $113 = HEAP32[$112>>2]|0;
        (FUNCTION_TABLE_ii[$113 & 8191]($58)|0);
        $114 = HEAP32[$62>>2]|0;
        $115 = ($114|0)==(0|0);
        if (!($115)) {
         $116 = ((($114)) + 24|0);
         $117 = HEAP32[$116>>2]|0;
         $118 = ((($117)) + 4|0);
         $119 = HEAP32[$118>>2]|0;
         $120 = ((($119)) + 8|0);
         $121 = HEAP32[$120>>2]|0;
         __THREW__ = 0;
         (invoke_ii($121|0,($118|0))|0);
         $122 = __THREW__; __THREW__ = 0;
         $123 = $122&1;
         if ($123) {
          label = 37;
          break;
         }
         $124 = ((($117)) + 24|0);
         $125 = HEAP8[$124>>0]|0;
         $126 = ($125<<24>>24)==(0);
         if ($126) {
          HEAP8[$124>>0] = 1;
          $127 = ((($117)) + 16|0);
          __THREW__ = 0;
          (invoke_ii(2504,($127|0))|0);
          $128 = __THREW__; __THREW__ = 0;
          $129 = $128&1;
          if ($129) {
           label = 34;
           break;
          }
         }
         $139 = HEAP32[$118>>2]|0;
         $140 = ((($139)) + 12|0);
         $141 = HEAP32[$140>>2]|0;
         __THREW__ = 0;
         (invoke_ii($141|0,($118|0))|0);
         $142 = __THREW__; __THREW__ = 0;
         $143 = $142&1;
         if ($143) {
          label = 37;
          break;
         }
        }
        $151 = HEAP32[$100>>2]|0;
        $152 = ($151|0)==(0|0);
        if (!($152)) {
         $153 = HEAP32[$151>>2]|0;
         $154 = HEAP32[$153>>2]|0;
         __THREW__ = 0;
         invoke_vi($154|0,($151|0));
         $155 = __THREW__; __THREW__ = 0;
         $156 = $155&1;
         if ($156) {
          label = 37;
          break;
         }
        }
        $157 = HEAP32[$58>>2]|0;
        $158 = ((($157)) + 12|0);
        $159 = HEAP32[$158>>2]|0;
        (FUNCTION_TABLE_ii[$159 & 8191]($58)|0);
        $160 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(5)|0);
        if ($160) {
         $161 = (__ZN3osg6notifyENS_14NotifySeverityE(5)|0);
         $162 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($161,145812,41)|0);
         $163 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEPKv($162,$$pre$phiZ2D)|0);
         $164 = HEAP32[$163>>2]|0;
         $165 = ((($164)) + -12|0);
         $166 = HEAP32[$165>>2]|0;
         $167 = (($163) + ($166)|0);
         __ZNKSt3__28ios_base6getlocEv($2,$167);
         __THREW__ = 0;
         $168 = (invoke_iii(3255,($2|0),(215188|0))|0);
         $169 = __THREW__; __THREW__ = 0;
         $170 = $169&1;
         if ($170) {
          label = 44;
          break;
         }
         $171 = HEAP32[$168>>2]|0;
         $172 = ((($171)) + 28|0);
         $173 = HEAP32[$172>>2]|0;
         __THREW__ = 0;
         $174 = (invoke_iii($173|0,($168|0),10)|0);
         $175 = __THREW__; __THREW__ = 0;
         $176 = $175&1;
         if ($176) {
          label = 44;
          break;
         }
         __ZNSt3__26localeD2Ev($2);
         (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($163,$174)|0);
         (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($163)|0);
        }
        (__ZN11OpenThreads6Thread18YieldCurrentThreadEv()|0);
        $183 = (__ZN11OpenThreads6Thread9isRunningEv($$pre$phi33Z2D)|0);
        if (!($183)) {
         break L37;
        }
       }
       if ((label|0) == 34) {
        $130 = ___cxa_find_matching_catch_2()|0;
        $131 = tempRet0;
        $132 = HEAP32[$118>>2]|0;
        $133 = ((($132)) + 12|0);
        $134 = HEAP32[$133>>2]|0;
        __THREW__ = 0;
        (invoke_ii($134|0,($118|0))|0);
        $135 = __THREW__; __THREW__ = 0;
        $136 = $135&1;
        if ($136) {
         $137 = ___cxa_find_matching_catch_3(0|0)|0;
         $138 = tempRet0;
         ___clang_call_terminate($137);
         // unreachable;
        } else {
         $eh$lpad$body13$index7Z2D = $131;$eh$lpad$body13$indexZ2D = $130;
        }
       }
       else if ((label|0) == 37) {
        $144 = ___cxa_find_matching_catch_2()|0;
        $145 = tempRet0;
        $eh$lpad$body13$index7Z2D = $145;$eh$lpad$body13$indexZ2D = $144;
       }
       else if ((label|0) == 44) {
        $177 = ___cxa_find_matching_catch_2()|0;
        $178 = tempRet0;
        __THREW__ = 0;
        invoke_vi(3263,($2|0));
        $179 = __THREW__; __THREW__ = 0;
        $180 = $179&1;
        if ($180) {
         $181 = ___cxa_find_matching_catch_3(0|0)|0;
         $182 = tempRet0;
         ___clang_call_terminate($181);
         // unreachable;
        } else {
         ___resumeException($177|0);
         // unreachable;
        }
       }
       $146 = HEAP32[$58>>2]|0;
       $147 = ((($146)) + 12|0);
       $148 = HEAP32[$147>>2]|0;
       __THREW__ = 0;
       (invoke_ii($148|0,($58|0))|0);
       $149 = __THREW__; __THREW__ = 0;
       $150 = $149&1;
       if ($150) {
        $210 = ___cxa_find_matching_catch_3(0|0)|0;
        $211 = tempRet0;
        ___clang_call_terminate($210);
        // unreachable;
       } else {
        $eh$lpad$body13$sink27$index12Z2D = $eh$lpad$body13$index7Z2D;$eh$lpad$body13$sink27$indexZ2D = $eh$lpad$body13$indexZ2D;
        ___resumeException($eh$lpad$body13$sink27$indexZ2D|0);
        // unreachable;
       }
      }
     } while(0);
     (__ZN11OpenThreads6Thread4joinEv($$pre$phi33Z2D)|0);
     break L12;
    }
   } while(0);
   if ((label|0) == 24) {
    $93 = ___cxa_find_matching_catch_2()|0;
    $94 = tempRet0;
    $eh$lpad$body$index2Z2D = $94;$eh$lpad$body$indexZ2D = $93;
   }
   $95 = HEAP32[$58>>2]|0;
   $96 = ((($95)) + 12|0);
   $97 = HEAP32[$96>>2]|0;
   __THREW__ = 0;
   (invoke_ii($97|0,($58|0))|0);
   $98 = __THREW__; __THREW__ = 0;
   $99 = $98&1;
   if ($99) {
    $210 = ___cxa_find_matching_catch_3(0|0)|0;
    $211 = tempRet0;
    ___clang_call_terminate($210);
    // unreachable;
   } else {
    $eh$lpad$body13$sink27$index12Z2D = $eh$lpad$body$index2Z2D;$eh$lpad$body13$sink27$indexZ2D = $eh$lpad$body$indexZ2D;
    ___resumeException($eh$lpad$body13$sink27$indexZ2D|0);
    // unreachable;
   }
  }
 } while(0);
 $184 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
 if (!($184)) {
  STACKTOP = sp;return 0;
 }
 $185 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
 $186 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($185,145854,45)|0);
 $187 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEPKv($186,$$pre$phiZ2D)|0);
 $188 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($187,145781,13)|0);
 $189 = (__ZN11OpenThreads6Thread9isRunningEv($$pre$phi33Z2D)|0);
 $190 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEb($188,$189)|0);
 $191 = HEAP32[$190>>2]|0;
 $192 = ((($191)) + -12|0);
 $193 = HEAP32[$192>>2]|0;
 $194 = (($190) + ($193)|0);
 __ZNKSt3__28ios_base6getlocEv($1,$194);
 __THREW__ = 0;
 $195 = (invoke_iii(3255,($1|0),(215188|0))|0);
 $196 = __THREW__; __THREW__ = 0;
 $197 = $196&1;
 if (!($197)) {
  $198 = HEAP32[$195>>2]|0;
  $199 = ((($198)) + 28|0);
  $200 = HEAP32[$199>>2]|0;
  __THREW__ = 0;
  $201 = (invoke_iii($200|0,($195|0),10)|0);
  $202 = __THREW__; __THREW__ = 0;
  $203 = $202&1;
  if (!($203)) {
   __ZNSt3__26localeD2Ev($1);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($190,$201)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($190)|0);
   STACKTOP = sp;return 0;
  }
 }
 $204 = ___cxa_find_matching_catch_2()|0;
 $205 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($1|0));
 $206 = __THREW__; __THREW__ = 0;
 $207 = $206&1;
 if ($207) {
  $208 = ___cxa_find_matching_catch_3(0|0)|0;
  $209 = tempRet0;
  ___clang_call_terminate($208);
  // unreachable;
 } else {
  ___resumeException($204|0);
  // unreachable;
 }
 return (0)|0;
}
function __ZThn12_N3osg15OperationThreadD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -12|0);
 __ZN3osg15OperationThreadD2Ev($1);
 return;
}
function __ZThn12_N3osg15OperationThreadD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -12|0);
 __THREW__ = 0;
 invoke_vi(1884,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch_2()|0;
  $5 = tempRet0;
  __ZdlPv($1);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZdlPv($1);
  return;
 }
}
function __ZThn12_N3osg15OperationThread6cancelEv($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -12|0);
 (__ZN3osg15OperationThread6cancelEv($1)|0);
 return 0;
}
function __ZThn12_N3osg15OperationThread3runEv($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -12|0);
 __ZN3osg15OperationThread3runEv($1);
 return;
}
function __ZN3osg14OperationQueue16getNextOperationEb($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$1 = 0, $$18 = 0, $$cast$i = 0, $$sroa$0$0$$sroa_idx = 0, $$sroa$03$0$$sroa_idx = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($1)) + 36|0);
 if ($2) {
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==(0);
  if ($5) {
   $6 = ((($1)) + 24|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ((($7)) + 4|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = ((($9)) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   (FUNCTION_TABLE_ii[$11 & 8191]($8)|0);
   $12 = ((($7)) + 24|0);
   $13 = HEAP8[$12>>0]|0;
   $14 = ($13<<24>>24)==(0);
   if ($14) {
    $15 = ((($7)) + 16|0);
    __THREW__ = 0;
    (invoke_iii(2501,($15|0),($8|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     $18 = ___cxa_find_matching_catch_2()|0;
     $19 = tempRet0;
     $20 = HEAP32[$8>>2]|0;
     $21 = ((($20)) + 12|0);
     $22 = HEAP32[$21>>2]|0;
     __THREW__ = 0;
     (invoke_ii($22|0,($8|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      $25 = ___cxa_find_matching_catch_3(0|0)|0;
      $26 = tempRet0;
      ___clang_call_terminate($25);
      // unreachable;
     } else {
      ___resumeException($18|0);
      // unreachable;
     }
    }
   }
   $27 = HEAP32[$8>>2]|0;
   $28 = ((($27)) + 12|0);
   $29 = HEAP32[$28>>2]|0;
   (FUNCTION_TABLE_ii[$29 & 8191]($8)|0);
  }
 }
 $30 = ((($1)) + 12|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ((($31)) + 8|0);
 $33 = HEAP32[$32>>2]|0;
 (FUNCTION_TABLE_ii[$33 & 8191]($30)|0);
 $34 = HEAP32[$3>>2]|0;
 $35 = ($34|0)==(0);
 if ($35) {
  HEAP32[$0>>2] = 0;
  $123 = HEAP32[$30>>2]|0;
  $124 = ((($123)) + 12|0);
  $125 = HEAP32[$124>>2]|0;
  (FUNCTION_TABLE_ii[$125 & 8191]($30)|0);
  return;
 }
 $36 = ((($1)) + 40|0);
 $37 = ((($1)) + 28|0);
 $38 = HEAP32[$36>>2]|0;
 $39 = ($38|0)==($37|0);
 if ($39) {
  $40 = ((($1)) + 32|0);
  $41 = HEAP32[$40>>2]|0;
  $$sroa$03$0$$sroa_idx = ((($1)) + 40|0);
  HEAP32[$$sroa$03$0$$sroa_idx>>2] = $41;
  $42 = $41;
  $44 = $42;
 } else {
  $44 = $38;
 }
 $43 = ((($44)) + 8|0);
 $45 = HEAP32[$43>>2]|0;
 $46 = ($45|0)==(0|0);
 if (!($46)) {
  $47 = HEAP32[$45>>2]|0;
  $48 = ((($47)) + -12|0);
  $49 = HEAP32[$48>>2]|0;
  $50 = (($45) + ($49)|0);
  $51 = ((($50)) + 8|0);
  $52 = HEAP32[$51>>2]|0;HEAP32[$51>>2] = (($52+1)|0);
 }
 $53 = ((($45)) + 16|0);
 $54 = HEAP8[$53>>0]|0;
 $55 = ($54<<24>>24)==(0);
 $56 = HEAP32[$36>>2]|0;
 $57 = ((($56)) + 4|0);
 do {
  if ($55) {
   $58 = HEAP32[$57>>2]|0;
   $$cast$i = $58;
   $59 = HEAP32[$56>>2]|0;
   $60 = ((($59)) + 4|0);
   HEAP32[$60>>2] = $$cast$i;
   $61 = HEAP32[$57>>2]|0;
   HEAP32[$61>>2] = $59;
   $62 = HEAP32[$3>>2]|0;
   $63 = (($62) + -1)|0;
   HEAP32[$3>>2] = $63;
   $64 = ((($56)) + 8|0);
   $65 = HEAP32[$64>>2]|0;
   $66 = ($65|0)==(0|0);
   if ($66) {
    label = 19;
   } else {
    $67 = HEAP32[$65>>2]|0;
    $68 = ((($67)) + -12|0);
    $69 = HEAP32[$68>>2]|0;
    $70 = (($65) + ($69)|0);
    $71 = ((($70)) + 8|0);
    $72 = HEAP32[$71>>2]|0;HEAP32[$71>>2] = (($72-1)|0);
    $73 = ($72|0)==(1);
    if ($73) {
     __THREW__ = 0;
     invoke_viii(3262,($70|0),1,1);
     $74 = __THREW__; __THREW__ = 0;
     $75 = $74&1;
     if (!($75)) {
      label = 19;
     }
    } else {
     label = 19;
    }
   }
   if ((label|0) == 19) {
    __ZdlPv($56);
    $$sroa$0$0$$sroa_idx = ((($1)) + 40|0);
    HEAP32[$$sroa$0$0$$sroa_idx>>2] = $58;
    $76 = HEAP32[$3>>2]|0;
    $77 = ($76|0)==(0);
    if (!($77)) {
     label = 24;
     break;
    }
    $78 = ((($1)) + 24|0);
    $79 = HEAP32[$78>>2]|0;
    $80 = ((($79)) + 4|0);
    $81 = ((($79)) + 24|0);
    $82 = HEAP8[$81>>0]|0;
    $83 = ($82<<24>>24)==(0);
    if ($83) {
     label = 24;
     break;
    }
    $84 = HEAP32[$80>>2]|0;
    $85 = ((($84)) + 8|0);
    $86 = HEAP32[$85>>2]|0;
    __THREW__ = 0;
    (invoke_ii($86|0,($80|0))|0);
    $87 = __THREW__; __THREW__ = 0;
    $88 = $87&1;
    if (!($88)) {
     HEAP8[$81>>0] = 0;
     $89 = HEAP32[$80>>2]|0;
     $90 = ((($89)) + 12|0);
     $91 = HEAP32[$90>>2]|0;
     __THREW__ = 0;
     (invoke_ii($91|0,($80|0))|0);
     $92 = __THREW__; __THREW__ = 0;
     $93 = $92&1;
     if (!($93)) {
      label = 24;
      break;
     }
    }
   }
   $112 = ___cxa_find_matching_catch_2()|0;
   $113 = tempRet0;
   if ($46) {
    $$1 = $112;$$18 = $113;
   } else {
    $114 = HEAP32[$45>>2]|0;
    $115 = ((($114)) + -12|0);
    $116 = HEAP32[$115>>2]|0;
    $117 = (($45) + ($116)|0);
    $118 = ((($117)) + 8|0);
    $119 = HEAP32[$118>>2]|0;HEAP32[$118>>2] = (($119-1)|0);
    $120 = ($119|0)==(1);
    if ($120) {
     __THREW__ = 0;
     invoke_viii(3262,($117|0),1,1);
     $121 = __THREW__; __THREW__ = 0;
     $122 = $121&1;
     if ($122) {
      $131 = ___cxa_find_matching_catch_3(0|0)|0;
      $132 = tempRet0;
      ___clang_call_terminate($131);
      // unreachable;
     } else {
      $$1 = $112;$$18 = $113;
     }
    } else {
     $$1 = $112;$$18 = $113;
    }
   }
  } else {
   $94 = HEAP32[$57>>2]|0;
   HEAP32[$36>>2] = $94;
   label = 24;
  }
 } while(0);
 do {
  if ((label|0) == 24) {
   HEAP32[$0>>2] = $45;
   if ($46) {
    $123 = HEAP32[$30>>2]|0;
    $124 = ((($123)) + 12|0);
    $125 = HEAP32[$124>>2]|0;
    (FUNCTION_TABLE_ii[$125 & 8191]($30)|0);
    return;
   }
   $95 = HEAP32[$45>>2]|0;
   $96 = ((($95)) + -12|0);
   $97 = HEAP32[$96>>2]|0;
   $98 = (($45) + ($97)|0);
   $99 = ((($98)) + 8|0);
   $100 = HEAP32[$99>>2]|0;HEAP32[$99>>2] = (($100+1)|0);
   $101 = HEAP32[$45>>2]|0;
   $102 = ((($101)) + -12|0);
   $103 = HEAP32[$102>>2]|0;
   $104 = (($45) + ($103)|0);
   $105 = ((($104)) + 8|0);
   $106 = HEAP32[$105>>2]|0;HEAP32[$105>>2] = (($106-1)|0);
   $107 = ($106|0)==(1);
   if (!($107)) {
    $123 = HEAP32[$30>>2]|0;
    $124 = ((($123)) + 12|0);
    $125 = HEAP32[$124>>2]|0;
    (FUNCTION_TABLE_ii[$125 & 8191]($30)|0);
    return;
   }
   __THREW__ = 0;
   invoke_viii(3262,($104|0),1,1);
   $108 = __THREW__; __THREW__ = 0;
   $109 = $108&1;
   if ($109) {
    $110 = ___cxa_find_matching_catch_2()|0;
    $111 = tempRet0;
    $$1 = $110;$$18 = $111;
    break;
   } else {
    $123 = HEAP32[$30>>2]|0;
    $124 = ((($123)) + 12|0);
    $125 = HEAP32[$124>>2]|0;
    (FUNCTION_TABLE_ii[$125 & 8191]($30)|0);
    return;
   }
  }
 } while(0);
 $126 = HEAP32[$30>>2]|0;
 $127 = ((($126)) + 12|0);
 $128 = HEAP32[$127>>2]|0;
 __THREW__ = 0;
 (invoke_ii($128|0,($30|0))|0);
 $129 = __THREW__; __THREW__ = 0;
 $130 = $129&1;
 if ($130) {
  $131 = ___cxa_find_matching_catch_3(0|0)|0;
  $132 = tempRet0;
  ___clang_call_terminate($131);
  // unreachable;
 } else {
  ___resumeException($$1|0);
  // unreachable;
 }
}
function __ZN3osg14OperationQueueC2Ev($0) {
 $0 = $0|0;
 var $$0 = 0, $$023$i$i = 0, $$03 = 0, $$3 = 0, $$36 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg10ReferencedC2Eb($0,1);
 HEAP32[$0>>2] = (63600);
 $1 = ((($0)) + 12|0);
 __THREW__ = 0;
 invoke_vii(3507,($1|0),0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $37 = ___cxa_find_matching_catch_2()|0;
  $38 = tempRet0;
  $$3 = $37;$$36 = $38;
 } else {
  $4 = ((($0)) + 24|0);
  HEAP32[$4>>2] = 0;
  $5 = ((($0)) + 28|0);
  HEAP32[$5>>2] = $5;
  $6 = ((($0)) + 32|0);
  HEAP32[$6>>2] = $5;
  $7 = ((($0)) + 36|0);
  HEAP32[$7>>2] = 0;
  $8 = ((($0)) + 40|0);
  $9 = ((($0)) + 44|0);
  $10 = ((($0)) + 48|0);
  HEAP32[$10>>2] = 0;
  $11 = ((($0)) + 52|0);
  HEAP32[$11>>2] = 0;
  $12 = ((($0)) + 48|0);
  HEAP32[$9>>2] = $12;
  $13 = $5;
  HEAP32[$8>>2] = $13;
  __THREW__ = 0;
  $14 = (invoke_ii(3276,40)|0);
  $15 = __THREW__; __THREW__ = 0;
  $16 = $15&1;
  do {
   if ($16) {
    label = 10;
   } else {
    __THREW__ = 0;
    invoke_vi(3803,($14|0));
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     $41 = ___cxa_find_matching_catch_2()|0;
     $42 = tempRet0;
     __ZdlPv($14);
     $$0 = $41;$$03 = $42;
     break;
    }
    $19 = HEAP32[$4>>2]|0;
    $20 = ($19|0)==($14|0);
    if ($20) {
     return;
    }
    HEAP32[$4>>2] = $14;
    $21 = HEAP32[$14>>2]|0;
    $22 = ((($21)) + -12|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = (($14) + ($23)|0);
    $25 = ((($24)) + 8|0);
    $26 = HEAP32[$25>>2]|0;HEAP32[$25>>2] = (($26+1)|0);
    $27 = ($19|0)==(0|0);
    if ($27) {
     return;
    }
    $28 = HEAP32[$19>>2]|0;
    $29 = ((($28)) + -12|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = (($19) + ($30)|0);
    $32 = ((($31)) + 8|0);
    $33 = HEAP32[$32>>2]|0;HEAP32[$32>>2] = (($33-1)|0);
    $34 = ($33|0)==(1);
    if (!($34)) {
     return;
    }
    __THREW__ = 0;
    invoke_viii(3262,($31|0),1,1);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     label = 10;
    } else {
     return;
    }
   }
  } while(0);
  if ((label|0) == 10) {
   $39 = ___cxa_find_matching_catch_2()|0;
   $40 = tempRet0;
   $$0 = $39;$$03 = $40;
  }
  $43 = HEAP32[$12>>2]|0;
  __ZNSt3__26__treeIPN3osg15OperationThreadENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($9,$43);
  $44 = HEAP32[$7>>2]|0;
  $45 = ($44|0)==(0);
  L22: do {
   if (!($45)) {
    $46 = HEAP32[$6>>2]|0;
    $47 = HEAP32[$5>>2]|0;
    $48 = ((($47)) + 4|0);
    $49 = HEAP32[$48>>2]|0;
    $50 = HEAP32[$46>>2]|0;
    $51 = ((($50)) + 4|0);
    HEAP32[$51>>2] = $49;
    $52 = HEAP32[$48>>2]|0;
    HEAP32[$52>>2] = $50;
    HEAP32[$7>>2] = 0;
    $53 = ($46|0)==($5|0);
    if (!($53)) {
     $$023$i$i = $46;
     while(1) {
      $54 = ((($$023$i$i)) + 4|0);
      $55 = HEAP32[$54>>2]|0;
      $56 = ((($$023$i$i)) + 8|0);
      $57 = HEAP32[$56>>2]|0;
      $58 = ($57|0)==(0|0);
      if (!($58)) {
       $59 = HEAP32[$57>>2]|0;
       $60 = ((($59)) + -12|0);
       $61 = HEAP32[$60>>2]|0;
       $62 = (($57) + ($61)|0);
       $63 = ((($62)) + 8|0);
       $64 = HEAP32[$63>>2]|0;HEAP32[$63>>2] = (($64-1)|0);
       $65 = ($64|0)==(1);
       if ($65) {
        __THREW__ = 0;
        invoke_viii(3262,($62|0),1,1);
        $66 = __THREW__; __THREW__ = 0;
        $67 = $66&1;
        if ($67) {
         break;
        }
       }
      }
      __ZdlPv($$023$i$i);
      $68 = ($55|0)==($5|0);
      if ($68) {
       break L22;
      } else {
       $$023$i$i = $55;
      }
     }
     $69 = ___cxa_find_matching_catch_2()|0;
     $70 = tempRet0;
     ___cxa_call_unexpected(($69|0));
     // unreachable;
    }
   }
  } while(0);
  $71 = HEAP32[$4>>2]|0;
  $72 = ($71|0)==(0|0);
  if (!($72)) {
   $73 = HEAP32[$71>>2]|0;
   $74 = ((($73)) + -12|0);
   $75 = HEAP32[$74>>2]|0;
   $76 = (($71) + ($75)|0);
   $77 = ((($76)) + 8|0);
   $78 = HEAP32[$77>>2]|0;HEAP32[$77>>2] = (($78-1)|0);
   $79 = ($78|0)==(1);
   if ($79) {
    __THREW__ = 0;
    invoke_viii(3262,($76|0),1,1);
    $80 = __THREW__; __THREW__ = 0;
    $81 = $80&1;
    if ($81) {
     $86 = ___cxa_find_matching_catch_3(0|0)|0;
     $87 = tempRet0;
     ___clang_call_terminate($86);
     // unreachable;
    }
   }
  }
  HEAP32[$4>>2] = 0;
  __THREW__ = 0;
  invoke_vi(707,($1|0));
  $82 = __THREW__; __THREW__ = 0;
  $83 = $82&1;
  if ($83) {
   $86 = ___cxa_find_matching_catch_3(0|0)|0;
   $87 = tempRet0;
   ___clang_call_terminate($86);
   // unreachable;
  } else {
   $$3 = $$0;$$36 = $$03;
  }
 }
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $84 = __THREW__; __THREW__ = 0;
 $85 = $84&1;
 if ($85) {
  $86 = ___cxa_find_matching_catch_3(0|0)|0;
  $87 = tempRet0;
  ___clang_call_terminate($86);
  // unreachable;
 } else {
  ___resumeException($$3|0);
  // unreachable;
 }
}
function __ZN3osg14OperationQueue3addEPNS_9OperationE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$1 = 0, $$14 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
 do {
  if ($3) {
   $4 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
   $5 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($4,145946,9)|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ((($6)) + -12|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($5) + ($8)|0);
   __ZNKSt3__28ios_base6getlocEv($2,$9);
   __THREW__ = 0;
   $10 = (invoke_iii(3255,($2|0),(215188|0))|0);
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if (!($12)) {
    $13 = HEAP32[$10>>2]|0;
    $14 = ((($13)) + 28|0);
    $15 = HEAP32[$14>>2]|0;
    __THREW__ = 0;
    $16 = (invoke_iii($15|0,($10|0),10)|0);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if (!($18)) {
     __ZNSt3__26localeD2Ev($2);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($5,$16)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($5)|0);
     break;
    }
   }
   $19 = ___cxa_find_matching_catch_2()|0;
   $20 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($2|0));
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if ($22) {
    $23 = ___cxa_find_matching_catch_3(0|0)|0;
    $24 = tempRet0;
    ___clang_call_terminate($23);
    // unreachable;
   } else {
    ___resumeException($19|0);
    // unreachable;
   }
  }
 } while(0);
 $25 = ((($0)) + 12|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ((($26)) + 8|0);
 $28 = HEAP32[$27>>2]|0;
 (FUNCTION_TABLE_ii[$28 & 8191]($25)|0);
 $29 = ($1|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$1>>2]|0;
  $31 = ((($30)) + -12|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = (($1) + ($32)|0);
  $34 = ((($33)) + 8|0);
  $35 = HEAP32[$34>>2]|0;HEAP32[$34>>2] = (($35+1)|0);
 }
 $36 = ((($0)) + 28|0);
 __THREW__ = 0;
 $37 = (invoke_ii(3276,12)|0);
 $38 = __THREW__; __THREW__ = 0;
 $39 = $38&1;
 do {
  if ($39) {
   $97 = ___cxa_find_matching_catch_2()|0;
   $98 = tempRet0;
   if ($29) {
    $$1 = $98;$$14 = $97;
   } else {
    $99 = HEAP32[$1>>2]|0;
    $100 = ((($99)) + -12|0);
    $101 = HEAP32[$100>>2]|0;
    $102 = (($1) + ($101)|0);
    $103 = ((($102)) + 8|0);
    $104 = HEAP32[$103>>2]|0;HEAP32[$103>>2] = (($104-1)|0);
    $105 = ($104|0)==(1);
    if ($105) {
     __THREW__ = 0;
     invoke_viii(3262,($102|0),1,1);
     $106 = __THREW__; __THREW__ = 0;
     $107 = $106&1;
     if ($107) {
      $115 = ___cxa_find_matching_catch_3(0|0)|0;
      $116 = tempRet0;
      ___clang_call_terminate($115);
      // unreachable;
     } else {
      $$1 = $98;$$14 = $97;
     }
    } else {
     $$1 = $98;$$14 = $97;
    }
   }
  } else {
   $40 = ((($37)) + 8|0);
   HEAP32[$40>>2] = $1;
   if (!($29)) {
    $41 = HEAP32[$1>>2]|0;
    $42 = ((($41)) + -12|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = (($1) + ($43)|0);
    $45 = ((($44)) + 8|0);
    $46 = HEAP32[$45>>2]|0;HEAP32[$45>>2] = (($46+1)|0);
   }
   $47 = ((($37)) + 4|0);
   HEAP32[$47>>2] = $36;
   $48 = HEAP32[$36>>2]|0;
   HEAP32[$37>>2] = $48;
   $49 = ((($48)) + 4|0);
   HEAP32[$49>>2] = $37;
   HEAP32[$36>>2] = $37;
   $50 = ((($0)) + 36|0);
   $51 = HEAP32[$50>>2]|0;
   $52 = (($51) + 1)|0;
   HEAP32[$50>>2] = $52;
   if (!($29)) {
    $53 = HEAP32[$1>>2]|0;
    $54 = ((($53)) + -12|0);
    $55 = HEAP32[$54>>2]|0;
    $56 = (($1) + ($55)|0);
    $57 = ((($56)) + 8|0);
    $58 = HEAP32[$57>>2]|0;HEAP32[$57>>2] = (($58-1)|0);
    $59 = ($58|0)==(1);
    if ($59) {
     __THREW__ = 0;
     invoke_viii(3262,($56|0),1,1);
     $60 = __THREW__; __THREW__ = 0;
     $61 = $60&1;
     if ($61) {
      $95 = ___cxa_find_matching_catch_2()|0;
      $96 = tempRet0;
      $$1 = $96;$$14 = $95;
      break;
     }
    }
   }
   $62 = ((($0)) + 24|0);
   $63 = HEAP32[$62>>2]|0;
   $64 = ((($63)) + 4|0);
   $65 = ((($63)) + 24|0);
   $66 = HEAP8[$65>>0]|0;
   $67 = ($66<<24>>24)==(1);
   if ($67) {
    $92 = HEAP32[$25>>2]|0;
    $93 = ((($92)) + 12|0);
    $94 = HEAP32[$93>>2]|0;
    (FUNCTION_TABLE_ii[$94 & 8191]($25)|0);
    STACKTOP = sp;return;
   }
   $68 = HEAP32[$64>>2]|0;
   $69 = ((($68)) + 8|0);
   $70 = HEAP32[$69>>2]|0;
   __THREW__ = 0;
   (invoke_ii($70|0,($64|0))|0);
   $71 = __THREW__; __THREW__ = 0;
   $72 = $71&1;
   do {
    if ($72) {
     label = 28;
    } else {
     $73 = HEAP8[$65>>0]|0;
     $74 = ($73<<24>>24)==(0);
     if ($74) {
      HEAP8[$65>>0] = 1;
      $75 = ((($63)) + 16|0);
      __THREW__ = 0;
      (invoke_ii(2504,($75|0))|0);
      $76 = __THREW__; __THREW__ = 0;
      $77 = $76&1;
      if ($77) {
       $78 = ___cxa_find_matching_catch_2()|0;
       $79 = tempRet0;
       $80 = HEAP32[$64>>2]|0;
       $81 = ((($80)) + 12|0);
       $82 = HEAP32[$81>>2]|0;
       __THREW__ = 0;
       (invoke_ii($82|0,($64|0))|0);
       $83 = __THREW__; __THREW__ = 0;
       $84 = $83&1;
       if (!($84)) {
        $eh$lpad$body$index2Z2D = $79;$eh$lpad$body$indexZ2D = $78;
        break;
       }
       $85 = ___cxa_find_matching_catch_3(0|0)|0;
       $86 = tempRet0;
       ___clang_call_terminate($85);
       // unreachable;
      }
     }
     $87 = HEAP32[$64>>2]|0;
     $88 = ((($87)) + 12|0);
     $89 = HEAP32[$88>>2]|0;
     __THREW__ = 0;
     (invoke_ii($89|0,($64|0))|0);
     $90 = __THREW__; __THREW__ = 0;
     $91 = $90&1;
     if ($91) {
      label = 28;
     } else {
      $92 = HEAP32[$25>>2]|0;
      $93 = ((($92)) + 12|0);
      $94 = HEAP32[$93>>2]|0;
      (FUNCTION_TABLE_ii[$94 & 8191]($25)|0);
      STACKTOP = sp;return;
     }
    }
   } while(0);
   if ((label|0) == 28) {
    $108 = ___cxa_find_matching_catch_2()|0;
    $109 = tempRet0;
    $eh$lpad$body$index2Z2D = $109;$eh$lpad$body$indexZ2D = $108;
   }
   $$1 = $eh$lpad$body$index2Z2D;$$14 = $eh$lpad$body$indexZ2D;
  }
 } while(0);
 $110 = HEAP32[$25>>2]|0;
 $111 = ((($110)) + 12|0);
 $112 = HEAP32[$111>>2]|0;
 __THREW__ = 0;
 (invoke_ii($112|0,($25|0))|0);
 $113 = __THREW__; __THREW__ = 0;
 $114 = $113&1;
 if ($114) {
  $115 = ___cxa_find_matching_catch_3(0|0)|0;
  $116 = tempRet0;
  ___clang_call_terminate($115);
  // unreachable;
 } else {
  ___resumeException($$14|0);
  // unreachable;
 }
}
function __ZN3osg14OperationQueue13runOperationsEPNS_6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$2 = 0, $$29 = 0, $$cast$i = 0, $$pre = 0, $$sroa$0$0$$sroa_idx = 0, $$sroa$03$0$$sroa_idx = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 (FUNCTION_TABLE_ii[$5 & 8191]($2)|0);
 $6 = ((($0)) + 40|0);
 $7 = ((($0)) + 28|0);
 $8 = HEAP32[$6>>2]|0;
 $9 = ($8|0)==($7|0);
 if ($9) {
  $10 = ((($0)) + 32|0);
  $11 = HEAP32[$10>>2]|0;
  $$sroa$03$0$$sroa_idx = ((($0)) + 40|0);
  HEAP32[$$sroa$03$0$$sroa_idx>>2] = $11;
  $12 = $11;
  $13 = $11;
  $109 = $13;$14 = $12;
 } else {
  $109 = $8;$14 = $8;
 }
 $15 = ($14|0)==($7|0);
 $$pre = ((($0)) + 36|0);
 L4: do {
  if ($15) {
   label = 21;
  } else {
   $$sroa$0$0$$sroa_idx = ((($0)) + 40|0);
   $17 = $109;
   while(1) {
    $16 = ((($17)) + 8|0);
    $18 = HEAP32[$16>>2]|0;
    $19 = ($18|0)==(0|0);
    if (!($19)) {
     $20 = HEAP32[$18>>2]|0;
     $21 = ((($20)) + -12|0);
     $22 = HEAP32[$21>>2]|0;
     $23 = (($18) + ($22)|0);
     $24 = ((($23)) + 8|0);
     $25 = HEAP32[$24>>2]|0;HEAP32[$24>>2] = (($25+1)|0);
    }
    $26 = ((($18)) + 16|0);
    $27 = HEAP8[$26>>0]|0;
    $28 = ($27<<24>>24)==(0);
    $29 = HEAP32[$6>>2]|0;
    $30 = ((($29)) + 4|0);
    if ($28) {
     $31 = HEAP32[$30>>2]|0;
     $$cast$i = $31;
     $32 = HEAP32[$29>>2]|0;
     $33 = ((($32)) + 4|0);
     HEAP32[$33>>2] = $$cast$i;
     $34 = HEAP32[$30>>2]|0;
     HEAP32[$34>>2] = $32;
     $35 = HEAP32[$$pre>>2]|0;
     $36 = (($35) + -1)|0;
     HEAP32[$$pre>>2] = $36;
     $37 = ((($29)) + 8|0);
     $38 = HEAP32[$37>>2]|0;
     $39 = ($38|0)==(0|0);
     if (!($39)) {
      $40 = HEAP32[$38>>2]|0;
      $41 = ((($40)) + -12|0);
      $42 = HEAP32[$41>>2]|0;
      $43 = (($38) + ($42)|0);
      $44 = ((($43)) + 8|0);
      $45 = HEAP32[$44>>2]|0;HEAP32[$44>>2] = (($45-1)|0);
      $46 = ($45|0)==(1);
      if ($46) {
       __THREW__ = 0;
       invoke_viii(3262,($43|0),1,1);
       $47 = __THREW__; __THREW__ = 0;
       $48 = $47&1;
       if ($48) {
        break;
       }
      }
     }
     __ZdlPv($29);
     HEAP32[$$sroa$0$0$$sroa_idx>>2] = $31;
    } else {
     $51 = HEAP32[$30>>2]|0;
     HEAP32[$6>>2] = $51;
    }
    $52 = HEAP32[$18>>2]|0;
    $53 = ((($52)) + 4|0);
    $54 = HEAP32[$53>>2]|0;
    __THREW__ = 0;
    invoke_vii($54|0,($18|0),($1|0));
    $55 = __THREW__; __THREW__ = 0;
    $56 = $55&1;
    if ($56) {
     break;
    }
    $57 = HEAP32[$18>>2]|0;
    $58 = ((($57)) + -12|0);
    $59 = HEAP32[$58>>2]|0;
    $60 = (($18) + ($59)|0);
    $61 = ((($60)) + 8|0);
    $62 = HEAP32[$61>>2]|0;HEAP32[$61>>2] = (($62-1)|0);
    $63 = ($62|0)==(1);
    if ($63) {
     __THREW__ = 0;
     invoke_viii(3262,($60|0),1,1);
     $66 = __THREW__; __THREW__ = 0;
     $67 = $66&1;
     if ($67) {
      label = 18;
      break;
     }
    }
    $64 = HEAP32[$6>>2]|0;
    $65 = ($64|0)==($7|0);
    if ($65) {
     label = 21;
     break L4;
    } else {
     $17 = $64;
    }
   }
   if ((label|0) == 18) {
    $68 = ___cxa_find_matching_catch_2()|0;
    $69 = tempRet0;
    $$2 = $68;$$29 = $69;
    break;
   }
   $70 = ___cxa_find_matching_catch_2()|0;
   $71 = tempRet0;
   $72 = HEAP32[$18>>2]|0;
   $73 = ((($72)) + -12|0);
   $74 = HEAP32[$73>>2]|0;
   $75 = (($18) + ($74)|0);
   $76 = ((($75)) + 8|0);
   $77 = HEAP32[$76>>2]|0;HEAP32[$76>>2] = (($77-1)|0);
   $78 = ($77|0)==(1);
   if ($78) {
    __THREW__ = 0;
    invoke_viii(3262,($75|0),1,1);
    $79 = __THREW__; __THREW__ = 0;
    $80 = $79&1;
    if ($80) {
     $107 = ___cxa_find_matching_catch_3(0|0)|0;
     $108 = tempRet0;
     ___clang_call_terminate($107);
     // unreachable;
    } else {
     $$2 = $70;$$29 = $71;
    }
   } else {
    $$2 = $70;$$29 = $71;
   }
  }
 } while(0);
 if ((label|0) == 21) {
  $81 = HEAP32[$$pre>>2]|0;
  $82 = ($81|0)==(0);
  if (!($82)) {
   $99 = HEAP32[$2>>2]|0;
   $100 = ((($99)) + 12|0);
   $101 = HEAP32[$100>>2]|0;
   (FUNCTION_TABLE_ii[$101 & 8191]($2)|0);
   return;
  }
  $83 = ((($0)) + 24|0);
  $84 = HEAP32[$83>>2]|0;
  $85 = ((($84)) + 4|0);
  $86 = ((($84)) + 24|0);
  $87 = HEAP8[$86>>0]|0;
  $88 = ($87<<24>>24)==(0);
  if ($88) {
   $99 = HEAP32[$2>>2]|0;
   $100 = ((($99)) + 12|0);
   $101 = HEAP32[$100>>2]|0;
   (FUNCTION_TABLE_ii[$101 & 8191]($2)|0);
   return;
  }
  $89 = HEAP32[$85>>2]|0;
  $90 = ((($89)) + 8|0);
  $91 = HEAP32[$90>>2]|0;
  __THREW__ = 0;
  (invoke_ii($91|0,($85|0))|0);
  $92 = __THREW__; __THREW__ = 0;
  $93 = $92&1;
  if (!($93)) {
   HEAP8[$86>>0] = 0;
   $94 = HEAP32[$85>>2]|0;
   $95 = ((($94)) + 12|0);
   $96 = HEAP32[$95>>2]|0;
   __THREW__ = 0;
   (invoke_ii($96|0,($85|0))|0);
   $97 = __THREW__; __THREW__ = 0;
   $98 = $97&1;
   if (!($98)) {
    $99 = HEAP32[$2>>2]|0;
    $100 = ((($99)) + 12|0);
    $101 = HEAP32[$100>>2]|0;
    (FUNCTION_TABLE_ii[$101 & 8191]($2)|0);
    return;
   }
  }
  $49 = ___cxa_find_matching_catch_2()|0;
  $50 = tempRet0;
  $$2 = $49;$$29 = $50;
 }
 $102 = HEAP32[$2>>2]|0;
 $103 = ((($102)) + 12|0);
 $104 = HEAP32[$103>>2]|0;
 __THREW__ = 0;
 (invoke_ii($104|0,($2|0))|0);
 $105 = __THREW__; __THREW__ = 0;
 $106 = $105&1;
 if ($106) {
  $107 = ___cxa_find_matching_catch_3(0|0)|0;
  $108 = tempRet0;
  ___clang_call_terminate($107);
  // unreachable;
 } else {
  ___resumeException($$2|0);
  // unreachable;
 }
}
function __ZN3osg14OperationQueue20releaseAllOperationsEv($0) {
 $0 = $0|0;
 var $$sroa$03$0 = 0, $$sroa$03$013 = 0, $$sroa$03$014 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 (FUNCTION_TABLE_ii[$4 & 8191]($1)|0);
 $5 = ((($0)) + 32|0);
 $$sroa$03$013 = HEAP32[$5>>2]|0;
 $6 = ((($0)) + 28|0);
 $7 = $$sroa$03$013;
 $8 = ($7|0)==($6|0);
 if ($8) {
  $9 = HEAP32[$1>>2]|0;
  $10 = ((($9)) + 12|0);
  $11 = HEAP32[$10>>2]|0;
  (FUNCTION_TABLE_ii[$11 & 8191]($1)|0);
  return;
 } else {
  $$sroa$03$014 = $$sroa$03$013;$20 = $7;
 }
 while(1) {
  $12 = $$sroa$03$014;
  $13 = ((($12)) + 8|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = HEAP32[$14>>2]|0;
  $16 = HEAP32[$15>>2]|0;
  __THREW__ = 0;
  invoke_vi($16|0,($14|0));
  $17 = __THREW__; __THREW__ = 0;
  $18 = $17&1;
  if ($18) {
   break;
  }
  $19 = ((($20)) + 4|0);
  $$sroa$03$0 = HEAP32[$19>>2]|0;
  $21 = $$sroa$03$0;
  $22 = ($21|0)==($6|0);
  if ($22) {
   label = 2;
   break;
  } else {
   $$sroa$03$014 = $$sroa$03$0;$20 = $21;
  }
 }
 if ((label|0) == 2) {
  $9 = HEAP32[$1>>2]|0;
  $10 = ((($9)) + 12|0);
  $11 = HEAP32[$10>>2]|0;
  (FUNCTION_TABLE_ii[$11 & 8191]($1)|0);
  return;
 }
 $23 = ___cxa_find_matching_catch_2()|0;
 $24 = tempRet0;
 $25 = HEAP32[$1>>2]|0;
 $26 = ((($25)) + 12|0);
 $27 = HEAP32[$26>>2]|0;
 __THREW__ = 0;
 (invoke_ii($27|0,($1|0))|0);
 $28 = __THREW__; __THREW__ = 0;
 $29 = $28&1;
 if ($29) {
  $30 = ___cxa_find_matching_catch_3(0|0)|0;
  $31 = tempRet0;
  ___clang_call_terminate($30);
  // unreachable;
 } else {
  ___resumeException($23|0);
  // unreachable;
 }
}
function __ZN3osg15OperationThreadC2Ev($0) {
 $0 = $0|0;
 var $$0 = 0, $$02 = 0, $$1 = 0, $$13 = 0, $$3 = 0, $$35 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg10ReferencedC2Eb($0,1);
 $1 = ((($0)) + 12|0);
 __THREW__ = 0;
 invoke_vi(3843,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if ($3) {
   $19 = ___cxa_find_matching_catch_2()|0;
   $20 = tempRet0;
   $$3 = $20;$$35 = $19;
   label = 22;
  } else {
   HEAP32[$0>>2] = (63620);
   HEAP32[$1>>2] = (63648);
   $4 = ((($0)) + 20|0);
   HEAP32[$4>>2] = 0;
   $5 = ((($0)) + 24|0);
   HEAP32[$5>>2] = 0;
   $6 = ((($0)) + 28|0);
   HEAP32[$6>>2] = 0;
   $7 = ((($0)) + 32|0);
   __THREW__ = 0;
   invoke_vii(3507,($7|0),0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if ($9) {
    $21 = ___cxa_find_matching_catch_2()|0;
    $22 = tempRet0;
    $$1 = $22;$$13 = $21;
   } else {
    $10 = ((($0)) + 44|0);
    HEAP32[$10>>2] = 0;
    $11 = ((($0)) + 48|0);
    HEAP32[$11>>2] = 0;
    __THREW__ = 0;
    $12 = (invoke_ii(3276,56)|0);
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    do {
     if ($14) {
      label = 9;
     } else {
      __THREW__ = 0;
      invoke_vi(3844,($12|0));
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if ($16) {
       $25 = ___cxa_find_matching_catch_2()|0;
       $26 = tempRet0;
       __ZdlPv($12);
       $$0 = $26;$$02 = $25;
       break;
      }
      __THREW__ = 0;
      invoke_vii(3845,($0|0),($12|0));
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if ($18) {
       label = 9;
      } else {
       return;
      }
     }
    } while(0);
    if ((label|0) == 9) {
     $23 = ___cxa_find_matching_catch_2()|0;
     $24 = tempRet0;
     $$0 = $24;$$02 = $23;
    }
    $27 = HEAP32[$11>>2]|0;
    $28 = ($27|0)==(0|0);
    if (!($28)) {
     $29 = HEAP32[$27>>2]|0;
     $30 = ((($29)) + -12|0);
     $31 = HEAP32[$30>>2]|0;
     $32 = (($27) + ($31)|0);
     $33 = ((($32)) + 8|0);
     $34 = HEAP32[$33>>2]|0;HEAP32[$33>>2] = (($34-1)|0);
     $35 = ($34|0)==(1);
     if ($35) {
      __THREW__ = 0;
      invoke_viii(3262,($32|0),1,1);
      $36 = __THREW__; __THREW__ = 0;
      $37 = $36&1;
      if ($37) {
       break;
      }
     }
    }
    HEAP32[$11>>2] = 0;
    $38 = HEAP32[$10>>2]|0;
    $39 = ($38|0)==(0|0);
    if (!($39)) {
     $40 = ((($38)) + 8|0);
     $41 = HEAP32[$40>>2]|0;HEAP32[$40>>2] = (($41-1)|0);
     $42 = ($41|0)==(1);
     if ($42) {
      __THREW__ = 0;
      invoke_viii(3262,($38|0),1,1);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       break;
      }
     }
    }
    HEAP32[$10>>2] = 0;
    __THREW__ = 0;
    invoke_vi(707,($7|0));
    $45 = __THREW__; __THREW__ = 0;
    $46 = $45&1;
    if ($46) {
     break;
    } else {
     $$1 = $$0;$$13 = $$02;
    }
   }
   $47 = HEAP32[$4>>2]|0;
   $48 = ($47|0)==(0|0);
   if (!($48)) {
    $49 = ((($47)) + 8|0);
    $50 = HEAP32[$49>>2]|0;HEAP32[$49>>2] = (($50-1)|0);
    $51 = ($50|0)==(1);
    if ($51) {
     __THREW__ = 0;
     invoke_viii(3262,($47|0),1,1);
     $52 = __THREW__; __THREW__ = 0;
     $53 = $52&1;
     if ($53) {
      break;
     }
    }
   }
   HEAP32[$4>>2] = 0;
   __THREW__ = 0;
   invoke_vi(2489,($1|0));
   $54 = __THREW__; __THREW__ = 0;
   $55 = $54&1;
   if (!($55)) {
    $$3 = $$1;$$35 = $$13;
    label = 22;
   }
  }
 } while(0);
 if ((label|0) == 22) {
  __THREW__ = 0;
  invoke_vi(712,($0|0));
  $56 = __THREW__; __THREW__ = 0;
  $57 = $56&1;
  if (!($57)) {
   ___resumeException($$35|0);
   // unreachable;
  }
 }
 $58 = ___cxa_find_matching_catch_3(0|0)|0;
 $59 = tempRet0;
 ___clang_call_terminate($58);
 // unreachable;
}
function __ZN3osg15OperationThread17setOperationQueueEPNS_14OperationQueueE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i$i = 0, $$0$i$i$i$i$i$i$i = 0, $$0$ph$i$i$i$i$i = 0, $$0$ph$lcssa$i$i$i$i$i = 0, $$0$ph13$i$i$i$i$i = 0, $$024$i$i$i$i$i = 0, $$025$i$i$i$i$i = 0, $$036$i$i$i$i = 0, $$07$ph12$i$i$i$i$i = 0, $$0710$i$i$i$i$i = 0, $$in$i$i$i$i$i = 0, $$pr = 0, $$pre = 0, $$pre$i$i$i$i$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0;
 var $104 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 32|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 (FUNCTION_TABLE_ii[$5 & 8191]($2)|0);
 $6 = ((($0)) + 44|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==($1|0);
 if ($8) {
  $100 = HEAP32[$2>>2]|0;
  $101 = ((($100)) + 12|0);
  $102 = HEAP32[$101>>2]|0;
  (FUNCTION_TABLE_ii[$102 & 8191]($2)|0);
  return;
 }
 $16 = ($7|0)==(0|0);
 if ($16) {
  $54 = 0;
 } else {
  $17 = ((($7)) + 44|0);
  $18 = ((($7)) + 48|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = ($19|0)==(0|0);
  if ($20) {
   $54 = $7;
  } else {
   $$0$ph13$i$i$i$i$i = $18;$$07$ph12$i$i$i$i$i = $19;
   L6: while(1) {
    $$0710$i$i$i$i$i = $$07$ph12$i$i$i$i$i;
    while(1) {
     $21 = ((($$0710$i$i$i$i$i)) + 16|0);
     $22 = HEAP32[$21>>2]|0;
     $23 = ($22>>>0)<($0>>>0);
     if (!($23)) {
      break;
     }
     $26 = ((($$0710$i$i$i$i$i)) + 4|0);
     $27 = HEAP32[$26>>2]|0;
     $28 = ($27|0)==(0|0);
     if ($28) {
      $$0$ph$lcssa$i$i$i$i$i = $$0$ph13$i$i$i$i$i;
      break L6;
     } else {
      $$0710$i$i$i$i$i = $27;
     }
    }
    $24 = HEAP32[$$0710$i$i$i$i$i>>2]|0;
    $25 = ($24|0)==(0|0);
    if ($25) {
     $$0$ph$lcssa$i$i$i$i$i = $$0710$i$i$i$i$i;
     break;
    } else {
     $$0$ph13$i$i$i$i$i = $$0710$i$i$i$i$i;$$07$ph12$i$i$i$i$i = $24;
    }
   }
   $29 = ($$0$ph$lcssa$i$i$i$i$i|0)==($18|0);
   if ($29) {
    $54 = $7;
   } else {
    $30 = ((($$0$ph$lcssa$i$i$i$i$i)) + 16|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = ($31>>>0)>($0>>>0);
    if ($32) {
     $54 = $7;
    } else {
     $33 = ((($$0$ph$lcssa$i$i$i$i$i)) + 4|0);
     $34 = HEAP32[$33>>2]|0;
     $35 = ($34|0)==(0|0);
     if ($35) {
      $36 = ((($$0$ph$lcssa$i$i$i$i$i)) + 8|0);
      $37 = HEAP32[$36>>2]|0;
      $38 = HEAP32[$37>>2]|0;
      $39 = ($38|0)==($$0$ph$lcssa$i$i$i$i$i|0);
      if ($39) {
       $$0$i$i$i$i$i$i = $37;
      } else {
       $43 = $36;
       while(1) {
        $42 = HEAP32[$43>>2]|0;
        $44 = ((($42)) + 8|0);
        $45 = HEAP32[$44>>2]|0;
        $46 = HEAP32[$45>>2]|0;
        $47 = ($46|0)==($42|0);
        if ($47) {
         $$0$i$i$i$i$i$i = $45;
         break;
        } else {
         $43 = $44;
        }
       }
      }
     } else {
      $$0$i$i$i$i$i$i$i = $34;
      while(1) {
       $40 = HEAP32[$$0$i$i$i$i$i$i$i>>2]|0;
       $41 = ($40|0)==(0|0);
       if ($41) {
        break;
       } else {
        $$0$i$i$i$i$i$i$i = $40;
       }
      }
      $$0$i$i$i$i$i$i = $$0$i$i$i$i$i$i$i;
     }
     $48 = HEAP32[$17>>2]|0;
     $49 = ($48|0)==($$0$ph$lcssa$i$i$i$i$i|0);
     if ($49) {
      $50 = $$0$i$i$i$i$i$i;
      HEAP32[$17>>2] = $50;
     }
     $51 = ((($7)) + 52|0);
     $52 = HEAP32[$51>>2]|0;
     $53 = (($52) + -1)|0;
     HEAP32[$51>>2] = $53;
     __ZNSt3__213__tree_removeIPNS_16__tree_node_baseIPvEEEEvT_S5_($19,$$0$ph$lcssa$i$i$i$i$i);
     __ZdlPv($$0$ph$lcssa$i$i$i$i$i);
     $$pre = HEAP32[$6>>2]|0;
     $54 = $$pre;
    }
   }
  }
 }
 $55 = ($54|0)==($1|0);
 do {
  if ($55) {
   $65 = $1;
   label = 26;
  } else {
   HEAP32[$6>>2] = $1;
   $56 = ($1|0)==(0|0);
   if (!($56)) {
    $57 = ((($1)) + 8|0);
    $58 = HEAP32[$57>>2]|0;HEAP32[$57>>2] = (($58+1)|0);
   }
   $59 = ($54|0)==(0|0);
   if (!($59)) {
    $60 = ((($54)) + 8|0);
    $61 = HEAP32[$60>>2]|0;HEAP32[$60>>2] = (($61-1)|0);
    $62 = ($61|0)==(1);
    if ($62) {
     __THREW__ = 0;
     invoke_viii(3262,($54|0),1,1);
     $63 = __THREW__; __THREW__ = 0;
     $64 = $63&1;
     if ($64) {
      break;
     }
    }
   }
   $$pr = HEAP32[$6>>2]|0;
   $65 = $$pr;
   label = 26;
  }
 } while(0);
 if ((label|0) == 26) {
  $66 = ($65|0)==(0|0);
  if ($66) {
   $100 = HEAP32[$2>>2]|0;
   $101 = ((($100)) + 12|0);
   $102 = HEAP32[$101>>2]|0;
   (FUNCTION_TABLE_ii[$102 & 8191]($2)|0);
   return;
  }
  $67 = $0;
  $68 = ((($65)) + 44|0);
  $69 = ((($65)) + 48|0);
  $70 = HEAP32[$69>>2]|0;
  $71 = ($70|0)==(0|0);
  do {
   if ($71) {
    $$025$i$i$i$i$i = $69;$$036$i$i$i$i = $69;
   } else {
    $72 = ((($65)) + 48|0);
    $$0$i$i$i$i$i = $72;$$024$i$i$i$i$i = $70;
    while(1) {
     $73 = ((($$024$i$i$i$i$i)) + 16|0);
     $74 = HEAP32[$73>>2]|0;
     $75 = ($74>>>0)>($0>>>0);
     if ($75) {
      $76 = HEAP32[$$024$i$i$i$i$i>>2]|0;
      $77 = ($76|0)==(0|0);
      if ($77) {
       label = 32;
       break;
      } else {
       $$0$ph$i$i$i$i$i = $$024$i$i$i$i$i;$$in$i$i$i$i$i = $76;
      }
     } else {
      $78 = ($74>>>0)<($0>>>0);
      if (!($78)) {
       label = 36;
       break;
      }
      $79 = ((($$024$i$i$i$i$i)) + 4|0);
      $80 = HEAP32[$79>>2]|0;
      $81 = ($80|0)==(0|0);
      if ($81) {
       label = 35;
       break;
      } else {
       $$0$ph$i$i$i$i$i = $79;$$in$i$i$i$i$i = $80;
      }
     }
     $$0$i$i$i$i$i = $$0$ph$i$i$i$i$i;$$024$i$i$i$i$i = $$in$i$i$i$i$i;
    }
    if ((label|0) == 32) {
     $$025$i$i$i$i$i = $$024$i$i$i$i$i;$$036$i$i$i$i = $$024$i$i$i$i$i;
     break;
    }
    else if ((label|0) == 35) {
     $$025$i$i$i$i$i = $79;$$036$i$i$i$i = $$024$i$i$i$i$i;
     break;
    }
    else if ((label|0) == 36) {
     $$025$i$i$i$i$i = $$0$i$i$i$i$i;$$036$i$i$i$i = $$024$i$i$i$i$i;
     break;
    }
   }
  } while(0);
  $82 = HEAP32[$$025$i$i$i$i$i>>2]|0;
  $83 = ($82|0)==(0|0);
  if (!($83)) {
   $100 = HEAP32[$2>>2]|0;
   $101 = ((($100)) + 12|0);
   $102 = HEAP32[$101>>2]|0;
   (FUNCTION_TABLE_ii[$102 & 8191]($2)|0);
   return;
  }
  __THREW__ = 0;
  $84 = (invoke_ii(3276,20)|0);
  $85 = __THREW__; __THREW__ = 0;
  $86 = $85&1;
  if (!($86)) {
   $87 = ((($84)) + 16|0);
   HEAP32[$87>>2] = $67;
   HEAP32[$84>>2] = 0;
   $88 = ((($84)) + 4|0);
   HEAP32[$88>>2] = 0;
   $89 = ((($84)) + 8|0);
   HEAP32[$89>>2] = $$036$i$i$i$i;
   HEAP32[$$025$i$i$i$i$i>>2] = $84;
   $90 = HEAP32[$68>>2]|0;
   $91 = HEAP32[$90>>2]|0;
   $92 = ($91|0)==(0|0);
   if ($92) {
    $96 = $84;
   } else {
    $93 = $91;
    HEAP32[$68>>2] = $93;
    $$pre$i$i$i$i$i = HEAP32[$$025$i$i$i$i$i>>2]|0;
    $96 = $$pre$i$i$i$i$i;
   }
   $94 = ((($65)) + 48|0);
   $95 = HEAP32[$94>>2]|0;
   __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($95,$96);
   $97 = ((($65)) + 52|0);
   $98 = HEAP32[$97>>2]|0;
   $99 = (($98) + 1)|0;
   HEAP32[$97>>2] = $99;
   $100 = HEAP32[$2>>2]|0;
   $101 = ((($100)) + 12|0);
   $102 = HEAP32[$101>>2]|0;
   (FUNCTION_TABLE_ii[$102 & 8191]($2)|0);
   return;
  }
 }
 $9 = ___cxa_find_matching_catch_2()|0;
 $10 = tempRet0;
 $11 = HEAP32[$2>>2]|0;
 $12 = ((($11)) + 12|0);
 $13 = HEAP32[$12>>2]|0;
 __THREW__ = 0;
 (invoke_ii($13|0,($2|0))|0);
 $14 = __THREW__; __THREW__ = 0;
 $15 = $14&1;
 if ($15) {
  $103 = ___cxa_find_matching_catch_3(0|0)|0;
  $104 = tempRet0;
  ___clang_call_terminate($103);
  // unreachable;
 } else {
  ___resumeException($9|0);
  // unreachable;
 }
}
function __ZN3osg15OperationThread3addEPNS_9OperationE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$03 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 32|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 (FUNCTION_TABLE_ii[$5 & 8191]($2)|0);
 $6 = ((($0)) + 44|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 do {
  if ($8) {
   __THREW__ = 0;
   $9 = (invoke_ii(3276,56)|0);
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if ($11) {
    label = 8;
   } else {
    __THREW__ = 0;
    invoke_vi(3844,($9|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     $26 = ___cxa_find_matching_catch_2()|0;
     $27 = tempRet0;
     __ZdlPv($9);
     $$0 = $27;$$03 = $26;
     break;
    }
    $14 = HEAP32[$6>>2]|0;
    $15 = ($14|0)==($9|0);
    if ($15) {
     label = 10;
    } else {
     HEAP32[$6>>2] = $9;
     $16 = ((($9)) + 8|0);
     $17 = HEAP32[$16>>2]|0;HEAP32[$16>>2] = (($17+1)|0);
     $18 = ($14|0)==(0|0);
     if ($18) {
      label = 10;
     } else {
      $19 = ((($14)) + 8|0);
      $20 = HEAP32[$19>>2]|0;HEAP32[$19>>2] = (($20-1)|0);
      $21 = ($20|0)==(1);
      if ($21) {
       __THREW__ = 0;
       invoke_viii(3262,($14|0),1,1);
       $22 = __THREW__; __THREW__ = 0;
       $23 = $22&1;
       if ($23) {
        label = 8;
       } else {
        label = 10;
       }
      } else {
       label = 10;
      }
     }
    }
   }
  } else {
   label = 10;
  }
 } while(0);
 if ((label|0) == 10) {
  $28 = HEAP32[$6>>2]|0;
  __THREW__ = 0;
  invoke_vii(3846,($28|0),($1|0));
  $29 = __THREW__; __THREW__ = 0;
  $30 = $29&1;
  if ($30) {
   label = 8;
  } else {
   $31 = HEAP32[$2>>2]|0;
   $32 = ((($31)) + 12|0);
   $33 = HEAP32[$32>>2]|0;
   (FUNCTION_TABLE_ii[$33 & 8191]($2)|0);
   return;
  }
 }
 if ((label|0) == 8) {
  $24 = ___cxa_find_matching_catch_2()|0;
  $25 = tempRet0;
  $$0 = $25;$$03 = $24;
 }
 $34 = HEAP32[$2>>2]|0;
 $35 = ((($34)) + 12|0);
 $36 = HEAP32[$35>>2]|0;
 __THREW__ = 0;
 (invoke_ii($36|0,($2|0))|0);
 $37 = __THREW__; __THREW__ = 0;
 $38 = $37&1;
 if ($38) {
  $39 = ___cxa_find_matching_catch_3(0|0)|0;
  $40 = tempRet0;
  ___clang_call_terminate($39);
  // unreachable;
 } else {
  ___resumeException($$03|0);
  // unreachable;
 }
}
function __ZNSt3__26vectorIN3osg8PagedLOD12PerRangeDataENS_9allocatorIS3_EEE6resizeEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 6;
 $7 = ($6>>>0)<($1>>>0);
 $8 = $4;
 $9 = $3;
 if ($7) {
  $10 = (($1) - ($6))|0;
  __ZNSt3__26vectorIN3osg8PagedLOD12PerRangeDataENS_9allocatorIS3_EEE8__appendEj($0,$10);
  return;
 }
 $11 = ($6>>>0)>($1>>>0);
 if (!($11)) {
  return;
 }
 $12 = (($8) + ($1<<6)|0);
 $13 = ($9|0)==($12|0);
 if ($13) {
  return;
 } else {
  $15 = $9;
 }
 while(1) {
  $14 = ((($15)) + -64|0);
  HEAP32[$2>>2] = $14;
  $16 = ((($15)) + -8|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = ($17|0)==(0|0);
  if (!($18)) {
   $19 = ((($17)) + 8|0);
   $20 = HEAP32[$19>>2]|0;HEAP32[$19>>2] = (($20-1)|0);
   $21 = ($20|0)==(1);
   if ($21) {
    __THREW__ = 0;
    invoke_viii(3262,($17|0),1,1);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
   }
  }
  HEAP32[$16>>2] = 0;
  $24 = ((($14)) + 11|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = ($25<<24>>24)<(0);
  if ($26) {
   $29 = HEAP32[$14>>2]|0;
   __ZdlPv($29);
  }
  $27 = HEAP32[$2>>2]|0;
  $28 = ($27|0)==($12|0);
  if ($28) {
   label = 14;
   break;
  } else {
   $15 = $27;
  }
 }
 if ((label|0) == 14) {
  return;
 }
 $30 = ___cxa_find_matching_catch_2()|0;
 $31 = tempRet0;
 $32 = ((($14)) + 11|0);
 $33 = HEAP8[$32>>0]|0;
 $34 = ($33<<24>>24)<(0);
 if (!($34)) {
  ___cxa_call_unexpected(($30|0));
  // unreachable;
 }
 $35 = HEAP32[$14>>2]|0;
 __ZdlPv($35);
 ___cxa_call_unexpected(($30|0));
 // unreachable;
}
function __ZNSt3__26vectorIN3osg8PagedLOD12PerRangeDataENS_9allocatorIS3_EEE8__appendEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i = 0, $$0$i11 = 0, $$06$i$i = 0, $$in = 0, $$pre = 0, $$pre$i9 = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $11 = 0, $12 = 0;
 var $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0.0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0.0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $scevgep = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $2 = sp;
 $3 = ((($0)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) - ($6))|0;
 $8 = $7 >> 6;
 $9 = ($8>>>0)<($1>>>0);
 if (!($9)) {
  $10 = $6;
  $$0$i = $1;$12 = $10;
  while(1) {
   $11 = ((($12)) + 16|0);
   ;HEAP32[$12>>2]=0|0;HEAP32[$12+4>>2]=0|0;HEAP32[$12+8>>2]=0|0;HEAP32[$12+12>>2]=0|0;
   HEAPF32[$11>>2] = 1.0;
   $13 = ((($12)) + 24|0);
   HEAPF64[$13>>3] = 0.0;
   $14 = ((($12)) + 32|0);
   HEAP32[$14>>2] = 0;
   $15 = ((($12)) + 40|0);
   ;HEAP32[$15>>2]=0|0;HEAP32[$15+4>>2]=0|0;HEAP32[$15+8>>2]=0|0;HEAP32[$15+12>>2]=0|0;HEAP32[$15+16>>2]=0|0;
   $16 = HEAP32[$5>>2]|0;
   $17 = ((($16)) + 64|0);
   HEAP32[$5>>2] = $17;
   $18 = (($$0$i) + -1)|0;
   $19 = ($18|0)==(0);
   if ($19) {
    break;
   } else {
    $$0$i = $18;$12 = $17;
   }
  }
  STACKTOP = sp;return;
 }
 $20 = HEAP32[$0>>2]|0;
 $21 = (($6) - ($20))|0;
 $22 = $21 >> 6;
 $23 = (($22) + ($1))|0;
 $24 = ($23>>>0)>(67108863);
 if ($24) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $25 = ((($0)) + 8|0);
 $26 = (($4) - ($20))|0;
 $27 = $26 >> 6;
 $28 = ($27>>>0)<(33554431);
 $29 = $26 >> 5;
 $30 = ($29>>>0)<($23>>>0);
 $$sroa$speculated$i = $30 ? $23 : $29;
 $$sroa$speculated$$i = $28 ? $$sroa$speculated$i : 67108863;
 $31 = ((($2)) + 12|0);
 HEAP32[$31>>2] = 0;
 $32 = ((($2)) + 16|0);
 HEAP32[$32>>2] = $25;
 $33 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($33) {
   $42 = 0;
  } else {
   $34 = ($$sroa$speculated$$i>>>0)>(67108863);
   if (!($34)) {
    $40 = $$sroa$speculated$$i << 6;
    $41 = (__Znwj($40)|0);
    $42 = $41;
    break;
   }
   $35 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($35|0),(204840|0));
   $36 = __THREW__; __THREW__ = 0;
   $37 = $36&1;
   if ($37) {
    $38 = ___cxa_find_matching_catch_2()|0;
    $39 = tempRet0;
    ___cxa_free_exception(($35|0));
    ___resumeException($38|0);
    // unreachable;
   } else {
    HEAP32[$35>>2] = (99824);
    ___cxa_throw(($35|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 HEAP32[$2>>2] = $42;
 $43 = (($42) + ($22<<6)|0);
 $44 = ((($2)) + 8|0);
 HEAP32[$44>>2] = $43;
 $45 = ((($2)) + 4|0);
 HEAP32[$45>>2] = $43;
 $46 = (($42) + ($$sroa$speculated$$i<<6)|0);
 $47 = ((($2)) + 12|0);
 HEAP32[$47>>2] = $46;
 $$0$i11 = $1;$49 = $43;
 while(1) {
  $48 = ((($49)) + 16|0);
  ;HEAP32[$49>>2]=0|0;HEAP32[$49+4>>2]=0|0;HEAP32[$49+8>>2]=0|0;HEAP32[$49+12>>2]=0|0;
  HEAPF32[$48>>2] = 1.0;
  $50 = ((($49)) + 24|0);
  HEAPF64[$50>>3] = 0.0;
  $51 = ((($49)) + 32|0);
  HEAP32[$51>>2] = 0;
  $52 = ((($49)) + 40|0);
  ;HEAP32[$52>>2]=0|0;HEAP32[$52+4>>2]=0|0;HEAP32[$52+8>>2]=0|0;HEAP32[$52+12>>2]=0|0;HEAP32[$52+16>>2]=0|0;
  $53 = ((($49)) + 64|0);
  $54 = (($$0$i11) + -1)|0;
  $55 = ($54|0)==(0);
  if ($55) {
   break;
  } else {
   $$0$i11 = $54;$49 = $53;
  }
 }
 $scevgep = (($42) + ($23<<6)|0);
 HEAP32[$44>>2] = $scevgep;
 $56 = HEAP32[$0>>2]|0;
 $57 = HEAP32[$5>>2]|0;
 $58 = ($57|0)==($56|0);
 do {
  if ($58) {
   $59 = $57;
   $60 = $56;
   $$in = $43;$97 = $60;$99 = $59;
  } else {
   $$06$i$i = $57;$63 = $43;
   while(1) {
    $61 = ((($$06$i$i)) + -64|0);
    $62 = ((($63)) + -64|0);
    __THREW__ = 0;
    invoke_vii(3457,($62|0),($61|0));
    $64 = __THREW__; __THREW__ = 0;
    $65 = $64&1;
    if ($65) {
     break;
    }
    $66 = ((($63)) + -52|0);
    $67 = ((($$06$i$i)) + -52|0);
    $68 = HEAP32[$67>>2]|0;
    HEAP32[$66>>2] = $68;
    $69 = ((($63)) + -48|0);
    $70 = ((($$06$i$i)) + -48|0);
    $71 = HEAP32[$70>>2]|0;
    HEAP32[$69>>2] = $71;
    $72 = ((($63)) + -40|0);
    $73 = ((($$06$i$i)) + -40|0);
    $74 = +HEAPF64[$73>>3];
    HEAPF64[$72>>3] = $74;
    $75 = ((($63)) + -32|0);
    $76 = ((($$06$i$i)) + -32|0);
    $77 = HEAP32[$76>>2]|0;
    HEAP32[$75>>2] = $77;
    $78 = ((($63)) + -24|0);
    $79 = ((($$06$i$i)) + -24|0);
    $80 = +HEAPF64[$79>>3];
    HEAPF64[$78>>3] = $80;
    $81 = ((($63)) + -16|0);
    $82 = ((($$06$i$i)) + -16|0);
    $83 = HEAP32[$82>>2]|0;
    HEAP32[$81>>2] = $83;
    $84 = ((($63)) + -12|0);
    $85 = ((($$06$i$i)) + -12|0);
    $86 = HEAP32[$85>>2]|0;
    HEAP32[$84>>2] = $86;
    $87 = ((($63)) + -8|0);
    $88 = ((($$06$i$i)) + -8|0);
    $89 = HEAP32[$88>>2]|0;
    HEAP32[$87>>2] = $89;
    $90 = ($89|0)==(0|0);
    if (!($90)) {
     $91 = ((($89)) + 8|0);
     $92 = HEAP32[$91>>2]|0;HEAP32[$91>>2] = (($92+1)|0);
    }
    $93 = HEAP32[$45>>2]|0;
    $94 = ((($93)) + -64|0);
    HEAP32[$45>>2] = $94;
    $95 = ($61|0)==($56|0);
    if ($95) {
     label = 20;
     break;
    } else {
     $$06$i$i = $61;$63 = $94;
    }
   }
   if ((label|0) == 20) {
    $$pre$i9 = HEAP32[$0>>2]|0;
    $$pre = HEAP32[$5>>2]|0;
    $$in = $94;$97 = $$pre$i9;$99 = $$pre;
    break;
   }
   $103 = ___cxa_find_matching_catch_2()|0;
   $104 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3847,($2|0));
   $105 = __THREW__; __THREW__ = 0;
   $106 = $105&1;
   if ($106) {
    $107 = ___cxa_find_matching_catch_3(0|0)|0;
    $108 = tempRet0;
    ___clang_call_terminate($107);
    // unreachable;
   } else {
    ___resumeException($103|0);
    // unreachable;
   }
  }
 } while(0);
 $96 = $$in;
 HEAP32[$0>>2] = $96;
 HEAP32[$45>>2] = $97;
 $98 = HEAP32[$44>>2]|0;
 HEAP32[$5>>2] = $98;
 HEAP32[$44>>2] = $99;
 $100 = HEAP32[$3>>2]|0;
 $101 = HEAP32[$47>>2]|0;
 HEAP32[$3>>2] = $101;
 HEAP32[$47>>2] = $100;
 $102 = HEAP32[$45>>2]|0;
 HEAP32[$2>>2] = $102;
 __ZNSt3__214__split_bufferIN3osg8PagedLOD12PerRangeDataERNS_9allocatorIS3_EEED2Ev($2);
 STACKTOP = sp;return;
}
function __ZNSt3__214__split_bufferIN3osg8PagedLOD12PerRangeDataERNS_9allocatorIS3_EEED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==($2|0);
 L1: do {
  if (!($5)) {
   $7 = $4;
   while(1) {
    $6 = ((($7)) + -64|0);
    HEAP32[$3>>2] = $6;
    $8 = ((($7)) + -8|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = ($9|0)==(0|0);
    if (!($10)) {
     $11 = ((($9)) + 8|0);
     $12 = HEAP32[$11>>2]|0;HEAP32[$11>>2] = (($12-1)|0);
     $13 = ($12|0)==(1);
     if ($13) {
      __THREW__ = 0;
      invoke_viii(3262,($9|0),1,1);
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if ($15) {
       break;
      }
     }
    }
    HEAP32[$8>>2] = 0;
    $16 = ((($6)) + 11|0);
    $17 = HEAP8[$16>>0]|0;
    $18 = ($17<<24>>24)<(0);
    if ($18) {
     $21 = HEAP32[$6>>2]|0;
     __ZdlPv($21);
    }
    $19 = HEAP32[$3>>2]|0;
    $20 = ($19|0)==($2|0);
    if ($20) {
     break L1;
    } else {
     $7 = $19;
    }
   }
   $22 = ___cxa_find_matching_catch_2()|0;
   $23 = tempRet0;
   $24 = ((($6)) + 11|0);
   $25 = HEAP8[$24>>0]|0;
   $26 = ($25<<24>>24)<(0);
   if (!($26)) {
    ___cxa_call_unexpected(($22|0));
    // unreachable;
   }
   $27 = HEAP32[$6>>2]|0;
   __ZdlPv($27);
   ___cxa_call_unexpected(($22|0));
   // unreachable;
  }
 } while(0);
 $28 = HEAP32[$0>>2]|0;
 $29 = ($28|0)==(0|0);
 if ($29) {
  return;
 }
 __ZdlPv($28);
 return;
}
function __ZN3osg8PagedLOD20expandPerRangeDataToEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 200|0);
 $3 = ((($0)) + 204|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$2>>2]|0;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 6;
 $8 = ($7>>>0)>($1>>>0);
 if ($8) {
  return;
 }
 $9 = (($1) + 1)|0;
 __ZNSt3__26vectorIN3osg8PagedLOD12PerRangeDataENS_9allocatorIS3_EEE6resizeEj($2,$9);
 return;
}
function __ZN3osg11PolygonModeD2Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg14StateAttributeD2Ev($0);
 return;
}
function __ZN3osg11PolygonModeD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1573,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK3osg11PolygonMode9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(64)|0);
 __THREW__ = 0;
 invoke_vi(3339,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $6 = ___cxa_find_matching_catch_2()|0;
  $7 = tempRet0;
  __ZdlPv($1);
  ___resumeException($6|0);
  // unreachable;
 } else {
  HEAP32[$1>>2] = (63676);
  $4 = ((($1)) + 56|0);
  HEAP32[$4>>2] = 6914;
  $5 = ((($1)) + 60|0);
  HEAP32[$5>>2] = 6914;
  return ($1|0);
 }
 return (0)|0;
}
function __ZNK3osg11PolygonMode5cloneERKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(64)|0);
 __THREW__ = 0;
 invoke_viii(3729,($2|0),($0|0),($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $11 = ___cxa_find_matching_catch_2()|0;
  $12 = tempRet0;
  __ZdlPv($2);
  ___resumeException($11|0);
  // unreachable;
 } else {
  HEAP32[$2>>2] = (63676);
  $5 = ((($2)) + 56|0);
  $6 = ((($0)) + 56|0);
  $7 = HEAP32[$6>>2]|0;
  HEAP32[$5>>2] = $7;
  $8 = ((($2)) + 60|0);
  $9 = ((($0)) + 60|0);
  $10 = HEAP32[$9>>2]|0;
  HEAP32[$8>>2] = $10;
  return ($2|0);
 }
 return (0)|0;
}
function __ZNK3osg11PolygonMode12isSameKindAsEPKNS_6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,26232,0)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK3osg11PolygonMode11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175113|0);
}
function __ZNK3osg11PolygonMode9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (146028|0);
}
function __ZNK3osg11PolygonMode7getTypeEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 1;
}
function __ZNK3osg11PolygonMode7compareERKNS_14StateAttributeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$ = 0, $$$ = 0, $$2 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($0|0)==($1|0);
 if ($2) {
  $$2 = 0;
  return ($$2|0);
 }
 $3 = ($0|0)==(0|0);
 if ($3) {
  ___cxa_bad_typeid();
  // unreachable;
 }
 $4 = HEAP32[$0>>2]|0;
 $5 = ((($4)) + -4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$1>>2]|0;
 $8 = ((($7)) + -4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($6)) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($9)) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($11>>>0)<($13>>>0);
 if ($14) {
  $$2 = -1;
  return ($$2|0);
 }
 $15 = ($11|0)==($13|0);
 if (!($15)) {
  $$2 = 1;
  return ($$2|0);
 }
 $16 = ((($0)) + 56|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ((($1)) + 56|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($17|0)<($19|0);
 if ($20) {
  $$2 = -1;
  return ($$2|0);
 }
 $21 = ($19|0)<($17|0);
 if ($21) {
  $$2 = 1;
  return ($$2|0);
 } else {
  $22 = ((($0)) + 60|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = ((($1)) + 60|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = ($23|0)<($25|0);
  $27 = ($25|0)<($23|0);
  $$ = $27&1;
  $$$ = $26 ? -1 : $$;
  return ($$$|0);
 }
 return (0)|0;
}
function __ZNK3osg11PolygonMode5applyERNS_5StateE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $4 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
 $5 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($4,145972,55)|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($6)) + -12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($5) + ($8)|0);
 __ZNKSt3__28ios_base6getlocEv($2,$9);
 __THREW__ = 0;
 $10 = (invoke_iii(3255,($2|0),(215188|0))|0);
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if (!($12)) {
  $13 = HEAP32[$10>>2]|0;
  $14 = ((($13)) + 28|0);
  $15 = HEAP32[$14>>2]|0;
  __THREW__ = 0;
  $16 = (invoke_iii($15|0,($10|0),10)|0);
  $17 = __THREW__; __THREW__ = 0;
  $18 = $17&1;
  if (!($18)) {
   __ZNSt3__26localeD2Ev($2);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($5,$16)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($5)|0);
   STACKTOP = sp;return;
  }
 }
 $19 = ___cxa_find_matching_catch_2()|0;
 $20 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($2|0));
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if ($22) {
  $23 = ___cxa_find_matching_catch_3(0|0)|0;
  $24 = tempRet0;
  ___clang_call_terminate($23);
  // unreachable;
 } else {
  ___resumeException($19|0);
  // unreachable;
 }
}
function __ZN3osg11PolygonModeC2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg14StateAttributeC2Ev($0);
 HEAP32[$0>>2] = (63676);
 $1 = ((($0)) + 56|0);
 HEAP32[$1>>2] = 6914;
 $2 = ((($0)) + 60|0);
 HEAP32[$2>>2] = 6914;
 return;
}
function __ZN3osg14PolygonStippleD2Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg14StateAttributeD2Ev($0);
 return;
}
function __ZN3osg14PolygonStippleD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1573,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK3osg14PolygonStipple9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $1 = (__Znwj(184)|0);
 __THREW__ = 0;
 invoke_vi(3339,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $5 = ___cxa_find_matching_catch_2()|0;
  $6 = tempRet0;
  __ZdlPv($1);
  ___resumeException($5|0);
  // unreachable;
 } else {
  HEAP32[$1>>2] = (63864);
  $4 = ((($1)) + 56|0);
  dest=$4; src=146131; stop=dest+128|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
  return ($1|0);
 }
 return (0)|0;
}
function __ZNK3osg14PolygonStipple5cloneERKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $2 = (__Znwj(184)|0);
 __THREW__ = 0;
 invoke_viii(3729,($2|0),($0|0),($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $7 = ___cxa_find_matching_catch_2()|0;
  $8 = tempRet0;
  __ZdlPv($2);
  ___resumeException($7|0);
  // unreachable;
 } else {
  HEAP32[$2>>2] = (63864);
  $5 = ((($0)) + 56|0);
  $6 = ((($2)) + 56|0);
  dest=$6; src=$5; stop=dest+128|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
  return ($2|0);
 }
 return (0)|0;
}
function __ZNK3osg14PolygonStipple12isSameKindAsEPKNS_6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,26248,0)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK3osg14PolygonStipple11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175113|0);
}
function __ZNK3osg14PolygonStipple9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (146116|0);
}
function __ZNK3osg14PolygonStipple7getTypeEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 14;
}
function __ZNK3osg14PolygonStipple7compareERKNS_14StateAttributeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$026 = 0, $$3 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($0|0)==($1|0);
 if ($2) {
  $$3 = 0;
  return ($$3|0);
 }
 $3 = ($0|0)==(0|0);
 if ($3) {
  ___cxa_bad_typeid();
  // unreachable;
 }
 $4 = HEAP32[$0>>2]|0;
 $5 = ((($4)) + -4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$1>>2]|0;
 $8 = ((($7)) + -4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($6)) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($9)) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($11>>>0)<($13>>>0);
 if ($14) {
  $$3 = -1;
  return ($$3|0);
 }
 $15 = ($11|0)==($13|0);
 if (!($15)) {
  $$3 = 1;
  return ($$3|0);
 }
 $16 = ((($1)) + 56|0);
 $$026 = 0;
 while(1) {
  $19 = (((($0)) + 56|0) + ($$026)|0);
  $20 = HEAP8[$19>>0]|0;
  $21 = (($16) + ($$026)|0);
  $22 = HEAP8[$21>>0]|0;
  $23 = ($20&255)<($22&255);
  if ($23) {
   $$3 = -1;
   label = 10;
   break;
  }
  $24 = ($20&255)>($22&255);
  $17 = (($$026) + 1)|0;
  if ($24) {
   $$3 = 1;
   label = 10;
   break;
  }
  $18 = ($17>>>0)<(128);
  if ($18) {
   $$026 = $17;
  } else {
   $$3 = 0;
   label = 10;
   break;
  }
 }
 if ((label|0) == 10) {
  return ($$3|0);
 }
 return (0)|0;
}
function __ZNK3osg14PolygonStipple12getModeUsageERNS_14StateAttribute9ModeUsageE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 8191]($1,2882);
 return 1;
}
function __ZNK3osg14PolygonStipple5applyERNS_5StateE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $4 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
 $5 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($4,146060,55)|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($6)) + -12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($5) + ($8)|0);
 __ZNKSt3__28ios_base6getlocEv($2,$9);
 __THREW__ = 0;
 $10 = (invoke_iii(3255,($2|0),(215188|0))|0);
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if (!($12)) {
  $13 = HEAP32[$10>>2]|0;
  $14 = ((($13)) + 28|0);
  $15 = HEAP32[$14>>2]|0;
  __THREW__ = 0;
  $16 = (invoke_iii($15|0,($10|0),10)|0);
  $17 = __THREW__; __THREW__ = 0;
  $18 = $17&1;
  if (!($18)) {
   __ZNSt3__26localeD2Ev($2);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($5,$16)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($5)|0);
   STACKTOP = sp;return;
  }
 }
 $19 = ___cxa_find_matching_catch_2()|0;
 $20 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($2|0));
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if ($22) {
  $23 = ___cxa_find_matching_catch_3(0|0)|0;
  $24 = tempRet0;
  ___clang_call_terminate($23);
  // unreachable;
 } else {
  ___resumeException($19|0);
  // unreachable;
 }
}
function __ZN3osg14PolygonStippleC2EPKh($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg14StateAttributeC2Ev($0);
 HEAP32[$0>>2] = (63864);
 $2 = ((($0)) + 56|0);
 _memmove(($2|0),($1|0),128)|0;
 return;
}
function __ZN3osg17DrawElementsUByteD2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (64052);
 $1 = ((($0)) + 64|0);
 HEAP32[$1>>2] = (64300);
 __THREW__ = 0;
 invoke_vii(322,($0|0),(0|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  HEAP32[$1>>2] = (53536);
  $4 = ((($0)) + 68|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0|0);
  if ($6) {
   __ZN3osg10BufferDataD2Ev($0);
   return;
  }
  $7 = ((($0)) + 72|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)==($5|0);
  if (!($9)) {
   HEAP32[$7>>2] = $5;
  }
  __ZdlPv($5);
  __ZN3osg10BufferDataD2Ev($0);
  return;
 }
 $10 = ___cxa_find_matching_catch_2()|0;
 $11 = tempRet0;
 HEAP32[$1>>2] = (53536);
 $12 = ((($0)) + 68|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0|0);
 if (!($14)) {
  $15 = ((($0)) + 72|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($16|0)==($13|0);
  if (!($17)) {
   HEAP32[$15>>2] = $13;
  }
  __ZdlPv($13);
 }
 __THREW__ = 0;
 invoke_vi(1265,($0|0));
 $18 = __THREW__; __THREW__ = 0;
 $19 = $18&1;
 if ($19) {
  $20 = ___cxa_find_matching_catch_3(0|0)|0;
  $21 = tempRet0;
  ___clang_call_terminate($20);
  // unreachable;
 } else {
  ___resumeException($10|0);
  // unreachable;
 }
}
function __ZN3osg17DrawElementsUByteD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(2092,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK3osg17DrawElementsUByte9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(80)|0);
 __THREW__ = 0;
 invoke_vii(3435,($1|0),1);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $14 = ___cxa_find_matching_catch_2()|0;
  $15 = tempRet0;
  __ZdlPv($1);
  ___resumeException($14|0);
  // unreachable;
 } else {
  $4 = ((($1)) + 12|0);
  ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;
  $5 = ((($1)) + 24|0);
  HEAP32[$5>>2] = 2;
  $6 = ((($1)) + 28|0);
  ;HEAP32[$6>>2]=0|0;HEAP32[$6+4>>2]=0|0;HEAP32[$6+8>>2]=0|0;HEAP32[$6+12>>2]=0|0;HEAP32[$6+16>>2]=0|0;HEAP32[$6+20>>2]=0|0;
  $7 = ((($1)) + 52|0);
  HEAP32[$7>>2] = 3;
  $8 = ((($1)) + 56|0);
  HEAP32[$8>>2] = 0;
  $9 = ((($1)) + 60|0);
  HEAP32[$9>>2] = 0;
  $10 = ((($1)) + 64|0);
  $11 = ((($1)) + 68|0);
  HEAP32[$11>>2] = 0;
  $12 = ((($1)) + 72|0);
  HEAP32[$12>>2] = 0;
  $13 = ((($1)) + 76|0);
  HEAP32[$13>>2] = 0;
  HEAP32[$1>>2] = (64052);
  HEAP32[$10>>2] = (64300);
  return ($1|0);
 }
 return (0)|0;
}
function __ZNK3osg17DrawElementsUByte5cloneERKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(80)|0);
 __THREW__ = 0;
 invoke_viii(3848,($2|0),($0|0),($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch_2()|0;
  $6 = tempRet0;
  __ZdlPv($2);
  ___resumeException($5|0);
  // unreachable;
 } else {
  return ($2|0);
 }
 return (0)|0;
}
function __ZNK3osg17DrawElementsUByte12isSameKindAsEPKNS_6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,26264,0)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK3osg17DrawElementsUByte11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175113|0);
}
function __ZNK3osg17DrawElementsUByte9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (171425|0);
}
function __ZNK3osg17DrawElementsUByte14getDataPointerEv($0) {
 $0 = $0|0;
 var $$ = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 68|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 72|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2|0)==($4|0);
 $$ = $5 ? 0 : $2;
 return ($$|0);
}
function __ZNK3osg17DrawElementsUByte16getTotalDataSizeEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 68|0);
 $2 = ((($0)) + 72|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$1>>2]|0;
 $5 = (($3) - ($4))|0;
 return ($5|0);
}
function __ZNK3osg17DrawElementsUByte20supportsBufferObjectEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function __ZNK3osg17DrawElementsUByte4drawERNS_5StateEb($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$ = 0, $$$ = 0, $$pre$i = 0, $$pre$phi$iZ2D = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 60|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(9);
 $$ = $5 ? 6 : $4;
 $6 = ($$|0)==(8);
 $$$ = $6 ? 5 : $$;
 if (!($2)) {
  $72 = ((($0)) + 56|0);
  $73 = HEAP32[$72>>2]|0;
  $74 = ($73|0)>(0);
  $75 = ((($0)) + 68|0);
  $76 = ((($0)) + 72|0);
  $77 = HEAP32[$76>>2]|0;
  $78 = HEAP32[$75>>2]|0;
  $79 = (($77) - ($78))|0;
  $80 = $78;
  if (!($74)) {
   _glDrawElements(($$$|0),($79|0),5121,($80|0));
   return;
  }
  $81 = ((($1)) + 780|0);
  $82 = HEAP32[$81>>2]|0;
  $83 = ($82|0)==(0|0);
  if ($83) {
   _glDrawElements(($$$|0),($79|0),5121,($80|0));
   return;
  } else {
   FUNCTION_TABLE_viiiii[$82 & 8191]($$$,$79,5121,$80,$73);
   return;
  }
 }
 $7 = ((($0)) + 40|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if ($9) {
  $10 = ((($1)) + 132|0);
  $11 = HEAP32[$10>>2]|0;
  $53 = $11;
 } else {
  $12 = ((($1)) + 124|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (__ZNK3osg12BufferObject25getOrCreateGLBufferObjectEj($8,$13)|0);
  $15 = ($14|0)==(0|0);
  $16 = ((($1)) + 132|0);
  $17 = HEAP32[$16>>2]|0;
  if ($15) {
   $53 = $17;
  } else {
   $18 = ((($14)) + 36|0);
   $19 = HEAP8[$18>>0]|0;
   $20 = ($19<<24>>24)==(0);
   if ($20) {
    $21 = ((($17)) + 100|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = ($22|0)==($14|0);
    if (!($23)) {
     $24 = ((($14)) + 72|0);
     $25 = HEAP32[$24>>2]|0;
     $26 = ((($25)) + 724|0);
     $27 = HEAP32[$26>>2]|0;
     $28 = ((($14)) + 20|0);
     $29 = HEAP32[$28>>2]|0;
     $30 = ((($14)) + 16|0);
     $31 = HEAP32[$30>>2]|0;
     FUNCTION_TABLE_vii[$27 & 8191]($29,$31);
     $32 = ((($14)) + 56|0);
     $33 = HEAP32[$32>>2]|0;
     $34 = ($33|0)==(0|0);
     if ($34) {
      $$pre$phi$iZ2D = $21;
      label = 10;
     } else {
      __ZN3osg17GLBufferObjectSet10moveToBackEPNS_14GLBufferObjectE($33,$14);
      $$pre$phi$iZ2D = $21;
      label = 10;
     }
    }
   } else {
    __ZN3osg14GLBufferObject13compileBufferEv($14);
    $$pre$i = ((($17)) + 100|0);
    $$pre$phi$iZ2D = $$pre$i;
    label = 10;
   }
   if ((label|0) == 10) {
    HEAP32[$$pre$phi$iZ2D>>2] = $14;
   }
   $35 = ((($0)) + 56|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = ($36|0)>(0);
   $38 = ((($0)) + 68|0);
   $39 = ((($0)) + 72|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = HEAP32[$38>>2]|0;
   $42 = (($40) - ($41))|0;
   $43 = ((($0)) + 36|0);
   $44 = HEAP32[$43>>2]|0;
   $45 = ((($14)) + 40|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = (((($46) + (($44*20)|0)|0)) + 12|0);
   $48 = HEAP32[$47>>2]|0;
   if (!($37)) {
    _glDrawElements(($$$|0),($42|0),5121,($48|0));
    return;
   }
   $49 = ((($1)) + 780|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = ($50|0)==(0|0);
   if ($51) {
    _glDrawElements(($$$|0),($42|0),5121,($48|0));
    return;
   } else {
    FUNCTION_TABLE_viiiii[$50 & 8191]($$$,$42,5121,$48,$36);
    return;
   }
  }
 }
 $52 = ((($53)) + 100|0);
 $54 = HEAP32[$52>>2]|0;
 $55 = ($54|0)==(0|0);
 if (!($55)) {
  $56 = ((($53)) + 16|0);
  $57 = HEAP32[$56>>2]|0;
  $58 = ((($57)) + 724|0);
  $59 = HEAP32[$58>>2]|0;
  FUNCTION_TABLE_vii[$59 & 8191](34963,0);
  HEAP32[$52>>2] = 0;
 }
 $60 = ((($0)) + 56|0);
 $61 = HEAP32[$60>>2]|0;
 $62 = ($61|0)>(0);
 $63 = ((($0)) + 68|0);
 $64 = ((($0)) + 72|0);
 $65 = HEAP32[$64>>2]|0;
 $66 = HEAP32[$63>>2]|0;
 $67 = (($65) - ($66))|0;
 $68 = $66;
 if (!($62)) {
  _glDrawElements(($$$|0),($67|0),5121,($68|0));
  return;
 }
 $69 = ((($1)) + 780|0);
 $70 = HEAP32[$69>>2]|0;
 $71 = ($70|0)==(0|0);
 if ($71) {
  _glDrawElements(($$$|0),($67|0),5121,($68|0));
  return;
 } else {
  FUNCTION_TABLE_viiiii[$70 & 8191]($$$,$67,5121,$68,$61);
  return;
 }
}
function __ZNK3osg17DrawElementsUByte6acceptERNS_16PrimitiveFunctorE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 68|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 72|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if ($6) {
  return;
 }
 $7 = $3;
 $8 = $5;
 $9 = HEAP32[$1>>2]|0;
 $10 = ((($9)) + 36|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($0)) + 60|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($8) - ($7))|0;
 FUNCTION_TABLE_viiii[$11 & 8191]($1,$13,$14,$3);
 return;
}
function __ZNK3osg17DrawElementsUByte6acceptERNS_21PrimitiveIndexFunctorE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 68|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 72|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if ($6) {
  return;
 }
 $7 = $3;
 $8 = $5;
 $9 = HEAP32[$1>>2]|0;
 $10 = ((($9)) + 36|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($0)) + 60|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($8) - ($7))|0;
 FUNCTION_TABLE_viiii[$11 & 8191]($1,$13,$14,$3);
 return;
}
function __ZNK3osg17DrawElementsUByte5indexEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 68|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + ($1)|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = $5&255;
 return ($6|0);
}
function __ZNK3osg17DrawElementsUByte13getNumIndicesEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 68|0);
 $2 = ((($0)) + 72|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$1>>2]|0;
 $5 = (($3) - ($4))|0;
 return ($5|0);
}
function __ZN3osg17DrawElementsUByte13offsetIndicesEi($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$sroa$02$06 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 68|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 72|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if ($6) {
  return;
 } else {
  $$sroa$02$06 = $3;
 }
 while(1) {
  $7 = HEAP8[$$sroa$02$06>>0]|0;
  $8 = $7&255;
  $9 = (($8) + ($1))|0;
  $10 = $9&255;
  HEAP8[$$sroa$02$06>>0] = $10;
  $11 = ((($$sroa$02$06)) + 1|0);
  $12 = HEAP32[$4>>2]|0;
  $13 = ($11|0)==($12|0);
  if ($13) {
   break;
  } else {
   $$sroa$02$06 = $11;
  }
 }
 return;
}
function __ZNK3osg12PrimitiveSet16getNumPrimitivesEv($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 60|0);
 $2 = HEAP32[$1>>2]|0;
 switch ($2|0) {
 case 0:  {
  $3 = HEAP32[$0>>2]|0;
  $4 = ((($3)) + 200|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (FUNCTION_TABLE_ii[$5 & 8191]($0)|0);
  $$0 = $6;
  return ($$0|0);
  break;
 }
 case 1:  {
  $7 = HEAP32[$0>>2]|0;
  $8 = ((($7)) + 200|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (FUNCTION_TABLE_ii[$9 & 8191]($0)|0);
  $11 = $10 >>> 1;
  $$0 = $11;
  return ($$0|0);
  break;
 }
 case 4:  {
  $12 = HEAP32[$0>>2]|0;
  $13 = ((($12)) + 200|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (FUNCTION_TABLE_ii[$14 & 8191]($0)|0);
  $16 = (($15>>>0) / 3)&-1;
  $$0 = $16;
  return ($$0|0);
  break;
 }
 case 7:  {
  $17 = HEAP32[$0>>2]|0;
  $18 = ((($17)) + 200|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = (FUNCTION_TABLE_ii[$19 & 8191]($0)|0);
  $21 = $20 >>> 2;
  $$0 = $21;
  return ($$0|0);
  break;
 }
 case 9: case 14: case 8: case 6: case 5: case 2: case 3:  {
  $22 = HEAP32[$0>>2]|0;
  $23 = ((($22)) + 200|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = (FUNCTION_TABLE_ii[$24 & 8191]($0)|0);
  $26 = ($25|0)!=(0);
  $27 = $26&1;
  $$0 = $27;
  return ($$0|0);
  break;
 }
 default: {
  $$0 = 0;
  return ($$0|0);
 }
 }
 return (0)|0;
}
function __ZN3osg17DrawElementsUByte11getDataTypeEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 5121;
}
function __ZN3osg17DrawElementsUByte14resizeElementsEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 HEAP8[$2>>0] = 0;
 $3 = ((($0)) + 68|0);
 $4 = ((($0)) + 72|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$3>>2]|0;
 $7 = (($5) - ($6))|0;
 $8 = ($7>>>0)<($1>>>0);
 $9 = $6;
 $10 = $5;
 if ($8) {
  $11 = (($1) - ($7))|0;
  __ZNSt3__26vectorIhNS_9allocatorIhEEE8__appendEjRKh($3,$11,$2);
  STACKTOP = sp;return;
 }
 $12 = ($7>>>0)>($1>>>0);
 if (!($12)) {
  STACKTOP = sp;return;
 }
 $13 = (($9) + ($1)|0);
 $14 = ($10|0)==($13|0);
 if ($14) {
  STACKTOP = sp;return;
 }
 HEAP32[$4>>2] = $13;
 STACKTOP = sp;return;
}
function __ZN3osg17DrawElementsUByte15reserveElementsEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 68|0);
 $3 = ((($0)) + 76|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$2>>2]|0;
 $6 = (($4) - ($5))|0;
 $7 = ($6>>>0)<($1>>>0);
 $8 = $5;
 if (!($7)) {
  return;
 }
 $9 = ((($0)) + 72|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) - ($5))|0;
 $12 = (__Znwj($1)|0);
 $13 = (($12) + ($11)|0);
 $14 = $13;
 $15 = (($12) + ($1)|0);
 $16 = $15;
 $17 = (0 - ($11))|0;
 $18 = (($13) + ($17)|0);
 $19 = $18;
 $20 = ($11|0)>(0);
 if ($20) {
  _memcpy(($18|0),($8|0),($11|0))|0;
 }
 HEAP32[$2>>2] = $19;
 HEAP32[$9>>2] = $14;
 HEAP32[$3>>2] = $16;
 $21 = ($5|0)==(0);
 if ($21) {
  return;
 }
 __ZdlPv($8);
 return;
}
function __ZN3osg17DrawElementsUByte10setElementEjj($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = $2&255;
 $4 = ((($0)) + 68|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + ($1)|0);
 HEAP8[$6>>0] = $3;
 return;
}
function __ZN3osg17DrawElementsUByte10getElementEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 68|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + ($1)|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = $5&255;
 return ($6|0);
}
function __ZN3osg17DrawElementsUByte10addElementEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$sroa$speculated$$i$i$i$i = 0, $$sroa$speculated$i$i$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = $1&255;
 $3 = ((($0)) + 68|0);
 $4 = ((($0)) + 72|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($0)) + 76|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5|0)==($7|0);
 $9 = $7;
 if (!($8)) {
  HEAP8[$5>>0] = $2;
  $10 = HEAP32[$4>>2]|0;
  $11 = ((($10)) + 1|0);
  HEAP32[$4>>2] = $11;
  return;
 }
 $12 = $5;
 $13 = HEAP32[$3>>2]|0;
 $14 = (($12) - ($13))|0;
 $15 = (($14) + 1)|0;
 $16 = ($15|0)<(0);
 $17 = $13;
 if ($16) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($3);
  // unreachable;
 }
 $18 = (($9) - ($13))|0;
 $19 = ($18>>>0)<(1073741823);
 $20 = $18 << 1;
 $21 = ($20>>>0)<($15>>>0);
 $$sroa$speculated$i$i$i$i = $21 ? $15 : $20;
 $$sroa$speculated$$i$i$i$i = $19 ? $$sroa$speculated$i$i$i$i : 2147483647;
 $22 = ($$sroa$speculated$$i$i$i$i|0)==(0);
 if ($22) {
  $25 = 0;
 } else {
  $23 = (__Znwj($$sroa$speculated$$i$i$i$i)|0);
  $25 = $23;
 }
 $24 = (($25) + ($14)|0);
 $26 = (($25) + ($$sroa$speculated$$i$i$i$i)|0);
 $27 = $26;
 HEAP8[$24>>0] = $2;
 $28 = ((($24)) + 1|0);
 $29 = $28;
 $30 = (0 - ($14))|0;
 $31 = (($24) + ($30)|0);
 $32 = $31;
 $33 = ($14|0)>(0);
 if ($33) {
  _memcpy(($31|0),($17|0),($14|0))|0;
 }
 HEAP32[$3>>2] = $32;
 HEAP32[$4>>2] = $29;
 HEAP32[$6>>2] = $27;
 $34 = ($13|0)==(0);
 if ($34) {
  return;
 }
 __ZdlPv($17);
 return;
}
function __ZThn64_N3osg17DrawElementsUByteD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -64|0);
 __ZN3osg17DrawElementsUByteD2Ev($1);
 return;
}
function __ZThn64_N3osg17DrawElementsUByteD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -64|0);
 __THREW__ = 0;
 invoke_vi(2092,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch_2()|0;
  $5 = tempRet0;
  __ZdlPv($1);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZdlPv($1);
  return;
 }
}
function __ZN3osg17DrawElementsUByteC2ERKS0_RKNS_6CopyOpE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg6ObjectC2ERKS0_RKNS_6CopyOpE($0,$1,$2);
 HEAP32[$0>>2] = (55116);
 $3 = ((($0)) + 32|0);
 HEAP32[$3>>2] = 0;
 $4 = ((($0)) + 36|0);
 HEAP32[$4>>2] = 0;
 $5 = ((($0)) + 40|0);
 HEAP32[$5>>2] = 0;
 $6 = ((($0)) + 44|0);
 $7 = ((($1)) + 44|0);
 $8 = HEAP32[$7>>2]|0;
 HEAP32[$6>>2] = $8;
 $9 = ($8|0)==(0|0);
 if (!($9)) {
  $10 = HEAP32[$8>>2]|0;
  $11 = ((($10)) + -12|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($8) + ($12)|0);
  $14 = ((($13)) + 8|0);
  $15 = HEAP32[$14>>2]|0;HEAP32[$14>>2] = (($15+1)|0);
 }
 $16 = ((($0)) + 48|0);
 HEAP32[$16>>2] = 0;
 $17 = ((($0)) + 52|0);
 $18 = ((($1)) + 52|0);
 $19 = HEAP32[$18>>2]|0;
 HEAP32[$17>>2] = $19;
 $20 = ((($0)) + 56|0);
 $21 = ((($1)) + 56|0);
 $22 = HEAP32[$21>>2]|0;
 HEAP32[$20>>2] = $22;
 $23 = ((($0)) + 60|0);
 $24 = ((($1)) + 60|0);
 $25 = HEAP32[$24>>2]|0;
 HEAP32[$23>>2] = $25;
 HEAP32[$0>>2] = (52272);
 $26 = ((($0)) + 64|0);
 HEAP32[$26>>2] = (53536);
 $27 = ((($0)) + 68|0);
 $28 = ((($1)) + 68|0);
 HEAP32[$27>>2] = 0;
 $29 = ((($0)) + 72|0);
 HEAP32[$29>>2] = 0;
 $30 = ((($0)) + 76|0);
 HEAP32[$30>>2] = 0;
 $31 = ((($1)) + 72|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = HEAP32[$28>>2]|0;
 $34 = (($32) - ($33))|0;
 $35 = ($34|0)==(0);
 if ($35) {
  HEAP32[$0>>2] = (64052);
  HEAP32[$26>>2] = (64300);
  return;
 }
 $36 = ($34|0)<(0);
 if ($36) {
  __THREW__ = 0;
  invoke_vi(3307,($27|0));
  $37 = __THREW__; __THREW__ = 0;
 } else {
  __THREW__ = 0;
  $38 = (invoke_ii(3276,($34|0))|0);
  $39 = __THREW__; __THREW__ = 0;
  $40 = $39&1;
  if (!($40)) {
   HEAP32[$29>>2] = $38;
   HEAP32[$27>>2] = $38;
   $41 = (($38) + ($34)|0);
   $42 = ((($0)) + 76|0);
   HEAP32[$42>>2] = $41;
   $43 = HEAP32[$28>>2]|0;
   $44 = HEAP32[$31>>2]|0;
   $45 = $43;
   $46 = (($44) - ($45))|0;
   $47 = ($46|0)>(0);
   if (!($47)) {
    HEAP32[$0>>2] = (64052);
    HEAP32[$26>>2] = (64300);
    return;
   }
   _memcpy(($38|0),($43|0),($46|0))|0;
   $48 = (($38) + ($46)|0);
   HEAP32[$29>>2] = $48;
   HEAP32[$0>>2] = (64052);
   HEAP32[$26>>2] = (64300);
   return;
  }
 }
 $49 = ___cxa_find_matching_catch_2()|0;
 $50 = tempRet0;
 $51 = HEAP32[$27>>2]|0;
 $52 = ($51|0)==(0|0);
 if (!($52)) {
  $53 = HEAP32[$29>>2]|0;
  $54 = ($53|0)==($51|0);
  if (!($54)) {
   HEAP32[$29>>2] = $51;
  }
  __ZdlPv($51);
 }
 __THREW__ = 0;
 invoke_vi(1265,($0|0));
 $55 = __THREW__; __THREW__ = 0;
 $56 = $55&1;
 if ($56) {
  $57 = ___cxa_find_matching_catch_3(0|0)|0;
  $58 = tempRet0;
  ___clang_call_terminate($57);
  // unreachable;
 } else {
  ___resumeException($49|0);
  // unreachable;
 }
}
function __ZN3osg18DrawElementsUShortD2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i$i$i3 = 0, $scevgep5$i$i$i$i = 0, $scevgep5$i$i$i$i4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (64316);
 $1 = ((($0)) + 64|0);
 HEAP32[$1>>2] = (64564);
 __THREW__ = 0;
 invoke_vii(322,($0|0),(0|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  HEAP32[$1>>2] = (53520);
  $4 = ((($0)) + 68|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0|0);
  if ($6) {
   __ZN3osg10BufferDataD2Ev($0);
   return;
  }
  $7 = ((($0)) + 72|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)==($5|0);
  if (!($9)) {
   $scevgep$i$i$i$i = ((($8)) + -2|0);
   $10 = $scevgep$i$i$i$i;
   $11 = $5;
   $12 = (($10) - ($11))|0;
   $13 = $12 >>> 1;
   $14 = $13 ^ -1;
   $scevgep5$i$i$i$i = (($8) + ($14<<1)|0);
   HEAP32[$7>>2] = $scevgep5$i$i$i$i;
  }
  __ZdlPv($5);
  __ZN3osg10BufferDataD2Ev($0);
  return;
 }
 $15 = ___cxa_find_matching_catch_2()|0;
 $16 = tempRet0;
 HEAP32[$1>>2] = (53520);
 $17 = ((($0)) + 68|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ($18|0)==(0|0);
 if (!($19)) {
  $20 = ((($0)) + 72|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = ($21|0)==($18|0);
  if (!($22)) {
   $scevgep$i$i$i$i3 = ((($21)) + -2|0);
   $23 = $scevgep$i$i$i$i3;
   $24 = $18;
   $25 = (($23) - ($24))|0;
   $26 = $25 >>> 1;
   $27 = $26 ^ -1;
   $scevgep5$i$i$i$i4 = (($21) + ($27<<1)|0);
   HEAP32[$20>>2] = $scevgep5$i$i$i$i4;
  }
  __ZdlPv($18);
 }
 __THREW__ = 0;
 invoke_vi(1265,($0|0));
 $28 = __THREW__; __THREW__ = 0;
 $29 = $28&1;
 if ($29) {
  $30 = ___cxa_find_matching_catch_3(0|0)|0;
  $31 = tempRet0;
  ___clang_call_terminate($30);
  // unreachable;
 } else {
  ___resumeException($15|0);
  // unreachable;
 }
}
function __ZN3osg18DrawElementsUShortD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(2116,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK3osg18DrawElementsUShort9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(80)|0);
 __THREW__ = 0;
 invoke_vii(3435,($1|0),1);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $14 = ___cxa_find_matching_catch_2()|0;
  $15 = tempRet0;
  __ZdlPv($1);
  ___resumeException($14|0);
  // unreachable;
 } else {
  $4 = ((($1)) + 12|0);
  ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;
  $5 = ((($1)) + 24|0);
  HEAP32[$5>>2] = 2;
  $6 = ((($1)) + 28|0);
  ;HEAP32[$6>>2]=0|0;HEAP32[$6+4>>2]=0|0;HEAP32[$6+8>>2]=0|0;HEAP32[$6+12>>2]=0|0;HEAP32[$6+16>>2]=0|0;HEAP32[$6+20>>2]=0|0;
  $7 = ((($1)) + 52|0);
  HEAP32[$7>>2] = 4;
  $8 = ((($1)) + 56|0);
  HEAP32[$8>>2] = 0;
  $9 = ((($1)) + 60|0);
  HEAP32[$9>>2] = 0;
  $10 = ((($1)) + 64|0);
  $11 = ((($1)) + 68|0);
  HEAP32[$11>>2] = 0;
  $12 = ((($1)) + 72|0);
  HEAP32[$12>>2] = 0;
  $13 = ((($1)) + 76|0);
  HEAP32[$13>>2] = 0;
  HEAP32[$1>>2] = (64316);
  HEAP32[$10>>2] = (64564);
  return ($1|0);
 }
 return (0)|0;
}
function __ZNK3osg18DrawElementsUShort5cloneERKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0;
 var $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(80)|0);
 __THREW__ = 0;
 invoke_viii(3468,($2|0),($0|0),($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $39 = ___cxa_find_matching_catch_2()|0;
  $40 = tempRet0;
  $eh$lpad$body$index2Z2D = $40;$eh$lpad$body$indexZ2D = $39;
  __ZdlPv($2);
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 HEAP32[$2>>2] = (55116);
 $5 = ((($2)) + 32|0);
 HEAP32[$5>>2] = 0;
 $6 = ((($2)) + 36|0);
 HEAP32[$6>>2] = 0;
 $7 = ((($2)) + 40|0);
 HEAP32[$7>>2] = 0;
 $8 = ((($2)) + 44|0);
 $9 = ((($0)) + 44|0);
 $10 = HEAP32[$9>>2]|0;
 HEAP32[$8>>2] = $10;
 $11 = ($10|0)==(0|0);
 if (!($11)) {
  $12 = HEAP32[$10>>2]|0;
  $13 = ((($12)) + -12|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($10) + ($14)|0);
  $16 = ((($15)) + 8|0);
  $17 = HEAP32[$16>>2]|0;HEAP32[$16>>2] = (($17+1)|0);
 }
 $18 = ((($2)) + 48|0);
 HEAP32[$18>>2] = 0;
 $19 = ((($2)) + 52|0);
 $20 = ((($0)) + 52|0);
 $21 = HEAP32[$20>>2]|0;
 HEAP32[$19>>2] = $21;
 $22 = ((($2)) + 56|0);
 $23 = ((($0)) + 56|0);
 $24 = HEAP32[$23>>2]|0;
 HEAP32[$22>>2] = $24;
 $25 = ((($2)) + 60|0);
 $26 = ((($0)) + 60|0);
 $27 = HEAP32[$26>>2]|0;
 HEAP32[$25>>2] = $27;
 HEAP32[$2>>2] = (52272);
 $28 = ((($2)) + 64|0);
 HEAP32[$28>>2] = (53520);
 $29 = ((($2)) + 68|0);
 $30 = ((($0)) + 68|0);
 __THREW__ = 0;
 invoke_vii(3849,($29|0),($30|0));
 $31 = __THREW__; __THREW__ = 0;
 $32 = $31&1;
 if (!($32)) {
  HEAP32[$2>>2] = (64316);
  HEAP32[$28>>2] = (64564);
  return ($2|0);
 }
 $33 = ___cxa_find_matching_catch_2()|0;
 $34 = tempRet0;
 __THREW__ = 0;
 invoke_vi(1265,($2|0));
 $35 = __THREW__; __THREW__ = 0;
 $36 = $35&1;
 if ($36) {
  $37 = ___cxa_find_matching_catch_3(0|0)|0;
  $38 = tempRet0;
  ___clang_call_terminate($37);
  // unreachable;
 } else {
  $eh$lpad$body$index2Z2D = $34;$eh$lpad$body$indexZ2D = $33;
  __ZdlPv($2);
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 return (0)|0;
}
function __ZNK3osg18DrawElementsUShort12isSameKindAsEPKNS_6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,26296,0)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK3osg18DrawElementsUShort11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175113|0);
}
function __ZNK3osg18DrawElementsUShort9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (171443|0);
}
function __ZNK3osg18DrawElementsUShort14getDataPointerEv($0) {
 $0 = $0|0;
 var $$phitmp = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 68|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 72|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2|0)==($4|0);
 $$phitmp = $5 ? 0 : $2;
 return ($$phitmp|0);
}
function __ZNK3osg18DrawElementsUShort16getTotalDataSizeEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 68|0);
 $2 = ((($0)) + 72|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$1>>2]|0;
 $5 = (($3) - ($4))|0;
 return ($5|0);
}
function __ZNK3osg18DrawElementsUShort20supportsBufferObjectEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function __ZNK3osg18DrawElementsUShort4drawERNS_5StateEb($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$ = 0, $$$ = 0, $$pre$i = 0, $$pre$phi$iZ2D = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 60|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(9);
 $$ = $5 ? 6 : $4;
 $6 = ($$|0)==(8);
 $$$ = $6 ? 5 : $$;
 if (!($2)) {
  $74 = ((($0)) + 56|0);
  $75 = HEAP32[$74>>2]|0;
  $76 = ($75|0)>(0);
  $77 = ((($0)) + 68|0);
  $78 = ((($0)) + 72|0);
  $79 = HEAP32[$78>>2]|0;
  $80 = HEAP32[$77>>2]|0;
  $81 = (($79) - ($80))|0;
  $82 = $81 >> 1;
  $83 = $80;
  if (!($76)) {
   _glDrawElements(($$$|0),($82|0),5123,($83|0));
   return;
  }
  $84 = ((($1)) + 780|0);
  $85 = HEAP32[$84>>2]|0;
  $86 = ($85|0)==(0|0);
  if ($86) {
   _glDrawElements(($$$|0),($82|0),5123,($83|0));
   return;
  } else {
   FUNCTION_TABLE_viiiii[$85 & 8191]($$$,$82,5123,$83,$75);
   return;
  }
 }
 $7 = ((($0)) + 40|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if ($9) {
  $10 = ((($1)) + 132|0);
  $11 = HEAP32[$10>>2]|0;
  $54 = $11;
 } else {
  $12 = ((($1)) + 124|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (__ZNK3osg12BufferObject25getOrCreateGLBufferObjectEj($8,$13)|0);
  $15 = ($14|0)==(0|0);
  $16 = ((($1)) + 132|0);
  $17 = HEAP32[$16>>2]|0;
  if ($15) {
   $54 = $17;
  } else {
   $18 = ((($14)) + 36|0);
   $19 = HEAP8[$18>>0]|0;
   $20 = ($19<<24>>24)==(0);
   if ($20) {
    $21 = ((($17)) + 100|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = ($22|0)==($14|0);
    if (!($23)) {
     $24 = ((($14)) + 72|0);
     $25 = HEAP32[$24>>2]|0;
     $26 = ((($25)) + 724|0);
     $27 = HEAP32[$26>>2]|0;
     $28 = ((($14)) + 20|0);
     $29 = HEAP32[$28>>2]|0;
     $30 = ((($14)) + 16|0);
     $31 = HEAP32[$30>>2]|0;
     FUNCTION_TABLE_vii[$27 & 8191]($29,$31);
     $32 = ((($14)) + 56|0);
     $33 = HEAP32[$32>>2]|0;
     $34 = ($33|0)==(0|0);
     if ($34) {
      $$pre$phi$iZ2D = $21;
      label = 10;
     } else {
      __ZN3osg17GLBufferObjectSet10moveToBackEPNS_14GLBufferObjectE($33,$14);
      $$pre$phi$iZ2D = $21;
      label = 10;
     }
    }
   } else {
    __ZN3osg14GLBufferObject13compileBufferEv($14);
    $$pre$i = ((($17)) + 100|0);
    $$pre$phi$iZ2D = $$pre$i;
    label = 10;
   }
   if ((label|0) == 10) {
    HEAP32[$$pre$phi$iZ2D>>2] = $14;
   }
   $35 = ((($0)) + 56|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = ($36|0)>(0);
   $38 = ((($0)) + 68|0);
   $39 = ((($0)) + 72|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = HEAP32[$38>>2]|0;
   $42 = (($40) - ($41))|0;
   $43 = $42 >> 1;
   $44 = ((($0)) + 36|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = ((($14)) + 40|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = (((($47) + (($45*20)|0)|0)) + 12|0);
   $49 = HEAP32[$48>>2]|0;
   if (!($37)) {
    _glDrawElements(($$$|0),($43|0),5123,($49|0));
    return;
   }
   $50 = ((($1)) + 780|0);
   $51 = HEAP32[$50>>2]|0;
   $52 = ($51|0)==(0|0);
   if ($52) {
    _glDrawElements(($$$|0),($43|0),5123,($49|0));
    return;
   } else {
    FUNCTION_TABLE_viiiii[$51 & 8191]($$$,$43,5123,$49,$36);
    return;
   }
  }
 }
 $53 = ((($54)) + 100|0);
 $55 = HEAP32[$53>>2]|0;
 $56 = ($55|0)==(0|0);
 if (!($56)) {
  $57 = ((($54)) + 16|0);
  $58 = HEAP32[$57>>2]|0;
  $59 = ((($58)) + 724|0);
  $60 = HEAP32[$59>>2]|0;
  FUNCTION_TABLE_vii[$60 & 8191](34963,0);
  HEAP32[$53>>2] = 0;
 }
 $61 = ((($0)) + 56|0);
 $62 = HEAP32[$61>>2]|0;
 $63 = ($62|0)>(0);
 $64 = ((($0)) + 68|0);
 $65 = ((($0)) + 72|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = HEAP32[$64>>2]|0;
 $68 = (($66) - ($67))|0;
 $69 = $68 >> 1;
 $70 = $67;
 if (!($63)) {
  _glDrawElements(($$$|0),($69|0),5123,($70|0));
  return;
 }
 $71 = ((($1)) + 780|0);
 $72 = HEAP32[$71>>2]|0;
 $73 = ($72|0)==(0|0);
 if ($73) {
  _glDrawElements(($$$|0),($69|0),5123,($70|0));
  return;
 } else {
  FUNCTION_TABLE_viiiii[$72 & 8191]($$$,$69,5123,$70,$62);
  return;
 }
}
function __ZNK3osg18DrawElementsUShort6acceptERNS_16PrimitiveFunctorE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 68|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 72|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if ($6) {
  return;
 }
 $7 = $3;
 $8 = $5;
 $9 = HEAP32[$1>>2]|0;
 $10 = ((($9)) + 40|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($0)) + 60|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($8) - ($7))|0;
 $15 = $14 >> 1;
 FUNCTION_TABLE_viiii[$11 & 8191]($1,$13,$15,$3);
 return;
}
function __ZNK3osg18DrawElementsUShort6acceptERNS_21PrimitiveIndexFunctorE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 68|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 72|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if ($6) {
  return;
 }
 $7 = $3;
 $8 = $5;
 $9 = HEAP32[$1>>2]|0;
 $10 = ((($9)) + 40|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($0)) + 60|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($8) - ($7))|0;
 $15 = $14 >> 1;
 FUNCTION_TABLE_viiii[$11 & 8191]($1,$13,$15,$3);
 return;
}
function __ZNK3osg18DrawElementsUShort5indexEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 68|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + ($1<<1)|0);
 $5 = HEAP16[$4>>1]|0;
 $6 = $5&65535;
 return ($6|0);
}
function __ZNK3osg18DrawElementsUShort13getNumIndicesEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 68|0);
 $2 = ((($0)) + 72|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$1>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 1;
 return ($6|0);
}
function __ZN3osg18DrawElementsUShort13offsetIndicesEi($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$sroa$02$06 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 68|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 72|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if ($6) {
  return;
 } else {
  $$sroa$02$06 = $3;
 }
 while(1) {
  $7 = HEAP16[$$sroa$02$06>>1]|0;
  $8 = $7&65535;
  $9 = (($8) + ($1))|0;
  $10 = $9&65535;
  HEAP16[$$sroa$02$06>>1] = $10;
  $11 = ((($$sroa$02$06)) + 2|0);
  $12 = ($11|0)==($5|0);
  if ($12) {
   break;
  } else {
   $$sroa$02$06 = $11;
  }
 }
 return;
}
function __ZN3osg18DrawElementsUShort11getDataTypeEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 5123;
}
function __ZN3osg18DrawElementsUShort14resizeElementsEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i = 0;
 var $scevgep5$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 HEAP16[$2>>1] = 0;
 $3 = ((($0)) + 68|0);
 $4 = ((($0)) + 72|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$3>>2]|0;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 1;
 $9 = ($8>>>0)<($1>>>0);
 $10 = $6;
 $11 = $5;
 if ($9) {
  $12 = (($1) - ($8))|0;
  __ZNSt3__26vectorItNS_9allocatorItEEE8__appendEjRKt($3,$12,$2);
  STACKTOP = sp;return;
 }
 $13 = ($8>>>0)>($1>>>0);
 if (!($13)) {
  STACKTOP = sp;return;
 }
 $14 = (($10) + ($1<<1)|0);
 $15 = ($11|0)==($14|0);
 if ($15) {
  STACKTOP = sp;return;
 }
 $scevgep$i$i$i$i = ((($11)) + -2|0);
 $16 = $scevgep$i$i$i$i;
 $17 = $14;
 $18 = (($16) - ($17))|0;
 $19 = $18 >>> 1;
 $20 = $19 ^ -1;
 $scevgep5$i$i$i$i = (($11) + ($20<<1)|0);
 HEAP32[$4>>2] = $scevgep5$i$i$i$i;
 STACKTOP = sp;return;
}
function __ZN3osg18DrawElementsUShort15reserveElementsEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 68|0);
 __ZNSt3__26vectorItNS_9allocatorItEEE7reserveEj($2,$1);
 return;
}
function __ZN3osg18DrawElementsUShort10setElementEjj($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = $2&65535;
 $4 = ((($0)) + 68|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + ($1<<1)|0);
 HEAP16[$6>>1] = $3;
 return;
}
function __ZN3osg18DrawElementsUShort10getElementEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 68|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + ($1<<1)|0);
 $5 = HEAP16[$4>>1]|0;
 $6 = $5&65535;
 return ($6|0);
}
function __ZN3osg18DrawElementsUShort10addElementEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = $1&65535;
 HEAP16[$2>>1] = $3;
 $4 = ((($0)) + 72|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($0)) + 76|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5|0)==($7|0);
 if ($8) {
  $10 = ((($0)) + 68|0);
  __ZNSt3__26vectorItNS_9allocatorItEEE21__push_back_slow_pathIKtEEvRT_($10,$2);
  STACKTOP = sp;return;
 } else {
  HEAP16[$5>>1] = $3;
  $9 = ((($5)) + 2|0);
  HEAP32[$4>>2] = $9;
  STACKTOP = sp;return;
 }
}
function __ZThn64_N3osg18DrawElementsUShortD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -64|0);
 __ZN3osg18DrawElementsUShortD2Ev($1);
 return;
}
function __ZThn64_N3osg18DrawElementsUShortD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -64|0);
 __THREW__ = 0;
 invoke_vi(2116,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch_2()|0;
  $5 = tempRet0;
  __ZdlPv($1);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZdlPv($1);
  return;
 }
}
function __ZN3osg16DrawElementsUIntD2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i$i$i3 = 0, $scevgep5$i$i$i$i = 0, $scevgep5$i$i$i$i4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (64580);
 $1 = ((($0)) + 64|0);
 HEAP32[$1>>2] = (64828);
 __THREW__ = 0;
 invoke_vii(322,($0|0),(0|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  HEAP32[$1>>2] = (52520);
  $4 = ((($0)) + 68|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0|0);
  if ($6) {
   __ZN3osg10BufferDataD2Ev($0);
   return;
  }
  $7 = ((($0)) + 72|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)==($5|0);
  if (!($9)) {
   $scevgep$i$i$i$i = ((($8)) + -4|0);
   $10 = $scevgep$i$i$i$i;
   $11 = $5;
   $12 = (($10) - ($11))|0;
   $13 = $12 >>> 2;
   $14 = $13 ^ -1;
   $scevgep5$i$i$i$i = (($8) + ($14<<2)|0);
   HEAP32[$7>>2] = $scevgep5$i$i$i$i;
  }
  __ZdlPv($5);
  __ZN3osg10BufferDataD2Ev($0);
  return;
 }
 $15 = ___cxa_find_matching_catch_2()|0;
 $16 = tempRet0;
 HEAP32[$1>>2] = (52520);
 $17 = ((($0)) + 68|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ($18|0)==(0|0);
 if (!($19)) {
  $20 = ((($0)) + 72|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = ($21|0)==($18|0);
  if (!($22)) {
   $scevgep$i$i$i$i3 = ((($21)) + -4|0);
   $23 = $scevgep$i$i$i$i3;
   $24 = $18;
   $25 = (($23) - ($24))|0;
   $26 = $25 >>> 2;
   $27 = $26 ^ -1;
   $scevgep5$i$i$i$i4 = (($21) + ($27<<2)|0);
   HEAP32[$20>>2] = $scevgep5$i$i$i$i4;
  }
  __ZdlPv($18);
 }
 __THREW__ = 0;
 invoke_vi(1265,($0|0));
 $28 = __THREW__; __THREW__ = 0;
 $29 = $28&1;
 if ($29) {
  $30 = ___cxa_find_matching_catch_3(0|0)|0;
  $31 = tempRet0;
  ___clang_call_terminate($30);
  // unreachable;
 } else {
  ___resumeException($15|0);
  // unreachable;
 }
}
function __ZN3osg16DrawElementsUIntD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(2140,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK3osg16DrawElementsUInt9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(80)|0);
 __THREW__ = 0;
 invoke_vii(3435,($1|0),1);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $14 = ___cxa_find_matching_catch_2()|0;
  $15 = tempRet0;
  __ZdlPv($1);
  ___resumeException($14|0);
  // unreachable;
 } else {
  $4 = ((($1)) + 12|0);
  ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;
  $5 = ((($1)) + 24|0);
  HEAP32[$5>>2] = 2;
  $6 = ((($1)) + 28|0);
  ;HEAP32[$6>>2]=0|0;HEAP32[$6+4>>2]=0|0;HEAP32[$6+8>>2]=0|0;HEAP32[$6+12>>2]=0|0;HEAP32[$6+16>>2]=0|0;HEAP32[$6+20>>2]=0|0;
  $7 = ((($1)) + 52|0);
  HEAP32[$7>>2] = 5;
  $8 = ((($1)) + 56|0);
  HEAP32[$8>>2] = 0;
  $9 = ((($1)) + 60|0);
  HEAP32[$9>>2] = 0;
  $10 = ((($1)) + 64|0);
  $11 = ((($1)) + 68|0);
  HEAP32[$11>>2] = 0;
  $12 = ((($1)) + 72|0);
  HEAP32[$12>>2] = 0;
  $13 = ((($1)) + 76|0);
  HEAP32[$13>>2] = 0;
  HEAP32[$1>>2] = (64580);
  HEAP32[$10>>2] = (64828);
  return ($1|0);
 }
 return (0)|0;
}
function __ZNK3osg16DrawElementsUInt5cloneERKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0;
 var $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(80)|0);
 __THREW__ = 0;
 invoke_viii(3468,($2|0),($0|0),($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $39 = ___cxa_find_matching_catch_2()|0;
  $40 = tempRet0;
  $eh$lpad$body$index2Z2D = $40;$eh$lpad$body$indexZ2D = $39;
  __ZdlPv($2);
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 HEAP32[$2>>2] = (55116);
 $5 = ((($2)) + 32|0);
 HEAP32[$5>>2] = 0;
 $6 = ((($2)) + 36|0);
 HEAP32[$6>>2] = 0;
 $7 = ((($2)) + 40|0);
 HEAP32[$7>>2] = 0;
 $8 = ((($2)) + 44|0);
 $9 = ((($0)) + 44|0);
 $10 = HEAP32[$9>>2]|0;
 HEAP32[$8>>2] = $10;
 $11 = ($10|0)==(0|0);
 if (!($11)) {
  $12 = HEAP32[$10>>2]|0;
  $13 = ((($12)) + -12|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($10) + ($14)|0);
  $16 = ((($15)) + 8|0);
  $17 = HEAP32[$16>>2]|0;HEAP32[$16>>2] = (($17+1)|0);
 }
 $18 = ((($2)) + 48|0);
 HEAP32[$18>>2] = 0;
 $19 = ((($2)) + 52|0);
 $20 = ((($0)) + 52|0);
 $21 = HEAP32[$20>>2]|0;
 HEAP32[$19>>2] = $21;
 $22 = ((($2)) + 56|0);
 $23 = ((($0)) + 56|0);
 $24 = HEAP32[$23>>2]|0;
 HEAP32[$22>>2] = $24;
 $25 = ((($2)) + 60|0);
 $26 = ((($0)) + 60|0);
 $27 = HEAP32[$26>>2]|0;
 HEAP32[$25>>2] = $27;
 HEAP32[$2>>2] = (52272);
 $28 = ((($2)) + 64|0);
 HEAP32[$28>>2] = (52520);
 $29 = ((($2)) + 68|0);
 $30 = ((($0)) + 68|0);
 __THREW__ = 0;
 invoke_vii(3317,($29|0),($30|0));
 $31 = __THREW__; __THREW__ = 0;
 $32 = $31&1;
 if (!($32)) {
  HEAP32[$2>>2] = (64580);
  HEAP32[$28>>2] = (64828);
  return ($2|0);
 }
 $33 = ___cxa_find_matching_catch_2()|0;
 $34 = tempRet0;
 __THREW__ = 0;
 invoke_vi(1265,($2|0));
 $35 = __THREW__; __THREW__ = 0;
 $36 = $35&1;
 if ($36) {
  $37 = ___cxa_find_matching_catch_3(0|0)|0;
  $38 = tempRet0;
  ___clang_call_terminate($37);
  // unreachable;
 } else {
  $eh$lpad$body$index2Z2D = $34;$eh$lpad$body$indexZ2D = $33;
  __ZdlPv($2);
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 return (0)|0;
}
function __ZNK3osg16DrawElementsUInt12isSameKindAsEPKNS_6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,26328,0)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK3osg16DrawElementsUInt11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175113|0);
}
function __ZNK3osg16DrawElementsUInt9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (171462|0);
}
function __ZNK3osg16DrawElementsUInt14getDataPointerEv($0) {
 $0 = $0|0;
 var $$phitmp = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 68|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 72|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2|0)==($4|0);
 $$phitmp = $5 ? 0 : $2;
 return ($$phitmp|0);
}
function __ZNK3osg16DrawElementsUInt16getTotalDataSizeEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 68|0);
 $2 = ((($0)) + 72|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$1>>2]|0;
 $5 = (($3) - ($4))|0;
 return ($5|0);
}
function __ZNK3osg16DrawElementsUInt20supportsBufferObjectEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function __ZNK3osg16DrawElementsUInt4drawERNS_5StateEb($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$ = 0, $$$ = 0, $$pre$i = 0, $$pre$phi$iZ2D = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 60|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(9);
 $$ = $5 ? 6 : $4;
 $6 = ($$|0)==(8);
 $$$ = $6 ? 5 : $$;
 if (!($2)) {
  $74 = ((($0)) + 56|0);
  $75 = HEAP32[$74>>2]|0;
  $76 = ($75|0)>(0);
  $77 = ((($0)) + 68|0);
  $78 = ((($0)) + 72|0);
  $79 = HEAP32[$78>>2]|0;
  $80 = HEAP32[$77>>2]|0;
  $81 = (($79) - ($80))|0;
  $82 = $81 >> 2;
  $83 = $80;
  if (!($76)) {
   _glDrawElements(($$$|0),($82|0),5125,($83|0));
   return;
  }
  $84 = ((($1)) + 780|0);
  $85 = HEAP32[$84>>2]|0;
  $86 = ($85|0)==(0|0);
  if ($86) {
   _glDrawElements(($$$|0),($82|0),5125,($83|0));
   return;
  } else {
   FUNCTION_TABLE_viiiii[$85 & 8191]($$$,$82,5125,$83,$75);
   return;
  }
 }
 $7 = ((($0)) + 40|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if ($9) {
  $10 = ((($1)) + 132|0);
  $11 = HEAP32[$10>>2]|0;
  $54 = $11;
 } else {
  $12 = ((($1)) + 124|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (__ZNK3osg12BufferObject25getOrCreateGLBufferObjectEj($8,$13)|0);
  $15 = ($14|0)==(0|0);
  $16 = ((($1)) + 132|0);
  $17 = HEAP32[$16>>2]|0;
  if ($15) {
   $54 = $17;
  } else {
   $18 = ((($14)) + 36|0);
   $19 = HEAP8[$18>>0]|0;
   $20 = ($19<<24>>24)==(0);
   if ($20) {
    $21 = ((($17)) + 100|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = ($22|0)==($14|0);
    if (!($23)) {
     $24 = ((($14)) + 72|0);
     $25 = HEAP32[$24>>2]|0;
     $26 = ((($25)) + 724|0);
     $27 = HEAP32[$26>>2]|0;
     $28 = ((($14)) + 20|0);
     $29 = HEAP32[$28>>2]|0;
     $30 = ((($14)) + 16|0);
     $31 = HEAP32[$30>>2]|0;
     FUNCTION_TABLE_vii[$27 & 8191]($29,$31);
     $32 = ((($14)) + 56|0);
     $33 = HEAP32[$32>>2]|0;
     $34 = ($33|0)==(0|0);
     if ($34) {
      $$pre$phi$iZ2D = $21;
      label = 10;
     } else {
      __ZN3osg17GLBufferObjectSet10moveToBackEPNS_14GLBufferObjectE($33,$14);
      $$pre$phi$iZ2D = $21;
      label = 10;
     }
    }
   } else {
    __ZN3osg14GLBufferObject13compileBufferEv($14);
    $$pre$i = ((($17)) + 100|0);
    $$pre$phi$iZ2D = $$pre$i;
    label = 10;
   }
   if ((label|0) == 10) {
    HEAP32[$$pre$phi$iZ2D>>2] = $14;
   }
   $35 = ((($0)) + 56|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = ($36|0)>(0);
   $38 = ((($0)) + 68|0);
   $39 = ((($0)) + 72|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = HEAP32[$38>>2]|0;
   $42 = (($40) - ($41))|0;
   $43 = $42 >> 2;
   $44 = ((($0)) + 36|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = ((($14)) + 40|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = (((($47) + (($45*20)|0)|0)) + 12|0);
   $49 = HEAP32[$48>>2]|0;
   if (!($37)) {
    _glDrawElements(($$$|0),($43|0),5125,($49|0));
    return;
   }
   $50 = ((($1)) + 780|0);
   $51 = HEAP32[$50>>2]|0;
   $52 = ($51|0)==(0|0);
   if ($52) {
    _glDrawElements(($$$|0),($43|0),5125,($49|0));
    return;
   } else {
    FUNCTION_TABLE_viiiii[$51 & 8191]($$$,$43,5125,$49,$36);
    return;
   }
  }
 }
 $53 = ((($54)) + 100|0);
 $55 = HEAP32[$53>>2]|0;
 $56 = ($55|0)==(0|0);
 if (!($56)) {
  $57 = ((($54)) + 16|0);
  $58 = HEAP32[$57>>2]|0;
  $59 = ((($58)) + 724|0);
  $60 = HEAP32[$59>>2]|0;
  FUNCTION_TABLE_vii[$60 & 8191](34963,0);
  HEAP32[$53>>2] = 0;
 }
 $61 = ((($0)) + 56|0);
 $62 = HEAP32[$61>>2]|0;
 $63 = ($62|0)>(0);
 $64 = ((($0)) + 68|0);
 $65 = ((($0)) + 72|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = HEAP32[$64>>2]|0;
 $68 = (($66) - ($67))|0;
 $69 = $68 >> 2;
 $70 = $67;
 if (!($63)) {
  _glDrawElements(($$$|0),($69|0),5125,($70|0));
  return;
 }
 $71 = ((($1)) + 780|0);
 $72 = HEAP32[$71>>2]|0;
 $73 = ($72|0)==(0|0);
 if ($73) {
  _glDrawElements(($$$|0),($69|0),5125,($70|0));
  return;
 } else {
  FUNCTION_TABLE_viiiii[$72 & 8191]($$$,$69,5125,$70,$62);
  return;
 }
}
function __ZNK3osg16DrawElementsUInt6acceptERNS_16PrimitiveFunctorE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 68|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 72|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if ($6) {
  return;
 }
 $7 = $3;
 $8 = $5;
 $9 = HEAP32[$1>>2]|0;
 $10 = ((($9)) + 44|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($0)) + 60|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($8) - ($7))|0;
 $15 = $14 >> 2;
 FUNCTION_TABLE_viiii[$11 & 8191]($1,$13,$15,$3);
 return;
}
function __ZNK3osg16DrawElementsUInt6acceptERNS_21PrimitiveIndexFunctorE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 68|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 72|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if ($6) {
  return;
 }
 $7 = $3;
 $8 = $5;
 $9 = HEAP32[$1>>2]|0;
 $10 = ((($9)) + 44|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($0)) + 60|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($8) - ($7))|0;
 $15 = $14 >> 2;
 FUNCTION_TABLE_viiii[$11 & 8191]($1,$13,$15,$3);
 return;
}
function __ZNK3osg16DrawElementsUInt5indexEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 68|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + ($1<<2)|0);
 $5 = HEAP32[$4>>2]|0;
 return ($5|0);
}
function __ZNK3osg16DrawElementsUInt13getNumIndicesEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 68|0);
 $2 = ((($0)) + 72|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$1>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 return ($6|0);
}
function __ZN3osg16DrawElementsUInt13offsetIndicesEi($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$sroa$02$06 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 68|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 72|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if ($6) {
  return;
 } else {
  $$sroa$02$06 = $3;
 }
 while(1) {
  $7 = HEAP32[$$sroa$02$06>>2]|0;
  $8 = (($7) + ($1))|0;
  HEAP32[$$sroa$02$06>>2] = $8;
  $9 = ((($$sroa$02$06)) + 4|0);
  $10 = ($9|0)==($5|0);
  if ($10) {
   break;
  } else {
   $$sroa$02$06 = $9;
  }
 }
 return;
}
function __ZN3osg16DrawElementsUInt11getDataTypeEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 5125;
}
function __ZN3osg16DrawElementsUInt14resizeElementsEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i = 0;
 var $scevgep5$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 HEAP32[$2>>2] = 0;
 $3 = ((($0)) + 68|0);
 $4 = ((($0)) + 72|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$3>>2]|0;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 2;
 $9 = ($8>>>0)<($1>>>0);
 $10 = $6;
 $11 = $5;
 if ($9) {
  $12 = (($1) - ($8))|0;
  __ZNSt3__26vectorIjNS_9allocatorIjEEE8__appendEjRKj($3,$12,$2);
  STACKTOP = sp;return;
 }
 $13 = ($8>>>0)>($1>>>0);
 if (!($13)) {
  STACKTOP = sp;return;
 }
 $14 = (($10) + ($1<<2)|0);
 $15 = ($11|0)==($14|0);
 if ($15) {
  STACKTOP = sp;return;
 }
 $scevgep$i$i$i$i = ((($11)) + -4|0);
 $16 = $scevgep$i$i$i$i;
 $17 = $14;
 $18 = (($16) - ($17))|0;
 $19 = $18 >>> 2;
 $20 = $19 ^ -1;
 $scevgep5$i$i$i$i = (($11) + ($20<<2)|0);
 HEAP32[$4>>2] = $scevgep5$i$i$i$i;
 STACKTOP = sp;return;
}
function __ZN3osg16DrawElementsUInt15reserveElementsEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 68|0);
 __ZNSt3__26vectorIjNS_9allocatorIjEEE7reserveEj($2,$1);
 return;
}
function __ZN3osg16DrawElementsUInt10setElementEjj($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 68|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + ($1<<2)|0);
 HEAP32[$5>>2] = $2;
 return;
}
function __ZN3osg16DrawElementsUInt10getElementEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 68|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + ($1<<2)|0);
 $5 = HEAP32[$4>>2]|0;
 return ($5|0);
}
function __ZN3osg16DrawElementsUInt10addElementEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 HEAP32[$2>>2] = $1;
 $3 = ((($0)) + 72|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 76|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4|0)==($6|0);
 if ($7) {
  $9 = ((($0)) + 68|0);
  __ZNSt3__26vectorIjNS_9allocatorIjEEE21__push_back_slow_pathIKjEEvRT_($9,$2);
  STACKTOP = sp;return;
 } else {
  HEAP32[$4>>2] = $1;
  $8 = ((($4)) + 4|0);
  HEAP32[$3>>2] = $8;
  STACKTOP = sp;return;
 }
}
function __ZThn64_N3osg16DrawElementsUIntD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -64|0);
 __ZN3osg16DrawElementsUIntD2Ev($1);
 return;
}
function __ZThn64_N3osg16DrawElementsUIntD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -64|0);
 __THREW__ = 0;
 invoke_vi(2140,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch_2()|0;
  $5 = tempRet0;
  __ZdlPv($1);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZdlPv($1);
  return;
 }
}
function __ZN3osg12PrimitiveSet15getDrawElementsEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZNK3osg12PrimitiveSet15getDrawElementsEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function __ZN3osg10DrawArraysD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1265,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK3osg10DrawArrays9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(72)|0);
 __THREW__ = 0;
 invoke_vii(3435,($1|0),1);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $12 = ___cxa_find_matching_catch_2()|0;
  $13 = tempRet0;
  __ZdlPv($1);
  ___resumeException($12|0);
  // unreachable;
 } else {
  $4 = ((($1)) + 12|0);
  ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;
  $5 = ((($1)) + 24|0);
  HEAP32[$5>>2] = 2;
  $6 = ((($1)) + 28|0);
  ;HEAP32[$6>>2]=0|0;HEAP32[$6+4>>2]=0|0;HEAP32[$6+8>>2]=0|0;HEAP32[$6+12>>2]=0|0;HEAP32[$6+16>>2]=0|0;HEAP32[$6+20>>2]=0|0;
  $7 = ((($1)) + 52|0);
  HEAP32[$7>>2] = 1;
  $8 = ((($1)) + 56|0);
  HEAP32[$8>>2] = 0;
  $9 = ((($1)) + 60|0);
  HEAP32[$9>>2] = 0;
  HEAP32[$1>>2] = (64844);
  $10 = ((($1)) + 64|0);
  HEAP32[$10>>2] = 0;
  $11 = ((($1)) + 68|0);
  HEAP32[$11>>2] = 0;
  return ($1|0);
 }
 return (0)|0;
}
function __ZNK3osg10DrawArrays5cloneERKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(72)|0);
 __THREW__ = 0;
 invoke_viii(3468,($2|0),($0|0),($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $34 = ___cxa_find_matching_catch_2()|0;
  $35 = tempRet0;
  __ZdlPv($2);
  ___resumeException($34|0);
  // unreachable;
 }
 HEAP32[$2>>2] = (55116);
 $5 = ((($2)) + 32|0);
 HEAP32[$5>>2] = 0;
 $6 = ((($2)) + 36|0);
 HEAP32[$6>>2] = 0;
 $7 = ((($2)) + 40|0);
 HEAP32[$7>>2] = 0;
 $8 = ((($2)) + 44|0);
 $9 = ((($0)) + 44|0);
 $10 = HEAP32[$9>>2]|0;
 HEAP32[$8>>2] = $10;
 $11 = ($10|0)==(0|0);
 if (!($11)) {
  $12 = HEAP32[$10>>2]|0;
  $13 = ((($12)) + -12|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($10) + ($14)|0);
  $16 = ((($15)) + 8|0);
  $17 = HEAP32[$16>>2]|0;HEAP32[$16>>2] = (($17+1)|0);
 }
 $18 = ((($2)) + 48|0);
 HEAP32[$18>>2] = 0;
 $19 = ((($2)) + 52|0);
 $20 = ((($0)) + 52|0);
 $21 = HEAP32[$20>>2]|0;
 HEAP32[$19>>2] = $21;
 $22 = ((($2)) + 56|0);
 $23 = ((($0)) + 56|0);
 $24 = HEAP32[$23>>2]|0;
 HEAP32[$22>>2] = $24;
 $25 = ((($2)) + 60|0);
 $26 = ((($0)) + 60|0);
 $27 = HEAP32[$26>>2]|0;
 HEAP32[$25>>2] = $27;
 HEAP32[$2>>2] = (64844);
 $28 = ((($2)) + 64|0);
 $29 = ((($0)) + 64|0);
 $30 = HEAP32[$29>>2]|0;
 HEAP32[$28>>2] = $30;
 $31 = ((($2)) + 68|0);
 $32 = ((($0)) + 68|0);
 $33 = HEAP32[$32>>2]|0;
 HEAP32[$31>>2] = $33;
 return ($2|0);
}
function __ZNK3osg10DrawArrays12isSameKindAsEPKNS_6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,26376,0)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK3osg10DrawArrays11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175113|0);
}
function __ZNK3osg10DrawArrays9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (171397|0);
}
function __ZNK3osg10DrawArrays4drawERNS_5StateEb($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 60|0);
 $4 = HEAP32[$3>>2]|0;
 switch ($4|0) {
 case 7:  {
  $5 = ((($0)) + 64|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ((($0)) + 68|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ((($0)) + 56|0);
  $10 = HEAP32[$9>>2]|0;
  __ZN3osg5State9drawQuadsEiii($1,$6,$8,$10);
  return;
  break;
 }
 case 9:  {
  $$0 = 6;
  break;
 }
 case 8:  {
  $$0 = 5;
  break;
 }
 default: {
  $$0 = $4;
 }
 }
 $11 = ((($0)) + 56|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)>(0);
 $14 = ((($0)) + 68|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ((($0)) + 64|0);
 $17 = HEAP32[$16>>2]|0;
 if (!($13)) {
  _glDrawArrays(($$0|0),($17|0),($15|0));
  return;
 }
 $18 = ((($1)) + 776|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)==(0|0);
 if ($20) {
  _glDrawArrays(($$0|0),($17|0),($15|0));
  return;
 } else {
  FUNCTION_TABLE_viiii[$19 & 8191]($$0,$17,$15,$12);
  return;
 }
}
function __ZNK3osg10DrawArrays6acceptERNS_16PrimitiveFunctorE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 32|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 60|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($0)) + 64|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($0)) + 68|0);
 $10 = HEAP32[$9>>2]|0;
 FUNCTION_TABLE_viiii[$4 & 8191]($1,$6,$8,$10);
 return;
}
function __ZNK3osg10DrawArrays6acceptERNS_21PrimitiveIndexFunctorE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 32|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 60|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($0)) + 64|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($0)) + 68|0);
 $10 = HEAP32[$9>>2]|0;
 FUNCTION_TABLE_viiii[$4 & 8191]($1,$6,$8,$10);
 return;
}
function __ZNK3osg10DrawArrays5indexEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 64|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + ($1))|0;
 return ($4|0);
}
function __ZNK3osg10DrawArrays13getNumIndicesEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 68|0);
 $2 = HEAP32[$1>>2]|0;
 return ($2|0);
}
function __ZN3osg10DrawArrays13offsetIndicesEi($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 64|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + ($1))|0;
 HEAP32[$2>>2] = $4;
 return;
}
function __ZN3osg7Program21setThreadSafeRefUnrefEb($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$07 = 0, $$pre = 0, $$pre8 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg6Object21setThreadSafeRefUnrefEb($0,$1);
 $2 = ((($0)) + 104|0);
 $3 = ((($0)) + 108|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$2>>2]|0;
 $6 = ($4|0)==($5|0);
 if ($6) {
  return;
 } else {
  $$07 = 0;$20 = $4;$7 = $5;
 }
 while(1) {
  $8 = $7;
  $9 = (($8) + ($$07<<2)|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10|0)==(0|0);
  if ($11) {
   $16 = $7;$17 = $20;
  } else {
   $12 = HEAP32[$10>>2]|0;
   $13 = HEAP32[$12>>2]|0;
   FUNCTION_TABLE_vii[$13 & 8191]($10,$1);
   $$pre = HEAP32[$3>>2]|0;
   $$pre8 = HEAP32[$2>>2]|0;
   $16 = $$pre8;$17 = $$pre;
  }
  $14 = (($$07) + 1)|0;
  $15 = (($17) - ($16))|0;
  $18 = $15 >> 2;
  $19 = ($14>>>0)<($18>>>0);
  if ($19) {
   $$07 = $14;$20 = $17;$7 = $16;
  } else {
   break;
  }
 }
 return;
}
function __ZN3osg7ProgramD2Ev($0) {
 $0 = $0|0;
 var $$01544 = 0, $$2 = 0, $$29 = 0, $$in = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i$i$i = 0, $$pre$i$i$i28 = 0, $$pre$i$i22 = 0, $$pre$i18 = 0, $$pre$i30 = 0, $$pre$i39 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0;
 var $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (65068);
 $1 = ((($0)) + 104|0);
 $2 = ((($0)) + 108|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$1>>2]|0;
 $5 = ($3|0)==($4|0);
 L1: do {
  if ($5) {
   label = 4;
  } else {
   $$01544 = 0;$$in = $4;
   while(1) {
    $6 = $$in;
    $7 = (($6) + ($$01544<<2)|0);
    $8 = HEAP32[$7>>2]|0;
    __THREW__ = 0;
    (invoke_iii(3850,($8|0),($0|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = (($$01544) + 1)|0;
    $12 = HEAP32[$2>>2]|0;
    $13 = HEAP32[$1>>2]|0;
    $14 = (($12) - ($13))|0;
    $15 = $14 >> 2;
    $16 = ($11>>>0)<($15>>>0);
    if ($16) {
     $$01544 = $11;$$in = $13;
    } else {
     label = 4;
     break L1;
    }
   }
   $90 = ___cxa_find_matching_catch_2()|0;
   $91 = tempRet0;
   $92 = ((($0)) + 160|0);
   $93 = ((($0)) + 164|0);
   $94 = HEAP32[$93>>2]|0;
   __ZNSt3__26__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EENS4_IS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($92,$94);
   $95 = ((($0)) + 148|0);
   $96 = HEAP32[$95>>2]|0;
   $97 = ($96|0)==(0|0);
   if (!($97)) {
    $98 = ((($0)) + 152|0);
    $99 = HEAP32[$98>>2]|0;
    $100 = ($99|0)==($96|0);
    if ($100) {
     $109 = $96;
    } else {
     $102 = $99;
     while(1) {
      $101 = ((($102)) + -12|0);
      HEAP32[$98>>2] = $101;
      $103 = ((($101)) + 11|0);
      $104 = HEAP8[$103>>0]|0;
      $105 = ($104<<24>>24)<(0);
      if ($105) {
       $108 = HEAP32[$101>>2]|0;
       __ZdlPv($108);
       $$pre$i$i$i28 = HEAP32[$98>>2]|0;
       $106 = $$pre$i$i$i28;
      } else {
       $106 = $101;
      }
      $107 = ($106|0)==($96|0);
      if ($107) {
       break;
      } else {
       $102 = $106;
      }
     }
     $$pre$i30 = HEAP32[$95>>2]|0;
     $109 = $$pre$i30;
    }
    __ZdlPv($109);
   }
   $112 = ((($0)) + 116|0);
   $113 = HEAP32[$112>>2]|0;
   $114 = ($113|0)==(0|0);
   if (!($114)) {
    $115 = ((($113)) + 8|0);
    $116 = HEAP32[$115>>2]|0;HEAP32[$115>>2] = (($116-1)|0);
    $117 = ($116|0)==(1);
    if ($117) {
     __THREW__ = 0;
     invoke_viii(3262,($113|0),1,1);
     $118 = __THREW__; __THREW__ = 0;
     $119 = $118&1;
     if ($119) {
      $169 = ___cxa_find_matching_catch_3(0|0)|0;
      $170 = tempRet0;
      ___clang_call_terminate($169);
      // unreachable;
     }
    }
   }
   HEAP32[$112>>2] = 0;
   $$2 = $91;$$29 = $90;
  }
 } while(0);
 do {
  if ((label|0) == 4) {
   $17 = ((($0)) + 160|0);
   $18 = ((($0)) + 164|0);
   $19 = HEAP32[$18>>2]|0;
   __ZNSt3__26__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EENS4_IS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($17,$19);
   $20 = ((($0)) + 148|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = ($21|0)==(0|0);
   if (!($22)) {
    $23 = ((($0)) + 152|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = ($24|0)==($21|0);
    if ($25) {
     $34 = $21;
    } else {
     $27 = $24;
     while(1) {
      $26 = ((($27)) + -12|0);
      HEAP32[$23>>2] = $26;
      $28 = ((($26)) + 11|0);
      $29 = HEAP8[$28>>0]|0;
      $30 = ($29<<24>>24)<(0);
      if ($30) {
       $33 = HEAP32[$26>>2]|0;
       __ZdlPv($33);
       $$pre$i$i$i = HEAP32[$23>>2]|0;
       $31 = $$pre$i$i$i;
      } else {
       $31 = $26;
      }
      $32 = ($31|0)==($21|0);
      if ($32) {
       break;
      } else {
       $27 = $31;
      }
     }
     $$pre$i = HEAP32[$20>>2]|0;
     $34 = $$pre$i;
    }
    __ZdlPv($34);
   }
   $35 = ((($0)) + 116|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = ($36|0)==(0|0);
   if (!($37)) {
    $38 = ((($36)) + 8|0);
    $39 = HEAP32[$38>>2]|0;HEAP32[$38>>2] = (($39-1)|0);
    $40 = ($39|0)==(1);
    if ($40) {
     __THREW__ = 0;
     invoke_viii(3262,($36|0),1,1);
     $41 = __THREW__; __THREW__ = 0;
     $42 = $41&1;
     if ($42) {
      $110 = ___cxa_find_matching_catch_2()|0;
      $111 = tempRet0;
      $$2 = $111;$$29 = $110;
      break;
     }
    }
   }
   HEAP32[$35>>2] = 0;
   $43 = HEAP32[$1>>2]|0;
   $44 = ($43|0)==(0|0);
   if (!($44)) {
    $45 = HEAP32[$2>>2]|0;
    $46 = ($45|0)==($43|0);
    do {
     if ($46) {
      $60 = $43;
     } else {
      $48 = $45;
      while(1) {
       $47 = ((($48)) + -4|0);
       HEAP32[$2>>2] = $47;
       $49 = HEAP32[$47>>2]|0;
       $50 = ($49|0)==(0|0);
       if (!($50)) {
        $51 = ((($49)) + 8|0);
        $52 = HEAP32[$51>>2]|0;HEAP32[$51>>2] = (($52-1)|0);
        $53 = ($52|0)==(1);
        if ($53) {
         __THREW__ = 0;
         invoke_viii(3262,($49|0),1,1);
         $54 = __THREW__; __THREW__ = 0;
         $55 = $54&1;
         if ($55) {
          label = 20;
          break;
         }
        }
       }
       HEAP32[$47>>2] = 0;
       $56 = HEAP32[$2>>2]|0;
       $57 = ($56|0)==($43|0);
       if ($57) {
        label = 21;
        break;
       } else {
        $48 = $56;
       }
      }
      if ((label|0) == 20) {
       $58 = ___cxa_find_matching_catch_2()|0;
       $59 = tempRet0;
       ___cxa_call_unexpected(($58|0));
       // unreachable;
      }
      else if ((label|0) == 21) {
       $$pre$i18 = HEAP32[$1>>2]|0;
       $60 = $$pre$i18;
       break;
      }
     }
    } while(0);
    __ZdlPv($60);
   }
   $61 = ((($0)) + 92|0);
   $62 = ((($0)) + 96|0);
   $63 = HEAP32[$62>>2]|0;
   __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEjEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($61,$63);
   $64 = ((($0)) + 80|0);
   $65 = ((($0)) + 84|0);
   $66 = HEAP32[$65>>2]|0;
   __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEjEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($64,$66);
   $67 = ((($0)) + 68|0);
   $68 = ((($0)) + 72|0);
   $69 = HEAP32[$68>>2]|0;
   __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEjEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($67,$69);
   $70 = ((($0)) + 56|0);
   $71 = HEAP32[$70>>2]|0;
   $72 = ($71|0)==(0|0);
   if ($72) {
    __ZN3osg14StateAttributeD2Ev($0);
    return;
   }
   $73 = ((($0)) + 60|0);
   $74 = HEAP32[$73>>2]|0;
   $75 = ($74|0)==($71|0);
   do {
    if ($75) {
     $89 = $71;
    } else {
     $77 = $74;
     while(1) {
      $76 = ((($77)) + -4|0);
      HEAP32[$73>>2] = $76;
      $78 = HEAP32[$76>>2]|0;
      $79 = ($78|0)==(0|0);
      if (!($79)) {
       $80 = ((($78)) + 8|0);
       $81 = HEAP32[$80>>2]|0;HEAP32[$80>>2] = (($81-1)|0);
       $82 = ($81|0)==(1);
       if ($82) {
        __THREW__ = 0;
        invoke_viii(3262,($78|0),1,1);
        $83 = __THREW__; __THREW__ = 0;
        $84 = $83&1;
        if ($84) {
         label = 29;
         break;
        }
       }
      }
      HEAP32[$76>>2] = 0;
      $85 = HEAP32[$73>>2]|0;
      $86 = ($85|0)==($71|0);
      if ($86) {
       label = 30;
       break;
      } else {
       $77 = $85;
      }
     }
     if ((label|0) == 29) {
      $87 = ___cxa_find_matching_catch_2()|0;
      $88 = tempRet0;
      ___cxa_call_unexpected(($87|0));
      // unreachable;
     }
     else if ((label|0) == 30) {
      $$pre$i$i22 = HEAP32[$70>>2]|0;
      $89 = $$pre$i$i22;
      break;
     }
    }
   } while(0);
   __ZdlPv($89);
   __ZN3osg14StateAttributeD2Ev($0);
   return;
  }
 } while(0);
 $120 = HEAP32[$1>>2]|0;
 $121 = ($120|0)==(0|0);
 if (!($121)) {
  $122 = HEAP32[$2>>2]|0;
  $123 = ($122|0)==($120|0);
  do {
   if ($123) {
    $137 = $120;
   } else {
    $125 = $122;
    while(1) {
     $124 = ((($125)) + -4|0);
     HEAP32[$2>>2] = $124;
     $126 = HEAP32[$124>>2]|0;
     $127 = ($126|0)==(0|0);
     if (!($127)) {
      $128 = ((($126)) + 8|0);
      $129 = HEAP32[$128>>2]|0;HEAP32[$128>>2] = (($129-1)|0);
      $130 = ($129|0)==(1);
      if ($130) {
       __THREW__ = 0;
       invoke_viii(3262,($126|0),1,1);
       $131 = __THREW__; __THREW__ = 0;
       $132 = $131&1;
       if ($132) {
        label = 51;
        break;
       }
      }
     }
     HEAP32[$124>>2] = 0;
     $133 = HEAP32[$2>>2]|0;
     $134 = ($133|0)==($120|0);
     if ($134) {
      label = 52;
      break;
     } else {
      $125 = $133;
     }
    }
    if ((label|0) == 51) {
     $135 = ___cxa_find_matching_catch_2()|0;
     $136 = tempRet0;
     ___cxa_call_unexpected(($135|0));
     // unreachable;
    }
    else if ((label|0) == 52) {
     $$pre$i39 = HEAP32[$1>>2]|0;
     $137 = $$pre$i39;
     break;
    }
   }
  } while(0);
  __ZdlPv($137);
 }
 $138 = ((($0)) + 92|0);
 $139 = ((($0)) + 96|0);
 $140 = HEAP32[$139>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEjEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($138,$140);
 $141 = ((($0)) + 80|0);
 $142 = ((($0)) + 84|0);
 $143 = HEAP32[$142>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEjEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($141,$143);
 $144 = ((($0)) + 68|0);
 $145 = ((($0)) + 72|0);
 $146 = HEAP32[$145>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEjEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($144,$146);
 $147 = ((($0)) + 56|0);
 $148 = HEAP32[$147>>2]|0;
 $149 = ($148|0)==(0|0);
 if (!($149)) {
  $150 = ((($0)) + 60|0);
  $151 = HEAP32[$150>>2]|0;
  $152 = ($151|0)==($148|0);
  do {
   if ($152) {
    $166 = $148;
   } else {
    $154 = $151;
    while(1) {
     $153 = ((($154)) + -4|0);
     HEAP32[$150>>2] = $153;
     $155 = HEAP32[$153>>2]|0;
     $156 = ($155|0)==(0|0);
     if (!($156)) {
      $157 = ((($155)) + 8|0);
      $158 = HEAP32[$157>>2]|0;HEAP32[$157>>2] = (($158-1)|0);
      $159 = ($158|0)==(1);
      if ($159) {
       __THREW__ = 0;
       invoke_viii(3262,($155|0),1,1);
       $160 = __THREW__; __THREW__ = 0;
       $161 = $160&1;
       if ($161) {
        label = 60;
        break;
       }
      }
     }
     HEAP32[$153>>2] = 0;
     $162 = HEAP32[$150>>2]|0;
     $163 = ($162|0)==($148|0);
     if ($163) {
      label = 61;
      break;
     } else {
      $154 = $162;
     }
    }
    if ((label|0) == 60) {
     $164 = ___cxa_find_matching_catch_2()|0;
     $165 = tempRet0;
     ___cxa_call_unexpected(($164|0));
     // unreachable;
    }
    else if ((label|0) == 61) {
     $$pre$i$i = HEAP32[$147>>2]|0;
     $166 = $$pre$i$i;
     break;
    }
   }
  } while(0);
  __ZdlPv($166);
 }
 __THREW__ = 0;
 invoke_vi(1573,($0|0));
 $167 = __THREW__; __THREW__ = 0;
 $168 = $167&1;
 if ($168) {
  $169 = ___cxa_find_matching_catch_3(0|0)|0;
  $170 = tempRet0;
  ___clang_call_terminate($169);
  // unreachable;
 } else {
  ___resumeException($$29|0);
  // unreachable;
 }
}
function __ZN3osg7ProgramD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(2179,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK3osg7Program9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(172)|0);
 __THREW__ = 0;
 invoke_vi(3613,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch_2()|0;
  $5 = tempRet0;
  __ZdlPv($1);
  ___resumeException($4|0);
  // unreachable;
 } else {
  return ($1|0);
 }
 return (0)|0;
}
function __ZNK3osg7Program5cloneERKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(172)|0);
 __THREW__ = 0;
 invoke_viii(3851,($2|0),($0|0),($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch_2()|0;
  $6 = tempRet0;
  __ZdlPv($2);
  ___resumeException($5|0);
  // unreachable;
 } else {
  return ($2|0);
 }
 return (0)|0;
}
function __ZNK3osg7Program12isSameKindAsEPKNS_6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,26392,0)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK3osg7Program11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175113|0);
}
function __ZNK3osg7Program9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (146968|0);
}
function __ZN3osg7Program21resizeGLObjectBuffersEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$07 = 0, $$pre = 0, $$pre8 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 104|0);
 $3 = ((($0)) + 108|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$2>>2]|0;
 $6 = ($4|0)==($5|0);
 if (!($6)) {
  $$07 = 0;$22 = $4;$8 = $5;
  while(1) {
   $9 = $8;
   $10 = (($9) + ($$07<<2)|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = ($11|0)==(0|0);
   if ($12) {
    $18 = $8;$19 = $22;
   } else {
    $13 = HEAP32[$11>>2]|0;
    $14 = ((($13)) + 132|0);
    $15 = HEAP32[$14>>2]|0;
    FUNCTION_TABLE_vii[$15 & 8191]($11,$1);
    $$pre = HEAP32[$3>>2]|0;
    $$pre8 = HEAP32[$2>>2]|0;
    $18 = $$pre8;$19 = $$pre;
   }
   $16 = (($$07) + 1)|0;
   $17 = (($19) - ($18))|0;
   $20 = $17 >> 2;
   $21 = ($16>>>0)<($20>>>0);
   if ($21) {
    $$07 = $16;$22 = $19;$8 = $18;
   } else {
    break;
   }
  }
 }
 $7 = ((($0)) + 56|0);
 __ZN3osg14buffered_valueINS_7ref_ptrINS_7Program14ProgramObjectsEEEE6resizeEj($7,$1);
 return;
}
function __ZNK3osg7Program16releaseGLObjectsEPNS_5StateE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$019 = 0, $$02$i$i$i$i$i = 0, $$pre = 0, $$pre20 = 0, $$sroa$01$0$i$i$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 104|0);
 $3 = ((($0)) + 108|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$2>>2]|0;
 $6 = ($4|0)==($5|0);
 if (!($6)) {
  $$019 = 0;$50 = $4;$8 = $5;
  while(1) {
   $9 = $8;
   $10 = (($9) + ($$019<<2)|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = ($11|0)==(0|0);
   if ($12) {
    $18 = $8;$19 = $50;
   } else {
    $13 = HEAP32[$11>>2]|0;
    $14 = ((($13)) + 136|0);
    $15 = HEAP32[$14>>2]|0;
    FUNCTION_TABLE_vii[$15 & 8191]($11,$1);
    $$pre = HEAP32[$3>>2]|0;
    $$pre20 = HEAP32[$2>>2]|0;
    $18 = $$pre20;$19 = $$pre;
   }
   $16 = (($$019) + 1)|0;
   $17 = (($19) - ($18))|0;
   $20 = $17 >> 2;
   $21 = ($16>>>0)<($20>>>0);
   if ($21) {
    $$019 = $16;$50 = $19;$8 = $18;
   } else {
    break;
   }
  }
 }
 $7 = ($1|0)==(0|0);
 if (!($7)) {
  $41 = ((($1)) + 124|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = ((($0)) + 56|0);
  $44 = (__ZN3osg14buffered_valueINS_7ref_ptrINS_7Program14ProgramObjectsEEEEixEj($43,$42)|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = ($45|0)==(0|0);
  if ($46) {
   return;
  }
  HEAP32[$44>>2] = 0;
  $47 = ((($45)) + 8|0);
  $48 = HEAP32[$47>>2]|0;HEAP32[$47>>2] = (($48-1)|0);
  $49 = ($48|0)==(1);
  if (!($49)) {
   return;
  }
  __ZNK3osg10Referenced24signalObserversAndDeleteEbb($45,1,1);
  return;
 }
 $22 = ((($0)) + 56|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ((($0)) + 60|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = $23;
 $27 = (($25) - ($26))|0;
 $28 = ($27|0)>(0);
 if (!($28)) {
  return;
 }
 $29 = $27 >>> 2;
 $$02$i$i$i$i$i = $29;$$sroa$01$0$i$i$i$i = $26;$31 = $23;
 while(1) {
  $30 = HEAP32[$31>>2]|0;
  $32 = ($30|0)==(0|0);
  if (!($32)) {
   HEAP32[$31>>2] = 0;
   $33 = ((($30)) + 8|0);
   $34 = HEAP32[$33>>2]|0;HEAP32[$33>>2] = (($34-1)|0);
   $35 = ($34|0)==(1);
   if ($35) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($30,1,1);
   }
  }
  $36 = $$sroa$01$0$i$i$i$i;
  $37 = ((($36)) + 4|0);
  $38 = $37;
  $39 = (($$02$i$i$i$i$i) + -1)|0;
  $40 = ($$02$i$i$i$i$i|0)>(1);
  if ($40) {
   $$02$i$i$i$i$i = $39;$$sroa$01$0$i$i$i$i = $38;$31 = $37;
  } else {
   break;
  }
 }
 return;
}
function __ZNK3osg7Program7getTypeEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 36;
}
function __ZNK3osg7Program7compareERKNS_14StateAttributeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$5 = 0, $$sroa$045$056 = 0, $$sroa$048$057 = 0, $$sroa$speculated$i$i$i = 0, $$sroa$speculated$i$i$i$i$i$i$i$i = 0, $$sroa$speculated$i$i$i$i3$i$i$i$i = 0, $$sroa$speculated$i$i$i38 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($0|0)==($1|0);
 if ($2) {
  $$5 = 0;
  return ($$5|0);
 }
 $3 = ($0|0)==(0|0);
 if ($3) {
  ___cxa_bad_typeid();
  // unreachable;
 }
 $4 = HEAP32[$0>>2]|0;
 $5 = ((($4)) + -4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$1>>2]|0;
 $8 = ((($7)) + -4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($6)) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($9)) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($11>>>0)<($13>>>0);
 if ($14) {
  $$5 = -1;
  return ($$5|0);
 }
 $15 = ($11|0)==($13|0);
 if (!($15)) {
  $$5 = 1;
  return ($$5|0);
 }
 $16 = ((($0)) + 104|0);
 $17 = ((($0)) + 108|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = HEAP32[$16>>2]|0;
 $20 = (($18) - ($19))|0;
 $21 = $20 >> 2;
 $22 = ((($1)) + 104|0);
 $23 = ((($22)) + 4|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = HEAP32[$22>>2]|0;
 $26 = (($24) - ($25))|0;
 $27 = $26 >> 2;
 $28 = ($21>>>0)<($27>>>0);
 $29 = $19;
 $30 = $25;
 $31 = $18;
 if ($28) {
  $$5 = -1;
  return ($$5|0);
 }
 $32 = ($27>>>0)<($21>>>0);
 if ($32) {
  $$5 = 1;
  return ($$5|0);
 }
 $33 = ((($0)) + 12|0);
 $34 = ((($1)) + 12|0);
 $35 = ((($34)) + 11|0);
 $36 = HEAP8[$35>>0]|0;
 $37 = ($36<<24>>24)<(0);
 $38 = ((($1)) + 16|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = $36&255;
 $41 = $37 ? $39 : $40;
 $42 = ((($33)) + 11|0);
 $43 = HEAP8[$42>>0]|0;
 $44 = ($43<<24>>24)<(0);
 $45 = ((($0)) + 16|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = $43&255;
 $48 = $44 ? $46 : $47;
 $49 = ($41>>>0)<($48>>>0);
 $$sroa$speculated$i$i$i38 = $49 ? $41 : $48;
 $50 = ($$sroa$speculated$i$i$i38|0)==(0);
 if ($50) {
  label = 10;
 } else {
  $51 = HEAP32[$33>>2]|0;
  $52 = $44 ? $51 : $33;
  $53 = HEAP32[$34>>2]|0;
  $54 = $37 ? $53 : $34;
  $55 = (_memcmp($52,$54,$$sroa$speculated$i$i$i38)|0);
  $56 = ($55|0)==(0);
  if ($56) {
   label = 10;
  } else {
   $58 = ($55|0)<(0);
   if ($58) {
    $$5 = -1;
    return ($$5|0);
   }
  }
 }
 if ((label|0) == 10) {
  $57 = ($48>>>0)<($41>>>0);
  if ($57) {
   $$5 = -1;
   return ($$5|0);
  }
 }
 $59 = ($48>>>0)<($41>>>0);
 $$sroa$speculated$i$i$i = $59 ? $48 : $41;
 $60 = ($$sroa$speculated$i$i$i|0)==(0);
 if ($60) {
  label = 14;
 } else {
  $61 = HEAP32[$34>>2]|0;
  $62 = $37 ? $61 : $34;
  $63 = HEAP32[$33>>2]|0;
  $64 = $44 ? $63 : $33;
  $65 = (_memcmp($62,$64,$$sroa$speculated$i$i$i)|0);
  $66 = ($65|0)==(0);
  if ($66) {
   label = 14;
  } else {
   $67 = ($65|0)<(0);
   if ($67) {
    $$5 = 1;
    return ($$5|0);
   }
  }
 }
 if ((label|0) == 14) {
  if ($49) {
   $$5 = 1;
   return ($$5|0);
  }
 }
 $68 = ((($0)) + 120|0);
 $69 = HEAP32[$68>>2]|0;
 $70 = ((($1)) + 120|0);
 $71 = HEAP32[$70>>2]|0;
 $72 = ($69|0)<($71|0);
 if ($72) {
  $$5 = -1;
  return ($$5|0);
 }
 $73 = ($71|0)<($69|0);
 if ($73) {
  $$5 = 1;
  return ($$5|0);
 }
 $74 = ((($0)) + 124|0);
 $75 = HEAP32[$74>>2]|0;
 $76 = ((($1)) + 124|0);
 $77 = HEAP32[$76>>2]|0;
 $78 = ($75|0)<($77|0);
 if ($78) {
  $$5 = -1;
  return ($$5|0);
 }
 $79 = ($77|0)<($75|0);
 if ($79) {
  $$5 = 1;
  return ($$5|0);
 }
 $80 = ((($0)) + 128|0);
 $81 = HEAP32[$80>>2]|0;
 $82 = ((($1)) + 128|0);
 $83 = HEAP32[$82>>2]|0;
 $84 = ($81|0)<($83|0);
 if ($84) {
  $$5 = -1;
  return ($$5|0);
 }
 $85 = ($83|0)<($81|0);
 if ($85) {
  $$5 = 1;
  return ($$5|0);
 }
 $86 = ((($0)) + 132|0);
 $87 = HEAP32[$86>>2]|0;
 $88 = ((($1)) + 132|0);
 $89 = HEAP32[$88>>2]|0;
 $90 = ($87|0)<($89|0);
 if ($90) {
  $$5 = -1;
  return ($$5|0);
 }
 $91 = ($89|0)<($87|0);
 if ($91) {
  $$5 = 1;
  return ($$5|0);
 }
 $92 = ((($0)) + 136|0);
 $93 = HEAP32[$92>>2]|0;
 $94 = ((($1)) + 136|0);
 $95 = HEAP32[$94>>2]|0;
 $96 = ($93|0)<($95|0);
 if ($96) {
  $$5 = -1;
  return ($$5|0);
 }
 $97 = ($95|0)<($93|0);
 if ($97) {
  $$5 = 1;
  return ($$5|0);
 }
 $98 = ((($0)) + 140|0);
 $99 = HEAP32[$98>>2]|0;
 $100 = ((($1)) + 140|0);
 $101 = HEAP32[$100>>2]|0;
 $102 = ($99|0)<($101|0);
 if ($102) {
  $$5 = -1;
  return ($$5|0);
 }
 $103 = ($101|0)<($99|0);
 if ($103) {
  $$5 = 1;
  return ($$5|0);
 }
 $104 = ((($1)) + 148|0);
 $105 = ((($0)) + 152|0);
 $106 = HEAP32[$105>>2]|0;
 $107 = HEAP32[$104>>2]|0;
 $108 = ((($104)) + 4|0);
 $109 = HEAP32[$108>>2]|0;
 $110 = ($107|0)==($109|0);
 L71: do {
  if (!($110)) {
   $111 = ((($0)) + 148|0);
   $112 = HEAP32[$111>>2]|0;
   $113 = $112;$116 = $107;
   L73: while(1) {
    $114 = ($113|0)==($106|0);
    if ($114) {
     $$5 = -1;
     label = 44;
     break;
    }
    $115 = ((($116)) + 11|0);
    $117 = HEAP8[$115>>0]|0;
    $118 = ($117<<24>>24)<(0);
    $119 = ((($116)) + 4|0);
    $120 = HEAP32[$119>>2]|0;
    $121 = $117&255;
    $122 = $118 ? $120 : $121;
    $123 = ((($113)) + 11|0);
    $124 = HEAP8[$123>>0]|0;
    $125 = ($124<<24>>24)<(0);
    $126 = ((($113)) + 4|0);
    $127 = HEAP32[$126>>2]|0;
    $128 = $124&255;
    $129 = $125 ? $127 : $128;
    $130 = ($122>>>0)<($129>>>0);
    $$sroa$speculated$i$i$i$i3$i$i$i$i = $130 ? $122 : $129;
    $131 = ($$sroa$speculated$i$i$i$i3$i$i$i$i|0)==(0);
    do {
     if ($131) {
      label = 33;
     } else {
      $132 = HEAP32[$113>>2]|0;
      $133 = $125 ? $132 : $113;
      $134 = HEAP32[$116>>2]|0;
      $135 = $118 ? $134 : $116;
      $136 = (_memcmp($133,$135,$$sroa$speculated$i$i$i$i3$i$i$i$i)|0);
      $137 = ($136|0)==(0);
      if ($137) {
       label = 33;
       break;
      }
      $139 = ($136|0)<(0);
      if ($139) {
       $$5 = -1;
       label = 44;
       break L73;
      }
     }
    } while(0);
    if ((label|0) == 33) {
     label = 0;
     $138 = ($129>>>0)<($122>>>0);
     if ($138) {
      $$5 = -1;
      label = 44;
      break;
     }
    }
    $140 = ($129>>>0)<($122>>>0);
    $$sroa$speculated$i$i$i$i$i$i$i$i = $140 ? $129 : $122;
    $141 = ($$sroa$speculated$i$i$i$i$i$i$i$i|0)==(0);
    do {
     if ($141) {
      label = 37;
     } else {
      $142 = HEAP32[$116>>2]|0;
      $143 = $118 ? $142 : $116;
      $144 = HEAP32[$113>>2]|0;
      $145 = $125 ? $144 : $113;
      $146 = (_memcmp($143,$145,$$sroa$speculated$i$i$i$i$i$i$i$i)|0);
      $147 = ($146|0)==(0);
      if ($147) {
       label = 37;
       break;
      }
      $148 = ($146|0)<(0);
      if ($148) {
       break L71;
      }
     }
    } while(0);
    if ((label|0) == 37) {
     label = 0;
     if ($130) {
      break L71;
     }
    }
    $149 = ((($113)) + 12|0);
    $150 = ((($116)) + 12|0);
    $151 = ($150|0)==($109|0);
    if ($151) {
     break L71;
    } else {
     $113 = $149;$116 = $150;
    }
   }
   if ((label|0) == 44) {
    return ($$5|0);
   }
  }
 } while(0);
 $152 = ((($0)) + 144|0);
 $153 = HEAP32[$152>>2]|0;
 $154 = ((($1)) + 144|0);
 $155 = HEAP32[$154>>2]|0;
 $156 = ($153>>>0)<($155>>>0);
 if ($156) {
  $$5 = -1;
  return ($$5|0);
 }
 $157 = ($29|0)==($31|0);
 if ($157) {
  $$5 = 0;
  return ($$5|0);
 } else {
  $$sroa$045$056 = $30;$$sroa$048$057 = $29;
 }
 while(1) {
  $158 = HEAP32[$$sroa$048$057>>2]|0;
  $159 = HEAP32[$$sroa$045$056>>2]|0;
  $160 = (__ZNK3osg6Shader7compareERKS0_($158,$159)|0);
  $161 = ($160|0)==(0);
  if (!($161)) {
   $$5 = $160;
   label = 44;
   break;
  }
  $162 = ((($$sroa$048$057)) + 4|0);
  $163 = ((($$sroa$045$056)) + 4|0);
  $164 = HEAP32[$17>>2]|0;
  $165 = ($162|0)==($164|0);
  if ($165) {
   $$5 = 0;
   label = 44;
   break;
  } else {
   $$sroa$045$056 = $163;$$sroa$048$057 = $162;
  }
 }
 if ((label|0) == 44) {
  return ($$5|0);
 }
 return (0)|0;
}
function __ZNK3osg7Program5applyERNS_5StateE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 784|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + 24|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)==(0);
 if ($6) {
  return;
 }
 $7 = (__ZNK3osg7Program6getPCPERNS_5StateE($0,$1)|0);
 $8 = ((($7)) + 36|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = ($9<<24>>24)==(0);
 if (!($10)) {
  $11 = HEAP32[$0>>2]|0;
  $12 = ((($11)) + 176|0);
  $13 = HEAP32[$12>>2]|0;
  FUNCTION_TABLE_vii[$13 & 8191]($0,$1);
 }
 $14 = ((($7)) + 37|0);
 $15 = HEAP8[$14>>0]|0;
 $16 = ($15<<24>>24)==(0);
 if ($16) {
  $27 = ((($3)) + 176|0);
  $28 = HEAP32[$27>>2]|0;
  FUNCTION_TABLE_vi[$28 & 8191](0);
  $29 = ((($1)) + 664|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = ($30|0)==(0|0);
  if ($31) {
   return;
  }
  HEAP32[$29>>2] = 0;
  return;
 }
 $17 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
 if ($17) {
  $18 = HEAP32[$7>>2]|0;
  $19 = ((($18)) + 16|0);
  $20 = HEAP32[$19>>2]|0;
  (FUNCTION_TABLE_ii[$20 & 8191]($7)|0);
 }
 $21 = HEAP32[$7>>2]|0;
 $22 = ((($21)) + 28|0);
 $23 = HEAP32[$22>>2]|0;
 FUNCTION_TABLE_vi[$23 & 8191]($7);
 $24 = ((($1)) + 664|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)==($7|0);
 if ($26) {
  return;
 }
 HEAP32[$24>>2] = $7;
 return;
}
function __ZNK3osg7Program16compileGLObjectsERNS_5StateE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$03044 = 0, $$041 = 0, $$arith = 0, $$in = 0, $$overflow = 0, $$sroa$033$0$$sroa$033$0$3440$cast = 0, $$sroa$033$0$$sroa$033$0$3443 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 104|0);
 $3 = ((($0)) + 108|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$2>>2]|0;
 $6 = ($4|0)==($5|0);
 if (!($6)) {
  $$03044 = 0;$$in = $5;
  while(1) {
   $12 = $$in;
   $13 = (($12) + ($$03044<<2)|0);
   $14 = HEAP32[$13>>2]|0;
   __ZNK3osg6Shader13compileShaderERNS_5StateE($14,$1);
   $15 = (($$03044) + 1)|0;
   $16 = HEAP32[$3>>2]|0;
   $17 = HEAP32[$2>>2]|0;
   $18 = (($16) - ($17))|0;
   $19 = $18 >> 2;
   $20 = ($15>>>0)<($19>>>0);
   if ($20) {
    $$03044 = $15;$$in = $17;
   } else {
    break;
   }
  }
 }
 $7 = ((($0)) + 148|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($0)) + 152|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8|0)==($10|0);
 if ($11) {
  $47 = (__ZNK3osg7Program6getPCPERNS_5StateE($0,$1)|0);
  $48 = HEAP32[$47>>2]|0;
  $49 = ((($48)) + 12|0);
  $50 = HEAP32[$49>>2]|0;
  FUNCTION_TABLE_vii[$50 & 8191]($47,$1);
  return;
 }
 $21 = (__ZNK3osg7Program6getPCPERNS_5StateE($0,$1)|0);
 $22 = ((($1)) + 784|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = HEAP32[$9>>2]|0;
 $25 = HEAP32[$7>>2]|0;
 $26 = (($24) - ($25))|0;
 $27 = (($26|0) / 12)&-1;
 $$arith = $27<<2;
 $$overflow = ($27>>>0)>(1073741823);
 $28 = $$overflow ? -1 : $$arith;
 $29 = (__Znaj($28)|0);
 $30 = $24;
 $$sroa$033$0$$sroa$033$0$3440$cast = $25;
 $31 = ($$sroa$033$0$$sroa$033$0$3440$cast|0)==($30|0);
 if (!($31)) {
  $$041 = $29;$$sroa$033$0$$sroa$033$0$3443 = $$sroa$033$0$$sroa$033$0$3440$cast;
  while(1) {
   $38 = ((($$sroa$033$0$$sroa$033$0$3443)) + 11|0);
   $39 = HEAP8[$38>>0]|0;
   $40 = ($39<<24>>24)<(0);
   if ($40) {
    $41 = HEAP32[$$sroa$033$0$$sroa$033$0$3443>>2]|0;
    $43 = $41;
   } else {
    $43 = $$sroa$033$0$$sroa$033$0$3443;
   }
   $42 = ((($$041)) + 4|0);
   HEAP32[$$041>>2] = $43;
   $44 = ((($$sroa$033$0$$sroa$033$0$3443)) + 12|0);
   $45 = HEAP32[$9>>2]|0;
   $46 = ($44|0)==($45|0);
   if ($46) {
    break;
   } else {
    $$041 = $42;$$sroa$033$0$$sroa$033$0$3443 = $44;
   }
  }
 }
 $32 = ((($23)) + 1416|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ((($21)) + 20|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = ((($0)) + 144|0);
 $37 = HEAP32[$36>>2]|0;
 FUNCTION_TABLE_viiii[$33 & 8191]($35,$27,$29,$37);
 __ZdaPv($29);
 $47 = (__ZNK3osg7Program6getPCPERNS_5StateE($0,$1)|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = ((($48)) + 12|0);
 $50 = HEAP32[$49>>2]|0;
 FUNCTION_TABLE_vii[$50 & 8191]($47,$1);
 return;
}
function __ZNK3osg7Program6getPCPERNS_5StateE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$02026$i$i44 = 0, $$02125$i$i45 = 0, $$027$i$i43 = 0, $$028 = 0, $$042 = 0, $$1 = 0, $$127 = 0, $$in = 0, $$pre$i = 0, $$pre$i$i = 0, $$sink16$i = 0, $$sink16$i$us = 0, $$sink29$index = 0, $$sink29$index3 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0;
 var $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0;
 var $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $phitmp$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp + 12|0;
 $3 = sp;
 $4 = ((($1)) + 124|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($0)) + 160|0);
 __ZN3osg5State15getDefineStringERKNSt3__23setINS1_12basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEENS1_4lessIS8_EENS6_IS8_EEEE($3,$1,$6);
 $7 = ((($0)) + 56|0);
 __THREW__ = 0;
 $8 = (invoke_iii(3852,($7|0),($5|0))|0);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 L1: do {
  if ($10) {
   label = 10;
  } else {
   $11 = HEAP32[$8>>2]|0;
   $12 = ($11|0)==(0|0);
   if ($12) {
    __THREW__ = 0;
    $13 = (invoke_ii(3276,32)|0);
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     label = 10;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3853,($13|0));
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     $38 = ___cxa_find_matching_catch_2()|0;
     $39 = tempRet0;
     __ZdlPv($13);
     $$1 = $39;$$127 = $38;
     break;
    }
    HEAP32[$13>>2] = (65256);
    $18 = ((($13)) + 12|0);
    HEAP32[$18>>2] = $5;
    $19 = ((($13)) + 16|0);
    HEAP32[$19>>2] = $0;
    $20 = ((($13)) + 20|0);
    HEAP32[$20>>2] = 0;
    $21 = ((($13)) + 24|0);
    HEAP32[$21>>2] = 0;
    $22 = ((($13)) + 28|0);
    HEAP32[$22>>2] = 0;
    __THREW__ = 0;
    $23 = (invoke_iii(3852,($7|0),($5|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     label = 10;
     break;
    }
    $26 = HEAP32[$23>>2]|0;
    $27 = ($26|0)==($13|0);
    if (!($27)) {
     HEAP32[$23>>2] = $13;
     $28 = ((($13)) + 8|0);
     $29 = HEAP32[$28>>2]|0;HEAP32[$28>>2] = (($29+1)|0);
     $30 = ($26|0)==(0|0);
     if (!($30)) {
      $31 = ((($26)) + 8|0);
      $32 = HEAP32[$31>>2]|0;HEAP32[$31>>2] = (($32-1)|0);
      $33 = ($32|0)==(1);
      if ($33) {
       __THREW__ = 0;
       invoke_viii(3262,($26|0),1,1);
       $34 = __THREW__; __THREW__ = 0;
       $35 = $34&1;
       if ($35) {
        label = 10;
        break;
       }
      }
     }
    }
   }
   __THREW__ = 0;
   $40 = (invoke_iii(3852,($7|0),($5|0))|0);
   $41 = __THREW__; __THREW__ = 0;
   $42 = $41&1;
   if ($42) {
    label = 10;
   } else {
    $43 = HEAP32[$40>>2]|0;
    $44 = ((($43)) + 20|0);
    $45 = HEAP32[$44>>2]|0;
    $46 = ((($43)) + 24|0);
    $47 = HEAP32[$46>>2]|0;
    $48 = ($45|0)==($47|0);
    L15: do {
     if ($48) {
      label = 26;
     } else {
      $49 = ((($3)) + 11|0);
      $50 = HEAP8[$49>>0]|0;
      $51 = ($50<<24>>24)<(0);
      $52 = ((($3)) + 4|0);
      $53 = HEAP32[$52>>2]|0;
      $54 = $50&255;
      $55 = $51 ? $53 : $54;
      $56 = HEAP32[$3>>2]|0;
      $57 = $51 ? $56 : $3;
      $58 = ($55|0)==(0);
      if ($58) {
       $$sink16$i$us = $45;
       while(1) {
        $59 = HEAP32[$$sink16$i$us>>2]|0;
        $60 = ((($59)) + 24|0);
        $61 = ((($60)) + 11|0);
        $62 = HEAP8[$61>>0]|0;
        $63 = ($62<<24>>24)<(0);
        $64 = ((($59)) + 28|0);
        $65 = HEAP32[$64>>2]|0;
        $66 = $62&255;
        $67 = $63 ? $65 : $66;
        $68 = ($67|0)==(0);
        if ($68) {
         $$028 = $59;
         break L15;
        }
        $69 = ((($$sink16$i$us)) + 4|0);
        $70 = ($69|0)==($47|0);
        if ($70) {
         label = 26;
         break L15;
        } else {
         $$sink16$i$us = $69;
        }
       }
      } else {
       $$sink16$i = $45;
      }
      L21: while(1) {
       $71 = HEAP32[$$sink16$i>>2]|0;
       $72 = ((($71)) + 24|0);
       $73 = ((($72)) + 11|0);
       $74 = HEAP8[$73>>0]|0;
       $75 = ($74<<24>>24)<(0);
       $76 = ((($71)) + 28|0);
       $77 = HEAP32[$76>>2]|0;
       $78 = $74&255;
       $79 = $75 ? $77 : $78;
       $80 = ($79|0)==($55|0);
       do {
        if ($80) {
         $81 = HEAP32[$72>>2]|0;
         if ($75) {
          $92 = (_memcmp($81,$57,$55)|0);
          $phitmp$i$i = ($92|0)==(0);
          if ($phitmp$i$i) {
           $$028 = $71;
           break L15;
          } else {
           break;
          }
         }
         $82 = $81;
         $83 = $82&255;
         $84 = HEAP8[$57>>0]|0;
         $85 = ($83<<24>>24)==($84<<24>>24);
         if ($85) {
          $$02026$i$i44 = $72;$$02125$i$i45 = $78;$$027$i$i43 = $57;
          while(1) {
           $86 = (($$02125$i$i45) + -1)|0;
           $87 = ((($$02026$i$i44)) + 1|0);
           $88 = ($86|0)==(0);
           if ($88) {
            break L21;
           }
           $89 = ((($$027$i$i43)) + 1|0);
           $$pre$i = HEAP8[$87>>0]|0;
           $90 = HEAP8[$89>>0]|0;
           $91 = ($$pre$i<<24>>24)==($90<<24>>24);
           if ($91) {
            $$02026$i$i44 = $87;$$02125$i$i45 = $86;$$027$i$i43 = $89;
           } else {
            break;
           }
          }
         }
        }
       } while(0);
       $93 = ((($$sink16$i)) + 4|0);
       $94 = ($93|0)==($47|0);
       if ($94) {
        label = 26;
        break L15;
       } else {
        $$sink16$i = $93;
       }
      }
      $95 = ($71|0)==(0|0);
      if ($95) {
       label = 26;
      } else {
       $$028 = $71;
      }
     }
    } while(0);
    L34: do {
     if ((label|0) == 26) {
      __THREW__ = 0;
      $96 = (invoke_iii(3852,($7|0),($5|0))|0);
      $97 = __THREW__; __THREW__ = 0;
      $98 = $97&1;
      do {
       if ($98) {
        label = 30;
       } else {
        $99 = HEAP32[$96>>2]|0;
        __THREW__ = 0;
        $100 = (invoke_iii(3854,($99|0),($3|0))|0);
        $101 = __THREW__; __THREW__ = 0;
        $102 = $101&1;
        if ($102) {
         label = 30;
        } else {
         $103 = ((($0)) + 104|0);
         $104 = ((($0)) + 108|0);
         $105 = HEAP32[$104>>2]|0;
         $106 = HEAP32[$103>>2]|0;
         $107 = ($105|0)==($106|0);
         if ($107) {
          $$028 = $100;
          break L34;
         }
         $108 = ((($100)) + 108|0);
         $109 = ((($100)) + 112|0);
         $110 = ((($100)) + 116|0);
         $$042 = 0;$$in = $106;
         while(1) {
          $113 = $$in;
          $114 = (($113) + ($$042<<2)|0);
          $115 = HEAP32[$114>>2]|0;
          HEAP32[$2>>2] = $115;
          $116 = ($115|0)==(0|0);
          if (!($116)) {
           $117 = ((($115)) + 8|0);
           $118 = HEAP32[$117>>2]|0;HEAP32[$117>>2] = (($118+1)|0);
          }
          $119 = HEAP32[$109>>2]|0;
          $120 = HEAP32[$110>>2]|0;
          $121 = ($119|0)==($120|0);
          if ($121) {
           __THREW__ = 0;
           invoke_vii(3855,($108|0),($2|0));
           $128 = __THREW__; __THREW__ = 0;
           $129 = $128&1;
           if ($129) {
            break;
           }
          } else {
           $122 = HEAP32[$2>>2]|0;
           HEAP32[$119>>2] = $122;
           $123 = ($122|0)==(0|0);
           if ($123) {
            $127 = $119;
           } else {
            $124 = ((($122)) + 8|0);
            $125 = HEAP32[$124>>2]|0;HEAP32[$124>>2] = (($125+1)|0);
            $$pre$i$i = HEAP32[$109>>2]|0;
            $127 = $$pre$i$i;
           }
           $126 = ((($127)) + 4|0);
           HEAP32[$109>>2] = $126;
          }
          $130 = HEAP32[$2>>2]|0;
          $131 = ($130|0)==(0|0);
          if (!($131)) {
           $132 = ((($130)) + 8|0);
           $133 = HEAP32[$132>>2]|0;HEAP32[$132>>2] = (($133-1)|0);
           $134 = ($133|0)==(1);
           if ($134) {
            __THREW__ = 0;
            invoke_viii(3262,($130|0),1,1);
            $135 = __THREW__; __THREW__ = 0;
            $136 = $135&1;
            if ($136) {
             label = 47;
             break;
            }
           }
          }
          $148 = (($$042) + 1)|0;
          $149 = HEAP32[$104>>2]|0;
          $150 = HEAP32[$103>>2]|0;
          $151 = (($149) - ($150))|0;
          $152 = $151 >> 2;
          $153 = ($148>>>0)<($152>>>0);
          if ($153) {
           $$042 = $148;$$in = $150;
          } else {
           $$028 = $100;
           break L34;
          }
         }
         if ((label|0) == 47) {
          $154 = ___cxa_find_matching_catch_2()|0;
          $155 = tempRet0;
          $$sink29$index = $154;$$sink29$index3 = $155;
          break;
         }
         $137 = ___cxa_find_matching_catch_2()|0;
         $138 = tempRet0;
         $139 = HEAP32[$2>>2]|0;
         $140 = ($139|0)==(0|0);
         if (!($140)) {
          $141 = ((($139)) + 8|0);
          $142 = HEAP32[$141>>2]|0;HEAP32[$141>>2] = (($142-1)|0);
          $143 = ($142|0)==(1);
          if ($143) {
           __THREW__ = 0;
           invoke_viii(3262,($139|0),1,1);
           $144 = __THREW__; __THREW__ = 0;
           $145 = $144&1;
           if ($145) {
            $146 = ___cxa_find_matching_catch_3(0|0)|0;
            $147 = tempRet0;
            ___clang_call_terminate($146);
            // unreachable;
           }
          }
         }
         $$sink29$index = $137;$$sink29$index3 = $138;
        }
       }
      } while(0);
      if ((label|0) == 30) {
       $111 = ___cxa_find_matching_catch_2()|0;
       $112 = tempRet0;
       $$sink29$index = $111;$$sink29$index3 = $112;
      }
      $$1 = $$sink29$index3;$$127 = $$sink29$index;
      break L1;
     }
    } while(0);
    $156 = ((($3)) + 11|0);
    $157 = HEAP8[$156>>0]|0;
    $158 = ($157<<24>>24)<(0);
    if (!($158)) {
     STACKTOP = sp;return ($$028|0);
    }
    $159 = HEAP32[$3>>2]|0;
    __ZdlPv($159);
    STACKTOP = sp;return ($$028|0);
   }
  }
 } while(0);
 if ((label|0) == 10) {
  $36 = ___cxa_find_matching_catch_2()|0;
  $37 = tempRet0;
  $$1 = $37;$$127 = $36;
 }
 $160 = ((($3)) + 11|0);
 $161 = HEAP8[$160>>0]|0;
 $162 = ($161<<24>>24)<(0);
 if (!($162)) {
  ___resumeException($$127|0);
  // unreachable;
 }
 $163 = HEAP32[$3>>2]|0;
 __ZdlPv($163);
 ___resumeException($$127|0);
 // unreachable;
 return (0)|0;
}
function __ZN3osg14buffered_valueINS_7ref_ptrINS_7Program14ProgramObjectsEEEEixEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$pre = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = ((($0)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$0>>2]|0;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 2;
 $8 = ($7>>>0)>($1>>>0);
 $9 = $5;
 if ($8) {
  $47 = $9;
  $46 = (($47) + ($1<<2)|0);
  STACKTOP = sp;return ($46|0);
 }
 $10 = (($1) + 1)|0;
 HEAP32[$2>>2] = 0;
 $11 = ($10>>>0)>($7>>>0);
 $12 = $4;
 L4: do {
  if ($11) {
   $13 = (($10) - ($7))|0;
   __THREW__ = 0;
   invoke_viii(3856,($0|0),($13|0),($2|0));
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if ($15) {
    $37 = ___cxa_find_matching_catch_2()|0;
    $38 = tempRet0;
    $39 = HEAP32[$2>>2]|0;
    $40 = ($39|0)==(0|0);
    if ($40) {
     ___resumeException($37|0);
     // unreachable;
    }
    $41 = ((($39)) + 8|0);
    $42 = HEAP32[$41>>2]|0;HEAP32[$41>>2] = (($42-1)|0);
    $43 = ($42|0)==(1);
    if (!($43)) {
     ___resumeException($37|0);
     // unreachable;
    }
    __THREW__ = 0;
    invoke_viii(3262,($39|0),1,1);
    $44 = __THREW__; __THREW__ = 0;
    $45 = $44&1;
    if ($45) {
     $48 = ___cxa_find_matching_catch_3(0|0)|0;
     $49 = tempRet0;
     ___clang_call_terminate($48);
     // unreachable;
    } else {
     ___resumeException($37|0);
     // unreachable;
    }
   }
  } else {
   $16 = ($10>>>0)<($7>>>0);
   if ($16) {
    $17 = (($9) + ($10<<2)|0);
    $18 = ($12|0)==($17|0);
    if (!($18)) {
     $20 = $12;
     while(1) {
      $19 = ((($20)) + -4|0);
      HEAP32[$3>>2] = $19;
      $21 = HEAP32[$19>>2]|0;
      $22 = ($21|0)==(0|0);
      if (!($22)) {
       $23 = ((($21)) + 8|0);
       $24 = HEAP32[$23>>2]|0;HEAP32[$23>>2] = (($24-1)|0);
       $25 = ($24|0)==(1);
       if ($25) {
        __THREW__ = 0;
        invoke_viii(3262,($21|0),1,1);
        $26 = __THREW__; __THREW__ = 0;
        $27 = $26&1;
        if ($27) {
         break;
        }
       }
      }
      HEAP32[$19>>2] = 0;
      $28 = HEAP32[$3>>2]|0;
      $29 = ($28|0)==($17|0);
      if ($29) {
       break L4;
      } else {
       $20 = $28;
      }
     }
     $30 = ___cxa_find_matching_catch_2()|0;
     $31 = tempRet0;
     ___cxa_call_unexpected(($30|0));
     // unreachable;
    }
   }
  }
 } while(0);
 $32 = HEAP32[$2>>2]|0;
 $33 = ($32|0)==(0|0);
 if (!($33)) {
  $34 = ((($32)) + 8|0);
  $35 = HEAP32[$34>>2]|0;HEAP32[$34>>2] = (($35-1)|0);
  $36 = ($35|0)==(1);
  if ($36) {
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($32,1,1);
  }
 }
 $$pre = HEAP32[$0>>2]|0;
 $47 = $$pre;
 $46 = (($47) + ($1<<2)|0);
 STACKTOP = sp;return ($46|0);
}
function __ZN3osg7Program14ProgramObjects23createPerContextProgramERKNSt3__212basic_stringIcNS2_11char_traitsIcEENS2_9allocatorIcEEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$08 = 0, $$pre$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = (__Znwj(120)|0);
 $4 = ((($0)) + 16|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($0)) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 __THREW__ = 0;
 invoke_viiii(3857,($3|0),($5|0),($7|0),0);
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $32 = ___cxa_find_matching_catch_2()|0;
  $33 = tempRet0;
  __ZdlPv($3);
  $$0 = $33;$$08 = $32;
  ___resumeException($$08|0);
  // unreachable;
 }
 HEAP32[$2>>2] = $3;
 $10 = ((($3)) + 8|0);
 $11 = HEAP32[$10>>2]|0;HEAP32[$10>>2] = (($11+1)|0);
 $12 = ((($0)) + 24|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($0)) + 28|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($13|0)==($15|0);
 if ($16) {
  $23 = ((($0)) + 20|0);
  __THREW__ = 0;
  invoke_vii(3858,($23|0),($2|0));
  $24 = __THREW__; __THREW__ = 0;
  $25 = $24&1;
  if ($25) {
   $34 = ___cxa_find_matching_catch_2()|0;
   $35 = tempRet0;
   $36 = HEAP32[$2>>2]|0;
   $37 = ($36|0)==(0|0);
   if (!($37)) {
    $38 = ((($36)) + 8|0);
    $39 = HEAP32[$38>>2]|0;HEAP32[$38>>2] = (($39-1)|0);
    $40 = ($39|0)==(1);
    if ($40) {
     __THREW__ = 0;
     invoke_viii(3262,($36|0),1,1);
     $41 = __THREW__; __THREW__ = 0;
     $42 = $41&1;
     if ($42) {
      $43 = ___cxa_find_matching_catch_3(0|0)|0;
      $44 = tempRet0;
      ___clang_call_terminate($43);
      // unreachable;
     }
    }
   }
   $$0 = $35;$$08 = $34;
   ___resumeException($$08|0);
   // unreachable;
  }
 } else {
  $17 = HEAP32[$2>>2]|0;
  HEAP32[$13>>2] = $17;
  $18 = ($17|0)==(0|0);
  if ($18) {
   $22 = $13;
  } else {
   $19 = ((($17)) + 8|0);
   $20 = HEAP32[$19>>2]|0;HEAP32[$19>>2] = (($20+1)|0);
   $$pre$i = HEAP32[$12>>2]|0;
   $22 = $$pre$i;
  }
  $21 = ((($22)) + 4|0);
  HEAP32[$12>>2] = $21;
 }
 $26 = HEAP32[$2>>2]|0;
 $27 = ($26|0)==(0|0);
 if ($27) {
  $31 = ((($3)) + 24|0);
  (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEaSERKS5_($31,$1)|0);
  STACKTOP = sp;return ($3|0);
 }
 $28 = ((($26)) + 8|0);
 $29 = HEAP32[$28>>2]|0;HEAP32[$28>>2] = (($29-1)|0);
 $30 = ($29|0)==(1);
 if (!($30)) {
  $31 = ((($3)) + 24|0);
  (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEaSERKS5_($31,$1)|0);
  STACKTOP = sp;return ($3|0);
 }
 __ZNK3osg10Referenced24signalObserversAndDeleteEbb($26,1,1);
 $31 = ((($3)) + 24|0);
 (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEaSERKS5_($31,$1)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZNSt3__26vectorIN3osg7ref_ptrINS1_6ShaderEEENS_9allocatorIS4_EEE21__push_back_slow_pathIKS4_EEvRT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$06$i$i = 0, $$pre = 0, $$pre$i = 0, $$pre38 = 0, $$pre39 = 0, $$sroa$7$0 = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(1073741823);
 $9 = $4;
 $10 = $3;
 if ($8) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $11 = ((($0)) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) - ($4))|0;
 $14 = $13 >> 2;
 $15 = ($14>>>0)<(536870911);
 $16 = $13 >> 1;
 $17 = ($16>>>0)<($7>>>0);
 $$sroa$speculated$i = $17 ? $7 : $16;
 $$sroa$speculated$$i = $15 ? $$sroa$speculated$i : 1073741823;
 $18 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($18) {
   $28 = 0;
  } else {
   $19 = ($$sroa$speculated$$i>>>0)>(1073741823);
   if (!($19)) {
    $25 = $$sroa$speculated$$i << 2;
    $26 = (__Znwj($25)|0);
    $28 = $26;
    break;
   }
   $20 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($20|0),(204840|0));
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if ($22) {
    $23 = ___cxa_find_matching_catch_2()|0;
    $24 = tempRet0;
    ___cxa_free_exception(($20|0));
    ___resumeException($23|0);
    // unreachable;
   } else {
    HEAP32[$20>>2] = (99824);
    ___cxa_throw(($20|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $27 = (($28) + ($6<<2)|0);
 $29 = $27;
 $30 = (($28) + ($$sroa$speculated$$i<<2)|0);
 $31 = $30;
 $32 = HEAP32[$1>>2]|0;
 HEAP32[$27>>2] = $32;
 $33 = ($32|0)==(0|0);
 if ($33) {
  $38 = $10;$40 = $9;
 } else {
  $34 = ((($32)) + 8|0);
  $35 = HEAP32[$34>>2]|0;HEAP32[$34>>2] = (($35+1)|0);
  $$pre = HEAP32[$0>>2]|0;
  $$pre38 = HEAP32[$2>>2]|0;
  $38 = $$pre38;$40 = $$pre;
 }
 $36 = ((($27)) + 4|0);
 $37 = $36;
 $39 = ($38|0)==($40|0);
 if ($39) {
  $41 = $38;
  $53 = $29;$54 = $41;$56 = $38;
 } else {
  $$06$i$i = $38;$$sroa$7$0 = $29;$44 = $27;
  while(1) {
   $42 = ((($$06$i$i)) + -4|0);
   $43 = ((($44)) + -4|0);
   $45 = HEAP32[$42>>2]|0;
   HEAP32[$43>>2] = $45;
   $46 = ($45|0)==(0|0);
   if (!($46)) {
    $47 = ((($45)) + 8|0);
    $48 = HEAP32[$47>>2]|0;HEAP32[$47>>2] = (($48+1)|0);
   }
   $49 = $$sroa$7$0;
   $50 = ((($49)) + -4|0);
   $51 = $50;
   $52 = ($42|0)==($40|0);
   if ($52) {
    break;
   } else {
    $$06$i$i = $42;$$sroa$7$0 = $51;$44 = $50;
   }
  }
  $$pre$i = HEAP32[$0>>2]|0;
  $$pre39 = HEAP32[$2>>2]|0;
  $53 = $51;$54 = $$pre$i;$56 = $$pre39;
 }
 HEAP32[$0>>2] = $53;
 HEAP32[$2>>2] = $37;
 HEAP32[$11>>2] = $31;
 $55 = $54;
 $57 = ($56|0)==($55|0);
 L25: do {
  if (!($57)) {
   $59 = $56;
   while(1) {
    $58 = ((($59)) + -4|0);
    $60 = HEAP32[$58>>2]|0;
    $61 = ($60|0)==(0|0);
    if (!($61)) {
     $62 = ((($60)) + 8|0);
     $63 = HEAP32[$62>>2]|0;HEAP32[$62>>2] = (($63-1)|0);
     $64 = ($63|0)==(1);
     if ($64) {
      __THREW__ = 0;
      invoke_viii(3262,($60|0),1,1);
      $65 = __THREW__; __THREW__ = 0;
      $66 = $65&1;
      if ($66) {
       break;
      }
     }
    }
    HEAP32[$58>>2] = 0;
    $67 = ($58|0)==($55|0);
    if ($67) {
     break L25;
    } else {
     $59 = $58;
    }
   }
   $68 = ___cxa_find_matching_catch_2()|0;
   $69 = tempRet0;
   ___cxa_call_unexpected(($68|0));
   // unreachable;
  }
 } while(0);
 $70 = ($54|0)==(0);
 if ($70) {
  return;
 }
 $71 = $54;
 __ZdlPv($71);
 return;
}
function __ZN3osg7Program17PerContextProgramC2EPKS0_jj($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$pre$i = 0, $$pre$i16 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg10ReferencedC2Ev($0);
 HEAP32[$0>>2] = (65276);
 $4 = ((($0)) + 16|0);
 HEAP32[$4>>2] = 0;
 $5 = ((($0)) + 20|0);
 HEAP32[$5>>2] = $3;
 $6 = ((($0)) + 24|0);
 ;HEAP32[$6>>2]=0|0;HEAP32[$6+4>>2]=0|0;HEAP32[$6+8>>2]=0|0;
 $7 = ((($0)) + 38|0);
 HEAP8[$7>>0] = 0;
 $8 = ((($0)) + 40|0);
 HEAP32[$8>>2] = $2;
 $9 = ((($0)) + 44|0);
 HEAP8[$9>>0] = 0;
 $10 = ((($0)) + 48|0);
 $11 = ((($0)) + 52|0);
 HEAP32[$11>>2] = 0;
 $12 = ((($0)) + 56|0);
 HEAP32[$12>>2] = 0;
 $13 = ((($0)) + 52|0);
 HEAP32[$10>>2] = $13;
 $14 = ((($0)) + 60|0);
 $15 = ((($0)) + 64|0);
 HEAP32[$15>>2] = 0;
 $16 = ((($0)) + 68|0);
 HEAP32[$16>>2] = 0;
 $17 = ((($0)) + 64|0);
 HEAP32[$14>>2] = $17;
 $18 = ((($0)) + 72|0);
 $19 = ((($0)) + 76|0);
 HEAP32[$19>>2] = 0;
 $20 = ((($0)) + 80|0);
 HEAP32[$20>>2] = 0;
 $21 = ((($0)) + 76|0);
 HEAP32[$18>>2] = $21;
 $22 = ((($0)) + 84|0);
 $23 = ((($0)) + 88|0);
 HEAP32[$23>>2] = 0;
 $24 = ((($0)) + 92|0);
 HEAP32[$24>>2] = 0;
 $25 = ((($0)) + 88|0);
 HEAP32[$22>>2] = $25;
 $26 = ((($0)) + 96|0);
 $27 = ((($0)) + 100|0);
 $28 = ((($0)) + 108|0);
 $29 = ((($0)) + 112|0);
 $30 = ((($0)) + 12|0);
 ;HEAP32[$26>>2]=0|0;HEAP32[$26+4>>2]=0|0;HEAP32[$26+8>>2]=0|0;HEAP32[$26+12>>2]=0|0;HEAP32[$26+16>>2]=0|0;HEAP32[$26+20>>2]=0|0;
 HEAP32[$30>>2] = $1;
 $31 = ($3|0)==(0);
 if (!($31)) {
  $72 = ((($0)) + 36|0);
  HEAP8[$72>>0] = 1;
  $73 = ((($0)) + 37|0);
  HEAP8[$73>>0] = 0;
  return;
 }
 __THREW__ = 0;
 $32 = (invoke_iii(3718,($2|0),1)|0);
 $33 = __THREW__; __THREW__ = 0;
 $34 = $33&1;
 do {
  if (!($34)) {
   $35 = HEAP32[$4>>2]|0;
   $36 = ($35|0)==($32|0);
   if (!($36)) {
    HEAP32[$4>>2] = $32;
    $37 = ($32|0)==(0|0);
    if (!($37)) {
     $38 = ((($32)) + 8|0);
     $39 = HEAP32[$38>>2]|0;HEAP32[$38>>2] = (($39+1)|0);
    }
    $40 = ($35|0)==(0|0);
    if (!($40)) {
     $41 = ((($35)) + 8|0);
     $42 = HEAP32[$41>>2]|0;HEAP32[$41>>2] = (($42-1)|0);
     $43 = ($42|0)==(1);
     if ($43) {
      __THREW__ = 0;
      invoke_viii(3262,($35|0),1,1);
      $44 = __THREW__; __THREW__ = 0;
      $45 = $44&1;
      if ($45) {
       break;
      }
     }
    }
   }
   $46 = HEAP32[$4>>2]|0;
   $47 = ((($46)) + 56|0);
   $48 = HEAP32[$47>>2]|0;
   __THREW__ = 0;
   $49 = (invoke_i($48|0)|0);
   $50 = __THREW__; __THREW__ = 0;
   $51 = $50&1;
   if (!($51)) {
    HEAP32[$5>>2] = $49;
    HEAP8[$9>>0] = 1;
    $72 = ((($0)) + 36|0);
    HEAP8[$72>>0] = 1;
    $73 = ((($0)) + 37|0);
    HEAP8[$73>>0] = 0;
    return;
   }
  }
 } while(0);
 $52 = ___cxa_find_matching_catch_2()|0;
 $53 = tempRet0;
 $54 = HEAP32[$28>>2]|0;
 $55 = ($54|0)==(0|0);
 if (!($55)) {
  $56 = HEAP32[$29>>2]|0;
  $57 = ($56|0)==($54|0);
  do {
   if ($57) {
    $71 = $54;
   } else {
    $59 = $56;
    while(1) {
     $58 = ((($59)) + -4|0);
     HEAP32[$29>>2] = $58;
     $60 = HEAP32[$58>>2]|0;
     $61 = ($60|0)==(0|0);
     if (!($61)) {
      $62 = ((($60)) + 8|0);
      $63 = HEAP32[$62>>2]|0;HEAP32[$62>>2] = (($63-1)|0);
      $64 = ($63|0)==(1);
      if ($64) {
       __THREW__ = 0;
       invoke_viii(3262,($60|0),1,1);
       $65 = __THREW__; __THREW__ = 0;
       $66 = $65&1;
       if ($66) {
        label = 17;
        break;
       }
      }
     }
     HEAP32[$58>>2] = 0;
     $67 = HEAP32[$29>>2]|0;
     $68 = ($67|0)==($54|0);
     if ($68) {
      label = 18;
      break;
     } else {
      $59 = $67;
     }
    }
    if ((label|0) == 17) {
     $69 = ___cxa_find_matching_catch_2()|0;
     $70 = tempRet0;
     ___cxa_call_unexpected(($69|0));
     // unreachable;
    }
    else if ((label|0) == 18) {
     $$pre$i16 = HEAP32[$28>>2]|0;
     $71 = $$pre$i16;
     break;
    }
   }
  } while(0);
  __ZdlPv($71);
 }
 $74 = HEAP32[$26>>2]|0;
 $75 = ($74|0)==(0|0);
 if (!($75)) {
  $76 = HEAP32[$27>>2]|0;
  $77 = ($76|0)==($74|0);
  do {
   if ($77) {
    $91 = $74;
   } else {
    $79 = $76;
    while(1) {
     $78 = ((($79)) + -4|0);
     HEAP32[$27>>2] = $78;
     $80 = HEAP32[$78>>2]|0;
     $81 = ($80|0)==(0|0);
     if (!($81)) {
      $82 = ((($80)) + 8|0);
      $83 = HEAP32[$82>>2]|0;HEAP32[$82>>2] = (($83-1)|0);
      $84 = ($83|0)==(1);
      if ($84) {
       __THREW__ = 0;
       invoke_viii(3262,($80|0),1,1);
       $85 = __THREW__; __THREW__ = 0;
       $86 = $85&1;
       if ($86) {
        label = 27;
        break;
       }
      }
     }
     HEAP32[$78>>2] = 0;
     $87 = HEAP32[$27>>2]|0;
     $88 = ($87|0)==($74|0);
     if ($88) {
      label = 28;
      break;
     } else {
      $79 = $87;
     }
    }
    if ((label|0) == 27) {
     $89 = ___cxa_find_matching_catch_2()|0;
     $90 = tempRet0;
     ___cxa_call_unexpected(($89|0));
     // unreachable;
    }
    else if ((label|0) == 28) {
     $$pre$i = HEAP32[$26>>2]|0;
     $91 = $$pre$i;
     break;
    }
   }
  } while(0);
  __ZdlPv($91);
 }
 $92 = HEAP32[$25>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIjNS_4pairIN3osg7ref_ptrIKNS3_7UniformEEEjEEEENS_19__map_value_compareIjS9_NS_4lessIjEELb1EEENS_9allocatorIS9_EEE7destroyEPNS_11__tree_nodeIS9_PvEE($22,$92);
 $93 = HEAP32[$21>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7Program16UniformBlockInfoEEENS_19__map_value_compareIS7_SB_NS_4lessIS7_EELb1EEENS5_ISB_EEE7destroyEPNS_11__tree_nodeISB_PvEE($18,$93);
 $94 = HEAP32[$17>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7Program13ActiveVarInfoEEENS_19__map_value_compareIS7_SB_NS_4lessIS7_EELb1EEENS5_ISB_EEE7destroyEPNS_11__tree_nodeISB_PvEE($14,$94);
 $95 = HEAP32[$13>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIjN3osg7Program13ActiveVarInfoEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($10,$95);
 $96 = ((($6)) + 11|0);
 $97 = HEAP8[$96>>0]|0;
 $98 = ($97<<24>>24)<(0);
 if ($98) {
  $99 = HEAP32[$6>>2]|0;
  __ZdlPv($99);
 }
 $100 = HEAP32[$4>>2]|0;
 $101 = ($100|0)==(0|0);
 if (!($101)) {
  $102 = ((($100)) + 8|0);
  $103 = HEAP32[$102>>2]|0;HEAP32[$102>>2] = (($103-1)|0);
  $104 = ($103|0)==(1);
  if ($104) {
   __THREW__ = 0;
   invoke_viii(3262,($100|0),1,1);
   $105 = __THREW__; __THREW__ = 0;
   $106 = $105&1;
   if ($106) {
    $109 = ___cxa_find_matching_catch_3(0|0)|0;
    $110 = tempRet0;
    ___clang_call_terminate($109);
    // unreachable;
   }
  }
 }
 HEAP32[$4>>2] = 0;
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $107 = __THREW__; __THREW__ = 0;
 $108 = $107&1;
 if ($108) {
  $109 = ___cxa_find_matching_catch_3(0|0)|0;
  $110 = tempRet0;
  ___clang_call_terminate($109);
  // unreachable;
 } else {
  ___resumeException($52|0);
  // unreachable;
 }
}
function __ZNSt3__26vectorIN3osg7ref_ptrINS1_7Program17PerContextProgramEEENS_9allocatorIS5_EEE21__push_back_slow_pathIKS5_EEvRT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$06$i$i = 0, $$pre = 0, $$pre$i = 0, $$pre38 = 0, $$pre39 = 0, $$sroa$7$0 = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(1073741823);
 $9 = $4;
 $10 = $3;
 if ($8) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $11 = ((($0)) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) - ($4))|0;
 $14 = $13 >> 2;
 $15 = ($14>>>0)<(536870911);
 $16 = $13 >> 1;
 $17 = ($16>>>0)<($7>>>0);
 $$sroa$speculated$i = $17 ? $7 : $16;
 $$sroa$speculated$$i = $15 ? $$sroa$speculated$i : 1073741823;
 $18 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($18) {
   $28 = 0;
  } else {
   $19 = ($$sroa$speculated$$i>>>0)>(1073741823);
   if (!($19)) {
    $25 = $$sroa$speculated$$i << 2;
    $26 = (__Znwj($25)|0);
    $28 = $26;
    break;
   }
   $20 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($20|0),(204840|0));
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if ($22) {
    $23 = ___cxa_find_matching_catch_2()|0;
    $24 = tempRet0;
    ___cxa_free_exception(($20|0));
    ___resumeException($23|0);
    // unreachable;
   } else {
    HEAP32[$20>>2] = (99824);
    ___cxa_throw(($20|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $27 = (($28) + ($6<<2)|0);
 $29 = $27;
 $30 = (($28) + ($$sroa$speculated$$i<<2)|0);
 $31 = $30;
 $32 = HEAP32[$1>>2]|0;
 HEAP32[$27>>2] = $32;
 $33 = ($32|0)==(0|0);
 if ($33) {
  $38 = $10;$40 = $9;
 } else {
  $34 = ((($32)) + 8|0);
  $35 = HEAP32[$34>>2]|0;HEAP32[$34>>2] = (($35+1)|0);
  $$pre = HEAP32[$0>>2]|0;
  $$pre38 = HEAP32[$2>>2]|0;
  $38 = $$pre38;$40 = $$pre;
 }
 $36 = ((($27)) + 4|0);
 $37 = $36;
 $39 = ($38|0)==($40|0);
 if ($39) {
  $41 = $38;
  $53 = $29;$54 = $41;$56 = $38;
 } else {
  $$06$i$i = $38;$$sroa$7$0 = $29;$44 = $27;
  while(1) {
   $42 = ((($$06$i$i)) + -4|0);
   $43 = ((($44)) + -4|0);
   $45 = HEAP32[$42>>2]|0;
   HEAP32[$43>>2] = $45;
   $46 = ($45|0)==(0|0);
   if (!($46)) {
    $47 = ((($45)) + 8|0);
    $48 = HEAP32[$47>>2]|0;HEAP32[$47>>2] = (($48+1)|0);
   }
   $49 = $$sroa$7$0;
   $50 = ((($49)) + -4|0);
   $51 = $50;
   $52 = ($42|0)==($40|0);
   if ($52) {
    break;
   } else {
    $$06$i$i = $42;$$sroa$7$0 = $51;$44 = $50;
   }
  }
  $$pre$i = HEAP32[$0>>2]|0;
  $$pre39 = HEAP32[$2>>2]|0;
  $53 = $51;$54 = $$pre$i;$56 = $$pre39;
 }
 HEAP32[$0>>2] = $53;
 HEAP32[$2>>2] = $37;
 HEAP32[$11>>2] = $31;
 $55 = $54;
 $57 = ($56|0)==($55|0);
 L25: do {
  if (!($57)) {
   $59 = $56;
   while(1) {
    $58 = ((($59)) + -4|0);
    $60 = HEAP32[$58>>2]|0;
    $61 = ($60|0)==(0|0);
    if (!($61)) {
     $62 = ((($60)) + 8|0);
     $63 = HEAP32[$62>>2]|0;HEAP32[$62>>2] = (($63-1)|0);
     $64 = ($63|0)==(1);
     if ($64) {
      __THREW__ = 0;
      invoke_viii(3262,($60|0),1,1);
      $65 = __THREW__; __THREW__ = 0;
      $66 = $65&1;
      if ($66) {
       break;
      }
     }
    }
    HEAP32[$58>>2] = 0;
    $67 = ($58|0)==($55|0);
    if ($67) {
     break L25;
    } else {
     $59 = $58;
    }
   }
   $68 = ___cxa_find_matching_catch_2()|0;
   $69 = tempRet0;
   ___cxa_call_unexpected(($68|0));
   // unreachable;
  }
 } while(0);
 $70 = ($54|0)==(0);
 if ($70) {
  return;
 }
 $71 = $54;
 __ZdlPv($71);
 return;
}
function __ZNSt3__26__treeINS_12__value_typeIjNS_4pairIN3osg7ref_ptrIKNS3_7UniformEEEjEEEENS_19__map_value_compareIjS9_NS_4lessIjEELb1EEENS_9allocatorIS9_EEE7destroyEPNS_11__tree_nodeIS9_PvEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 }
 $3 = HEAP32[$1>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIjNS_4pairIN3osg7ref_ptrIKNS3_7UniformEEEjEEEENS_19__map_value_compareIjS9_NS_4lessIjEELb1EEENS_9allocatorIS9_EEE7destroyEPNS_11__tree_nodeIS9_PvEE($0,$3);
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIjNS_4pairIN3osg7ref_ptrIKNS3_7UniformEEEjEEEENS_19__map_value_compareIjS9_NS_4lessIjEELb1EEENS_9allocatorIS9_EEE7destroyEPNS_11__tree_nodeIS9_PvEE($0,$5);
 $6 = ((($1)) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = ((($7)) + 8|0);
  $10 = HEAP32[$9>>2]|0;HEAP32[$9>>2] = (($10-1)|0);
  $11 = ($10|0)==(1);
  if ($11) {
   __THREW__ = 0;
   invoke_viii(3262,($7|0),1,1);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if ($13) {
    $14 = ___cxa_find_matching_catch_2()|0;
    $15 = tempRet0;
    ___cxa_call_unexpected(($14|0));
    // unreachable;
   }
  }
 }
 __ZdlPv($1);
 return;
}
function __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7Program16UniformBlockInfoEEENS_19__map_value_compareIS7_SB_NS_4lessIS7_EELb1EEENS5_ISB_EEE7destroyEPNS_11__tree_nodeISB_PvEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 }
 $3 = HEAP32[$1>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7Program16UniformBlockInfoEEENS_19__map_value_compareIS7_SB_NS_4lessIS7_EELb1EEENS5_ISB_EEE7destroyEPNS_11__tree_nodeISB_PvEE($0,$3);
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7Program16UniformBlockInfoEEENS_19__map_value_compareIS7_SB_NS_4lessIS7_EELb1EEENS5_ISB_EEE7destroyEPNS_11__tree_nodeISB_PvEE($0,$5);
 $6 = ((($1)) + 16|0);
 $7 = ((($6)) + 11|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = ($8<<24>>24)<(0);
 if ($9) {
  $10 = HEAP32[$6>>2]|0;
  __ZdlPv($10);
 }
 __ZdlPv($1);
 return;
}
function __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7Program13ActiveVarInfoEEENS_19__map_value_compareIS7_SB_NS_4lessIS7_EELb1EEENS5_ISB_EEE7destroyEPNS_11__tree_nodeISB_PvEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 }
 $3 = HEAP32[$1>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7Program13ActiveVarInfoEEENS_19__map_value_compareIS7_SB_NS_4lessIS7_EELb1EEENS5_ISB_EEE7destroyEPNS_11__tree_nodeISB_PvEE($0,$3);
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7Program13ActiveVarInfoEEENS_19__map_value_compareIS7_SB_NS_4lessIS7_EELb1EEENS5_ISB_EEE7destroyEPNS_11__tree_nodeISB_PvEE($0,$5);
 $6 = ((($1)) + 16|0);
 $7 = ((($6)) + 11|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = ($8<<24>>24)<(0);
 if ($9) {
  $10 = HEAP32[$6>>2]|0;
  __ZdlPv($10);
 }
 __ZdlPv($1);
 return;
}
function __ZNSt3__26__treeINS_12__value_typeIjN3osg7Program13ActiveVarInfoEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 } else {
  $3 = HEAP32[$1>>2]|0;
  __ZNSt3__26__treeINS_12__value_typeIjN3osg7Program13ActiveVarInfoEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($0,$3);
  $4 = ((($1)) + 4|0);
  $5 = HEAP32[$4>>2]|0;
  __ZNSt3__26__treeINS_12__value_typeIjN3osg7Program13ActiveVarInfoEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($0,$5);
  __ZdlPv($1);
  return;
 }
}
function __ZN3osg7Program17PerContextProgramD2Ev($0) {
 $0 = $0|0;
 var $$6 = 0, $$68 = 0, $$pre$i = 0, $$pre$i13 = 0, $$pre$i20 = 0, $$pre$i28 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (65276);
 $1 = ((($0)) + 44|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 do {
  if ($3) {
   label = 14;
  } else {
   $4 = ((($0)) + 40|0);
   $5 = HEAP32[$4>>2]|0;
   __THREW__ = 0;
   $6 = (invoke_ii(3683,($5|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    __THREW__ = 0;
    $9 = (invoke_ii(3859,($6|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     $12 = HEAP32[$9>>2]|0;
     $13 = ((($12)) + 44|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = ((($0)) + 20|0);
     $16 = HEAP32[$15>>2]|0;
     __THREW__ = 0;
     invoke_vii($14|0,($9|0),($16|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if (!($18)) {
      label = 14;
      break;
     }
    }
   }
   $19 = ___cxa_find_matching_catch_2()|0;
   $20 = tempRet0;
   $21 = ((($0)) + 108|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = ($22|0)==(0|0);
   if (!($23)) {
    $24 = ((($0)) + 112|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = ($25|0)==($22|0);
    do {
     if ($26) {
      $40 = $22;
     } else {
      $28 = $25;
      while(1) {
       $27 = ((($28)) + -4|0);
       HEAP32[$24>>2] = $27;
       $29 = HEAP32[$27>>2]|0;
       $30 = ($29|0)==(0|0);
       if (!($30)) {
        $31 = ((($29)) + 8|0);
        $32 = HEAP32[$31>>2]|0;HEAP32[$31>>2] = (($32-1)|0);
        $33 = ($32|0)==(1);
        if ($33) {
         __THREW__ = 0;
         invoke_viii(3262,($29|0),1,1);
         $34 = __THREW__; __THREW__ = 0;
         $35 = $34&1;
         if ($35) {
          label = 11;
          break;
         }
        }
       }
       HEAP32[$27>>2] = 0;
       $36 = HEAP32[$24>>2]|0;
       $37 = ($36|0)==($22|0);
       if ($37) {
        label = 12;
        break;
       } else {
        $28 = $36;
       }
      }
      if ((label|0) == 11) {
       $38 = ___cxa_find_matching_catch_2()|0;
       $39 = tempRet0;
       ___cxa_call_unexpected(($38|0));
       // unreachable;
      }
      else if ((label|0) == 12) {
       $$pre$i = HEAP32[$21>>2]|0;
       $40 = $$pre$i;
       break;
      }
     }
    } while(0);
    __ZdlPv($40);
   }
   $106 = ((($0)) + 96|0);
   $107 = HEAP32[$106>>2]|0;
   $108 = ($107|0)==(0|0);
   if (!($108)) {
    $109 = ((($0)) + 100|0);
    $110 = HEAP32[$109>>2]|0;
    $111 = ($110|0)==($107|0);
    do {
     if ($111) {
      $125 = $107;
     } else {
      $113 = $110;
      while(1) {
       $112 = ((($113)) + -4|0);
       HEAP32[$109>>2] = $112;
       $114 = HEAP32[$112>>2]|0;
       $115 = ($114|0)==(0|0);
       if (!($115)) {
        $116 = ((($114)) + 8|0);
        $117 = HEAP32[$116>>2]|0;HEAP32[$116>>2] = (($117-1)|0);
        $118 = ($117|0)==(1);
        if ($118) {
         __THREW__ = 0;
         invoke_viii(3262,($114|0),1,1);
         $119 = __THREW__; __THREW__ = 0;
         $120 = $119&1;
         if ($120) {
          label = 44;
          break;
         }
        }
       }
       HEAP32[$112>>2] = 0;
       $121 = HEAP32[$109>>2]|0;
       $122 = ($121|0)==($107|0);
       if ($122) {
        label = 45;
        break;
       } else {
        $113 = $121;
       }
      }
      if ((label|0) == 44) {
       $123 = ___cxa_find_matching_catch_2()|0;
       $124 = tempRet0;
       ___cxa_call_unexpected(($123|0));
       // unreachable;
      }
      else if ((label|0) == 45) {
       $$pre$i28 = HEAP32[$106>>2]|0;
       $125 = $$pre$i28;
       break;
      }
     }
    } while(0);
    __ZdlPv($125);
   }
   $126 = ((($0)) + 84|0);
   $127 = ((($0)) + 88|0);
   $128 = HEAP32[$127>>2]|0;
   __ZNSt3__26__treeINS_12__value_typeIjNS_4pairIN3osg7ref_ptrIKNS3_7UniformEEEjEEEENS_19__map_value_compareIjS9_NS_4lessIjEELb1EEENS_9allocatorIS9_EEE7destroyEPNS_11__tree_nodeIS9_PvEE($126,$128);
   $129 = ((($0)) + 72|0);
   $130 = ((($0)) + 76|0);
   $131 = HEAP32[$130>>2]|0;
   __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7Program16UniformBlockInfoEEENS_19__map_value_compareIS7_SB_NS_4lessIS7_EELb1EEENS5_ISB_EEE7destroyEPNS_11__tree_nodeISB_PvEE($129,$131);
   $132 = ((($0)) + 60|0);
   $133 = ((($0)) + 64|0);
   $134 = HEAP32[$133>>2]|0;
   __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7Program13ActiveVarInfoEEENS_19__map_value_compareIS7_SB_NS_4lessIS7_EELb1EEENS5_ISB_EEE7destroyEPNS_11__tree_nodeISB_PvEE($132,$134);
   $135 = ((($0)) + 48|0);
   $136 = ((($0)) + 52|0);
   $137 = HEAP32[$136>>2]|0;
   __ZNSt3__26__treeINS_12__value_typeIjN3osg7Program13ActiveVarInfoEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($135,$137);
   $138 = ((($0)) + 24|0);
   $139 = ((($138)) + 11|0);
   $140 = HEAP8[$139>>0]|0;
   $141 = ($140<<24>>24)<(0);
   if ($141) {
    $142 = HEAP32[$138>>2]|0;
    __ZdlPv($142);
   }
   $143 = ((($0)) + 16|0);
   $144 = HEAP32[$143>>2]|0;
   $145 = ($144|0)==(0|0);
   if (!($145)) {
    $146 = ((($144)) + 8|0);
    $147 = HEAP32[$146>>2]|0;HEAP32[$146>>2] = (($147-1)|0);
    $148 = ($147|0)==(1);
    if ($148) {
     __THREW__ = 0;
     invoke_viii(3262,($144|0),1,1);
     $149 = __THREW__; __THREW__ = 0;
     $150 = $149&1;
     if ($150) {
      $155 = ___cxa_find_matching_catch_3(0|0)|0;
      $156 = tempRet0;
      ___clang_call_terminate($155);
      // unreachable;
     }
    }
   }
   HEAP32[$143>>2] = 0;
   $$6 = $20;$$68 = $19;
  }
 } while(0);
 do {
  if ((label|0) == 14) {
   $41 = ((($0)) + 108|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = ($42|0)==(0|0);
   if (!($43)) {
    $44 = ((($0)) + 112|0);
    $45 = HEAP32[$44>>2]|0;
    $46 = ($45|0)==($42|0);
    do {
     if ($46) {
      $60 = $42;
     } else {
      $48 = $45;
      while(1) {
       $47 = ((($48)) + -4|0);
       HEAP32[$44>>2] = $47;
       $49 = HEAP32[$47>>2]|0;
       $50 = ($49|0)==(0|0);
       if (!($50)) {
        $51 = ((($49)) + 8|0);
        $52 = HEAP32[$51>>2]|0;HEAP32[$51>>2] = (($52-1)|0);
        $53 = ($52|0)==(1);
        if ($53) {
         __THREW__ = 0;
         invoke_viii(3262,($49|0),1,1);
         $54 = __THREW__; __THREW__ = 0;
         $55 = $54&1;
         if ($55) {
          label = 20;
          break;
         }
        }
       }
       HEAP32[$47>>2] = 0;
       $56 = HEAP32[$44>>2]|0;
       $57 = ($56|0)==($42|0);
       if ($57) {
        label = 21;
        break;
       } else {
        $48 = $56;
       }
      }
      if ((label|0) == 20) {
       $58 = ___cxa_find_matching_catch_2()|0;
       $59 = tempRet0;
       ___cxa_call_unexpected(($58|0));
       // unreachable;
      }
      else if ((label|0) == 21) {
       $$pre$i13 = HEAP32[$41>>2]|0;
       $60 = $$pre$i13;
       break;
      }
     }
    } while(0);
    __ZdlPv($60);
   }
   $61 = ((($0)) + 96|0);
   $62 = HEAP32[$61>>2]|0;
   $63 = ($62|0)==(0|0);
   if (!($63)) {
    $64 = ((($0)) + 100|0);
    $65 = HEAP32[$64>>2]|0;
    $66 = ($65|0)==($62|0);
    do {
     if ($66) {
      $80 = $62;
     } else {
      $68 = $65;
      while(1) {
       $67 = ((($68)) + -4|0);
       HEAP32[$64>>2] = $67;
       $69 = HEAP32[$67>>2]|0;
       $70 = ($69|0)==(0|0);
       if (!($70)) {
        $71 = ((($69)) + 8|0);
        $72 = HEAP32[$71>>2]|0;HEAP32[$71>>2] = (($72-1)|0);
        $73 = ($72|0)==(1);
        if ($73) {
         __THREW__ = 0;
         invoke_viii(3262,($69|0),1,1);
         $74 = __THREW__; __THREW__ = 0;
         $75 = $74&1;
         if ($75) {
          label = 29;
          break;
         }
        }
       }
       HEAP32[$67>>2] = 0;
       $76 = HEAP32[$64>>2]|0;
       $77 = ($76|0)==($62|0);
       if ($77) {
        label = 30;
        break;
       } else {
        $68 = $76;
       }
      }
      if ((label|0) == 29) {
       $78 = ___cxa_find_matching_catch_2()|0;
       $79 = tempRet0;
       ___cxa_call_unexpected(($78|0));
       // unreachable;
      }
      else if ((label|0) == 30) {
       $$pre$i20 = HEAP32[$61>>2]|0;
       $80 = $$pre$i20;
       break;
      }
     }
    } while(0);
    __ZdlPv($80);
   }
   $81 = ((($0)) + 84|0);
   $82 = ((($0)) + 88|0);
   $83 = HEAP32[$82>>2]|0;
   __ZNSt3__26__treeINS_12__value_typeIjNS_4pairIN3osg7ref_ptrIKNS3_7UniformEEEjEEEENS_19__map_value_compareIjS9_NS_4lessIjEELb1EEENS_9allocatorIS9_EEE7destroyEPNS_11__tree_nodeIS9_PvEE($81,$83);
   $84 = ((($0)) + 72|0);
   $85 = ((($0)) + 76|0);
   $86 = HEAP32[$85>>2]|0;
   __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7Program16UniformBlockInfoEEENS_19__map_value_compareIS7_SB_NS_4lessIS7_EELb1EEENS5_ISB_EEE7destroyEPNS_11__tree_nodeISB_PvEE($84,$86);
   $87 = ((($0)) + 60|0);
   $88 = ((($0)) + 64|0);
   $89 = HEAP32[$88>>2]|0;
   __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7Program13ActiveVarInfoEEENS_19__map_value_compareIS7_SB_NS_4lessIS7_EELb1EEENS5_ISB_EEE7destroyEPNS_11__tree_nodeISB_PvEE($87,$89);
   $90 = ((($0)) + 48|0);
   $91 = ((($0)) + 52|0);
   $92 = HEAP32[$91>>2]|0;
   __ZNSt3__26__treeINS_12__value_typeIjN3osg7Program13ActiveVarInfoEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($90,$92);
   $93 = ((($0)) + 24|0);
   $94 = ((($93)) + 11|0);
   $95 = HEAP8[$94>>0]|0;
   $96 = ($95<<24>>24)<(0);
   if ($96) {
    $97 = HEAP32[$93>>2]|0;
    __ZdlPv($97);
   }
   $98 = ((($0)) + 16|0);
   $99 = HEAP32[$98>>2]|0;
   $100 = ($99|0)==(0|0);
   if ($100) {
    HEAP32[$98>>2] = 0;
    __ZN3osg10ReferencedD2Ev($0);
    return;
   }
   $101 = ((($99)) + 8|0);
   $102 = HEAP32[$101>>2]|0;HEAP32[$101>>2] = (($102-1)|0);
   $103 = ($102|0)==(1);
   if (!($103)) {
    HEAP32[$98>>2] = 0;
    __ZN3osg10ReferencedD2Ev($0);
    return;
   }
   __THREW__ = 0;
   invoke_viii(3262,($99|0),1,1);
   $104 = __THREW__; __THREW__ = 0;
   $105 = $104&1;
   if ($105) {
    $151 = ___cxa_find_matching_catch_2()|0;
    $152 = tempRet0;
    $$6 = $152;$$68 = $151;
    break;
   } else {
    HEAP32[$98>>2] = 0;
    __ZN3osg10ReferencedD2Ev($0);
    return;
   }
  }
 } while(0);
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $153 = __THREW__; __THREW__ = 0;
 $154 = $153&1;
 if ($154) {
  $155 = ___cxa_find_matching_catch_3(0|0)|0;
  $156 = tempRet0;
  ___clang_call_terminate($155);
  // unreachable;
 } else {
  ___resumeException($$68|0);
  // unreachable;
 }
}
function __ZN3osg7Program17PerContextProgramD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(2194,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZN3osg7Program17PerContextProgram11linkProgramERNS_5StateE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$$i = 0, $$0$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i238 = 0, $$0$i$i$i$i248 = 0, $$0$i$i$i$i262 = 0, $$0$i$i$i$i330 = 0, $$0$i$i$i$i397 = 0, $$0$i$i209 = 0, $$0$i$i315 = 0, $$0$i$i340 = 0, $$0$i$i357 = 0, $$0$i$i409 = 0, $$0$i$i434 = 0, $$0$ph$i$i = 0, $$0$ph$i$i206 = 0, $$0$ph$i$i337 = 0, $$0$ph$i$i354 = 0, $$0$ph$i$i406 = 0, $$0$ph$i$i431 = 0;
 var $$014$i = 0, $$014$i218 = 0, $$014$i343 = 0, $$014$i363 = 0, $$014$i418 = 0, $$014$i437 = 0, $$0155752 = 0, $$0157753 = 0, $$0158755 = 0, $$0159757 = 0, $$016$i$i = 0, $$016$i$i347 = 0, $$016$i$i489 = 0, $$0160761 = 0, $$017$i$i = 0, $$017$i$i348 = 0, $$017$i$i490 = 0, $$0193 = 0, $$0193$in = 0, $$0194768 = 0;
 var $$0195792 = 0, $$0196778 = 0, $$024$i$i = 0, $$024$i$i208 = 0, $$024$i$i339 = 0, $$024$i$i356 = 0, $$024$i$i408 = 0, $$024$i$i433 = 0, $$025$i$i = 0, $$025$i$i211 = 0, $$025$i$i341 = 0, $$025$i$i359 = 0, $$025$i$i411 = 0, $$025$i$i435 = 0, $$025$i47$i = 0, $$025$i47$i213 = 0, $$025$i47$i360 = 0, $$025$i53$i = 0, $$025$i53$i413 = 0, $$025$i65$i = 0;
 var $$034$i = 0, $$034$i210 = 0, $$034$i358 = 0, $$03446$i = 0, $$03446$i214 = 0, $$03446$i361 = 0, $$037$i = 0, $$037$i410 = 0, $$03752$i = 0, $$03752$i414 = 0, $$049$i = 0, $$04964$i = 0, $$0795 = 0, $$11 = 0, $$11172 = 0, $$15 = 0, $$15176 = 0, $$16 = 0, $$16177 = 0, $$17 = 0;
 var $$17178 = 0, $$18 = 0, $$18179 = 0, $$19 = 0, $$19180 = 0, $$21 = 0, $$21182 = 0, $$25 = 0, $$25186 = 0, $$28 = 0, $$28189 = 0, $$29 = 0, $$29190 = 0, $$30 = 0, $$30191 = 0, $$31 = 0, $$31192 = 0, $$4 = 0, $$4165 = 0, $$5 = 0;
 var $$5166 = 0, $$6 = 0, $$6167 = 0, $$7 = 0, $$7168 = 0, $$cast = 0, $$in = 0, $$in$i$i = 0, $$in$i$i205 = 0, $$in$i$i336 = 0, $$in$i$i353 = 0, $$in$i$i405 = 0, $$in$i$i430 = 0, $$phi$trans$insert = 0, $$pr597$pre = 0, $$pre = 0, $$pre$i$i = 0, $$pre$i$i$i$i = 0, $$pre$i$i216 = 0, $$pre$i$i342 = 0;
 var $$pre$i$i362 = 0, $$pre$i$i416 = 0, $$pre$i$i436 = 0, $$pre$phi884Z2D = 0, $$pre$phi886Z2D = 0, $$pre$phi890Z2D = 0, $$pre$phi892Z2D = 0, $$pre$phi897Z2D = 0, $$pre$phi901Z2D = 0, $$pre$phi905Z2D = 0, $$pre$phi907Z2D = 0, $$pre$phi909Z2D = 0, $$pre$phi913Z2D = 0, $$pre$phi917Z2D = 0, $$pre$phi919Z2D = 0, $$pre$phi923Z2D = 0, $$pre$phi927Z2D = 0, $$pre864 = 0, $$pre865 = 0, $$pre866 = 0;
 var $$pre867 = 0, $$pre869 = 0, $$pre870 = 0, $$pre871 = 0, $$pre873 = 0, $$pre875 = 0, $$pre876 = 0, $$pre877 = 0, $$pre878 = 0, $$pre879 = 0, $$pre880 = 0, $$pre883 = 0, $$pre889 = 0, $$pre896 = 0, $$pre900 = 0, $$pre908 = 0, $$pre910 = 0, $$pre916 = 0, $$pre918 = 0, $$pre920 = 0;
 var $$pre926 = 0, $$sink599$index = 0, $$sink599$index12 = 0, $$sroa$0505$0$be = 0, $$sroa$0505$0765 = 0, $$sroa$0517$0$$sroa_idx = 0, $$sroa$0541$0$be = 0, $$sroa$0541$0775 = 0, $$sroa$0558$0$be = 0, $$sroa$0558$0780 = 0, $$sroa$0565$0$be = 0, $$sroa$0565$0783 = 0, $$sroa$0574$0$be = 0, $$sroa$0574$0786 = 0, $$sroa$0584$0$be = 0, $$sroa$0584$0789 = 0, $$sroa$5$0$$sroa_idx496 = 0, $$sroa$5520$0$$sroa_idx521 = 0, $$sroa$6$0$$sroa_idx499 = 0, $$sroa$6524$0$$sroa_idx525 = 0;
 var $10 = 0, $100 = 0, $1000 = 0, $1001 = 0, $1002 = 0, $1003 = 0, $1004 = 0, $1005 = 0, $1006 = 0, $1007 = 0, $1008 = 0, $1009 = 0, $101 = 0, $1010 = 0, $1011 = 0, $1012 = 0, $1013 = 0, $1014 = 0, $1015 = 0, $1016 = 0;
 var $1017 = 0, $1018 = 0, $1019 = 0, $102 = 0, $1020 = 0, $1021 = 0, $1022 = 0, $1023 = 0, $1024 = 0, $1025 = 0, $1026 = 0, $1027 = 0, $1028 = 0, $1029 = 0, $103 = 0, $1030 = 0, $1031 = 0, $1032 = 0, $1033 = 0, $1034 = 0;
 var $1035 = 0, $1036 = 0, $1037 = 0, $1038 = 0, $1039 = 0, $104 = 0, $1040 = 0, $1041 = 0, $1042 = 0, $1043 = 0, $1044 = 0, $1045 = 0, $1046 = 0, $1047 = 0, $1048 = 0, $1049 = 0, $105 = 0, $1050 = 0, $1051 = 0, $1052 = 0;
 var $1053 = 0, $1054 = 0, $1055 = 0, $1056 = 0, $1057 = 0, $1058 = 0, $1059 = 0, $106 = 0, $1060 = 0, $1061 = 0, $1062 = 0, $1063 = 0, $1064 = 0, $1065 = 0, $1066 = 0, $1067 = 0, $1068 = 0, $1069 = 0, $107 = 0, $1070 = 0;
 var $1071 = 0, $1072 = 0, $1073 = 0, $1074 = 0, $1075 = 0, $1076 = 0, $1077 = 0, $1078 = 0, $1079 = 0, $108 = 0, $1080 = 0, $1081 = 0, $1082 = 0, $1083 = 0, $1084 = 0, $1085 = 0, $1086 = 0, $1087 = 0, $1088 = 0, $1089 = 0;
 var $109 = 0, $1090 = 0, $1091 = 0, $1092 = 0, $1093 = 0, $1094 = 0, $1095 = 0, $1096 = 0, $1097 = 0, $1098 = 0, $1099 = 0, $11 = 0, $110 = 0, $1100 = 0, $1101 = 0, $1102 = 0, $1103 = 0, $1104 = 0, $1105 = 0, $1106 = 0;
 var $1107 = 0, $1108 = 0, $1109 = 0, $111 = 0, $1110 = 0, $1111 = 0, $1112 = 0, $1113 = 0, $1114 = 0, $1115 = 0, $1116 = 0, $1117 = 0, $1118 = 0, $1119 = 0, $112 = 0, $1120 = 0, $1121 = 0, $1122 = 0, $1123 = 0, $1124 = 0;
 var $1125 = 0, $1126 = 0, $1127 = 0, $1128 = 0, $1129 = 0, $113 = 0, $1130 = 0, $1131 = 0, $1132 = 0, $1133 = 0, $1134 = 0, $1135 = 0, $1136 = 0, $1137 = 0, $1138 = 0, $1139 = 0, $114 = 0, $1140 = 0, $1141 = 0, $1142 = 0;
 var $1143 = 0, $1144 = 0, $1145 = 0, $1146 = 0, $1147 = 0, $1148 = 0, $1149 = 0, $115 = 0, $1150 = 0, $1151 = 0, $1152 = 0, $1153 = 0, $1154 = 0, $1155 = 0, $1156 = 0, $1157 = 0, $1158 = 0, $1159 = 0, $116 = 0, $1160 = 0;
 var $1161 = 0, $1162 = 0, $1163 = 0, $1164 = 0, $1165 = 0, $1166 = 0, $1167 = 0, $1168 = 0, $1169 = 0, $117 = 0, $1170 = 0, $1171 = 0, $1172 = 0, $1173 = 0, $1174 = 0, $1175 = 0, $1176 = 0, $1177 = 0, $1178 = 0, $1179 = 0;
 var $118 = 0, $1180 = 0, $1181 = 0, $1182 = 0, $1183 = 0, $1184 = 0, $1185 = 0, $1186 = 0, $1187 = 0, $1188 = 0, $1189 = 0, $119 = 0, $1190 = 0, $1191 = 0, $1192 = 0, $1193 = 0, $1194 = 0, $1195 = 0, $1196 = 0, $1197 = 0;
 var $1198 = 0, $1199 = 0, $12 = 0, $120 = 0, $1200 = 0, $1201 = 0, $1202 = 0, $1203 = 0, $1204 = 0, $1205 = 0, $1206 = 0, $1207 = 0, $1208 = 0, $1209 = 0, $121 = 0, $1210 = 0, $1211 = 0, $1212 = 0, $1213 = 0, $1214 = 0;
 var $1215 = 0, $1216 = 0, $1217 = 0, $1218 = 0, $1219 = 0, $122 = 0, $1220 = 0, $1221 = 0, $1222 = 0, $1223 = 0, $1224 = 0, $1225 = 0, $1226 = 0, $1227 = 0, $1228 = 0, $1229 = 0, $123 = 0, $1230 = 0, $1231 = 0, $1232 = 0;
 var $1233 = 0, $1234 = 0, $1235 = 0, $1236 = 0, $1237 = 0, $1238 = 0, $1239 = 0, $124 = 0, $1240 = 0, $1241 = 0, $1242 = 0, $1243 = 0, $1244 = 0, $1245 = 0, $1246 = 0, $1247 = 0, $1248 = 0, $1249 = 0, $125 = 0, $1250 = 0;
 var $1251 = 0, $1252 = 0, $1253 = 0, $1254 = 0, $1255 = 0, $1256 = 0, $1257 = 0, $1258 = 0, $1259 = 0, $126 = 0, $1260 = 0, $1261 = 0, $1262 = 0, $1263 = 0, $1264 = 0, $1265 = 0, $1266 = 0, $1267 = 0, $1268 = 0, $1269 = 0;
 var $127 = 0, $1270 = 0, $1271 = 0, $1272 = 0, $1273 = 0, $1274 = 0, $1275 = 0, $1276 = 0, $1277 = 0, $1278 = 0, $1279 = 0, $128 = 0, $1280 = 0, $1281 = 0, $1282 = 0, $1283 = 0, $1284 = 0, $1285 = 0, $1286 = 0, $1287 = 0;
 var $1288 = 0, $1289 = 0, $129 = 0, $1290 = 0, $1291 = 0, $1292 = 0, $1293 = 0, $1294 = 0, $1295 = 0, $1296 = 0, $1297 = 0, $1298 = 0, $1299 = 0, $13 = 0, $130 = 0, $1300 = 0, $1301 = 0, $1302 = 0, $1303 = 0, $1304 = 0;
 var $1305 = 0, $1306 = 0, $1307 = 0, $1308 = 0, $1309 = 0, $131 = 0, $1310 = 0, $1311 = 0, $1312 = 0, $1313 = 0, $1314 = 0, $1315 = 0, $1316 = 0, $1317 = 0, $1318 = 0, $1319 = 0, $132 = 0, $1320 = 0, $1321 = 0, $1322 = 0;
 var $1323 = 0, $1324 = 0, $1325 = 0, $1326 = 0, $1327 = 0, $1328 = 0, $1329 = 0, $133 = 0, $1330 = 0, $1331 = 0, $1332 = 0, $1333 = 0, $1334 = 0, $1335 = 0, $1336 = 0, $1337 = 0, $1338 = 0, $1339 = 0, $134 = 0, $1340 = 0;
 var $1341 = 0, $1342 = 0, $1343 = 0, $1344 = 0, $1345 = 0, $1346 = 0, $1347 = 0, $1348 = 0, $1349 = 0, $135 = 0, $1350 = 0, $1351 = 0, $1352 = 0, $1353 = 0, $1354 = 0, $1355 = 0, $1356 = 0, $1357 = 0, $1358 = 0, $1359 = 0;
 var $136 = 0, $1360 = 0, $1361 = 0, $1362 = 0, $1363 = 0, $1364 = 0, $1365 = 0, $1366 = 0, $1367 = 0, $1368 = 0, $1369 = 0, $137 = 0, $1370 = 0, $1371 = 0, $1372 = 0, $1373 = 0, $1374 = 0, $1375 = 0, $1376 = 0, $1377 = 0;
 var $1378 = 0, $1379 = 0, $138 = 0, $1380 = 0, $1381 = 0, $1382 = 0, $1383 = 0, $1384 = 0, $1385 = 0, $1386 = 0, $1387 = 0, $1388 = 0, $1389 = 0, $139 = 0, $1390 = 0, $1391 = 0, $1392 = 0, $1393 = 0, $1394 = 0, $1395 = 0;
 var $1396 = 0, $1397 = 0, $1398 = 0, $1399 = 0, $14 = 0, $140 = 0, $1400 = 0, $1401 = 0, $1402 = 0, $1403 = 0, $1404 = 0, $1405 = 0, $1406 = 0, $1407 = 0, $1408 = 0, $1409 = 0, $141 = 0, $1410 = 0, $1411 = 0, $1412 = 0;
 var $1413 = 0, $1414 = 0, $1415 = 0, $1416 = 0, $1417 = 0, $1418 = 0, $1419 = 0, $142 = 0, $1420 = 0, $1421 = 0, $1422 = 0, $1423 = 0, $1424 = 0, $1425 = 0, $1426 = 0, $1427 = 0, $1428 = 0, $1429 = 0, $143 = 0, $1430 = 0;
 var $1431 = 0, $1432 = 0, $1433 = 0, $1434 = 0, $1435 = 0, $1436 = 0, $1437 = 0, $1438 = 0, $1439 = 0, $144 = 0, $1440 = 0, $1441 = 0, $1442 = 0, $1443 = 0, $1444 = 0, $1445 = 0, $1446 = 0, $1447 = 0, $1448 = 0, $1449 = 0;
 var $145 = 0, $1450 = 0, $1451 = 0, $1452 = 0, $1453 = 0, $1454 = 0, $1455 = 0, $1456 = 0, $1457 = 0, $1458 = 0, $1459 = 0, $146 = 0, $1460 = 0, $1461 = 0, $1462 = 0, $1463 = 0, $1464 = 0, $1465 = 0, $1466 = 0, $1467 = 0;
 var $1468 = 0, $1469 = 0, $147 = 0, $1470 = 0, $1471 = 0, $1472 = 0, $1473 = 0, $1474 = 0, $1475 = 0, $1476 = 0, $1477 = 0, $1478 = 0, $1479 = 0, $148 = 0, $1480 = 0, $1481 = 0, $1482 = 0, $1483 = 0, $1484 = 0, $1485 = 0;
 var $1486 = 0, $1487 = 0, $1488 = 0, $1489 = 0, $149 = 0, $1490 = 0, $1491 = 0, $1492 = 0, $1493 = 0, $1494 = 0, $1495 = 0, $1496 = 0, $1497 = 0, $1498 = 0, $1499 = 0, $15 = 0, $150 = 0, $1500 = 0, $1501 = 0, $1502 = 0;
 var $1503 = 0, $1504 = 0, $1505 = 0, $1506 = 0, $1507 = 0, $1508 = 0, $1509 = 0, $151 = 0, $1510 = 0, $1511 = 0, $1512 = 0, $1513 = 0, $1514 = 0, $1515 = 0, $1516 = 0, $1517 = 0, $1518 = 0, $1519 = 0, $152 = 0, $1520 = 0;
 var $1521 = 0, $1522 = 0, $1523 = 0, $1524 = 0, $1525 = 0, $1526 = 0, $1527 = 0, $1528 = 0, $1529 = 0, $153 = 0, $1530 = 0, $1531 = 0, $1532 = 0, $1533 = 0, $1534 = 0, $1535 = 0, $1536 = 0, $1537 = 0, $1538 = 0, $1539 = 0;
 var $154 = 0, $1540 = 0, $1541 = 0, $1542 = 0, $1543 = 0, $1544 = 0, $1545 = 0, $1546 = 0, $1547 = 0, $1548 = 0, $1549 = 0, $155 = 0, $1550 = 0, $1551 = 0, $1552 = 0, $1553 = 0, $1554 = 0, $1555 = 0, $1556 = 0, $1557 = 0;
 var $1558 = 0, $1559 = 0, $156 = 0, $1560 = 0, $1561 = 0, $1562 = 0, $1563 = 0, $1564 = 0, $1565 = 0, $1566 = 0, $1567 = 0, $1568 = 0, $1569 = 0, $157 = 0, $1570 = 0, $1571 = 0, $1572 = 0, $1573 = 0, $1574 = 0, $1575 = 0;
 var $1576 = 0, $1577 = 0, $1578 = 0, $1579 = 0, $158 = 0, $1580 = 0, $1581 = 0, $1582 = 0, $1583 = 0, $1584 = 0, $1585 = 0, $1586 = 0, $1587 = 0, $1588 = 0, $1589 = 0, $159 = 0, $1590 = 0, $1591 = 0, $1592 = 0, $1593 = 0;
 var $1594 = 0, $1595 = 0, $1596 = 0, $1597 = 0, $1598 = 0, $1599 = 0, $16 = 0, $160 = 0, $1600 = 0, $1601 = 0, $1602 = 0, $1603 = 0, $1604 = 0, $1605 = 0, $1606 = 0, $1607 = 0, $1608 = 0, $1609 = 0, $161 = 0, $1610 = 0;
 var $1611 = 0, $1612 = 0, $1613 = 0, $1614 = 0, $1615 = 0, $1616 = 0, $1617 = 0, $1618 = 0, $1619 = 0, $162 = 0, $1620 = 0, $1621 = 0, $1622 = 0, $1623 = 0, $1624 = 0, $1625 = 0, $1626 = 0, $1627 = 0, $1628 = 0, $1629 = 0;
 var $163 = 0, $1630 = 0, $1631 = 0, $1632 = 0, $1633 = 0, $1634 = 0, $1635 = 0, $1636 = 0, $1637 = 0, $1638 = 0, $1639 = 0, $164 = 0, $1640 = 0, $1641 = 0, $1642 = 0, $1643 = 0, $1644 = 0, $1645 = 0, $1646 = 0, $1647 = 0;
 var $1648 = 0, $1649 = 0, $165 = 0, $1650 = 0, $1651 = 0, $1652 = 0, $1653 = 0, $1654 = 0, $1655 = 0, $1656 = 0, $1657 = 0, $1658 = 0, $1659 = 0, $166 = 0, $1660 = 0, $1661 = 0, $1662 = 0, $1663 = 0, $1664 = 0, $1665 = 0;
 var $1666 = 0, $1667 = 0, $1668 = 0, $1669 = 0, $167 = 0, $1670 = 0, $1671 = 0, $1672 = 0, $1673 = 0, $1674 = 0, $1675 = 0, $1676 = 0, $1677 = 0, $1678 = 0, $1679 = 0, $168 = 0, $1680 = 0, $1681 = 0, $1682 = 0, $1683 = 0;
 var $1684 = 0, $1685 = 0, $1686 = 0, $1687 = 0, $1688 = 0, $1689 = 0, $169 = 0, $1690 = 0, $1691 = 0, $1692 = 0, $1693 = 0, $1694 = 0, $1695 = 0, $1696 = 0, $1697 = 0, $1698 = 0, $1699 = 0, $17 = 0, $170 = 0, $1700 = 0;
 var $1701 = 0, $1702 = 0, $1703 = 0, $1704 = 0, $1705 = 0, $1706 = 0, $1707 = 0, $1708 = 0, $1709 = 0, $171 = 0, $1710 = 0, $1711 = 0, $1712 = 0, $1713 = 0, $1714 = 0, $1715 = 0, $1716 = 0, $1717 = 0, $1718 = 0, $1719 = 0;
 var $172 = 0, $1720 = 0, $1721 = 0, $1722 = 0, $1723 = 0, $1724 = 0, $1725 = 0, $1726 = 0, $1727 = 0, $1728 = 0, $1729 = 0, $173 = 0, $1730 = 0, $1731 = 0, $1732 = 0, $1733 = 0, $1734 = 0, $1735 = 0, $1736 = 0, $1737 = 0;
 var $1738 = 0, $1739 = 0, $174 = 0, $1740 = 0, $1741 = 0, $1742 = 0, $1743 = 0, $1744 = 0, $1745 = 0, $1746 = 0, $1747 = 0, $1748 = 0, $1749 = 0, $175 = 0, $1750 = 0, $1751 = 0, $1752 = 0, $1753 = 0, $1754 = 0, $1755 = 0;
 var $1756 = 0, $1757 = 0, $1758 = 0, $1759 = 0, $176 = 0, $1760 = 0, $1761 = 0, $1762 = 0, $1763 = 0, $1764 = 0, $1765 = 0, $1766 = 0, $1767 = 0, $1768 = 0, $1769 = 0, $177 = 0, $1770 = 0, $1771 = 0, $1772 = 0, $1773 = 0;
 var $1774 = 0, $1775 = 0, $1776 = 0, $1777 = 0, $1778 = 0, $1779 = 0, $178 = 0, $1780 = 0, $1781 = 0, $1782 = 0, $1783 = 0, $1784 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0;
 var $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0;
 var $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0;
 var $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0;
 var $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0;
 var $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0;
 var $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0;
 var $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0;
 var $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0;
 var $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0;
 var $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0;
 var $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0;
 var $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0;
 var $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0;
 var $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0;
 var $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0;
 var $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0;
 var $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0;
 var $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0;
 var $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0;
 var $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0;
 var $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0;
 var $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0;
 var $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0;
 var $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0;
 var $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0;
 var $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0;
 var $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0;
 var $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0;
 var $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0;
 var $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0;
 var $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0;
 var $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0;
 var $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0;
 var $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0;
 var $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0;
 var $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = 0;
 var $834 = 0, $835 = 0, $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0, $850 = 0, $851 = 0;
 var $852 = 0, $853 = 0, $854 = 0, $855 = 0, $856 = 0, $857 = 0, $858 = 0, $859 = 0, $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0, $869 = 0, $87 = 0;
 var $870 = 0, $871 = 0, $872 = 0, $873 = 0, $874 = 0, $875 = 0, $876 = 0, $877 = 0, $878 = 0, $879 = 0, $88 = 0, $880 = 0, $881 = 0, $882 = 0, $883 = 0, $884 = 0, $885 = 0, $886 = 0, $887 = 0, $888 = 0;
 var $889 = 0, $89 = 0, $890 = 0, $891 = 0, $892 = 0, $893 = 0, $894 = 0, $895 = 0, $896 = 0, $897 = 0, $898 = 0, $899 = 0, $9 = 0, $90 = 0, $900 = 0, $901 = 0, $902 = 0, $903 = 0, $904 = 0, $905 = 0;
 var $906 = 0, $907 = 0, $908 = 0, $909 = 0, $91 = 0, $910 = 0, $911 = 0, $912 = 0, $913 = 0, $914 = 0, $915 = 0, $916 = 0, $917 = 0, $918 = 0, $919 = 0, $92 = 0, $920 = 0, $921 = 0, $922 = 0, $923 = 0;
 var $924 = 0, $925 = 0, $926 = 0, $927 = 0, $928 = 0, $929 = 0, $93 = 0, $930 = 0, $931 = 0, $932 = 0, $933 = 0, $934 = 0, $935 = 0, $936 = 0, $937 = 0, $938 = 0, $939 = 0, $94 = 0, $940 = 0, $941 = 0;
 var $942 = 0, $943 = 0, $944 = 0, $945 = 0, $946 = 0, $947 = 0, $948 = 0, $949 = 0, $95 = 0, $950 = 0, $951 = 0, $952 = 0, $953 = 0, $954 = 0, $955 = 0, $956 = 0, $957 = 0, $958 = 0, $959 = 0, $96 = 0;
 var $960 = 0, $961 = 0, $962 = 0, $963 = 0, $964 = 0, $965 = 0, $966 = 0, $967 = 0, $968 = 0, $969 = 0, $97 = 0, $970 = 0, $971 = 0, $972 = 0, $973 = 0, $974 = 0, $975 = 0, $976 = 0, $977 = 0, $978 = 0;
 var $979 = 0, $98 = 0, $980 = 0, $981 = 0, $982 = 0, $983 = 0, $984 = 0, $985 = 0, $986 = 0, $987 = 0, $988 = 0, $989 = 0, $99 = 0, $990 = 0, $991 = 0, $992 = 0, $993 = 0, $994 = 0, $995 = 0, $996 = 0;
 var $997 = 0, $998 = 0, $999 = 0, $eh$lpad$body$index48Z2D = 0, $eh$lpad$body$indexZ2D = 0, $eh$lpad$body226$index53Z2D = 0, $eh$lpad$body226$indexZ2D = 0, $eh$lpad$body285$index19Z2D = 0, $eh$lpad$body285$indexZ2D = 0, $eh$lpad$body307$index24Z2D = 0, $eh$lpad$body307$indexZ2D = 0, $eh$lpad$body322$index29Z2D = 0, $eh$lpad$body322$indexZ2D = 0, $eh$lpad$body385$index34Z2D = 0, $eh$lpad$body385$indexZ2D = 0, $eh$lpad$body458$index41Z2D = 0, $eh$lpad$body458$indexZ2D = 0, $or$cond = 0, $or$cond3 = 0, $or$cond601 = 0;
 var $scevgep$i$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i$i$i452 = 0, $scevgep$i$i$i465 = 0, $scevgep$i$i$i470 = 0, $scevgep$i$i$i473 = 0, $scevgep$i$i$i478 = 0, $scevgep$i$i$i483 = 0, $scevgep5$i$i$i = 0, $scevgep5$i$i$i$i = 0, $scevgep5$i$i$i$i453 = 0, $scevgep5$i$i$i466 = 0, $scevgep5$i$i$i471 = 0, $scevgep5$i$i$i474 = 0, $scevgep5$i$i$i479 = 0, $scevgep5$i$i$i484 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 368|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(368|0);
 $2 = sp + 356|0;
 $3 = sp + 352|0;
 $4 = sp + 348|0;
 $5 = sp + 344|0;
 $6 = sp + 340|0;
 $7 = sp + 336|0;
 $8 = sp + 332|0;
 $9 = sp + 328|0;
 $10 = sp + 324|0;
 $11 = sp + 320|0;
 $12 = sp + 316|0;
 $13 = sp + 312|0;
 $14 = sp + 232|0;
 $15 = sp + 220|0;
 $16 = sp + 216|0;
 $17 = sp + 204|0;
 $18 = sp + 192|0;
 $19 = sp + 188|0;
 $20 = sp + 184|0;
 $21 = sp + 172|0;
 $22 = sp + 168|0;
 $23 = sp + 164|0;
 $24 = sp + 144|0;
 $25 = sp + 132|0;
 $26 = sp + 120|0;
 $27 = sp + 116|0;
 $28 = sp + 112|0;
 $29 = sp + 108|0;
 $30 = sp + 104|0;
 $31 = sp + 92|0;
 $32 = sp + 80|0;
 $33 = sp + 68|0;
 $34 = sp + 56|0;
 $35 = sp + 52|0;
 $36 = sp + 48|0;
 $37 = sp + 44|0;
 $38 = sp + 40|0;
 $39 = sp + 36|0;
 $40 = sp + 24|0;
 $41 = sp + 20|0;
 $42 = sp + 16|0;
 $43 = sp + 12|0;
 $44 = sp;
 $45 = ((($0)) + 36|0);
 $46 = HEAP8[$45>>0]|0;
 $47 = ($46<<24>>24)==(0);
 if ($47) {
  STACKTOP = sp;return;
 }
 HEAP8[$45>>0] = 0;
 $48 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
 do {
  if ($48) {
   $49 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
   $50 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($49,146498,22)|0);
   $51 = ((($0)) + 12|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = ((($52)) + 12|0);
   $54 = ((($53)) + 11|0);
   $55 = HEAP8[$54>>0]|0;
   $56 = ($55<<24>>24)<(0);
   $57 = HEAP32[$53>>2]|0;
   $58 = $56 ? $57 : $53;
   $59 = ((($52)) + 16|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = $55&255;
   $62 = $56 ? $60 : $61;
   $63 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($50,$58,$62)|0);
   $64 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($63,172027,1)|0);
   $65 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($64,146471,4)|0);
   $66 = ((($0)) + 20|0);
   $67 = HEAP32[$66>>2]|0;
   $68 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($65,$67)|0);
   $69 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($68,146476,11)|0);
   $70 = ((($0)) + 40|0);
   $71 = HEAP32[$70>>2]|0;
   $72 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($69,$71)|0);
   $73 = HEAP32[$72>>2]|0;
   $74 = ((($73)) + -12|0);
   $75 = HEAP32[$74>>2]|0;
   $76 = (($72) + ($75)|0);
   __ZNKSt3__28ios_base6getlocEv($11,$76);
   __THREW__ = 0;
   $77 = (invoke_iii(3255,($11|0),(215188|0))|0);
   $78 = __THREW__; __THREW__ = 0;
   $79 = $78&1;
   if (!($79)) {
    $80 = HEAP32[$77>>2]|0;
    $81 = ((($80)) + 28|0);
    $82 = HEAP32[$81>>2]|0;
    __THREW__ = 0;
    $83 = (invoke_iii($82|0,($77|0),10)|0);
    $84 = __THREW__; __THREW__ = 0;
    $85 = $84&1;
    if (!($85)) {
     __ZNSt3__26localeD2Ev($11);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($72,$83)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($72)|0);
     $$pre$phi897Z2D = $51;
     break;
    }
   }
   $86 = ___cxa_find_matching_catch_2()|0;
   $87 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($11|0));
   $88 = __THREW__; __THREW__ = 0;
   $89 = $88&1;
   if ($89) {
    $90 = ___cxa_find_matching_catch_3(0|0)|0;
    $91 = tempRet0;
    ___clang_call_terminate($90);
    // unreachable;
   } else {
    ___resumeException($86|0);
    // unreachable;
   }
  } else {
   $$pre896 = ((($0)) + 12|0);
   $$pre$phi897Z2D = $$pre896;
  }
 } while(0);
 $92 = HEAP32[$$pre$phi897Z2D>>2]|0;
 $93 = ((($92)) + 116|0);
 $94 = HEAP32[$93>>2]|0;
 $95 = ((($0)) + 38|0);
 HEAP8[$95>>0] = 0;
 $96 = ($94|0)!=(0|0);
 if ($96) {
  $97 = ((($94)) + 32|0);
  $98 = ((($94)) + 36|0);
  $99 = HEAP32[$98>>2]|0;
  $100 = HEAP32[$97>>2]|0;
  $101 = ($99|0)==($100|0);
  $102 = $100;
  if ($101) {
   label = 13;
  } else {
   $103 = $99;
   HEAP32[$12>>2] = 0;
   $104 = ((($0)) + 16|0);
   $105 = HEAP32[$104>>2]|0;
   $106 = ((($105)) + 612|0);
   $107 = HEAP32[$106>>2]|0;
   $108 = ((($0)) + 20|0);
   $109 = HEAP32[$108>>2]|0;
   $110 = ((($94)) + 44|0);
   $111 = HEAP32[$110>>2]|0;
   $112 = ($102|0)==($103|0);
   $$$i = $112 ? 0 : $102;
   $113 = (($99) - ($100))|0;
   FUNCTION_TABLE_viiii[$107 & 8191]($109,$111,$$$i,$113);
   $114 = HEAP32[$104>>2]|0;
   $115 = ((($114)) + 104|0);
   $116 = HEAP32[$115>>2]|0;
   $117 = HEAP32[$108>>2]|0;
   FUNCTION_TABLE_viii[$116 & 8191]($117,35714,$12);
   $118 = HEAP32[$12>>2]|0;
   $119 = ($118|0)==(1);
   $120 = ((($0)) + 37|0);
   $121 = $119&1;
   HEAP8[$120>>0] = $121;
   HEAP8[$95>>0] = $121;
   if (!($119)) {
    label = 13;
   }
  }
 } else {
  label = 13;
 }
 L18: do {
  if ((label|0) == 13) {
   $122 = ((($0)) + 16|0);
   $123 = HEAP32[$122>>2]|0;
   $124 = ((($123)) + 29|0);
   $125 = HEAP8[$124>>0]|0;
   $126 = ($125<<24>>24)==(0);
   if (!($126)) {
    $127 = ((($123)) + 448|0);
    $128 = HEAP32[$127>>2]|0;
    $129 = ((($0)) + 20|0);
    $130 = HEAP32[$129>>2]|0;
    $131 = HEAP32[$$pre$phi897Z2D>>2]|0;
    $132 = ((($131)) + 120|0);
    $133 = HEAP32[$132>>2]|0;
    FUNCTION_TABLE_viii[$128 & 8191]($130,36314,$133);
    $134 = HEAP32[$122>>2]|0;
    $135 = ((($134)) + 448|0);
    $136 = HEAP32[$135>>2]|0;
    $137 = HEAP32[$129>>2]|0;
    $138 = HEAP32[$$pre$phi897Z2D>>2]|0;
    $139 = ((($138)) + 124|0);
    $140 = HEAP32[$139>>2]|0;
    FUNCTION_TABLE_viii[$136 & 8191]($137,36315,$140);
    $141 = HEAP32[$122>>2]|0;
    $142 = ((($141)) + 448|0);
    $143 = HEAP32[$142>>2]|0;
    $144 = HEAP32[$129>>2]|0;
    $145 = HEAP32[$$pre$phi897Z2D>>2]|0;
    $146 = ((($145)) + 128|0);
    $147 = HEAP32[$146>>2]|0;
    FUNCTION_TABLE_viii[$143 & 8191]($144,36316,$147);
    $$pr597$pre = HEAP8[$95>>0]|0;
    $148 = ($$pr597$pre<<24>>24)==(0);
    if (!($148)) {
     break;
    }
   }
   $149 = HEAP32[$122>>2]|0;
   $150 = ((($149)) + 96|0);
   $151 = HEAP32[$150>>2]|0;
   $152 = ((($0)) + 20|0);
   $153 = HEAP32[$152>>2]|0;
   FUNCTION_TABLE_viiii[$151 & 8191]($153,20,$13,$14);
   $154 = ((($15)) + 4|0);
   HEAP32[$154>>2] = 0;
   $155 = ((($15)) + 8|0);
   HEAP32[$155>>2] = 0;
   $156 = ((($15)) + 4|0);
   HEAP32[$15>>2] = $156;
   $157 = HEAP32[$13>>2]|0;
   $158 = ($157|0)>(0);
   L23: do {
    if ($158) {
     $$0795 = 0;$166 = 0;$1776 = $157;$1777 = 0;
     while(1) {
      $165 = (($14) + ($$0795<<2)|0);
      $167 = ($166|0)==(0|0);
      do {
       if ($167) {
        $$025$i$i = $156;$$034$i = $156;$178 = $1777;
        label = 29;
       } else {
        $168 = HEAP32[$165>>2]|0;
        $$0$i$i = $154;$$024$i$i = $166;$1778 = $1777;
        while(1) {
         $169 = ((($$024$i$i)) + 16|0);
         $170 = HEAP32[$169>>2]|0;
         $171 = ($168>>>0)<($170>>>0);
         if ($171) {
          $172 = HEAP32[$$024$i$i>>2]|0;
          $173 = ($172|0)==(0|0);
          if ($173) {
           label = 24;
           break;
          } else {
           $$0$ph$i$i = $$024$i$i;$$in$i$i = $172;
          }
         } else {
          $174 = ($170>>>0)<($168>>>0);
          if (!($174)) {
           label = 28;
           break;
          }
          $175 = ((($$024$i$i)) + 4|0);
          $176 = HEAP32[$175>>2]|0;
          $177 = ($176|0)==(0|0);
          if ($177) {
           label = 27;
           break;
          } else {
           $$0$ph$i$i = $175;$$in$i$i = $176;
          }
         }
         $$0$i$i = $$0$ph$i$i;$$024$i$i = $$in$i$i;$1778 = $$in$i$i;
        }
        if ((label|0) == 24) {
         label = 0;
         $$025$i47$i = $$024$i$i;$$03446$i = $$024$i$i;
         label = 30;
         break;
        }
        else if ((label|0) == 27) {
         label = 0;
         $$025$i47$i = $175;$$03446$i = $$024$i$i;
         label = 30;
         break;
        }
        else if ((label|0) == 28) {
         label = 0;
         $$025$i$i = $$0$i$i;$$034$i = $$024$i$i;$178 = $1778;
         label = 29;
         break;
        }
       }
      } while(0);
      if ((label|0) == 29) {
       label = 0;
       $179 = ($178|0)==(0|0);
       if ($179) {
        $$025$i47$i = $$025$i$i;$$03446$i = $$034$i;
        label = 30;
       } else {
        $$014$i = $178;$201 = $1776;
       }
      }
      if ((label|0) == 30) {
       label = 0;
       __THREW__ = 0;
       $180 = (invoke_ii(3276,24)|0);
       $181 = __THREW__; __THREW__ = 0;
       $182 = $181&1;
       if ($182) {
        break;
       }
       $183 = ((($180)) + 16|0);
       $184 = HEAP32[$165>>2]|0;
       HEAP32[$183>>2] = $184;
       $185 = ((($180)) + 20|0);
       HEAP32[$185>>2] = 0;
       HEAP32[$180>>2] = 0;
       $186 = ((($180)) + 4|0);
       HEAP32[$186>>2] = 0;
       $187 = ((($180)) + 8|0);
       HEAP32[$187>>2] = $$03446$i;
       HEAP32[$$025$i47$i>>2] = $180;
       $188 = HEAP32[$15>>2]|0;
       $189 = HEAP32[$188>>2]|0;
       $190 = ($189|0)==(0|0);
       if ($190) {
        $193 = $180;
       } else {
        $191 = $189;
        HEAP32[$15>>2] = $191;
        $$pre$i$i = HEAP32[$$025$i47$i>>2]|0;
        $193 = $$pre$i$i;
       }
       $192 = HEAP32[$154>>2]|0;
       __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($192,$193);
       $194 = HEAP32[$155>>2]|0;
       $195 = (($194) + 1)|0;
       HEAP32[$155>>2] = $195;
       $$pre864 = HEAP32[$13>>2]|0;
       $$014$i = $180;$201 = $$pre864;
      }
      $196 = ((($$014$i)) + 20|0);
      $197 = HEAP32[$196>>2]|0;
      $198 = (($197) + -1)|0;
      HEAP32[$196>>2] = $198;
      $199 = (($$0795) + 1)|0;
      $200 = ($199|0)<($201|0);
      if (!($200)) {
       label = 17;
       break L23;
      }
      $$pre = HEAP32[$156>>2]|0;
      $$0795 = $199;$166 = $$pre;$1776 = $201;$1777 = $$pre;
     }
     $202 = ___cxa_find_matching_catch_2()|0;
     $203 = tempRet0;
     $$pre$phi892Z2D = $156;$$sink599$index = $202;$$sink599$index12 = $203;
    } else {
     label = 17;
    }
   } while(0);
   L51: do {
    if ((label|0) == 17) {
     $159 = HEAP32[$$pre$phi897Z2D>>2]|0;
     $160 = ((($159)) + 104|0);
     $161 = ((($159)) + 108|0);
     $162 = HEAP32[$161>>2]|0;
     $163 = HEAP32[$160>>2]|0;
     $164 = ($162|0)==($163|0);
     L53: do {
      if (!($164)) {
       $$0195792 = 0;$207 = $159;
       while(1) {
        $206 = ((($207)) + 104|0);
        $208 = HEAP32[$206>>2]|0;
        $209 = (($208) + ($$0195792<<2)|0);
        $210 = HEAP32[$209>>2]|0;
        __THREW__ = 0;
        $211 = (invoke_iii(3860,($210|0),($1|0))|0);
        $212 = __THREW__; __THREW__ = 0;
        $213 = $212&1;
        if ($213) {
         label = 55;
         break;
        }
        $214 = ($211|0)==(0|0);
        if (!($214)) {
         $215 = ((($211)) + 20|0);
         $216 = HEAP32[$215>>2]|0;
         $217 = HEAP32[$156>>2]|0;
         $218 = ($217|0)==(0|0);
         do {
          if ($218) {
           $$025$i$i211 = $156;$$034$i210 = $156;$228 = $217;
           label = 49;
          } else {
           $$0$i$i209 = $154;$$024$i$i208 = $217;$1779 = $217;
           while(1) {
            $219 = ((($$024$i$i208)) + 16|0);
            $220 = HEAP32[$219>>2]|0;
            $221 = ($216>>>0)<($220>>>0);
            if ($221) {
             $222 = HEAP32[$$024$i$i208>>2]|0;
             $223 = ($222|0)==(0|0);
             if ($223) {
              label = 44;
              break;
             } else {
              $$0$ph$i$i206 = $$024$i$i208;$$in$i$i205 = $222;
             }
            } else {
             $224 = ($220>>>0)<($216>>>0);
             if (!($224)) {
              label = 48;
              break;
             }
             $225 = ((($$024$i$i208)) + 4|0);
             $226 = HEAP32[$225>>2]|0;
             $227 = ($226|0)==(0|0);
             if ($227) {
              label = 47;
              break;
             } else {
              $$0$ph$i$i206 = $225;$$in$i$i205 = $226;
             }
            }
            $$0$i$i209 = $$0$ph$i$i206;$$024$i$i208 = $$in$i$i205;$1779 = $$in$i$i205;
           }
           if ((label|0) == 44) {
            label = 0;
            $$025$i47$i213 = $$024$i$i208;$$03446$i214 = $$024$i$i208;
            label = 50;
            break;
           }
           else if ((label|0) == 47) {
            label = 0;
            $$025$i47$i213 = $225;$$03446$i214 = $$024$i$i208;
            label = 50;
            break;
           }
           else if ((label|0) == 48) {
            label = 0;
            $$025$i$i211 = $$0$i$i209;$$034$i210 = $$024$i$i208;$228 = $1779;
            label = 49;
            break;
           }
          }
         } while(0);
         if ((label|0) == 49) {
          label = 0;
          $229 = ($228|0)==(0|0);
          if ($229) {
           $$025$i47$i213 = $$025$i$i211;$$03446$i214 = $$034$i210;
           label = 50;
          } else {
           $$014$i218 = $228;
          }
         }
         if ((label|0) == 50) {
          label = 0;
          __THREW__ = 0;
          $230 = (invoke_ii(3276,24)|0);
          $231 = __THREW__; __THREW__ = 0;
          $232 = $231&1;
          if ($232) {
           label = 56;
           break;
          }
          $233 = ((($230)) + 16|0);
          HEAP32[$233>>2] = $216;
          $234 = ((($230)) + 20|0);
          HEAP32[$234>>2] = 0;
          HEAP32[$230>>2] = 0;
          $235 = ((($230)) + 4|0);
          HEAP32[$235>>2] = 0;
          $236 = ((($230)) + 8|0);
          HEAP32[$236>>2] = $$03446$i214;
          HEAP32[$$025$i47$i213>>2] = $230;
          $237 = HEAP32[$15>>2]|0;
          $238 = HEAP32[$237>>2]|0;
          $239 = ($238|0)==(0|0);
          if ($239) {
           $242 = $230;
          } else {
           $240 = $238;
           HEAP32[$15>>2] = $240;
           $$pre$i$i216 = HEAP32[$$025$i47$i213>>2]|0;
           $242 = $$pre$i$i216;
          }
          $241 = HEAP32[$154>>2]|0;
          __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($241,$242);
          $243 = HEAP32[$155>>2]|0;
          $244 = (($243) + 1)|0;
          HEAP32[$155>>2] = $244;
          $$014$i218 = $230;
         }
         $245 = ((($$014$i218)) + 20|0);
         $246 = HEAP32[$245>>2]|0;
         $247 = (($246) + 1)|0;
         HEAP32[$245>>2] = $247;
        }
        $252 = (($$0195792) + 1)|0;
        $253 = HEAP32[$$pre$phi897Z2D>>2]|0;
        $254 = ((($253)) + 104|0);
        $255 = ((($253)) + 108|0);
        $256 = HEAP32[$255>>2]|0;
        $257 = HEAP32[$254>>2]|0;
        $258 = (($256) - ($257))|0;
        $259 = $258 >> 2;
        $260 = ($252>>>0)<($259>>>0);
        if ($260) {
         $$0195792 = $252;$207 = $253;
        } else {
         break L53;
        }
       }
       if ((label|0) == 55) {
        $248 = ___cxa_find_matching_catch_2()|0;
        $249 = tempRet0;
        $$pre$phi892Z2D = $156;$$sink599$index = $248;$$sink599$index12 = $249;
        break L51;
       }
       else if ((label|0) == 56) {
        $250 = ___cxa_find_matching_catch_2()|0;
        $251 = tempRet0;
        $$pre$phi892Z2D = $156;$$sink599$index = $250;$$sink599$index12 = $251;
        break L51;
       }
      }
     } while(0);
     $204 = HEAP32[$15>>2]|0;
     $205 = ($204|0)==($156|0);
     L86: do {
      if (!($205)) {
       $$sroa$0584$0789 = $204;
       while(1) {
        $262 = ((($$sroa$0584$0789)) + 16|0);
        $263 = ((($$sroa$0584$0789)) + 20|0);
        $264 = HEAP32[$263>>2]|0;
        $265 = ($264|0)>(0);
        if ($265) {
         $266 = HEAP32[$122>>2]|0;
         $267 = ((($266)) + 44|0);
         $268 = HEAP32[$267>>2]|0;
         $269 = HEAP32[$152>>2]|0;
         $270 = HEAP32[$262>>2]|0;
         __THREW__ = 0;
         invoke_vii($268|0,($269|0),($270|0));
         $271 = __THREW__; __THREW__ = 0;
         $272 = $271&1;
         if ($272) {
          break;
         }
        } else {
         $273 = ($264|0)<(0);
         if ($273) {
          $274 = HEAP32[$122>>2]|0;
          $275 = ((($274)) + 76|0);
          $276 = HEAP32[$275>>2]|0;
          $277 = HEAP32[$152>>2]|0;
          $278 = HEAP32[$262>>2]|0;
          __THREW__ = 0;
          invoke_vii($276|0,($277|0),($278|0));
          $279 = __THREW__; __THREW__ = 0;
          $280 = $279&1;
          if ($280) {
           break;
          }
         }
        }
        $281 = ((($$sroa$0584$0789)) + 4|0);
        $282 = HEAP32[$281>>2]|0;
        $283 = ($282|0)==(0|0);
        if ($283) {
         $284 = ((($$sroa$0584$0789)) + 8|0);
         $285 = HEAP32[$284>>2]|0;
         $286 = HEAP32[$285>>2]|0;
         $287 = ($286|0)==($$sroa$0584$0789|0);
         if ($287) {
          $$sroa$0584$0$be = $285;
         } else {
          $292 = $284;
          while(1) {
           $291 = HEAP32[$292>>2]|0;
           $293 = ((($291)) + 8|0);
           $294 = HEAP32[$293>>2]|0;
           $295 = HEAP32[$294>>2]|0;
           $296 = ($295|0)==($291|0);
           if ($296) {
            $$sroa$0584$0$be = $294;
            break;
           } else {
            $292 = $293;
           }
          }
         }
        } else {
         $$0$i$i$i$i = $282;
         while(1) {
          $289 = HEAP32[$$0$i$i$i$i>>2]|0;
          $290 = ($289|0)==(0|0);
          if ($290) {
           break;
          } else {
           $$0$i$i$i$i = $289;
          }
         }
         $$sroa$0584$0$be = $$0$i$i$i$i;
        }
        $288 = ($$sroa$0584$0$be|0)==($156|0);
        if ($288) {
         break L86;
        } else {
         $$sroa$0584$0789 = $$sroa$0584$0$be;
        }
       }
       $297 = ___cxa_find_matching_catch_2()|0;
       $298 = tempRet0;
       $$pre$phi892Z2D = $156;$$sink599$index = $297;$$sink599$index12 = $298;
       break L51;
      }
     } while(0);
     $261 = HEAP32[$156>>2]|0;
     __ZNSt3__26__treeINS_12__value_typeIjiEENS_19__map_value_compareIjS2_NS_4lessIjEELb1EEENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($15,$261);
     break L18;
    }
   } while(0);
   $299 = HEAP32[$$pre$phi892Z2D>>2]|0;
   __ZNSt3__26__treeINS_12__value_typeIjiEENS_19__map_value_compareIjS2_NS_4lessIjEELb1EEENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($15,$299);
   $$31 = $$sink599$index;$$31192 = $$sink599$index12;
   ___resumeException($$31|0);
   // unreachable;
  }
 } while(0);
 $300 = ((($0)) + 96|0);
 $301 = HEAP32[$300>>2]|0;
 $302 = ((($0)) + 100|0);
 $303 = HEAP32[$302>>2]|0;
 $304 = ($303|0)==($301|0);
 L107: do {
  if (!($304)) {
   $306 = $303;
   while(1) {
    $305 = ((($306)) + -4|0);
    HEAP32[$302>>2] = $305;
    $307 = HEAP32[$305>>2]|0;
    $308 = ($307|0)==(0|0);
    if (!($308)) {
     $309 = ((($307)) + 8|0);
     $310 = HEAP32[$309>>2]|0;HEAP32[$309>>2] = (($310-1)|0);
     $311 = ($310|0)==(1);
     if ($311) {
      __THREW__ = 0;
      invoke_viii(3262,($307|0),1,1);
      $312 = __THREW__; __THREW__ = 0;
      $313 = $312&1;
      if ($313) {
       break;
      }
     }
    }
    HEAP32[$305>>2] = 0;
    $314 = HEAP32[$302>>2]|0;
    $315 = ($314|0)==($301|0);
    if ($315) {
     break L107;
    } else {
     $306 = $314;
    }
   }
   $316 = ___cxa_find_matching_catch_2()|0;
   $317 = tempRet0;
   ___cxa_call_unexpected(($316|0));
   // unreachable;
  }
 } while(0);
 $318 = ((($0)) + 108|0);
 $319 = HEAP32[$318>>2]|0;
 $320 = ((($0)) + 112|0);
 $321 = HEAP32[$320>>2]|0;
 $322 = ($321|0)==($319|0);
 L116: do {
  if (!($322)) {
   $324 = $321;
   while(1) {
    $323 = ((($324)) + -4|0);
    HEAP32[$320>>2] = $323;
    $325 = HEAP32[$323>>2]|0;
    $326 = ($325|0)==(0|0);
    if (!($326)) {
     $327 = ((($325)) + 8|0);
     $328 = HEAP32[$327>>2]|0;HEAP32[$327>>2] = (($328-1)|0);
     $329 = ($328|0)==(1);
     if ($329) {
      __THREW__ = 0;
      invoke_viii(3262,($325|0),1,1);
      $330 = __THREW__; __THREW__ = 0;
      $331 = $330&1;
      if ($331) {
       break;
      }
     }
    }
    HEAP32[$323>>2] = 0;
    $332 = HEAP32[$320>>2]|0;
    $333 = ($332|0)==($319|0);
    if ($333) {
     break L116;
    } else {
     $324 = $332;
    }
   }
   $334 = ___cxa_find_matching_catch_2()|0;
   $335 = tempRet0;
   ___cxa_call_unexpected(($334|0));
   // unreachable;
  }
 } while(0);
 $336 = ((($0)) + 48|0);
 $337 = ((($0)) + 52|0);
 $338 = HEAP32[$337>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIjN3osg7Program13ActiveVarInfoEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($336,$338);
 $339 = ((($0)) + 56|0);
 HEAP32[$339>>2] = 0;
 HEAP32[$336>>2] = $337;
 HEAP32[$337>>2] = 0;
 $340 = ((($0)) + 60|0);
 $341 = ((($0)) + 64|0);
 $342 = HEAP32[$341>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7Program13ActiveVarInfoEEENS_19__map_value_compareIS7_SB_NS_4lessIS7_EELb1EEENS5_ISB_EEE7destroyEPNS_11__tree_nodeISB_PvEE($340,$342);
 $343 = ((($0)) + 68|0);
 HEAP32[$343>>2] = 0;
 HEAP32[$340>>2] = $341;
 HEAP32[$341>>2] = 0;
 $344 = ((($0)) + 84|0);
 $345 = ((($0)) + 88|0);
 $346 = HEAP32[$345>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIjNS_4pairIN3osg7ref_ptrIKNS3_7UniformEEEjEEEENS_19__map_value_compareIjS9_NS_4lessIjEELb1EEENS_9allocatorIS9_EEE7destroyEPNS_11__tree_nodeIS9_PvEE($344,$346);
 $347 = ((($0)) + 92|0);
 HEAP32[$347>>2] = 0;
 HEAP32[$344>>2] = $345;
 HEAP32[$345>>2] = 0;
 $348 = HEAP8[$95>>0]|0;
 $349 = ($348<<24>>24)==(0);
 if ($349) {
  $350 = HEAP32[$$pre$phi897Z2D>>2]|0;
  $351 = ((($350)) + 68|0);
  $352 = HEAP32[$351>>2]|0;
  $353 = ((($350)) + 72|0);
  $354 = ($352|0)==($353|0);
  L127: do {
   if (!($354)) {
    $355 = ((($0)) + 16|0);
    $356 = ((($0)) + 20|0);
    $$sroa$0574$0786 = $352;
    while(1) {
     $360 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
     if ($360) {
      $361 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
      $362 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($361,146521,32)|0);
      $363 = ((($$sroa$0574$0786)) + 16|0);
      $364 = ((($$sroa$0574$0786)) + 28|0);
      $365 = HEAP32[$364>>2]|0;
      $366 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($362,$365)|0);
      $367 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($366,146554,2)|0);
      $368 = ((($363)) + 11|0);
      $369 = HEAP8[$368>>0]|0;
      $370 = ($369<<24>>24)<(0);
      $371 = HEAP32[$363>>2]|0;
      $372 = $370 ? $371 : $363;
      $373 = ((($$sroa$0574$0786)) + 20|0);
      $374 = HEAP32[$373>>2]|0;
      $375 = $369&255;
      $376 = $370 ? $374 : $375;
      $377 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($367,$372,$376)|0);
      $378 = HEAP32[$377>>2]|0;
      $379 = ((($378)) + -12|0);
      $380 = HEAP32[$379>>2]|0;
      $381 = (($377) + ($380)|0);
      __ZNKSt3__28ios_base6getlocEv($8,$381);
      __THREW__ = 0;
      $382 = (invoke_iii(3255,($8|0),(215188|0))|0);
      $383 = __THREW__; __THREW__ = 0;
      $384 = $383&1;
      if ($384) {
       break;
      }
      $385 = HEAP32[$382>>2]|0;
      $386 = ((($385)) + 28|0);
      $387 = HEAP32[$386>>2]|0;
      __THREW__ = 0;
      $388 = (invoke_iii($387|0,($382|0),10)|0);
      $389 = __THREW__; __THREW__ = 0;
      $390 = $389&1;
      if ($390) {
       break;
      }
      __ZNSt3__26localeD2Ev($8);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($377,$388)|0);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($377)|0);
      $$pre$phi919Z2D = $363;$$pre$phi923Z2D = $364;$$pre$phi927Z2D = $368;
     } else {
      $$pre918 = ((($$sroa$0574$0786)) + 16|0);
      $$pre920 = ((($$sroa$0574$0786)) + 28|0);
      $$pre926 = ((($$pre918)) + 11|0);
      $$pre$phi919Z2D = $$pre918;$$pre$phi923Z2D = $$pre920;$$pre$phi927Z2D = $$pre926;
     }
     $397 = HEAP32[$355>>2]|0;
     $398 = ((($397)) + 48|0);
     $399 = HEAP32[$398>>2]|0;
     $400 = HEAP32[$356>>2]|0;
     $401 = HEAP32[$$pre$phi923Z2D>>2]|0;
     $402 = HEAP8[$$pre$phi927Z2D>>0]|0;
     $403 = ($402<<24>>24)<(0);
     if ($403) {
      $404 = HEAP32[$$pre$phi919Z2D>>2]|0;
      $405 = $404;
     } else {
      $405 = $$pre$phi919Z2D;
     }
     FUNCTION_TABLE_viii[$399 & 8191]($400,$401,$405);
     $406 = ((($$sroa$0574$0786)) + 4|0);
     $407 = HEAP32[$406>>2]|0;
     $408 = ($407|0)==(0|0);
     if ($408) {
      $409 = ((($$sroa$0574$0786)) + 8|0);
      $410 = HEAP32[$409>>2]|0;
      $411 = HEAP32[$410>>2]|0;
      $412 = ($411|0)==($$sroa$0574$0786|0);
      if ($412) {
       $$sroa$0574$0$be = $410;
      } else {
       $417 = $409;
       while(1) {
        $416 = HEAP32[$417>>2]|0;
        $418 = ((($416)) + 8|0);
        $419 = HEAP32[$418>>2]|0;
        $420 = HEAP32[$419>>2]|0;
        $421 = ($420|0)==($416|0);
        if ($421) {
         $$sroa$0574$0$be = $419;
         break;
        } else {
         $417 = $418;
        }
       }
      }
     } else {
      $$0$i$i$i$i238 = $407;
      while(1) {
       $414 = HEAP32[$$0$i$i$i$i238>>2]|0;
       $415 = ($414|0)==(0|0);
       if ($415) {
        break;
       } else {
        $$0$i$i$i$i238 = $414;
       }
      }
      $$sroa$0574$0$be = $$0$i$i$i$i238;
     }
     $413 = ($$sroa$0574$0$be|0)==($353|0);
     if ($413) {
      break L127;
     } else {
      $$sroa$0574$0786 = $$sroa$0574$0$be;
     }
    }
    $391 = ___cxa_find_matching_catch_2()|0;
    $392 = tempRet0;
    __THREW__ = 0;
    invoke_vi(3263,($8|0));
    $393 = __THREW__; __THREW__ = 0;
    $394 = $393&1;
    if ($394) {
     $395 = ___cxa_find_matching_catch_3(0|0)|0;
     $396 = tempRet0;
     ___clang_call_terminate($395);
     // unreachable;
    } else {
     ___resumeException($391|0);
     // unreachable;
    }
   }
  } while(0);
  $357 = ((($1)) + 348|0);
  $358 = HEAP8[$357>>0]|0;
  $359 = ($358<<24>>24)==(0);
  L154: do {
   if (!($359)) {
    $422 = ((($1)) + 564|0);
    $423 = HEAP32[$422>>2]|0;
    $424 = ((($1)) + 568|0);
    $425 = ($423|0)==($424|0);
    if (!($425)) {
     $426 = ((($0)) + 16|0);
     $427 = ((($0)) + 20|0);
     $$sroa$0565$0783 = $423;
     while(1) {
      $428 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
      if ($428) {
       $429 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
       $430 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($429,146557,30)|0);
       $431 = ((($$sroa$0565$0783)) + 16|0);
       $432 = ((($$sroa$0565$0783)) + 28|0);
       $433 = HEAP32[$432>>2]|0;
       $434 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($430,$433)|0);
       $435 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($434,146554,2)|0);
       $436 = ((($431)) + 11|0);
       $437 = HEAP8[$436>>0]|0;
       $438 = ($437<<24>>24)<(0);
       $439 = HEAP32[$431>>2]|0;
       $440 = $438 ? $439 : $431;
       $441 = ((($$sroa$0565$0783)) + 20|0);
       $442 = HEAP32[$441>>2]|0;
       $443 = $437&255;
       $444 = $438 ? $442 : $443;
       $445 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($435,$440,$444)|0);
       $446 = HEAP32[$445>>2]|0;
       $447 = ((($446)) + -12|0);
       $448 = HEAP32[$447>>2]|0;
       $449 = (($445) + ($448)|0);
       __ZNKSt3__28ios_base6getlocEv($7,$449);
       __THREW__ = 0;
       $450 = (invoke_iii(3255,($7|0),(215188|0))|0);
       $451 = __THREW__; __THREW__ = 0;
       $452 = $451&1;
       if ($452) {
        break;
       }
       $453 = HEAP32[$450>>2]|0;
       $454 = ((($453)) + 28|0);
       $455 = HEAP32[$454>>2]|0;
       __THREW__ = 0;
       $456 = (invoke_iii($455|0,($450|0),10)|0);
       $457 = __THREW__; __THREW__ = 0;
       $458 = $457&1;
       if ($458) {
        break;
       }
       __ZNSt3__26localeD2Ev($7);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($445,$456)|0);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($445)|0);
       $$pre$phi909Z2D = $431;$$pre$phi913Z2D = $432;$$pre$phi917Z2D = $436;
      } else {
       $$pre908 = ((($$sroa$0565$0783)) + 16|0);
       $$pre910 = ((($$sroa$0565$0783)) + 28|0);
       $$pre916 = ((($$pre908)) + 11|0);
       $$pre$phi909Z2D = $$pre908;$$pre$phi913Z2D = $$pre910;$$pre$phi917Z2D = $$pre916;
      }
      $465 = HEAP32[$426>>2]|0;
      $466 = ((($465)) + 48|0);
      $467 = HEAP32[$466>>2]|0;
      $468 = HEAP32[$427>>2]|0;
      $469 = HEAP32[$$pre$phi913Z2D>>2]|0;
      $470 = HEAP8[$$pre$phi917Z2D>>0]|0;
      $471 = ($470<<24>>24)<(0);
      if ($471) {
       $472 = HEAP32[$$pre$phi909Z2D>>2]|0;
       $473 = $472;
      } else {
       $473 = $$pre$phi909Z2D;
      }
      FUNCTION_TABLE_viii[$467 & 8191]($468,$469,$473);
      $474 = ((($$sroa$0565$0783)) + 4|0);
      $475 = HEAP32[$474>>2]|0;
      $476 = ($475|0)==(0|0);
      if ($476) {
       $477 = ((($$sroa$0565$0783)) + 8|0);
       $478 = HEAP32[$477>>2]|0;
       $479 = HEAP32[$478>>2]|0;
       $480 = ($479|0)==($$sroa$0565$0783|0);
       if ($480) {
        $$sroa$0565$0$be = $478;
       } else {
        $485 = $477;
        while(1) {
         $484 = HEAP32[$485>>2]|0;
         $486 = ((($484)) + 8|0);
         $487 = HEAP32[$486>>2]|0;
         $488 = HEAP32[$487>>2]|0;
         $489 = ($488|0)==($484|0);
         if ($489) {
          $$sroa$0565$0$be = $487;
          break;
         } else {
          $485 = $486;
         }
        }
       }
      } else {
       $$0$i$i$i$i248 = $475;
       while(1) {
        $482 = HEAP32[$$0$i$i$i$i248>>2]|0;
        $483 = ($482|0)==(0|0);
        if ($483) {
         break;
        } else {
         $$0$i$i$i$i248 = $482;
        }
       }
       $$sroa$0565$0$be = $$0$i$i$i$i248;
      }
      $481 = ($$sroa$0565$0$be|0)==($424|0);
      if ($481) {
       break L154;
      } else {
       $$sroa$0565$0783 = $$sroa$0565$0$be;
      }
     }
     $459 = ___cxa_find_matching_catch_2()|0;
     $460 = tempRet0;
     __THREW__ = 0;
     invoke_vi(3263,($7|0));
     $461 = __THREW__; __THREW__ = 0;
     $462 = $461&1;
     if ($462) {
      $463 = ___cxa_find_matching_catch_3(0|0)|0;
      $464 = tempRet0;
      ___clang_call_terminate($463);
      // unreachable;
     } else {
      ___resumeException($459|0);
      // unreachable;
     }
    }
   }
  } while(0);
  $490 = HEAP32[$$pre$phi897Z2D>>2]|0;
  $491 = ((($490)) + 80|0);
  $492 = HEAP32[$491>>2]|0;
  $493 = ((($490)) + 84|0);
  $494 = ($492|0)==($493|0);
  if (!($494)) {
   $495 = ((($0)) + 16|0);
   $496 = ((($0)) + 20|0);
   $$sroa$0558$0780 = $492;
   while(1) {
    $498 = HEAP32[$495>>2]|0;
    $499 = ((($498)) + 464|0);
    $500 = HEAP32[$499>>2]|0;
    $501 = HEAP32[$496>>2]|0;
    $502 = ((($$sroa$0558$0780)) + 16|0);
    $503 = ((($$sroa$0558$0780)) + 28|0);
    $504 = HEAP32[$503>>2]|0;
    $505 = ((($502)) + 11|0);
    $506 = HEAP8[$505>>0]|0;
    $507 = ($506<<24>>24)<(0);
    if ($507) {
     $508 = HEAP32[$502>>2]|0;
     $509 = $508;
    } else {
     $509 = $502;
    }
    FUNCTION_TABLE_viii[$500 & 8191]($501,$504,$509);
    $510 = ((($$sroa$0558$0780)) + 4|0);
    $511 = HEAP32[$510>>2]|0;
    $512 = ($511|0)==(0|0);
    if ($512) {
     $513 = ((($$sroa$0558$0780)) + 8|0);
     $514 = HEAP32[$513>>2]|0;
     $515 = HEAP32[$514>>2]|0;
     $516 = ($515|0)==($$sroa$0558$0780|0);
     if ($516) {
      $$sroa$0558$0$be = $514;
     } else {
      $521 = $513;
      while(1) {
       $520 = HEAP32[$521>>2]|0;
       $522 = ((($520)) + 8|0);
       $523 = HEAP32[$522>>2]|0;
       $524 = HEAP32[$523>>2]|0;
       $525 = ($524|0)==($520|0);
       if ($525) {
        $$sroa$0558$0$be = $523;
        break;
       } else {
        $521 = $522;
       }
      }
     }
    } else {
     $$0$i$i$i$i262 = $511;
     while(1) {
      $518 = HEAP32[$$0$i$i$i$i262>>2]|0;
      $519 = ($518|0)==(0|0);
      if ($519) {
       break;
      } else {
       $$0$i$i$i$i262 = $518;
      }
     }
     $$sroa$0558$0$be = $$0$i$i$i$i262;
    }
    $517 = ($$sroa$0558$0$be|0)==($493|0);
    if ($517) {
     break;
    } else {
     $$sroa$0558$0780 = $$sroa$0558$0$be;
    }
   }
  }
  $497 = ((($0)) + 16|0);
  if ($96) {
   $526 = HEAP32[$497>>2]|0;
   $527 = ((($526)) + 448|0);
   $528 = HEAP32[$527>>2]|0;
   $529 = ((($0)) + 20|0);
   $530 = HEAP32[$529>>2]|0;
   FUNCTION_TABLE_viii[$528 & 8191]($530,33367,1);
   $$pre$phi901Z2D = $529;
  } else {
   $$pre900 = ((($0)) + 20|0);
   $$pre$phi901Z2D = $$pre900;
  }
  HEAP32[$16>>2] = 0;
  $531 = HEAP32[$497>>2]|0;
  $532 = ((($531)) + 168|0);
  $533 = HEAP32[$532>>2]|0;
  $534 = HEAP32[$$pre$phi901Z2D>>2]|0;
  FUNCTION_TABLE_vi[$533 & 8191]($534);
  $535 = HEAP32[$497>>2]|0;
  $536 = ((($535)) + 104|0);
  $537 = HEAP32[$536>>2]|0;
  $538 = HEAP32[$$pre$phi901Z2D>>2]|0;
  FUNCTION_TABLE_viii[$537 & 8191]($538,35714,$16);
  $539 = HEAP32[$16>>2]|0;
  $540 = ($539|0)==(1);
  $541 = ((($0)) + 37|0);
  $542 = $540&1;
  HEAP8[$541>>0] = $542;
  $543 = $542;
 } else {
  $$phi$trans$insert = ((($0)) + 37|0);
  $$pre865 = HEAP8[$$phi$trans$insert>>0]|0;
  $543 = $$pre865;
 }
 $544 = ($543<<24>>24)==(0);
 if ($544) {
  $545 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
  do {
   if ($545) {
    $546 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
    $547 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($546,146588,14)|0);
    $548 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEPKv($547,$0)|0);
    $549 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($548,172027,1)|0);
    $550 = HEAP32[$$pre$phi897Z2D>>2]|0;
    $551 = ((($550)) + 12|0);
    $552 = ((($551)) + 11|0);
    $553 = HEAP8[$552>>0]|0;
    $554 = ($553<<24>>24)<(0);
    $555 = HEAP32[$551>>2]|0;
    $556 = $554 ? $555 : $551;
    $557 = ((($550)) + 16|0);
    $558 = HEAP32[$557>>2]|0;
    $559 = $553&255;
    $560 = $554 ? $558 : $559;
    $561 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($549,$556,$560)|0);
    $562 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($561,147911,8)|0);
    $563 = HEAP32[$562>>2]|0;
    $564 = ((($563)) + -12|0);
    $565 = HEAP32[$564>>2]|0;
    $566 = (($562) + ($565)|0);
    __ZNKSt3__28ios_base6getlocEv($6,$566);
    __THREW__ = 0;
    $567 = (invoke_iii(3255,($6|0),(215188|0))|0);
    $568 = __THREW__; __THREW__ = 0;
    $569 = $568&1;
    if (!($569)) {
     $570 = HEAP32[$567>>2]|0;
     $571 = ((($570)) + 28|0);
     $572 = HEAP32[$571>>2]|0;
     __THREW__ = 0;
     $573 = (invoke_iii($572|0,($567|0),10)|0);
     $574 = __THREW__; __THREW__ = 0;
     $575 = $574&1;
     if (!($575)) {
      __ZNSt3__26localeD2Ev($6);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($562,$573)|0);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($562)|0);
      break;
     }
    }
    $576 = ___cxa_find_matching_catch_2()|0;
    $577 = tempRet0;
    __THREW__ = 0;
    invoke_vi(3263,($6|0));
    $578 = __THREW__; __THREW__ = 0;
    $579 = $578&1;
    if ($579) {
     $580 = ___cxa_find_matching_catch_3(0|0)|0;
     $581 = tempRet0;
     ___clang_call_terminate($580);
     // unreachable;
    } else {
     ___resumeException($576|0);
     // unreachable;
    }
   }
  } while(0);
  ;HEAP32[$17>>2]=0|0;HEAP32[$17+4>>2]=0|0;HEAP32[$17+8>>2]=0|0;
  $582 = HEAP32[$0>>2]|0;
  $583 = ((($582)) + 20|0);
  $584 = HEAP32[$583>>2]|0;
  __THREW__ = 0;
  $585 = (invoke_iii($584|0,($0|0),($17|0))|0);
  $586 = __THREW__; __THREW__ = 0;
  $587 = $586&1;
  L217: do {
   if ($587) {
    label = 165;
   } else {
    L219: do {
     if ($585) {
      __THREW__ = 0;
      $588 = (invoke_ii(3265,3)|0);
      $589 = __THREW__; __THREW__ = 0;
      $590 = $589&1;
      if ($590) {
       label = 165;
       break L217;
      }
      if ($588) {
       __THREW__ = 0;
       $591 = (invoke_ii(3266,3)|0);
       $592 = __THREW__; __THREW__ = 0;
       $593 = $592&1;
       if ($593) {
        label = 165;
        break L217;
       }
       __THREW__ = 0;
       $594 = (invoke_iiii(3267,($591|0),(146603|0),9)|0);
       $595 = __THREW__; __THREW__ = 0;
       $596 = $595&1;
       if ($596) {
        label = 165;
        break L217;
       }
       $597 = HEAP32[$$pre$phi897Z2D>>2]|0;
       $598 = ((($597)) + 12|0);
       $599 = ((($598)) + 11|0);
       $600 = HEAP8[$599>>0]|0;
       $601 = ($600<<24>>24)<(0);
       $602 = HEAP32[$598>>2]|0;
       $603 = $601 ? $602 : $598;
       $604 = ((($597)) + 16|0);
       $605 = HEAP32[$604>>2]|0;
       $606 = $600&255;
       $607 = $601 ? $605 : $606;
       __THREW__ = 0;
       $608 = (invoke_iiii(3267,($594|0),($603|0),($607|0))|0);
       $609 = __THREW__; __THREW__ = 0;
       $610 = $609&1;
       if ($610) {
        label = 165;
        break L217;
       }
       __THREW__ = 0;
       $611 = (invoke_iiii(3267,($608|0),(147930|0),11)|0);
       $612 = __THREW__; __THREW__ = 0;
       $613 = $612&1;
       if ($613) {
        label = 165;
        break L217;
       }
       $614 = ((($17)) + 11|0);
       $615 = HEAP8[$614>>0]|0;
       $616 = ($615<<24>>24)<(0);
       $617 = HEAP32[$17>>2]|0;
       $618 = $616 ? $617 : $17;
       $619 = ((($17)) + 4|0);
       $620 = HEAP32[$619>>2]|0;
       $621 = $615&255;
       $622 = $616 ? $620 : $621;
       __THREW__ = 0;
       $623 = (invoke_iiii(3267,($611|0),($618|0),($622|0))|0);
       $624 = __THREW__; __THREW__ = 0;
       $625 = $624&1;
       if ($625) {
        label = 165;
        break L217;
       }
       $626 = HEAP32[$623>>2]|0;
       $627 = ((($626)) + -12|0);
       $628 = HEAP32[$627>>2]|0;
       $629 = (($623) + ($628)|0);
       __THREW__ = 0;
       invoke_vii(3257,($5|0),($629|0));
       $630 = __THREW__; __THREW__ = 0;
       $631 = $630&1;
       if ($631) {
        label = 165;
        break L217;
       }
       __THREW__ = 0;
       $632 = (invoke_iii(3255,($5|0),(215188|0))|0);
       $633 = __THREW__; __THREW__ = 0;
       $634 = $633&1;
       do {
        if (!($634)) {
         $635 = HEAP32[$632>>2]|0;
         $636 = ((($635)) + 28|0);
         $637 = HEAP32[$636>>2]|0;
         __THREW__ = 0;
         $638 = (invoke_iii($637|0,($632|0),10)|0);
         $639 = __THREW__; __THREW__ = 0;
         $640 = $639&1;
         if ($640) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3263,($5|0));
         $647 = __THREW__; __THREW__ = 0;
         $648 = $647&1;
         if ($648) {
          label = 165;
          break L217;
         }
         __THREW__ = 0;
         (invoke_iii(3268,($623|0),($638|0))|0);
         $649 = __THREW__; __THREW__ = 0;
         $650 = $649&1;
         if ($650) {
          label = 165;
          break L217;
         }
         __THREW__ = 0;
         (invoke_ii(3269,($623|0))|0);
         $651 = __THREW__; __THREW__ = 0;
         $652 = $651&1;
         if ($652) {
          label = 165;
          break L217;
         } else {
          break L219;
         }
        }
       } while(0);
       $641 = ___cxa_find_matching_catch_2()|0;
       $642 = tempRet0;
       __THREW__ = 0;
       invoke_vi(3263,($5|0));
       $643 = __THREW__; __THREW__ = 0;
       $644 = $643&1;
       if ($644) {
        $645 = ___cxa_find_matching_catch_3(0|0)|0;
        $646 = tempRet0;
        ___clang_call_terminate($645);
        // unreachable;
       } else {
        $$pre$phi884Z2D = $614;$eh$lpad$body285$index19Z2D = $642;$eh$lpad$body285$indexZ2D = $641;
        break L217;
       }
      }
     }
    } while(0);
    $658 = ((($17)) + 11|0);
    $659 = HEAP8[$658>>0]|0;
    $660 = ($659<<24>>24)<(0);
    if ($660) {
     $661 = HEAP32[$17>>2]|0;
     __ZdlPv($661);
    }
    STACKTOP = sp;return;
   }
  } while(0);
  if ((label|0) == 165) {
   $653 = ___cxa_find_matching_catch_2()|0;
   $654 = tempRet0;
   $$pre883 = ((($17)) + 11|0);
   $$pre$phi884Z2D = $$pre883;$eh$lpad$body285$index19Z2D = $654;$eh$lpad$body285$indexZ2D = $653;
  }
  $655 = HEAP8[$$pre$phi884Z2D>>0]|0;
  $656 = ($655<<24>>24)<(0);
  if ($656) {
   $657 = HEAP32[$17>>2]|0;
   __ZdlPv($657);
  }
  $$31 = $eh$lpad$body285$indexZ2D;$$31192 = $eh$lpad$body285$index19Z2D;
  ___resumeException($$31|0);
  // unreachable;
 }
 ;HEAP32[$18>>2]=0|0;HEAP32[$18+4>>2]=0|0;HEAP32[$18+8>>2]=0|0;
 $662 = HEAP32[$0>>2]|0;
 $663 = ((($662)) + 20|0);
 $664 = HEAP32[$663>>2]|0;
 __THREW__ = 0;
 $665 = (invoke_iii($664|0,($0|0),($18|0))|0);
 $666 = __THREW__; __THREW__ = 0;
 $667 = $666&1;
 L251: do {
  if ($667) {
   label = 191;
  } else {
   L253: do {
    if ($665) {
     __THREW__ = 0;
     $668 = (invoke_ii(3265,4)|0);
     $669 = __THREW__; __THREW__ = 0;
     $670 = $669&1;
     if ($670) {
      label = 191;
      break L251;
     }
     if ($668) {
      __THREW__ = 0;
      $671 = (invoke_ii(3266,4)|0);
      $672 = __THREW__; __THREW__ = 0;
      $673 = $672&1;
      if ($673) {
       label = 191;
       break L251;
      }
      __THREW__ = 0;
      $674 = (invoke_iiii(3267,($671|0),(146603|0),9)|0);
      $675 = __THREW__; __THREW__ = 0;
      $676 = $675&1;
      if ($676) {
       label = 191;
       break L251;
      }
      $677 = HEAP32[$$pre$phi897Z2D>>2]|0;
      $678 = ((($677)) + 12|0);
      $679 = ((($678)) + 11|0);
      $680 = HEAP8[$679>>0]|0;
      $681 = ($680<<24>>24)<(0);
      $682 = HEAP32[$678>>2]|0;
      $683 = $681 ? $682 : $678;
      $684 = ((($677)) + 16|0);
      $685 = HEAP32[$684>>2]|0;
      $686 = $680&255;
      $687 = $681 ? $685 : $686;
      __THREW__ = 0;
      $688 = (invoke_iiii(3267,($674|0),($683|0),($687|0))|0);
      $689 = __THREW__; __THREW__ = 0;
      $690 = $689&1;
      if ($690) {
       label = 191;
       break L251;
      }
      __THREW__ = 0;
      $691 = (invoke_iiii(3267,($688|0),(146613|0),2)|0);
      $692 = __THREW__; __THREW__ = 0;
      $693 = $692&1;
      if ($693) {
       label = 191;
       break L251;
      }
      __THREW__ = 0;
      $694 = (invoke_iiii(3267,($691|0),(146616|0),25)|0);
      $695 = __THREW__; __THREW__ = 0;
      $696 = $695&1;
      if ($696) {
       label = 191;
       break L251;
      }
      $697 = ((($18)) + 11|0);
      $698 = HEAP8[$697>>0]|0;
      $699 = ($698<<24>>24)<(0);
      $700 = HEAP32[$18>>2]|0;
      $701 = $699 ? $700 : $18;
      $702 = ((($18)) + 4|0);
      $703 = HEAP32[$702>>2]|0;
      $704 = $698&255;
      $705 = $699 ? $703 : $704;
      __THREW__ = 0;
      $706 = (invoke_iiii(3267,($694|0),($701|0),($705|0))|0);
      $707 = __THREW__; __THREW__ = 0;
      $708 = $707&1;
      if ($708) {
       label = 191;
       break L251;
      }
      $709 = HEAP32[$706>>2]|0;
      $710 = ((($709)) + -12|0);
      $711 = HEAP32[$710>>2]|0;
      $712 = (($706) + ($711)|0);
      __THREW__ = 0;
      invoke_vii(3257,($4|0),($712|0));
      $713 = __THREW__; __THREW__ = 0;
      $714 = $713&1;
      if ($714) {
       label = 191;
       break L251;
      }
      __THREW__ = 0;
      $715 = (invoke_iii(3255,($4|0),(215188|0))|0);
      $716 = __THREW__; __THREW__ = 0;
      $717 = $716&1;
      do {
       if (!($717)) {
        $718 = HEAP32[$715>>2]|0;
        $719 = ((($718)) + 28|0);
        $720 = HEAP32[$719>>2]|0;
        __THREW__ = 0;
        $721 = (invoke_iii($720|0,($715|0),10)|0);
        $722 = __THREW__; __THREW__ = 0;
        $723 = $722&1;
        if ($723) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3263,($4|0));
        $730 = __THREW__; __THREW__ = 0;
        $731 = $730&1;
        if ($731) {
         label = 191;
         break L251;
        }
        __THREW__ = 0;
        (invoke_iii(3268,($706|0),($721|0))|0);
        $732 = __THREW__; __THREW__ = 0;
        $733 = $732&1;
        if ($733) {
         label = 191;
         break L251;
        }
        __THREW__ = 0;
        (invoke_ii(3269,($706|0))|0);
        $734 = __THREW__; __THREW__ = 0;
        $735 = $734&1;
        if ($735) {
         label = 191;
         break L251;
        } else {
         break L253;
        }
       }
      } while(0);
      $724 = ___cxa_find_matching_catch_2()|0;
      $725 = tempRet0;
      __THREW__ = 0;
      invoke_vi(3263,($4|0));
      $726 = __THREW__; __THREW__ = 0;
      $727 = $726&1;
      if ($727) {
       $728 = ___cxa_find_matching_catch_3(0|0)|0;
       $729 = tempRet0;
       ___clang_call_terminate($728);
       // unreachable;
      } else {
       $$pre$phi890Z2D = $697;$eh$lpad$body307$index24Z2D = $725;$eh$lpad$body307$indexZ2D = $724;
       break L251;
      }
     }
    }
   } while(0);
   $741 = ((($0)) + 16|0);
   $742 = HEAP32[$741>>2]|0;
   $743 = ((($0)) + 20|0);
   $744 = HEAP32[$743>>2]|0;
   $745 = HEAP32[$$pre$phi897Z2D>>2]|0;
   $746 = ((($745)) + 12|0);
   $747 = ((($742)) + 1688|0);
   $748 = HEAP32[$747>>2]|0;
   $749 = ($748|0)==(0|0);
   if (!($749)) {
    $750 = ((($746)) + 11|0);
    $751 = HEAP8[$750>>0]|0;
    $752 = ($751<<24>>24)<(0);
    $753 = ((($745)) + 16|0);
    $754 = HEAP32[$753>>2]|0;
    $755 = $751&255;
    $756 = $752 ? $754 : $755;
    $757 = ($756|0)==(0);
    if (!($757)) {
     $758 = HEAP32[$746>>2]|0;
     $759 = $752 ? $758 : $746;
     __THREW__ = 0;
     invoke_viiii($748|0,33506,($744|0),($756|0),($759|0));
     $760 = __THREW__; __THREW__ = 0;
     $761 = $760&1;
     if ($761) {
      label = 191;
      break;
     }
    }
   }
   $762 = ((($18)) + 11|0);
   $763 = HEAP8[$762>>0]|0;
   $764 = ($763<<24>>24)<(0);
   if ($764) {
    $765 = HEAP32[$18>>2]|0;
    __ZdlPv($765);
   }
   $766 = HEAP32[$741>>2]|0;
   $767 = ((($766)) + 32|0);
   $768 = HEAP8[$767>>0]|0;
   $769 = ($768<<24>>24)==(0);
   if ($769) {
    $977 = $766;
   } else {
    HEAP32[$19>>2] = 0;
    HEAP32[$20>>2] = 0;
    $770 = ((($766)) + 104|0);
    $771 = HEAP32[$770>>2]|0;
    $772 = HEAP32[$743>>2]|0;
    FUNCTION_TABLE_viii[$771 & 8191]($772,35382,$19);
    $773 = HEAP32[$741>>2]|0;
    $774 = ((($773)) + 104|0);
    $775 = HEAP32[$774>>2]|0;
    $776 = HEAP32[$743>>2]|0;
    FUNCTION_TABLE_viii[$775 & 8191]($776,35381,$20);
    $777 = HEAP32[$20>>2]|0;
    $778 = ($777|0)>(0);
    if ($778) {
     HEAP32[$21>>2] = 0;
     $779 = ((($21)) + 4|0);
     HEAP32[$779>>2] = 0;
     $780 = ((($21)) + 8|0);
     HEAP32[$780>>2] = 0;
     __THREW__ = 0;
     $781 = (invoke_ii(3276,($777|0))|0);
     $782 = __THREW__; __THREW__ = 0;
     $783 = $782&1;
     if ($783) {
      $800 = ___cxa_find_matching_catch_2()|0;
      $801 = tempRet0;
      $802 = HEAP32[$21>>2]|0;
      $803 = ($802|0)==(0|0);
      if ($803) {
       ___resumeException($800|0);
       // unreachable;
      }
      $804 = HEAP32[$779>>2]|0;
      $805 = ($804|0)==($802|0);
      if (!($805)) {
       HEAP32[$779>>2] = $802;
      }
      __ZdlPv($802);
      ___resumeException($800|0);
      // unreachable;
     }
     HEAP32[$779>>2] = $781;
     HEAP32[$21>>2] = $781;
     $784 = (($781) + ($777)|0);
     $785 = ((($21)) + 8|0);
     HEAP32[$785>>2] = $784;
     $$0$i$i315 = $777;$786 = $781;
     while(1) {
      HEAP8[$786>>0] = 0;
      $787 = ((($786)) + 1|0);
      $788 = (($$0$i$i315) + -1)|0;
      $789 = ($788|0)==(0);
      if ($789) {
       break;
      } else {
       $$0$i$i315 = $788;$786 = $787;
      }
     }
     HEAP32[$779>>2] = $787;
     $790 = HEAP32[$19>>2]|0;
     $791 = ($790|0)==(0);
     L298: do {
      if (!($791)) {
       $792 = ((($0)) + 72|0);
       $793 = ((($25)) + 11|0);
       $794 = ((($24)) + 12|0);
       $795 = ((($0)) + 76|0);
       $796 = ((($0)) + 80|0);
       $797 = ((($24)) + 11|0);
       $798 = ((($25)) + 8|0);
       $799 = ((($25)) + 4|0);
       $$0196778 = 0;
       while(1) {
        HEAP32[$22>>2] = 0;
        HEAP32[$23>>2] = 0;
        $810 = HEAP32[$741>>2]|0;
        $811 = ((($810)) + 600|0);
        $812 = HEAP32[$811>>2]|0;
        $813 = HEAP32[$743>>2]|0;
        $814 = HEAP32[$20>>2]|0;
        $815 = HEAP32[$21>>2]|0;
        __THREW__ = 0;
        invoke_viiiii($812|0,($813|0),($$0196778|0),($814|0),($22|0),($815|0));
        $816 = __THREW__; __THREW__ = 0;
        $817 = $816&1;
        if ($817) {
         label = 240;
         break;
        }
        $818 = HEAP32[$741>>2]|0;
        $819 = ((($818)) + 596|0);
        $820 = HEAP32[$819>>2]|0;
        $821 = HEAP32[$743>>2]|0;
        __THREW__ = 0;
        invoke_viiii($820|0,($821|0),($$0196778|0),35392,($23|0));
        $822 = __THREW__; __THREW__ = 0;
        $823 = $822&1;
        if ($823) {
         label = 240;
         break;
        }
        $824 = HEAP32[$21>>2]|0;
        ;HEAP32[$25>>2]=0|0;HEAP32[$25+4>>2]=0|0;HEAP32[$25+8>>2]=0|0;
        $825 = (_strlen($824)|0);
        $826 = ($825>>>0)>(4294967279);
        if ($826) {
         label = 220;
         break;
        }
        $828 = ($825>>>0)<(11);
        if ($828) {
         $835 = $825&255;
         HEAP8[$793>>0] = $835;
         $836 = ($825|0)==(0);
         if ($836) {
          $$017$i$i = $25;
         } else {
          $$016$i$i = $25;
          label = 225;
         }
        } else {
         $829 = (($825) + 16)|0;
         $830 = $829 & -16;
         __THREW__ = 0;
         $831 = (invoke_ii(3276,($830|0))|0);
         $832 = __THREW__; __THREW__ = 0;
         $833 = $832&1;
         if ($833) {
          label = 241;
          break;
         }
         HEAP32[$25>>2] = $831;
         $834 = $830 | -2147483648;
         HEAP32[$798>>2] = $834;
         HEAP32[$799>>2] = $825;
         $$016$i$i = $831;
         label = 225;
        }
        if ((label|0) == 225) {
         label = 0;
         _memcpy(($$016$i$i|0),($824|0),($825|0))|0;
         $$017$i$i = $$016$i$i;
        }
        $837 = (($$017$i$i) + ($825)|0);
        HEAP8[$837>>0] = 0;
        $838 = HEAP32[$23>>2]|0;
        __THREW__ = 0;
        invoke_vii(3457,($24|0),($25|0));
        $839 = __THREW__; __THREW__ = 0;
        $840 = $839&1;
        if ($840) {
         label = 242;
         break;
        }
        $841 = $794;
        $842 = $841;
        HEAP32[$842>>2] = $$0196778;
        $843 = (($841) + 4)|0;
        $844 = $843;
        HEAP32[$844>>2] = $838;
        __THREW__ = 0;
        $845 = (invoke_iiii(3861,($792|0),($3|0),($24|0))|0);
        $846 = __THREW__; __THREW__ = 0;
        $847 = $846&1;
        if ($847) {
         label = 243;
         break;
        }
        $848 = HEAP32[$845>>2]|0;
        $849 = ($848|0)==(0|0);
        if ($849) {
         __THREW__ = 0;
         $850 = (invoke_ii(3276,36)|0);
         $851 = __THREW__; __THREW__ = 0;
         $852 = $851&1;
         if ($852) {
          label = 243;
          break;
         }
         $853 = ((($850)) + 16|0);
         __THREW__ = 0;
         invoke_vii(3457,($853|0),($24|0));
         $854 = __THREW__; __THREW__ = 0;
         $855 = $854&1;
         if ($855) {
          label = 231;
          break;
         }
         $858 = ((($850)) + 28|0);
         $859 = $794;
         $860 = $859;
         $861 = HEAP32[$860>>2]|0;
         $862 = (($859) + 4)|0;
         $863 = $862;
         $864 = HEAP32[$863>>2]|0;
         $865 = $858;
         $866 = $865;
         HEAP32[$866>>2] = $861;
         $867 = (($865) + 4)|0;
         $868 = $867;
         HEAP32[$868>>2] = $864;
         $869 = HEAP32[$3>>2]|0;
         HEAP32[$850>>2] = 0;
         $870 = ((($850)) + 4|0);
         HEAP32[$870>>2] = 0;
         $871 = ((($850)) + 8|0);
         HEAP32[$871>>2] = $869;
         HEAP32[$845>>2] = $850;
         $872 = HEAP32[$792>>2]|0;
         $873 = HEAP32[$872>>2]|0;
         $874 = ($873|0)==(0|0);
         if ($874) {
          $877 = $850;
         } else {
          $875 = $873;
          HEAP32[$792>>2] = $875;
          $$pre$i$i$i$i = HEAP32[$845>>2]|0;
          $877 = $$pre$i$i$i$i;
         }
         $876 = HEAP32[$795>>2]|0;
         __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($876,$877);
         $878 = HEAP32[$796>>2]|0;
         $879 = (($878) + 1)|0;
         HEAP32[$796>>2] = $879;
        }
        $880 = HEAP8[$797>>0]|0;
        $881 = ($880<<24>>24)<(0);
        if ($881) {
         $882 = HEAP32[$24>>2]|0;
         __ZdlPv($882);
        }
        $883 = HEAP8[$793>>0]|0;
        $884 = ($883<<24>>24)<(0);
        if ($884) {
         $885 = HEAP32[$25>>2]|0;
         __ZdlPv($885);
        }
        $886 = (($$0196778) + 1)|0;
        $887 = HEAP32[$19>>2]|0;
        $888 = ($886>>>0)<($887>>>0);
        if ($888) {
         $$0196778 = $886;
        } else {
         break L298;
        }
       }
       if ((label|0) == 220) {
        __THREW__ = 0;
        invoke_vi(3367,($25|0));
        $827 = __THREW__; __THREW__ = 0;
        label = 241;
       }
       else if ((label|0) == 231) {
        $856 = ___cxa_find_matching_catch_2()|0;
        $857 = tempRet0;
        __ZdlPv($850);
        $eh$lpad$body322$index29Z2D = $857;$eh$lpad$body322$indexZ2D = $856;
        label = 244;
       }
       else if ((label|0) == 240) {
        $889 = ___cxa_find_matching_catch_2()|0;
        $890 = tempRet0;
        $$6 = $889;$$6167 = $890;
       }
       else if ((label|0) == 242) {
        $893 = ___cxa_find_matching_catch_2()|0;
        $894 = tempRet0;
        $$4 = $893;$$4165 = $894;
        label = 246;
       }
       else if ((label|0) == 243) {
        $895 = ___cxa_find_matching_catch_2()|0;
        $896 = tempRet0;
        $eh$lpad$body322$index29Z2D = $896;$eh$lpad$body322$indexZ2D = $895;
        label = 244;
       }
       do {
        if ((label|0) == 241) {
         $891 = ___cxa_find_matching_catch_2()|0;
         $892 = tempRet0;
         $$5 = $891;$$5166 = $892;
         label = 248;
        }
        else if ((label|0) == 244) {
         $897 = HEAP8[$797>>0]|0;
         $898 = ($897<<24>>24)<(0);
         if (!($898)) {
          $$4 = $eh$lpad$body322$indexZ2D;$$4165 = $eh$lpad$body322$index29Z2D;
          label = 246;
          break;
         }
         $899 = HEAP32[$24>>2]|0;
         __ZdlPv($899);
         $$4 = $eh$lpad$body322$indexZ2D;$$4165 = $eh$lpad$body322$index29Z2D;
         label = 246;
        }
       } while(0);
       do {
        if ((label|0) == 246) {
         $900 = HEAP8[$793>>0]|0;
         $901 = ($900<<24>>24)<(0);
         if (!($901)) {
          $$5 = $$4;$$5166 = $$4165;
          label = 248;
          break;
         }
         $902 = HEAP32[$25>>2]|0;
         __ZdlPv($902);
         $$5 = $$4;$$5166 = $$4165;
         label = 248;
        }
       } while(0);
       if ((label|0) == 248) {
        $$6 = $$5;$$6167 = $$5166;
       }
       $903 = HEAP32[$21>>2]|0;
       $904 = ($903|0)==(0|0);
       if (!($904)) {
        $905 = HEAP32[$779>>2]|0;
        $906 = ($905|0)==($903|0);
        if (!($906)) {
         HEAP32[$779>>2] = $903;
        }
        __ZdlPv($903);
       }
       $$31 = $$6;$$31192 = $$6167;
       ___resumeException($$31|0);
       // unreachable;
      }
     } while(0);
     $806 = HEAP32[$21>>2]|0;
     $807 = ($806|0)==(0|0);
     if (!($807)) {
      $808 = HEAP32[$779>>2]|0;
      $809 = ($808|0)==($806|0);
      if (!($809)) {
       HEAP32[$779>>2] = $806;
      }
      __ZdlPv($806);
     }
    }
    $907 = HEAP32[$$pre$phi897Z2D>>2]|0;
    $908 = ((($0)) + 72|0);
    $909 = HEAP32[$908>>2]|0;
    $910 = ((($0)) + 76|0);
    $911 = ($909|0)==($910|0);
    if (!($911)) {
     $912 = ((($907)) + 92|0);
     $913 = ((($907)) + 96|0);
     $$sroa$0541$0775 = $909;
     while(1) {
      $914 = ((($$sroa$0541$0775)) + 16|0);
      $915 = (__ZNKSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEjEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE4findIS7_EENS_21__tree_const_iteratorIS8_PNS_11__tree_nodeIS8_PvEEiEERKT_($912,$914)|0);
      $916 = ($915|0)==($913|0);
      do {
       if ($916) {
        $944 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
        if (!($944)) {
         break;
        }
        $945 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
        $946 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($945,146642,14)|0);
        $947 = ((($914)) + 11|0);
        $948 = HEAP8[$947>>0]|0;
        $949 = ($948<<24>>24)<(0);
        $950 = HEAP32[$914>>2]|0;
        $951 = $949 ? $950 : $914;
        $952 = ((($$sroa$0541$0775)) + 20|0);
        $953 = HEAP32[$952>>2]|0;
        $954 = $948&255;
        $955 = $949 ? $953 : $954;
        $956 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($946,$951,$955)|0);
        (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($956,146668,17)|0);
       } else {
        $917 = HEAP32[$741>>2]|0;
        $918 = ((($917)) + 604|0);
        $919 = HEAP32[$918>>2]|0;
        $920 = HEAP32[$743>>2]|0;
        $921 = ((($$sroa$0541$0775)) + 28|0);
        $922 = HEAP32[$921>>2]|0;
        $923 = ((($915)) + 28|0);
        $924 = HEAP32[$923>>2]|0;
        FUNCTION_TABLE_viii[$919 & 8191]($920,$922,$924);
        $925 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
        if (!($925)) {
         break;
        }
        $926 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
        $927 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($926,146642,14)|0);
        $928 = ((($914)) + 11|0);
        $929 = HEAP8[$928>>0]|0;
        $930 = ($929<<24>>24)<(0);
        $931 = HEAP32[$914>>2]|0;
        $932 = $930 ? $931 : $914;
        $933 = ((($$sroa$0541$0775)) + 20|0);
        $934 = HEAP32[$933>>2]|0;
        $935 = $929&255;
        $936 = $930 ? $934 : $935;
        $937 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($927,$932,$936)|0);
        $938 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($937,205152,2)|0);
        $939 = HEAP32[$921>>2]|0;
        $940 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($938,$939)|0);
        $941 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($940,146657,10)|0);
        $942 = HEAP32[$923>>2]|0;
        $943 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($941,$942)|0);
        (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($943,195712,1)|0);
       }
      } while(0);
      $957 = ((($$sroa$0541$0775)) + 4|0);
      $958 = HEAP32[$957>>2]|0;
      $959 = ($958|0)==(0|0);
      do {
       if ($959) {
        $960 = ((($$sroa$0541$0775)) + 8|0);
        $961 = HEAP32[$960>>2]|0;
        $962 = HEAP32[$961>>2]|0;
        $963 = ($962|0)==($$sroa$0541$0775|0);
        if ($963) {
         $$sroa$0541$0$be = $961;
         break;
        } else {
         $968 = $960;
        }
        while(1) {
         $967 = HEAP32[$968>>2]|0;
         $969 = ((($967)) + 8|0);
         $970 = HEAP32[$969>>2]|0;
         $971 = HEAP32[$970>>2]|0;
         $972 = ($971|0)==($967|0);
         if ($972) {
          $$sroa$0541$0$be = $970;
          break;
         } else {
          $968 = $969;
         }
        }
       } else {
        $$0$i$i$i$i330 = $958;
        while(1) {
         $965 = HEAP32[$$0$i$i$i$i330>>2]|0;
         $966 = ($965|0)==(0|0);
         if ($966) {
          break;
         } else {
          $$0$i$i$i$i330 = $965;
         }
        }
        $$sroa$0541$0$be = $$0$i$i$i$i330;
       }
      } while(0);
      $964 = ($$sroa$0541$0$be|0)==($910|0);
      if ($964) {
       break;
      } else {
       $$sroa$0541$0775 = $$sroa$0541$0$be;
      }
     }
    }
    $$pre866 = HEAP32[$741>>2]|0;
    $977 = $$pre866;
   }
   $973 = ((($26)) + 4|0);
   HEAP32[$973>>2] = 0;
   $974 = ((($26)) + 8|0);
   HEAP32[$974>>2] = 0;
   $975 = ((($26)) + 4|0);
   HEAP32[$26>>2] = $975;
   HEAP32[$27>>2] = 0;
   HEAP32[$28>>2] = 0;
   $976 = ((($977)) + 104|0);
   $978 = HEAP32[$976>>2]|0;
   $979 = HEAP32[$743>>2]|0;
   __THREW__ = 0;
   invoke_viii($978|0,($979|0),35718,($27|0));
   $980 = __THREW__; __THREW__ = 0;
   $981 = $980&1;
   L379: do {
    if ($981) {
     label = 273;
    } else {
     $982 = HEAP32[$741>>2]|0;
     $983 = ((($982)) + 104|0);
     $984 = HEAP32[$983>>2]|0;
     $985 = HEAP32[$743>>2]|0;
     __THREW__ = 0;
     invoke_viii($984|0,($985|0),35719,($28|0));
     $986 = __THREW__; __THREW__ = 0;
     $987 = $986&1;
     if ($987) {
      label = 273;
     } else {
      $988 = HEAP32[$27>>2]|0;
      $989 = ($988|0)>(0);
      $990 = HEAP32[$28>>2]|0;
      $991 = ($990|0)>(1);
      $or$cond = $989 & $991;
      L382: do {
       if ($or$cond) {
        HEAP32[$29>>2] = 0;
        HEAP32[$30>>2] = 0;
        __THREW__ = 0;
        $992 = (invoke_ii(3820,($990|0))|0);
        $993 = __THREW__; __THREW__ = 0;
        $994 = $993&1;
        L384: do {
         if ($994) {
          $1001 = ___cxa_find_matching_catch_2()|0;
          $1002 = tempRet0;
          $$11 = $1001;$$11172 = $1002;
         } else {
          $995 = ((($31)) + 11|0);
          $996 = ((($0)) + 52|0);
          $997 = ((($31)) + 8|0);
          $998 = ((($31)) + 4|0);
          $$0194768 = 0;$1007 = $990;
          L387: while(1) {
           $1003 = HEAP32[$741>>2]|0;
           $1004 = ((($1003)) + 92|0);
           $1005 = HEAP32[$1004>>2]|0;
           $1006 = HEAP32[$743>>2]|0;
           __THREW__ = 0;
           invoke_viiiiiii($1005|0,($1006|0),($$0194768|0),($1007|0),(0|0),($29|0),($30|0),($992|0));
           $1008 = __THREW__; __THREW__ = 0;
           $1009 = $1008&1;
           if ($1009) {
            label = 280;
            break;
           }
           $1010 = (_strlen($992)|0);
           $1011 = ($1010|0)>(0);
           do {
            if ($1011) {
             $1012 = (($1010) + -1)|0;
             $1013 = (($992) + ($1012)|0);
             $1014 = HEAP8[$1013>>0]|0;
             $1015 = ($1014<<24>>24)==(93);
             if ($1015) {
              $$0193$in = $1010;
             } else {
              break;
             }
             while(1) {
              $$0193 = (($$0193$in) + -1)|0;
              $1016 = ($$0193$in|0)>(1);
              $1017 = (($992) + ($$0193)|0);
              if (!($1016)) {
               break;
              }
              $1018 = HEAP8[$1017>>0]|0;
              $1019 = ($1018<<24>>24)==(91);
              if ($1019) {
               break;
              } else {
               $$0193$in = $$0193;
              }
             }
             HEAP8[$1017>>0] = 0;
            }
           } while(0);
           $1022 = HEAP32[$30>>2]|0;
           $1023 = ($1022|0)==(37595);
           if ($1023) {
            $1024 = HEAP32[$975>>2]|0;
            $1025 = ($1024|0)==(0|0);
            do {
             if ($1025) {
              $$025$i$i341 = $975;$$037$i = $975;$1035 = $1024;
              label = 292;
             } else {
              $$0$i$i340 = $973;$$024$i$i339 = $1024;$1780 = $1024;
              while(1) {
               $1026 = ((($$024$i$i339)) + 16|0);
               $1027 = HEAP32[$1026>>2]|0;
               $1028 = ($$0194768>>>0)<($1027>>>0);
               if ($1028) {
                $1029 = HEAP32[$$024$i$i339>>2]|0;
                $1030 = ($1029|0)==(0|0);
                if ($1030) {
                 label = 287;
                 break;
                } else {
                 $$0$ph$i$i337 = $$024$i$i339;$$in$i$i336 = $1029;
                }
               } else {
                $1031 = ($1027>>>0)<($$0194768>>>0);
                if (!($1031)) {
                 label = 291;
                 break;
                }
                $1032 = ((($$024$i$i339)) + 4|0);
                $1033 = HEAP32[$1032>>2]|0;
                $1034 = ($1033|0)==(0|0);
                if ($1034) {
                 label = 290;
                 break;
                } else {
                 $$0$ph$i$i337 = $1032;$$in$i$i336 = $1033;
                }
               }
               $$0$i$i340 = $$0$ph$i$i337;$$024$i$i339 = $$in$i$i336;$1780 = $$in$i$i336;
              }
              if ((label|0) == 287) {
               label = 0;
               $$025$i53$i = $$024$i$i339;$$03752$i = $$024$i$i339;
               label = 293;
               break;
              }
              else if ((label|0) == 290) {
               label = 0;
               $$025$i53$i = $1032;$$03752$i = $$024$i$i339;
               label = 293;
               break;
              }
              else if ((label|0) == 291) {
               label = 0;
               $$025$i$i341 = $$0$i$i340;$$037$i = $$024$i$i339;$1035 = $1780;
               label = 292;
               break;
              }
             }
            } while(0);
            if ((label|0) == 292) {
             label = 0;
             $1036 = ($1035|0)==(0|0);
             if ($1036) {
              $$025$i53$i = $$025$i$i341;$$03752$i = $$037$i;
              label = 293;
             } else {
              $$014$i343 = $1035;
             }
            }
            if ((label|0) == 293) {
             label = 0;
             __THREW__ = 0;
             $1037 = (invoke_ii(3276,32)|0);
             $1038 = __THREW__; __THREW__ = 0;
             $1039 = $1038&1;
             if ($1039) {
              label = 298;
              break;
             }
             $1040 = ((($1037)) + 16|0);
             HEAP32[$1040>>2] = $$0194768;
             $1041 = ((($1037)) + 20|0);
             ;HEAP32[$1041>>2]=0|0;HEAP32[$1041+4>>2]=0|0;HEAP32[$1041+8>>2]=0|0;
             HEAP32[$1037>>2] = 0;
             $1042 = ((($1037)) + 4|0);
             HEAP32[$1042>>2] = 0;
             $1043 = ((($1037)) + 8|0);
             HEAP32[$1043>>2] = $$03752$i;
             HEAP32[$$025$i53$i>>2] = $1037;
             $1044 = HEAP32[$26>>2]|0;
             $1045 = HEAP32[$1044>>2]|0;
             $1046 = ($1045|0)==(0|0);
             if ($1046) {
              $1049 = $1037;
             } else {
              $1047 = $1045;
              HEAP32[$26>>2] = $1047;
              $$pre$i$i342 = HEAP32[$$025$i53$i>>2]|0;
              $1049 = $$pre$i$i342;
             }
             $1048 = HEAP32[$973>>2]|0;
             __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($1048,$1049);
             $1050 = HEAP32[$974>>2]|0;
             $1051 = (($1050) + 1)|0;
             HEAP32[$974>>2] = $1051;
             $$014$i343 = $1037;
            }
            $1052 = ((($$014$i343)) + 20|0);
            __THREW__ = 0;
            (invoke_iii(3786,($1052|0),($992|0))|0);
            $1053 = __THREW__; __THREW__ = 0;
            $1054 = $1053&1;
            if ($1054) {
             label = 298;
             break;
            }
           }
           $1057 = HEAP32[$741>>2]|0;
           $1058 = ((($1057)) + 132|0);
           $1059 = HEAP32[$1058>>2]|0;
           $1060 = HEAP32[$743>>2]|0;
           __THREW__ = 0;
           $1061 = (invoke_iii($1059|0,($1060|0),($992|0))|0);
           $1062 = __THREW__; __THREW__ = 0;
           $1063 = $1062&1;
           if ($1063) {
            label = 347;
            break;
           }
           $1064 = ($1061|0)==(-1);
           do {
            if (!($1064)) {
             $1065 = HEAP32[$30>>2]|0;
             $1066 = HEAP32[$29>>2]|0;
             ;HEAP32[$31>>2]=0|0;HEAP32[$31+4>>2]=0|0;HEAP32[$31+8>>2]=0|0;
             $1067 = (_strlen($992)|0);
             $1068 = ($1067>>>0)>(4294967279);
             if ($1068) {
              label = 302;
              break L387;
             }
             $1070 = ($1067>>>0)<(11);
             if ($1070) {
              $1077 = $1067&255;
              HEAP8[$995>>0] = $1077;
              $1078 = ($1067|0)==(0);
              if ($1078) {
               $$017$i$i348 = $31;
              } else {
               $$016$i$i347 = $31;
               label = 307;
              }
             } else {
              $1071 = (($1067) + 16)|0;
              $1072 = $1071 & -16;
              __THREW__ = 0;
              $1073 = (invoke_ii(3276,($1072|0))|0);
              $1074 = __THREW__; __THREW__ = 0;
              $1075 = $1074&1;
              if ($1075) {
               label = 348;
               break L387;
              }
              HEAP32[$31>>2] = $1073;
              $1076 = $1072 | -2147483648;
              HEAP32[$997>>2] = $1076;
              HEAP32[$998>>2] = $1067;
              $$016$i$i347 = $1073;
              label = 307;
             }
             if ((label|0) == 307) {
              label = 0;
              _memcpy(($$016$i$i347|0),($992|0),($1067|0))|0;
              $$017$i$i348 = $$016$i$i347;
             }
             $1079 = (($$017$i$i348) + ($1067)|0);
             HEAP8[$1079>>0] = 0;
             __THREW__ = 0;
             $1080 = (invoke_ii(3862,($31|0))|0);
             $1081 = __THREW__; __THREW__ = 0;
             $1082 = $1081&1;
             if ($1082) {
              label = 349;
              break L387;
             }
             $1083 = HEAP32[$337>>2]|0;
             $1084 = ($1083|0)==(0|0);
             do {
              if ($1084) {
               $$025$i$i359 = $337;$$034$i358 = $337;$1094 = $1083;
               label = 318;
              } else {
               $$0$i$i357 = $996;$$024$i$i356 = $1083;$1781 = $1083;
               while(1) {
                $1085 = ((($$024$i$i356)) + 16|0);
                $1086 = HEAP32[$1085>>2]|0;
                $1087 = ($1080>>>0)<($1086>>>0);
                if ($1087) {
                 $1088 = HEAP32[$$024$i$i356>>2]|0;
                 $1089 = ($1088|0)==(0|0);
                 if ($1089) {
                  label = 313;
                  break;
                 } else {
                  $$0$ph$i$i354 = $$024$i$i356;$$in$i$i353 = $1088;
                 }
                } else {
                 $1090 = ($1086>>>0)<($1080>>>0);
                 if (!($1090)) {
                  label = 317;
                  break;
                 }
                 $1091 = ((($$024$i$i356)) + 4|0);
                 $1092 = HEAP32[$1091>>2]|0;
                 $1093 = ($1092|0)==(0|0);
                 if ($1093) {
                  label = 316;
                  break;
                 } else {
                  $$0$ph$i$i354 = $1091;$$in$i$i353 = $1092;
                 }
                }
                $$0$i$i357 = $$0$ph$i$i354;$$024$i$i356 = $$in$i$i353;$1781 = $$in$i$i353;
               }
               if ((label|0) == 313) {
                label = 0;
                $$025$i47$i360 = $$024$i$i356;$$03446$i361 = $$024$i$i356;
                label = 319;
                break;
               }
               else if ((label|0) == 316) {
                label = 0;
                $$025$i47$i360 = $1091;$$03446$i361 = $$024$i$i356;
                label = 319;
                break;
               }
               else if ((label|0) == 317) {
                label = 0;
                $$025$i$i359 = $$0$i$i357;$$034$i358 = $$024$i$i356;$1094 = $1781;
                label = 318;
                break;
               }
              }
             } while(0);
             if ((label|0) == 318) {
              label = 0;
              $1095 = ($1094|0)==(0|0);
              if ($1095) {
               $$025$i47$i360 = $$025$i$i359;$$03446$i361 = $$034$i358;
               label = 319;
              } else {
               $$014$i363 = $1094;
              }
             }
             if ((label|0) == 319) {
              label = 0;
              __THREW__ = 0;
              $1096 = (invoke_ii(3276,32)|0);
              $1097 = __THREW__; __THREW__ = 0;
              $1098 = $1097&1;
              if ($1098) {
               label = 349;
               break L387;
              }
              $1099 = ((($1096)) + 16|0);
              HEAP32[$1099>>2] = $1080;
              $1100 = ((($1096)) + 20|0);
              HEAP32[$1100>>2] = -1;
              $1101 = ((($1096)) + 24|0);
              HEAP32[$1101>>2] = 0;
              $1102 = ((($1096)) + 28|0);
              HEAP32[$1102>>2] = -1;
              HEAP32[$1096>>2] = 0;
              $1103 = ((($1096)) + 4|0);
              HEAP32[$1103>>2] = 0;
              $1104 = ((($1096)) + 8|0);
              HEAP32[$1104>>2] = $$03446$i361;
              HEAP32[$$025$i47$i360>>2] = $1096;
              $1105 = HEAP32[$336>>2]|0;
              $1106 = HEAP32[$1105>>2]|0;
              $1107 = ($1106|0)==(0|0);
              if ($1107) {
               $1110 = $1096;
              } else {
               $1108 = $1106;
               HEAP32[$336>>2] = $1108;
               $$pre$i$i362 = HEAP32[$$025$i47$i360>>2]|0;
               $1110 = $$pre$i$i362;
              }
              $1109 = HEAP32[$996>>2]|0;
              __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($1109,$1110);
              $1111 = HEAP32[$339>>2]|0;
              $1112 = (($1111) + 1)|0;
              HEAP32[$339>>2] = $1112;
              $$014$i363 = $1096;
             }
             $$sroa$0517$0$$sroa_idx = ((($$014$i363)) + 20|0);
             HEAP32[$$sroa$0517$0$$sroa_idx>>2] = $1061;
             $$sroa$5520$0$$sroa_idx521 = ((($$014$i363)) + 24|0);
             HEAP32[$$sroa$5520$0$$sroa_idx521>>2] = $1065;
             $$sroa$6524$0$$sroa_idx525 = ((($$014$i363)) + 28|0);
             HEAP32[$$sroa$6524$0$$sroa_idx525>>2] = $1066;
             $1113 = HEAP8[$995>>0]|0;
             $1114 = ($1113<<24>>24)<(0);
             if ($1114) {
              $1115 = HEAP32[$31>>2]|0;
              __ZdlPv($1115);
             }
             __THREW__ = 0;
             $1116 = (invoke_ii(3265,4)|0);
             $1117 = __THREW__; __THREW__ = 0;
             $1118 = $1117&1;
             if ($1118) {
              label = 352;
              break L387;
             }
             if (!($1116)) {
              break;
             }
             __THREW__ = 0;
             $1119 = (invoke_ii(3266,4)|0);
             $1120 = __THREW__; __THREW__ = 0;
             $1121 = $1120&1;
             if ($1121) {
              label = 352;
              break L387;
             }
             __THREW__ = 0;
             $1122 = (invoke_iiii(3267,($1119|0),(146686|0),10)|0);
             $1123 = __THREW__; __THREW__ = 0;
             $1124 = $1123&1;
             if ($1124) {
              label = 352;
              break L387;
             }
             $1125 = (_strlen($992)|0);
             __THREW__ = 0;
             $1126 = (invoke_iiii(3267,($1122|0),($992|0),($1125|0))|0);
             $1127 = __THREW__; __THREW__ = 0;
             $1128 = $1127&1;
             if ($1128) {
              label = 352;
              break L387;
             }
             __THREW__ = 0;
             $1129 = (invoke_iiii(3267,($1126|0),(172027|0),1)|0);
             $1130 = __THREW__; __THREW__ = 0;
             $1131 = $1130&1;
             if ($1131) {
              label = 352;
              break L387;
             }
             __THREW__ = 0;
             $1132 = (invoke_iiii(3267,($1129|0),(146697|0),5)|0);
             $1133 = __THREW__; __THREW__ = 0;
             $1134 = $1133&1;
             if ($1134) {
              label = 352;
              break L387;
             }
             __THREW__ = 0;
             $1135 = (invoke_iii(3863,($1132|0),($1061|0))|0);
             $1136 = __THREW__; __THREW__ = 0;
             $1137 = $1136&1;
             if ($1137) {
              label = 352;
              break L387;
             }
             __THREW__ = 0;
             $1138 = (invoke_iiii(3267,($1135|0),(146703|0),6)|0);
             $1139 = __THREW__; __THREW__ = 0;
             $1140 = $1139&1;
             if ($1140) {
              label = 352;
              break L387;
             }
             $1141 = HEAP32[$29>>2]|0;
             __THREW__ = 0;
             $1142 = (invoke_iii(3863,($1138|0),($1141|0))|0);
             $1143 = __THREW__; __THREW__ = 0;
             $1144 = $1143&1;
             if ($1144) {
              label = 352;
              break L387;
             }
             __THREW__ = 0;
             $1145 = (invoke_iiii(3267,($1142|0),(146710|0),6)|0);
             $1146 = __THREW__; __THREW__ = 0;
             $1147 = $1146&1;
             if ($1147) {
              label = 352;
              break L387;
             }
             $1148 = HEAP32[$30>>2]|0;
             __THREW__ = 0;
             $1149 = (invoke_ii(3864,($1148|0))|0);
             $1150 = __THREW__; __THREW__ = 0;
             $1151 = $1150&1;
             if ($1151) {
              label = 352;
              break L387;
             }
             $1152 = (_strlen($1149)|0);
             __THREW__ = 0;
             $1153 = (invoke_iiii(3267,($1145|0),($1149|0),($1152|0))|0);
             $1154 = __THREW__; __THREW__ = 0;
             $1155 = $1154&1;
             if ($1155) {
              label = 352;
              break L387;
             }
             $1156 = HEAP32[$1153>>2]|0;
             $1157 = ((($1156)) + -12|0);
             $1158 = HEAP32[$1157>>2]|0;
             $1159 = (($1153) + ($1158)|0);
             __THREW__ = 0;
             invoke_vii(3257,($2|0),($1159|0));
             $1160 = __THREW__; __THREW__ = 0;
             $1161 = $1160&1;
             if ($1161) {
              label = 352;
              break L387;
             }
             __THREW__ = 0;
             $1162 = (invoke_iii(3255,($2|0),(215188|0))|0);
             $1163 = __THREW__; __THREW__ = 0;
             $1164 = $1163&1;
             if ($1164) {
              label = 341;
              break L387;
             }
             $1165 = HEAP32[$1162>>2]|0;
             $1166 = ((($1165)) + 28|0);
             $1167 = HEAP32[$1166>>2]|0;
             __THREW__ = 0;
             $1168 = (invoke_iii($1167|0,($1162|0),10)|0);
             $1169 = __THREW__; __THREW__ = 0;
             $1170 = $1169&1;
             if ($1170) {
              label = 341;
              break L387;
             }
             __THREW__ = 0;
             invoke_vi(3263,($2|0));
             $1177 = __THREW__; __THREW__ = 0;
             $1178 = $1177&1;
             if ($1178) {
              label = 352;
              break L387;
             }
             __THREW__ = 0;
             (invoke_iii(3268,($1153|0),($1168|0))|0);
             $1179 = __THREW__; __THREW__ = 0;
             $1180 = $1179&1;
             if ($1180) {
              label = 352;
              break L387;
             }
             __THREW__ = 0;
             (invoke_ii(3269,($1153|0))|0);
             $1181 = __THREW__; __THREW__ = 0;
             $1182 = $1181&1;
             if ($1182) {
              label = 352;
              break L387;
             }
            }
           } while(0);
           $1194 = (($$0194768) + 1)|0;
           $1195 = HEAP32[$27>>2]|0;
           $1196 = ($1194|0)<($1195|0);
           if (!($1196)) {
            label = 356;
            break;
           }
           $$pre867 = HEAP32[$28>>2]|0;
           $$0194768 = $1194;$1007 = $$pre867;
          }
          do {
           if ((label|0) == 280) {
            $1020 = ___cxa_find_matching_catch_2()|0;
            $1021 = tempRet0;
            $$11 = $1020;$$11172 = $1021;
            break L384;
           }
           else if ((label|0) == 298) {
            $1055 = ___cxa_find_matching_catch_2()|0;
            $1056 = tempRet0;
            $$11 = $1055;$$11172 = $1056;
            break L384;
           }
           else if ((label|0) == 302) {
            __THREW__ = 0;
            invoke_vi(3367,($31|0));
            $1069 = __THREW__; __THREW__ = 0;
            label = 348;
           }
           else if ((label|0) == 341) {
            $1171 = ___cxa_find_matching_catch_2()|0;
            $1172 = tempRet0;
            __THREW__ = 0;
            invoke_vi(3263,($2|0));
            $1173 = __THREW__; __THREW__ = 0;
            $1174 = $1173&1;
            if ($1174) {
             $1175 = ___cxa_find_matching_catch_3(0|0)|0;
             $1176 = tempRet0;
             ___clang_call_terminate($1175);
             // unreachable;
            } else {
             $eh$lpad$body385$index34Z2D = $1172;$eh$lpad$body385$indexZ2D = $1171;
             label = 353;
             break;
            }
           }
           else if ((label|0) == 347) {
            $1183 = ___cxa_find_matching_catch_2()|0;
            $1184 = tempRet0;
            $$11 = $1183;$$11172 = $1184;
            break L384;
           }
           else if ((label|0) == 349) {
            $1187 = ___cxa_find_matching_catch_2()|0;
            $1188 = tempRet0;
            $1189 = HEAP8[$995>>0]|0;
            $1190 = ($1189<<24>>24)<(0);
            if (!($1190)) {
             $$7 = $1187;$$7168 = $1188;
             break;
            }
            $1191 = HEAP32[$31>>2]|0;
            __ZdlPv($1191);
            $$7 = $1187;$$7168 = $1188;
           }
           else if ((label|0) == 352) {
            $1192 = ___cxa_find_matching_catch_2()|0;
            $1193 = tempRet0;
            $eh$lpad$body385$index34Z2D = $1193;$eh$lpad$body385$indexZ2D = $1192;
            label = 353;
           }
           else if ((label|0) == 356) {
            __ZdaPv($992);
            break L382;
           }
          } while(0);
          if ((label|0) == 348) {
           $1185 = ___cxa_find_matching_catch_2()|0;
           $1186 = tempRet0;
           $$7 = $1185;$$7168 = $1186;
          }
          else if ((label|0) == 353) {
           $$11 = $eh$lpad$body385$indexZ2D;$$11172 = $eh$lpad$body385$index34Z2D;
           break;
          }
          $$11 = $$7;$$11172 = $$7168;
         }
        } while(0);
        $$30 = $$11;$$30191 = $$11172;
        break L379;
       }
      } while(0);
      $1197 = HEAP32[$741>>2]|0;
      $1198 = ((($1197)) + 35|0);
      $1199 = HEAP8[$1198>>0]|0;
      $1200 = ($1199<<24>>24)==(0);
      $1201 = HEAP32[$974>>2]|0;
      $1202 = ($1201|0)==(0);
      $or$cond601 = $1200 | $1202;
      L496: do {
       if ($or$cond601) {
        $1610 = $1197;
       } else {
        HEAP32[$32>>2] = 0;
        $1203 = ((($32)) + 4|0);
        HEAP32[$1203>>2] = 0;
        $1204 = ((($32)) + 8|0);
        HEAP32[$1204>>2] = 0;
        $1205 = ($1201>>>0)>(1073741823);
        do {
         if ($1205) {
          __THREW__ = 0;
          invoke_vi(3307,($32|0));
          $1206 = __THREW__; __THREW__ = 0;
         } else {
          $1207 = $1201 << 2;
          __THREW__ = 0;
          $1208 = (invoke_ii(3276,($1207|0))|0);
          $1209 = __THREW__; __THREW__ = 0;
          $1210 = $1209&1;
          if ($1210) {
           break;
          }
          HEAP32[$32>>2] = $1208;
          $1222 = (($1208) + ($1201<<2)|0);
          $1223 = ((($32)) + 8|0);
          HEAP32[$1223>>2] = $1222;
          _memset(($1208|0),0,($1207|0))|0;
          HEAP32[$1203>>2] = $1222;
          HEAP32[$33>>2] = 0;
          $1224 = ((($33)) + 4|0);
          HEAP32[$1224>>2] = 0;
          $1225 = ((($33)) + 8|0);
          HEAP32[$1225>>2] = 0;
          $1226 = HEAP32[$26>>2]|0;
          $1227 = ($1226|0)==($975|0);
          do {
           if ($1227) {
            $$pre$phi905Z2D = $1224;$$pre$phi907Z2D = $33;$1230 = $1197;$1234 = 0;$1235 = 0;$1237 = $1208;
            label = 370;
           } else {
            $1228 = ((($33)) + 8|0);
            $$sroa$0505$0765 = $1226;$1246 = 0;$1248 = 0;
            while(1) {
             $1245 = ((($$sroa$0505$0765)) + 16|0);
             $1247 = ($1246|0)==($1248|0);
             if ($1247) {
              __THREW__ = 0;
              invoke_vii(3437,($33|0),($1245|0));
              $1251 = __THREW__; __THREW__ = 0;
              $1252 = $1251&1;
              if ($1252) {
               label = 374;
               break;
              }
             } else {
              $1249 = HEAP32[$1245>>2]|0;
              HEAP32[$1246>>2] = $1249;
              $1250 = ((($1246)) + 4|0);
              HEAP32[$1224>>2] = $1250;
             }
             $1253 = ((($$sroa$0505$0765)) + 4|0);
             $1254 = HEAP32[$1253>>2]|0;
             $1255 = ($1254|0)==(0|0);
             do {
              if ($1255) {
               $1256 = ((($$sroa$0505$0765)) + 8|0);
               $1257 = HEAP32[$1256>>2]|0;
               $1258 = HEAP32[$1257>>2]|0;
               $1259 = ($1258|0)==($$sroa$0505$0765|0);
               if ($1259) {
                $$sroa$0505$0$be = $1257;
                break;
               } else {
                $1264 = $1256;
               }
               while(1) {
                $1263 = HEAP32[$1264>>2]|0;
                $1265 = ((($1263)) + 8|0);
                $1266 = HEAP32[$1265>>2]|0;
                $1267 = HEAP32[$1266>>2]|0;
                $1268 = ($1267|0)==($1263|0);
                if ($1268) {
                 $$sroa$0505$0$be = $1266;
                 break;
                } else {
                 $1264 = $1265;
                }
               }
              } else {
               $$0$i$i$i$i397 = $1254;
               while(1) {
                $1261 = HEAP32[$$0$i$i$i$i397>>2]|0;
                $1262 = ($1261|0)==(0|0);
                if ($1262) {
                 break;
                } else {
                 $$0$i$i$i$i397 = $1261;
                }
               }
               $$sroa$0505$0$be = $$0$i$i$i$i397;
              }
             } while(0);
             $1260 = ($$sroa$0505$0$be|0)==($975|0);
             if ($1260) {
              label = 369;
              break;
             }
             $$pre869 = HEAP32[$1224>>2]|0;
             $$pre870 = HEAP32[$1228>>2]|0;
             $$sroa$0505$0765 = $$sroa$0505$0$be;$1246 = $$pre869;$1248 = $$pre870;
            }
            if ((label|0) == 369) {
             $$pre871 = HEAP32[$741>>2]|0;
             $$pre873 = HEAP32[$1224>>2]|0;
             $$pre875 = HEAP32[$33>>2]|0;
             $$pre876 = HEAP32[$32>>2]|0;
             $$pre$phi905Z2D = $1224;$$pre$phi907Z2D = $33;$1230 = $$pre871;$1234 = $$pre875;$1235 = $$pre873;$1237 = $$pre876;
             label = 370;
             break;
            }
            else if ((label|0) == 374) {
             $1243 = ___cxa_find_matching_catch_2()|0;
             $1244 = tempRet0;
             $$21 = $1243;$$21182 = $1244;
             break;
            }
           }
          } while(0);
          L523: do {
           if ((label|0) == 370) {
            $1229 = ((($1230)) + 584|0);
            $1231 = HEAP32[$1229>>2]|0;
            $1232 = HEAP32[$743>>2]|0;
            $1233 = (($1235) - ($1234))|0;
            $1236 = $1233 >> 2;
            $$cast = $1234;
            __THREW__ = 0;
            invoke_viiiii($1231|0,($1232|0),($1236|0),($$cast|0),37594,($1237|0));
            $1238 = __THREW__; __THREW__ = 0;
            $1239 = $1238&1;
            if ($1239) {
             $1275 = ___cxa_find_matching_catch_2()|0;
             $1276 = tempRet0;
             $$21 = $1275;$$21182 = $1276;
             break;
            }
            $1240 = HEAP32[$$pre$phi905Z2D>>2]|0;
            $1241 = HEAP32[$$pre$phi907Z2D>>2]|0;
            $1242 = ($1240|0)==($1241|0);
            L528: do {
             if (!($1242)) {
              $$0160761 = 0;
              while(1) {
               __THREW__ = 0;
               $1277 = (invoke_ii(3265,4)|0);
               $1278 = __THREW__; __THREW__ = 0;
               $1279 = $1278&1;
               if ($1279) {
                break;
               }
               if ($1277) {
                __THREW__ = 0;
                $1280 = (invoke_ii(3266,4)|0);
                $1281 = __THREW__; __THREW__ = 0;
                $1282 = $1281&1;
                if ($1282) {
                 break;
                }
                __THREW__ = 0;
                $1283 = (invoke_iiii(3267,($1280|0),(146717|0),25)|0);
                $1284 = __THREW__; __THREW__ = 0;
                $1285 = $1284&1;
                if ($1285) {
                 break;
                }
                $1286 = HEAP32[$33>>2]|0;
                $1287 = (($1286) + ($$0160761<<2)|0);
                $1288 = HEAP32[$975>>2]|0;
                $1289 = ($1288|0)==(0|0);
                do {
                 if ($1289) {
                  $$025$i$i411 = $975;$$037$i410 = $975;$1300 = $1288;
                  label = 402;
                 } else {
                  $1290 = HEAP32[$1287>>2]|0;
                  $$0$i$i409 = $973;$$024$i$i408 = $1288;$1783 = $1288;
                  while(1) {
                   $1291 = ((($$024$i$i408)) + 16|0);
                   $1292 = HEAP32[$1291>>2]|0;
                   $1293 = ($1290>>>0)<($1292>>>0);
                   if ($1293) {
                    $1294 = HEAP32[$$024$i$i408>>2]|0;
                    $1295 = ($1294|0)==(0|0);
                    if ($1295) {
                     label = 397;
                     break;
                    } else {
                     $$0$ph$i$i406 = $$024$i$i408;$$in$i$i405 = $1294;
                    }
                   } else {
                    $1296 = ($1292>>>0)<($1290>>>0);
                    if (!($1296)) {
                     label = 401;
                     break;
                    }
                    $1297 = ((($$024$i$i408)) + 4|0);
                    $1298 = HEAP32[$1297>>2]|0;
                    $1299 = ($1298|0)==(0|0);
                    if ($1299) {
                     label = 400;
                     break;
                    } else {
                     $$0$ph$i$i406 = $1297;$$in$i$i405 = $1298;
                    }
                   }
                   $$0$i$i409 = $$0$ph$i$i406;$$024$i$i408 = $$in$i$i405;$1783 = $$in$i$i405;
                  }
                  if ((label|0) == 397) {
                   label = 0;
                   $$025$i53$i413 = $$024$i$i408;$$03752$i414 = $$024$i$i408;
                   label = 403;
                   break;
                  }
                  else if ((label|0) == 400) {
                   label = 0;
                   $$025$i53$i413 = $1297;$$03752$i414 = $$024$i$i408;
                   label = 403;
                   break;
                  }
                  else if ((label|0) == 401) {
                   label = 0;
                   $$025$i$i411 = $$0$i$i409;$$037$i410 = $$024$i$i408;$1300 = $1783;
                   label = 402;
                   break;
                  }
                 }
                } while(0);
                if ((label|0) == 402) {
                 label = 0;
                 $1301 = ($1300|0)==(0|0);
                 if ($1301) {
                  $$025$i53$i413 = $$025$i$i411;$$03752$i414 = $$037$i410;
                  label = 403;
                 } else {
                  $$014$i418 = $1300;
                 }
                }
                if ((label|0) == 403) {
                 label = 0;
                 __THREW__ = 0;
                 $1302 = (invoke_ii(3276,32)|0);
                 $1303 = __THREW__; __THREW__ = 0;
                 $1304 = $1303&1;
                 if ($1304) {
                  break;
                 }
                 $1305 = ((($1302)) + 16|0);
                 $1306 = HEAP32[$1287>>2]|0;
                 HEAP32[$1305>>2] = $1306;
                 $1307 = ((($1302)) + 20|0);
                 ;HEAP32[$1307>>2]=0|0;HEAP32[$1307+4>>2]=0|0;HEAP32[$1307+8>>2]=0|0;
                 HEAP32[$1302>>2] = 0;
                 $1308 = ((($1302)) + 4|0);
                 HEAP32[$1308>>2] = 0;
                 $1309 = ((($1302)) + 8|0);
                 HEAP32[$1309>>2] = $$03752$i414;
                 HEAP32[$$025$i53$i413>>2] = $1302;
                 $1310 = HEAP32[$26>>2]|0;
                 $1311 = HEAP32[$1310>>2]|0;
                 $1312 = ($1311|0)==(0|0);
                 if ($1312) {
                  $1315 = $1302;
                 } else {
                  $1313 = $1311;
                  HEAP32[$26>>2] = $1313;
                  $$pre$i$i416 = HEAP32[$$025$i53$i413>>2]|0;
                  $1315 = $$pre$i$i416;
                 }
                 $1314 = HEAP32[$973>>2]|0;
                 __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($1314,$1315);
                 $1316 = HEAP32[$974>>2]|0;
                 $1317 = (($1316) + 1)|0;
                 HEAP32[$974>>2] = $1317;
                 $$014$i418 = $1302;
                }
                $1318 = ((($$014$i418)) + 20|0);
                $1319 = ((($1318)) + 11|0);
                $1320 = HEAP8[$1319>>0]|0;
                $1321 = ($1320<<24>>24)<(0);
                $1322 = HEAP32[$1318>>2]|0;
                $1323 = $1321 ? $1322 : $1318;
                $1324 = ((($$014$i418)) + 24|0);
                $1325 = HEAP32[$1324>>2]|0;
                $1326 = $1320&255;
                $1327 = $1321 ? $1325 : $1326;
                __THREW__ = 0;
                $1328 = (invoke_iiii(3267,($1283|0),($1323|0),($1327|0))|0);
                $1329 = __THREW__; __THREW__ = 0;
                $1330 = $1329&1;
                if ($1330) {
                 break;
                }
                __THREW__ = 0;
                $1331 = (invoke_iiii(3267,($1328|0),(172027|0),1)|0);
                $1332 = __THREW__; __THREW__ = 0;
                $1333 = $1332&1;
                if ($1333) {
                 break;
                }
                __THREW__ = 0;
                $1334 = (invoke_iiii(3267,($1331|0),(146743|0),14)|0);
                $1335 = __THREW__; __THREW__ = 0;
                $1336 = $1335&1;
                if ($1336) {
                 break;
                }
                $1337 = HEAP32[$32>>2]|0;
                $1338 = (($1337) + ($$0160761<<2)|0);
                $1339 = HEAP32[$1338>>2]|0;
                __THREW__ = 0;
                $1340 = (invoke_iii(3863,($1334|0),($1339|0))|0);
                $1341 = __THREW__; __THREW__ = 0;
                $1342 = $1341&1;
                if ($1342) {
                 break;
                }
                __THREW__ = 0;
                (invoke_iiii(3267,($1340|0),(146758|0),2)|0);
                $1343 = __THREW__; __THREW__ = 0;
                $1344 = $1343&1;
                if ($1344) {
                 break;
                }
               }
               $1347 = (($$0160761) + 1)|0;
               $1348 = HEAP32[$$pre$phi905Z2D>>2]|0;
               $1349 = HEAP32[$$pre$phi907Z2D>>2]|0;
               $1350 = (($1348) - ($1349))|0;
               $1351 = $1350 >> 2;
               $1352 = ($1347>>>0)<($1351>>>0);
               if ($1352) {
                $$0160761 = $1347;
               } else {
                break L528;
               }
              }
              $1345 = ___cxa_find_matching_catch_2()|0;
              $1346 = tempRet0;
              $$21 = $1345;$$21182 = $1346;
              break L523;
             }
            } while(0);
            $1269 = ((($34)) + 4|0);
            HEAP32[$1269>>2] = 0;
            $1270 = ((($34)) + 8|0);
            HEAP32[$1270>>2] = 0;
            $1271 = ((($34)) + 4|0);
            HEAP32[$34>>2] = $1271;
            $1272 = HEAP32[$1203>>2]|0;
            $1273 = HEAP32[$32>>2]|0;
            $1274 = ($1272|0)==($1273|0);
            L566: do {
             if ($1274) {
              label = 414;
             } else {
              $$0159757 = 0;$$in = $1273;$1361 = 0;$1782 = 0;
              while(1) {
               $1359 = $$in;
               $1360 = (($1359) + ($$0159757<<2)|0);
               $1362 = ($1361|0)==(0|0);
               do {
                if ($1362) {
                 $$025$i$i435 = $1271;$$049$i = $1271;$1373 = $1782;
                 label = 425;
                } else {
                 $1363 = HEAP32[$1360>>2]|0;
                 $$0$i$i434 = $1269;$$024$i$i433 = $1361;$1784 = $1782;
                 while(1) {
                  $1364 = ((($$024$i$i433)) + 16|0);
                  $1365 = HEAP32[$1364>>2]|0;
                  $1366 = ($1363|0)<($1365|0);
                  if ($1366) {
                   $1367 = HEAP32[$$024$i$i433>>2]|0;
                   $1368 = ($1367|0)==(0|0);
                   if ($1368) {
                    label = 420;
                    break;
                   } else {
                    $$0$ph$i$i431 = $$024$i$i433;$$in$i$i430 = $1367;
                   }
                  } else {
                   $1369 = ($1365|0)<($1363|0);
                   if (!($1369)) {
                    label = 424;
                    break;
                   }
                   $1370 = ((($$024$i$i433)) + 4|0);
                   $1371 = HEAP32[$1370>>2]|0;
                   $1372 = ($1371|0)==(0|0);
                   if ($1372) {
                    label = 423;
                    break;
                   } else {
                    $$0$ph$i$i431 = $1370;$$in$i$i430 = $1371;
                   }
                  }
                  $$0$i$i434 = $$0$ph$i$i431;$$024$i$i433 = $$in$i$i430;$1784 = $$in$i$i430;
                 }
                 if ((label|0) == 420) {
                  label = 0;
                  $$025$i65$i = $$024$i$i433;$$04964$i = $$024$i$i433;
                  label = 426;
                  break;
                 }
                 else if ((label|0) == 423) {
                  label = 0;
                  $$025$i65$i = $1370;$$04964$i = $$024$i$i433;
                  label = 426;
                  break;
                 }
                 else if ((label|0) == 424) {
                  label = 0;
                  $$025$i$i435 = $$0$i$i434;$$049$i = $$024$i$i433;$1373 = $1784;
                  label = 425;
                  break;
                 }
                }
               } while(0);
               if ((label|0) == 425) {
                label = 0;
                $1374 = ($1373|0)==(0|0);
                if ($1374) {
                 $$025$i65$i = $$025$i$i435;$$04964$i = $$049$i;
                 label = 426;
                } else {
                 $$014$i437 = $1373;
                }
               }
               if ((label|0) == 426) {
                label = 0;
                __THREW__ = 0;
                $1375 = (invoke_ii(3276,32)|0);
                $1376 = __THREW__; __THREW__ = 0;
                $1377 = $1376&1;
                if ($1377) {
                 label = 435;
                 break;
                }
                $1378 = ((($1375)) + 16|0);
                $1379 = HEAP32[$1360>>2]|0;
                HEAP32[$1378>>2] = $1379;
                $1380 = ((($1375)) + 20|0);
                HEAP32[$1380>>2] = 0;
                $1381 = ((($1375)) + 24|0);
                HEAP32[$1381>>2] = 0;
                $1382 = ((($1375)) + 28|0);
                HEAP32[$1382>>2] = 0;
                HEAP32[$1375>>2] = 0;
                $1383 = ((($1375)) + 4|0);
                HEAP32[$1383>>2] = 0;
                $1384 = ((($1375)) + 8|0);
                HEAP32[$1384>>2] = $$04964$i;
                HEAP32[$$025$i65$i>>2] = $1375;
                $1385 = HEAP32[$34>>2]|0;
                $1386 = HEAP32[$1385>>2]|0;
                $1387 = ($1386|0)==(0|0);
                if ($1387) {
                 $1390 = $1375;
                } else {
                 $1388 = $1386;
                 HEAP32[$34>>2] = $1388;
                 $$pre$i$i436 = HEAP32[$$025$i65$i>>2]|0;
                 $1390 = $$pre$i$i436;
                }
                $1389 = HEAP32[$1269>>2]|0;
                __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($1389,$1390);
                $1391 = HEAP32[$1270>>2]|0;
                $1392 = (($1391) + 1)|0;
                HEAP32[$1270>>2] = $1392;
                $$014$i437 = $1375;
               }
               $1393 = HEAP32[$33>>2]|0;
               $1394 = (($1393) + ($$0159757<<2)|0);
               $1395 = HEAP32[$1394>>2]|0;
               HEAP32[$35>>2] = $1395;
               $1396 = ((($$014$i437)) + 24|0);
               $1397 = HEAP32[$1396>>2]|0;
               $1398 = ((($$014$i437)) + 28|0);
               $1399 = HEAP32[$1398>>2]|0;
               $1400 = ($1397|0)==($1399|0);
               if ($1400) {
                $1402 = ((($$014$i437)) + 20|0);
                __THREW__ = 0;
                invoke_vii(3865,($1402|0),($35|0));
                $1403 = __THREW__; __THREW__ = 0;
                $1404 = $1403&1;
                if ($1404) {
                 label = 436;
                 break;
                }
               } else {
                HEAP32[$1397>>2] = $1395;
                $1401 = ((($1397)) + 4|0);
                HEAP32[$1396>>2] = $1401;
               }
               $1405 = (($$0159757) + 1)|0;
               $1406 = HEAP32[$1203>>2]|0;
               $1407 = HEAP32[$32>>2]|0;
               $1408 = (($1406) - ($1407))|0;
               $1409 = $1408 >> 2;
               $1410 = ($1405>>>0)<($1409>>>0);
               if (!($1410)) {
                label = 414;
                break L566;
               }
               $$pre877 = HEAP32[$1271>>2]|0;
               $$0159757 = $1405;$$in = $1407;$1361 = $$pre877;$1782 = $$pre877;
              }
              if ((label|0) == 435) {
               $1411 = ___cxa_find_matching_catch_2()|0;
               $1412 = tempRet0;
               $$19 = $1411;$$19180 = $1412;$$pre$phi886Z2D = $1271;
               break;
              }
              else if ((label|0) == 436) {
               $1413 = ___cxa_find_matching_catch_2()|0;
               $1414 = tempRet0;
               $$19 = $1413;$$19180 = $1414;$$pre$phi886Z2D = $1271;
               break;
              }
             }
            } while(0);
            if ((label|0) == 414) {
             HEAP32[$36>>2] = 0;
             $1353 = HEAP32[$741>>2]|0;
             $1354 = ((($1353)) + 104|0);
             $1355 = HEAP32[$1354>>2]|0;
             $1356 = HEAP32[$743>>2]|0;
             __THREW__ = 0;
             invoke_viii($1355|0,($1356|0),37593,($36|0));
             $1357 = __THREW__; __THREW__ = 0;
             $1358 = $1357&1;
             L602: do {
              if ($1358) {
               $1420 = ___cxa_find_matching_catch_2()|0;
               $1421 = tempRet0;
               $$18 = $1420;$$18179 = $1421;
              } else {
               $1415 = HEAP32[$36>>2]|0;
               $1416 = ($1415|0)==(0);
               L605: do {
                if (!($1416)) {
                 $1417 = ((($40)) + 4|0);
                 $1418 = ((($40)) + 8|0);
                 $1419 = ((($40)) + 8|0);
                 $$0158755 = 0;
                 L607: while(1) {
                  HEAP32[$37>>2] = 0;
                  $1422 = HEAP32[$741>>2]|0;
                  $1423 = ((($1422)) + 684|0);
                  $1424 = HEAP32[$1423>>2]|0;
                  $1425 = HEAP32[$743>>2]|0;
                  __THREW__ = 0;
                  invoke_viiii($1424|0,($1425|0),($$0158755|0),37569,($37|0));
                  $1426 = __THREW__; __THREW__ = 0;
                  $1427 = $1426&1;
                  if ($1427) {
                   label = 454;
                   break;
                  }
                  HEAP32[$38>>2] = 0;
                  $1428 = HEAP32[$741>>2]|0;
                  $1429 = ((($1428)) + 684|0);
                  $1430 = HEAP32[$1429>>2]|0;
                  $1431 = HEAP32[$743>>2]|0;
                  __THREW__ = 0;
                  invoke_viiii($1430|0,($1431|0),($$0158755|0),37573,($38|0));
                  $1432 = __THREW__; __THREW__ = 0;
                  $1433 = $1432&1;
                  if ($1433) {
                   label = 455;
                   break;
                  }
                  HEAP32[$39>>2] = 0;
                  $1434 = HEAP32[$741>>2]|0;
                  $1435 = ((($1434)) + 684|0);
                  $1436 = HEAP32[$1435>>2]|0;
                  $1437 = HEAP32[$743>>2]|0;
                  __THREW__ = 0;
                  invoke_viiii($1436|0,($1437|0),($$0158755|0),37572,($39|0));
                  $1438 = __THREW__; __THREW__ = 0;
                  $1439 = $1438&1;
                  if ($1439) {
                   label = 456;
                   break;
                  }
                  __THREW__ = 0;
                  $1440 = (invoke_ii(3265,4)|0);
                  $1441 = __THREW__; __THREW__ = 0;
                  $1442 = $1441&1;
                  if ($1442) {
                   label = 456;
                   break;
                  }
                  if ($1440) {
                   __THREW__ = 0;
                   $1443 = (invoke_ii(3266,4)|0);
                   $1444 = __THREW__; __THREW__ = 0;
                   $1445 = $1444&1;
                   if ($1445) {
                    label = 456;
                    break;
                   }
                   __THREW__ = 0;
                   $1446 = (invoke_iiii(3267,($1443|0),(146761|0),37)|0);
                   $1447 = __THREW__; __THREW__ = 0;
                   $1448 = $1447&1;
                   if ($1448) {
                    label = 456;
                    break;
                   }
                   $1449 = HEAP32[$37>>2]|0;
                   __THREW__ = 0;
                   $1450 = (invoke_iii(3863,($1446|0),($1449|0))|0);
                   $1451 = __THREW__; __THREW__ = 0;
                   $1452 = $1451&1;
                   if ($1452) {
                    label = 456;
                    break;
                   }
                   __THREW__ = 0;
                   $1453 = (invoke_iiii(3267,($1450|0),(172027|0),1)|0);
                   $1454 = __THREW__; __THREW__ = 0;
                   $1455 = $1454&1;
                   if ($1455) {
                    label = 456;
                    break;
                   }
                   __THREW__ = 0;
                   $1456 = (invoke_iiii(3267,($1453|0),(146799|0),28)|0);
                   $1457 = __THREW__; __THREW__ = 0;
                   $1458 = $1457&1;
                   if ($1458) {
                    label = 456;
                    break;
                   }
                   $1459 = HEAP32[$38>>2]|0;
                   __THREW__ = 0;
                   $1460 = (invoke_iii(3863,($1456|0),($1459|0))|0);
                   $1461 = __THREW__; __THREW__ = 0;
                   $1462 = $1461&1;
                   if ($1462) {
                    label = 456;
                    break;
                   }
                   __THREW__ = 0;
                   $1463 = (invoke_iiii(3267,($1460|0),(146828|0),11)|0);
                   $1464 = __THREW__; __THREW__ = 0;
                   $1465 = $1464&1;
                   if ($1465) {
                    label = 456;
                    break;
                   }
                   $1466 = HEAP32[$39>>2]|0;
                   __THREW__ = 0;
                   $1467 = (invoke_iii(3863,($1463|0),($1466|0))|0);
                   $1468 = __THREW__; __THREW__ = 0;
                   $1469 = $1468&1;
                   if ($1469) {
                    label = 456;
                    break;
                   }
                   __THREW__ = 0;
                   (invoke_iiii(3267,($1467|0),(195712|0),1)|0);
                   $1470 = __THREW__; __THREW__ = 0;
                   $1471 = $1470&1;
                   if ($1471) {
                    label = 456;
                    break;
                   }
                  }
                  $1478 = HEAP32[$38>>2]|0;
                  $1479 = ($1478|0)==(0);
                  if (!($1479)) {
                   HEAP32[$40>>2] = 0;
                   HEAP32[$1417>>2] = 0;
                   HEAP32[$1418>>2] = 0;
                   $1480 = ($1478>>>0)>(1073741823);
                   if ($1480) {
                    label = 460;
                    break;
                   }
                   $1485 = $1478 << 2;
                   __THREW__ = 0;
                   $1486 = (invoke_ii(3276,($1485|0))|0);
                   $1487 = __THREW__; __THREW__ = 0;
                   $1488 = $1487&1;
                   if ($1488) {
                    label = 462;
                    break;
                   }
                   HEAP32[$40>>2] = $1486;
                   $1498 = (($1486) + ($1478<<2)|0);
                   HEAP32[$1419>>2] = $1498;
                   _memset(($1486|0),0,($1485|0))|0;
                   HEAP32[$1417>>2] = $1498;
                   $1499 = HEAP32[$741>>2]|0;
                   $1500 = ((($1499)) + 684|0);
                   $1501 = HEAP32[$1500>>2]|0;
                   $1502 = HEAP32[$743>>2]|0;
                   __THREW__ = 0;
                   invoke_viiii($1501|0,($1502|0),($$0158755|0),37574,($1486|0));
                   $1503 = __THREW__; __THREW__ = 0;
                   $1504 = $1503&1;
                   if ($1504) {
                    label = 491;
                    break;
                   }
                   __THREW__ = 0;
                   $1505 = (invoke_ii(3265,4)|0);
                   $1506 = __THREW__; __THREW__ = 0;
                   $1507 = $1506&1;
                   if ($1507) {
                    label = 491;
                    break;
                   }
                   if ($1505) {
                    __THREW__ = 0;
                    $1508 = (invoke_ii(3266,4)|0);
                    $1509 = __THREW__; __THREW__ = 0;
                    $1510 = $1509&1;
                    if ($1510) {
                     label = 491;
                     break;
                    }
                    __THREW__ = 0;
                    (invoke_iiii(3267,($1508|0),(146840|0),16)|0);
                    $1511 = __THREW__; __THREW__ = 0;
                    $1512 = $1511&1;
                    if ($1512) {
                     label = 491;
                     break;
                    }
                   }
                   $1513 = HEAP32[$38>>2]|0;
                   $1514 = ($1513|0)>(0);
                   if ($1514) {
                    $$0157753 = 0;
                    while(1) {
                     __THREW__ = 0;
                     $1524 = (invoke_ii(3265,4)|0);
                     $1525 = __THREW__; __THREW__ = 0;
                     $1526 = $1525&1;
                     if ($1526) {
                      label = 491;
                      break L607;
                     }
                     if ($1524) {
                      __THREW__ = 0;
                      $1527 = (invoke_ii(3266,4)|0);
                      $1528 = __THREW__; __THREW__ = 0;
                      $1529 = $1528&1;
                      if ($1529) {
                       label = 491;
                       break L607;
                      }
                      $1530 = HEAP32[$40>>2]|0;
                      $1531 = (($1530) + ($$0157753<<2)|0);
                      $1532 = HEAP32[$1531>>2]|0;
                      __THREW__ = 0;
                      (invoke_iii(3863,($1527|0),($1532|0))|0);
                      $1533 = __THREW__; __THREW__ = 0;
                      $1534 = $1533&1;
                      if ($1534) {
                       label = 491;
                       break L607;
                      }
                     }
                     $1535 = HEAP32[$38>>2]|0;
                     $1536 = (($1535) + -1)|0;
                     $1537 = ($$0157753|0)<($1536|0);
                     do {
                      if ($1537) {
                       __THREW__ = 0;
                       $1538 = (invoke_ii(3265,4)|0);
                       $1539 = __THREW__; __THREW__ = 0;
                       $1540 = $1539&1;
                       if ($1540) {
                        label = 491;
                        break L607;
                       }
                       if (!($1538)) {
                        break;
                       }
                       __THREW__ = 0;
                       $1541 = (invoke_ii(3266,4)|0);
                       $1542 = __THREW__; __THREW__ = 0;
                       $1543 = $1542&1;
                       if ($1543) {
                        label = 491;
                        break L607;
                       }
                       __THREW__ = 0;
                       (invoke_iiii(3267,($1541|0),(146554|0),2)|0);
                       $1544 = __THREW__; __THREW__ = 0;
                       $1545 = $1544&1;
                       if ($1545) {
                        label = 491;
                        break L607;
                       }
                      } else {
                       __THREW__ = 0;
                       $1546 = (invoke_ii(3265,4)|0);
                       $1547 = __THREW__; __THREW__ = 0;
                       $1548 = $1547&1;
                       if ($1548) {
                        label = 491;
                        break L607;
                       }
                       if (!($1546)) {
                        break;
                       }
                       __THREW__ = 0;
                       $1549 = (invoke_ii(3266,4)|0);
                       $1550 = __THREW__; __THREW__ = 0;
                       $1551 = $1550&1;
                       if ($1551) {
                        label = 491;
                        break L607;
                       }
                       __THREW__ = 0;
                       (invoke_iiii(3267,($1549|0),(146758|0),2)|0);
                       $1552 = __THREW__; __THREW__ = 0;
                       $1553 = $1552&1;
                       if ($1553) {
                        label = 491;
                        break L607;
                       }
                      }
                     } while(0);
                     $1554 = (($$0157753) + 1)|0;
                     $1555 = HEAP32[$38>>2]|0;
                     $1556 = ($1554|0)<($1555|0);
                     if ($1556) {
                      $$0157753 = $1554;
                     } else {
                      break;
                     }
                    }
                   }
                   $1515 = HEAP32[$40>>2]|0;
                   $1516 = ($1515|0)==(0|0);
                   if (!($1516)) {
                    $1517 = HEAP32[$1417>>2]|0;
                    $1518 = ($1517|0)==($1515|0);
                    if (!($1518)) {
                     $scevgep$i$i$i = ((($1517)) + -4|0);
                     $1519 = $scevgep$i$i$i;
                     $1520 = $1515;
                     $1521 = (($1519) - ($1520))|0;
                     $1522 = $1521 >>> 2;
                     $1523 = $1522 ^ -1;
                     $scevgep5$i$i$i = (($1517) + ($1523<<2)|0);
                     HEAP32[$1417>>2] = $scevgep5$i$i$i;
                    }
                    __ZdlPv($1515);
                   }
                  }
                  $1568 = (($$0158755) + 1)|0;
                  $1569 = HEAP32[$36>>2]|0;
                  $1570 = ($1568>>>0)<($1569>>>0);
                  if ($1570) {
                   $$0158755 = $1568;
                  } else {
                   break L605;
                  }
                 }
                 do {
                  if ((label|0) == 454) {
                   $1472 = ___cxa_find_matching_catch_2()|0;
                   $1473 = tempRet0;
                   $$17 = $1472;$$17178 = $1473;
                  }
                  else if ((label|0) == 455) {
                   $1474 = ___cxa_find_matching_catch_2()|0;
                   $1475 = tempRet0;
                   $$16 = $1474;$$16177 = $1475;
                   label = 498;
                  }
                  else if ((label|0) == 456) {
                   $1476 = ___cxa_find_matching_catch_2()|0;
                   $1477 = tempRet0;
                   $eh$lpad$body458$index41Z2D = $1477;$eh$lpad$body458$indexZ2D = $1476;
                   label = 457;
                  }
                  else if ((label|0) == 460) {
                   __THREW__ = 0;
                   invoke_vi(3307,($40|0));
                   $1481 = __THREW__; __THREW__ = 0;
                   $1482 = ___cxa_find_matching_catch_2()|0;
                   $1483 = tempRet0;
                   $$pre878 = HEAP32[$40>>2]|0;
                   $1484 = ($$pre878|0)==(0|0);
                   if ($1484) {
                    $eh$lpad$body458$index41Z2D = $1483;$eh$lpad$body458$indexZ2D = $1482;
                    label = 457;
                    break;
                   }
                   $1491 = HEAP32[$1417>>2]|0;
                   $1492 = ($1491|0)==($$pre878|0);
                   if (!($1492)) {
                    $scevgep$i$i$i$i452 = ((($1491)) + -4|0);
                    $1493 = $scevgep$i$i$i$i452;
                    $1494 = $$pre878;
                    $1495 = (($1493) - ($1494))|0;
                    $1496 = $1495 >>> 2;
                    $1497 = $1496 ^ -1;
                    $scevgep5$i$i$i$i453 = (($1491) + ($1497<<2)|0);
                    HEAP32[$1417>>2] = $scevgep5$i$i$i$i453;
                   }
                   __ZdlPv($$pre878);
                   $eh$lpad$body458$index41Z2D = $1483;$eh$lpad$body458$indexZ2D = $1482;
                   label = 457;
                  }
                  else if ((label|0) == 462) {
                   $1489 = ___cxa_find_matching_catch_2()|0;
                   $1490 = tempRet0;
                   $eh$lpad$body458$index41Z2D = $1490;$eh$lpad$body458$indexZ2D = $1489;
                   label = 457;
                  }
                  else if ((label|0) == 491) {
                   $1557 = ___cxa_find_matching_catch_2()|0;
                   $1558 = tempRet0;
                   $1559 = HEAP32[$40>>2]|0;
                   $1560 = ($1559|0)==(0|0);
                   if (!($1560)) {
                    $1561 = HEAP32[$1417>>2]|0;
                    $1562 = ($1561|0)==($1559|0);
                    if (!($1562)) {
                     $scevgep$i$i$i465 = ((($1561)) + -4|0);
                     $1563 = $scevgep$i$i$i465;
                     $1564 = $1559;
                     $1565 = (($1563) - ($1564))|0;
                     $1566 = $1565 >>> 2;
                     $1567 = $1566 ^ -1;
                     $scevgep5$i$i$i466 = (($1561) + ($1567<<2)|0);
                     HEAP32[$1417>>2] = $scevgep5$i$i$i466;
                    }
                    __ZdlPv($1559);
                   }
                   $$15 = $1557;$$15176 = $1558;
                   label = 497;
                  }
                 } while(0);
                 if ((label|0) == 457) {
                  $$15 = $eh$lpad$body458$indexZ2D;$$15176 = $eh$lpad$body458$index41Z2D;
                  label = 497;
                 }
                 if ((label|0) == 497) {
                  $$16 = $$15;$$16177 = $$15176;
                  label = 498;
                 }
                 if ((label|0) == 498) {
                  $$17 = $$16;$$17178 = $$16177;
                 }
                 $$18 = $$17;$$18179 = $$17178;
                 break L602;
                }
               } while(0);
               $1571 = HEAP32[$1271>>2]|0;
               __ZNSt3__26__treeINS_12__value_typeIiNS_6vectorIiNS_9allocatorIiEEEEEENS_19__map_value_compareIiS6_NS_4lessIiEELb1EEENS3_IS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($34,$1571);
               $1572 = HEAP32[$33>>2]|0;
               $1573 = ($1572|0)==(0|0);
               if (!($1573)) {
                $1574 = HEAP32[$1224>>2]|0;
                $1575 = ($1574|0)==($1572|0);
                if (!($1575)) {
                 $scevgep$i$i$i470 = ((($1574)) + -4|0);
                 $1576 = $scevgep$i$i$i470;
                 $1577 = $1572;
                 $1578 = (($1576) - ($1577))|0;
                 $1579 = $1578 >>> 2;
                 $1580 = $1579 ^ -1;
                 $scevgep5$i$i$i471 = (($1574) + ($1580<<2)|0);
                 HEAP32[$1224>>2] = $scevgep5$i$i$i471;
                }
                __ZdlPv($1572);
               }
               $1581 = HEAP32[$32>>2]|0;
               $1582 = ($1581|0)==(0|0);
               if (!($1582)) {
                $1583 = HEAP32[$1203>>2]|0;
                $1584 = ($1583|0)==($1581|0);
                if (!($1584)) {
                 $scevgep$i$i$i473 = ((($1583)) + -4|0);
                 $1585 = $scevgep$i$i$i473;
                 $1586 = $1581;
                 $1587 = (($1585) - ($1586))|0;
                 $1588 = $1587 >>> 2;
                 $1589 = $1588 ^ -1;
                 $scevgep5$i$i$i474 = (($1583) + ($1589<<2)|0);
                 HEAP32[$1203>>2] = $scevgep5$i$i$i474;
                }
                __ZdlPv($1581);
               }
               $$pre879 = HEAP32[$741>>2]|0;
               $1610 = $$pre879;
               break L496;
              }
             } while(0);
             $$19 = $$18;$$19180 = $$18179;$$pre$phi886Z2D = $1271;
            }
            $1590 = HEAP32[$$pre$phi886Z2D>>2]|0;
            __ZNSt3__26__treeINS_12__value_typeIiNS_6vectorIiNS_9allocatorIiEEEEEENS_19__map_value_compareIiS6_NS_4lessIiEELb1EEENS3_IS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($34,$1590);
            $$21 = $$19;$$21182 = $$19180;
           }
          } while(0);
          $1591 = HEAP32[$33>>2]|0;
          $1592 = ($1591|0)==(0|0);
          if (!($1592)) {
           $1593 = HEAP32[$1224>>2]|0;
           $1594 = ($1593|0)==($1591|0);
           if (!($1594)) {
            $scevgep$i$i$i478 = ((($1593)) + -4|0);
            $1595 = $scevgep$i$i$i478;
            $1596 = $1591;
            $1597 = (($1595) - ($1596))|0;
            $1598 = $1597 >>> 2;
            $1599 = $1598 ^ -1;
            $scevgep5$i$i$i479 = (($1593) + ($1599<<2)|0);
            HEAP32[$1224>>2] = $scevgep5$i$i$i479;
           }
           __ZdlPv($1591);
          }
          $1600 = HEAP32[$32>>2]|0;
          $1601 = ($1600|0)==(0|0);
          if (!($1601)) {
           $1602 = HEAP32[$1203>>2]|0;
           $1603 = ($1602|0)==($1600|0);
           if (!($1603)) {
            $scevgep$i$i$i483 = ((($1602)) + -4|0);
            $1604 = $scevgep$i$i$i483;
            $1605 = $1600;
            $1606 = (($1604) - ($1605))|0;
            $1607 = $1606 >>> 2;
            $1608 = $1607 ^ -1;
            $scevgep5$i$i$i484 = (($1602) + ($1608<<2)|0);
            HEAP32[$1203>>2] = $scevgep5$i$i$i484;
           }
           __ZdlPv($1600);
          }
          $$30 = $$21;$$30191 = $$21182;
          break L379;
         }
        } while(0);
        $1211 = ___cxa_find_matching_catch_2()|0;
        $1212 = tempRet0;
        $1213 = HEAP32[$32>>2]|0;
        $1214 = ($1213|0)==(0|0);
        if (!($1214)) {
         $1215 = HEAP32[$1203>>2]|0;
         $1216 = ($1215|0)==($1213|0);
         if (!($1216)) {
          $scevgep$i$i$i$i = ((($1215)) + -4|0);
          $1217 = $scevgep$i$i$i$i;
          $1218 = $1213;
          $1219 = (($1217) - ($1218))|0;
          $1220 = $1219 >>> 2;
          $1221 = $1220 ^ -1;
          $scevgep5$i$i$i$i = (($1215) + ($1221<<2)|0);
          HEAP32[$1203>>2] = $scevgep5$i$i$i$i;
         }
         __ZdlPv($1213);
        }
        $$30 = $1211;$$30191 = $1212;
        break L379;
       }
      } while(0);
      HEAP32[$41>>2] = 0;
      $1609 = ((($1610)) + 104|0);
      $1611 = HEAP32[$1609>>2]|0;
      $1612 = HEAP32[$743>>2]|0;
      __THREW__ = 0;
      invoke_viii($1611|0,($1612|0),35721,($41|0));
      $1613 = __THREW__; __THREW__ = 0;
      $1614 = $1613&1;
      L720: do {
       if ($1614) {
        label = 525;
       } else {
        $1615 = HEAP32[$741>>2]|0;
        $1616 = ((($1615)) + 104|0);
        $1617 = HEAP32[$1616>>2]|0;
        $1618 = HEAP32[$743>>2]|0;
        __THREW__ = 0;
        invoke_viii($1617|0,($1618|0),35722,($28|0));
        $1619 = __THREW__; __THREW__ = 0;
        $1620 = $1619&1;
        if ($1620) {
         label = 525;
         break;
        }
        $1621 = HEAP32[$41>>2]|0;
        $1622 = ($1621|0)>(0);
        $1623 = HEAP32[$28>>2]|0;
        $1624 = ($1623|0)>(1);
        $or$cond3 = $1622 & $1624;
        L723: do {
         if ($or$cond3) {
          HEAP32[$42>>2] = 0;
          HEAP32[$43>>2] = 0;
          __THREW__ = 0;
          $1625 = (invoke_ii(3820,($1623|0))|0);
          $1626 = __THREW__; __THREW__ = 0;
          $1627 = $1626&1;
          L725: do {
           if ($1627) {
            $1633 = ___cxa_find_matching_catch_2()|0;
            $1634 = tempRet0;
            $$28 = $1633;$$28189 = $1634;
           } else {
            $1628 = ((($44)) + 11|0);
            $1629 = ((($44)) + 8|0);
            $1630 = ((($44)) + 4|0);
            $$0155752 = 0;$1639 = $1623;
            L728: while(1) {
             $1635 = HEAP32[$741>>2]|0;
             $1636 = ((($1635)) + 88|0);
             $1637 = HEAP32[$1636>>2]|0;
             $1638 = HEAP32[$743>>2]|0;
             __THREW__ = 0;
             invoke_viiiiiii($1637|0,($1638|0),($$0155752|0),($1639|0),(0|0),($42|0),($43|0),($1625|0));
             $1640 = __THREW__; __THREW__ = 0;
             $1641 = $1640&1;
             if ($1641) {
              label = 560;
              break;
             }
             $1642 = HEAP32[$741>>2]|0;
             $1643 = ((($1642)) + 100|0);
             $1644 = HEAP32[$1643>>2]|0;
             $1645 = HEAP32[$743>>2]|0;
             __THREW__ = 0;
             $1646 = (invoke_iii($1644|0,($1645|0),($1625|0))|0);
             $1647 = __THREW__; __THREW__ = 0;
             $1648 = $1647&1;
             if ($1648) {
              label = 560;
              break;
             }
             $1649 = ($1646|0)==(-1);
             do {
              if (!($1649)) {
               $1650 = HEAP32[$43>>2]|0;
               $1651 = HEAP32[$42>>2]|0;
               ;HEAP32[$44>>2]=0|0;HEAP32[$44+4>>2]=0|0;HEAP32[$44+8>>2]=0|0;
               $1652 = (_strlen($1625)|0);
               $1653 = ($1652>>>0)>(4294967279);
               if ($1653) {
                label = 532;
                break L728;
               }
               $1655 = ($1652>>>0)<(11);
               if ($1655) {
                $1662 = $1652&255;
                HEAP8[$1628>>0] = $1662;
                $1663 = ($1652|0)==(0);
                if ($1663) {
                 $$017$i$i490 = $44;
                } else {
                 $$016$i$i489 = $44;
                 label = 537;
                }
               } else {
                $1656 = (($1652) + 16)|0;
                $1657 = $1656 & -16;
                __THREW__ = 0;
                $1658 = (invoke_ii(3276,($1657|0))|0);
                $1659 = __THREW__; __THREW__ = 0;
                $1660 = $1659&1;
                if ($1660) {
                 label = 561;
                 break L728;
                }
                HEAP32[$44>>2] = $1658;
                $1661 = $1657 | -2147483648;
                HEAP32[$1629>>2] = $1661;
                HEAP32[$1630>>2] = $1652;
                $$016$i$i489 = $1658;
                label = 537;
               }
               if ((label|0) == 537) {
                label = 0;
                _memcpy(($$016$i$i489|0),($1625|0),($1652|0))|0;
                $$017$i$i490 = $$016$i$i489;
               }
               $1664 = (($$017$i$i490) + ($1652)|0);
               HEAP8[$1664>>0] = 0;
               __THREW__ = 0;
               $1665 = (invoke_iii(3866,($340|0),($44|0))|0);
               $1666 = __THREW__; __THREW__ = 0;
               $1667 = $1666&1;
               if ($1667) {
                label = 562;
                break L728;
               }
               HEAP32[$1665>>2] = $1646;
               $$sroa$5$0$$sroa_idx496 = ((($1665)) + 4|0);
               HEAP32[$$sroa$5$0$$sroa_idx496>>2] = $1650;
               $$sroa$6$0$$sroa_idx499 = ((($1665)) + 8|0);
               HEAP32[$$sroa$6$0$$sroa_idx499>>2] = $1651;
               $1668 = HEAP8[$1628>>0]|0;
               $1669 = ($1668<<24>>24)<(0);
               if ($1669) {
                $1670 = HEAP32[$44>>2]|0;
                __ZdlPv($1670);
               }
               __THREW__ = 0;
               $1671 = (invoke_ii(3265,4)|0);
               $1672 = __THREW__; __THREW__ = 0;
               $1673 = $1672&1;
               if ($1673) {
                label = 565;
                break L728;
               }
               if (!($1671)) {
                break;
               }
               __THREW__ = 0;
               $1674 = (invoke_ii(3266,4)|0);
               $1675 = __THREW__; __THREW__ = 0;
               $1676 = $1675&1;
               if ($1676) {
                label = 565;
                break L728;
               }
               __THREW__ = 0;
               $1677 = (invoke_iiii(3267,($1674|0),(146857|0),9)|0);
               $1678 = __THREW__; __THREW__ = 0;
               $1679 = $1678&1;
               if ($1679) {
                label = 565;
                break L728;
               }
               $1680 = (_strlen($1625)|0);
               __THREW__ = 0;
               $1681 = (invoke_iiii(3267,($1677|0),($1625|0),($1680|0))|0);
               $1682 = __THREW__; __THREW__ = 0;
               $1683 = $1682&1;
               if ($1683) {
                label = 565;
                break L728;
               }
               __THREW__ = 0;
               $1684 = (invoke_iiii(3267,($1681|0),(172027|0),1)|0);
               $1685 = __THREW__; __THREW__ = 0;
               $1686 = $1685&1;
               if ($1686) {
                label = 565;
                break L728;
               }
               __THREW__ = 0;
               $1687 = (invoke_iiii(3267,($1684|0),(146697|0),5)|0);
               $1688 = __THREW__; __THREW__ = 0;
               $1689 = $1688&1;
               if ($1689) {
                label = 565;
                break L728;
               }
               __THREW__ = 0;
               $1690 = (invoke_iii(3863,($1687|0),($1646|0))|0);
               $1691 = __THREW__; __THREW__ = 0;
               $1692 = $1691&1;
               if ($1692) {
                label = 565;
                break L728;
               }
               __THREW__ = 0;
               $1693 = (invoke_iiii(3267,($1690|0),(146703|0),6)|0);
               $1694 = __THREW__; __THREW__ = 0;
               $1695 = $1694&1;
               if ($1695) {
                label = 565;
                break L728;
               }
               $1696 = HEAP32[$42>>2]|0;
               __THREW__ = 0;
               $1697 = (invoke_iii(3863,($1693|0),($1696|0))|0);
               $1698 = __THREW__; __THREW__ = 0;
               $1699 = $1698&1;
               if ($1699) {
                label = 565;
                break L728;
               }
               $1700 = HEAP32[$1697>>2]|0;
               $1701 = ((($1700)) + -12|0);
               $1702 = HEAP32[$1701>>2]|0;
               $1703 = (($1697) + ($1702)|0);
               __THREW__ = 0;
               invoke_vii(3257,($9|0),($1703|0));
               $1704 = __THREW__; __THREW__ = 0;
               $1705 = $1704&1;
               if ($1705) {
                label = 565;
                break L728;
               }
               __THREW__ = 0;
               $1706 = (invoke_iii(3255,($9|0),(215188|0))|0);
               $1707 = __THREW__; __THREW__ = 0;
               $1708 = $1707&1;
               if ($1708) {
                label = 554;
                break L728;
               }
               $1709 = HEAP32[$1706>>2]|0;
               $1710 = ((($1709)) + 28|0);
               $1711 = HEAP32[$1710>>2]|0;
               __THREW__ = 0;
               $1712 = (invoke_iii($1711|0,($1706|0),10)|0);
               $1713 = __THREW__; __THREW__ = 0;
               $1714 = $1713&1;
               if ($1714) {
                label = 554;
                break L728;
               }
               __THREW__ = 0;
               invoke_vi(3263,($9|0));
               $1721 = __THREW__; __THREW__ = 0;
               $1722 = $1721&1;
               if ($1722) {
                label = 565;
                break L728;
               }
               __THREW__ = 0;
               (invoke_iii(3268,($1697|0),($1712|0))|0);
               $1723 = __THREW__; __THREW__ = 0;
               $1724 = $1723&1;
               if ($1724) {
                label = 565;
                break L728;
               }
               __THREW__ = 0;
               (invoke_ii(3269,($1697|0))|0);
               $1725 = __THREW__; __THREW__ = 0;
               $1726 = $1725&1;
               if ($1726) {
                label = 565;
                break L728;
               }
              }
             } while(0);
             $1738 = (($$0155752) + 1)|0;
             $1739 = HEAP32[$41>>2]|0;
             $1740 = ($1738|0)<($1739|0);
             if (!($1740)) {
              label = 569;
              break;
             }
             $$pre880 = HEAP32[$28>>2]|0;
             $$0155752 = $1738;$1639 = $$pre880;
            }
            do {
             if ((label|0) == 532) {
              __THREW__ = 0;
              invoke_vi(3367,($44|0));
              $1654 = __THREW__; __THREW__ = 0;
              label = 561;
             }
             else if ((label|0) == 554) {
              $1715 = ___cxa_find_matching_catch_2()|0;
              $1716 = tempRet0;
              __THREW__ = 0;
              invoke_vi(3263,($9|0));
              $1717 = __THREW__; __THREW__ = 0;
              $1718 = $1717&1;
              if ($1718) {
               $1719 = ___cxa_find_matching_catch_3(0|0)|0;
               $1720 = tempRet0;
               ___clang_call_terminate($1719);
               // unreachable;
              } else {
               $eh$lpad$body226$index53Z2D = $1716;$eh$lpad$body226$indexZ2D = $1715;
               label = 566;
               break;
              }
             }
             else if ((label|0) == 560) {
              $1727 = ___cxa_find_matching_catch_2()|0;
              $1728 = tempRet0;
              $$28 = $1727;$$28189 = $1728;
              break L725;
             }
             else if ((label|0) == 562) {
              $1731 = ___cxa_find_matching_catch_2()|0;
              $1732 = tempRet0;
              $1733 = HEAP8[$1628>>0]|0;
              $1734 = ($1733<<24>>24)<(0);
              if (!($1734)) {
               $$25 = $1731;$$25186 = $1732;
               break;
              }
              $1735 = HEAP32[$44>>2]|0;
              __ZdlPv($1735);
              $$25 = $1731;$$25186 = $1732;
             }
             else if ((label|0) == 565) {
              $1736 = ___cxa_find_matching_catch_2()|0;
              $1737 = tempRet0;
              $eh$lpad$body226$index53Z2D = $1737;$eh$lpad$body226$indexZ2D = $1736;
              label = 566;
             }
             else if ((label|0) == 569) {
              __ZdaPv($1625);
              break L723;
             }
            } while(0);
            if ((label|0) == 561) {
             $1729 = ___cxa_find_matching_catch_2()|0;
             $1730 = tempRet0;
             $$25 = $1729;$$25186 = $1730;
            }
            else if ((label|0) == 566) {
             $$28 = $eh$lpad$body226$indexZ2D;$$28189 = $eh$lpad$body226$index53Z2D;
             break;
            }
            $$28 = $$25;$$28189 = $$25186;
           }
          } while(0);
          $$29 = $$28;$$29190 = $$28189;
          break L720;
         }
        } while(0);
        __THREW__ = 0;
        $1741 = (invoke_ii(3265,4)|0);
        $1742 = __THREW__; __THREW__ = 0;
        $1743 = $1742&1;
        if ($1743) {
         label = 525;
         break;
        }
        L781: do {
         if ($1741) {
          __THREW__ = 0;
          $1744 = (invoke_ii(3266,4)|0);
          $1745 = __THREW__; __THREW__ = 0;
          $1746 = $1745&1;
          if ($1746) {
           label = 525;
           break L720;
          }
          $1747 = HEAP32[$1744>>2]|0;
          $1748 = ((($1747)) + -12|0);
          $1749 = HEAP32[$1748>>2]|0;
          $1750 = (($1744) + ($1749)|0);
          __THREW__ = 0;
          invoke_vii(3257,($10|0),($1750|0));
          $1751 = __THREW__; __THREW__ = 0;
          $1752 = $1751&1;
          if ($1752) {
           label = 525;
           break L720;
          }
          __THREW__ = 0;
          $1753 = (invoke_iii(3255,($10|0),(215188|0))|0);
          $1754 = __THREW__; __THREW__ = 0;
          $1755 = $1754&1;
          do {
           if (!($1755)) {
            $1756 = HEAP32[$1753>>2]|0;
            $1757 = ((($1756)) + 28|0);
            $1758 = HEAP32[$1757>>2]|0;
            __THREW__ = 0;
            $1759 = (invoke_iii($1758|0,($1753|0),10)|0);
            $1760 = __THREW__; __THREW__ = 0;
            $1761 = $1760&1;
            if ($1761) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3263,($10|0));
            $1768 = __THREW__; __THREW__ = 0;
            $1769 = $1768&1;
            if ($1769) {
             label = 525;
             break L720;
            }
            __THREW__ = 0;
            (invoke_iii(3268,($1744|0),($1759|0))|0);
            $1770 = __THREW__; __THREW__ = 0;
            $1771 = $1770&1;
            if ($1771) {
             label = 525;
             break L720;
            }
            __THREW__ = 0;
            (invoke_ii(3269,($1744|0))|0);
            $1772 = __THREW__; __THREW__ = 0;
            $1773 = $1772&1;
            if ($1773) {
             label = 525;
             break L720;
            } else {
             break L781;
            }
           }
          } while(0);
          $1762 = ___cxa_find_matching_catch_2()|0;
          $1763 = tempRet0;
          __THREW__ = 0;
          invoke_vi(3263,($10|0));
          $1764 = __THREW__; __THREW__ = 0;
          $1765 = $1764&1;
          if ($1765) {
           $1766 = ___cxa_find_matching_catch_3(0|0)|0;
           $1767 = tempRet0;
           ___clang_call_terminate($1766);
           // unreachable;
          } else {
           $eh$lpad$body$index48Z2D = $1763;$eh$lpad$body$indexZ2D = $1762;
           label = 526;
           break L720;
          }
         }
        } while(0);
        $1774 = HEAP32[$975>>2]|0;
        __ZNSt3__26__treeINS_12__value_typeIjNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEEENS_19__map_value_compareIjS8_NS_4lessIjEELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($26,$1774);
        STACKTOP = sp;return;
       }
      } while(0);
      if ((label|0) == 525) {
       $1631 = ___cxa_find_matching_catch_2()|0;
       $1632 = tempRet0;
       $eh$lpad$body$index48Z2D = $1632;$eh$lpad$body$indexZ2D = $1631;
       label = 526;
      }
      if ((label|0) == 526) {
       $$29 = $eh$lpad$body$indexZ2D;$$29190 = $eh$lpad$body$index48Z2D;
      }
      $$30 = $$29;$$30191 = $$29190;
     }
    }
   } while(0);
   if ((label|0) == 273) {
    $999 = ___cxa_find_matching_catch_2()|0;
    $1000 = tempRet0;
    $$30 = $999;$$30191 = $1000;
   }
   $1775 = HEAP32[$975>>2]|0;
   __ZNSt3__26__treeINS_12__value_typeIjNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEEENS_19__map_value_compareIjS8_NS_4lessIjEELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($26,$1775);
   $$31 = $$30;$$31192 = $$30191;
   ___resumeException($$31|0);
   // unreachable;
  }
 } while(0);
 if ((label|0) == 191) {
  $736 = ___cxa_find_matching_catch_2()|0;
  $737 = tempRet0;
  $$pre889 = ((($18)) + 11|0);
  $$pre$phi890Z2D = $$pre889;$eh$lpad$body307$index24Z2D = $737;$eh$lpad$body307$indexZ2D = $736;
 }
 $738 = HEAP8[$$pre$phi890Z2D>>0]|0;
 $739 = ($738<<24>>24)<(0);
 if ($739) {
  $740 = HEAP32[$18>>2]|0;
  __ZdlPv($740);
 }
 $$31 = $eh$lpad$body307$indexZ2D;$$31192 = $eh$lpad$body307$index24Z2D;
 ___resumeException($$31|0);
 // unreachable;
}
function __ZN3osg7Program17PerContextProgram15validateProgramEv($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index3Z2D = 0, $eh$lpad$body$indexZ2D = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $1 = sp + 24|0;
 $2 = sp + 20|0;
 $3 = sp + 16|0;
 $4 = sp + 12|0;
 $5 = sp;
 HEAP32[$4>>2] = 0;
 $6 = ((($0)) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($7)) + 256|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($0)) + 20|0);
 $11 = HEAP32[$10>>2]|0;
 FUNCTION_TABLE_vi[$9 & 8191]($11);
 $12 = HEAP32[$6>>2]|0;
 $13 = ((($12)) + 104|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP32[$10>>2]|0;
 FUNCTION_TABLE_viii[$14 & 8191]($15,35715,$4);
 $16 = HEAP32[$4>>2]|0;
 $17 = ($16|0)==(1);
 if ($17) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $18 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
 do {
  if ($18) {
   $19 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
   $20 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($19,146444,26)|0);
   $21 = ((($0)) + 12|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = ((($22)) + 12|0);
   $24 = ((($23)) + 11|0);
   $25 = HEAP8[$24>>0]|0;
   $26 = ($25<<24>>24)<(0);
   $27 = HEAP32[$23>>2]|0;
   $28 = $26 ? $27 : $23;
   $29 = ((($22)) + 16|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = $25&255;
   $32 = $26 ? $30 : $31;
   $33 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($20,$28,$32)|0);
   $34 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($33,172027,1)|0);
   $35 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($34,146471,4)|0);
   $36 = HEAP32[$10>>2]|0;
   $37 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($35,$36)|0);
   $38 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($37,146476,11)|0);
   $39 = ((($0)) + 40|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($38,$40)|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = ((($42)) + -12|0);
   $44 = HEAP32[$43>>2]|0;
   $45 = (($41) + ($44)|0);
   __ZNKSt3__28ios_base6getlocEv($2,$45);
   __THREW__ = 0;
   $46 = (invoke_iii(3255,($2|0),(215188|0))|0);
   $47 = __THREW__; __THREW__ = 0;
   $48 = $47&1;
   if (!($48)) {
    $49 = HEAP32[$46>>2]|0;
    $50 = ((($49)) + 28|0);
    $51 = HEAP32[$50>>2]|0;
    __THREW__ = 0;
    $52 = (invoke_iii($51|0,($46|0),10)|0);
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if (!($54)) {
     __ZNSt3__26localeD2Ev($2);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($41,$52)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($41)|0);
     break;
    }
   }
   $55 = ___cxa_find_matching_catch_2()|0;
   $56 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($2|0));
   $57 = __THREW__; __THREW__ = 0;
   $58 = $57&1;
   if ($58) {
    $59 = ___cxa_find_matching_catch_3(0|0)|0;
    $60 = tempRet0;
    ___clang_call_terminate($59);
    // unreachable;
   } else {
    ___resumeException($55|0);
    // unreachable;
   }
  }
 } while(0);
 ;HEAP32[$5>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;
 $61 = HEAP32[$0>>2]|0;
 $62 = ((($61)) + 20|0);
 $63 = HEAP32[$62>>2]|0;
 __THREW__ = 0;
 $64 = (invoke_iii($63|0,($0|0),($5|0))|0);
 $65 = __THREW__; __THREW__ = 0;
 $66 = $65&1;
 L14: do {
  if ($66) {
   label = 25;
  } else {
   do {
    if ($64) {
     __THREW__ = 0;
     $67 = (invoke_ii(3265,2)|0);
     $68 = __THREW__; __THREW__ = 0;
     $69 = $68&1;
     if ($69) {
      label = 25;
      break L14;
     }
     if ($67) {
      __THREW__ = 0;
      $70 = (invoke_ii(3266,2)|0);
      $71 = __THREW__; __THREW__ = 0;
      $72 = $71&1;
      if ($72) {
       label = 25;
       break L14;
      }
      __THREW__ = 0;
      $73 = (invoke_iiii(3267,($70|0),(146488|0),9)|0);
      $74 = __THREW__; __THREW__ = 0;
      $75 = $74&1;
      if ($75) {
       label = 25;
       break L14;
      }
      $76 = ((($5)) + 11|0);
      $77 = HEAP8[$76>>0]|0;
      $78 = ($77<<24>>24)<(0);
      $79 = HEAP32[$5>>2]|0;
      $80 = $78 ? $79 : $5;
      $81 = ((($5)) + 4|0);
      $82 = HEAP32[$81>>2]|0;
      $83 = $77&255;
      $84 = $78 ? $82 : $83;
      __THREW__ = 0;
      $85 = (invoke_iiii(3267,($73|0),($80|0),($84|0))|0);
      $86 = __THREW__; __THREW__ = 0;
      $87 = $86&1;
      if ($87) {
       label = 25;
       break L14;
      }
      $88 = HEAP32[$85>>2]|0;
      $89 = ((($88)) + -12|0);
      $90 = HEAP32[$89>>2]|0;
      $91 = (($85) + ($90)|0);
      __THREW__ = 0;
      invoke_vii(3257,($1|0),($91|0));
      $92 = __THREW__; __THREW__ = 0;
      $93 = $92&1;
      if ($93) {
       label = 25;
       break L14;
      }
      __THREW__ = 0;
      $94 = (invoke_iii(3255,($1|0),(215188|0))|0);
      $95 = __THREW__; __THREW__ = 0;
      $96 = $95&1;
      if (!($96)) {
       $97 = HEAP32[$94>>2]|0;
       $98 = ((($97)) + 28|0);
       $99 = HEAP32[$98>>2]|0;
       __THREW__ = 0;
       $100 = (invoke_iii($99|0,($94|0),10)|0);
       $101 = __THREW__; __THREW__ = 0;
       $102 = $101&1;
       if (!($102)) {
        __THREW__ = 0;
        invoke_vi(3263,($1|0));
        $109 = __THREW__; __THREW__ = 0;
        $110 = $109&1;
        if ($110) {
         label = 25;
         break L14;
        }
        __THREW__ = 0;
        (invoke_iii(3268,($85|0),($100|0))|0);
        $111 = __THREW__; __THREW__ = 0;
        $112 = $111&1;
        if ($112) {
         label = 25;
         break L14;
        }
        __THREW__ = 0;
        (invoke_ii(3269,($85|0))|0);
        $113 = __THREW__; __THREW__ = 0;
        $114 = $113&1;
        if ($114) {
         label = 25;
         break L14;
        } else {
         break;
        }
       }
      }
      $103 = ___cxa_find_matching_catch_2()|0;
      $104 = tempRet0;
      __THREW__ = 0;
      invoke_vi(3263,($1|0));
      $105 = __THREW__; __THREW__ = 0;
      $106 = $105&1;
      if ($106) {
       $107 = ___cxa_find_matching_catch_3(0|0)|0;
       $108 = tempRet0;
       ___clang_call_terminate($107);
       // unreachable;
      } else {
       $eh$lpad$body$index3Z2D = $104;$eh$lpad$body$indexZ2D = $103;
       break L14;
      }
     }
    }
   } while(0);
   __THREW__ = 0;
   $121 = (invoke_ii(3265,2)|0);
   $122 = __THREW__; __THREW__ = 0;
   $123 = $122&1;
   if ($123) {
    label = 25;
   } else {
    do {
     if ($121) {
      __THREW__ = 0;
      $124 = (invoke_ii(3266,2)|0);
      $125 = __THREW__; __THREW__ = 0;
      $126 = $125&1;
      if ($126) {
       label = 25;
       break L14;
      }
      $127 = HEAP32[$124>>2]|0;
      $128 = ((($127)) + -12|0);
      $129 = HEAP32[$128>>2]|0;
      $130 = (($124) + ($129)|0);
      __THREW__ = 0;
      invoke_vii(3257,($3|0),($130|0));
      $131 = __THREW__; __THREW__ = 0;
      $132 = $131&1;
      if ($132) {
       label = 25;
       break L14;
      }
      __THREW__ = 0;
      $133 = (invoke_iii(3255,($3|0),(215188|0))|0);
      $134 = __THREW__; __THREW__ = 0;
      $135 = $134&1;
      if (!($135)) {
       $136 = HEAP32[$133>>2]|0;
       $137 = ((($136)) + 28|0);
       $138 = HEAP32[$137>>2]|0;
       __THREW__ = 0;
       $139 = (invoke_iii($138|0,($133|0),10)|0);
       $140 = __THREW__; __THREW__ = 0;
       $141 = $140&1;
       if (!($141)) {
        __THREW__ = 0;
        invoke_vi(3263,($3|0));
        $148 = __THREW__; __THREW__ = 0;
        $149 = $148&1;
        if ($149) {
         label = 25;
         break L14;
        }
        __THREW__ = 0;
        (invoke_iii(3268,($124|0),($139|0))|0);
        $150 = __THREW__; __THREW__ = 0;
        $151 = $150&1;
        if ($151) {
         label = 25;
         break L14;
        }
        __THREW__ = 0;
        (invoke_ii(3269,($124|0))|0);
        $152 = __THREW__; __THREW__ = 0;
        $153 = $152&1;
        if ($153) {
         label = 25;
         break L14;
        } else {
         break;
        }
       }
      }
      $142 = ___cxa_find_matching_catch_2()|0;
      $143 = tempRet0;
      __THREW__ = 0;
      invoke_vi(3263,($3|0));
      $144 = __THREW__; __THREW__ = 0;
      $145 = $144&1;
      if ($145) {
       $146 = ___cxa_find_matching_catch_3(0|0)|0;
       $147 = tempRet0;
       ___clang_call_terminate($146);
       // unreachable;
      } else {
       $eh$lpad$body$index3Z2D = $143;$eh$lpad$body$indexZ2D = $142;
       break L14;
      }
     }
    } while(0);
    $154 = ((($5)) + 11|0);
    $155 = HEAP8[$154>>0]|0;
    $156 = ($155<<24>>24)<(0);
    if ($156) {
     $157 = HEAP32[$5>>2]|0;
     __ZdlPv($157);
    }
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 if ((label|0) == 25) {
  $115 = ___cxa_find_matching_catch_2()|0;
  $116 = tempRet0;
  $eh$lpad$body$index3Z2D = $116;$eh$lpad$body$indexZ2D = $115;
 }
 $117 = ((($5)) + 11|0);
 $118 = HEAP8[$117>>0]|0;
 $119 = ($118<<24>>24)<(0);
 if (!($119)) {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 $120 = HEAP32[$5>>2]|0;
 __ZdlPv($120);
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
 return (0)|0;
}
function __ZNK3osg7Program17PerContextProgram10getInfoLogERNSt3__212basic_stringIcNS2_11char_traitsIcEENS2_9allocatorIcEEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (__ZNK3osg12GLExtensions17getProgramInfoLogEjRNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE($3,$5,$1)|0);
 return ($6|0);
}
function __ZN3osg7Program17PerContextProgram20compileProgramBinaryERNS_5StateE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$$i = 0, $$0 = 0, $$pre = 0, $$pre10 = 0, $$pre9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp + 4|0;
 $3 = sp;
 $4 = HEAP32[$0>>2]|0;
 $5 = ((($4)) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 FUNCTION_TABLE_vii[$6 & 8191]($0,$1);
 HEAP32[$2>>2] = 0;
 $7 = ((($0)) + 16|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($8)) + 104|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ((($0)) + 20|0);
 $12 = HEAP32[$11>>2]|0;
 FUNCTION_TABLE_viii[$10 & 8191]($12,34625,$2);
 $13 = HEAP32[$2>>2]|0;
 $14 = ($13|0)==(0);
 if ($14) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $15 = (__Znwj(48)|0);
 __THREW__ = 0;
 invoke_vi(3282,($15|0));
 $16 = __THREW__; __THREW__ = 0;
 $17 = $16&1;
 if ($17) {
  $35 = ___cxa_find_matching_catch_2()|0;
  $36 = tempRet0;
  __ZdlPv($15);
  ___resumeException($35|0);
  // unreachable;
 }
 $18 = ((($15)) + 12|0);
 ;HEAP32[$18>>2]=0|0;HEAP32[$18+4>>2]=0|0;HEAP32[$18+8>>2]=0|0;
 $19 = ((($15)) + 24|0);
 HEAP32[$19>>2] = 2;
 $20 = ((($15)) + 28|0);
 HEAP32[$20>>2] = 0;
 HEAP32[$15>>2] = (65316);
 $21 = ((($15)) + 32|0);
 ;HEAP32[$21>>2]=0|0;HEAP32[$21+4>>2]=0|0;HEAP32[$21+8>>2]=0|0;HEAP32[$21+12>>2]=0|0;
 $22 = HEAP32[$2>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  $29 = 0;$31 = 0;$32 = 0;
 } else {
  $24 = ((($15)) + 36|0);
  __ZNSt3__26vectorIhNS_9allocatorIhEEE8__appendEj($21,$22);
  $$pre = HEAP32[$2>>2]|0;
  $$pre9 = HEAP32[$21>>2]|0;
  $$pre10 = HEAP32[$24>>2]|0;
  $29 = $$pre9;$31 = $$pre10;$32 = $$pre;
 }
 HEAP32[$3>>2] = 0;
 $25 = HEAP32[$7>>2]|0;
 $26 = ((($25)) + 608|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = HEAP32[$11>>2]|0;
 $30 = ($29|0)==($31|0);
 $$$i = $30 ? 0 : $29;
 FUNCTION_TABLE_viiiii[$27 & 8191]($28,$32,0,$3,$$$i);
 $33 = HEAP32[$3>>2]|0;
 $34 = ((($15)) + 44|0);
 HEAP32[$34>>2] = $33;
 $$0 = $15;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK3osg7Program17PerContextProgram10useProgramEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 176|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 FUNCTION_TABLE_vi[$4 & 8191]($6);
 $7 = ((($0)) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($8)) + 132|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)>(0);
 if (!($11)) {
  return;
 }
 $12 = ((($8)) + 136|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)>(0);
 if (!($14)) {
  return;
 }
 $15 = ((($8)) + 140|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)>(0);
 if (!($17)) {
  return;
 }
 $18 = HEAP32[$1>>2]|0;
 $19 = ((($18)) + 688|0);
 $20 = HEAP32[$19>>2]|0;
 FUNCTION_TABLE_viii[$20 & 8191]($10,$13,$16);
 return;
}
function __ZNSt3__26vectorIhNS_9allocatorIhEEE8__appendEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i = 0, $$0$i14 = 0, $$sroa$15$0 = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) - ($5))|0;
 $7 = ($6>>>0)<($1>>>0);
 if (!($7)) {
  $8 = $5;
  $$0$i = $1;$9 = $8;
  while(1) {
   HEAP8[$9>>0] = 0;
   $10 = HEAP32[$4>>2]|0;
   $11 = ((($10)) + 1|0);
   HEAP32[$4>>2] = $11;
   $12 = (($$0$i) + -1)|0;
   $13 = ($12|0)==(0);
   if ($13) {
    break;
   } else {
    $$0$i = $12;$9 = $11;
   }
  }
  return;
 }
 $14 = HEAP32[$0>>2]|0;
 $15 = (($5) - ($14))|0;
 $16 = (($15) + ($1))|0;
 $17 = ($16|0)<(0);
 if ($17) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $18 = (($3) - ($14))|0;
 $19 = ($18>>>0)<(1073741823);
 $20 = $18 << 1;
 $21 = ($20>>>0)<($16>>>0);
 $$sroa$speculated$i = $21 ? $16 : $20;
 $$sroa$speculated$$i = $19 ? $$sroa$speculated$i : 2147483647;
 $22 = ($$sroa$speculated$$i|0)==(0);
 if ($22) {
  $25 = 0;
 } else {
  $23 = (__Znwj($$sroa$speculated$$i)|0);
  $25 = $23;
 }
 $24 = (($25) + ($15)|0);
 $26 = $24;
 $27 = (($25) + ($$sroa$speculated$$i)|0);
 $$0$i14 = $1;$$sroa$15$0 = $26;$28 = $24;
 while(1) {
  HEAP8[$28>>0] = 0;
  $29 = $$sroa$15$0;
  $30 = ((($29)) + 1|0);
  $31 = $30;
  $32 = (($$0$i14) + -1)|0;
  $33 = ($32|0)==(0);
  if ($33) {
   break;
  } else {
   $$0$i14 = $32;$$sroa$15$0 = $31;$28 = $30;
  }
 }
 $34 = $27;
 $35 = HEAP32[$0>>2]|0;
 $36 = HEAP32[$4>>2]|0;
 $37 = $35;
 $38 = (($36) - ($37))|0;
 $39 = (0 - ($38))|0;
 $40 = (($24) + ($39)|0);
 $41 = $40;
 $42 = ($38|0)>(0);
 if ($42) {
  _memcpy(($40|0),($35|0),($38|0))|0;
 }
 HEAP32[$0>>2] = $41;
 HEAP32[$4>>2] = $31;
 HEAP32[$2>>2] = $34;
 $43 = ($35|0)==(0|0);
 if ($43) {
  return;
 }
 __ZdlPv($35);
 return;
}
function __ZN3osg7Program13ProgramBinaryD2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (65316);
 $1 = ((($0)) + 32|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  __ZN3osg6ObjectD2Ev($0);
  return;
 }
 $4 = ((($0)) + 36|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==($2|0);
 if (!($6)) {
  HEAP32[$4>>2] = $2;
 }
 __ZdlPv($2);
 __ZN3osg6ObjectD2Ev($0);
 return;
}
function __ZN3osg7Program13ProgramBinaryD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (65316);
 $1 = ((($0)) + 32|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = ((($0)) + 36|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==($2|0);
  if (!($6)) {
   HEAP32[$4>>2] = $2;
  }
  __ZdlPv($2);
 }
 __THREW__ = 0;
 invoke_vi(388,($0|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch_2()|0;
  $10 = tempRet0;
  __ZdlPv($0);
  ___resumeException($9|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK3osg7Program13ProgramBinary9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(48)|0);
 __THREW__ = 0;
 invoke_vi(3282,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $8 = ___cxa_find_matching_catch_2()|0;
  $9 = tempRet0;
  __ZdlPv($1);
  ___resumeException($8|0);
  // unreachable;
 } else {
  $4 = ((($1)) + 12|0);
  ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;
  $5 = ((($1)) + 24|0);
  HEAP32[$5>>2] = 2;
  $6 = ((($1)) + 28|0);
  HEAP32[$6>>2] = 0;
  HEAP32[$1>>2] = (65316);
  $7 = ((($1)) + 32|0);
  ;HEAP32[$7>>2]=0|0;HEAP32[$7+4>>2]=0|0;HEAP32[$7+8>>2]=0|0;HEAP32[$7+12>>2]=0|0;
  return ($1|0);
 }
 return (0)|0;
}
function __ZNK3osg7Program13ProgramBinary5cloneERKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(48)|0);
 __THREW__ = 0;
 invoke_viii(3867,($2|0),($0|0),($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch_2()|0;
  $6 = tempRet0;
  __ZdlPv($2);
  ___resumeException($5|0);
  // unreachable;
 } else {
  return ($2|0);
 }
 return (0)|0;
}
function __ZNK3osg7Program13ProgramBinary12isSameKindAsEPKNS_6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,26424,0)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK3osg7Program13ProgramBinary11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175113|0);
}
function __ZNK3osg7Program13ProgramBinary9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (146400|0);
}
function __ZN3osg7Program13ProgramBinaryC2ERKS1_RKNS_6CopyOpE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg6ObjectC2ERKS0_RKNS_6CopyOpE($0,$1,$2);
 HEAP32[$0>>2] = (65316);
 $3 = ((($0)) + 32|0);
 $4 = ((($1)) + 32|0);
 HEAP32[$3>>2] = 0;
 $5 = ((($0)) + 36|0);
 HEAP32[$5>>2] = 0;
 $6 = ((($0)) + 40|0);
 HEAP32[$6>>2] = 0;
 $7 = ((($1)) + 36|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$4>>2]|0;
 $10 = (($8) - ($9))|0;
 $11 = ($10|0)==(0);
 if ($11) {
  $31 = ((($0)) + 44|0);
  $32 = ((($1)) + 44|0);
  $33 = HEAP32[$32>>2]|0;
  HEAP32[$31>>2] = $33;
  return;
 }
 $12 = ($10|0)<(0);
 if ($12) {
  __THREW__ = 0;
  invoke_vi(3307,($3|0));
  $13 = __THREW__; __THREW__ = 0;
 } else {
  __THREW__ = 0;
  $14 = (invoke_ii(3276,($10|0))|0);
  $15 = __THREW__; __THREW__ = 0;
  $16 = $15&1;
  if (!($16)) {
   HEAP32[$5>>2] = $14;
   HEAP32[$3>>2] = $14;
   $17 = (($14) + ($10)|0);
   $18 = ((($0)) + 40|0);
   HEAP32[$18>>2] = $17;
   $19 = HEAP32[$4>>2]|0;
   $20 = HEAP32[$7>>2]|0;
   $21 = $19;
   $22 = (($20) - ($21))|0;
   $23 = ($22|0)>(0);
   if (!($23)) {
    $31 = ((($0)) + 44|0);
    $32 = ((($1)) + 44|0);
    $33 = HEAP32[$32>>2]|0;
    HEAP32[$31>>2] = $33;
    return;
   }
   _memcpy(($14|0),($19|0),($22|0))|0;
   $24 = (($14) + ($22)|0);
   HEAP32[$5>>2] = $24;
   $31 = ((($0)) + 44|0);
   $32 = ((($1)) + 44|0);
   $33 = HEAP32[$32>>2]|0;
   HEAP32[$31>>2] = $33;
   return;
  }
 }
 $25 = ___cxa_find_matching_catch_2()|0;
 $26 = tempRet0;
 $27 = HEAP32[$3>>2]|0;
 $28 = ($27|0)==(0|0);
 if (!($28)) {
  $29 = HEAP32[$5>>2]|0;
  $30 = ($29|0)==($27|0);
  if (!($30)) {
   HEAP32[$5>>2] = $27;
  }
  __ZdlPv($27);
 }
 __THREW__ = 0;
 invoke_vi(388,($0|0));
 $34 = __THREW__; __THREW__ = 0;
 $35 = $34&1;
 if ($35) {
  $36 = ___cxa_find_matching_catch_3(0|0)|0;
  $37 = tempRet0;
  ___clang_call_terminate($36);
  // unreachable;
 } else {
  ___resumeException($25|0);
  // unreachable;
 }
}
function __ZNSt3__26__treeINS_12__value_typeIjiEENS_19__map_value_compareIjS2_NS_4lessIjEELb1EEENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 } else {
  $3 = HEAP32[$1>>2]|0;
  __ZNSt3__26__treeINS_12__value_typeIjiEENS_19__map_value_compareIjS2_NS_4lessIjEELb1EEENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($0,$3);
  $4 = ((($1)) + 4|0);
  $5 = HEAP32[$4>>2]|0;
  __ZNSt3__26__treeINS_12__value_typeIjiEENS_19__map_value_compareIjS2_NS_4lessIjEELb1EEENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($0,$5);
  __ZdlPv($1);
  return;
 }
}
function __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7Program16UniformBlockInfoEEENS_19__map_value_compareIS7_SB_NS_4lessIS7_EELb1EEENS5_ISB_EEE12__find_equalIS7_EERPNS_16__tree_node_baseIPvEERPNS_15__tree_end_nodeISM_EERKT_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$0$ph = 0, $$024 = 0, $$025 = 0, $$in = 0, $$sroa$speculated$i$i$i$i$i = 0, $$sroa$speculated$i$i$i$i$i26 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  HEAP32[$1>>2] = $3;
  $$025 = $3;
  return ($$025|0);
 }
 $6 = ((($0)) + 4|0);
 $7 = ((($2)) + 11|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = ($8<<24>>24)<(0);
 $10 = ((($2)) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $8&255;
 $13 = $9 ? $11 : $12;
 $14 = HEAP32[$2>>2]|0;
 $15 = $9 ? $14 : $2;
 $$0 = $6;$$024 = $4;
 while(1) {
  $16 = ((($$024)) + 16|0);
  $17 = ((($16)) + 11|0);
  $18 = HEAP8[$17>>0]|0;
  $19 = ($18<<24>>24)<(0);
  $20 = ((($$024)) + 20|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = $18&255;
  $23 = $19 ? $21 : $22;
  $24 = ($23>>>0)<($13>>>0);
  $$sroa$speculated$i$i$i$i$i26 = $24 ? $23 : $13;
  $25 = ($$sroa$speculated$i$i$i$i$i26|0)==(0);
  if ($25) {
   label = 6;
  } else {
   $26 = HEAP32[$16>>2]|0;
   $27 = $19 ? $26 : $16;
   $28 = (_memcmp($15,$27,$$sroa$speculated$i$i$i$i$i26)|0);
   $29 = ($28|0)==(0);
   if ($29) {
    label = 6;
   } else {
    $31 = ($28|0)<(0);
    if ($31) {
     label = 8;
    } else {
     label = 10;
    }
   }
  }
  if ((label|0) == 6) {
   label = 0;
   $30 = ($13>>>0)<($23>>>0);
   if ($30) {
    label = 8;
   } else {
    label = 10;
   }
  }
  if ((label|0) == 8) {
   label = 0;
   $32 = HEAP32[$$024>>2]|0;
   $33 = ($32|0)==(0|0);
   if ($33) {
    label = 9;
    break;
   } else {
    $$0$ph = $$024;$$in = $32;
   }
  }
  else if ((label|0) == 10) {
   label = 0;
   $34 = ($13>>>0)<($23>>>0);
   $$sroa$speculated$i$i$i$i$i = $34 ? $13 : $23;
   $35 = ($$sroa$speculated$i$i$i$i$i|0)==(0);
   if ($35) {
    label = 12;
   } else {
    $36 = HEAP32[$16>>2]|0;
    $37 = $19 ? $36 : $16;
    $38 = (_memcmp($37,$15,$$sroa$speculated$i$i$i$i$i)|0);
    $39 = ($38|0)==(0);
    if ($39) {
     label = 12;
    } else {
     $40 = ($38|0)<(0);
     if (!($40)) {
      label = 16;
      break;
     }
    }
   }
   if ((label|0) == 12) {
    label = 0;
    if (!($24)) {
     label = 16;
     break;
    }
   }
   $41 = ((($$024)) + 4|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = ($42|0)==(0|0);
   if ($43) {
    label = 15;
    break;
   } else {
    $$0$ph = $41;$$in = $42;
   }
  }
  $$0 = $$0$ph;$$024 = $$in;
 }
 if ((label|0) == 9) {
  HEAP32[$1>>2] = $$024;
  $$025 = $$024;
  return ($$025|0);
 }
 else if ((label|0) == 15) {
  HEAP32[$1>>2] = $$024;
  $$025 = $41;
  return ($$025|0);
 }
 else if ((label|0) == 16) {
  HEAP32[$1>>2] = $$024;
  $$025 = $$0;
  return ($$025|0);
 }
 return (0)|0;
}
function __ZNKSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEjEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE4findIS7_EENS_21__tree_const_iteratorIS8_PNS_11__tree_nodeIS8_PvEEiEERKT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$ph$lcssa$i = 0, $$0$ph15$i = 0, $$07$ph14$i = 0, $$0711$i = 0, $$sroa$0$0 = 0, $$sroa$speculated$i$i$i$i$i = 0, $$sroa$speculated$i$i$i$i$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 do {
  if (!($4)) {
   $5 = ((($1)) + 11|0);
   $6 = HEAP8[$5>>0]|0;
   $7 = ($6<<24>>24)<(0);
   $8 = ((($1)) + 4|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = $6&255;
   $11 = $7 ? $9 : $10;
   $12 = HEAP32[$1>>2]|0;
   $13 = $7 ? $12 : $1;
   $$0$ph15$i = $2;$$07$ph14$i = $3;
   L3: while(1) {
    $$0711$i = $$07$ph14$i;
    while(1) {
     $14 = ((($$0711$i)) + 16|0);
     $15 = ((($14)) + 11|0);
     $16 = HEAP8[$15>>0]|0;
     $17 = ($16<<24>>24)<(0);
     $18 = ((($$0711$i)) + 20|0);
     $19 = HEAP32[$18>>2]|0;
     $20 = $16&255;
     $21 = $17 ? $19 : $20;
     $22 = ($11>>>0)<($21>>>0);
     $$sroa$speculated$i$i$i$i$i$i = $22 ? $11 : $21;
     $23 = ($$sroa$speculated$i$i$i$i$i$i|0)==(0);
     if ($23) {
      label = 6;
     } else {
      $24 = HEAP32[$14>>2]|0;
      $25 = $17 ? $24 : $14;
      $26 = (_memcmp($25,$13,$$sroa$speculated$i$i$i$i$i$i)|0);
      $27 = ($26|0)==(0);
      if ($27) {
       label = 6;
      } else {
       $29 = ($26|0)<(0);
       if (!($29)) {
        break;
       }
      }
     }
     if ((label|0) == 6) {
      label = 0;
      $28 = ($21>>>0)<($11>>>0);
      if (!($28)) {
       break;
      }
     }
     $32 = ((($$0711$i)) + 4|0);
     $33 = HEAP32[$32>>2]|0;
     $34 = ($33|0)==(0|0);
     if ($34) {
      $$0$ph$lcssa$i = $$0$ph15$i;
      break L3;
     } else {
      $$0711$i = $33;
     }
    }
    $30 = HEAP32[$$0711$i>>2]|0;
    $31 = ($30|0)==(0|0);
    if ($31) {
     $$0$ph$lcssa$i = $$0711$i;
     break;
    } else {
     $$0$ph15$i = $$0711$i;$$07$ph14$i = $30;
    }
   }
   $35 = ($$0$ph$lcssa$i|0)==($2|0);
   if (!($35)) {
    $36 = ((($$0$ph$lcssa$i)) + 16|0);
    $37 = ((($36)) + 11|0);
    $38 = HEAP8[$37>>0]|0;
    $39 = ($38<<24>>24)<(0);
    $40 = ((($$0$ph$lcssa$i)) + 20|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = $38&255;
    $43 = $39 ? $41 : $42;
    $44 = ($43>>>0)<($11>>>0);
    $$sroa$speculated$i$i$i$i$i = $44 ? $43 : $11;
    $45 = ($$sroa$speculated$i$i$i$i$i|0)==(0);
    if (!($45)) {
     $46 = HEAP32[$36>>2]|0;
     $47 = $39 ? $46 : $36;
     $48 = (_memcmp($13,$47,$$sroa$speculated$i$i$i$i$i)|0);
     $49 = ($48|0)==(0);
     if (!($49)) {
      $51 = ($48|0)<(0);
      if ($51) {
       break;
      } else {
       $$sroa$0$0 = $$0$ph$lcssa$i;
      }
      return ($$sroa$0$0|0);
     }
    }
    $50 = ($11>>>0)<($43>>>0);
    if (!($50)) {
     $$sroa$0$0 = $$0$ph$lcssa$i;
     return ($$sroa$0$0|0);
    }
   }
  }
 } while(0);
 $$sroa$0$0 = $2;
 return ($$sroa$0$0|0);
}
function __ZNSt3__26__treeINS_12__value_typeIiNS_6vectorIiNS_9allocatorIiEEEEEENS_19__map_value_compareIiS6_NS_4lessIiEELb1EEENS3_IS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 }
 $3 = HEAP32[$1>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIiNS_6vectorIiNS_9allocatorIiEEEEEENS_19__map_value_compareIiS6_NS_4lessIiEELb1EEENS3_IS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($0,$3);
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIiNS_6vectorIiNS_9allocatorIiEEEEEENS_19__map_value_compareIiS6_NS_4lessIiEELb1EEENS3_IS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($0,$5);
 $6 = ((($1)) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = ((($1)) + 24|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10|0)==($7|0);
  if (!($11)) {
   $scevgep$i$i$i$i$i$i = ((($10)) + -4|0);
   $12 = $scevgep$i$i$i$i$i$i;
   $13 = $7;
   $14 = (($12) - ($13))|0;
   $15 = $14 >>> 2;
   $16 = $15 ^ -1;
   $scevgep5$i$i$i$i$i$i = (($10) + ($16<<2)|0);
   HEAP32[$9>>2] = $scevgep5$i$i$i$i$i$i;
  }
  __ZdlPv($7);
 }
 __ZdlPv($1);
 return;
}
function __ZNSt3__23mapINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7Program13ActiveVarInfoENS_4lessIS6_EENS4_INS_4pairIKS6_S9_EEEEEixERSD_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$014 = 0, $$pre$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = (__ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7Program13ActiveVarInfoEEENS_19__map_value_compareIS7_SB_NS_4lessIS7_EELb1EEENS5_ISB_EEE12__find_equalIS7_EERPNS_16__tree_node_baseIPvEERPNS_15__tree_end_nodeISM_EERKT_($0,$2,$1)|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if (!($5)) {
  $$014 = $4;
  $28 = ((($$014)) + 28|0);
  STACKTOP = sp;return ($28|0);
 }
 $6 = (__Znwj(40)|0);
 $7 = ((($6)) + 16|0);
 __THREW__ = 0;
 invoke_vii(3457,($7|0),($1|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $10 = ___cxa_find_matching_catch_2()|0;
  $11 = tempRet0;
  __ZdlPv($6);
  ___resumeException($10|0);
  // unreachable;
 }
 $12 = ((($6)) + 28|0);
 HEAP32[$12>>2] = -1;
 $13 = ((($6)) + 32|0);
 HEAP32[$13>>2] = 0;
 $14 = ((($6)) + 36|0);
 HEAP32[$14>>2] = -1;
 $15 = HEAP32[$2>>2]|0;
 HEAP32[$6>>2] = 0;
 $16 = ((($6)) + 4|0);
 HEAP32[$16>>2] = 0;
 $17 = ((($6)) + 8|0);
 HEAP32[$17>>2] = $15;
 HEAP32[$3>>2] = $6;
 $18 = HEAP32[$0>>2]|0;
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)==(0|0);
 if ($20) {
  $24 = $6;
 } else {
  $21 = $19;
  HEAP32[$0>>2] = $21;
  $$pre$i = HEAP32[$3>>2]|0;
  $24 = $$pre$i;
 }
 $22 = ((($0)) + 4|0);
 $23 = HEAP32[$22>>2]|0;
 __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($23,$24);
 $25 = ((($0)) + 8|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (($26) + 1)|0;
 HEAP32[$25>>2] = $27;
 $$014 = $6;
 $28 = ((($$014)) + 28|0);
 STACKTOP = sp;return ($28|0);
}
function __ZNSt3__26__treeINS_12__value_typeIjNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEEENS_19__map_value_compareIjS8_NS_4lessIjEELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 }
 $3 = HEAP32[$1>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIjNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEEENS_19__map_value_compareIjS8_NS_4lessIjEELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($0,$3);
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIjNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEEENS_19__map_value_compareIjS8_NS_4lessIjEELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($0,$5);
 $6 = ((($1)) + 20|0);
 $7 = ((($6)) + 11|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = ($8<<24>>24)<(0);
 if ($9) {
  $10 = HEAP32[$6>>2]|0;
  __ZdlPv($10);
 }
 __ZdlPv($1);
 return;
}
function __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7Program13ActiveVarInfoEEENS_19__map_value_compareIS7_SB_NS_4lessIS7_EELb1EEENS5_ISB_EEE12__find_equalIS7_EERPNS_16__tree_node_baseIPvEERPNS_15__tree_end_nodeISM_EERKT_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$0$ph = 0, $$024 = 0, $$025 = 0, $$in = 0, $$sroa$speculated$i$i$i$i$i = 0, $$sroa$speculated$i$i$i$i$i26 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  HEAP32[$1>>2] = $3;
  $$025 = $3;
  return ($$025|0);
 }
 $6 = ((($0)) + 4|0);
 $7 = ((($2)) + 11|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = ($8<<24>>24)<(0);
 $10 = ((($2)) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $8&255;
 $13 = $9 ? $11 : $12;
 $14 = HEAP32[$2>>2]|0;
 $15 = $9 ? $14 : $2;
 $$0 = $6;$$024 = $4;
 while(1) {
  $16 = ((($$024)) + 16|0);
  $17 = ((($16)) + 11|0);
  $18 = HEAP8[$17>>0]|0;
  $19 = ($18<<24>>24)<(0);
  $20 = ((($$024)) + 20|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = $18&255;
  $23 = $19 ? $21 : $22;
  $24 = ($23>>>0)<($13>>>0);
  $$sroa$speculated$i$i$i$i$i26 = $24 ? $23 : $13;
  $25 = ($$sroa$speculated$i$i$i$i$i26|0)==(0);
  if ($25) {
   label = 6;
  } else {
   $26 = HEAP32[$16>>2]|0;
   $27 = $19 ? $26 : $16;
   $28 = (_memcmp($15,$27,$$sroa$speculated$i$i$i$i$i26)|0);
   $29 = ($28|0)==(0);
   if ($29) {
    label = 6;
   } else {
    $31 = ($28|0)<(0);
    if ($31) {
     label = 8;
    } else {
     label = 10;
    }
   }
  }
  if ((label|0) == 6) {
   label = 0;
   $30 = ($13>>>0)<($23>>>0);
   if ($30) {
    label = 8;
   } else {
    label = 10;
   }
  }
  if ((label|0) == 8) {
   label = 0;
   $32 = HEAP32[$$024>>2]|0;
   $33 = ($32|0)==(0|0);
   if ($33) {
    label = 9;
    break;
   } else {
    $$0$ph = $$024;$$in = $32;
   }
  }
  else if ((label|0) == 10) {
   label = 0;
   $34 = ($13>>>0)<($23>>>0);
   $$sroa$speculated$i$i$i$i$i = $34 ? $13 : $23;
   $35 = ($$sroa$speculated$i$i$i$i$i|0)==(0);
   if ($35) {
    label = 12;
   } else {
    $36 = HEAP32[$16>>2]|0;
    $37 = $19 ? $36 : $16;
    $38 = (_memcmp($37,$15,$$sroa$speculated$i$i$i$i$i)|0);
    $39 = ($38|0)==(0);
    if ($39) {
     label = 12;
    } else {
     $40 = ($38|0)<(0);
     if (!($40)) {
      label = 16;
      break;
     }
    }
   }
   if ((label|0) == 12) {
    label = 0;
    if (!($24)) {
     label = 16;
     break;
    }
   }
   $41 = ((($$024)) + 4|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = ($42|0)==(0|0);
   if ($43) {
    label = 15;
    break;
   } else {
    $$0$ph = $41;$$in = $42;
   }
  }
  $$0 = $$0$ph;$$024 = $$in;
 }
 if ((label|0) == 9) {
  HEAP32[$1>>2] = $$024;
  $$025 = $$024;
  return ($$025|0);
 }
 else if ((label|0) == 15) {
  HEAP32[$1>>2] = $$024;
  $$025 = $41;
  return ($$025|0);
 }
 else if ((label|0) == 16) {
  HEAP32[$1>>2] = $$024;
  $$025 = $$0;
  return ($$025|0);
 }
 return (0)|0;
}
function __ZN3osg11ContextData3getI16GLProgramManagerEEPT_v($0) {
 $0 = $0|0;
 var $$0$i$i = 0, $$0$ph$i$i = 0, $$014$i = 0, $$024$i$i = 0, $$025$i$i = 0, $$025$i53$i = 0, $$037$i = 0, $$03752$i = 0, $$in$i$i = 0, $$pre$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0;
 var dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $2 = ((($0)) + 36|0);
 $3 = ((($0)) + 40|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 do {
  if ($5) {
   $$025$i$i = $3;$$037$i = $3;$16 = $4;
   label = 12;
  } else {
   $6 = ((($0)) + 40|0);
   $$0$i$i = $6;$$024$i$i = $4;$68 = $4;
   while(1) {
    $7 = ((($$024$i$i)) + 16|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = ($8>>>0)>(26440>>>0);
    if ($9) {
     $10 = HEAP32[$$024$i$i>>2]|0;
     $11 = ($10|0)==(0|0);
     if ($11) {
      label = 6;
      break;
     } else {
      $$0$ph$i$i = $$024$i$i;$$in$i$i = $10;
     }
    } else {
     $12 = ($8>>>0)<(26440>>>0);
     if (!($12)) {
      label = 10;
      break;
     }
     $13 = ((($$024$i$i)) + 4|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = ($14|0)==(0|0);
     if ($15) {
      label = 9;
      break;
     } else {
      $$0$ph$i$i = $13;$$in$i$i = $14;
     }
    }
    $$0$i$i = $$0$ph$i$i;$$024$i$i = $$in$i$i;$68 = $$in$i$i;
   }
   if ((label|0) == 6) {
    $$025$i53$i = $$024$i$i;$$03752$i = $$024$i$i;
    label = 13;
    break;
   }
   else if ((label|0) == 9) {
    $$025$i53$i = $13;$$03752$i = $$024$i$i;
    label = 13;
    break;
   }
   else if ((label|0) == 10) {
    $$025$i$i = $$0$i$i;$$037$i = $$024$i$i;$16 = $68;
    label = 12;
    break;
   }
  }
 } while(0);
 if ((label|0) == 12) {
  $17 = ($16|0)==(0|0);
  if ($17) {
   $$025$i53$i = $$025$i$i;$$03752$i = $$037$i;
   label = 13;
  } else {
   $$014$i = $16;
  }
 }
 if ((label|0) == 13) {
  $18 = (__Znwj(24)|0);
  $19 = ((($18)) + 16|0);
  HEAP32[$19>>2] = (26440);
  $20 = ((($18)) + 20|0);
  HEAP32[$20>>2] = 0;
  HEAP32[$18>>2] = 0;
  $21 = ((($18)) + 4|0);
  HEAP32[$21>>2] = 0;
  $22 = ((($18)) + 8|0);
  HEAP32[$22>>2] = $$03752$i;
  HEAP32[$$025$i53$i>>2] = $18;
  $23 = HEAP32[$2>>2]|0;
  $24 = HEAP32[$23>>2]|0;
  $25 = ($24|0)==(0|0);
  if ($25) {
   $29 = $18;
  } else {
   $26 = $24;
   HEAP32[$2>>2] = $26;
   $$pre$i$i = HEAP32[$$025$i53$i>>2]|0;
   $29 = $$pre$i$i;
  }
  $27 = ((($0)) + 40|0);
  $28 = HEAP32[$27>>2]|0;
  __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($28,$29);
  $30 = ((($0)) + 44|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = (($31) + 1)|0;
  HEAP32[$30>>2] = $32;
  $$014$i = $18;
 }
 $33 = ((($$014$i)) + 20|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)==(0|0);
 if (!($35)) {
  $67 = HEAP32[$33>>2]|0;
  STACKTOP = sp;return ($67|0);
 }
 $36 = (__Znwj(52)|0);
 $37 = ((($0)) + 24|0);
 $38 = HEAP32[$37>>2]|0;
 __THREW__ = 0;
 $39 = (invoke_ii(3276,32)|0);
 $40 = __THREW__; __THREW__ = 0;
 $41 = $40&1;
 if ($41) {
  $65 = ___cxa_find_matching_catch_2()|0;
  $66 = tempRet0;
  $eh$lpad$body$index2Z2D = $66;$eh$lpad$body$indexZ2D = $65;
  __ZdlPv($36);
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 HEAP32[$1>>2] = $39;
 $42 = ((($1)) + 8|0);
 HEAP32[$42>>2] = -2147483616;
 $43 = ((($1)) + 4|0);
 HEAP32[$43>>2] = 16;
 dest=$39; src=146867; stop=dest+16|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $44 = ((($39)) + 16|0);
 HEAP8[$44>>0] = 0;
 __THREW__ = 0;
 invoke_viii(3762,($36|0),($1|0),($38|0));
 $45 = __THREW__; __THREW__ = 0;
 $46 = $45&1;
 if ($46) {
  $51 = ___cxa_find_matching_catch_2()|0;
  $52 = tempRet0;
  $53 = ((($1)) + 11|0);
  $54 = HEAP8[$53>>0]|0;
  $55 = ($54<<24>>24)<(0);
  if ($55) {
   $56 = HEAP32[$1>>2]|0;
   __ZdlPv($56);
  }
  $eh$lpad$body$index2Z2D = $52;$eh$lpad$body$indexZ2D = $51;
  __ZdlPv($36);
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 $47 = ((($1)) + 11|0);
 $48 = HEAP8[$47>>0]|0;
 $49 = ($48<<24>>24)<(0);
 if ($49) {
  $50 = HEAP32[$1>>2]|0;
  __ZdlPv($50);
 }
 HEAP32[$36>>2] = (65464);
 $57 = HEAP32[$33>>2]|0;
 $58 = ($57|0)==($36|0);
 if ($58) {
  $67 = HEAP32[$33>>2]|0;
  STACKTOP = sp;return ($67|0);
 }
 HEAP32[$33>>2] = $36;
 $59 = ((($36)) + 8|0);
 $60 = HEAP32[$59>>2]|0;HEAP32[$59>>2] = (($60+1)|0);
 $61 = ($57|0)==(0|0);
 if ($61) {
  $67 = HEAP32[$33>>2]|0;
  STACKTOP = sp;return ($67|0);
 }
 $62 = ((($57)) + 8|0);
 $63 = HEAP32[$62>>2]|0;HEAP32[$62>>2] = (($63-1)|0);
 $64 = ($63|0)==(1);
 if (!($64)) {
  $67 = HEAP32[$33>>2]|0;
  STACKTOP = sp;return ($67|0);
 }
 __ZNK3osg10Referenced24signalObserversAndDeleteEbb($57,1,1);
 $67 = HEAP32[$33>>2]|0;
 STACKTOP = sp;return ($67|0);
}
function __ZN16GLProgramManagerD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1702,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZN16GLProgramManager14deleteGLObjectEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (__ZN3osg12GLExtensions3GetEjb($3,1)|0);
 $5 = ((($4)) + 24|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = ($6<<24>>24)==(0);
 if ($7) {
  return;
 }
 $8 = ((($4)) + 64|0);
 $9 = HEAP32[$8>>2]|0;
 FUNCTION_TABLE_vi[$9 & 8191]($1);
 return;
}
function __ZN3osg7Program14ProgramObjectsD2Ev($0) {
 $0 = $0|0;
 var $$pre$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (65256);
 $1 = ((($0)) + 20|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  __ZN3osg14GraphicsObjectD2Ev($0);
  return;
 }
 $4 = ((($0)) + 24|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==($2|0);
 do {
  if ($6) {
   $20 = $2;
  } else {
   $8 = $5;
   while(1) {
    $7 = ((($8)) + -4|0);
    HEAP32[$4>>2] = $7;
    $9 = HEAP32[$7>>2]|0;
    $10 = ($9|0)==(0|0);
    if (!($10)) {
     $11 = ((($9)) + 8|0);
     $12 = HEAP32[$11>>2]|0;HEAP32[$11>>2] = (($12-1)|0);
     $13 = ($12|0)==(1);
     if ($13) {
      __THREW__ = 0;
      invoke_viii(3262,($9|0),1,1);
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if ($15) {
       label = 7;
       break;
      }
     }
    }
    HEAP32[$7>>2] = 0;
    $16 = HEAP32[$4>>2]|0;
    $17 = ($16|0)==($2|0);
    if ($17) {
     label = 8;
     break;
    } else {
     $8 = $16;
    }
   }
   if ((label|0) == 7) {
    $18 = ___cxa_find_matching_catch_2()|0;
    $19 = tempRet0;
    ___cxa_call_unexpected(($18|0));
    // unreachable;
   }
   else if ((label|0) == 8) {
    $$pre$i = HEAP32[$1>>2]|0;
    $20 = $$pre$i;
    break;
   }
  }
 } while(0);
 __ZdlPv($20);
 __ZN3osg14GraphicsObjectD2Ev($0);
 return;
}
function __ZN3osg7Program14ProgramObjectsD0Ev($0) {
 $0 = $0|0;
 var $$pre$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (65256);
 $1 = ((($0)) + 20|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = ((($0)) + 24|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==($2|0);
  do {
   if ($6) {
    $20 = $2;
   } else {
    $8 = $5;
    while(1) {
     $7 = ((($8)) + -4|0);
     HEAP32[$4>>2] = $7;
     $9 = HEAP32[$7>>2]|0;
     $10 = ($9|0)==(0|0);
     if (!($10)) {
      $11 = ((($9)) + 8|0);
      $12 = HEAP32[$11>>2]|0;HEAP32[$11>>2] = (($12-1)|0);
      $13 = ($12|0)==(1);
      if ($13) {
       __THREW__ = 0;
       invoke_viii(3262,($9|0),1,1);
       $14 = __THREW__; __THREW__ = 0;
       $15 = $14&1;
       if ($15) {
        label = 7;
        break;
       }
      }
     }
     HEAP32[$7>>2] = 0;
     $16 = HEAP32[$4>>2]|0;
     $17 = ($16|0)==($2|0);
     if ($17) {
      label = 8;
      break;
     } else {
      $8 = $16;
     }
    }
    if ((label|0) == 7) {
     $18 = ___cxa_find_matching_catch_2()|0;
     $19 = tempRet0;
     ___cxa_call_unexpected(($18|0));
     // unreachable;
    }
    else if ((label|0) == 8) {
     $$pre$i$i = HEAP32[$1>>2]|0;
     $20 = $$pre$i$i;
     break;
    }
   }
  } while(0);
  __ZdlPv($20);
 }
 __THREW__ = 0;
 invoke_vi(1859,($0|0));
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if ($22) {
  $23 = ___cxa_find_matching_catch_2()|0;
  $24 = tempRet0;
  __ZdlPv($0);
  ___resumeException($23|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNSt3__26vectorIN3osg7ref_ptrINS1_7Program14ProgramObjectsEEENS_9allocatorIS5_EEE8__appendEjRKS5_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$i = 0, $$0$i16 = 0, $$06$i$i = 0, $$pre = 0, $$pre$i19 = 0, $$pre5$i = 0, $$sroa$16$0 = 0, $$sroa$7$0 = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) - ($6))|0;
 $8 = $7 >> 2;
 $9 = ($8>>>0)<($1>>>0);
 if (!($9)) {
  $10 = $6;
  $$0$i = $1;$12 = $10;
  while(1) {
   $11 = HEAP32[$2>>2]|0;
   HEAP32[$12>>2] = $11;
   $13 = ($11|0)==(0|0);
   if ($13) {
    $17 = $12;
   } else {
    $14 = ((($11)) + 8|0);
    $15 = HEAP32[$14>>2]|0;HEAP32[$14>>2] = (($15+1)|0);
    $$pre5$i = HEAP32[$5>>2]|0;
    $17 = $$pre5$i;
   }
   $16 = ((($17)) + 4|0);
   HEAP32[$5>>2] = $16;
   $18 = (($$0$i) + -1)|0;
   $19 = ($18|0)==(0);
   if ($19) {
    break;
   } else {
    $$0$i = $18;$12 = $16;
   }
  }
  return;
 }
 $20 = HEAP32[$0>>2]|0;
 $21 = (($6) - ($20))|0;
 $22 = $21 >> 2;
 $23 = (($22) + ($1))|0;
 $24 = ($23>>>0)>(1073741823);
 if ($24) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $25 = (($4) - ($20))|0;
 $26 = $25 >> 2;
 $27 = ($26>>>0)<(536870911);
 $28 = $25 >> 1;
 $29 = ($28>>>0)<($23>>>0);
 $$sroa$speculated$i = $29 ? $23 : $28;
 $$sroa$speculated$$i = $27 ? $$sroa$speculated$i : 1073741823;
 $30 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($30) {
   $40 = 0;
  } else {
   $31 = ($$sroa$speculated$$i>>>0)>(1073741823);
   if (!($31)) {
    $37 = $$sroa$speculated$$i << 2;
    $38 = (__Znwj($37)|0);
    $40 = $38;
    break;
   }
   $32 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($32|0),(204840|0));
   $33 = __THREW__; __THREW__ = 0;
   $34 = $33&1;
   if ($34) {
    $35 = ___cxa_find_matching_catch_2()|0;
    $36 = tempRet0;
    ___cxa_free_exception(($32|0));
    ___resumeException($35|0);
    // unreachable;
   } else {
    HEAP32[$32>>2] = (99824);
    ___cxa_throw(($32|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $39 = (($40) + ($22<<2)|0);
 $41 = $39;
 $42 = (($40) + ($$sroa$speculated$$i<<2)|0);
 $$0$i16 = $1;$$sroa$16$0 = $41;$44 = $39;
 while(1) {
  $43 = HEAP32[$2>>2]|0;
  HEAP32[$44>>2] = $43;
  $45 = ($43|0)==(0|0);
  if ($45) {
   $50 = $44;
  } else {
   $46 = ((($43)) + 8|0);
   $47 = HEAP32[$46>>2]|0;HEAP32[$46>>2] = (($47+1)|0);
   $48 = $$sroa$16$0;
   $50 = $48;
  }
  $49 = ((($50)) + 4|0);
  $51 = $49;
  $52 = (($$0$i16) + -1)|0;
  $53 = ($52|0)==(0);
  if ($53) {
   break;
  } else {
   $$0$i16 = $52;$$sroa$16$0 = $51;$44 = $49;
  }
 }
 $54 = $42;
 $55 = HEAP32[$0>>2]|0;
 $56 = HEAP32[$5>>2]|0;
 $57 = ($56|0)==($55|0);
 if ($57) {
  $58 = $55;
  $70 = $41;$71 = $58;$73 = $55;
 } else {
  $$06$i$i = $56;$$sroa$7$0 = $41;$61 = $39;
  while(1) {
   $59 = ((($$06$i$i)) + -4|0);
   $60 = ((($61)) + -4|0);
   $62 = HEAP32[$59>>2]|0;
   HEAP32[$60>>2] = $62;
   $63 = ($62|0)==(0|0);
   if (!($63)) {
    $64 = ((($62)) + 8|0);
    $65 = HEAP32[$64>>2]|0;HEAP32[$64>>2] = (($65+1)|0);
   }
   $66 = $$sroa$7$0;
   $67 = ((($66)) + -4|0);
   $68 = $67;
   $69 = ($59|0)==($55|0);
   if ($69) {
    break;
   } else {
    $$06$i$i = $59;$$sroa$7$0 = $68;$61 = $67;
   }
  }
  $$pre$i19 = HEAP32[$0>>2]|0;
  $$pre = HEAP32[$5>>2]|0;
  $70 = $68;$71 = $$pre$i19;$73 = $$pre;
 }
 HEAP32[$0>>2] = $70;
 HEAP32[$5>>2] = $51;
 HEAP32[$3>>2] = $54;
 $72 = $71;
 $74 = ($73|0)==($72|0);
 L37: do {
  if (!($74)) {
   $76 = $73;
   while(1) {
    $75 = ((($76)) + -4|0);
    $77 = HEAP32[$75>>2]|0;
    $78 = ($77|0)==(0|0);
    if (!($78)) {
     $79 = ((($77)) + 8|0);
     $80 = HEAP32[$79>>2]|0;HEAP32[$79>>2] = (($80-1)|0);
     $81 = ($80|0)==(1);
     if ($81) {
      __THREW__ = 0;
      invoke_viii(3262,($77|0),1,1);
      $82 = __THREW__; __THREW__ = 0;
      $83 = $82&1;
      if ($83) {
       break;
      }
     }
    }
    HEAP32[$75>>2] = 0;
    $84 = ($75|0)==($72|0);
    if ($84) {
     break L37;
    } else {
     $76 = $75;
    }
   }
   $85 = ___cxa_find_matching_catch_2()|0;
   $86 = tempRet0;
   ___cxa_call_unexpected(($85|0));
   // unreachable;
  }
 } while(0);
 $87 = ($71|0)==(0);
 if ($87) {
  return;
 }
 $88 = $71;
 __ZdlPv($88);
 return;
}
function __ZN3osg14buffered_valueINS_7ref_ptrINS_7Program14ProgramObjectsEEEE6resizeEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 HEAP32[$2>>2] = 0;
 $3 = ((($0)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$0>>2]|0;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 2;
 $8 = ($7>>>0)<($1>>>0);
 $9 = $5;
 $10 = $4;
 L1: do {
  if ($8) {
   $11 = (($1) - ($7))|0;
   __THREW__ = 0;
   invoke_viii(3856,($0|0),($11|0),($2|0));
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if ($13) {
    $35 = ___cxa_find_matching_catch_2()|0;
    $36 = tempRet0;
    $37 = HEAP32[$2>>2]|0;
    $38 = ($37|0)==(0|0);
    if ($38) {
     ___resumeException($35|0);
     // unreachable;
    }
    $39 = ((($37)) + 8|0);
    $40 = HEAP32[$39>>2]|0;HEAP32[$39>>2] = (($40-1)|0);
    $41 = ($40|0)==(1);
    if (!($41)) {
     ___resumeException($35|0);
     // unreachable;
    }
    __THREW__ = 0;
    invoke_viii(3262,($37|0),1,1);
    $42 = __THREW__; __THREW__ = 0;
    $43 = $42&1;
    if ($43) {
     $44 = ___cxa_find_matching_catch_3(0|0)|0;
     $45 = tempRet0;
     ___clang_call_terminate($44);
     // unreachable;
    } else {
     ___resumeException($35|0);
     // unreachable;
    }
   }
  } else {
   $14 = ($7>>>0)>($1>>>0);
   if ($14) {
    $15 = (($9) + ($1<<2)|0);
    $16 = ($10|0)==($15|0);
    if (!($16)) {
     $18 = $10;
     while(1) {
      $17 = ((($18)) + -4|0);
      HEAP32[$3>>2] = $17;
      $19 = HEAP32[$17>>2]|0;
      $20 = ($19|0)==(0|0);
      if (!($20)) {
       $21 = ((($19)) + 8|0);
       $22 = HEAP32[$21>>2]|0;HEAP32[$21>>2] = (($22-1)|0);
       $23 = ($22|0)==(1);
       if ($23) {
        __THREW__ = 0;
        invoke_viii(3262,($19|0),1,1);
        $24 = __THREW__; __THREW__ = 0;
        $25 = $24&1;
        if ($25) {
         break;
        }
       }
      }
      HEAP32[$17>>2] = 0;
      $26 = HEAP32[$3>>2]|0;
      $27 = ($26|0)==($15|0);
      if ($27) {
       break L1;
      } else {
       $18 = $26;
      }
     }
     $28 = ___cxa_find_matching_catch_2()|0;
     $29 = tempRet0;
     ___cxa_call_unexpected(($28|0));
     // unreachable;
    }
   }
  }
 } while(0);
 $30 = HEAP32[$2>>2]|0;
 $31 = ($30|0)==(0|0);
 if ($31) {
  STACKTOP = sp;return;
 }
 $32 = ((($30)) + 8|0);
 $33 = HEAP32[$32>>2]|0;HEAP32[$32>>2] = (($33-1)|0);
 $34 = ($33|0)==(1);
 if (!($34)) {
  STACKTOP = sp;return;
 }
 __ZNK3osg10Referenced24signalObserversAndDeleteEbb($30,1,1);
 STACKTOP = sp;return;
}
function __ZN3osg7ProgramC2ERKS0_RKNS_6CopyOpE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$i$i$i$i = 0, $$0$i$i$i$i66 = 0, $$05499 = 0, $$055101 = 0, $$12 = 0, $$1253 = 0, $$5 = 0, $$546 = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i$i$i = 0, $$pre$i61 = 0, $$sroa$077$0$be = 0, $$sroa$077$096 = 0, $$sroa$086$0$be = 0, $$sroa$086$097 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0;
 var $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0;
 var $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0;
 var $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0;
 var $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0;
 var $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0;
 var $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0;
 var $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 __ZN3osg14StateAttributeC2ERKS0_RKNS_6CopyOpE($0,$1,$2);
 HEAP32[$0>>2] = (65068);
 $4 = ((($0)) + 56|0);
 __THREW__ = 0;
 $5 = (invoke_i(3285)|0);
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 do {
  if ($7) {
   label = 15;
  } else {
   $8 = HEAP32[$5>>2]|0;
   __THREW__ = 0;
   $9 = (invoke_ii(3286,($8|0))|0);
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if ($11) {
    label = 15;
   } else {
    HEAP32[$3>>2] = 0;
    __THREW__ = 0;
    invoke_viii(3868,($4|0),($9|0),($3|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     $21 = ___cxa_find_matching_catch_2()|0;
     $22 = tempRet0;
     $23 = HEAP32[$3>>2]|0;
     $24 = ($23|0)==(0|0);
     if (!($24)) {
      $25 = ((($23)) + 8|0);
      $26 = HEAP32[$25>>2]|0;HEAP32[$25>>2] = (($26-1)|0);
      $27 = ($26|0)==(1);
      if ($27) {
       __THREW__ = 0;
       invoke_viii(3262,($23|0),1,1);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if ($29) {
        $30 = ___cxa_find_matching_catch_3(0|0)|0;
        $31 = tempRet0;
        ___clang_call_terminate($30);
        // unreachable;
       }
      }
     }
     $eh$lpad$body$index2Z2D = $22;$eh$lpad$body$indexZ2D = $21;
     label = 16;
     break;
    }
    $14 = HEAP32[$3>>2]|0;
    $15 = ($14|0)==(0|0);
    if (!($15)) {
     $16 = ((($14)) + 8|0);
     $17 = HEAP32[$16>>2]|0;HEAP32[$16>>2] = (($17-1)|0);
     $18 = ($17|0)==(1);
     if ($18) {
      __THREW__ = 0;
      invoke_viii(3262,($14|0),1,1);
      $19 = __THREW__; __THREW__ = 0;
      $20 = $19&1;
      if ($20) {
       label = 15;
       break;
      }
     }
    }
    $32 = ((($0)) + 68|0);
    $33 = ((($0)) + 72|0);
    HEAP32[$33>>2] = 0;
    $34 = ((($0)) + 76|0);
    HEAP32[$34>>2] = 0;
    $35 = ((($0)) + 72|0);
    HEAP32[$32>>2] = $35;
    $36 = ((($0)) + 80|0);
    $37 = ((($0)) + 84|0);
    HEAP32[$37>>2] = 0;
    $38 = ((($0)) + 88|0);
    HEAP32[$38>>2] = 0;
    $39 = ((($0)) + 84|0);
    HEAP32[$36>>2] = $39;
    $40 = ((($0)) + 92|0);
    $41 = ((($0)) + 96|0);
    HEAP32[$41>>2] = 0;
    $42 = ((($0)) + 100|0);
    HEAP32[$42>>2] = 0;
    $43 = ((($0)) + 96|0);
    HEAP32[$40>>2] = $43;
    $44 = ((($0)) + 104|0);
    $45 = ((($0)) + 108|0);
    $46 = ((($0)) + 116|0);
    $47 = ((($0)) + 148|0);
    HEAP32[$47>>2] = 0;
    $48 = ((($0)) + 152|0);
    HEAP32[$48>>2] = 0;
    $49 = ((($0)) + 156|0);
    HEAP32[$49>>2] = 0;
    $50 = ((($0)) + 160|0);
    $51 = ((($0)) + 164|0);
    HEAP32[$51>>2] = 0;
    $52 = ((($0)) + 168|0);
    HEAP32[$52>>2] = 0;
    $53 = ((($0)) + 164|0);
    ;HEAP32[$44>>2]=0|0;HEAP32[$44+4>>2]=0|0;HEAP32[$44+8>>2]=0|0;HEAP32[$44+12>>2]=0|0;
    HEAP32[$50>>2] = $53;
    $54 = ((($2)) + 4|0);
    $55 = HEAP32[$54>>2]|0;
    $56 = $55 & 16;
    $57 = ($56|0)==(0);
    $58 = ((($1)) + 104|0);
    $59 = ((($1)) + 108|0);
    $60 = HEAP32[$59>>2]|0;
    $61 = HEAP32[$58>>2]|0;
    $62 = ($60|0)!=($61|0);
    $63 = $61;
    L16: do {
     if ($57) {
      if ($62) {
       $$05499 = 0;$90 = $63;
       while(1) {
        $89 = (($90) + ($$05499<<2)|0);
        $91 = HEAP32[$89>>2]|0;
        __THREW__ = 0;
        (invoke_iii(3620,($0|0),($91|0))|0);
        $92 = __THREW__; __THREW__ = 0;
        $93 = $92&1;
        if ($93) {
         break;
        }
        $94 = (($$05499) + 1)|0;
        $95 = HEAP32[$59>>2]|0;
        $96 = HEAP32[$58>>2]|0;
        $97 = (($95) - ($96))|0;
        $98 = $97 >> 2;
        $99 = ($94>>>0)<($98>>>0);
        $100 = $96;
        if ($99) {
         $$05499 = $94;$90 = $100;
        } else {
         label = 26;
         break L16;
        }
       }
       $87 = ___cxa_find_matching_catch_2()|0;
       $88 = tempRet0;
       $$5 = $87;$$546 = $88;
      } else {
       label = 26;
      }
     } else {
      if ($62) {
       $$055101 = 0;$72 = $63;
       while(1) {
        __THREW__ = 0;
        $68 = (invoke_ii(3276,128)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         label = 17;
         break;
        }
        $71 = (($72) + ($$055101<<2)|0);
        $73 = HEAP32[$71>>2]|0;
        __THREW__ = 0;
        invoke_viii(3869,($68|0),($73|0),($2|0));
        $74 = __THREW__; __THREW__ = 0;
        $75 = $74&1;
        if ($75) {
         label = 22;
         break;
        }
        __THREW__ = 0;
        (invoke_iii(3620,($0|0),($68|0))|0);
        $76 = __THREW__; __THREW__ = 0;
        $77 = $76&1;
        if ($77) {
         label = 17;
         break;
        }
        $78 = (($$055101) + 1)|0;
        $79 = HEAP32[$59>>2]|0;
        $80 = HEAP32[$58>>2]|0;
        $81 = (($79) - ($80))|0;
        $82 = $81 >> 2;
        $83 = ($78>>>0)<($82>>>0);
        $84 = $80;
        if ($83) {
         $$055101 = $78;$72 = $84;
        } else {
         label = 26;
         break L16;
        }
       }
       if ((label|0) == 17) {
        $66 = ___cxa_find_matching_catch_2()|0;
        $67 = tempRet0;
        $$5 = $66;$$546 = $67;
        break;
       }
       else if ((label|0) == 22) {
        $85 = ___cxa_find_matching_catch_2()|0;
        $86 = tempRet0;
        __ZdlPv($68);
        $$5 = $85;$$546 = $86;
        break;
       }
      } else {
       label = 26;
      }
     }
    } while(0);
    L31: do {
     if ((label|0) == 26) {
      $101 = ((($1)) + 68|0);
      $102 = HEAP32[$101>>2]|0;
      $103 = ((($1)) + 72|0);
      $104 = ($102|0)==($103|0);
      L33: do {
       if (!($104)) {
        $$sroa$086$097 = $102;
        while(1) {
         $109 = ((($$sroa$086$097)) + 16|0);
         $110 = ((($$sroa$086$097)) + 28|0);
         $111 = HEAP32[$110>>2]|0;
         __THREW__ = 0;
         $112 = (invoke_iii(3870,($32|0),($109|0))|0);
         $113 = __THREW__; __THREW__ = 0;
         $114 = $113&1;
         if ($114) {
          break;
         }
         HEAP32[$112>>2] = $111;
         __THREW__ = 0;
         invoke_vi(3871,($0|0));
         $115 = __THREW__; __THREW__ = 0;
         $116 = $115&1;
         if ($116) {
          break;
         }
         $117 = ((($$sroa$086$097)) + 4|0);
         $118 = HEAP32[$117>>2]|0;
         $119 = ($118|0)==(0|0);
         if ($119) {
          $120 = ((($$sroa$086$097)) + 8|0);
          $121 = HEAP32[$120>>2]|0;
          $122 = HEAP32[$121>>2]|0;
          $123 = ($122|0)==($$sroa$086$097|0);
          if ($123) {
           $$sroa$086$0$be = $121;
          } else {
           $128 = $120;
           while(1) {
            $127 = HEAP32[$128>>2]|0;
            $129 = ((($127)) + 8|0);
            $130 = HEAP32[$129>>2]|0;
            $131 = HEAP32[$130>>2]|0;
            $132 = ($131|0)==($127|0);
            if ($132) {
             $$sroa$086$0$be = $130;
             break;
            } else {
             $128 = $129;
            }
           }
          }
         } else {
          $$0$i$i$i$i = $118;
          while(1) {
           $125 = HEAP32[$$0$i$i$i$i>>2]|0;
           $126 = ($125|0)==(0|0);
           if ($126) {
            break;
           } else {
            $$0$i$i$i$i = $125;
           }
          }
          $$sroa$086$0$be = $$0$i$i$i$i;
         }
         $124 = ($$sroa$086$0$be|0)==($103|0);
         if ($124) {
          break L33;
         } else {
          $$sroa$086$097 = $$sroa$086$0$be;
         }
        }
        $133 = ___cxa_find_matching_catch_2()|0;
        $134 = tempRet0;
        $$5 = $133;$$546 = $134;
        break L31;
       }
      } while(0);
      $105 = ((($1)) + 80|0);
      $106 = HEAP32[$105>>2]|0;
      $107 = ((($1)) + 84|0);
      $108 = ($106|0)==($107|0);
      L48: do {
       if (!($108)) {
        $$sroa$077$096 = $106;
        while(1) {
         $163 = ((($$sroa$077$096)) + 16|0);
         $164 = ((($$sroa$077$096)) + 28|0);
         $165 = HEAP32[$164>>2]|0;
         __THREW__ = 0;
         $166 = (invoke_iii(3870,($36|0),($163|0))|0);
         $167 = __THREW__; __THREW__ = 0;
         $168 = $167&1;
         if ($168) {
          break;
         }
         HEAP32[$166>>2] = $165;
         __THREW__ = 0;
         invoke_vi(3871,($0|0));
         $169 = __THREW__; __THREW__ = 0;
         $170 = $169&1;
         if ($170) {
          break;
         }
         $171 = ((($$sroa$077$096)) + 4|0);
         $172 = HEAP32[$171>>2]|0;
         $173 = ($172|0)==(0|0);
         if ($173) {
          $174 = ((($$sroa$077$096)) + 8|0);
          $175 = HEAP32[$174>>2]|0;
          $176 = HEAP32[$175>>2]|0;
          $177 = ($176|0)==($$sroa$077$096|0);
          if ($177) {
           $$sroa$077$0$be = $175;
          } else {
           $182 = $174;
           while(1) {
            $181 = HEAP32[$182>>2]|0;
            $183 = ((($181)) + 8|0);
            $184 = HEAP32[$183>>2]|0;
            $185 = HEAP32[$184>>2]|0;
            $186 = ($185|0)==($181|0);
            if ($186) {
             $$sroa$077$0$be = $184;
             break;
            } else {
             $182 = $183;
            }
           }
          }
         } else {
          $$0$i$i$i$i66 = $172;
          while(1) {
           $179 = HEAP32[$$0$i$i$i$i66>>2]|0;
           $180 = ($179|0)==(0|0);
           if ($180) {
            break;
           } else {
            $$0$i$i$i$i66 = $179;
           }
          }
          $$sroa$077$0$be = $$0$i$i$i$i66;
         }
         $178 = ($$sroa$077$0$be|0)==($107|0);
         if ($178) {
          break L48;
         } else {
          $$sroa$077$096 = $$sroa$077$0$be;
         }
        }
        $187 = ___cxa_find_matching_catch_2()|0;
        $188 = tempRet0;
        $$5 = $187;$$546 = $188;
        break L31;
       }
      } while(0);
      $135 = ((($1)) + 120|0);
      $136 = HEAP32[$135>>2]|0;
      $137 = ((($0)) + 120|0);
      HEAP32[$137>>2] = $136;
      $138 = ((($1)) + 124|0);
      $139 = HEAP32[$138>>2]|0;
      $140 = ((($0)) + 124|0);
      HEAP32[$140>>2] = $139;
      $141 = ((($1)) + 128|0);
      $142 = HEAP32[$141>>2]|0;
      $143 = ((($0)) + 128|0);
      HEAP32[$143>>2] = $142;
      $144 = ((($1)) + 132|0);
      $145 = HEAP32[$144>>2]|0;
      $146 = ((($0)) + 132|0);
      HEAP32[$146>>2] = $145;
      $147 = ((($1)) + 136|0);
      $148 = HEAP32[$147>>2]|0;
      $149 = ((($0)) + 136|0);
      HEAP32[$149>>2] = $148;
      $150 = ((($1)) + 140|0);
      $151 = HEAP32[$150>>2]|0;
      $152 = ((($0)) + 140|0);
      HEAP32[$152>>2] = $151;
      $153 = ((($1)) + 144|0);
      $154 = HEAP32[$153>>2]|0;
      $155 = ((($0)) + 144|0);
      HEAP32[$155>>2] = $154;
      $156 = ($0|0)==($1|0);
      if ($156) {
       STACKTOP = sp;return;
      }
      $157 = ((($1)) + 148|0);
      $158 = HEAP32[$157>>2]|0;
      $159 = ((($1)) + 152|0);
      $160 = HEAP32[$159>>2]|0;
      __THREW__ = 0;
      invoke_viii(3872,($47|0),($158|0),($160|0));
      $161 = __THREW__; __THREW__ = 0;
      $162 = $161&1;
      if ($162) {
       $189 = ___cxa_find_matching_catch_2()|0;
       $190 = tempRet0;
       $$5 = $189;$$546 = $190;
       break;
      } else {
       STACKTOP = sp;return;
      }
     }
    } while(0);
    $191 = HEAP32[$53>>2]|0;
    __ZNSt3__26__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EENS4_IS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($50,$191);
    $192 = HEAP32[$47>>2]|0;
    $193 = ($192|0)==(0|0);
    if (!($193)) {
     $194 = HEAP32[$48>>2]|0;
     $195 = ($194|0)==($192|0);
     if ($195) {
      $204 = $192;
     } else {
      $197 = $194;
      while(1) {
       $196 = ((($197)) + -12|0);
       HEAP32[$48>>2] = $196;
       $198 = ((($196)) + 11|0);
       $199 = HEAP8[$198>>0]|0;
       $200 = ($199<<24>>24)<(0);
       if ($200) {
        $203 = HEAP32[$196>>2]|0;
        __ZdlPv($203);
        $$pre$i$i$i = HEAP32[$48>>2]|0;
        $201 = $$pre$i$i$i;
       } else {
        $201 = $196;
       }
       $202 = ($201|0)==($192|0);
       if ($202) {
        break;
       } else {
        $197 = $201;
       }
      }
      $$pre$i61 = HEAP32[$47>>2]|0;
      $204 = $$pre$i61;
     }
     __ZdlPv($204);
    }
    $205 = HEAP32[$46>>2]|0;
    $206 = ($205|0)==(0|0);
    if (!($206)) {
     $207 = ((($205)) + 8|0);
     $208 = HEAP32[$207>>2]|0;HEAP32[$207>>2] = (($208-1)|0);
     $209 = ($208|0)==(1);
     if ($209) {
      __THREW__ = 0;
      invoke_viii(3262,($205|0),1,1);
      $210 = __THREW__; __THREW__ = 0;
      $211 = $210&1;
      if ($211) {
       $254 = ___cxa_find_matching_catch_3(0|0)|0;
       $255 = tempRet0;
       ___clang_call_terminate($254);
       // unreachable;
      }
     }
    }
    HEAP32[$46>>2] = 0;
    $212 = HEAP32[$44>>2]|0;
    $213 = ($212|0)==(0|0);
    if (!($213)) {
     $214 = HEAP32[$45>>2]|0;
     $215 = ($214|0)==($212|0);
     do {
      if ($215) {
       $229 = $212;
      } else {
       $217 = $214;
       while(1) {
        $216 = ((($217)) + -4|0);
        HEAP32[$45>>2] = $216;
        $218 = HEAP32[$216>>2]|0;
        $219 = ($218|0)==(0|0);
        if (!($219)) {
         $220 = ((($218)) + 8|0);
         $221 = HEAP32[$220>>2]|0;HEAP32[$220>>2] = (($221-1)|0);
         $222 = ($221|0)==(1);
         if ($222) {
          __THREW__ = 0;
          invoke_viii(3262,($218|0),1,1);
          $223 = __THREW__; __THREW__ = 0;
          $224 = $223&1;
          if ($224) {
           label = 66;
           break;
          }
         }
        }
        HEAP32[$216>>2] = 0;
        $225 = HEAP32[$45>>2]|0;
        $226 = ($225|0)==($212|0);
        if ($226) {
         label = 67;
         break;
        } else {
         $217 = $225;
        }
       }
       if ((label|0) == 66) {
        $227 = ___cxa_find_matching_catch_2()|0;
        $228 = tempRet0;
        ___cxa_call_unexpected(($227|0));
        // unreachable;
       }
       else if ((label|0) == 67) {
        $$pre$i = HEAP32[$44>>2]|0;
        $229 = $$pre$i;
        break;
       }
      }
     } while(0);
     __ZdlPv($229);
    }
    $230 = HEAP32[$43>>2]|0;
    __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEjEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($40,$230);
    $231 = HEAP32[$39>>2]|0;
    __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEjEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($36,$231);
    $232 = HEAP32[$35>>2]|0;
    __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEjEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($32,$232);
    $233 = HEAP32[$4>>2]|0;
    $234 = ($233|0)==(0|0);
    if ($234) {
     $$12 = $$5;$$1253 = $$546;
    } else {
     $235 = ((($0)) + 60|0);
     $236 = HEAP32[$235>>2]|0;
     $237 = ($236|0)==($233|0);
     do {
      if ($237) {
       $251 = $233;
      } else {
       $239 = $236;
       while(1) {
        $238 = ((($239)) + -4|0);
        HEAP32[$235>>2] = $238;
        $240 = HEAP32[$238>>2]|0;
        $241 = ($240|0)==(0|0);
        if (!($241)) {
         $242 = ((($240)) + 8|0);
         $243 = HEAP32[$242>>2]|0;HEAP32[$242>>2] = (($243-1)|0);
         $244 = ($243|0)==(1);
         if ($244) {
          __THREW__ = 0;
          invoke_viii(3262,($240|0),1,1);
          $245 = __THREW__; __THREW__ = 0;
          $246 = $245&1;
          if ($246) {
           label = 75;
           break;
          }
         }
        }
        HEAP32[$238>>2] = 0;
        $247 = HEAP32[$235>>2]|0;
        $248 = ($247|0)==($233|0);
        if ($248) {
         label = 76;
         break;
        } else {
         $239 = $247;
        }
       }
       if ((label|0) == 75) {
        $249 = ___cxa_find_matching_catch_2()|0;
        $250 = tempRet0;
        ___cxa_call_unexpected(($249|0));
        // unreachable;
       }
       else if ((label|0) == 76) {
        $$pre$i$i = HEAP32[$4>>2]|0;
        $251 = $$pre$i$i;
        break;
       }
      }
     } while(0);
     __ZdlPv($251);
     $$12 = $$5;$$1253 = $$546;
    }
   }
  }
 } while(0);
 if ((label|0) == 15) {
  $64 = ___cxa_find_matching_catch_2()|0;
  $65 = tempRet0;
  $eh$lpad$body$index2Z2D = $65;$eh$lpad$body$indexZ2D = $64;
  label = 16;
 }
 if ((label|0) == 16) {
  $$12 = $eh$lpad$body$indexZ2D;$$1253 = $eh$lpad$body$index2Z2D;
 }
 __THREW__ = 0;
 invoke_vi(1573,($0|0));
 $252 = __THREW__; __THREW__ = 0;
 $253 = $252&1;
 if ($253) {
  $254 = ___cxa_find_matching_catch_3(0|0)|0;
  $255 = tempRet0;
  ___clang_call_terminate($254);
  // unreachable;
 } else {
  ___resumeException($$12|0);
  // unreachable;
 }
}
function __ZNSt3__26vectorIN3osg7ref_ptrINS1_7Program14ProgramObjectsEEENS_9allocatorIS5_EEEC2EjRKS5_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$i = 0, $$pre$i7 = 0, $$pre5$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = 0;
 $3 = ((($0)) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = ((($0)) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = ($1|0)==(0);
 if ($5) {
  return;
 }
 $6 = ($1>>>0)>(1073741823);
 if ($6) {
  __THREW__ = 0;
  invoke_vi(3307,($0|0));
  $7 = __THREW__; __THREW__ = 0;
 } else {
  $8 = $1 << 2;
  __THREW__ = 0;
  $9 = (invoke_ii(3276,($8|0))|0);
  $10 = __THREW__; __THREW__ = 0;
  $11 = $10&1;
  if (!($11)) {
   HEAP32[$3>>2] = $9;
   HEAP32[$0>>2] = $9;
   $12 = (($9) + ($1<<2)|0);
   $13 = ((($0)) + 8|0);
   HEAP32[$13>>2] = $12;
   $$0$i = $1;$15 = $9;
   while(1) {
    $14 = HEAP32[$2>>2]|0;
    HEAP32[$15>>2] = $14;
    $16 = ($14|0)==(0|0);
    if ($16) {
     $20 = $15;
    } else {
     $17 = ((($14)) + 8|0);
     $18 = HEAP32[$17>>2]|0;HEAP32[$17>>2] = (($18+1)|0);
     $$pre5$i = HEAP32[$3>>2]|0;
     $20 = $$pre5$i;
    }
    $19 = ((($20)) + 4|0);
    HEAP32[$3>>2] = $19;
    $21 = (($$0$i) + -1)|0;
    $22 = ($21|0)==(0);
    if ($22) {
     break;
    } else {
     $$0$i = $21;$15 = $19;
    }
   }
   return;
  }
 }
 $23 = ___cxa_find_matching_catch_2()|0;
 $24 = tempRet0;
 $25 = HEAP32[$0>>2]|0;
 $26 = ($25|0)==(0|0);
 if ($26) {
  ___resumeException($23|0);
  // unreachable;
 }
 $27 = HEAP32[$3>>2]|0;
 $28 = ($27|0)==($25|0);
 do {
  if ($28) {
   $42 = $25;
  } else {
   $30 = $27;
   while(1) {
    $29 = ((($30)) + -4|0);
    HEAP32[$3>>2] = $29;
    $31 = HEAP32[$29>>2]|0;
    $32 = ($31|0)==(0|0);
    if (!($32)) {
     $33 = ((($31)) + 8|0);
     $34 = HEAP32[$33>>2]|0;HEAP32[$33>>2] = (($34-1)|0);
     $35 = ($34|0)==(1);
     if ($35) {
      __THREW__ = 0;
      invoke_viii(3262,($31|0),1,1);
      $36 = __THREW__; __THREW__ = 0;
      $37 = $36&1;
      if ($37) {
       label = 15;
       break;
      }
     }
    }
    HEAP32[$29>>2] = 0;
    $38 = HEAP32[$3>>2]|0;
    $39 = ($38|0)==($25|0);
    if ($39) {
     label = 16;
     break;
    } else {
     $30 = $38;
    }
   }
   if ((label|0) == 15) {
    $40 = ___cxa_find_matching_catch_2()|0;
    $41 = tempRet0;
    ___cxa_call_unexpected(($40|0));
    // unreachable;
   }
   else if ((label|0) == 16) {
    $$pre$i7 = HEAP32[$0>>2]|0;
    $42 = $$pre$i7;
    break;
   }
  }
 } while(0);
 __ZdlPv($42);
 ___resumeException($23|0);
 // unreachable;
}
function __ZN3osg7Program9addShaderEPNS_6ShaderE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$01928 = 0, $$02027 = 0, $$1 = 0, $$pre$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = ($1|0)==(0|0);
 if ($3) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $4 = ((($0)) + 104|0);
 $5 = ((($0)) + 108|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$4>>2]|0;
 $8 = ($6|0)==($7|0);
 $9 = $7;
 L4: do {
  if (!($8)) {
   $10 = (($6) - ($7))|0;
   $11 = $10 >> 2;
   $$01928 = 0;
   while(1) {
    $19 = (($9) + ($$01928<<2)|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = ($20|0)==($1|0);
    $12 = (($$01928) + 1)|0;
    if ($21) {
     $$1 = 0;
     break;
    }
    $13 = ($12>>>0)<($11>>>0);
    if ($13) {
     $$01928 = $12;
    } else {
     break L4;
    }
   }
   STACKTOP = sp;return ($$1|0);
  }
 } while(0);
 $14 = ((($0)) + 56|0);
 $15 = ((($0)) + 60|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = HEAP32[$14>>2]|0;
 $18 = ($16|0)==($17|0);
 if (!($18)) {
  $$02027 = 0;
  while(1) {
   $36 = (__ZN3osg14buffered_valueINS_7ref_ptrINS_7Program14ProgramObjectsEEEEixEj($14,$$02027)|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = ($37|0)==(0|0);
   if (!($38)) {
    $39 = (__ZN3osg14buffered_valueINS_7ref_ptrINS_7Program14ProgramObjectsEEEEixEj($14,$$02027)|0);
    $40 = HEAP32[$39>>2]|0;
    __ZN3osg7Program14ProgramObjects17addShaderToAttachEPNS_6ShaderE($40,$1);
   }
   $41 = (($$02027) + 1)|0;
   $42 = HEAP32[$15>>2]|0;
   $43 = HEAP32[$14>>2]|0;
   $44 = (($42) - ($43))|0;
   $45 = $44 >> 2;
   $46 = ($41>>>0)<($45>>>0);
   if ($46) {
    $$02027 = $41;
   } else {
    break;
   }
  }
 }
 (__ZN3osg6Shader13addProgramRefEPNS_7ProgramE($1,$0)|0);
 HEAP32[$2>>2] = $1;
 $22 = ((($1)) + 8|0);
 $23 = HEAP32[$22>>2]|0;HEAP32[$22>>2] = (($23+1)|0);
 $24 = HEAP32[$5>>2]|0;
 $25 = ((($0)) + 112|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($24|0)==($26|0);
 if ($27) {
  __THREW__ = 0;
  invoke_vii(3855,($4|0),($2|0));
  $34 = __THREW__; __THREW__ = 0;
  $35 = $34&1;
  if ($35) {
   $52 = ___cxa_find_matching_catch_2()|0;
   $53 = tempRet0;
   $54 = HEAP32[$2>>2]|0;
   $55 = ($54|0)==(0|0);
   if ($55) {
    ___resumeException($52|0);
    // unreachable;
   }
   $56 = ((($54)) + 8|0);
   $57 = HEAP32[$56>>2]|0;HEAP32[$56>>2] = (($57-1)|0);
   $58 = ($57|0)==(1);
   if (!($58)) {
    ___resumeException($52|0);
    // unreachable;
   }
   __THREW__ = 0;
   invoke_viii(3262,($54|0),1,1);
   $59 = __THREW__; __THREW__ = 0;
   $60 = $59&1;
   if ($60) {
    $61 = ___cxa_find_matching_catch_3(0|0)|0;
    $62 = tempRet0;
    ___clang_call_terminate($61);
    // unreachable;
   } else {
    ___resumeException($52|0);
    // unreachable;
   }
  }
 } else {
  $28 = HEAP32[$2>>2]|0;
  HEAP32[$24>>2] = $28;
  $29 = ($28|0)==(0|0);
  if ($29) {
   $33 = $24;
  } else {
   $30 = ((($28)) + 8|0);
   $31 = HEAP32[$30>>2]|0;HEAP32[$30>>2] = (($31+1)|0);
   $$pre$i = HEAP32[$5>>2]|0;
   $33 = $$pre$i;
  }
  $32 = ((($33)) + 4|0);
  HEAP32[$5>>2] = $32;
 }
 $47 = HEAP32[$2>>2]|0;
 $48 = ($47|0)==(0|0);
 if (!($48)) {
  $49 = ((($47)) + 8|0);
  $50 = HEAP32[$49>>2]|0;HEAP32[$49>>2] = (($50-1)|0);
  $51 = ($50|0)==(1);
  if ($51) {
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($47,1,1);
  }
 }
 __ZN3osg7Program12dirtyProgramEv($0);
 $$1 = 1;
 STACKTOP = sp;return ($$1|0);
}
function __ZNSt3__23mapINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEjNS_4lessIS6_EENS4_INS_4pairIKS6_jEEEEEixERSA_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$014 = 0, $$pre$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = (__ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEjEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE12__find_equalIS7_EERPNS_16__tree_node_baseIPvEERPNS_15__tree_end_nodeISJ_EERKT_($0,$2,$1)|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if (!($5)) {
  $$014 = $4;
  $26 = ((($$014)) + 28|0);
  STACKTOP = sp;return ($26|0);
 }
 $6 = (__Znwj(32)|0);
 $7 = ((($6)) + 16|0);
 __THREW__ = 0;
 invoke_vii(3457,($7|0),($1|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $10 = ___cxa_find_matching_catch_2()|0;
  $11 = tempRet0;
  __ZdlPv($6);
  ___resumeException($10|0);
  // unreachable;
 }
 $12 = ((($6)) + 28|0);
 HEAP32[$12>>2] = 0;
 $13 = HEAP32[$2>>2]|0;
 HEAP32[$6>>2] = 0;
 $14 = ((($6)) + 4|0);
 HEAP32[$14>>2] = 0;
 $15 = ((($6)) + 8|0);
 HEAP32[$15>>2] = $13;
 HEAP32[$3>>2] = $6;
 $16 = HEAP32[$0>>2]|0;
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==(0|0);
 if ($18) {
  $22 = $6;
 } else {
  $19 = $17;
  HEAP32[$0>>2] = $19;
  $$pre$i = HEAP32[$3>>2]|0;
  $22 = $$pre$i;
 }
 $20 = ((($0)) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($21,$22);
 $23 = ((($0)) + 8|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (($24) + 1)|0;
 HEAP32[$23>>2] = $25;
 $$014 = $6;
 $26 = ((($$014)) + 28|0);
 STACKTOP = sp;return ($26|0);
}
function __ZN3osg7Program12dirtyProgramEv($0) {
 $0 = $0|0;
 var $$0$i$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i26 = 0, $$0$i$i$i30 = 0, $$054 = 0, $$byval_copy = 0, $$byval_copy1 = 0, $$in7$i = 0, $$in7$i19 = 0, $$pre$i$i$i$i = 0, $$pre$i$i$i$i22 = 0, $$sroa$02$06$i = 0, $$sroa$038$053 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $$byval_copy1 = sp + 28|0;
 $$byval_copy = sp + 24|0;
 $1 = sp + 20|0;
 $2 = sp + 16|0;
 $3 = sp + 12|0;
 $4 = sp + 8|0;
 $5 = sp + 4|0;
 $6 = sp;
 $7 = ((($0)) + 56|0);
 $8 = ((($0)) + 60|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$7>>2]|0;
 $11 = ($9|0)==($10|0);
 if (!($11)) {
  $$054 = 0;
  while(1) {
   $23 = (__ZN3osg14buffered_valueINS_7ref_ptrINS_7Program14ProgramObjectsEEEEixEj($7,$$054)|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = ($24|0)==(0|0);
   if (!($25)) {
    $26 = (__ZN3osg14buffered_valueINS_7ref_ptrINS_7Program14ProgramObjectsEEEEixEj($7,$$054)|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = ((($27)) + 20|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = ((($27)) + 24|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = ($29|0)==($31|0);
    if (!($32)) {
     $$sroa$02$06$i = $29;
     while(1) {
      $33 = HEAP32[$$sroa$02$06$i>>2]|0;
      $34 = ((($33)) + 36|0);
      HEAP8[$34>>0] = 1;
      $35 = ((($33)) + 37|0);
      HEAP8[$35>>0] = 0;
      $36 = ((($$sroa$02$06$i)) + 4|0);
      $37 = ($36|0)==($31|0);
      if ($37) {
       break;
      } else {
       $$sroa$02$06$i = $36;
      }
     }
    }
   }
   $38 = (($$054) + 1)|0;
   $39 = HEAP32[$8>>2]|0;
   $40 = HEAP32[$7>>2]|0;
   $41 = (($39) - ($40))|0;
   $42 = $41 >> 2;
   $43 = ($38>>>0)<($42>>>0);
   if ($43) {
    $$054 = $38;
   } else {
    break;
   }
  }
 }
 $12 = ((($0)) + 160|0);
 $13 = ((($0)) + 164|0);
 $14 = HEAP32[$13>>2]|0;
 __ZNSt3__26__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EENS4_IS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($12,$14);
 $15 = ((($0)) + 168|0);
 HEAP32[$15>>2] = 0;
 HEAP32[$12>>2] = $13;
 HEAP32[$13>>2] = 0;
 $16 = ((($0)) + 104|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ((($0)) + 108|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($17|0)==($19|0);
 if ($20) {
  STACKTOP = sp;return;
 }
 $21 = $13;
 $22 = ((($0)) + 164|0);
 $$sroa$038$053 = $17;
 L13: while(1) {
  $44 = HEAP32[$$sroa$038$053>>2]|0;
  $45 = ((($44)) + 80|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = ((($44)) + 84|0);
  $48 = ($46|0)==($47|0);
  if (!($48)) {
   $$in7$i19 = $46;
   while(1) {
    $49 = ((($$in7$i19)) + 16|0);
    HEAP32[$3>>2] = $21;
    ;HEAP32[$$byval_copy>>2]=HEAP32[$3>>2]|0;
    $50 = (__ZNSt3__26__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EENS4_IS6_EEE12__find_equalIS6_EERPNS_16__tree_node_baseIPvEENS_21__tree_const_iteratorIS6_PNS_11__tree_nodeIS6_SD_EEiEERPNS_15__tree_end_nodeISF_EESG_RKT_($12,$$byval_copy,$1,$2,$49)|0);
    $51 = HEAP32[$50>>2]|0;
    $52 = ($51|0)==(0|0);
    if ($52) {
     $53 = (__Znwj(28)|0);
     $54 = ((($53)) + 16|0);
     __THREW__ = 0;
     invoke_vii(3457,($54|0),($49|0));
     $55 = __THREW__; __THREW__ = 0;
     $56 = $55&1;
     if ($56) {
      label = 12;
      break L13;
     }
     $59 = HEAP32[$1>>2]|0;
     HEAP32[$53>>2] = 0;
     $60 = ((($53)) + 4|0);
     HEAP32[$60>>2] = 0;
     $61 = ((($53)) + 8|0);
     HEAP32[$61>>2] = $59;
     HEAP32[$50>>2] = $53;
     $62 = HEAP32[$12>>2]|0;
     $63 = HEAP32[$62>>2]|0;
     $64 = ($63|0)==(0|0);
     if ($64) {
      $67 = $53;
     } else {
      $65 = $63;
      HEAP32[$12>>2] = $65;
      $$pre$i$i$i$i22 = HEAP32[$50>>2]|0;
      $67 = $$pre$i$i$i$i22;
     }
     $66 = HEAP32[$22>>2]|0;
     __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($66,$67);
     $68 = HEAP32[$15>>2]|0;
     $69 = (($68) + 1)|0;
     HEAP32[$15>>2] = $69;
    }
    $70 = ((($$in7$i19)) + 4|0);
    $71 = HEAP32[$70>>2]|0;
    $72 = ($71|0)==(0|0);
    if ($72) {
     $73 = ((($$in7$i19)) + 8|0);
     $74 = HEAP32[$73>>2]|0;
     $75 = HEAP32[$74>>2]|0;
     $76 = ($75|0)==($$in7$i19|0);
     if ($76) {
      $$0$i$i$i30 = $74;
     } else {
      $80 = $73;
      while(1) {
       $79 = HEAP32[$80>>2]|0;
       $81 = ((($79)) + 8|0);
       $82 = HEAP32[$81>>2]|0;
       $83 = HEAP32[$82>>2]|0;
       $84 = ($83|0)==($79|0);
       if ($84) {
        $$0$i$i$i30 = $82;
        break;
       } else {
        $80 = $81;
       }
      }
     }
    } else {
     $$0$i$i$i$i26 = $71;
     while(1) {
      $77 = HEAP32[$$0$i$i$i$i26>>2]|0;
      $78 = ($77|0)==(0|0);
      if ($78) {
       break;
      } else {
       $$0$i$i$i$i26 = $77;
      }
     }
     $$0$i$i$i30 = $$0$i$i$i$i26;
    }
    $85 = ($$0$i$i$i30|0)==($47|0);
    if ($85) {
     break;
    } else {
     $$in7$i19 = $$0$i$i$i30;
    }
   }
  }
  $86 = ((($44)) + 92|0);
  $87 = HEAP32[$86>>2]|0;
  $88 = ((($44)) + 96|0);
  $89 = ($87|0)==($88|0);
  if (!($89)) {
   $$in7$i = $87;
   while(1) {
    $90 = ((($$in7$i)) + 16|0);
    HEAP32[$6>>2] = $21;
    ;HEAP32[$$byval_copy1>>2]=HEAP32[$6>>2]|0;
    $91 = (__ZNSt3__26__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EENS4_IS6_EEE12__find_equalIS6_EERPNS_16__tree_node_baseIPvEENS_21__tree_const_iteratorIS6_PNS_11__tree_nodeIS6_SD_EEiEERPNS_15__tree_end_nodeISF_EESG_RKT_($12,$$byval_copy1,$4,$5,$90)|0);
    $92 = HEAP32[$91>>2]|0;
    $93 = ($92|0)==(0|0);
    if ($93) {
     $94 = (__Znwj(28)|0);
     $95 = ((($94)) + 16|0);
     __THREW__ = 0;
     invoke_vii(3457,($95|0),($90|0));
     $96 = __THREW__; __THREW__ = 0;
     $97 = $96&1;
     if ($97) {
      label = 25;
      break L13;
     }
     $100 = HEAP32[$4>>2]|0;
     HEAP32[$94>>2] = 0;
     $101 = ((($94)) + 4|0);
     HEAP32[$101>>2] = 0;
     $102 = ((($94)) + 8|0);
     HEAP32[$102>>2] = $100;
     HEAP32[$91>>2] = $94;
     $103 = HEAP32[$12>>2]|0;
     $104 = HEAP32[$103>>2]|0;
     $105 = ($104|0)==(0|0);
     if ($105) {
      $108 = $94;
     } else {
      $106 = $104;
      HEAP32[$12>>2] = $106;
      $$pre$i$i$i$i = HEAP32[$91>>2]|0;
      $108 = $$pre$i$i$i$i;
     }
     $107 = HEAP32[$22>>2]|0;
     __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($107,$108);
     $109 = HEAP32[$15>>2]|0;
     $110 = (($109) + 1)|0;
     HEAP32[$15>>2] = $110;
    }
    $111 = ((($$in7$i)) + 4|0);
    $112 = HEAP32[$111>>2]|0;
    $113 = ($112|0)==(0|0);
    if ($113) {
     $114 = ((($$in7$i)) + 8|0);
     $115 = HEAP32[$114>>2]|0;
     $116 = HEAP32[$115>>2]|0;
     $117 = ($116|0)==($$in7$i|0);
     if ($117) {
      $$0$i$i$i = $115;
     } else {
      $121 = $114;
      while(1) {
       $120 = HEAP32[$121>>2]|0;
       $122 = ((($120)) + 8|0);
       $123 = HEAP32[$122>>2]|0;
       $124 = HEAP32[$123>>2]|0;
       $125 = ($124|0)==($120|0);
       if ($125) {
        $$0$i$i$i = $123;
        break;
       } else {
        $121 = $122;
       }
      }
     }
    } else {
     $$0$i$i$i$i = $112;
     while(1) {
      $118 = HEAP32[$$0$i$i$i$i>>2]|0;
      $119 = ($118|0)==(0|0);
      if ($119) {
       break;
      } else {
       $$0$i$i$i$i = $118;
      }
     }
     $$0$i$i$i = $$0$i$i$i$i;
    }
    $126 = ($$0$i$i$i|0)==($88|0);
    if ($126) {
     break;
    } else {
     $$in7$i = $$0$i$i$i;
    }
   }
  }
  $127 = ((($$sroa$038$053)) + 4|0);
  $128 = HEAP32[$18>>2]|0;
  $129 = ($127|0)==($128|0);
  if ($129) {
   label = 8;
   break;
  } else {
   $$sroa$038$053 = $127;
  }
 }
 if ((label|0) == 8) {
  STACKTOP = sp;return;
 }
 else if ((label|0) == 12) {
  $57 = ___cxa_find_matching_catch_2()|0;
  $58 = tempRet0;
  __ZdlPv($53);
  ___resumeException($57|0);
  // unreachable;
 }
 else if ((label|0) == 25) {
  $98 = ___cxa_find_matching_catch_2()|0;
  $99 = tempRet0;
  __ZdlPv($94);
  ___resumeException($98|0);
  // unreachable;
 }
}
function __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEjEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 }
 $3 = HEAP32[$1>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEjEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($0,$3);
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEjEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($0,$5);
 $6 = ((($1)) + 16|0);
 $7 = ((($6)) + 11|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = ($8<<24>>24)<(0);
 if ($9) {
  $10 = HEAP32[$6>>2]|0;
  __ZdlPv($10);
 }
 __ZdlPv($1);
 return;
}
function __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEjEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE12__find_equalIS7_EERPNS_16__tree_node_baseIPvEERPNS_15__tree_end_nodeISJ_EERKT_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$0$ph = 0, $$024 = 0, $$025 = 0, $$in = 0, $$sroa$speculated$i$i$i$i$i = 0, $$sroa$speculated$i$i$i$i$i26 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  HEAP32[$1>>2] = $3;
  $$025 = $3;
  return ($$025|0);
 }
 $6 = ((($0)) + 4|0);
 $7 = ((($2)) + 11|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = ($8<<24>>24)<(0);
 $10 = ((($2)) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $8&255;
 $13 = $9 ? $11 : $12;
 $14 = HEAP32[$2>>2]|0;
 $15 = $9 ? $14 : $2;
 $$0 = $6;$$024 = $4;
 while(1) {
  $16 = ((($$024)) + 16|0);
  $17 = ((($16)) + 11|0);
  $18 = HEAP8[$17>>0]|0;
  $19 = ($18<<24>>24)<(0);
  $20 = ((($$024)) + 20|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = $18&255;
  $23 = $19 ? $21 : $22;
  $24 = ($23>>>0)<($13>>>0);
  $$sroa$speculated$i$i$i$i$i26 = $24 ? $23 : $13;
  $25 = ($$sroa$speculated$i$i$i$i$i26|0)==(0);
  if ($25) {
   label = 6;
  } else {
   $26 = HEAP32[$16>>2]|0;
   $27 = $19 ? $26 : $16;
   $28 = (_memcmp($15,$27,$$sroa$speculated$i$i$i$i$i26)|0);
   $29 = ($28|0)==(0);
   if ($29) {
    label = 6;
   } else {
    $31 = ($28|0)<(0);
    if ($31) {
     label = 8;
    } else {
     label = 10;
    }
   }
  }
  if ((label|0) == 6) {
   label = 0;
   $30 = ($13>>>0)<($23>>>0);
   if ($30) {
    label = 8;
   } else {
    label = 10;
   }
  }
  if ((label|0) == 8) {
   label = 0;
   $32 = HEAP32[$$024>>2]|0;
   $33 = ($32|0)==(0|0);
   if ($33) {
    label = 9;
    break;
   } else {
    $$0$ph = $$024;$$in = $32;
   }
  }
  else if ((label|0) == 10) {
   label = 0;
   $34 = ($13>>>0)<($23>>>0);
   $$sroa$speculated$i$i$i$i$i = $34 ? $13 : $23;
   $35 = ($$sroa$speculated$i$i$i$i$i|0)==(0);
   if ($35) {
    label = 12;
   } else {
    $36 = HEAP32[$16>>2]|0;
    $37 = $19 ? $36 : $16;
    $38 = (_memcmp($37,$15,$$sroa$speculated$i$i$i$i$i)|0);
    $39 = ($38|0)==(0);
    if ($39) {
     label = 12;
    } else {
     $40 = ($38|0)<(0);
     if (!($40)) {
      label = 16;
      break;
     }
    }
   }
   if ((label|0) == 12) {
    label = 0;
    if (!($24)) {
     label = 16;
     break;
    }
   }
   $41 = ((($$024)) + 4|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = ($42|0)==(0|0);
   if ($43) {
    label = 15;
    break;
   } else {
    $$0$ph = $41;$$in = $42;
   }
  }
  $$0 = $$0$ph;$$024 = $$in;
 }
 if ((label|0) == 9) {
  HEAP32[$1>>2] = $$024;
  $$025 = $$024;
  return ($$025|0);
 }
 else if ((label|0) == 15) {
  HEAP32[$1>>2] = $$024;
  $$025 = $41;
  return ($$025|0);
 }
 else if ((label|0) == 16) {
  HEAP32[$1>>2] = $$024;
  $$025 = $$0;
  return ($$025|0);
 }
 return (0)|0;
}
function __ZN3osg7Program14ProgramObjects17addShaderToAttachEPNS_6ShaderE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$pre$i$i = 0, $$sroa$03$08 = 0, $$sroa$03$08$us = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = ((($0)) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 24|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4|0)==($6|0);
 if ($7) {
  STACKTOP = sp;return;
 }
 $8 = ($1|0)==(0|0);
 $9 = ((($1)) + 8|0);
 L4: do {
  if ($8) {
   $$sroa$03$08$us = $4;
   while(1) {
    $10 = HEAP32[$$sroa$03$08$us>>2]|0;
    HEAP32[$2>>2] = 0;
    $11 = ((($10)) + 112|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ((($10)) + 116|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ($12|0)==($14|0);
    if ($15) {
     $17 = ((($10)) + 108|0);
     __THREW__ = 0;
     invoke_vii(3855,($17|0),($2|0));
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break L4;
     }
    } else {
     HEAP32[$12>>2] = 0;
     $16 = ((($12)) + 4|0);
     HEAP32[$11>>2] = $16;
    }
    $20 = HEAP32[$2>>2]|0;
    $21 = ($20|0)==(0|0);
    if (!($21)) {
     $22 = ((($20)) + 8|0);
     $23 = HEAP32[$22>>2]|0;HEAP32[$22>>2] = (($23-1)|0);
     $24 = ($23|0)==(1);
     if ($24) {
      __ZNK3osg10Referenced24signalObserversAndDeleteEbb($20,1,1);
     }
    }
    $25 = ((($$sroa$03$08$us)) + 4|0);
    $26 = HEAP32[$5>>2]|0;
    $27 = ($25|0)==($26|0);
    if ($27) {
     break;
    } else {
     $$sroa$03$08$us = $25;
    }
   }
   STACKTOP = sp;return;
  } else {
   $$sroa$03$08 = $4;
   while(1) {
    $28 = HEAP32[$$sroa$03$08>>2]|0;
    HEAP32[$2>>2] = $1;
    $29 = HEAP32[$9>>2]|0;HEAP32[$9>>2] = (($29+1)|0);
    $30 = ((($28)) + 112|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = ((($28)) + 116|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = ($31|0)==($33|0);
    if ($34) {
     $41 = ((($28)) + 108|0);
     __THREW__ = 0;
     invoke_vii(3855,($41|0),($2|0));
     $42 = __THREW__; __THREW__ = 0;
     $43 = $42&1;
     if ($43) {
      break L4;
     }
    } else {
     $35 = HEAP32[$2>>2]|0;
     HEAP32[$31>>2] = $35;
     $36 = ($35|0)==(0|0);
     if ($36) {
      $40 = $31;
     } else {
      $37 = ((($35)) + 8|0);
      $38 = HEAP32[$37>>2]|0;HEAP32[$37>>2] = (($38+1)|0);
      $$pre$i$i = HEAP32[$30>>2]|0;
      $40 = $$pre$i$i;
     }
     $39 = ((($40)) + 4|0);
     HEAP32[$30>>2] = $39;
    }
    $44 = HEAP32[$2>>2]|0;
    $45 = ($44|0)==(0|0);
    if (!($45)) {
     $46 = ((($44)) + 8|0);
     $47 = HEAP32[$46>>2]|0;HEAP32[$46>>2] = (($47-1)|0);
     $48 = ($47|0)==(1);
     if ($48) {
      __ZNK3osg10Referenced24signalObserversAndDeleteEbb($44,1,1);
     }
    }
    $60 = ((($$sroa$03$08)) + 4|0);
    $61 = HEAP32[$5>>2]|0;
    $62 = ($60|0)==($61|0);
    if ($62) {
     break;
    } else {
     $$sroa$03$08 = $60;
    }
   }
   STACKTOP = sp;return;
  }
 } while(0);
 $49 = ___cxa_find_matching_catch_2()|0;
 $50 = tempRet0;
 $51 = HEAP32[$2>>2]|0;
 $52 = ($51|0)==(0|0);
 if ($52) {
  ___resumeException($49|0);
  // unreachable;
 }
 $53 = ((($51)) + 8|0);
 $54 = HEAP32[$53>>2]|0;HEAP32[$53>>2] = (($54-1)|0);
 $55 = ($54|0)==(1);
 if (!($55)) {
  ___resumeException($49|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(3262,($51|0),1,1);
 $56 = __THREW__; __THREW__ = 0;
 $57 = $56&1;
 if ($57) {
  $58 = ___cxa_find_matching_catch_3(0|0)|0;
  $59 = tempRet0;
  ___clang_call_terminate($58);
  // unreachable;
 } else {
  ___resumeException($49|0);
  // unreachable;
 }
}
function __ZN3osg7ProgramC2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 __ZN3osg14StateAttributeC2Ev($0);
 HEAP32[$0>>2] = (65068);
 $2 = ((($0)) + 56|0);
 __THREW__ = 0;
 $3 = (invoke_i(3285)|0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 do {
  if ($5) {
   label = 13;
  } else {
   $6 = HEAP32[$3>>2]|0;
   __THREW__ = 0;
   $7 = (invoke_ii(3286,($6|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if ($9) {
    label = 13;
   } else {
    HEAP32[$1>>2] = 0;
    __THREW__ = 0;
    invoke_viii(3868,($2|0),($7|0),($1|0));
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     $12 = HEAP32[$1>>2]|0;
     $13 = ($12|0)==(0|0);
     if (!($13)) {
      $14 = ((($12)) + 8|0);
      $15 = HEAP32[$14>>2]|0;HEAP32[$14>>2] = (($15-1)|0);
      $16 = ($15|0)==(1);
      if ($16) {
       __THREW__ = 0;
       invoke_viii(3262,($12|0),1,1);
       $17 = __THREW__; __THREW__ = 0;
       $18 = $17&1;
       if ($18) {
        label = 13;
        break;
       }
      }
     }
     $30 = ((($0)) + 72|0);
     HEAP32[$30>>2] = 0;
     $31 = ((($0)) + 76|0);
     HEAP32[$31>>2] = 0;
     $32 = ((($0)) + 72|0);
     $33 = ((($0)) + 68|0);
     HEAP32[$33>>2] = $32;
     $34 = ((($0)) + 84|0);
     HEAP32[$34>>2] = 0;
     $35 = ((($0)) + 88|0);
     HEAP32[$35>>2] = 0;
     $36 = ((($0)) + 84|0);
     $37 = ((($0)) + 80|0);
     HEAP32[$37>>2] = $36;
     $38 = ((($0)) + 96|0);
     HEAP32[$38>>2] = 0;
     $39 = ((($0)) + 100|0);
     HEAP32[$39>>2] = 0;
     $40 = ((($0)) + 96|0);
     $41 = ((($0)) + 92|0);
     HEAP32[$41>>2] = $40;
     $42 = ((($0)) + 104|0);
     $43 = ((($0)) + 120|0);
     ;HEAP32[$42>>2]=0|0;HEAP32[$42+4>>2]=0|0;HEAP32[$42+8>>2]=0|0;HEAP32[$42+12>>2]=0|0;
     HEAP32[$43>>2] = 1;
     $44 = ((($0)) + 124|0);
     HEAP32[$44>>2] = 4;
     $45 = ((($0)) + 128|0);
     HEAP32[$45>>2] = 5;
     $46 = ((($0)) + 132|0);
     HEAP32[$46>>2] = 0;
     $47 = ((($0)) + 136|0);
     HEAP32[$47>>2] = 0;
     $48 = ((($0)) + 140|0);
     HEAP32[$48>>2] = 0;
     $49 = ((($0)) + 144|0);
     HEAP32[$49>>2] = 35981;
     $50 = ((($0)) + 148|0);
     HEAP32[$50>>2] = 0;
     $51 = ((($0)) + 152|0);
     HEAP32[$51>>2] = 0;
     $52 = ((($0)) + 156|0);
     HEAP32[$52>>2] = 0;
     $53 = ((($0)) + 164|0);
     HEAP32[$53>>2] = 0;
     $54 = ((($0)) + 168|0);
     HEAP32[$54>>2] = 0;
     $55 = ((($0)) + 164|0);
     $56 = ((($0)) + 160|0);
     HEAP32[$56>>2] = $55;
     STACKTOP = sp;return;
    }
    $19 = ___cxa_find_matching_catch_2()|0;
    $20 = tempRet0;
    $21 = HEAP32[$1>>2]|0;
    $22 = ($21|0)==(0|0);
    if (!($22)) {
     $23 = ((($21)) + 8|0);
     $24 = HEAP32[$23>>2]|0;HEAP32[$23>>2] = (($24-1)|0);
     $25 = ($24|0)==(1);
     if ($25) {
      __THREW__ = 0;
      invoke_viii(3262,($21|0),1,1);
      $26 = __THREW__; __THREW__ = 0;
      $27 = $26&1;
      if ($27) {
       $28 = ___cxa_find_matching_catch_3(0|0)|0;
       $29 = tempRet0;
       ___clang_call_terminate($28);
       // unreachable;
      }
     }
    }
    $eh$lpad$body$index2Z2D = $20;$eh$lpad$body$indexZ2D = $19;
   }
  }
 } while(0);
 if ((label|0) == 13) {
  $57 = ___cxa_find_matching_catch_2()|0;
  $58 = tempRet0;
  $eh$lpad$body$index2Z2D = $58;$eh$lpad$body$indexZ2D = $57;
 }
 __THREW__ = 0;
 invoke_vi(1573,($0|0));
 $59 = __THREW__; __THREW__ = 0;
 $60 = $59&1;
 if ($60) {
  $61 = ___cxa_find_matching_catch_3(0|0)|0;
  $62 = tempRet0;
  ___clang_call_terminate($61);
  // unreachable;
 } else {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
}
function __ZN3osg7Program21addBindAttribLocationERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEj($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 68|0);
 $4 = (__ZNSt3__23mapINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEjNS_4lessIS6_EENS4_INS_4pairIKS6_jEEEEEixERSA_($3,$1)|0);
 HEAP32[$4>>2] = $2;
 __ZN3osg7Program12dirtyProgramEv($0);
 return;
}
function __ZNK3osg7Program15isFixedFunctionEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEjEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE4findIS7_EENS_15__tree_iteratorIS8_PNS_11__tree_nodeIS8_PvEEiEERKT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$ph$lcssa$i = 0, $$0$ph15$i = 0, $$07$ph14$i = 0, $$0711$i = 0, $$sroa$0$0 = 0, $$sroa$speculated$i$i$i$i$i = 0, $$sroa$speculated$i$i$i$i$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 do {
  if (!($4)) {
   $5 = ((($1)) + 11|0);
   $6 = HEAP8[$5>>0]|0;
   $7 = ($6<<24>>24)<(0);
   $8 = ((($1)) + 4|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = $6&255;
   $11 = $7 ? $9 : $10;
   $12 = HEAP32[$1>>2]|0;
   $13 = $7 ? $12 : $1;
   $$0$ph15$i = $2;$$07$ph14$i = $3;
   L3: while(1) {
    $$0711$i = $$07$ph14$i;
    while(1) {
     $14 = ((($$0711$i)) + 16|0);
     $15 = ((($14)) + 11|0);
     $16 = HEAP8[$15>>0]|0;
     $17 = ($16<<24>>24)<(0);
     $18 = ((($$0711$i)) + 20|0);
     $19 = HEAP32[$18>>2]|0;
     $20 = $16&255;
     $21 = $17 ? $19 : $20;
     $22 = ($11>>>0)<($21>>>0);
     $$sroa$speculated$i$i$i$i$i$i = $22 ? $11 : $21;
     $23 = ($$sroa$speculated$i$i$i$i$i$i|0)==(0);
     if ($23) {
      label = 6;
     } else {
      $24 = HEAP32[$14>>2]|0;
      $25 = $17 ? $24 : $14;
      $26 = (_memcmp($25,$13,$$sroa$speculated$i$i$i$i$i$i)|0);
      $27 = ($26|0)==(0);
      if ($27) {
       label = 6;
      } else {
       $29 = ($26|0)<(0);
       if (!($29)) {
        break;
       }
      }
     }
     if ((label|0) == 6) {
      label = 0;
      $28 = ($21>>>0)<($11>>>0);
      if (!($28)) {
       break;
      }
     }
     $32 = ((($$0711$i)) + 4|0);
     $33 = HEAP32[$32>>2]|0;
     $34 = ($33|0)==(0|0);
     if ($34) {
      $$0$ph$lcssa$i = $$0$ph15$i;
      break L3;
     } else {
      $$0711$i = $33;
     }
    }
    $30 = HEAP32[$$0711$i>>2]|0;
    $31 = ($30|0)==(0|0);
    if ($31) {
     $$0$ph$lcssa$i = $$0711$i;
     break;
    } else {
     $$0$ph15$i = $$0711$i;$$07$ph14$i = $30;
    }
   }
   $35 = ($$0$ph$lcssa$i|0)==($2|0);
   if (!($35)) {
    $36 = ((($$0$ph$lcssa$i)) + 16|0);
    $37 = ((($36)) + 11|0);
    $38 = HEAP8[$37>>0]|0;
    $39 = ($38<<24>>24)<(0);
    $40 = ((($$0$ph$lcssa$i)) + 20|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = $38&255;
    $43 = $39 ? $41 : $42;
    $44 = ($43>>>0)<($11>>>0);
    $$sroa$speculated$i$i$i$i$i = $44 ? $43 : $11;
    $45 = ($$sroa$speculated$i$i$i$i$i|0)==(0);
    if (!($45)) {
     $46 = HEAP32[$36>>2]|0;
     $47 = $39 ? $46 : $36;
     $48 = (_memcmp($13,$47,$$sroa$speculated$i$i$i$i$i)|0);
     $49 = ($48|0)==(0);
     if (!($49)) {
      $51 = ($48|0)<(0);
      if ($51) {
       break;
      } else {
       $$sroa$0$0 = $$0$ph$lcssa$i;
      }
      return ($$sroa$0$0|0);
     }
    }
    $50 = ($11>>>0)<($43>>>0);
    if (!($50)) {
     $$sroa$0$0 = $$0$ph$lcssa$i;
     return ($$sroa$0$0|0);
    }
   }
  }
 } while(0);
 $$sroa$0$0 = $2;
 return ($$sroa$0$0|0);
}
function __ZN3osg4Quat10makeRotateEdddd($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = +$1;
 $2 = +$2;
 $3 = +$3;
 $4 = +$4;
 var $$sink = 0.0, $$sink44 = 0.0, $$sink46 = 0.0, $$sink47 = 0.0, $10 = 0.0, $11 = 0, $12 = 0.0, $13 = 0.0, $14 = 0.0, $15 = 0.0, $16 = 0.0, $17 = 0.0, $18 = 0.0, $19 = 0.0, $20 = 0.0, $21 = 0.0, $22 = 0, $23 = 0, $24 = 0, $5 = 0.0;
 var $6 = 0.0, $7 = 0.0, $8 = 0.0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = $2 * $2;
 $6 = $3 * $3;
 $7 = $5 + $6;
 $8 = $4 * $4;
 $9 = $7 + $8;
 $10 = (+Math_sqrt((+$9)));
 $11 = $10 < 9.9999999999999995E-8;
 if ($11) {
  $$sink = 1.0;$$sink44 = 0.0;$$sink46 = 0.0;$$sink47 = 0.0;
 } else {
  $12 = 1.0 / $10;
  $13 = $1 * 0.5;
  $14 = (+Math_cos((+$13)));
  $15 = (+Math_sin((+$13)));
  $16 = $15 * $2;
  $17 = $12 * $16;
  $18 = $15 * $3;
  $19 = $12 * $18;
  $20 = $15 * $4;
  $21 = $12 * $20;
  $$sink = $14;$$sink44 = $21;$$sink46 = $19;$$sink47 = $17;
 }
 HEAPF64[$0>>3] = $$sink47;
 $22 = ((($0)) + 8|0);
 HEAPF64[$22>>3] = $$sink46;
 $23 = ((($0)) + 16|0);
 HEAPF64[$23>>3] = $$sink44;
 $24 = ((($0)) + 24|0);
 HEAPF64[$24>>3] = $$sink;
 return;
}
function __ZN3osg4Quat10makeRotateEdRKNS_5Vec3fE($0,$1,$2) {
 $0 = $0|0;
 $1 = +$1;
 $2 = $2|0;
 var $$sink$i = 0.0, $$sink44$i = 0.0, $$sink46$i = 0.0, $$sink47$i = 0.0, $10 = 0.0, $11 = 0.0, $12 = 0.0, $13 = 0.0, $14 = 0.0, $15 = 0.0, $16 = 0.0, $17 = 0, $18 = 0.0, $19 = 0.0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0.0, $25 = 0.0;
 var $26 = 0.0, $27 = 0.0, $28 = 0, $29 = 0, $3 = 0.0, $30 = 0, $4 = 0.0, $5 = 0, $6 = 0.0, $7 = 0.0, $8 = 0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = +HEAPF32[$2>>2];
 $4 = $3;
 $5 = ((($2)) + 4|0);
 $6 = +HEAPF32[$5>>2];
 $7 = $6;
 $8 = ((($2)) + 8|0);
 $9 = +HEAPF32[$8>>2];
 $10 = $9;
 $11 = $4 * $4;
 $12 = $7 * $7;
 $13 = $11 + $12;
 $14 = $10 * $10;
 $15 = $13 + $14;
 $16 = (+Math_sqrt((+$15)));
 $17 = $16 < 9.9999999999999995E-8;
 if ($17) {
  $$sink$i = 1.0;$$sink44$i = 0.0;$$sink46$i = 0.0;$$sink47$i = 0.0;
 } else {
  $18 = 1.0 / $16;
  $19 = $1 * 0.5;
  $20 = (+Math_cos((+$19)));
  $21 = (+Math_sin((+$19)));
  $22 = $4 * $21;
  $23 = $18 * $22;
  $24 = $7 * $21;
  $25 = $18 * $24;
  $26 = $10 * $21;
  $27 = $18 * $26;
  $$sink$i = $20;$$sink44$i = $27;$$sink46$i = $25;$$sink47$i = $23;
 }
 HEAPF64[$0>>3] = $$sink47$i;
 $28 = ((($0)) + 8|0);
 HEAPF64[$28>>3] = $$sink46$i;
 $29 = ((($0)) + 16|0);
 HEAPF64[$29>>3] = $$sink44$i;
 $30 = ((($0)) + 24|0);
 HEAPF64[$30>>3] = $$sink$i;
 return;
}
function __ZN3osg4Quat10makeRotateEdRKNS_5Vec3dE($0,$1,$2) {
 $0 = $0|0;
 $1 = +$1;
 $2 = $2|0;
 var $$sink$i = 0.0, $$sink44$i = 0.0, $$sink46$i = 0.0, $$sink47$i = 0.0, $10 = 0.0, $11 = 0.0, $12 = 0.0, $13 = 0.0, $14 = 0, $15 = 0.0, $16 = 0.0, $17 = 0.0, $18 = 0.0, $19 = 0.0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0.0, $25 = 0;
 var $26 = 0, $27 = 0, $3 = 0.0, $4 = 0, $5 = 0.0, $6 = 0, $7 = 0.0, $8 = 0.0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = +HEAPF64[$2>>3];
 $4 = ((($2)) + 8|0);
 $5 = +HEAPF64[$4>>3];
 $6 = ((($2)) + 16|0);
 $7 = +HEAPF64[$6>>3];
 $8 = $3 * $3;
 $9 = $5 * $5;
 $10 = $8 + $9;
 $11 = $7 * $7;
 $12 = $10 + $11;
 $13 = (+Math_sqrt((+$12)));
 $14 = $13 < 9.9999999999999995E-8;
 if ($14) {
  $$sink$i = 1.0;$$sink44$i = 0.0;$$sink46$i = 0.0;$$sink47$i = 0.0;
 } else {
  $15 = 1.0 / $13;
  $16 = $1 * 0.5;
  $17 = (+Math_cos((+$16)));
  $18 = (+Math_sin((+$16)));
  $19 = $3 * $18;
  $20 = $15 * $19;
  $21 = $5 * $18;
  $22 = $15 * $21;
  $23 = $7 * $18;
  $24 = $15 * $23;
  $$sink$i = $17;$$sink44$i = $24;$$sink46$i = $22;$$sink47$i = $20;
 }
 HEAPF64[$0>>3] = $$sink47$i;
 $25 = ((($0)) + 8|0);
 HEAPF64[$25>>3] = $$sink46$i;
 $26 = ((($0)) + 16|0);
 HEAPF64[$26>>3] = $$sink44$i;
 $27 = ((($0)) + 24|0);
 HEAPF64[$27>>3] = $$sink$i;
 return;
}
function __ZN3osg4Quat10makeRotateERKNS_5Vec3dES3_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0.0, $$048 = 0.0, $$sink = 0.0, $$sink99 = 0.0, $$sroa$060$0 = 0.0, $$sroa$060$0$copyload = 0.0, $$sroa$072$0 = 0.0, $$sroa$072$0$copyload = 0.0, $$sroa$11$0 = 0.0, $$sroa$11$0$$sroa_idx68 = 0, $$sroa$11$0$copyload = 0.0, $$sroa$12$0 = 0.0, $$sroa$12$0$$sroa_idx81 = 0, $$sroa$12$0$copyload = 0.0, $$sroa$21$0 = 0.0, $$sroa$21$0$$sroa_idx90 = 0, $$sroa$21$0$copyload = 0.0, $$sroa$7$0 = 0.0, $$sroa$7$0$$sroa_idx64 = 0, $$sroa$7$0$copyload = 0.0;
 var $10 = 0.0, $11 = 0.0, $12 = 0.0, $13 = 0.0, $14 = 0.0, $15 = 0.0, $16 = 0.0, $17 = 0.0, $18 = 0.0, $19 = 0, $20 = 0, $21 = 0.0, $22 = 0, $23 = 0.0, $24 = 0, $25 = 0.0, $26 = 0.0, $27 = 0.0, $28 = 0.0, $29 = 0.0;
 var $3 = 0.0, $30 = 0.0, $31 = 0.0, $32 = 0.0, $33 = 0.0, $34 = 0.0, $35 = 0, $36 = 0.0, $37 = 0, $38 = 0.0, $39 = 0.0, $4 = 0.0, $40 = 0.0, $41 = 0.0, $42 = 0, $43 = 0.0, $44 = 0.0, $45 = 0.0, $46 = 0, $47 = 0.0;
 var $48 = 0.0, $49 = 0.0, $5 = 0.0, $50 = 0.0, $51 = 0.0, $52 = 0, $53 = 0.0, $54 = 0.0, $55 = 0.0, $56 = 0.0, $57 = 0.0, $58 = 0.0, $59 = 0.0, $6 = 0.0, $60 = 0, $61 = 0.0, $62 = 0.0, $63 = 0.0, $64 = 0.0, $65 = 0.0;
 var $66 = 0.0, $67 = 0.0, $68 = 0.0, $69 = 0.0, $7 = 0.0, $70 = 0.0, $71 = 0.0, $72 = 0.0, $73 = 0.0, $74 = 0.0, $75 = 0.0, $76 = 0, $77 = 0, $78 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond3 = 0, $or$cond50 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $$sroa$072$0$copyload = +HEAPF64[$1>>3];
 $$sroa$12$0$$sroa_idx81 = ((($1)) + 8|0);
 $$sroa$12$0$copyload = +HEAPF64[$$sroa$12$0$$sroa_idx81>>3];
 $$sroa$21$0$$sroa_idx90 = ((($1)) + 16|0);
 $$sroa$21$0$copyload = +HEAPF64[$$sroa$21$0$$sroa_idx90>>3];
 $$sroa$060$0$copyload = +HEAPF64[$2>>3];
 $$sroa$7$0$$sroa_idx64 = ((($2)) + 8|0);
 $$sroa$7$0$copyload = +HEAPF64[$$sroa$7$0$$sroa_idx64>>3];
 $$sroa$11$0$$sroa_idx68 = ((($2)) + 16|0);
 $$sroa$11$0$copyload = +HEAPF64[$$sroa$11$0$$sroa_idx68>>3];
 $3 = $$sroa$072$0$copyload * $$sroa$072$0$copyload;
 $4 = $$sroa$12$0$copyload * $$sroa$12$0$copyload;
 $5 = $3 + $4;
 $6 = $$sroa$21$0$copyload * $$sroa$21$0$copyload;
 $7 = $5 + $6;
 $8 = $7 < 0.99999990000000005;
 $9 = $7 > 1.0000001000000001;
 $or$cond = $8 | $9;
 if ($or$cond) {
  $10 = (+Math_sqrt((+$7)));
  $11 = $$sroa$072$0$copyload / $10;
  $12 = $$sroa$12$0$copyload / $10;
  $13 = $$sroa$21$0$copyload / $10;
  $$0 = $10;$$sroa$072$0 = $11;$$sroa$12$0 = $12;$$sroa$21$0 = $13;
 } else {
  $$0 = 1.0;$$sroa$072$0 = $$sroa$072$0$copyload;$$sroa$12$0 = $$sroa$12$0$copyload;$$sroa$21$0 = $$sroa$21$0$copyload;
 }
 $14 = $$sroa$060$0$copyload * $$sroa$060$0$copyload;
 $15 = $$sroa$7$0$copyload * $$sroa$7$0$copyload;
 $16 = $14 + $15;
 $17 = $$sroa$11$0$copyload * $$sroa$11$0$copyload;
 $18 = $16 + $17;
 $19 = $18 < 0.99999990000000005;
 $20 = $18 > 1.0000001000000001;
 $or$cond3 = $19 | $20;
 if ($or$cond3) {
  $21 = $7 + -9.9999999999999995E-8;
  $22 = $18 > $21;
  $23 = $7 + 9.9999999999999995E-8;
  $24 = $18 < $23;
  $or$cond50 = $22 & $24;
  if ($or$cond50) {
   $$048 = $$0;
  } else {
   $25 = (+Math_sqrt((+$18)));
   $$048 = $25;
  }
  $26 = $$sroa$060$0$copyload / $$048;
  $27 = $$sroa$7$0$copyload / $$048;
  $28 = $$sroa$11$0$copyload / $$048;
  $$sroa$060$0 = $26;$$sroa$11$0 = $28;$$sroa$7$0 = $27;
 } else {
  $$sroa$060$0 = $$sroa$060$0$copyload;$$sroa$11$0 = $$sroa$11$0$copyload;$$sroa$7$0 = $$sroa$7$0$copyload;
 }
 $29 = $$sroa$072$0 * $$sroa$060$0;
 $30 = $$sroa$12$0 * $$sroa$7$0;
 $31 = $29 + $30;
 $32 = $$sroa$21$0 * $$sroa$11$0;
 $33 = $31 + $32;
 $34 = $33 + 1.0;
 $35 = $34 < 9.9999999999999995E-8;
 if (!($35)) {
  $61 = $34 * 0.5;
  $62 = (+Math_sqrt((+$61)));
  $63 = $62 * 2.0;
  $64 = $$sroa$060$0 / $63;
  $65 = $$sroa$7$0 / $63;
  $66 = $$sroa$11$0 / $63;
  $67 = $$sroa$12$0 * $66;
  $68 = $$sroa$21$0 * $65;
  $69 = $67 - $68;
  $70 = $$sroa$21$0 * $64;
  $71 = $$sroa$072$0 * $66;
  $72 = $70 - $71;
  $73 = $$sroa$072$0 * $65;
  $74 = $$sroa$12$0 * $64;
  $75 = $73 - $74;
  HEAPF64[$0>>3] = $69;
  $76 = ((($0)) + 8|0);
  HEAPF64[$76>>3] = $72;
  $$sink = $62;$$sink99 = $75;
  $77 = ((($0)) + 16|0);
  HEAPF64[$77>>3] = $$sink99;
  $78 = ((($0)) + 24|0);
  HEAPF64[$78>>3] = $$sink;
  return;
 }
 $36 = (+Math_abs((+$$sroa$072$0)));
 $37 = $36 < 0.59999999999999998;
 if ($37) {
  $38 = $$sroa$072$0 * $$sroa$072$0;
  $39 = 1.0 - $38;
  $40 = (+Math_sqrt((+$39)));
  HEAPF64[$0>>3] = 0.0;
  $41 = $$sroa$21$0 / $40;
  $42 = ((($0)) + 8|0);
  HEAPF64[$42>>3] = $41;
  $43 = -$$sroa$12$0;
  $44 = $43 / $40;
  $$sink = 0.0;$$sink99 = $44;
  $77 = ((($0)) + 16|0);
  HEAPF64[$77>>3] = $$sink99;
  $78 = ((($0)) + 24|0);
  HEAPF64[$78>>3] = $$sink;
  return;
 }
 $45 = (+Math_abs((+$$sroa$12$0)));
 $46 = $45 < 0.59999999999999998;
 if ($46) {
  $47 = $$sroa$12$0 * $$sroa$12$0;
  $48 = 1.0 - $47;
  $49 = (+Math_sqrt((+$48)));
  $50 = -$$sroa$21$0;
  $51 = $50 / $49;
  HEAPF64[$0>>3] = $51;
  $52 = ((($0)) + 8|0);
  HEAPF64[$52>>3] = 0.0;
  $53 = $$sroa$072$0 / $49;
  $$sink = 0.0;$$sink99 = $53;
  $77 = ((($0)) + 16|0);
  HEAPF64[$77>>3] = $$sink99;
  $78 = ((($0)) + 24|0);
  HEAPF64[$78>>3] = $$sink;
  return;
 } else {
  $54 = $$sroa$21$0 * $$sroa$21$0;
  $55 = 1.0 - $54;
  $56 = (+Math_sqrt((+$55)));
  $57 = $$sroa$12$0 / $56;
  HEAPF64[$0>>3] = $57;
  $58 = -$$sroa$072$0;
  $59 = $58 / $56;
  $60 = ((($0)) + 8|0);
  HEAPF64[$60>>3] = $59;
  $$sink = 0.0;$$sink99 = 0.0;
  $77 = ((($0)) + 16|0);
  HEAPF64[$77>>3] = $$sink99;
  $78 = ((($0)) + 24|0);
  HEAPF64[$78>>3] = $$sink;
  return;
 }
}
function __ZN3osg10ReferencedD2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index3Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp + 4|0;
 $2 = sp;
 HEAP32[$0>>2] = (65528);
 /* fence */;
 $3 = ((($0)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 L1: do {
  if ($5) {
   label = 36;
  } else {
   __THREW__ = 0;
   $6 = (invoke_ii(3265,2)|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    do {
     if ($6) {
      __THREW__ = 0;
      $9 = (invoke_ii(3266,2)|0);
      $10 = __THREW__; __THREW__ = 0;
      $11 = $10&1;
      if ($11) {
       break L1;
      }
      __THREW__ = 0;
      $12 = (invoke_iiii(3267,($9|0),(147008|0),42)|0);
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if ($14) {
       break L1;
      }
      __THREW__ = 0;
      $15 = (invoke_iii(3275,($12|0),($0|0))|0);
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if ($17) {
       break L1;
      }
      __THREW__ = 0;
      $18 = (invoke_iiii(3267,($15|0),(147051|0),10)|0);
      $19 = __THREW__; __THREW__ = 0;
      $20 = $19&1;
      if ($20) {
       break L1;
      }
      __THREW__ = 0;
      $21 = (invoke_iiii(3267,($18|0),(147062|0),19)|0);
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if ($23) {
       break L1;
      }
      __THREW__ = 0;
      $24 = (invoke_iiii(3267,($21|0),(150128|0),1)|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if ($26) {
       break L1;
      }
      $27 = HEAP32[$24>>2]|0;
      $28 = ((($27)) + -12|0);
      $29 = HEAP32[$28>>2]|0;
      $30 = (($24) + ($29)|0);
      __THREW__ = 0;
      invoke_vii(3257,($1|0),($30|0));
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if ($32) {
       break L1;
      }
      __THREW__ = 0;
      $33 = (invoke_iii(3255,($1|0),(215188|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if (!($35)) {
       $36 = HEAP32[$33>>2]|0;
       $37 = ((($36)) + 28|0);
       $38 = HEAP32[$37>>2]|0;
       __THREW__ = 0;
       $39 = (invoke_iii($38|0,($33|0),10)|0);
       $40 = __THREW__; __THREW__ = 0;
       $41 = $40&1;
       if (!($41)) {
        __THREW__ = 0;
        invoke_vi(3263,($1|0));
        $42 = __THREW__; __THREW__ = 0;
        $43 = $42&1;
        if ($43) {
         break L1;
        }
        __THREW__ = 0;
        (invoke_iii(3268,($24|0),($39|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         break L1;
        }
        __THREW__ = 0;
        (invoke_ii(3269,($24|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         break L1;
        } else {
         break;
        }
       }
      }
      $44 = ___cxa_find_matching_catch_2()|0;
      $45 = tempRet0;
      __THREW__ = 0;
      invoke_vi(3263,($1|0));
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       $48 = ___cxa_find_matching_catch_3(0|0)|0;
       $49 = tempRet0;
       ___clang_call_terminate($48);
       // unreachable;
      }
      $eh$lpad$body$index3Z2D = $45;$eh$lpad$body$indexZ2D = $44;
      $56 = ((($0)) + 4|0);
      HEAP32[$56>>2] = 0;
      ___resumeException($eh$lpad$body$indexZ2D|0);
      // unreachable;
     }
    } while(0);
    __THREW__ = 0;
    $57 = (invoke_ii(3265,2)|0);
    $58 = __THREW__; __THREW__ = 0;
    $59 = $58&1;
    if (!($59)) {
     if ($57) {
      __THREW__ = 0;
      $60 = (invoke_ii(3266,2)|0);
      $61 = __THREW__; __THREW__ = 0;
      $62 = $61&1;
      if (!($62)) {
       __THREW__ = 0;
       $63 = (invoke_iiii(3267,($60|0),(147082|0),39)|0);
       $64 = __THREW__; __THREW__ = 0;
       $65 = $64&1;
       if (!($65)) {
        /* fence */;
        $66 = HEAP32[$3>>2]|0;
        __THREW__ = 0;
        $67 = (invoke_iii(3417,($63|0),($66|0))|0);
        $68 = __THREW__; __THREW__ = 0;
        $69 = $68&1;
        if (!($69)) {
         __THREW__ = 0;
         $70 = (invoke_iiii(3267,($67|0),(147122|0),29)|0);
         $71 = __THREW__; __THREW__ = 0;
         $72 = $71&1;
         if (!($72)) {
          $73 = HEAP32[$70>>2]|0;
          $74 = ((($73)) + -12|0);
          $75 = HEAP32[$74>>2]|0;
          $76 = (($70) + ($75)|0);
          __THREW__ = 0;
          invoke_vii(3257,($2|0),($76|0));
          $77 = __THREW__; __THREW__ = 0;
          $78 = $77&1;
          if (!($78)) {
           __THREW__ = 0;
           $79 = (invoke_iii(3255,($2|0),(215188|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            $82 = HEAP32[$79>>2]|0;
            $83 = ((($82)) + 28|0);
            $84 = HEAP32[$83>>2]|0;
            __THREW__ = 0;
            $85 = (invoke_iii($84|0,($79|0),10)|0);
            $86 = __THREW__; __THREW__ = 0;
            $87 = $86&1;
            if (!($87)) {
             __THREW__ = 0;
             invoke_vi(3263,($2|0));
             $88 = __THREW__; __THREW__ = 0;
             $89 = $88&1;
             if ($89) {
              break;
             }
             __THREW__ = 0;
             (invoke_iii(3268,($70|0),($85|0))|0);
             $96 = __THREW__; __THREW__ = 0;
             $97 = $96&1;
             if ($97) {
              break;
             }
             __THREW__ = 0;
             (invoke_ii(3269,($70|0))|0);
             $98 = __THREW__; __THREW__ = 0;
             $99 = $98&1;
             if ($99) {
              break;
             } else {
              label = 36;
              break;
             }
            }
           }
           $90 = ___cxa_find_matching_catch_2()|0;
           $91 = tempRet0;
           __THREW__ = 0;
           invoke_vi(3263,($2|0));
           $92 = __THREW__; __THREW__ = 0;
           $93 = $92&1;
           if ($93) {
            $94 = ___cxa_find_matching_catch_3(0|0)|0;
            $95 = tempRet0;
            ___clang_call_terminate($94);
            // unreachable;
           }
           $eh$lpad$body$index3Z2D = $91;$eh$lpad$body$indexZ2D = $90;
           $56 = ((($0)) + 4|0);
           HEAP32[$56>>2] = 0;
           ___resumeException($eh$lpad$body$indexZ2D|0);
           // unreachable;
          }
         }
        }
       }
      }
     } else {
      label = 36;
     }
    }
   }
  }
 } while(0);
 do {
  if ((label|0) == 36) {
   /* fence */;
   $100 = ((($0)) + 4|0);
   $101 = HEAP32[$100>>2]|0;
   $102 = ($101|0)==(0|0);
   if (!($102)) {
    __THREW__ = 0;
    invoke_vii(3873,($101|0),($0|0));
    $103 = __THREW__; __THREW__ = 0;
    $104 = $103&1;
    if ($104) {
     break;
    }
   }
   /* fence */;
   $105 = HEAP32[$100>>2]|0;
   $106 = ($105|0)==(0|0);
   if ($106) {
    HEAP32[$100>>2] = 0;
    STACKTOP = sp;return;
   }
   /* fence */;
   $107 = HEAP32[$100>>2]|0;
   $108 = ((($107)) + 8|0);
   $109 = HEAP32[$108>>2]|0;HEAP32[$108>>2] = (($109-1)|0);
   $110 = ($109|0)==(1);
   if (!($110)) {
    HEAP32[$100>>2] = 0;
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   invoke_viii(3262,($107|0),1,1);
   $111 = __THREW__; __THREW__ = 0;
   $112 = $111&1;
   if (!($112)) {
    HEAP32[$100>>2] = 0;
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $54 = ___cxa_find_matching_catch_2()|0;
 $55 = tempRet0;
 $eh$lpad$body$index3Z2D = $55;$eh$lpad$body$indexZ2D = $54;
 $56 = ((($0)) + 4|0);
 HEAP32[$56>>2] = 0;
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
}
function __ZN3osg10ReferencedD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK3osg10Referenced24signalObserversAndDeleteEbb($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$not = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $brmerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 /* fence */;
 $4 = ((($0)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 $$not = $1 ^ 1;
 $brmerge = $6 | $$not;
 if (!($brmerge)) {
  __ZN3osg11ObserverSet19signalObjectDeletedEPv($5,$0);
 }
 if (!($2)) {
  STACKTOP = sp;return;
 }
 /* fence */;
 $7 = ((($0)) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0);
 do {
  if (!($9)) {
   $10 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
   if ($10) {
    $11 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
    $12 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($11,147152,77)|0);
    /* fence */;
    $13 = HEAP32[$7>>2]|0;
    $14 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($12,$13)|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = ((($15)) + -12|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = (($14) + ($17)|0);
    __ZNKSt3__28ios_base6getlocEv($3,$18);
    __THREW__ = 0;
    $19 = (invoke_iii(3255,($3|0),(215188|0))|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if (!($21)) {
     $22 = HEAP32[$19>>2]|0;
     $23 = ((($22)) + 28|0);
     $24 = HEAP32[$23>>2]|0;
     __THREW__ = 0;
     $25 = (invoke_iii($24|0,($19|0),10)|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if (!($27)) {
      __ZNSt3__26localeD2Ev($3);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($14,$25)|0);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($14)|0);
      break;
     }
    }
    $28 = ___cxa_find_matching_catch_2()|0;
    $29 = tempRet0;
    __THREW__ = 0;
    invoke_vi(3263,($3|0));
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     $32 = ___cxa_find_matching_catch_3(0|0)|0;
     $33 = tempRet0;
     ___clang_call_terminate($32);
     // unreachable;
    } else {
     ___resumeException($28|0);
     // unreachable;
    }
   }
  }
 } while(0);
 $34 = HEAP32[52162]|0;
 $35 = ($34|0)==(0|0);
 if (!($35)) {
  $36 = HEAP32[$34>>2]|0;
  $37 = ((($36)) + 16|0);
  $38 = HEAP32[$37>>2]|0;
  FUNCTION_TABLE_vii[$38 & 8191]($34,$0);
  STACKTOP = sp;return;
 }
 $39 = ($0|0)==(0|0);
 if ($39) {
  STACKTOP = sp;return;
 }
 $40 = HEAP32[$0>>2]|0;
 $41 = ((($40)) + 8|0);
 $42 = HEAP32[$41>>2]|0;
 FUNCTION_TABLE_vi[$42 & 8191]($0);
 STACKTOP = sp;return;
}
function __GLOBAL__sub_I_Referenced_cpp() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN3osg10Referenced24getGlobalReferencedMutexEv()|0);
 HEAP32[52162] = 0;
 (___cxa_atexit((3874|0),(208648|0),(___dso_handle|0))|0);
 return;
}
function __ZN3osg10Referenced24getGlobalReferencedMutexEv() {
 var $$0 = 0, $$01 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[206080]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  $9 = HEAP32[52163]|0;
  return ($9|0);
 }
 $2 = (___cxa_guard_acquire(206080)|0);
 $3 = ($2|0)==(0);
 if ($3) {
  $9 = HEAP32[52163]|0;
  return ($9|0);
 }
 __THREW__ = 0;
 $4 = (invoke_ii(3276,12)|0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $10 = ___cxa_find_matching_catch_2()|0;
  $11 = tempRet0;
  $$0 = $11;$$01 = $10;
  ___resumeException($$01|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_vii(3507,($4|0),0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $12 = ___cxa_find_matching_catch_2()|0;
  $13 = tempRet0;
  __ZdlPv($4);
  $$0 = $13;$$01 = $12;
  ___resumeException($$01|0);
  // unreachable;
 } else {
  HEAP32[52163] = $4;
  (___cxa_atexit((3875|0),(208652|0),(___dso_handle|0))|0);
  $9 = HEAP32[52163]|0;
  return ($9|0);
 }
 return (0)|0;
}
function __ZN3osg12ResetPointerINS_13DeleteHandlerEED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  HEAP32[$0>>2] = 0;
  return;
 }
 $3 = HEAP32[$1>>2]|0;
 $4 = ((($3)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 FUNCTION_TABLE_vi[$5 & 8191]($1);
 HEAP32[$0>>2] = 0;
 return;
}
function __ZN3osg12ResetPointerIN11OpenThreads5MutexEED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  HEAP32[$0>>2] = 0;
  return;
 }
 $3 = HEAP32[$1>>2]|0;
 $4 = ((($3)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 FUNCTION_TABLE_vi[$5 & 8191]($1);
 HEAP32[$0>>2] = 0;
 return;
}
function __ZN3osg10Referenced16getDeleteHandlerEv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[52162]|0;
 return ($0|0);
}
function __ZN3osg10ReferencedC2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (65528);
 $1 = ((($0)) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = ((($0)) + 8|0);
 HEAP32[$2>>2] = 0;
 return;
}
function __ZN3osg10ReferencedC2Eb($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (65528);
 $2 = ((($0)) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = ((($0)) + 8|0);
 HEAP32[$3>>2] = 0;
 return;
}
function __ZNK3osg10Referenced22getOrCreateObserverSetEv($0) {
 $0 = $0|0;
 var $$lcssa11 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $success = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 4|0);
 /* fence */;
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $$lcssa11 = $2;
  return ($$lcssa11|0);
 }
 while(1) {
  $4 = (__Znwj(40)|0);
  __THREW__ = 0;
  invoke_vii(3876,($4|0),($0|0));
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if ($6) {
   label = 8;
   break;
  }
  $7 = ((($4)) + 8|0);
  $8 = HEAP32[$7>>2]|0;HEAP32[$7>>2] = (($8+1)|0);
  $9 = $4;
  $10 = HEAP32[$1>>2]|0;if (($10|0) == 0) HEAP32[$1>>2] = $9;
  $success = ($10|0)==(0);
  if (!($success)) {
   $13 = HEAP32[$7>>2]|0;HEAP32[$7>>2] = (($13-1)|0);
   $14 = ($13|0)==(1);
   if ($14) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($4,1,1);
   }
  }
  /* fence */;
  $11 = HEAP32[$1>>2]|0;
  $12 = ($11|0)==(0|0);
  if (!($12)) {
   $$lcssa11 = $11;
   label = 9;
   break;
  }
 }
 if ((label|0) == 8) {
  $15 = ___cxa_find_matching_catch_2()|0;
  $16 = tempRet0;
  __ZdlPv($4);
  ___resumeException($15|0);
  // unreachable;
 }
 else if ((label|0) == 9) {
  return ($$lcssa11|0);
 }
 return (0)|0;
}
function __ZNK3osg10Referenced11addObserverEPNS_8ObserverE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$lcssa11$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $success = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 /* fence */;
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $$lcssa11$i = $3;
  __ZN3osg11ObserverSet11addObserverEPNS_8ObserverE($$lcssa11$i,$1);
  return;
 }
 while(1) {
  $5 = (__Znwj(40)|0);
  __THREW__ = 0;
  invoke_vii(3876,($5|0),($0|0));
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if ($7) {
   label = 8;
   break;
  }
  $8 = ((($5)) + 8|0);
  $9 = HEAP32[$8>>2]|0;HEAP32[$8>>2] = (($9+1)|0);
  $10 = $5;
  $11 = HEAP32[$2>>2]|0;if (($11|0) == 0) HEAP32[$2>>2] = $10;
  $success = ($11|0)==(0);
  if (!($success)) {
   $14 = HEAP32[$8>>2]|0;HEAP32[$8>>2] = (($14-1)|0);
   $15 = ($14|0)==(1);
   if ($15) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($5,1,1);
   }
  }
  /* fence */;
  $12 = HEAP32[$2>>2]|0;
  $13 = ($12|0)==(0|0);
  if (!($13)) {
   $$lcssa11$i = $12;
   label = 9;
   break;
  }
 }
 if ((label|0) == 8) {
  $16 = ___cxa_find_matching_catch_2()|0;
  $17 = tempRet0;
  __ZdlPv($5);
  ___resumeException($16|0);
  // unreachable;
 }
 else if ((label|0) == 9) {
  __ZN3osg11ObserverSet11addObserverEPNS_8ObserverE($$lcssa11$i,$1);
  return;
 }
}
function __ZNK3osg10Referenced14removeObserverEPNS_8ObserverE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$lcssa11$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $success = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 /* fence */;
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $$lcssa11$i = $3;
  __ZN3osg11ObserverSet14removeObserverEPNS_8ObserverE($$lcssa11$i,$1);
  return;
 }
 while(1) {
  $5 = (__Znwj(40)|0);
  __THREW__ = 0;
  invoke_vii(3876,($5|0),($0|0));
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if ($7) {
   label = 8;
   break;
  }
  $8 = ((($5)) + 8|0);
  $9 = HEAP32[$8>>2]|0;HEAP32[$8>>2] = (($9+1)|0);
  $10 = $5;
  $11 = HEAP32[$2>>2]|0;if (($11|0) == 0) HEAP32[$2>>2] = $10;
  $success = ($11|0)==(0);
  if (!($success)) {
   $14 = HEAP32[$8>>2]|0;HEAP32[$8>>2] = (($14-1)|0);
   $15 = ($14|0)==(1);
   if ($15) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($5,1,1);
   }
  }
  /* fence */;
  $12 = HEAP32[$2>>2]|0;
  $13 = ($12|0)==(0|0);
  if (!($13)) {
   $$lcssa11$i = $12;
   label = 9;
   break;
  }
 }
 if ((label|0) == 8) {
  $16 = ___cxa_find_matching_catch_2()|0;
  $17 = tempRet0;
  __ZdlPv($5);
  ___resumeException($16|0);
  // unreachable;
 }
 else if ((label|0) == 9) {
  __ZN3osg11ObserverSet14removeObserverEPNS_8ObserverE($$lcssa11$i,$1);
  return;
 }
}
function __ZNK3osg10Referenced14unref_nodeleteEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 8|0);
 $2 = HEAP32[$1>>2]|0;HEAP32[$1>>2] = (($2-1)|0);
 $3 = (($2) + -1)|0;
 return ($3|0);
}
function __ZNK3osg6Shader6getPCSERNS_5StateE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$02026$i$i32 = 0, $$02125$i$i33 = 0, $$023 = 0, $$027$i$i31 = 0, $$1 = 0, $$122 = 0, $$124 = 0, $$pre$i = 0, $$sink16$i = 0, $$sink16$i$us = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $phitmp$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp + 12|0;
 $3 = sp;
 $4 = ((($0)) + 32|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(-1);
 if ($6) {
  $7 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
  if (!($7)) {
   $$124 = 0;
   STACKTOP = sp;return ($$124|0);
  }
  $8 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
  $9 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($8,147942,24)|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ((($10)) + -12|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($9) + ($12)|0);
  __ZNKSt3__28ios_base6getlocEv($2,$13);
  __THREW__ = 0;
  $14 = (invoke_iii(3255,($2|0),(215188|0))|0);
  $15 = __THREW__; __THREW__ = 0;
  $16 = $15&1;
  if (!($16)) {
   $17 = HEAP32[$14>>2]|0;
   $18 = ((($17)) + 28|0);
   $19 = HEAP32[$18>>2]|0;
   __THREW__ = 0;
   $20 = (invoke_iii($19|0,($14|0),10)|0);
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if (!($22)) {
    __ZNSt3__26localeD2Ev($2);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($9,$20)|0);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($9)|0);
    $$124 = 0;
    STACKTOP = sp;return ($$124|0);
   }
  }
  $23 = ___cxa_find_matching_catch_2()|0;
  $24 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3263,($2|0));
  $25 = __THREW__; __THREW__ = 0;
  $26 = $25&1;
  if ($26) {
   $27 = ___cxa_find_matching_catch_3(0|0)|0;
   $28 = tempRet0;
   ___clang_call_terminate($27);
   // unreachable;
  } else {
   ___resumeException($23|0);
   // unreachable;
  }
 }
 $29 = ((($0)) + 92|0);
 $30 = (__ZN3osg5State26supportsShaderRequirementsERKNSt3__23setINS1_12basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEENS1_4lessIS8_EENS6_IS8_EEEE($1,$29)|0);
 if (!($30)) {
  $$124 = 0;
  STACKTOP = sp;return ($$124|0);
 }
 $31 = ((($1)) + 124|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = ((($0)) + 116|0);
 $34 = (__ZN3osg14buffered_valueINS_7ref_ptrINS_6Shader13ShaderObjectsEEEEixEj($33,$32)|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = ($35|0)==(0|0);
 if ($36) {
  $37 = (__Znwj(32)|0);
  __THREW__ = 0;
  invoke_vi(3282,($37|0));
  $38 = __THREW__; __THREW__ = 0;
  $39 = $38&1;
  if ($39) {
   $54 = ___cxa_find_matching_catch_2()|0;
   $55 = tempRet0;
   __ZdlPv($37);
   $$1 = $55;$$122 = $54;
   ___resumeException($$122|0);
   // unreachable;
  }
  HEAP32[$37>>2] = (65548);
  $40 = ((($37)) + 12|0);
  HEAP32[$40>>2] = $32;
  $41 = ((($37)) + 16|0);
  HEAP32[$41>>2] = $0;
  $42 = ((($37)) + 20|0);
  HEAP32[$42>>2] = 0;
  $43 = ((($37)) + 24|0);
  HEAP32[$43>>2] = 0;
  $44 = ((($37)) + 28|0);
  HEAP32[$44>>2] = 0;
  $45 = (__ZN3osg14buffered_valueINS_7ref_ptrINS_6Shader13ShaderObjectsEEEEixEj($33,$32)|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = ($46|0)==($37|0);
  if (!($47)) {
   HEAP32[$45>>2] = $37;
   $48 = ((($37)) + 8|0);
   $49 = HEAP32[$48>>2]|0;HEAP32[$48>>2] = (($49+1)|0);
   $50 = ($46|0)==(0|0);
   if (!($50)) {
    $51 = ((($46)) + 8|0);
    $52 = HEAP32[$51>>2]|0;HEAP32[$51>>2] = (($52-1)|0);
    $53 = ($52|0)==(1);
    if ($53) {
     __ZNK3osg10Referenced24signalObserversAndDeleteEbb($46,1,1);
    }
   }
  }
 }
 $56 = ((($0)) + 80|0);
 __ZN3osg5State15getDefineStringERKNSt3__23setINS1_12basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEENS1_4lessIS8_EENS6_IS8_EEEE($3,$1,$56);
 __THREW__ = 0;
 $57 = (invoke_iii(3877,($33|0),($32|0))|0);
 $58 = __THREW__; __THREW__ = 0;
 $59 = $58&1;
 do {
  if (!($59)) {
   $60 = HEAP32[$57>>2]|0;
   $61 = ((($60)) + 20|0);
   $62 = HEAP32[$61>>2]|0;
   $63 = ((($60)) + 24|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = ($62|0)==($64|0);
   L30: do {
    if ($65) {
     label = 31;
    } else {
     $66 = ((($3)) + 11|0);
     $67 = HEAP8[$66>>0]|0;
     $68 = ($67<<24>>24)<(0);
     $69 = ((($3)) + 4|0);
     $70 = HEAP32[$69>>2]|0;
     $71 = $67&255;
     $72 = $68 ? $70 : $71;
     $73 = HEAP32[$3>>2]|0;
     $74 = $68 ? $73 : $3;
     $75 = ($72|0)==(0);
     if ($75) {
      $$sink16$i$us = $62;
      while(1) {
       $76 = HEAP32[$$sink16$i$us>>2]|0;
       $77 = ((($76)) + 24|0);
       $78 = ((($77)) + 11|0);
       $79 = HEAP8[$78>>0]|0;
       $80 = ($79<<24>>24)<(0);
       $81 = ((($76)) + 28|0);
       $82 = HEAP32[$81>>2]|0;
       $83 = $79&255;
       $84 = $80 ? $82 : $83;
       $85 = ($84|0)==(0);
       if ($85) {
        $$023 = $76;
        break L30;
       }
       $86 = ((($$sink16$i$us)) + 4|0);
       $87 = ($86|0)==($64|0);
       if ($87) {
        label = 31;
        break L30;
       } else {
        $$sink16$i$us = $86;
       }
      }
     } else {
      $$sink16$i = $62;
     }
     L36: while(1) {
      $88 = HEAP32[$$sink16$i>>2]|0;
      $89 = ((($88)) + 24|0);
      $90 = ((($89)) + 11|0);
      $91 = HEAP8[$90>>0]|0;
      $92 = ($91<<24>>24)<(0);
      $93 = ((($88)) + 28|0);
      $94 = HEAP32[$93>>2]|0;
      $95 = $91&255;
      $96 = $92 ? $94 : $95;
      $97 = ($96|0)==($72|0);
      do {
       if ($97) {
        $98 = HEAP32[$89>>2]|0;
        if ($92) {
         $109 = (_memcmp($98,$74,$72)|0);
         $phitmp$i$i = ($109|0)==(0);
         if ($phitmp$i$i) {
          $$023 = $88;
          break L30;
         } else {
          break;
         }
        }
        $99 = $98;
        $100 = $99&255;
        $101 = HEAP8[$74>>0]|0;
        $102 = ($100<<24>>24)==($101<<24>>24);
        if ($102) {
         $$02026$i$i32 = $89;$$02125$i$i33 = $95;$$027$i$i31 = $74;
         while(1) {
          $103 = (($$02125$i$i33) + -1)|0;
          $104 = ((($$02026$i$i32)) + 1|0);
          $105 = ($103|0)==(0);
          if ($105) {
           break L36;
          }
          $106 = ((($$027$i$i31)) + 1|0);
          $$pre$i = HEAP8[$104>>0]|0;
          $107 = HEAP8[$106>>0]|0;
          $108 = ($$pre$i<<24>>24)==($107<<24>>24);
          if ($108) {
           $$02026$i$i32 = $104;$$02125$i$i33 = $103;$$027$i$i31 = $106;
          } else {
           break;
          }
         }
        }
       }
      } while(0);
      $110 = ((($$sink16$i)) + 4|0);
      $111 = ($110|0)==($64|0);
      if ($111) {
       label = 31;
       break L30;
      } else {
       $$sink16$i = $110;
      }
     }
     $112 = ($88|0)==(0|0);
     if ($112) {
      label = 31;
     } else {
      $$023 = $88;
     }
    }
   } while(0);
   if ((label|0) == 31) {
    __THREW__ = 0;
    $113 = (invoke_iii(3878,($1|0),($29|0))|0);
    $114 = __THREW__; __THREW__ = 0;
    $115 = $114&1;
    if ($115) {
     break;
    }
    if ($113) {
     __THREW__ = 0;
     $116 = (invoke_iii(3877,($33|0),($32|0))|0);
     $117 = __THREW__; __THREW__ = 0;
     $118 = $117&1;
     if ($118) {
      break;
     }
     $119 = HEAP32[$116>>2]|0;
     __THREW__ = 0;
     $120 = (invoke_iii(3879,($119|0),($3|0))|0);
     $121 = __THREW__; __THREW__ = 0;
     $122 = $121&1;
     if ($122) {
      break;
     } else {
      $$023 = $120;
     }
    } else {
     $$023 = 0;
    }
   }
   $123 = ((($3)) + 11|0);
   $124 = HEAP8[$123>>0]|0;
   $125 = ($124<<24>>24)<(0);
   if ($125) {
    $126 = HEAP32[$3>>2]|0;
    __ZdlPv($126);
   }
   $$124 = $$023;
   STACKTOP = sp;return ($$124|0);
  }
 } while(0);
 $127 = ___cxa_find_matching_catch_2()|0;
 $128 = tempRet0;
 $129 = ((($3)) + 11|0);
 $130 = HEAP8[$129>>0]|0;
 $131 = ($130<<24>>24)<(0);
 if ($131) {
  $132 = HEAP32[$3>>2]|0;
  __ZdlPv($132);
 }
 $$1 = $128;$$122 = $127;
 ___resumeException($$122|0);
 // unreachable;
 return (0)|0;
}
function __ZN3osg6Shader16PerContextShader13compileShaderERNS_5StateE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$$i = 0, $$$i$i = 0, $$$i$i144 = 0, $$0$i = 0, $$0$i$i = 0, $$0$i$i137 = 0, $$0$i$i143 = 0, $$0$i117 = 0, $$0$i159 = 0, $$0$i176 = 0, $$0$i204 = 0, $$01112$i = 0, $$01112$i$i = 0, $$01112$i141 = 0, $$027$i = 0, $$03$i$i = 0, $$033102$i = 0, $$03393$i = 0, $$034100$i = 0, $$034101$i = 0;
 var $$063 = 0, $$068290 = 0, $$2 = 0, $$2$i = 0, $$229$i = 0, $$256 = 0, $$271 = 0, $$5 = 0, $$5$i = 0, $$5$i$sink = 0, $$532$i = 0, $$532$i$sink = 0, $$559 = 0, $$6 = 0, $$660 = 0, $$7 = 0, $$761 = 0, $$8 = 0, $$862 = 0, $$cast = 0;
 var $$phi$trans$insert = 0, $$pre = 0, $$pre$phi$iZ2D = 0, $$pre$phi319Z2D = 0, $$pre$phi323Z2D = 0, $$pre$phi327Z2D = 0, $$pre$phi331Z2D = 0, $$pre$phi335Z2D = 0, $$pre$phiZ2D = 0, $$pre311 = 0, $$pre312 = 0, $$pre313 = 0, $$pre315 = 0, $$pre316 = 0, $$pre317 = 0, $$pre318 = 0, $$pre322 = 0, $$pre326 = 0, $$pre330 = 0, $$pre334 = 0;
 var $$sink74$sink75$index = 0, $$sink74$sink75$index8 = 0, $10 = 0, $100 = 0, $1000 = 0, $1001 = 0, $1002 = 0, $1003 = 0, $1004 = 0, $1005 = 0, $1006 = 0, $1007 = 0, $1008 = 0, $1009 = 0, $101 = 0, $1010 = 0, $1011 = 0, $1012 = 0, $1013 = 0, $1014 = 0;
 var $1015 = 0, $1016 = 0, $1017 = 0, $1018 = 0, $1019 = 0, $102 = 0, $1020 = 0, $1021 = 0, $1022 = 0, $1023 = 0, $1024 = 0, $1025 = 0, $1026 = 0, $1027 = 0, $1028 = 0, $1029 = 0, $103 = 0, $1030 = 0, $1031 = 0, $1032 = 0;
 var $1033 = 0, $1034 = 0, $1035 = 0, $1036 = 0, $1037 = 0, $1038 = 0, $1039 = 0, $104 = 0, $1040 = 0, $1041 = 0, $1042 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0;
 var $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0;
 var $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0;
 var $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0;
 var $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0;
 var $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0;
 var $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0;
 var $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0;
 var $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0;
 var $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0;
 var $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0;
 var $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0;
 var $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0;
 var $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0;
 var $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0;
 var $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0;
 var $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0;
 var $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0;
 var $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0;
 var $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0;
 var $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0;
 var $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0;
 var $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0;
 var $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0;
 var $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0;
 var $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0;
 var $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0;
 var $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0;
 var $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0;
 var $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0;
 var $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0;
 var $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0;
 var $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0;
 var $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0;
 var $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0;
 var $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0;
 var $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = 0;
 var $834 = 0, $835 = 0, $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0, $850 = 0, $851 = 0;
 var $852 = 0, $853 = 0, $854 = 0, $855 = 0, $856 = 0, $857 = 0, $858 = 0, $859 = 0, $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0, $869 = 0, $87 = 0;
 var $870 = 0, $871 = 0, $872 = 0, $873 = 0, $874 = 0, $875 = 0, $876 = 0, $877 = 0, $878 = 0, $879 = 0, $88 = 0, $880 = 0, $881 = 0, $882 = 0, $883 = 0, $884 = 0, $885 = 0, $886 = 0, $887 = 0, $888 = 0;
 var $889 = 0, $89 = 0, $890 = 0, $891 = 0, $892 = 0, $893 = 0, $894 = 0, $895 = 0, $896 = 0, $897 = 0, $898 = 0, $899 = 0, $9 = 0, $90 = 0, $900 = 0, $901 = 0, $902 = 0, $903 = 0, $904 = 0, $905 = 0;
 var $906 = 0, $907 = 0, $908 = 0, $909 = 0, $91 = 0, $910 = 0, $911 = 0, $912 = 0, $913 = 0, $914 = 0, $915 = 0, $916 = 0, $917 = 0, $918 = 0, $919 = 0, $92 = 0, $920 = 0, $921 = 0, $922 = 0, $923 = 0;
 var $924 = 0, $925 = 0, $926 = 0, $927 = 0, $928 = 0, $929 = 0, $93 = 0, $930 = 0, $931 = 0, $932 = 0, $933 = 0, $934 = 0, $935 = 0, $936 = 0, $937 = 0, $938 = 0, $939 = 0, $94 = 0, $940 = 0, $941 = 0;
 var $942 = 0, $943 = 0, $944 = 0, $945 = 0, $946 = 0, $947 = 0, $948 = 0, $949 = 0, $95 = 0, $950 = 0, $951 = 0, $952 = 0, $953 = 0, $954 = 0, $955 = 0, $956 = 0, $957 = 0, $958 = 0, $959 = 0, $96 = 0;
 var $960 = 0, $961 = 0, $962 = 0, $963 = 0, $964 = 0, $965 = 0, $966 = 0, $967 = 0, $968 = 0, $969 = 0, $97 = 0, $970 = 0, $971 = 0, $972 = 0, $973 = 0, $974 = 0, $975 = 0, $976 = 0, $977 = 0, $978 = 0;
 var $979 = 0, $98 = 0, $980 = 0, $981 = 0, $982 = 0, $983 = 0, $984 = 0, $985 = 0, $986 = 0, $987 = 0, $988 = 0, $989 = 0, $99 = 0, $990 = 0, $991 = 0, $992 = 0, $993 = 0, $994 = 0, $995 = 0, $996 = 0;
 var $997 = 0, $998 = 0, $999 = 0, $cond1 = 0, $eh$lpad$body$i$i$index17Z2D = 0, $eh$lpad$body$i$i$indexZ2D = 0, $eh$lpad$body$i$index22Z2D = 0, $eh$lpad$body$i$indexZ2D = 0, $eh$lpad$body135$index32Z2D = 0, $eh$lpad$body135$indexZ2D = 0, $eh$lpad$body182$index37Z2D = 0, $eh$lpad$body182$indexZ2D = 0, $eh$lpad$body210$index42Z2D = 0, $eh$lpad$body210$indexZ2D = 0, $eh$lpad$body233$index47Z2D = 0, $eh$lpad$body233$indexZ2D = 0, $eh$lpad$body65$i$index27Z2D = 0, $eh$lpad$body65$i$indexZ2D = 0, $not$$i$i = 0, $or$cond = 0;
 var $or$cond358 = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i$i96 = 0, $scevgep5$i$i$i = 0, $scevgep5$i$i$i$i = 0, $scevgep5$i$i$i97 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 336|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(336|0);
 $2 = sp + 328|0;
 $3 = sp + 324|0;
 $4 = sp + 320|0;
 $5 = sp + 316|0;
 $6 = sp + 312|0;
 $7 = sp + 308|0;
 $8 = sp + 304|0;
 $9 = sp + 300|0;
 $10 = sp + 288|0;
 $11 = sp + 152|0;
 $12 = sp + 140|0;
 $13 = sp + 128|0;
 $14 = sp + 124|0;
 $15 = sp + 120|0;
 $16 = sp + 116|0;
 $17 = sp + 112|0;
 $18 = sp + 100|0;
 $19 = sp + 88|0;
 $20 = sp + 76|0;
 $21 = sp + 72|0;
 $22 = sp + 68|0;
 $23 = sp + 56|0;
 $24 = sp + 44|0;
 $25 = sp + 32|0;
 $26 = sp + 24|0;
 $27 = sp + 12|0;
 $28 = sp;
 $29 = ((($0)) + 36|0);
 $30 = HEAP8[$29>>0]|0;
 $31 = ($30<<24>>24)==(0);
 if ($31) {
  STACKTOP = sp;return;
 }
 HEAP8[$29>>0] = 0;
 $32 = ((($0)) + 12|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ((($33)) + 60|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = ($35|0)==(0|0);
 do {
  if ($36) {
   $293 = $33;
  } else {
   HEAP32[$17>>2] = 0;
   _glGetIntegerv(36345,($17|0));
   $37 = HEAP32[$17>>2]|0;
   $38 = ($37|0)>(0);
   L6: do {
    if ($38) {
     HEAP32[$18>>2] = 0;
     $39 = ((($18)) + 4|0);
     HEAP32[$39>>2] = 0;
     $40 = ((($18)) + 8|0);
     HEAP32[$40>>2] = 0;
     $41 = ($37>>>0)>(1073741823);
     if ($41) {
      __THREW__ = 0;
      invoke_vi(3307,($18|0));
      $42 = __THREW__; __THREW__ = 0;
     } else {
      $43 = $37 << 2;
      __THREW__ = 0;
      $44 = (invoke_ii(3276,($43|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if (!($46)) {
       HEAP32[$18>>2] = $44;
       $58 = (($44) + ($37<<2)|0);
       $59 = ((($18)) + 8|0);
       HEAP32[$59>>2] = $58;
       _memset(($44|0),0,($43|0))|0;
       HEAP32[$39>>2] = $58;
       __THREW__ = 0;
       invoke_vii(3797,36344,($44|0));
       $60 = __THREW__; __THREW__ = 0;
       $61 = $60&1;
       L12: do {
        if ($61) {
         label = 16;
        } else {
         $62 = HEAP32[$17>>2]|0;
         $63 = ($62|0)>(0);
         L14: do {
          if ($63) {
           $64 = ((($0)) + 20|0);
           $$068290 = 0;
           while(1) {
            __THREW__ = 0;
            $70 = (invoke_ii(3265,3)|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             label = 31;
             break;
            }
            if ($70) {
             __THREW__ = 0;
             $73 = (invoke_ii(3266,3)|0);
             $74 = __THREW__; __THREW__ = 0;
             $75 = $74&1;
             if ($75) {
              label = 31;
              break;
             }
             __THREW__ = 0;
             $76 = (invoke_iiii(3267,($73|0),(147249|0),9)|0);
             $77 = __THREW__; __THREW__ = 0;
             $78 = $77&1;
             if ($78) {
              label = 31;
              break;
             }
             $79 = HEAP32[$18>>2]|0;
             $80 = (($79) + ($$068290<<2)|0);
             $81 = HEAP32[$80>>2]|0;
             __THREW__ = 0;
             $82 = (invoke_iii(3863,($76|0),($81|0))|0);
             $83 = __THREW__; __THREW__ = 0;
             $84 = $83&1;
             if ($84) {
              label = 31;
              break;
             }
             $85 = HEAP32[$82>>2]|0;
             $86 = ((($85)) + -12|0);
             $87 = HEAP32[$86>>2]|0;
             $88 = (($82) + ($87)|0);
             __THREW__ = 0;
             invoke_vii(3257,($16|0),($88|0));
             $89 = __THREW__; __THREW__ = 0;
             $90 = $89&1;
             if ($90) {
              label = 31;
              break;
             }
             __THREW__ = 0;
             $91 = (invoke_iii(3255,($16|0),(215188|0))|0);
             $92 = __THREW__; __THREW__ = 0;
             $93 = $92&1;
             if ($93) {
              label = 26;
              break;
             }
             $94 = HEAP32[$91>>2]|0;
             $95 = ((($94)) + 28|0);
             $96 = HEAP32[$95>>2]|0;
             __THREW__ = 0;
             $97 = (invoke_iii($96|0,($91|0),10)|0);
             $98 = __THREW__; __THREW__ = 0;
             $99 = $98&1;
             if ($99) {
              label = 26;
              break;
             }
             __THREW__ = 0;
             invoke_vi(3263,($16|0));
             $100 = __THREW__; __THREW__ = 0;
             $101 = $100&1;
             if ($101) {
              label = 31;
              break;
             }
             __THREW__ = 0;
             (invoke_iii(3268,($82|0),($97|0))|0);
             $108 = __THREW__; __THREW__ = 0;
             $109 = $108&1;
             if ($109) {
              label = 31;
              break;
             }
             __THREW__ = 0;
             (invoke_ii(3269,($82|0))|0);
             $110 = __THREW__; __THREW__ = 0;
             $111 = $110&1;
             if ($111) {
              label = 31;
              break;
             }
            }
            $114 = HEAP32[$18>>2]|0;
            $115 = (($114) + ($$068290<<2)|0);
            $116 = HEAP32[$115>>2]|0;
            $117 = HEAP32[$32>>2]|0;
            $118 = ((($117)) + 60|0);
            $119 = HEAP32[$118>>2]|0;
            $120 = ((($119)) + 32|0);
            $121 = HEAP32[$120>>2]|0;
            $122 = ((($119)) + 36|0);
            $123 = HEAP32[$122>>2]|0;
            $124 = ($121|0)==($123|0);
            $$$i = $124 ? 0 : $121;
            $$cast = $123;
            $125 = $121;
            $126 = (($$cast) - ($125))|0;
            __THREW__ = 0;
            invoke_viiiii(3880,1,($64|0),($116|0),($$$i|0),($126|0));
            $127 = __THREW__; __THREW__ = 0;
            $128 = $127&1;
            if ($128) {
             label = 35;
             break;
            }
            __THREW__ = 0;
            $129 = (invoke_i(3794)|0);
            $130 = __THREW__; __THREW__ = 0;
            $131 = $130&1;
            if ($131) {
             label = 35;
             break;
            }
            $132 = ($129|0)==(0);
            $66 = (($$068290) + 1)|0;
            if ($132) {
             label = 36;
             break;
            }
            $65 = HEAP32[$17>>2]|0;
            $67 = ($66|0)<($65|0);
            if ($67) {
             $$068290 = $66;
            } else {
             label = 37;
             break L14;
            }
           }
           if ((label|0) == 26) {
            $102 = ___cxa_find_matching_catch_2()|0;
            $103 = tempRet0;
            __THREW__ = 0;
            invoke_vi(3263,($16|0));
            $104 = __THREW__; __THREW__ = 0;
            $105 = $104&1;
            if ($105) {
             $106 = ___cxa_find_matching_catch_3(0|0)|0;
             $107 = tempRet0;
             ___clang_call_terminate($106);
             // unreachable;
            } else {
             $$sink74$sink75$index = $102;$$sink74$sink75$index8 = $103;
             break L12;
            }
           }
           else if ((label|0) == 31) {
            $112 = ___cxa_find_matching_catch_2()|0;
            $113 = tempRet0;
            $$sink74$sink75$index = $112;$$sink74$sink75$index8 = $113;
            break L12;
           }
           else if ((label|0) == 35) {
            $133 = ___cxa_find_matching_catch_2()|0;
            $134 = tempRet0;
            $$sink74$sink75$index = $133;$$sink74$sink75$index8 = $134;
            break L12;
           }
           else if ((label|0) == 36) {
            $135 = ((($0)) + 37|0);
            HEAP8[$135>>0] = 1;
            $$271 = 1;
            break;
           }
          } else {
           label = 37;
          }
         } while(0);
         L41: do {
          if ((label|0) == 37) {
           $136 = HEAP32[$32>>2]|0;
           $137 = ((($136)) + 48|0);
           $138 = ((($137)) + 11|0);
           $139 = HEAP8[$138>>0]|0;
           $140 = ($139<<24>>24)<(0);
           if ($140) {
            $141 = ((($136)) + 52|0);
            $142 = HEAP32[$141>>2]|0;
            $144 = $142;
           } else {
            $143 = $139&255;
            $144 = $143;
           }
           $145 = ($144|0)==(0);
           if (!($145)) {
            __THREW__ = 0;
            $183 = (invoke_ii(3265,3)|0);
            $184 = __THREW__; __THREW__ = 0;
            $185 = $184&1;
            if ($185) {
             label = 16;
             break L12;
            }
            if (!($183)) {
             $$271 = 0;
             break;
            }
            __THREW__ = 0;
            $186 = (invoke_ii(3266,3)|0);
            $187 = __THREW__; __THREW__ = 0;
            $188 = $187&1;
            if ($188) {
             label = 16;
             break L12;
            }
            __THREW__ = 0;
            $189 = (invoke_iiii(3267,($186|0),(147372|0),138)|0);
            $190 = __THREW__; __THREW__ = 0;
            $191 = $190&1;
            if ($191) {
             label = 16;
             break L12;
            }
            $192 = HEAP32[$189>>2]|0;
            $193 = ((($192)) + -12|0);
            $194 = HEAP32[$193>>2]|0;
            $195 = (($189) + ($194)|0);
            __THREW__ = 0;
            invoke_vii(3257,($15|0),($195|0));
            $196 = __THREW__; __THREW__ = 0;
            $197 = $196&1;
            if ($197) {
             label = 16;
             break L12;
            }
            __THREW__ = 0;
            $198 = (invoke_iii(3255,($15|0),(215188|0))|0);
            $199 = __THREW__; __THREW__ = 0;
            $200 = $199&1;
            do {
             if (!($200)) {
              $201 = HEAP32[$198>>2]|0;
              $202 = ((($201)) + 28|0);
              $203 = HEAP32[$202>>2]|0;
              __THREW__ = 0;
              $204 = (invoke_iii($203|0,($198|0),10)|0);
              $205 = __THREW__; __THREW__ = 0;
              $206 = $205&1;
              if ($206) {
               break;
              }
              __THREW__ = 0;
              invoke_vi(3263,($15|0));
              $207 = __THREW__; __THREW__ = 0;
              $208 = $207&1;
              if ($208) {
               label = 16;
               break L12;
              }
              __THREW__ = 0;
              (invoke_iii(3268,($189|0),($204|0))|0);
              $215 = __THREW__; __THREW__ = 0;
              $216 = $215&1;
              if ($216) {
               label = 16;
               break L12;
              }
              __THREW__ = 0;
              (invoke_ii(3269,($189|0))|0);
              $217 = __THREW__; __THREW__ = 0;
              $218 = $217&1;
              if ($218) {
               label = 16;
               break L12;
              } else {
               $$271 = 0;
               break L41;
              }
             }
            } while(0);
            $209 = ___cxa_find_matching_catch_2()|0;
            $210 = tempRet0;
            __THREW__ = 0;
            invoke_vi(3263,($15|0));
            $211 = __THREW__; __THREW__ = 0;
            $212 = $211&1;
            if ($212) {
             $213 = ___cxa_find_matching_catch_3(0|0)|0;
             $214 = tempRet0;
             ___clang_call_terminate($213);
             // unreachable;
            } else {
             $$sink74$sink75$index = $209;$$sink74$sink75$index8 = $210;
             break L12;
            }
           }
           __THREW__ = 0;
           $146 = (invoke_ii(3265,2)|0);
           $147 = __THREW__; __THREW__ = 0;
           $148 = $147&1;
           if ($148) {
            label = 16;
            break L12;
           }
           L65: do {
            if ($146) {
             __THREW__ = 0;
             $149 = (invoke_ii(3266,2)|0);
             $150 = __THREW__; __THREW__ = 0;
             $151 = $150&1;
             if ($151) {
              label = 16;
              break L12;
             }
             __THREW__ = 0;
             $152 = (invoke_iiii(3267,($149|0),(147259|0),112)|0);
             $153 = __THREW__; __THREW__ = 0;
             $154 = $153&1;
             if ($154) {
              label = 16;
              break L12;
             }
             $155 = HEAP32[$152>>2]|0;
             $156 = ((($155)) + -12|0);
             $157 = HEAP32[$156>>2]|0;
             $158 = (($152) + ($157)|0);
             __THREW__ = 0;
             invoke_vii(3257,($3|0),($158|0));
             $159 = __THREW__; __THREW__ = 0;
             $160 = $159&1;
             if ($160) {
              label = 16;
              break L12;
             }
             __THREW__ = 0;
             $161 = (invoke_iii(3255,($3|0),(215188|0))|0);
             $162 = __THREW__; __THREW__ = 0;
             $163 = $162&1;
             do {
              if (!($163)) {
               $164 = HEAP32[$161>>2]|0;
               $165 = ((($164)) + 28|0);
               $166 = HEAP32[$165>>2]|0;
               __THREW__ = 0;
               $167 = (invoke_iii($166|0,($161|0),10)|0);
               $168 = __THREW__; __THREW__ = 0;
               $169 = $168&1;
               if ($169) {
                break;
               }
               __THREW__ = 0;
               invoke_vi(3263,($3|0));
               $170 = __THREW__; __THREW__ = 0;
               $171 = $170&1;
               if ($171) {
                label = 16;
                break L12;
               }
               __THREW__ = 0;
               (invoke_iii(3268,($152|0),($167|0))|0);
               $178 = __THREW__; __THREW__ = 0;
               $179 = $178&1;
               if ($179) {
                label = 16;
                break L12;
               }
               __THREW__ = 0;
               (invoke_ii(3269,($152|0))|0);
               $180 = __THREW__; __THREW__ = 0;
               $181 = $180&1;
               if ($181) {
                label = 16;
                break L12;
               } else {
                break L65;
               }
              }
             } while(0);
             $172 = ___cxa_find_matching_catch_2()|0;
             $173 = tempRet0;
             __THREW__ = 0;
             invoke_vi(3263,($3|0));
             $174 = __THREW__; __THREW__ = 0;
             $175 = $174&1;
             if ($175) {
              $176 = ___cxa_find_matching_catch_3(0|0)|0;
              $177 = tempRet0;
              ___clang_call_terminate($176);
              // unreachable;
             } else {
              $$sink74$sink75$index = $172;$$sink74$sink75$index8 = $173;
              break L12;
             }
            }
           } while(0);
           $182 = ((($0)) + 37|0);
           HEAP8[$182>>0] = 0;
           $$271 = 1;
          }
         } while(0);
         $219 = HEAP32[$18>>2]|0;
         $220 = ($219|0)==(0|0);
         if (!($220)) {
          $221 = HEAP32[$39>>2]|0;
          $222 = ($221|0)==($219|0);
          if (!($222)) {
           $scevgep$i$i$i = ((($221)) + -4|0);
           $223 = $scevgep$i$i$i;
           $224 = $219;
           $225 = (($223) - ($224))|0;
           $226 = $225 >>> 2;
           $227 = $226 ^ -1;
           $scevgep5$i$i$i = (($221) + ($227<<2)|0);
           HEAP32[$39>>2] = $scevgep5$i$i$i;
          }
          __ZdlPv($219);
         }
         $cond1 = ($$271|0)==(0);
         if ($cond1) {
          label = 98;
          break L6;
         } else {
          break L6;
         }
        }
       } while(0);
       if ((label|0) == 16) {
        $68 = ___cxa_find_matching_catch_2()|0;
        $69 = tempRet0;
        $$sink74$sink75$index = $68;$$sink74$sink75$index8 = $69;
       }
       $228 = HEAP32[$18>>2]|0;
       $229 = ($228|0)==(0|0);
       if (!($229)) {
        $230 = HEAP32[$39>>2]|0;
        $231 = ($230|0)==($228|0);
        if (!($231)) {
         $scevgep$i$i$i96 = ((($230)) + -4|0);
         $232 = $scevgep$i$i$i96;
         $233 = $228;
         $234 = (($232) - ($233))|0;
         $235 = $234 >>> 2;
         $236 = $235 ^ -1;
         $scevgep5$i$i$i97 = (($230) + ($236<<2)|0);
         HEAP32[$39>>2] = $scevgep5$i$i$i97;
        }
        __ZdlPv($228);
       }
       $$8 = $$sink74$sink75$index;$$862 = $$sink74$sink75$index8;
       ___resumeException($$8|0);
       // unreachable;
      }
     }
     $47 = ___cxa_find_matching_catch_2()|0;
     $48 = tempRet0;
     $49 = HEAP32[$18>>2]|0;
     $50 = ($49|0)==(0|0);
     if ($50) {
      ___resumeException($47|0);
      // unreachable;
     }
     $51 = HEAP32[$39>>2]|0;
     $52 = ($51|0)==($49|0);
     if (!($52)) {
      $scevgep$i$i$i$i = ((($51)) + -4|0);
      $53 = $scevgep$i$i$i$i;
      $54 = $49;
      $55 = (($53) - ($54))|0;
      $56 = $55 >>> 2;
      $57 = $56 ^ -1;
      $scevgep5$i$i$i$i = (($51) + ($57<<2)|0);
      HEAP32[$39>>2] = $scevgep5$i$i$i$i;
     }
     __ZdlPv($49);
     ___resumeException($47|0);
     // unreachable;
    } else {
     $237 = HEAP32[$32>>2]|0;
     $238 = ((($237)) + 48|0);
     $239 = ((($238)) + 11|0);
     $240 = HEAP8[$239>>0]|0;
     $241 = ($240<<24>>24)<(0);
     if ($241) {
      $242 = ((($237)) + 52|0);
      $243 = HEAP32[$242>>2]|0;
      $245 = $243;
     } else {
      $244 = $240&255;
      $245 = $244;
     }
     $246 = ($245|0)==(0);
     if (!($246)) {
      $270 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
      if (!($270)) {
       label = 98;
       break;
      }
      $271 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
      $272 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($271,147597,111)|0);
      $273 = HEAP32[$272>>2]|0;
      $274 = ((($273)) + -12|0);
      $275 = HEAP32[$274>>2]|0;
      $276 = (($272) + ($275)|0);
      __ZNKSt3__28ios_base6getlocEv($14,$276);
      __THREW__ = 0;
      $277 = (invoke_iii(3255,($14|0),(215188|0))|0);
      $278 = __THREW__; __THREW__ = 0;
      $279 = $278&1;
      if (!($279)) {
       $280 = HEAP32[$277>>2]|0;
       $281 = ((($280)) + 28|0);
       $282 = HEAP32[$281>>2]|0;
       __THREW__ = 0;
       $283 = (invoke_iii($282|0,($277|0),10)|0);
       $284 = __THREW__; __THREW__ = 0;
       $285 = $284&1;
       if (!($285)) {
        __ZNSt3__26localeD2Ev($14);
        (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($272,$283)|0);
        (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($272)|0);
        label = 98;
        break;
       }
      }
      $286 = ___cxa_find_matching_catch_2()|0;
      $287 = tempRet0;
      __THREW__ = 0;
      invoke_vi(3263,($14|0));
      $288 = __THREW__; __THREW__ = 0;
      $289 = $288&1;
      if ($289) {
       $290 = ___cxa_find_matching_catch_3(0|0)|0;
       $291 = tempRet0;
       ___clang_call_terminate($290);
       // unreachable;
      } else {
       ___resumeException($286|0);
       // unreachable;
      }
     }
     $247 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
     do {
      if ($247) {
       $248 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
       $249 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($248,147511,85)|0);
       $250 = HEAP32[$249>>2]|0;
       $251 = ((($250)) + -12|0);
       $252 = HEAP32[$251>>2]|0;
       $253 = (($249) + ($252)|0);
       __ZNKSt3__28ios_base6getlocEv($2,$253);
       __THREW__ = 0;
       $254 = (invoke_iii(3255,($2|0),(215188|0))|0);
       $255 = __THREW__; __THREW__ = 0;
       $256 = $255&1;
       if (!($256)) {
        $257 = HEAP32[$254>>2]|0;
        $258 = ((($257)) + 28|0);
        $259 = HEAP32[$258>>2]|0;
        __THREW__ = 0;
        $260 = (invoke_iii($259|0,($254|0),10)|0);
        $261 = __THREW__; __THREW__ = 0;
        $262 = $261&1;
        if (!($262)) {
         __ZNSt3__26localeD2Ev($2);
         (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($249,$260)|0);
         (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($249)|0);
         break;
        }
       }
       $263 = ___cxa_find_matching_catch_2()|0;
       $264 = tempRet0;
       __THREW__ = 0;
       invoke_vi(3263,($2|0));
       $265 = __THREW__; __THREW__ = 0;
       $266 = $265&1;
       if ($266) {
        $267 = ___cxa_find_matching_catch_3(0|0)|0;
        $268 = tempRet0;
        ___clang_call_terminate($267);
        // unreachable;
       } else {
        ___resumeException($263|0);
        // unreachable;
       }
      }
     } while(0);
     $269 = ((($0)) + 37|0);
     HEAP8[$269>>0] = 0;
    }
   } while(0);
   if ((label|0) == 98) {
    $$pre = HEAP32[$32>>2]|0;
    $293 = $$pre;
    break;
   }
   STACKTOP = sp;return;
  }
 } while(0);
 $292 = ((($293)) + 48|0);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_($19,$292);
 $294 = HEAP32[$32>>2]|0;
 $295 = ((($294)) + 32|0);
 $296 = HEAP32[$295>>2]|0;
 $297 = ($296|0)==(35633);
 do {
  if ($297) {
   $298 = ((($1)) + 348|0);
   $299 = HEAP8[$298>>0]|0;
   $300 = ($299<<24>>24)==(0);
   if ($300) {
    $301 = ((($1)) + 184|0);
    $302 = HEAP8[$301>>0]|0;
    $303 = ($302<<24>>24)==(0);
    if ($303) {
     label = 105;
     break;
    }
   }
   __THREW__ = 0;
   (invoke_iii(3881,($1|0),($19|0))|0);
   $304 = __THREW__; __THREW__ = 0;
   $305 = $304&1;
   if ($305) {
    label = 103;
   } else {
    label = 105;
   }
  } else {
   label = 105;
  }
 } while(0);
 L141: do {
  if ((label|0) == 105) {
   __THREW__ = 0;
   $308 = (invoke_i(3882)|0);
   $309 = __THREW__; __THREW__ = 0;
   $310 = $309&1;
   if ($310) {
    label = 103;
   } else {
    $311 = ($308|0)>(3);
    L144: do {
     if ($311) {
      $312 = ((($19)) + 11|0);
      $313 = HEAP8[$312>>0]|0;
      $314 = ($313<<24>>24)<(0);
      $315 = ((($19)) + 4|0);
      $316 = HEAP32[$315>>2]|0;
      $317 = $313&255;
      $318 = $314 ? $316 : $317;
      $319 = ($318|0)==(0);
      L146: do {
       if ($319) {
        __THREW__ = 0;
        invoke_vii(3457,($20|0),($19|0));
        $320 = __THREW__; __THREW__ = 0;
        $321 = $320&1;
        if ($321) {
         label = 103;
         break L141;
        }
       } else {
        $322 = ((($11)) + 56|0);
        $323 = ((($11)) + 4|0);
        HEAP32[$11>>2] = ((21372));
        HEAP32[$322>>2] = ((21392));
        $324 = ((($11)) + 56|0);
        __THREW__ = 0;
        invoke_vii(3368,($324|0),($323|0));
        $325 = __THREW__; __THREW__ = 0;
        $326 = $325&1;
        if ($326) {
         $353 = ___cxa_find_matching_catch_2()|0;
         $354 = tempRet0;
         $$0$i$i = $354;$$03$i$i = $353;
        } else {
         $327 = ((($11)) + 128|0);
         HEAP32[$327>>2] = 0;
         $328 = ((($11)) + 132|0);
         HEAP32[$328>>2] = -1;
         HEAP32[$11>>2] = (50156);
         HEAP32[$322>>2] = (50176);
         __THREW__ = 0;
         invoke_vi(3369,($323|0));
         $329 = __THREW__; __THREW__ = 0;
         $330 = $329&1;
         do {
          if ($330) {
           $355 = ___cxa_find_matching_catch_2()|0;
           $356 = tempRet0;
           $eh$lpad$body$i$i$index17Z2D = $356;$eh$lpad$body$i$i$indexZ2D = $355;
          } else {
           HEAP32[$323>>2] = (37132);
           $331 = ((($11)) + 36|0);
           $332 = ((($11)) + 52|0);
           ;HEAP32[$331>>2]=0|0;HEAP32[$331+4>>2]=0|0;HEAP32[$331+8>>2]=0|0;HEAP32[$331+12>>2]=0|0;
           HEAP32[$332>>2] = 16;
           ;HEAP32[$10>>2]=0|0;HEAP32[$10+4>>2]=0|0;HEAP32[$10+8>>2]=0|0;
           __THREW__ = 0;
           invoke_vii(3370,($323|0),($10|0));
           $333 = __THREW__; __THREW__ = 0;
           $334 = $333&1;
           if ($334) {
            $339 = ___cxa_find_matching_catch_2()|0;
            $340 = tempRet0;
            $341 = ((($10)) + 11|0);
            $342 = HEAP8[$341>>0]|0;
            $343 = ($342<<24>>24)<(0);
            if ($343) {
             $344 = HEAP32[$10>>2]|0;
             __ZdlPv($344);
            }
            $345 = ((($331)) + 11|0);
            $346 = HEAP8[$345>>0]|0;
            $347 = ($346<<24>>24)<(0);
            if ($347) {
             $348 = HEAP32[$331>>2]|0;
             __ZdlPv($348);
            }
            __THREW__ = 0;
            invoke_vi(2911,($323|0));
            $349 = __THREW__; __THREW__ = 0;
            $350 = $349&1;
            if (!($350)) {
             $eh$lpad$body$i$i$index17Z2D = $340;$eh$lpad$body$i$i$indexZ2D = $339;
             break;
            }
            $351 = ___cxa_find_matching_catch_3(0|0)|0;
            $352 = tempRet0;
            ___clang_call_terminate($351);
            // unreachable;
           }
           $335 = ((($10)) + 11|0);
           $336 = HEAP8[$335>>0]|0;
           $337 = ($336<<24>>24)<(0);
           if ($337) {
            $338 = HEAP32[$10>>2]|0;
            __ZdlPv($338);
           }
           $363 = HEAP8[$312>>0]|0;
           $364 = ($363<<24>>24)<(0);
           $365 = HEAP32[$315>>2]|0;
           $366 = $363&255;
           $367 = $364 ? $365 : $366;
           $368 = ($367|0)==(0);
           L168: do {
            if ($368) {
             $$03393$i = 1;$$034100$i = 0;$$pre$phi$iZ2D = $11;
             label = 153;
            } else {
             $369 = ((($12)) + 11|0);
             $370 = ((($12)) + 4|0);
             $$033102$i = 1;$$034101$i = 0;$371 = $363;$380 = $367;
             while(1) {
              $372 = ($371<<24>>24)<(0);
              $373 = HEAP32[$19>>2]|0;
              $374 = $372 ? $373 : $19;
              $$01112$i$i = $$034101$i;
              while(1) {
               $375 = (($374) + ($$01112$i$i)|0);
               $376 = HEAP8[$375>>0]|0;
               $377 = ($376<<24>>24)==(10);
               if ($377) {
                break;
               }
               $378 = (($$01112$i$i) + 1)|0;
               $379 = ($378>>>0)<($380>>>0);
               if ($379) {
                $$01112$i$i = $378;
               } else {
                $$03393$i = $$033102$i;$$034100$i = $$034101$i;$$pre$phi$iZ2D = $11;
                label = 153;
                break L168;
               }
              }
              $381 = HEAP32[$11>>2]|0;
              $382 = ((($381)) + -12|0);
              $383 = HEAP32[$382>>2]|0;
              $384 = (($11) + ($383)|0);
              $385 = ((($384)) + 12|0);
              HEAP32[$385>>2] = 5;
              $386 = HEAP32[$11>>2]|0;
              $387 = ((($386)) + -12|0);
              $388 = HEAP32[$387>>2]|0;
              $389 = (($11) + ($388)|0);
              $390 = ((($389)) + 4|0);
              $391 = HEAP32[$390>>2]|0;
              $392 = $391 & -177;
              $393 = $392 | 128;
              HEAP32[$390>>2] = $393;
              __THREW__ = 0;
              $394 = (invoke_iii(3417,($11|0),($$033102$i|0))|0);
              $395 = __THREW__; __THREW__ = 0;
              $396 = $395&1;
              if ($396) {
               label = 147;
               break;
              }
              __THREW__ = 0;
              $397 = (invoke_iiii(3267,($394|0),(205152|0),2)|0);
              $398 = __THREW__; __THREW__ = 0;
              $399 = $398&1;
              if ($399) {
               label = 147;
               break;
              }
              $400 = (($$01112$i$i) - ($$034101$i))|0;
              __THREW__ = 0;
              invoke_viiiii(3746,($12|0),($19|0),($$034101$i|0),($400|0),($19|0));
              $401 = __THREW__; __THREW__ = 0;
              $402 = $401&1;
              if ($402) {
               label = 148;
               break;
              }
              $403 = HEAP8[$369>>0]|0;
              $404 = ($403<<24>>24)<(0);
              $405 = HEAP32[$12>>2]|0;
              $406 = $404 ? $405 : $12;
              $407 = HEAP32[$370>>2]|0;
              $408 = $403&255;
              $409 = $404 ? $407 : $408;
              __THREW__ = 0;
              $410 = (invoke_iiii(3267,($397|0),($406|0),($409|0))|0);
              $411 = __THREW__; __THREW__ = 0;
              $412 = $411&1;
              if ($412) {
               label = 149;
               break;
              }
              $413 = HEAP32[$410>>2]|0;
              $414 = ((($413)) + -12|0);
              $415 = HEAP32[$414>>2]|0;
              $416 = (($410) + ($415)|0);
              __THREW__ = 0;
              invoke_vii(3257,($9|0),($416|0));
              $417 = __THREW__; __THREW__ = 0;
              $418 = $417&1;
              if ($418) {
               label = 149;
               break;
              }
              __THREW__ = 0;
              $419 = (invoke_iii(3255,($9|0),(215188|0))|0);
              $420 = __THREW__; __THREW__ = 0;
              $421 = $420&1;
              if ($421) {
               label = 139;
               break;
              }
              $422 = HEAP32[$419>>2]|0;
              $423 = ((($422)) + 28|0);
              $424 = HEAP32[$423>>2]|0;
              __THREW__ = 0;
              $425 = (invoke_iii($424|0,($419|0),10)|0);
              $426 = __THREW__; __THREW__ = 0;
              $427 = $426&1;
              if ($427) {
               label = 139;
               break;
              }
              __THREW__ = 0;
              invoke_vi(3263,($9|0));
              $428 = __THREW__; __THREW__ = 0;
              $429 = $428&1;
              if ($429) {
               label = 149;
               break;
              }
              __THREW__ = 0;
              (invoke_iii(3268,($410|0),($425|0))|0);
              $436 = __THREW__; __THREW__ = 0;
              $437 = $436&1;
              if ($437) {
               label = 149;
               break;
              }
              __THREW__ = 0;
              (invoke_ii(3269,($410|0))|0);
              $438 = __THREW__; __THREW__ = 0;
              $439 = $438&1;
              if ($439) {
               label = 149;
               break;
              }
              $440 = HEAP8[$369>>0]|0;
              $441 = ($440<<24>>24)<(0);
              if ($441) {
               $442 = HEAP32[$12>>2]|0;
               __ZdlPv($442);
              }
              $443 = (($$01112$i$i) + 1)|0;
              $444 = HEAP8[$312>>0]|0;
              $445 = ($444<<24>>24)<(0);
              $446 = HEAP32[$315>>2]|0;
              $447 = $444&255;
              $448 = $445 ? $446 : $447;
              $449 = ($443>>>0)<($448>>>0);
              if (!($449)) {
               label = 176;
               break L168;
              }
              $531 = (($$033102$i) + 1)|0;
              $$033102$i = $531;$$034101$i = $443;$371 = $444;$380 = $448;
             }
             do {
              if ((label|0) == 139) {
               $430 = ___cxa_find_matching_catch_2()|0;
               $431 = tempRet0;
               __THREW__ = 0;
               invoke_vi(3263,($9|0));
               $432 = __THREW__; __THREW__ = 0;
               $433 = $432&1;
               if ($433) {
                $434 = ___cxa_find_matching_catch_3(0|0)|0;
                $435 = tempRet0;
                ___clang_call_terminate($434);
                // unreachable;
               } else {
                $eh$lpad$body$i$index22Z2D = $431;$eh$lpad$body$i$indexZ2D = $430;
                label = 150;
                break;
               }
              }
              else if ((label|0) == 147) {
               $450 = ___cxa_find_matching_catch_2()|0;
               $451 = tempRet0;
               $$5$i = $451;$$532$i = $450;
               break L168;
              }
              else if ((label|0) == 148) {
               $452 = ___cxa_find_matching_catch_2()|0;
               $453 = tempRet0;
               $$0$i = $453;$$027$i = $452;
              }
              else if ((label|0) == 149) {
               $454 = ___cxa_find_matching_catch_2()|0;
               $455 = tempRet0;
               $eh$lpad$body$i$index22Z2D = $455;$eh$lpad$body$i$indexZ2D = $454;
               label = 150;
              }
             } while(0);
             if ((label|0) == 150) {
              $456 = HEAP8[$369>>0]|0;
              $457 = ($456<<24>>24)<(0);
              if ($457) {
               $458 = HEAP32[$12>>2]|0;
               __ZdlPv($458);
               $$0$i = $eh$lpad$body$i$index22Z2D;$$027$i = $eh$lpad$body$i$indexZ2D;
              } else {
               $$0$i = $eh$lpad$body$i$index22Z2D;$$027$i = $eh$lpad$body$i$indexZ2D;
              }
             }
             $$5$i = $$0$i;$$532$i = $$027$i;
            }
           } while(0);
           L203: do {
            if ((label|0) == 153) {
             $459 = HEAP32[$$pre$phi$iZ2D>>2]|0;
             $460 = ((($459)) + -12|0);
             $461 = HEAP32[$460>>2]|0;
             $462 = (($11) + ($461)|0);
             $463 = ((($462)) + 12|0);
             HEAP32[$463>>2] = 5;
             $464 = HEAP32[$$pre$phi$iZ2D>>2]|0;
             $465 = ((($464)) + -12|0);
             $466 = HEAP32[$465>>2]|0;
             $467 = (($11) + ($466)|0);
             $468 = ((($467)) + 4|0);
             $469 = HEAP32[$468>>2]|0;
             $470 = $469 & -177;
             $471 = $470 | 128;
             HEAP32[$468>>2] = $471;
             __THREW__ = 0;
             $472 = (invoke_iii(3417,($11|0),($$03393$i|0))|0);
             $473 = __THREW__; __THREW__ = 0;
             $474 = $473&1;
             if (!($474)) {
              __THREW__ = 0;
              $475 = (invoke_iiii(3267,($472|0),(205152|0),2)|0);
              $476 = __THREW__; __THREW__ = 0;
              $477 = $476&1;
              if (!($477)) {
               __THREW__ = 0;
               invoke_viiiii(3746,($13|0),($19|0),($$034100$i|0),-1,($19|0));
               $478 = __THREW__; __THREW__ = 0;
               $479 = $478&1;
               do {
                if ($479) {
                 $524 = ___cxa_find_matching_catch_2()|0;
                 $525 = tempRet0;
                 $$2$i = $525;$$229$i = $524;
                } else {
                 $480 = ((($13)) + 11|0);
                 $481 = HEAP8[$480>>0]|0;
                 $482 = ($481<<24>>24)<(0);
                 $483 = HEAP32[$13>>2]|0;
                 $484 = $482 ? $483 : $13;
                 $485 = ((($13)) + 4|0);
                 $486 = HEAP32[$485>>2]|0;
                 $487 = $481&255;
                 $488 = $482 ? $486 : $487;
                 __THREW__ = 0;
                 $489 = (invoke_iiii(3267,($475|0),($484|0),($488|0))|0);
                 $490 = __THREW__; __THREW__ = 0;
                 $491 = $490&1;
                 L211: do {
                  if ($491) {
                   label = 171;
                  } else {
                   $492 = HEAP32[$489>>2]|0;
                   $493 = ((($492)) + -12|0);
                   $494 = HEAP32[$493>>2]|0;
                   $495 = (($489) + ($494)|0);
                   __THREW__ = 0;
                   invoke_vii(3257,($8|0),($495|0));
                   $496 = __THREW__; __THREW__ = 0;
                   $497 = $496&1;
                   if ($497) {
                    label = 171;
                    break;
                   }
                   __THREW__ = 0;
                   $498 = (invoke_iii(3255,($8|0),(215188|0))|0);
                   $499 = __THREW__; __THREW__ = 0;
                   $500 = $499&1;
                   do {
                    if (!($500)) {
                     $501 = HEAP32[$498>>2]|0;
                     $502 = ((($501)) + 28|0);
                     $503 = HEAP32[$502>>2]|0;
                     __THREW__ = 0;
                     $504 = (invoke_iii($503|0,($498|0),10)|0);
                     $505 = __THREW__; __THREW__ = 0;
                     $506 = $505&1;
                     if ($506) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3263,($8|0));
                     $507 = __THREW__; __THREW__ = 0;
                     $508 = $507&1;
                     if ($508) {
                      label = 171;
                      break L211;
                     }
                     __THREW__ = 0;
                     (invoke_iii(3268,($489|0),($504|0))|0);
                     $515 = __THREW__; __THREW__ = 0;
                     $516 = $515&1;
                     if ($516) {
                      label = 171;
                      break L211;
                     }
                     __THREW__ = 0;
                     (invoke_ii(3269,($489|0))|0);
                     $517 = __THREW__; __THREW__ = 0;
                     $518 = $517&1;
                     if ($518) {
                      label = 171;
                      break L211;
                     }
                     $519 = HEAP8[$480>>0]|0;
                     $520 = ($519<<24>>24)<(0);
                     if ($520) {
                      $521 = HEAP32[$13>>2]|0;
                      __ZdlPv($521);
                     }
                     label = 176;
                     break L203;
                    }
                   } while(0);
                   $509 = ___cxa_find_matching_catch_2()|0;
                   $510 = tempRet0;
                   __THREW__ = 0;
                   invoke_vi(3263,($8|0));
                   $511 = __THREW__; __THREW__ = 0;
                   $512 = $511&1;
                   if ($512) {
                    $513 = ___cxa_find_matching_catch_3(0|0)|0;
                    $514 = tempRet0;
                    ___clang_call_terminate($513);
                    // unreachable;
                   } else {
                    $eh$lpad$body65$i$index27Z2D = $510;$eh$lpad$body65$i$indexZ2D = $509;
                    break;
                   }
                  }
                 } while(0);
                 if ((label|0) == 171) {
                  $526 = ___cxa_find_matching_catch_2()|0;
                  $527 = tempRet0;
                  $eh$lpad$body65$i$index27Z2D = $527;$eh$lpad$body65$i$indexZ2D = $526;
                 }
                 $528 = HEAP8[$480>>0]|0;
                 $529 = ($528<<24>>24)<(0);
                 if (!($529)) {
                  $$2$i = $eh$lpad$body65$i$index27Z2D;$$229$i = $eh$lpad$body65$i$indexZ2D;
                  break;
                 }
                 $530 = HEAP32[$13>>2]|0;
                 __ZdlPv($530);
                 $$2$i = $eh$lpad$body65$i$index27Z2D;$$229$i = $eh$lpad$body65$i$indexZ2D;
                }
               } while(0);
               $$5$i = $$2$i;$$532$i = $$229$i;
               break;
              }
             }
             $522 = ___cxa_find_matching_catch_2()|0;
             $523 = tempRet0;
             $$5$i = $523;$$532$i = $522;
            }
           } while(0);
           do {
            if ((label|0) == 176) {
             __THREW__ = 0;
             invoke_vii(3615,($20|0),($323|0));
             $532 = __THREW__; __THREW__ = 0;
             $533 = $532&1;
             if ($533) {
              $536 = ___cxa_find_matching_catch_2()|0;
              $537 = tempRet0;
              $$5$i = $537;$$532$i = $536;
              break;
             }
             __THREW__ = 0;
             invoke_vi(1113,($11|0));
             $534 = __THREW__; __THREW__ = 0;
             $535 = $534&1;
             if ($535) {
              label = 103;
              break L141;
             }
             break L146;
            }
           } while(0);
           __THREW__ = 0;
           invoke_vi(1113,($11|0));
           $538 = __THREW__; __THREW__ = 0;
           $539 = $538&1;
           if ($539) {
            $540 = ___cxa_find_matching_catch_3(0|0)|0;
            $541 = tempRet0;
            ___clang_call_terminate($540);
            // unreachable;
           } else {
            $$5$i$sink = $$5$i;$$532$i$sink = $$532$i;
            label = 104;
            break L141;
           }
          }
         } while(0);
         __THREW__ = 0;
         invoke_vii(3614,($11|0),((50188)|0));
         $357 = __THREW__; __THREW__ = 0;
         $358 = $357&1;
         if ($358) {
          $361 = ___cxa_find_matching_catch_3(0|0)|0;
          $362 = tempRet0;
          ___clang_call_terminate($361);
          // unreachable;
         } else {
          $$0$i$i = $eh$lpad$body$i$i$index17Z2D;$$03$i$i = $eh$lpad$body$i$i$indexZ2D;
         }
        }
        __THREW__ = 0;
        invoke_vi(2907,($322|0));
        $359 = __THREW__; __THREW__ = 0;
        $360 = $359&1;
        if (!($360)) {
         $$5$i$sink = $$0$i$i;$$532$i$sink = $$03$i$i;
         label = 104;
         break L141;
        }
        $361 = ___cxa_find_matching_catch_3(0|0)|0;
        $362 = tempRet0;
        ___clang_call_terminate($361);
        // unreachable;
       }
      } while(0);
      __THREW__ = 0;
      $542 = (invoke_ii(3265,4)|0);
      $543 = __THREW__; __THREW__ = 0;
      $544 = $543&1;
      L248: do {
       if ($544) {
        label = 207;
       } else {
        L250: do {
         if ($542) {
          __THREW__ = 0;
          $545 = (invoke_ii(3266,4)|0);
          $546 = __THREW__; __THREW__ = 0;
          $547 = $546&1;
          if ($547) {
           label = 207;
           break L248;
          }
          __THREW__ = 0;
          $548 = (invoke_iiii(3267,($545|0),(147709|0),11)|0);
          $549 = __THREW__; __THREW__ = 0;
          $550 = $549&1;
          if ($550) {
           label = 207;
           break L248;
          }
          $551 = HEAP32[$32>>2]|0;
          $552 = ((($551)) + 32|0);
          $553 = HEAP32[$552>>2]|0;
          switch ($553|0) {
          case 35633:  {
           $$0$i117 = 147774;
           break;
          }
          case 36488:  {
           $$0$i117 = 147762;
           break;
          }
          case 36487:  {
           $$0$i117 = 147747;
           break;
          }
          case 36313:  {
           $$0$i117 = 147738;
           break;
          }
          case 35632:  {
           $$0$i117 = 147729;
           break;
          }
          case 37305:  {
           $$0$i117 = 147721;
           break;
          }
          default: {
           $$0$i117 = 156745;
          }
          }
          $554 = (_strlen($$0$i117)|0);
          __THREW__ = 0;
          $555 = (invoke_iiii(3267,($548|0),($$0$i117|0),($554|0))|0);
          $556 = __THREW__; __THREW__ = 0;
          $557 = $556&1;
          if ($557) {
           label = 207;
           break L248;
          }
          __THREW__ = 0;
          $558 = (invoke_iiii(3267,($555|0),(147781|0),9)|0);
          $559 = __THREW__; __THREW__ = 0;
          $560 = $559&1;
          if ($560) {
           label = 207;
           break L248;
          }
          $561 = ((($20)) + 11|0);
          $562 = HEAP8[$561>>0]|0;
          $563 = ($562<<24>>24)<(0);
          $564 = HEAP32[$20>>2]|0;
          $565 = $563 ? $564 : $20;
          $566 = ((($20)) + 4|0);
          $567 = HEAP32[$566>>2]|0;
          $568 = $562&255;
          $569 = $563 ? $567 : $568;
          __THREW__ = 0;
          $570 = (invoke_iiii(3267,($558|0),($565|0),($569|0))|0);
          $571 = __THREW__; __THREW__ = 0;
          $572 = $571&1;
          if ($572) {
           label = 207;
           break L248;
          }
          $573 = HEAP32[$570>>2]|0;
          $574 = ((($573)) + -12|0);
          $575 = HEAP32[$574>>2]|0;
          $576 = (($570) + ($575)|0);
          __THREW__ = 0;
          invoke_vii(3257,($7|0),($576|0));
          $577 = __THREW__; __THREW__ = 0;
          $578 = $577&1;
          if ($578) {
           label = 207;
           break L248;
          }
          __THREW__ = 0;
          $579 = (invoke_iii(3255,($7|0),(215188|0))|0);
          $580 = __THREW__; __THREW__ = 0;
          $581 = $580&1;
          do {
           if (!($581)) {
            $582 = HEAP32[$579>>2]|0;
            $583 = ((($582)) + 28|0);
            $584 = HEAP32[$583>>2]|0;
            __THREW__ = 0;
            $585 = (invoke_iii($584|0,($579|0),10)|0);
            $586 = __THREW__; __THREW__ = 0;
            $587 = $586&1;
            if ($587) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3263,($7|0));
            $588 = __THREW__; __THREW__ = 0;
            $589 = $588&1;
            if ($589) {
             label = 207;
             break L248;
            }
            __THREW__ = 0;
            (invoke_iii(3268,($570|0),($585|0))|0);
            $596 = __THREW__; __THREW__ = 0;
            $597 = $596&1;
            if ($597) {
             label = 207;
             break L248;
            }
            __THREW__ = 0;
            (invoke_ii(3269,($570|0))|0);
            $598 = __THREW__; __THREW__ = 0;
            $599 = $598&1;
            if ($599) {
             label = 207;
             break L248;
            } else {
             $$pre$phi335Z2D = $561;
             break L250;
            }
           }
          } while(0);
          $590 = ___cxa_find_matching_catch_2()|0;
          $591 = tempRet0;
          __THREW__ = 0;
          invoke_vi(3263,($7|0));
          $592 = __THREW__; __THREW__ = 0;
          $593 = $592&1;
          if ($593) {
           $594 = ___cxa_find_matching_catch_3(0|0)|0;
           $595 = tempRet0;
           ___clang_call_terminate($594);
           // unreachable;
          } else {
           $$pre$phi331Z2D = $561;$eh$lpad$body135$index32Z2D = $591;$eh$lpad$body135$indexZ2D = $590;
           break L248;
          }
         } else {
          $$pre334 = ((($20)) + 11|0);
          $$pre$phi335Z2D = $$pre334;
         }
        } while(0);
        $605 = HEAP8[$$pre$phi335Z2D>>0]|0;
        $606 = ($605<<24>>24)<(0);
        if ($606) {
         $607 = HEAP32[$20>>2]|0;
         __ZdlPv($607);
        }
        break L144;
       }
      } while(0);
      if ((label|0) == 207) {
       $600 = ___cxa_find_matching_catch_2()|0;
       $601 = tempRet0;
       $$pre330 = ((($20)) + 11|0);
       $$pre$phi331Z2D = $$pre330;$eh$lpad$body135$index32Z2D = $601;$eh$lpad$body135$indexZ2D = $600;
      }
      $602 = HEAP8[$$pre$phi331Z2D>>0]|0;
      $603 = ($602<<24>>24)<(0);
      if ($603) {
       $604 = HEAP32[$20>>2]|0;
       __ZdlPv($604);
      }
      $$7 = $eh$lpad$body135$indexZ2D;$$761 = $eh$lpad$body135$index32Z2D;
      break L141;
     }
    } while(0);
    HEAP32[$21>>2] = 0;
    $608 = ((($0)) + 24|0);
    $609 = ((($608)) + 11|0);
    $610 = HEAP8[$609>>0]|0;
    $611 = ($610<<24>>24)<(0);
    if ($611) {
     $612 = ((($0)) + 28|0);
     $613 = HEAP32[$612>>2]|0;
     $615 = $613;
    } else {
     $614 = $610&255;
     $615 = $614;
    }
    $616 = ($615|0)==(0);
    L291: do {
     if ($616) {
      $617 = ((($19)) + 11|0);
      $618 = HEAP8[$617>>0]|0;
      $619 = ($618<<24>>24)<(0);
      $620 = HEAP32[$19>>2]|0;
      $621 = $619 ? $620 : $19;
      HEAP32[$22>>2] = $621;
      $622 = ((($0)) + 16|0);
      $623 = HEAP32[$622>>2]|0;
      $624 = ((($623)) + 172|0);
      $625 = HEAP32[$624>>2]|0;
      $626 = ((($0)) + 20|0);
      $627 = HEAP32[$626>>2]|0;
      __THREW__ = 0;
      invoke_viiii($625|0,($627|0),1,($22|0),(0|0));
      $628 = __THREW__; __THREW__ = 0;
      $629 = $628&1;
      if ($629) {
       $630 = ___cxa_find_matching_catch_2()|0;
       $631 = tempRet0;
       $$6 = $630;$$660 = $631;
       break;
      } else {
       $$pre$phi319Z2D = $626;$$pre$phiZ2D = $622;
       label = 273;
       break;
      }
     } else {
      ;HEAP32[$23>>2]=0|0;HEAP32[$23+4>>2]=0|0;HEAP32[$23+8>>2]=0|0;
      $632 = ((($19)) + 11|0);
      $633 = ((($19)) + 4|0);
      $$pre311 = HEAP8[$632>>0]|0;
      $$pre312 = HEAP32[$633>>2]|0;
      $$063 = 0;$634 = $$pre311;$637 = $$pre312;
      L297: while(1) {
       $635 = ($634<<24>>24)<(0);
       $636 = $634&255;
       $638 = $635 ? $637 : $636;
       $639 = ($638>>>0)>($$063>>>0);
       if (!($639)) {
        label = 254;
        break;
       }
       $640 = HEAP32[$19>>2]|0;
       $641 = $635 ? $640 : $19;
       $$01112$i = $$063;
       while(1) {
        $642 = (($641) + ($$01112$i)|0);
        $643 = HEAP8[$642>>0]|0;
        $$0$i$i137 = 147791;
        while(1) {
         $644 = HEAP8[$$0$i$i137>>0]|0;
         $645 = ($644<<24>>24)==(0);
         $646 = ($644<<24>>24)!=($643<<24>>24);
         $not$$i$i = $645 ^ 1;
         $$$i$i = $646 & $not$$i$i;
         $647 = ((($$0$i$i137)) + 1|0);
         if ($$$i$i) {
          $$0$i$i137 = $647;
         } else {
          break;
         }
        }
        if ($645) {
         break;
        }
        $648 = (($$01112$i) + 1)|0;
        $649 = ($648>>>0)<($638>>>0);
        if ($649) {
         $$01112$i = $648;
        } else {
         label = 254;
         break L297;
        }
       }
       $650 = ($$01112$i|0)!=(-1);
       $651 = ($638>>>0)>($$01112$i>>>0);
       $or$cond358 = $650 & $651;
       if ($or$cond358) {
        $$01112$i141 = $$01112$i;$655 = $643;
       } else {
        label = 254;
        break;
       }
       while(1) {
        $$0$i$i143 = 147794;
        while(1) {
         $652 = HEAP8[$$0$i$i143>>0]|0;
         $653 = ($652<<24>>24)!=(0);
         $654 = ($652<<24>>24)!=($655<<24>>24);
         $$$i$i144 = $653 & $654;
         $656 = ((($$0$i$i143)) + 1|0);
         if ($$$i$i144) {
          $$0$i$i143 = $656;
         } else {
          break;
         }
        }
        if ($653) {
         break;
        }
        $657 = (($$01112$i141) + 1)|0;
        $658 = ($657>>>0)<($638>>>0);
        if (!($658)) {
         label = 254;
         break L297;
        }
        $$phi$trans$insert = (($641) + ($657)|0);
        $$pre313 = HEAP8[$$phi$trans$insert>>0]|0;
        $$01112$i141 = $657;$655 = $$pre313;
       }
       $659 = ($$01112$i141|0)==(-1);
       if ($659) {
        label = 254;
        break;
       }
       $660 = (($$01112$i141) - ($$01112$i))|0;
       $661 = ($660>>>0)>(7);
       if ($661) {
        __THREW__ = 0;
        $662 = (invoke_iiiii(3883,($19|0),($$01112$i|0),8,(147797|0))|0);
        $663 = __THREW__; __THREW__ = 0;
        $664 = $663&1;
        if ($664) {
         label = 247;
         break;
        }
        $665 = ($662|0)==(0);
        if ($665) {
         label = 239;
         break;
        }
        $$pre315 = HEAP8[$632>>0]|0;
        $$pre316 = HEAP32[$633>>2]|0;
        $705 = $$pre315;$708 = $$pre316;
       } else {
        $705 = $634;$708 = $637;
       }
       $704 = (($$01112$i141) + 1)|0;
       $706 = ($705<<24>>24)<(0);
       $707 = $705&255;
       $709 = $706 ? $708 : $707;
       $710 = ($704>>>0)<($709>>>0);
       $711 = ($704|0)!=(-1);
       $or$cond = $711 & $710;
       if ($or$cond) {
        $$063 = $704;$634 = $705;$637 = $708;
       } else {
        label = 254;
        break;
       }
      }
      L321: do {
       if ((label|0) == 239) {
        $666 = (($660) + 1)|0;
        __THREW__ = 0;
        invoke_viiiii(3746,($24|0),($19|0),($$01112$i|0),($666|0),($19|0));
        $667 = __THREW__; __THREW__ = 0;
        $668 = $667&1;
        do {
         if ($668) {
          $694 = ___cxa_find_matching_catch_2()|0;
          $695 = tempRet0;
          $$2 = $694;$$256 = $695;
         } else {
          __THREW__ = 0;
          (invoke_iii(3477,($23|0),($24|0))|0);
          $669 = __THREW__; __THREW__ = 0;
          $670 = $669&1;
          if ($670) {
           $696 = ___cxa_find_matching_catch_2()|0;
           $697 = tempRet0;
           $698 = ((($24)) + 11|0);
           $699 = HEAP8[$698>>0]|0;
           $700 = ($699<<24>>24)<(0);
           if (!($700)) {
            $$2 = $696;$$256 = $697;
            break;
           }
           $701 = HEAP32[$24>>2]|0;
           __ZdlPv($701);
           $$2 = $696;$$256 = $697;
           break;
          }
          $671 = ((($24)) + 11|0);
          $672 = HEAP8[$671>>0]|0;
          $673 = ($672<<24>>24)<(0);
          if ($673) {
           $674 = HEAP32[$24>>2]|0;
           __ZdlPv($674);
          }
          $675 = ((($23)) + 11|0);
          $676 = HEAP8[$675>>0]|0;
          $677 = ($676<<24>>24)<(0);
          $678 = ((($23)) + 4|0);
          $679 = HEAP32[$678>>2]|0;
          $680 = $676&255;
          $681 = $677 ? $679 : $680;
          $682 = (($681) + -1)|0;
          $683 = HEAP32[$23>>2]|0;
          $684 = $677 ? $683 : $23;
          $685 = (($684) + ($682)|0);
          $686 = HEAP8[$685>>0]|0;
          $687 = ($686<<24>>24)==(10);
          if (!($687)) {
           __THREW__ = 0;
           invoke_vii(3433,($23|0),10);
           $688 = __THREW__; __THREW__ = 0;
           $689 = $688&1;
           if ($689) {
            label = 247;
            break L321;
           }
          }
          __THREW__ = 0;
          (invoke_iiii(3884,($19|0),($$01112$i|0),(147806|0))|0);
          $702 = __THREW__; __THREW__ = 0;
          $703 = $702&1;
          if ($703) {
           label = 247;
           break L321;
          } else {
           label = 254;
           break L321;
          }
         }
        } while(0);
        $$5 = $$2;$$559 = $$256;
       }
      } while(0);
      L337: do {
       if ((label|0) == 247) {
        $692 = ___cxa_find_matching_catch_2()|0;
        $693 = tempRet0;
        $$5 = $692;$$559 = $693;
       }
       else if ((label|0) == 254) {
        $712 = ((($23)) + 11|0);
        $713 = HEAP8[$712>>0]|0;
        $714 = ($713<<24>>24)<(0);
        $715 = ((($23)) + 4|0);
        $716 = HEAP32[$715>>2]|0;
        $717 = $713&255;
        $718 = $714 ? $716 : $717;
        $719 = ($718|0)==(0);
        do {
         if ($719) {
          $742 = HEAP8[$609>>0]|0;
          $743 = ($742<<24>>24)<(0);
          if ($743) {
           $744 = HEAP32[$608>>2]|0;
           $745 = $744;
          } else {
           $745 = $608;
          }
          HEAP32[$26>>2] = $745;
          $746 = HEAP8[$632>>0]|0;
          $747 = ($746<<24>>24)<(0);
          $748 = HEAP32[$19>>2]|0;
          $749 = $747 ? $748 : $19;
          $750 = ((($26)) + 4|0);
          HEAP32[$750>>2] = $749;
          $751 = ((($0)) + 16|0);
          $752 = HEAP32[$751>>2]|0;
          $753 = ((($752)) + 172|0);
          $754 = HEAP32[$753>>2]|0;
          $755 = ((($0)) + 20|0);
          $756 = HEAP32[$755>>2]|0;
          __THREW__ = 0;
          invoke_viiii($754|0,($756|0),2,($26|0),(0|0));
          $757 = __THREW__; __THREW__ = 0;
          $758 = $757&1;
          if ($758) {
           $759 = ___cxa_find_matching_catch_2()|0;
           $760 = tempRet0;
           $$5 = $759;$$559 = $760;
           break L337;
          } else {
           break;
          }
         } else {
          $720 = HEAP32[$23>>2]|0;
          $721 = $714 ? $720 : $23;
          HEAP32[$25>>2] = $721;
          $722 = HEAP8[$609>>0]|0;
          $723 = ($722<<24>>24)<(0);
          if ($723) {
           $724 = HEAP32[$608>>2]|0;
           $726 = $724;
          } else {
           $726 = $608;
          }
          $725 = ((($25)) + 4|0);
          HEAP32[$725>>2] = $726;
          $727 = HEAP8[$632>>0]|0;
          $728 = ($727<<24>>24)<(0);
          $729 = HEAP32[$19>>2]|0;
          $730 = $728 ? $729 : $19;
          $731 = ((($25)) + 8|0);
          HEAP32[$731>>2] = $730;
          $732 = ((($0)) + 16|0);
          $733 = HEAP32[$732>>2]|0;
          $734 = ((($733)) + 172|0);
          $735 = HEAP32[$734>>2]|0;
          $736 = ((($0)) + 20|0);
          $737 = HEAP32[$736>>2]|0;
          __THREW__ = 0;
          invoke_viiii($735|0,($737|0),3,($25|0),(0|0));
          $738 = __THREW__; __THREW__ = 0;
          $739 = $738&1;
          if ($739) {
           $740 = ___cxa_find_matching_catch_2()|0;
           $741 = tempRet0;
           $$5 = $740;$$559 = $741;
           break L337;
          } else {
           break;
          }
         }
        } while(0);
        $761 = HEAP8[$712>>0]|0;
        $762 = ($761<<24>>24)<(0);
        if ($762) {
         $763 = HEAP32[$23>>2]|0;
         __ZdlPv($763);
        }
        $$pre317 = ((($0)) + 16|0);
        $$pre318 = ((($0)) + 20|0);
        $$pre$phi319Z2D = $$pre318;$$pre$phiZ2D = $$pre317;
        label = 273;
        break L291;
       }
      } while(0);
      $764 = ((($23)) + 11|0);
      $765 = HEAP8[$764>>0]|0;
      $766 = ($765<<24>>24)<(0);
      if ($766) {
       $767 = HEAP32[$23>>2]|0;
       __ZdlPv($767);
      }
      $$6 = $$5;$$660 = $$559;
     }
    } while(0);
    L365: do {
     if ((label|0) == 273) {
      $768 = HEAP32[$$pre$phiZ2D>>2]|0;
      $769 = ((($768)) + 52|0);
      $770 = HEAP32[$769>>2]|0;
      $771 = HEAP32[$$pre$phi319Z2D>>2]|0;
      __THREW__ = 0;
      invoke_vi($770|0,($771|0));
      $772 = __THREW__; __THREW__ = 0;
      $773 = $772&1;
      L367: do {
       if ($773) {
        label = 245;
       } else {
        $774 = HEAP32[$$pre$phiZ2D>>2]|0;
        $775 = ((($774)) + 120|0);
        $776 = HEAP32[$775>>2]|0;
        $777 = HEAP32[$$pre$phi319Z2D>>2]|0;
        __THREW__ = 0;
        invoke_viii($776|0,($777|0),35713,($21|0));
        $778 = __THREW__; __THREW__ = 0;
        $779 = $778&1;
        if ($779) {
         label = 245;
        } else {
         $780 = HEAP32[$21>>2]|0;
         $781 = ($780|0)==(1);
         $782 = ((($0)) + 37|0);
         $783 = $781&1;
         HEAP8[$782>>0] = $783;
         L370: do {
          if ($781) {
           ;HEAP32[$28>>2]=0|0;HEAP32[$28+4>>2]=0|0;HEAP32[$28+8>>2]=0|0;
           $930 = HEAP32[$$pre$phiZ2D>>2]|0;
           $931 = HEAP32[$$pre$phi319Z2D>>2]|0;
           __THREW__ = 0;
           $932 = (invoke_iiii(3885,($930|0),($931|0),($28|0))|0);
           $933 = __THREW__; __THREW__ = 0;
           $934 = $933&1;
           L372: do {
            if ($934) {
             label = 358;
            } else {
             L374: do {
              if ($932) {
               __THREW__ = 0;
               $935 = (invoke_ii(3265,4)|0);
               $936 = __THREW__; __THREW__ = 0;
               $937 = $936&1;
               if ($937) {
                label = 358;
                break L372;
               }
               if ($935) {
                __THREW__ = 0;
                $938 = (invoke_ii(3266,4)|0);
                $939 = __THREW__; __THREW__ = 0;
                $940 = $939&1;
                if ($940) {
                 label = 358;
                 break L372;
                }
                $941 = HEAP32[$32>>2]|0;
                $942 = ((($941)) + 32|0);
                $943 = HEAP32[$942>>2]|0;
                switch ($943|0) {
                case 35633:  {
                 $$0$i204 = 147774;
                 break;
                }
                case 36488:  {
                 $$0$i204 = 147762;
                 break;
                }
                case 36487:  {
                 $$0$i204 = 147747;
                 break;
                }
                case 36313:  {
                 $$0$i204 = 147738;
                 break;
                }
                case 35632:  {
                 $$0$i204 = 147729;
                 break;
                }
                case 37305:  {
                 $$0$i204 = 147721;
                 break;
                }
                default: {
                 $$0$i204 = 156745;
                }
                }
                $944 = (_strlen($$0$i204)|0);
                __THREW__ = 0;
                $945 = (invoke_iiii(3267,($938|0),($$0$i204|0),($944|0))|0);
                $946 = __THREW__; __THREW__ = 0;
                $947 = $946&1;
                if ($947) {
                 label = 358;
                 break L372;
                }
                __THREW__ = 0;
                $948 = (invoke_iiii(3267,($945|0),(147920|0),9)|0);
                $949 = __THREW__; __THREW__ = 0;
                $950 = $949&1;
                if ($950) {
                 label = 358;
                 break L372;
                }
                $951 = HEAP32[$32>>2]|0;
                $952 = ((($951)) + 12|0);
                $953 = ((($952)) + 11|0);
                $954 = HEAP8[$953>>0]|0;
                $955 = ($954<<24>>24)<(0);
                $956 = HEAP32[$952>>2]|0;
                $957 = $955 ? $956 : $952;
                $958 = ((($951)) + 16|0);
                $959 = HEAP32[$958>>2]|0;
                $960 = $954&255;
                $961 = $955 ? $959 : $960;
                __THREW__ = 0;
                $962 = (invoke_iiii(3267,($948|0),($957|0),($961|0))|0);
                $963 = __THREW__; __THREW__ = 0;
                $964 = $963&1;
                if ($964) {
                 label = 358;
                 break L372;
                }
                __THREW__ = 0;
                $965 = (invoke_iiii(3267,($962|0),(147930|0),11)|0);
                $966 = __THREW__; __THREW__ = 0;
                $967 = $966&1;
                if ($967) {
                 label = 358;
                 break L372;
                }
                $968 = ((($28)) + 11|0);
                $969 = HEAP8[$968>>0]|0;
                $970 = ($969<<24>>24)<(0);
                $971 = HEAP32[$28>>2]|0;
                $972 = $970 ? $971 : $28;
                $973 = ((($28)) + 4|0);
                $974 = HEAP32[$973>>2]|0;
                $975 = $969&255;
                $976 = $970 ? $974 : $975;
                __THREW__ = 0;
                $977 = (invoke_iiii(3267,($965|0),($972|0),($976|0))|0);
                $978 = __THREW__; __THREW__ = 0;
                $979 = $978&1;
                if ($979) {
                 label = 358;
                 break L372;
                }
                $980 = HEAP32[$977>>2]|0;
                $981 = ((($980)) + -12|0);
                $982 = HEAP32[$981>>2]|0;
                $983 = (($977) + ($982)|0);
                __THREW__ = 0;
                invoke_vii(3257,($4|0),($983|0));
                $984 = __THREW__; __THREW__ = 0;
                $985 = $984&1;
                if ($985) {
                 label = 358;
                 break L372;
                }
                __THREW__ = 0;
                $986 = (invoke_iii(3255,($4|0),(215188|0))|0);
                $987 = __THREW__; __THREW__ = 0;
                $988 = $987&1;
                do {
                 if (!($988)) {
                  $989 = HEAP32[$986>>2]|0;
                  $990 = ((($989)) + 28|0);
                  $991 = HEAP32[$990>>2]|0;
                  __THREW__ = 0;
                  $992 = (invoke_iii($991|0,($986|0),10)|0);
                  $993 = __THREW__; __THREW__ = 0;
                  $994 = $993&1;
                  if ($994) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3263,($4|0));
                  $995 = __THREW__; __THREW__ = 0;
                  $996 = $995&1;
                  if ($996) {
                   label = 358;
                   break L372;
                  }
                  __THREW__ = 0;
                  (invoke_iii(3268,($977|0),($992|0))|0);
                  $1003 = __THREW__; __THREW__ = 0;
                  $1004 = $1003&1;
                  if ($1004) {
                   label = 358;
                   break L372;
                  }
                  __THREW__ = 0;
                  (invoke_ii(3269,($977|0))|0);
                  $1005 = __THREW__; __THREW__ = 0;
                  $1006 = $1005&1;
                  if ($1006) {
                   label = 358;
                   break L372;
                  } else {
                   break L374;
                  }
                 }
                } while(0);
                $997 = ___cxa_find_matching_catch_2()|0;
                $998 = tempRet0;
                __THREW__ = 0;
                invoke_vi(3263,($4|0));
                $999 = __THREW__; __THREW__ = 0;
                $1000 = $999&1;
                if ($1000) {
                 $1001 = ___cxa_find_matching_catch_3(0|0)|0;
                 $1002 = tempRet0;
                 ___clang_call_terminate($1001);
                 // unreachable;
                } else {
                 $$pre$phi323Z2D = $968;$eh$lpad$body233$index47Z2D = $998;$eh$lpad$body233$indexZ2D = $997;
                 break L372;
                }
               }
              }
             } while(0);
             $1012 = HEAP32[$$pre$phiZ2D>>2]|0;
             $1013 = HEAP32[$$pre$phi319Z2D>>2]|0;
             $1014 = HEAP32[$32>>2]|0;
             $1015 = ((($1014)) + 12|0);
             $1016 = ((($1012)) + 1688|0);
             $1017 = HEAP32[$1016>>2]|0;
             $1018 = ($1017|0)==(0|0);
             if (!($1018)) {
              $1019 = ((($1015)) + 11|0);
              $1020 = HEAP8[$1019>>0]|0;
              $1021 = ($1020<<24>>24)<(0);
              $1022 = ((($1014)) + 16|0);
              $1023 = HEAP32[$1022>>2]|0;
              $1024 = $1020&255;
              $1025 = $1021 ? $1023 : $1024;
              $1026 = ($1025|0)==(0);
              if (!($1026)) {
               $1027 = HEAP32[$1015>>2]|0;
               $1028 = $1021 ? $1027 : $1015;
               __THREW__ = 0;
               invoke_viiii($1017|0,33505,($1013|0),($1025|0),($1028|0));
               $1029 = __THREW__; __THREW__ = 0;
               $1030 = $1029&1;
               if ($1030) {
                label = 358;
                break;
               }
              }
             }
             $1031 = ((($28)) + 11|0);
             $1032 = HEAP8[$1031>>0]|0;
             $1033 = ($1032<<24>>24)<(0);
             if ($1033) {
              $1034 = HEAP32[$28>>2]|0;
              __ZdlPv($1034);
             }
             break L370;
            }
           } while(0);
           if ((label|0) == 358) {
            $1007 = ___cxa_find_matching_catch_2()|0;
            $1008 = tempRet0;
            $$pre322 = ((($28)) + 11|0);
            $$pre$phi323Z2D = $$pre322;$eh$lpad$body233$index47Z2D = $1008;$eh$lpad$body233$indexZ2D = $1007;
           }
           $1009 = HEAP8[$$pre$phi323Z2D>>0]|0;
           $1010 = ($1009<<24>>24)<(0);
           if ($1010) {
            $1011 = HEAP32[$28>>2]|0;
            __ZdlPv($1011);
           }
           $$6 = $eh$lpad$body233$indexZ2D;$$660 = $eh$lpad$body233$index47Z2D;
           break L365;
          } else {
           __THREW__ = 0;
           $784 = (invoke_ii(3265,2)|0);
           $785 = __THREW__; __THREW__ = 0;
           $786 = $785&1;
           if ($786) {
            label = 245;
            break L367;
           }
           L418: do {
            if ($784) {
             __THREW__ = 0;
             $787 = (invoke_ii(3266,2)|0);
             $788 = __THREW__; __THREW__ = 0;
             $789 = $788&1;
             if ($789) {
              label = 245;
              break L367;
             }
             $790 = HEAP32[$32>>2]|0;
             $791 = ((($790)) + 32|0);
             $792 = HEAP32[$791>>2]|0;
             switch ($792|0) {
             case 35633:  {
              $$0$i159 = 147774;
              break;
             }
             case 36488:  {
              $$0$i159 = 147762;
              break;
             }
             case 36487:  {
              $$0$i159 = 147747;
              break;
             }
             case 36313:  {
              $$0$i159 = 147738;
              break;
             }
             case 35632:  {
              $$0$i159 = 147729;
              break;
             }
             case 37305:  {
              $$0$i159 = 147721;
              break;
             }
             default: {
              $$0$i159 = 156745;
             }
             }
             $793 = (_strlen($$0$i159)|0);
             __THREW__ = 0;
             $794 = (invoke_iiii(3267,($787|0),($$0$i159|0),($793|0))|0);
             $795 = __THREW__; __THREW__ = 0;
             $796 = $795&1;
             if ($796) {
              label = 245;
              break L367;
             }
             __THREW__ = 0;
             $797 = (invoke_iiii(3267,($794|0),(147892|0),18)|0);
             $798 = __THREW__; __THREW__ = 0;
             $799 = $798&1;
             if ($799) {
              label = 245;
              break L367;
             }
             $800 = HEAP32[$32>>2]|0;
             $801 = ((($800)) + 12|0);
             $802 = ((($801)) + 11|0);
             $803 = HEAP8[$802>>0]|0;
             $804 = ($803<<24>>24)<(0);
             $805 = HEAP32[$801>>2]|0;
             $806 = $804 ? $805 : $801;
             $807 = ((($800)) + 16|0);
             $808 = HEAP32[$807>>2]|0;
             $809 = $803&255;
             $810 = $804 ? $808 : $809;
             __THREW__ = 0;
             $811 = (invoke_iiii(3267,($797|0),($806|0),($810|0))|0);
             $812 = __THREW__; __THREW__ = 0;
             $813 = $812&1;
             if ($813) {
              label = 245;
              break L367;
             }
             __THREW__ = 0;
             $814 = (invoke_iiii(3267,($811|0),(147911|0),8)|0);
             $815 = __THREW__; __THREW__ = 0;
             $816 = $815&1;
             if ($816) {
              label = 245;
              break L367;
             }
             $817 = HEAP32[$814>>2]|0;
             $818 = ((($817)) + -12|0);
             $819 = HEAP32[$818>>2]|0;
             $820 = (($814) + ($819)|0);
             __THREW__ = 0;
             invoke_vii(3257,($6|0),($820|0));
             $821 = __THREW__; __THREW__ = 0;
             $822 = $821&1;
             if ($822) {
              label = 245;
              break L367;
             }
             __THREW__ = 0;
             $823 = (invoke_iii(3255,($6|0),(215188|0))|0);
             $824 = __THREW__; __THREW__ = 0;
             $825 = $824&1;
             do {
              if (!($825)) {
               $826 = HEAP32[$823>>2]|0;
               $827 = ((($826)) + 28|0);
               $828 = HEAP32[$827>>2]|0;
               __THREW__ = 0;
               $829 = (invoke_iii($828|0,($823|0),10)|0);
               $830 = __THREW__; __THREW__ = 0;
               $831 = $830&1;
               if ($831) {
                break;
               }
               __THREW__ = 0;
               invoke_vi(3263,($6|0));
               $832 = __THREW__; __THREW__ = 0;
               $833 = $832&1;
               if ($833) {
                label = 245;
                break L367;
               }
               __THREW__ = 0;
               (invoke_iii(3268,($814|0),($829|0))|0);
               $840 = __THREW__; __THREW__ = 0;
               $841 = $840&1;
               if ($841) {
                label = 245;
                break L367;
               }
               __THREW__ = 0;
               (invoke_ii(3269,($814|0))|0);
               $842 = __THREW__; __THREW__ = 0;
               $843 = $842&1;
               if ($843) {
                label = 245;
                break L367;
               } else {
                break L418;
               }
              }
             } while(0);
             $834 = ___cxa_find_matching_catch_2()|0;
             $835 = tempRet0;
             __THREW__ = 0;
             invoke_vi(3263,($6|0));
             $836 = __THREW__; __THREW__ = 0;
             $837 = $836&1;
             if ($837) {
              $838 = ___cxa_find_matching_catch_3(0|0)|0;
              $839 = tempRet0;
              ___clang_call_terminate($838);
              // unreachable;
             } else {
              $eh$lpad$body182$index37Z2D = $835;$eh$lpad$body182$indexZ2D = $834;
              break L367;
             }
            }
           } while(0);
           ;HEAP32[$27>>2]=0|0;HEAP32[$27+4>>2]=0|0;HEAP32[$27+8>>2]=0|0;
           $844 = HEAP32[$$pre$phiZ2D>>2]|0;
           $845 = HEAP32[$$pre$phi319Z2D>>2]|0;
           __THREW__ = 0;
           $846 = (invoke_iiii(3885,($844|0),($845|0),($27|0))|0);
           $847 = __THREW__; __THREW__ = 0;
           $848 = $847&1;
           L444: do {
            if ($848) {
             label = 325;
            } else {
             L446: do {
              if ($846) {
               __THREW__ = 0;
               $849 = (invoke_ii(3265,2)|0);
               $850 = __THREW__; __THREW__ = 0;
               $851 = $850&1;
               if ($851) {
                label = 325;
                break L444;
               }
               if (!($849)) {
                break;
               }
               __THREW__ = 0;
               $852 = (invoke_ii(3266,2)|0);
               $853 = __THREW__; __THREW__ = 0;
               $854 = $853&1;
               if ($854) {
                label = 325;
                break L444;
               }
               $855 = HEAP32[$32>>2]|0;
               $856 = ((($855)) + 32|0);
               $857 = HEAP32[$856>>2]|0;
               switch ($857|0) {
               case 35633:  {
                $$0$i176 = 147774;
                break;
               }
               case 36488:  {
                $$0$i176 = 147762;
                break;
               }
               case 36487:  {
                $$0$i176 = 147747;
                break;
               }
               case 36313:  {
                $$0$i176 = 147738;
                break;
               }
               case 35632:  {
                $$0$i176 = 147729;
                break;
               }
               case 37305:  {
                $$0$i176 = 147721;
                break;
               }
               default: {
                $$0$i176 = 156745;
               }
               }
               $858 = (_strlen($$0$i176)|0);
               __THREW__ = 0;
               $859 = (invoke_iiii(3267,($852|0),($$0$i176|0),($858|0))|0);
               $860 = __THREW__; __THREW__ = 0;
               $861 = $860&1;
               if ($861) {
                label = 325;
                break L444;
               }
               __THREW__ = 0;
               $862 = (invoke_iiii(3267,($859|0),(147920|0),9)|0);
               $863 = __THREW__; __THREW__ = 0;
               $864 = $863&1;
               if ($864) {
                label = 325;
                break L444;
               }
               $865 = HEAP32[$32>>2]|0;
               $866 = ((($865)) + 12|0);
               $867 = ((($866)) + 11|0);
               $868 = HEAP8[$867>>0]|0;
               $869 = ($868<<24>>24)<(0);
               $870 = HEAP32[$866>>2]|0;
               $871 = $869 ? $870 : $866;
               $872 = ((($865)) + 16|0);
               $873 = HEAP32[$872>>2]|0;
               $874 = $868&255;
               $875 = $869 ? $873 : $874;
               __THREW__ = 0;
               $876 = (invoke_iiii(3267,($862|0),($871|0),($875|0))|0);
               $877 = __THREW__; __THREW__ = 0;
               $878 = $877&1;
               if ($878) {
                label = 325;
                break L444;
               }
               __THREW__ = 0;
               $879 = (invoke_iiii(3267,($876|0),(147930|0),11)|0);
               $880 = __THREW__; __THREW__ = 0;
               $881 = $880&1;
               if ($881) {
                label = 325;
                break L444;
               }
               $882 = ((($27)) + 11|0);
               $883 = HEAP8[$882>>0]|0;
               $884 = ($883<<24>>24)<(0);
               $885 = HEAP32[$27>>2]|0;
               $886 = $884 ? $885 : $27;
               $887 = ((($27)) + 4|0);
               $888 = HEAP32[$887>>2]|0;
               $889 = $883&255;
               $890 = $884 ? $888 : $889;
               __THREW__ = 0;
               $891 = (invoke_iiii(3267,($879|0),($886|0),($890|0))|0);
               $892 = __THREW__; __THREW__ = 0;
               $893 = $892&1;
               if ($893) {
                label = 325;
                break L444;
               }
               $894 = HEAP32[$891>>2]|0;
               $895 = ((($894)) + -12|0);
               $896 = HEAP32[$895>>2]|0;
               $897 = (($891) + ($896)|0);
               __THREW__ = 0;
               invoke_vii(3257,($5|0),($897|0));
               $898 = __THREW__; __THREW__ = 0;
               $899 = $898&1;
               if ($899) {
                label = 325;
                break L444;
               }
               __THREW__ = 0;
               $900 = (invoke_iii(3255,($5|0),(215188|0))|0);
               $901 = __THREW__; __THREW__ = 0;
               $902 = $901&1;
               do {
                if (!($902)) {
                 $903 = HEAP32[$900>>2]|0;
                 $904 = ((($903)) + 28|0);
                 $905 = HEAP32[$904>>2]|0;
                 __THREW__ = 0;
                 $906 = (invoke_iii($905|0,($900|0),10)|0);
                 $907 = __THREW__; __THREW__ = 0;
                 $908 = $907&1;
                 if ($908) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3263,($5|0));
                 $909 = __THREW__; __THREW__ = 0;
                 $910 = $909&1;
                 if ($910) {
                  label = 325;
                  break L444;
                 }
                 __THREW__ = 0;
                 (invoke_iii(3268,($891|0),($906|0))|0);
                 $917 = __THREW__; __THREW__ = 0;
                 $918 = $917&1;
                 if ($918) {
                  label = 325;
                  break L444;
                 }
                 __THREW__ = 0;
                 (invoke_ii(3269,($891|0))|0);
                 $919 = __THREW__; __THREW__ = 0;
                 $920 = $919&1;
                 if ($920) {
                  label = 325;
                  break L444;
                 } else {
                  break L446;
                 }
                }
               } while(0);
               $911 = ___cxa_find_matching_catch_2()|0;
               $912 = tempRet0;
               __THREW__ = 0;
               invoke_vi(3263,($5|0));
               $913 = __THREW__; __THREW__ = 0;
               $914 = $913&1;
               if ($914) {
                $915 = ___cxa_find_matching_catch_3(0|0)|0;
                $916 = tempRet0;
                ___clang_call_terminate($915);
                // unreachable;
               } else {
                $$pre$phi327Z2D = $882;$eh$lpad$body210$index42Z2D = $912;$eh$lpad$body210$indexZ2D = $911;
                break L444;
               }
              }
             } while(0);
             $926 = ((($27)) + 11|0);
             $927 = HEAP8[$926>>0]|0;
             $928 = ($927<<24>>24)<(0);
             if ($928) {
              $929 = HEAP32[$27>>2]|0;
              __ZdlPv($929);
             }
             break L370;
            }
           } while(0);
           if ((label|0) == 325) {
            $921 = ___cxa_find_matching_catch_2()|0;
            $922 = tempRet0;
            $$pre326 = ((($27)) + 11|0);
            $$pre$phi327Z2D = $$pre326;$eh$lpad$body210$index42Z2D = $922;$eh$lpad$body210$indexZ2D = $921;
           }
           $923 = HEAP8[$$pre$phi327Z2D>>0]|0;
           $924 = ($923<<24>>24)<(0);
           if ($924) {
            $925 = HEAP32[$27>>2]|0;
            __ZdlPv($925);
           }
           $$6 = $eh$lpad$body210$indexZ2D;$$660 = $eh$lpad$body210$index42Z2D;
           break L365;
          }
         } while(0);
         $1035 = ((($19)) + 11|0);
         $1036 = HEAP8[$1035>>0]|0;
         $1037 = ($1036<<24>>24)<(0);
         if ($1037) {
          $1038 = HEAP32[$19>>2]|0;
          __ZdlPv($1038);
         }
         STACKTOP = sp;return;
        }
       }
      } while(0);
      if ((label|0) == 245) {
       $690 = ___cxa_find_matching_catch_2()|0;
       $691 = tempRet0;
       $eh$lpad$body182$index37Z2D = $691;$eh$lpad$body182$indexZ2D = $690;
      }
      $$6 = $eh$lpad$body182$indexZ2D;$$660 = $eh$lpad$body182$index37Z2D;
     }
    } while(0);
    $$7 = $$6;$$761 = $$660;
   }
  }
 } while(0);
 if ((label|0) == 103) {
  $306 = ___cxa_find_matching_catch_2()|0;
  $307 = tempRet0;
  $$5$i$sink = $307;$$532$i$sink = $306;
  label = 104;
 }
 if ((label|0) == 104) {
  $$7 = $$532$i$sink;$$761 = $$5$i$sink;
 }
 $1039 = ((($19)) + 11|0);
 $1040 = HEAP8[$1039>>0]|0;
 $1041 = ($1040<<24>>24)<(0);
 if ($1041) {
  $1042 = HEAP32[$19>>2]|0;
  __ZdlPv($1042);
 }
 $$8 = $$7;$$862 = $$761;
 ___resumeException($$8|0);
 // unreachable;
}
function __ZN3osg14buffered_valueINS_7ref_ptrINS_6Shader13ShaderObjectsEEEEixEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$pre = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = ((($0)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$0>>2]|0;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 2;
 $8 = ($7>>>0)>($1>>>0);
 $9 = $5;
 if ($8) {
  $47 = $9;
  $46 = (($47) + ($1<<2)|0);
  STACKTOP = sp;return ($46|0);
 }
 $10 = (($1) + 1)|0;
 HEAP32[$2>>2] = 0;
 $11 = ($10>>>0)>($7>>>0);
 $12 = $4;
 L4: do {
  if ($11) {
   $13 = (($10) - ($7))|0;
   __THREW__ = 0;
   invoke_viii(3886,($0|0),($13|0),($2|0));
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if ($15) {
    $37 = ___cxa_find_matching_catch_2()|0;
    $38 = tempRet0;
    $39 = HEAP32[$2>>2]|0;
    $40 = ($39|0)==(0|0);
    if ($40) {
     ___resumeException($37|0);
     // unreachable;
    }
    $41 = ((($39)) + 8|0);
    $42 = HEAP32[$41>>2]|0;HEAP32[$41>>2] = (($42-1)|0);
    $43 = ($42|0)==(1);
    if (!($43)) {
     ___resumeException($37|0);
     // unreachable;
    }
    __THREW__ = 0;
    invoke_viii(3262,($39|0),1,1);
    $44 = __THREW__; __THREW__ = 0;
    $45 = $44&1;
    if ($45) {
     $48 = ___cxa_find_matching_catch_3(0|0)|0;
     $49 = tempRet0;
     ___clang_call_terminate($48);
     // unreachable;
    } else {
     ___resumeException($37|0);
     // unreachable;
    }
   }
  } else {
   $16 = ($10>>>0)<($7>>>0);
   if ($16) {
    $17 = (($9) + ($10<<2)|0);
    $18 = ($12|0)==($17|0);
    if (!($18)) {
     $20 = $12;
     while(1) {
      $19 = ((($20)) + -4|0);
      HEAP32[$3>>2] = $19;
      $21 = HEAP32[$19>>2]|0;
      $22 = ($21|0)==(0|0);
      if (!($22)) {
       $23 = ((($21)) + 8|0);
       $24 = HEAP32[$23>>2]|0;HEAP32[$23>>2] = (($24-1)|0);
       $25 = ($24|0)==(1);
       if ($25) {
        __THREW__ = 0;
        invoke_viii(3262,($21|0),1,1);
        $26 = __THREW__; __THREW__ = 0;
        $27 = $26&1;
        if ($27) {
         break;
        }
       }
      }
      HEAP32[$19>>2] = 0;
      $28 = HEAP32[$3>>2]|0;
      $29 = ($28|0)==($17|0);
      if ($29) {
       break L4;
      } else {
       $20 = $28;
      }
     }
     $30 = ___cxa_find_matching_catch_2()|0;
     $31 = tempRet0;
     ___cxa_call_unexpected(($30|0));
     // unreachable;
    }
   }
  }
 } while(0);
 $32 = HEAP32[$2>>2]|0;
 $33 = ($32|0)==(0|0);
 if (!($33)) {
  $34 = ((($32)) + 8|0);
  $35 = HEAP32[$34>>2]|0;HEAP32[$34>>2] = (($35-1)|0);
  $36 = ($35|0)==(1);
  if ($36) {
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($32,1,1);
  }
 }
 $$pre = HEAP32[$0>>2]|0;
 $47 = $$pre;
 $46 = (($47) + ($1<<2)|0);
 STACKTOP = sp;return ($46|0);
}
function __ZN3osg6Shader13ShaderObjects22createPerContextShaderERKNSt3__212basic_stringIcNS2_11char_traitsIcEENS2_9allocatorIcEEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$08 = 0, $$pre$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = (__Znwj(44)|0);
 $4 = ((($0)) + 16|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($0)) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 __THREW__ = 0;
 invoke_viii(3887,($3|0),($5|0),($7|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $32 = ___cxa_find_matching_catch_2()|0;
  $33 = tempRet0;
  __ZdlPv($3);
  $$0 = $33;$$08 = $32;
  ___resumeException($$08|0);
  // unreachable;
 }
 HEAP32[$2>>2] = $3;
 $10 = ((($3)) + 8|0);
 $11 = HEAP32[$10>>2]|0;HEAP32[$10>>2] = (($11+1)|0);
 $12 = ((($0)) + 24|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($0)) + 28|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($13|0)==($15|0);
 if ($16) {
  $23 = ((($0)) + 20|0);
  __THREW__ = 0;
  invoke_vii(3888,($23|0),($2|0));
  $24 = __THREW__; __THREW__ = 0;
  $25 = $24&1;
  if ($25) {
   $34 = ___cxa_find_matching_catch_2()|0;
   $35 = tempRet0;
   $36 = HEAP32[$2>>2]|0;
   $37 = ($36|0)==(0|0);
   if (!($37)) {
    $38 = ((($36)) + 8|0);
    $39 = HEAP32[$38>>2]|0;HEAP32[$38>>2] = (($39-1)|0);
    $40 = ($39|0)==(1);
    if ($40) {
     __THREW__ = 0;
     invoke_viii(3262,($36|0),1,1);
     $41 = __THREW__; __THREW__ = 0;
     $42 = $41&1;
     if ($42) {
      $43 = ___cxa_find_matching_catch_3(0|0)|0;
      $44 = tempRet0;
      ___clang_call_terminate($43);
      // unreachable;
     }
    }
   }
   $$0 = $35;$$08 = $34;
   ___resumeException($$08|0);
   // unreachable;
  }
 } else {
  $17 = HEAP32[$2>>2]|0;
  HEAP32[$13>>2] = $17;
  $18 = ($17|0)==(0|0);
  if ($18) {
   $22 = $13;
  } else {
   $19 = ((($17)) + 8|0);
   $20 = HEAP32[$19>>2]|0;HEAP32[$19>>2] = (($20+1)|0);
   $$pre$i = HEAP32[$12>>2]|0;
   $22 = $$pre$i;
  }
  $21 = ((($22)) + 4|0);
  HEAP32[$12>>2] = $21;
 }
 $26 = HEAP32[$2>>2]|0;
 $27 = ($26|0)==(0|0);
 if ($27) {
  $31 = ((($3)) + 24|0);
  (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEaSERKS5_($31,$1)|0);
  STACKTOP = sp;return ($3|0);
 }
 $28 = ((($26)) + 8|0);
 $29 = HEAP32[$28>>2]|0;HEAP32[$28>>2] = (($29-1)|0);
 $30 = ($29|0)==(1);
 if (!($30)) {
  $31 = ((($3)) + 24|0);
  (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEaSERKS5_($31,$1)|0);
  STACKTOP = sp;return ($3|0);
 }
 __ZNK3osg10Referenced24signalObserversAndDeleteEbb($26,1,1);
 $31 = ((($3)) + 24|0);
 (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEaSERKS5_($31,$1)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN3osg6Shader16PerContextShaderC2EPKS0_j($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg10ReferencedC2Ev($0);
 HEAP32[$0>>2] = (65568);
 $3 = ((($0)) + 16|0);
 HEAP32[$3>>2] = 0;
 $4 = ((($0)) + 24|0);
 ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;
 $5 = ((($0)) + 40|0);
 HEAP32[$5>>2] = $2;
 $6 = ((($0)) + 12|0);
 HEAP32[$6>>2] = $1;
 __THREW__ = 0;
 $7 = (invoke_iii(3718,($2|0),1)|0);
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 do {
  if (!($9)) {
   $10 = HEAP32[$3>>2]|0;
   $11 = ($10|0)==($7|0);
   if (!($11)) {
    HEAP32[$3>>2] = $7;
    $12 = ($7|0)==(0|0);
    if (!($12)) {
     $13 = ((($7)) + 8|0);
     $14 = HEAP32[$13>>2]|0;HEAP32[$13>>2] = (($14+1)|0);
    }
    $15 = ($10|0)==(0|0);
    if (!($15)) {
     $16 = ((($10)) + 8|0);
     $17 = HEAP32[$16>>2]|0;HEAP32[$16>>2] = (($17-1)|0);
     $18 = ($17|0)==(1);
     if ($18) {
      __THREW__ = 0;
      invoke_viii(3262,($10|0),1,1);
      $19 = __THREW__; __THREW__ = 0;
      $20 = $19&1;
      if ($20) {
       break;
      }
     }
    }
   }
   $21 = HEAP32[$3>>2]|0;
   $22 = ((($21)) + 60|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = ((($1)) + 32|0);
   $25 = HEAP32[$24>>2]|0;
   __THREW__ = 0;
   $26 = (invoke_ii($23|0,($25|0))|0);
   $27 = __THREW__; __THREW__ = 0;
   $28 = $27&1;
   if (!($28)) {
    $29 = ((($0)) + 20|0);
    HEAP32[$29>>2] = $26;
    $30 = ((($0)) + 36|0);
    HEAP8[$30>>0] = 1;
    $31 = ((($0)) + 37|0);
    HEAP8[$31>>0] = 0;
    return;
   }
  }
 } while(0);
 $32 = ___cxa_find_matching_catch_2()|0;
 $33 = tempRet0;
 $34 = ((($4)) + 11|0);
 $35 = HEAP8[$34>>0]|0;
 $36 = ($35<<24>>24)<(0);
 if ($36) {
  $37 = HEAP32[$4>>2]|0;
  __ZdlPv($37);
 }
 $38 = HEAP32[$3>>2]|0;
 $39 = ($38|0)==(0|0);
 if (!($39)) {
  $40 = ((($38)) + 8|0);
  $41 = HEAP32[$40>>2]|0;HEAP32[$40>>2] = (($41-1)|0);
  $42 = ($41|0)==(1);
  if ($42) {
   __THREW__ = 0;
   invoke_viii(3262,($38|0),1,1);
   $43 = __THREW__; __THREW__ = 0;
   $44 = $43&1;
   if ($44) {
    $47 = ___cxa_find_matching_catch_3(0|0)|0;
    $48 = tempRet0;
    ___clang_call_terminate($47);
    // unreachable;
   }
  }
 }
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $45 = __THREW__; __THREW__ = 0;
 $46 = $45&1;
 if ($46) {
  $47 = ___cxa_find_matching_catch_3(0|0)|0;
  $48 = tempRet0;
  ___clang_call_terminate($47);
  // unreachable;
 } else {
  ___resumeException($32|0);
  // unreachable;
 }
}
function __ZNSt3__26vectorIN3osg7ref_ptrINS1_6Shader16PerContextShaderEEENS_9allocatorIS5_EEE21__push_back_slow_pathIKS5_EEvRT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$06$i$i = 0, $$pre = 0, $$pre$i = 0, $$pre38 = 0, $$pre39 = 0, $$sroa$7$0 = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(1073741823);
 $9 = $4;
 $10 = $3;
 if ($8) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $11 = ((($0)) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) - ($4))|0;
 $14 = $13 >> 2;
 $15 = ($14>>>0)<(536870911);
 $16 = $13 >> 1;
 $17 = ($16>>>0)<($7>>>0);
 $$sroa$speculated$i = $17 ? $7 : $16;
 $$sroa$speculated$$i = $15 ? $$sroa$speculated$i : 1073741823;
 $18 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($18) {
   $28 = 0;
  } else {
   $19 = ($$sroa$speculated$$i>>>0)>(1073741823);
   if (!($19)) {
    $25 = $$sroa$speculated$$i << 2;
    $26 = (__Znwj($25)|0);
    $28 = $26;
    break;
   }
   $20 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($20|0),(204840|0));
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if ($22) {
    $23 = ___cxa_find_matching_catch_2()|0;
    $24 = tempRet0;
    ___cxa_free_exception(($20|0));
    ___resumeException($23|0);
    // unreachable;
   } else {
    HEAP32[$20>>2] = (99824);
    ___cxa_throw(($20|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $27 = (($28) + ($6<<2)|0);
 $29 = $27;
 $30 = (($28) + ($$sroa$speculated$$i<<2)|0);
 $31 = $30;
 $32 = HEAP32[$1>>2]|0;
 HEAP32[$27>>2] = $32;
 $33 = ($32|0)==(0|0);
 if ($33) {
  $38 = $10;$40 = $9;
 } else {
  $34 = ((($32)) + 8|0);
  $35 = HEAP32[$34>>2]|0;HEAP32[$34>>2] = (($35+1)|0);
  $$pre = HEAP32[$0>>2]|0;
  $$pre38 = HEAP32[$2>>2]|0;
  $38 = $$pre38;$40 = $$pre;
 }
 $36 = ((($27)) + 4|0);
 $37 = $36;
 $39 = ($38|0)==($40|0);
 if ($39) {
  $41 = $38;
  $53 = $29;$54 = $41;$56 = $38;
 } else {
  $$06$i$i = $38;$$sroa$7$0 = $29;$44 = $27;
  while(1) {
   $42 = ((($$06$i$i)) + -4|0);
   $43 = ((($44)) + -4|0);
   $45 = HEAP32[$42>>2]|0;
   HEAP32[$43>>2] = $45;
   $46 = ($45|0)==(0|0);
   if (!($46)) {
    $47 = ((($45)) + 8|0);
    $48 = HEAP32[$47>>2]|0;HEAP32[$47>>2] = (($48+1)|0);
   }
   $49 = $$sroa$7$0;
   $50 = ((($49)) + -4|0);
   $51 = $50;
   $52 = ($42|0)==($40|0);
   if ($52) {
    break;
   } else {
    $$06$i$i = $42;$$sroa$7$0 = $51;$44 = $50;
   }
  }
  $$pre$i = HEAP32[$0>>2]|0;
  $$pre39 = HEAP32[$2>>2]|0;
  $53 = $51;$54 = $$pre$i;$56 = $$pre39;
 }
 HEAP32[$0>>2] = $53;
 HEAP32[$2>>2] = $37;
 HEAP32[$11>>2] = $31;
 $55 = $54;
 $57 = ($56|0)==($55|0);
 L25: do {
  if (!($57)) {
   $59 = $56;
   while(1) {
    $58 = ((($59)) + -4|0);
    $60 = HEAP32[$58>>2]|0;
    $61 = ($60|0)==(0|0);
    if (!($61)) {
     $62 = ((($60)) + 8|0);
     $63 = HEAP32[$62>>2]|0;HEAP32[$62>>2] = (($63-1)|0);
     $64 = ($63|0)==(1);
     if ($64) {
      __THREW__ = 0;
      invoke_viii(3262,($60|0),1,1);
      $65 = __THREW__; __THREW__ = 0;
      $66 = $65&1;
      if ($66) {
       break;
      }
     }
    }
    HEAP32[$58>>2] = 0;
    $67 = ($58|0)==($55|0);
    if ($67) {
     break L25;
    } else {
     $59 = $58;
    }
   }
   $68 = ___cxa_find_matching_catch_2()|0;
   $69 = tempRet0;
   ___cxa_call_unexpected(($68|0));
   // unreachable;
  }
 } while(0);
 $70 = ($54|0)==(0);
 if ($70) {
  return;
 }
 $71 = $54;
 __ZdlPv($71);
 return;
}
function __ZN3osg6Shader16PerContextShaderD2Ev($0) {
 $0 = $0|0;
 var $$0 = 0, $$02 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (65568);
 $1 = ((($0)) + 40|0);
 $2 = HEAP32[$1>>2]|0;
 __THREW__ = 0;
 $3 = (invoke_ii(3683,($2|0))|0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 do {
  if ($5) {
   label = 10;
  } else {
   __THREW__ = 0;
   $6 = (invoke_ii(3889,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    label = 10;
   } else {
    $9 = HEAP32[$6>>2]|0;
    $10 = ((($9)) + 44|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ((($0)) + 20|0);
    $13 = HEAP32[$12>>2]|0;
    __THREW__ = 0;
    invoke_vii($11|0,($6|0),($13|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     label = 10;
    } else {
     $16 = ((($0)) + 24|0);
     $17 = ((($16)) + 11|0);
     $18 = HEAP8[$17>>0]|0;
     $19 = ($18<<24>>24)<(0);
     if ($19) {
      $20 = HEAP32[$16>>2]|0;
      __ZdlPv($20);
     }
     $21 = ((($0)) + 16|0);
     $22 = HEAP32[$21>>2]|0;
     $23 = ($22|0)==(0|0);
     if ($23) {
      HEAP32[$21>>2] = 0;
      __ZN3osg10ReferencedD2Ev($0);
      return;
     }
     $24 = ((($22)) + 8|0);
     $25 = HEAP32[$24>>2]|0;HEAP32[$24>>2] = (($25-1)|0);
     $26 = ($25|0)==(1);
     if (!($26)) {
      HEAP32[$21>>2] = 0;
      __ZN3osg10ReferencedD2Ev($0);
      return;
     }
     __THREW__ = 0;
     invoke_viii(3262,($22|0),1,1);
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     if ($28) {
      $44 = ___cxa_find_matching_catch_2()|0;
      $45 = tempRet0;
      $$0 = $45;$$02 = $44;
      break;
     } else {
      HEAP32[$21>>2] = 0;
      __ZN3osg10ReferencedD2Ev($0);
      return;
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 10) {
  $29 = ___cxa_find_matching_catch_2()|0;
  $30 = tempRet0;
  $31 = ((($0)) + 24|0);
  $32 = ((($31)) + 11|0);
  $33 = HEAP8[$32>>0]|0;
  $34 = ($33<<24>>24)<(0);
  if ($34) {
   $35 = HEAP32[$31>>2]|0;
   __ZdlPv($35);
  }
  $36 = ((($0)) + 16|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = ($37|0)==(0|0);
  if (!($38)) {
   $39 = ((($37)) + 8|0);
   $40 = HEAP32[$39>>2]|0;HEAP32[$39>>2] = (($40-1)|0);
   $41 = ($40|0)==(1);
   if ($41) {
    __THREW__ = 0;
    invoke_viii(3262,($37|0),1,1);
    $42 = __THREW__; __THREW__ = 0;
    $43 = $42&1;
    if ($43) {
     $48 = ___cxa_find_matching_catch_3(0|0)|0;
     $49 = tempRet0;
     ___clang_call_terminate($48);
     // unreachable;
    }
   }
  }
  HEAP32[$36>>2] = 0;
  $$0 = $30;$$02 = $29;
 }
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $46 = __THREW__; __THREW__ = 0;
 $47 = $46&1;
 if ($47) {
  $48 = ___cxa_find_matching_catch_3(0|0)|0;
  $49 = tempRet0;
  ___clang_call_terminate($48);
  // unreachable;
 } else {
  ___resumeException($$02|0);
  // unreachable;
 }
}
function __ZN3osg6Shader16PerContextShaderD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(2213,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZN3osg11ContextData3getI15GLShaderManagerEEPT_v($0) {
 $0 = $0|0;
 var $$0$i$i = 0, $$0$ph$i$i = 0, $$014$i = 0, $$024$i$i = 0, $$025$i$i = 0, $$025$i53$i = 0, $$037$i = 0, $$03752$i = 0, $$in$i$i = 0, $$pre$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0;
 var dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $2 = ((($0)) + 36|0);
 $3 = ((($0)) + 40|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 do {
  if ($5) {
   $$025$i$i = $3;$$037$i = $3;$16 = $4;
   label = 12;
  } else {
   $6 = ((($0)) + 40|0);
   $$0$i$i = $6;$$024$i$i = $4;$68 = $4;
   while(1) {
    $7 = ((($$024$i$i)) + 16|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = ($8>>>0)>(26512>>>0);
    if ($9) {
     $10 = HEAP32[$$024$i$i>>2]|0;
     $11 = ($10|0)==(0|0);
     if ($11) {
      label = 6;
      break;
     } else {
      $$0$ph$i$i = $$024$i$i;$$in$i$i = $10;
     }
    } else {
     $12 = ($8>>>0)<(26512>>>0);
     if (!($12)) {
      label = 10;
      break;
     }
     $13 = ((($$024$i$i)) + 4|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = ($14|0)==(0|0);
     if ($15) {
      label = 9;
      break;
     } else {
      $$0$ph$i$i = $13;$$in$i$i = $14;
     }
    }
    $$0$i$i = $$0$ph$i$i;$$024$i$i = $$in$i$i;$68 = $$in$i$i;
   }
   if ((label|0) == 6) {
    $$025$i53$i = $$024$i$i;$$03752$i = $$024$i$i;
    label = 13;
    break;
   }
   else if ((label|0) == 9) {
    $$025$i53$i = $13;$$03752$i = $$024$i$i;
    label = 13;
    break;
   }
   else if ((label|0) == 10) {
    $$025$i$i = $$0$i$i;$$037$i = $$024$i$i;$16 = $68;
    label = 12;
    break;
   }
  }
 } while(0);
 if ((label|0) == 12) {
  $17 = ($16|0)==(0|0);
  if ($17) {
   $$025$i53$i = $$025$i$i;$$03752$i = $$037$i;
   label = 13;
  } else {
   $$014$i = $16;
  }
 }
 if ((label|0) == 13) {
  $18 = (__Znwj(24)|0);
  $19 = ((($18)) + 16|0);
  HEAP32[$19>>2] = (26512);
  $20 = ((($18)) + 20|0);
  HEAP32[$20>>2] = 0;
  HEAP32[$18>>2] = 0;
  $21 = ((($18)) + 4|0);
  HEAP32[$21>>2] = 0;
  $22 = ((($18)) + 8|0);
  HEAP32[$22>>2] = $$03752$i;
  HEAP32[$$025$i53$i>>2] = $18;
  $23 = HEAP32[$2>>2]|0;
  $24 = HEAP32[$23>>2]|0;
  $25 = ($24|0)==(0|0);
  if ($25) {
   $29 = $18;
  } else {
   $26 = $24;
   HEAP32[$2>>2] = $26;
   $$pre$i$i = HEAP32[$$025$i53$i>>2]|0;
   $29 = $$pre$i$i;
  }
  $27 = ((($0)) + 40|0);
  $28 = HEAP32[$27>>2]|0;
  __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($28,$29);
  $30 = ((($0)) + 44|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = (($31) + 1)|0;
  HEAP32[$30>>2] = $32;
  $$014$i = $18;
 }
 $33 = ((($$014$i)) + 20|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)==(0|0);
 if (!($35)) {
  $67 = HEAP32[$33>>2]|0;
  STACKTOP = sp;return ($67|0);
 }
 $36 = (__Znwj(52)|0);
 $37 = ((($0)) + 24|0);
 $38 = HEAP32[$37>>2]|0;
 __THREW__ = 0;
 $39 = (invoke_ii(3276,16)|0);
 $40 = __THREW__; __THREW__ = 0;
 $41 = $40&1;
 if ($41) {
  $65 = ___cxa_find_matching_catch_2()|0;
  $66 = tempRet0;
  $eh$lpad$body$index2Z2D = $66;$eh$lpad$body$indexZ2D = $65;
  __ZdlPv($36);
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 HEAP32[$1>>2] = $39;
 $42 = ((($1)) + 8|0);
 HEAP32[$42>>2] = -2147483632;
 $43 = ((($1)) + 4|0);
 HEAP32[$43>>2] = 15;
 dest=$39; src=147967; stop=dest+15|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $44 = ((($39)) + 15|0);
 HEAP8[$44>>0] = 0;
 __THREW__ = 0;
 invoke_viii(3762,($36|0),($1|0),($38|0));
 $45 = __THREW__; __THREW__ = 0;
 $46 = $45&1;
 if ($46) {
  $51 = ___cxa_find_matching_catch_2()|0;
  $52 = tempRet0;
  $53 = ((($1)) + 11|0);
  $54 = HEAP8[$53>>0]|0;
  $55 = ($54<<24>>24)<(0);
  if ($55) {
   $56 = HEAP32[$1>>2]|0;
   __ZdlPv($56);
  }
  $eh$lpad$body$index2Z2D = $52;$eh$lpad$body$indexZ2D = $51;
  __ZdlPv($36);
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 $47 = ((($1)) + 11|0);
 $48 = HEAP8[$47>>0]|0;
 $49 = ($48<<24>>24)<(0);
 if ($49) {
  $50 = HEAP32[$1>>2]|0;
  __ZdlPv($50);
 }
 HEAP32[$36>>2] = (65588);
 $57 = HEAP32[$33>>2]|0;
 $58 = ($57|0)==($36|0);
 if ($58) {
  $67 = HEAP32[$33>>2]|0;
  STACKTOP = sp;return ($67|0);
 }
 HEAP32[$33>>2] = $36;
 $59 = ((($36)) + 8|0);
 $60 = HEAP32[$59>>2]|0;HEAP32[$59>>2] = (($60+1)|0);
 $61 = ($57|0)==(0|0);
 if ($61) {
  $67 = HEAP32[$33>>2]|0;
  STACKTOP = sp;return ($67|0);
 }
 $62 = ((($57)) + 8|0);
 $63 = HEAP32[$62>>2]|0;HEAP32[$62>>2] = (($63-1)|0);
 $64 = ($63|0)==(1);
 if (!($64)) {
  $67 = HEAP32[$33>>2]|0;
  STACKTOP = sp;return ($67|0);
 }
 __ZNK3osg10Referenced24signalObserversAndDeleteEbb($57,1,1);
 $67 = HEAP32[$33>>2]|0;
 STACKTOP = sp;return ($67|0);
}
function __ZN15GLShaderManagerD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1702,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZN15GLShaderManager14deleteGLObjectEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (__ZN3osg12GLExtensions3GetEjb($3,1)|0);
 $5 = ((($4)) + 24|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = ($6<<24>>24)==(0);
 if ($7) {
  return;
 }
 $8 = ((($4)) + 72|0);
 $9 = HEAP32[$8>>2]|0;
 FUNCTION_TABLE_vi[$9 & 8191]($1);
 return;
}
function __ZN3osg6Shader13ShaderObjectsD2Ev($0) {
 $0 = $0|0;
 var $$pre$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (65548);
 $1 = ((($0)) + 20|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  __ZN3osg10ReferencedD2Ev($0);
  return;
 }
 $4 = ((($0)) + 24|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==($2|0);
 do {
  if ($6) {
   $20 = $2;
  } else {
   $8 = $5;
   while(1) {
    $7 = ((($8)) + -4|0);
    HEAP32[$4>>2] = $7;
    $9 = HEAP32[$7>>2]|0;
    $10 = ($9|0)==(0|0);
    if (!($10)) {
     $11 = ((($9)) + 8|0);
     $12 = HEAP32[$11>>2]|0;HEAP32[$11>>2] = (($12-1)|0);
     $13 = ($12|0)==(1);
     if ($13) {
      __THREW__ = 0;
      invoke_viii(3262,($9|0),1,1);
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if ($15) {
       label = 7;
       break;
      }
     }
    }
    HEAP32[$7>>2] = 0;
    $16 = HEAP32[$4>>2]|0;
    $17 = ($16|0)==($2|0);
    if ($17) {
     label = 8;
     break;
    } else {
     $8 = $16;
    }
   }
   if ((label|0) == 7) {
    $18 = ___cxa_find_matching_catch_2()|0;
    $19 = tempRet0;
    ___cxa_call_unexpected(($18|0));
    // unreachable;
   }
   else if ((label|0) == 8) {
    $$pre$i = HEAP32[$1>>2]|0;
    $20 = $$pre$i;
    break;
   }
  }
 } while(0);
 __ZdlPv($20);
 __ZN3osg10ReferencedD2Ev($0);
 return;
}
function __ZN3osg6Shader13ShaderObjectsD0Ev($0) {
 $0 = $0|0;
 var $$pre$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (65548);
 $1 = ((($0)) + 20|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = ((($0)) + 24|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==($2|0);
  do {
   if ($6) {
    $20 = $2;
   } else {
    $8 = $5;
    while(1) {
     $7 = ((($8)) + -4|0);
     HEAP32[$4>>2] = $7;
     $9 = HEAP32[$7>>2]|0;
     $10 = ($9|0)==(0|0);
     if (!($10)) {
      $11 = ((($9)) + 8|0);
      $12 = HEAP32[$11>>2]|0;HEAP32[$11>>2] = (($12-1)|0);
      $13 = ($12|0)==(1);
      if ($13) {
       __THREW__ = 0;
       invoke_viii(3262,($9|0),1,1);
       $14 = __THREW__; __THREW__ = 0;
       $15 = $14&1;
       if ($15) {
        label = 7;
        break;
       }
      }
     }
     HEAP32[$7>>2] = 0;
     $16 = HEAP32[$4>>2]|0;
     $17 = ($16|0)==($2|0);
     if ($17) {
      label = 8;
      break;
     } else {
      $8 = $16;
     }
    }
    if ((label|0) == 7) {
     $18 = ___cxa_find_matching_catch_2()|0;
     $19 = tempRet0;
     ___cxa_call_unexpected(($18|0));
     // unreachable;
    }
    else if ((label|0) == 8) {
     $$pre$i$i = HEAP32[$1>>2]|0;
     $20 = $$pre$i$i;
     break;
    }
   }
  } while(0);
  __ZdlPv($20);
 }
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if ($22) {
  $23 = ___cxa_find_matching_catch_2()|0;
  $24 = tempRet0;
  __ZdlPv($0);
  ___resumeException($23|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNSt3__26vectorIN3osg7ref_ptrINS1_6Shader13ShaderObjectsEEENS_9allocatorIS5_EEE8__appendEjRKS5_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$i = 0, $$0$i16 = 0, $$06$i$i = 0, $$pre = 0, $$pre$i19 = 0, $$pre5$i = 0, $$sroa$16$0 = 0, $$sroa$7$0 = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) - ($6))|0;
 $8 = $7 >> 2;
 $9 = ($8>>>0)<($1>>>0);
 if (!($9)) {
  $10 = $6;
  $$0$i = $1;$12 = $10;
  while(1) {
   $11 = HEAP32[$2>>2]|0;
   HEAP32[$12>>2] = $11;
   $13 = ($11|0)==(0|0);
   if ($13) {
    $17 = $12;
   } else {
    $14 = ((($11)) + 8|0);
    $15 = HEAP32[$14>>2]|0;HEAP32[$14>>2] = (($15+1)|0);
    $$pre5$i = HEAP32[$5>>2]|0;
    $17 = $$pre5$i;
   }
   $16 = ((($17)) + 4|0);
   HEAP32[$5>>2] = $16;
   $18 = (($$0$i) + -1)|0;
   $19 = ($18|0)==(0);
   if ($19) {
    break;
   } else {
    $$0$i = $18;$12 = $16;
   }
  }
  return;
 }
 $20 = HEAP32[$0>>2]|0;
 $21 = (($6) - ($20))|0;
 $22 = $21 >> 2;
 $23 = (($22) + ($1))|0;
 $24 = ($23>>>0)>(1073741823);
 if ($24) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $25 = (($4) - ($20))|0;
 $26 = $25 >> 2;
 $27 = ($26>>>0)<(536870911);
 $28 = $25 >> 1;
 $29 = ($28>>>0)<($23>>>0);
 $$sroa$speculated$i = $29 ? $23 : $28;
 $$sroa$speculated$$i = $27 ? $$sroa$speculated$i : 1073741823;
 $30 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($30) {
   $40 = 0;
  } else {
   $31 = ($$sroa$speculated$$i>>>0)>(1073741823);
   if (!($31)) {
    $37 = $$sroa$speculated$$i << 2;
    $38 = (__Znwj($37)|0);
    $40 = $38;
    break;
   }
   $32 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($32|0),(204840|0));
   $33 = __THREW__; __THREW__ = 0;
   $34 = $33&1;
   if ($34) {
    $35 = ___cxa_find_matching_catch_2()|0;
    $36 = tempRet0;
    ___cxa_free_exception(($32|0));
    ___resumeException($35|0);
    // unreachable;
   } else {
    HEAP32[$32>>2] = (99824);
    ___cxa_throw(($32|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $39 = (($40) + ($22<<2)|0);
 $41 = $39;
 $42 = (($40) + ($$sroa$speculated$$i<<2)|0);
 $$0$i16 = $1;$$sroa$16$0 = $41;$44 = $39;
 while(1) {
  $43 = HEAP32[$2>>2]|0;
  HEAP32[$44>>2] = $43;
  $45 = ($43|0)==(0|0);
  if ($45) {
   $50 = $44;
  } else {
   $46 = ((($43)) + 8|0);
   $47 = HEAP32[$46>>2]|0;HEAP32[$46>>2] = (($47+1)|0);
   $48 = $$sroa$16$0;
   $50 = $48;
  }
  $49 = ((($50)) + 4|0);
  $51 = $49;
  $52 = (($$0$i16) + -1)|0;
  $53 = ($52|0)==(0);
  if ($53) {
   break;
  } else {
   $$0$i16 = $52;$$sroa$16$0 = $51;$44 = $49;
  }
 }
 $54 = $42;
 $55 = HEAP32[$0>>2]|0;
 $56 = HEAP32[$5>>2]|0;
 $57 = ($56|0)==($55|0);
 if ($57) {
  $58 = $55;
  $70 = $41;$71 = $58;$73 = $55;
 } else {
  $$06$i$i = $56;$$sroa$7$0 = $41;$61 = $39;
  while(1) {
   $59 = ((($$06$i$i)) + -4|0);
   $60 = ((($61)) + -4|0);
   $62 = HEAP32[$59>>2]|0;
   HEAP32[$60>>2] = $62;
   $63 = ($62|0)==(0|0);
   if (!($63)) {
    $64 = ((($62)) + 8|0);
    $65 = HEAP32[$64>>2]|0;HEAP32[$64>>2] = (($65+1)|0);
   }
   $66 = $$sroa$7$0;
   $67 = ((($66)) + -4|0);
   $68 = $67;
   $69 = ($59|0)==($55|0);
   if ($69) {
    break;
   } else {
    $$06$i$i = $59;$$sroa$7$0 = $68;$61 = $67;
   }
  }
  $$pre$i19 = HEAP32[$0>>2]|0;
  $$pre = HEAP32[$5>>2]|0;
  $70 = $68;$71 = $$pre$i19;$73 = $$pre;
 }
 HEAP32[$0>>2] = $70;
 HEAP32[$5>>2] = $51;
 HEAP32[$3>>2] = $54;
 $72 = $71;
 $74 = ($73|0)==($72|0);
 L37: do {
  if (!($74)) {
   $76 = $73;
   while(1) {
    $75 = ((($76)) + -4|0);
    $77 = HEAP32[$75>>2]|0;
    $78 = ($77|0)==(0|0);
    if (!($78)) {
     $79 = ((($77)) + 8|0);
     $80 = HEAP32[$79>>2]|0;HEAP32[$79>>2] = (($80-1)|0);
     $81 = ($80|0)==(1);
     if ($81) {
      __THREW__ = 0;
      invoke_viii(3262,($77|0),1,1);
      $82 = __THREW__; __THREW__ = 0;
      $83 = $82&1;
      if ($83) {
       break;
      }
     }
    }
    HEAP32[$75>>2] = 0;
    $84 = ($75|0)==($72|0);
    if ($84) {
     break L37;
    } else {
     $76 = $75;
    }
   }
   $85 = ___cxa_find_matching_catch_2()|0;
   $86 = tempRet0;
   ___cxa_call_unexpected(($85|0));
   // unreachable;
  }
 } while(0);
 $87 = ($71|0)==(0);
 if ($87) {
  return;
 }
 $88 = $71;
 __ZdlPv($88);
 return;
}
function __ZN3osg6ShaderD2Ev($0) {
 $0 = $0|0;
 var $$pre$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (65652);
 $1 = ((($0)) + 116|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = ((($0)) + 120|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==($2|0);
  do {
   if ($6) {
    $20 = $2;
   } else {
    $8 = $5;
    while(1) {
     $7 = ((($8)) + -4|0);
     HEAP32[$4>>2] = $7;
     $9 = HEAP32[$7>>2]|0;
     $10 = ($9|0)==(0|0);
     if (!($10)) {
      $11 = ((($9)) + 8|0);
      $12 = HEAP32[$11>>2]|0;HEAP32[$11>>2] = (($12-1)|0);
      $13 = ($12|0)==(1);
      if ($13) {
       __THREW__ = 0;
       invoke_viii(3262,($9|0),1,1);
       $14 = __THREW__; __THREW__ = 0;
       $15 = $14&1;
       if ($15) {
        label = 7;
        break;
       }
      }
     }
     HEAP32[$7>>2] = 0;
     $16 = HEAP32[$4>>2]|0;
     $17 = ($16|0)==($2|0);
     if ($17) {
      label = 8;
      break;
     } else {
      $8 = $16;
     }
    }
    if ((label|0) == 7) {
     $18 = ___cxa_find_matching_catch_2()|0;
     $19 = tempRet0;
     ___cxa_call_unexpected(($18|0));
     // unreachable;
    }
    else if ((label|0) == 8) {
     $$pre$i$i = HEAP32[$1>>2]|0;
     $20 = $$pre$i$i;
     break;
    }
   }
  } while(0);
  __ZdlPv($20);
 }
 $21 = ((($0)) + 104|0);
 $22 = ((($0)) + 108|0);
 $23 = HEAP32[$22>>2]|0;
 __ZNSt3__26__treeIPN3osg7ProgramENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($21,$23);
 $24 = ((($0)) + 92|0);
 $25 = ((($0)) + 96|0);
 $26 = HEAP32[$25>>2]|0;
 __ZNSt3__26__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EENS4_IS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($24,$26);
 $27 = ((($0)) + 80|0);
 $28 = ((($0)) + 84|0);
 $29 = HEAP32[$28>>2]|0;
 __ZNSt3__26__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EENS4_IS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($27,$29);
 $30 = ((($0)) + 64|0);
 $31 = ((($0)) + 68|0);
 $32 = HEAP32[$31>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIfNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEEENS_19__map_value_compareIfS8_NS_4lessIfEELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($30,$32);
 $33 = ((($0)) + 60|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)==(0|0);
 if (!($35)) {
  $36 = ((($34)) + 8|0);
  $37 = HEAP32[$36>>2]|0;HEAP32[$36>>2] = (($37-1)|0);
  $38 = ($37|0)==(1);
  if ($38) {
   __THREW__ = 0;
   invoke_viii(3262,($34|0),1,1);
   $39 = __THREW__; __THREW__ = 0;
   $40 = $39&1;
   if ($40) {
    $51 = ___cxa_find_matching_catch_2()|0;
    $52 = tempRet0;
    $53 = ((($0)) + 48|0);
    $54 = ((($53)) + 11|0);
    $55 = HEAP8[$54>>0]|0;
    $56 = ($55<<24>>24)<(0);
    if ($56) {
     $57 = HEAP32[$53>>2]|0;
     __ZdlPv($57);
    }
    $58 = ((($0)) + 36|0);
    $59 = ((($58)) + 11|0);
    $60 = HEAP8[$59>>0]|0;
    $61 = ($60<<24>>24)<(0);
    if ($61) {
     $62 = HEAP32[$58>>2]|0;
     __ZdlPv($62);
    }
    __THREW__ = 0;
    invoke_vi(388,($0|0));
    $63 = __THREW__; __THREW__ = 0;
    $64 = $63&1;
    if ($64) {
     $65 = ___cxa_find_matching_catch_3(0|0)|0;
     $66 = tempRet0;
     ___clang_call_terminate($65);
     // unreachable;
    } else {
     ___resumeException($51|0);
     // unreachable;
    }
   }
  }
 }
 HEAP32[$33>>2] = 0;
 $41 = ((($0)) + 48|0);
 $42 = ((($41)) + 11|0);
 $43 = HEAP8[$42>>0]|0;
 $44 = ($43<<24>>24)<(0);
 if ($44) {
  $45 = HEAP32[$41>>2]|0;
  __ZdlPv($45);
 }
 $46 = ((($0)) + 36|0);
 $47 = ((($46)) + 11|0);
 $48 = HEAP8[$47>>0]|0;
 $49 = ($48<<24>>24)<(0);
 if (!($49)) {
  __ZN3osg6ObjectD2Ev($0);
  return;
 }
 $50 = HEAP32[$46>>2]|0;
 __ZdlPv($50);
 __ZN3osg6ObjectD2Ev($0);
 return;
}
function __ZN3osg6ShaderD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(2217,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK3osg6Shader9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(128)|0);
 __THREW__ = 0;
 invoke_vii(3890,($1|0),-1);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch_2()|0;
  $5 = tempRet0;
  __ZdlPv($1);
  ___resumeException($4|0);
  // unreachable;
 } else {
  return ($1|0);
 }
 return (0)|0;
}
function __ZNK3osg6Shader5cloneERKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(128)|0);
 __THREW__ = 0;
 invoke_viii(3869,($2|0),($0|0),($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch_2()|0;
  $6 = tempRet0;
  __ZdlPv($2);
  ___resumeException($5|0);
  // unreachable;
 } else {
  return ($2|0);
 }
 return (0)|0;
}
function __ZNK3osg6Shader12isSameKindAsEPKNS_6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,26544,0)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK3osg6Shader11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175113|0);
}
function __ZNK3osg6Shader9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (148062|0);
}
function __ZN3osg6Shader21resizeGLObjectBuffersEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 116|0);
 __ZN3osg14buffered_valueINS_7ref_ptrINS_6Shader13ShaderObjectsEEEE6resizeEj($2,$1);
 return;
}
function __ZNK3osg6Shader16releaseGLObjectsEPNS_5StateE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$02$i$i$i$i$i = 0, $$sroa$01$0$i$i$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $22 = ((($1)) + 124|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = ((($0)) + 116|0);
  $25 = (__ZN3osg14buffered_valueINS_7ref_ptrINS_6Shader13ShaderObjectsEEEEixEj($24,$23)|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = ($26|0)==(0|0);
  if ($27) {
   return;
  }
  HEAP32[$25>>2] = 0;
  $28 = ((($26)) + 8|0);
  $29 = HEAP32[$28>>2]|0;HEAP32[$28>>2] = (($29-1)|0);
  $30 = ($29|0)==(1);
  if (!($30)) {
   return;
  }
  __ZNK3osg10Referenced24signalObserversAndDeleteEbb($26,1,1);
  return;
 }
 $3 = ((($0)) + 116|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 120|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $4;
 $8 = (($6) - ($7))|0;
 $9 = ($8|0)>(0);
 if (!($9)) {
  return;
 }
 $10 = $8 >>> 2;
 $$02$i$i$i$i$i = $10;$$sroa$01$0$i$i$i$i = $7;$12 = $4;
 while(1) {
  $11 = HEAP32[$12>>2]|0;
  $13 = ($11|0)==(0|0);
  if (!($13)) {
   HEAP32[$12>>2] = 0;
   $14 = ((($11)) + 8|0);
   $15 = HEAP32[$14>>2]|0;HEAP32[$14>>2] = (($15-1)|0);
   $16 = ($15|0)==(1);
   if ($16) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($11,1,1);
   }
  }
  $17 = $$sroa$01$0$i$i$i$i;
  $18 = ((($17)) + 4|0);
  $19 = $18;
  $20 = (($$02$i$i$i$i$i) + -1)|0;
  $21 = ($$02$i$i$i$i$i|0)>(1);
  if ($21) {
   $$02$i$i$i$i$i = $20;$$sroa$01$0$i$i$i$i = $19;$12 = $18;
  } else {
   break;
  }
 }
 return;
}
function __ZN3osg14buffered_valueINS_7ref_ptrINS_6Shader13ShaderObjectsEEEE6resizeEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 HEAP32[$2>>2] = 0;
 $3 = ((($0)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$0>>2]|0;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 2;
 $8 = ($7>>>0)<($1>>>0);
 $9 = $5;
 $10 = $4;
 L1: do {
  if ($8) {
   $11 = (($1) - ($7))|0;
   __THREW__ = 0;
   invoke_viii(3886,($0|0),($11|0),($2|0));
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if ($13) {
    $35 = ___cxa_find_matching_catch_2()|0;
    $36 = tempRet0;
    $37 = HEAP32[$2>>2]|0;
    $38 = ($37|0)==(0|0);
    if ($38) {
     ___resumeException($35|0);
     // unreachable;
    }
    $39 = ((($37)) + 8|0);
    $40 = HEAP32[$39>>2]|0;HEAP32[$39>>2] = (($40-1)|0);
    $41 = ($40|0)==(1);
    if (!($41)) {
     ___resumeException($35|0);
     // unreachable;
    }
    __THREW__ = 0;
    invoke_viii(3262,($37|0),1,1);
    $42 = __THREW__; __THREW__ = 0;
    $43 = $42&1;
    if ($43) {
     $44 = ___cxa_find_matching_catch_3(0|0)|0;
     $45 = tempRet0;
     ___clang_call_terminate($44);
     // unreachable;
    } else {
     ___resumeException($35|0);
     // unreachable;
    }
   }
  } else {
   $14 = ($7>>>0)>($1>>>0);
   if ($14) {
    $15 = (($9) + ($1<<2)|0);
    $16 = ($10|0)==($15|0);
    if (!($16)) {
     $18 = $10;
     while(1) {
      $17 = ((($18)) + -4|0);
      HEAP32[$3>>2] = $17;
      $19 = HEAP32[$17>>2]|0;
      $20 = ($19|0)==(0|0);
      if (!($20)) {
       $21 = ((($19)) + 8|0);
       $22 = HEAP32[$21>>2]|0;HEAP32[$21>>2] = (($22-1)|0);
       $23 = ($22|0)==(1);
       if ($23) {
        __THREW__ = 0;
        invoke_viii(3262,($19|0),1,1);
        $24 = __THREW__; __THREW__ = 0;
        $25 = $24&1;
        if ($25) {
         break;
        }
       }
      }
      HEAP32[$17>>2] = 0;
      $26 = HEAP32[$3>>2]|0;
      $27 = ($26|0)==($15|0);
      if ($27) {
       break L1;
      } else {
       $18 = $26;
      }
     }
     $28 = ___cxa_find_matching_catch_2()|0;
     $29 = tempRet0;
     ___cxa_call_unexpected(($28|0));
     // unreachable;
    }
   }
  }
 } while(0);
 $30 = HEAP32[$2>>2]|0;
 $31 = ($30|0)==(0|0);
 if ($31) {
  STACKTOP = sp;return;
 }
 $32 = ((($30)) + 8|0);
 $33 = HEAP32[$32>>2]|0;HEAP32[$32>>2] = (($33-1)|0);
 $34 = ($33|0)==(1);
 if (!($34)) {
  STACKTOP = sp;return;
 }
 __ZNK3osg10Referenced24signalObserversAndDeleteEbb($30,1,1);
 STACKTOP = sp;return;
}
function __ZN3osg6ShaderC2ERKS0_RKNS_6CopyOpE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i$i = 0, $$0$i$i$i$i$i$i$i = 0, $$0$i$i$i$i3$i$i = 0, $$0$i15$i$i$in$i$i = 0, $$034$i$i$i = 0, $$08$i$i$i$i$i$i = 0, $$1$i$i$i$i = 0, $$3 = 0, $$313 = 0, $$5 = 0, $$515 = 0, $$6 = 0, $$616 = 0, $$pre$i = 0, $$pre$i$i$i$i = 0, $$pre$i$i$i$pre$i = 0, $$pre$i10$i$i$i = 0, $$pre30$i = 0, $$sroa$011$0$i = 0;
 var $$sroa$021$0$i$i$i$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0;
 var $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0;
 var $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0;
 var $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0.0, $44 = 0.0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0.0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$i$index2Z2D = 0, $eh$lpad$body$i$indexZ2D = 0, $eh$lpad$body20$index7Z2D = 0, $eh$lpad$body20$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 __ZN3osg6ObjectC2ERKS0_RKNS_6CopyOpE($0,$1,$2);
 HEAP32[$0>>2] = (65652);
 $4 = ((($0)) + 32|0);
 $5 = ((($1)) + 32|0);
 $6 = HEAP32[$5>>2]|0;
 HEAP32[$4>>2] = $6;
 $7 = ((($0)) + 36|0);
 $8 = ((($1)) + 36|0);
 __THREW__ = 0;
 invoke_vii(3457,($7|0),($8|0));
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if ($10) {
  $139 = ___cxa_find_matching_catch_2()|0;
  $140 = tempRet0;
  $$6 = $140;$$616 = $139;
 } else {
  $11 = ((($0)) + 48|0);
  $12 = ((($1)) + 48|0);
  __THREW__ = 0;
  invoke_vii(3457,($11|0),($12|0));
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if ($14) {
   $141 = ___cxa_find_matching_catch_2()|0;
   $142 = tempRet0;
   $$5 = $142;$$515 = $141;
  } else {
   $15 = ((($0)) + 60|0);
   $16 = ((($1)) + 60|0);
   $17 = HEAP32[$16>>2]|0;
   HEAP32[$15>>2] = $17;
   $18 = ($17|0)==(0|0);
   if (!($18)) {
    $19 = ((($17)) + 8|0);
    $20 = HEAP32[$19>>2]|0;HEAP32[$19>>2] = (($20+1)|0);
   }
   $21 = ((($0)) + 64|0);
   $22 = ((($0)) + 68|0);
   HEAP32[$22>>2] = 0;
   $23 = ((($0)) + 72|0);
   HEAP32[$23>>2] = 0;
   $24 = ((($0)) + 68|0);
   HEAP32[$21>>2] = $24;
   $25 = ((($1)) + 64|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = ((($1)) + 68|0);
   $28 = ($26|0)==($27|0);
   L10: do {
    if ($28) {
     label = 33;
    } else {
     $29 = $24;
     $$pre$i$i$i$i = 0;$$sroa$011$0$i = $26;$169 = 0;$32 = $24;
     while(1) {
      $30 = ((($$sroa$011$0$i)) + 16|0);
      $31 = ($24|0)==($32|0);
      do {
       if ($31) {
        $$sroa$021$0$i$i$i$i = $29;
        label = 12;
       } else {
        $33 = ($$pre$i$i$i$i|0)==(0|0);
        if ($33) {
         $$0$i$i$i$i3$i$i = $24;
         while(1) {
          $37 = ((($$0$i$i$i$i3$i$i)) + 8|0);
          $38 = HEAP32[$37>>2]|0;
          $39 = HEAP32[$38>>2]|0;
          $40 = ($39|0)==($$0$i$i$i$i3$i$i|0);
          if ($40) {
           $$0$i$i$i$i3$i$i = $38;
          } else {
           $$08$i$i$i$i$i$i = $38;
           break;
          }
         }
        } else {
         $$0$i$i$i$i$i$i$i = $$pre$i$i$i$i;
         while(1) {
          $34 = ((($$0$i$i$i$i$i$i$i)) + 4|0);
          $35 = HEAP32[$34>>2]|0;
          $36 = ($35|0)==(0|0);
          if ($36) {
           $$08$i$i$i$i$i$i = $$0$i$i$i$i$i$i$i;
           break;
          } else {
           $$0$i$i$i$i$i$i$i = $35;
          }
         }
        }
        $41 = $$08$i$i$i$i$i$i;
        $42 = ((($$08$i$i$i$i$i$i)) + 16|0);
        $43 = +HEAPF32[$30>>2];
        $44 = +HEAPF32[$42>>2];
        $45 = $43 < $44;
        if ($45) {
         if ($33) {
          $$034$i$i$i = $24;$$1$i$i$i$i = $24;
         } else {
          $$0$i15$i$i$in$i$i = $$pre$i$i$i$i;
          while(1) {
           $49 = ((($$0$i15$i$i$in$i$i)) + 16|0);
           $50 = +HEAPF32[$49>>2];
           $51 = $43 < $50;
           if ($51) {
            $52 = HEAP32[$$0$i15$i$i$in$i$i>>2]|0;
            $53 = ($52|0)==(0|0);
            if ($53) {
             label = 17;
             break;
            } else {
             $$0$i15$i$i$in$i$i = $52;
             continue;
            }
           } else {
            $54 = ((($$0$i15$i$i$in$i$i)) + 4|0);
            $55 = HEAP32[$54>>2]|0;
            $56 = ($55|0)==(0|0);
            if ($56) {
             label = 19;
             break;
            } else {
             $$0$i15$i$i$in$i$i = $55;
             continue;
            }
           }
          }
          if ((label|0) == 17) {
           label = 0;
           $$034$i$i$i = $$0$i15$i$i$in$i$i;$$1$i$i$i$i = $$0$i15$i$i$in$i$i;
           break;
          }
          else if ((label|0) == 19) {
           label = 0;
           $$034$i$i$i = $$0$i15$i$i$in$i$i;$$1$i$i$i$i = $54;
           break;
          }
         }
        } else {
         $$sroa$021$0$i$i$i$i = $41;
         label = 12;
        }
       }
      } while(0);
      if ((label|0) == 12) {
       label = 0;
       $46 = ($$pre$i$i$i$i|0)==(0|0);
       if ($46) {
        $$034$i$i$i = $24;$$1$i$i$i$i = $24;
       } else {
        $47 = $$sroa$021$0$i$i$i$i;
        $48 = ((($47)) + 4|0);
        $$034$i$i$i = $47;$$1$i$i$i$i = $48;
       }
      }
      __THREW__ = 0;
      $57 = (invoke_ii(3276,32)|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 32;
       break;
      }
      $60 = ((($57)) + 16|0);
      $61 = HEAP32[$30>>2]|0;
      HEAP32[$60>>2] = $61;
      $62 = ((($57)) + 20|0);
      $63 = ((($$sroa$011$0$i)) + 20|0);
      __THREW__ = 0;
      invoke_vii(3457,($62|0),($63|0));
      $64 = __THREW__; __THREW__ = 0;
      $65 = $64&1;
      if ($65) {
       label = 22;
       break;
      }
      HEAP32[$57>>2] = 0;
      $68 = ((($57)) + 4|0);
      HEAP32[$68>>2] = 0;
      $69 = ((($57)) + 8|0);
      HEAP32[$69>>2] = $$034$i$i$i;
      HEAP32[$$1$i$i$i$i>>2] = $57;
      $70 = HEAP32[$21>>2]|0;
      $71 = HEAP32[$70>>2]|0;
      $72 = ($71|0)==(0|0);
      if ($72) {
       $75 = $57;
      } else {
       $73 = $71;
       HEAP32[$21>>2] = $73;
       $$pre$i10$i$i$i = HEAP32[$$1$i$i$i$i>>2]|0;
       $75 = $$pre$i10$i$i$i;
      }
      $74 = HEAP32[$22>>2]|0;
      __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($74,$75);
      $76 = HEAP32[$23>>2]|0;
      $77 = (($76) + 1)|0;
      HEAP32[$23>>2] = $77;
      $78 = ((($$sroa$011$0$i)) + 4|0);
      $79 = HEAP32[$78>>2]|0;
      $80 = ($79|0)==(0|0);
      if ($80) {
       $81 = ((($$sroa$011$0$i)) + 8|0);
       $82 = HEAP32[$81>>2]|0;
       $83 = HEAP32[$82>>2]|0;
       $84 = ($83|0)==($$sroa$011$0$i|0);
       if ($84) {
        $$0$i$i$i$i$i = $82;
       } else {
        $88 = $81;
        while(1) {
         $87 = HEAP32[$88>>2]|0;
         $89 = ((($87)) + 8|0);
         $90 = HEAP32[$89>>2]|0;
         $91 = HEAP32[$90>>2]|0;
         $92 = ($91|0)==($87|0);
         if ($92) {
          $$0$i$i$i$i$i = $90;
          break;
         } else {
          $88 = $89;
         }
        }
       }
      } else {
       $$0$i$i$i$i$i$i = $79;
       while(1) {
        $85 = HEAP32[$$0$i$i$i$i$i$i>>2]|0;
        $86 = ($85|0)==(0|0);
        if ($86) {
         break;
        } else {
         $$0$i$i$i$i$i$i = $85;
        }
       }
       $$0$i$i$i$i$i = $$0$i$i$i$i$i$i;
      }
      $93 = ($$0$i$i$i$i$i|0)==($27|0);
      if ($93) {
       label = 33;
       break L10;
      }
      $$pre$i = HEAP32[$21>>2]|0;
      $$pre$i$i$i$pre$i = HEAP32[$24>>2]|0;
      $$pre$i$i$i$i = $$pre$i$i$i$pre$i;$$sroa$011$0$i = $$0$i$i$i$i$i;$169 = $$pre$i$i$i$pre$i;$32 = $$pre$i;
     }
     if ((label|0) == 22) {
      $66 = ___cxa_find_matching_catch_2()|0;
      $67 = tempRet0;
      __ZdlPv($57);
      $$pre30$i = HEAP32[$24>>2]|0;
      $143 = $$pre30$i;$eh$lpad$body$i$index2Z2D = $67;$eh$lpad$body$i$indexZ2D = $66;
     }
     else if ((label|0) == 32) {
      $94 = ___cxa_find_matching_catch_2()|0;
      $95 = tempRet0;
      $143 = $169;$eh$lpad$body$i$index2Z2D = $95;$eh$lpad$body$i$indexZ2D = $94;
     }
     __ZNSt3__26__treeINS_12__value_typeIfNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEEENS_19__map_value_compareIfS8_NS_4lessIfEELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($21,$143);
     $$3 = $eh$lpad$body$i$index2Z2D;$$313 = $eh$lpad$body$i$indexZ2D;
    }
   } while(0);
   if ((label|0) == 33) {
    $96 = ((($0)) + 76|0);
    $97 = ((($1)) + 76|0);
    $98 = HEAP32[$97>>2]|0;
    HEAP32[$96>>2] = $98;
    $99 = ((($0)) + 80|0);
    $100 = ((($0)) + 84|0);
    HEAP32[$100>>2] = 0;
    $101 = ((($0)) + 88|0);
    HEAP32[$101>>2] = 0;
    $102 = ((($0)) + 84|0);
    HEAP32[$99>>2] = $102;
    $103 = ((($0)) + 92|0);
    $104 = ((($0)) + 96|0);
    HEAP32[$104>>2] = 0;
    $105 = ((($0)) + 100|0);
    HEAP32[$105>>2] = 0;
    $106 = ((($0)) + 96|0);
    HEAP32[$103>>2] = $106;
    $107 = ((($0)) + 104|0);
    $108 = ((($0)) + 108|0);
    HEAP32[$108>>2] = 0;
    $109 = ((($0)) + 112|0);
    HEAP32[$109>>2] = 0;
    $110 = ((($0)) + 108|0);
    HEAP32[$107>>2] = $110;
    $111 = ((($0)) + 116|0);
    __THREW__ = 0;
    $112 = (invoke_i(3285)|0);
    $113 = __THREW__; __THREW__ = 0;
    $114 = $113&1;
    do {
     if ($114) {
      label = 48;
     } else {
      $115 = HEAP32[$112>>2]|0;
      __THREW__ = 0;
      $116 = (invoke_ii(3286,($115|0))|0);
      $117 = __THREW__; __THREW__ = 0;
      $118 = $117&1;
      if ($118) {
       label = 48;
      } else {
       HEAP32[$3>>2] = 0;
       __THREW__ = 0;
       invoke_viii(3891,($111|0),($116|0),($3|0));
       $119 = __THREW__; __THREW__ = 0;
       $120 = $119&1;
       if ($120) {
        $128 = ___cxa_find_matching_catch_2()|0;
        $129 = tempRet0;
        $130 = HEAP32[$3>>2]|0;
        $131 = ($130|0)==(0|0);
        if (!($131)) {
         $132 = ((($130)) + 8|0);
         $133 = HEAP32[$132>>2]|0;HEAP32[$132>>2] = (($133-1)|0);
         $134 = ($133|0)==(1);
         if ($134) {
          __THREW__ = 0;
          invoke_viii(3262,($130|0),1,1);
          $135 = __THREW__; __THREW__ = 0;
          $136 = $135&1;
          if ($136) {
           $137 = ___cxa_find_matching_catch_3(0|0)|0;
           $138 = tempRet0;
           ___clang_call_terminate($137);
           // unreachable;
          }
         }
        }
        $eh$lpad$body20$index7Z2D = $129;$eh$lpad$body20$indexZ2D = $128;
        break;
       }
       $121 = HEAP32[$3>>2]|0;
       $122 = ($121|0)==(0|0);
       if ($122) {
        STACKTOP = sp;return;
       }
       $123 = ((($121)) + 8|0);
       $124 = HEAP32[$123>>2]|0;HEAP32[$123>>2] = (($124-1)|0);
       $125 = ($124|0)==(1);
       if (!($125)) {
        STACKTOP = sp;return;
       }
       __THREW__ = 0;
       invoke_viii(3262,($121|0),1,1);
       $126 = __THREW__; __THREW__ = 0;
       $127 = $126&1;
       if ($127) {
        label = 48;
       } else {
        STACKTOP = sp;return;
       }
      }
     }
    } while(0);
    if ((label|0) == 48) {
     $144 = ___cxa_find_matching_catch_2()|0;
     $145 = tempRet0;
     $eh$lpad$body20$index7Z2D = $145;$eh$lpad$body20$indexZ2D = $144;
    }
    $146 = HEAP32[$110>>2]|0;
    __ZNSt3__26__treeIPN3osg7ProgramENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($107,$146);
    $147 = HEAP32[$106>>2]|0;
    __ZNSt3__26__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EENS4_IS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($103,$147);
    $148 = HEAP32[$102>>2]|0;
    __ZNSt3__26__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EENS4_IS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($99,$148);
    $149 = HEAP32[$24>>2]|0;
    __ZNSt3__26__treeINS_12__value_typeIfNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEEENS_19__map_value_compareIfS8_NS_4lessIfEELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($21,$149);
    $$3 = $eh$lpad$body20$index7Z2D;$$313 = $eh$lpad$body20$indexZ2D;
   }
   $150 = HEAP32[$15>>2]|0;
   $151 = ($150|0)==(0|0);
   if (!($151)) {
    $152 = ((($150)) + 8|0);
    $153 = HEAP32[$152>>2]|0;HEAP32[$152>>2] = (($153-1)|0);
    $154 = ($153|0)==(1);
    if ($154) {
     __THREW__ = 0;
     invoke_viii(3262,($150|0),1,1);
     $155 = __THREW__; __THREW__ = 0;
     $156 = $155&1;
     if ($156) {
      $167 = ___cxa_find_matching_catch_3(0|0)|0;
      $168 = tempRet0;
      ___clang_call_terminate($167);
      // unreachable;
     }
    }
   }
   HEAP32[$15>>2] = 0;
   $157 = ((($11)) + 11|0);
   $158 = HEAP8[$157>>0]|0;
   $159 = ($158<<24>>24)<(0);
   if ($159) {
    $160 = HEAP32[$11>>2]|0;
    __ZdlPv($160);
    $$5 = $$3;$$515 = $$313;
   } else {
    $$5 = $$3;$$515 = $$313;
   }
  }
  $161 = ((($7)) + 11|0);
  $162 = HEAP8[$161>>0]|0;
  $163 = ($162<<24>>24)<(0);
  if ($163) {
   $164 = HEAP32[$7>>2]|0;
   __ZdlPv($164);
   $$6 = $$5;$$616 = $$515;
  } else {
   $$6 = $$5;$$616 = $$515;
  }
 }
 __THREW__ = 0;
 invoke_vi(388,($0|0));
 $165 = __THREW__; __THREW__ = 0;
 $166 = $165&1;
 if ($166) {
  $167 = ___cxa_find_matching_catch_3(0|0)|0;
  $168 = tempRet0;
  ___clang_call_terminate($167);
  // unreachable;
 } else {
  ___resumeException($$616|0);
  // unreachable;
 }
}
function __ZNSt3__26vectorIN3osg7ref_ptrINS1_6Shader13ShaderObjectsEEENS_9allocatorIS5_EEEC2EjRKS5_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$i = 0, $$pre$i7 = 0, $$pre5$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = 0;
 $3 = ((($0)) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = ((($0)) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = ($1|0)==(0);
 if ($5) {
  return;
 }
 $6 = ($1>>>0)>(1073741823);
 if ($6) {
  __THREW__ = 0;
  invoke_vi(3307,($0|0));
  $7 = __THREW__; __THREW__ = 0;
 } else {
  $8 = $1 << 2;
  __THREW__ = 0;
  $9 = (invoke_ii(3276,($8|0))|0);
  $10 = __THREW__; __THREW__ = 0;
  $11 = $10&1;
  if (!($11)) {
   HEAP32[$3>>2] = $9;
   HEAP32[$0>>2] = $9;
   $12 = (($9) + ($1<<2)|0);
   $13 = ((($0)) + 8|0);
   HEAP32[$13>>2] = $12;
   $$0$i = $1;$15 = $9;
   while(1) {
    $14 = HEAP32[$2>>2]|0;
    HEAP32[$15>>2] = $14;
    $16 = ($14|0)==(0|0);
    if ($16) {
     $20 = $15;
    } else {
     $17 = ((($14)) + 8|0);
     $18 = HEAP32[$17>>2]|0;HEAP32[$17>>2] = (($18+1)|0);
     $$pre5$i = HEAP32[$3>>2]|0;
     $20 = $$pre5$i;
    }
    $19 = ((($20)) + 4|0);
    HEAP32[$3>>2] = $19;
    $21 = (($$0$i) + -1)|0;
    $22 = ($21|0)==(0);
    if ($22) {
     break;
    } else {
     $$0$i = $21;$15 = $19;
    }
   }
   return;
  }
 }
 $23 = ___cxa_find_matching_catch_2()|0;
 $24 = tempRet0;
 $25 = HEAP32[$0>>2]|0;
 $26 = ($25|0)==(0|0);
 if ($26) {
  ___resumeException($23|0);
  // unreachable;
 }
 $27 = HEAP32[$3>>2]|0;
 $28 = ($27|0)==($25|0);
 do {
  if ($28) {
   $42 = $25;
  } else {
   $30 = $27;
   while(1) {
    $29 = ((($30)) + -4|0);
    HEAP32[$3>>2] = $29;
    $31 = HEAP32[$29>>2]|0;
    $32 = ($31|0)==(0|0);
    if (!($32)) {
     $33 = ((($31)) + 8|0);
     $34 = HEAP32[$33>>2]|0;HEAP32[$33>>2] = (($34-1)|0);
     $35 = ($34|0)==(1);
     if ($35) {
      __THREW__ = 0;
      invoke_viii(3262,($31|0),1,1);
      $36 = __THREW__; __THREW__ = 0;
      $37 = $36&1;
      if ($37) {
       label = 15;
       break;
      }
     }
    }
    HEAP32[$29>>2] = 0;
    $38 = HEAP32[$3>>2]|0;
    $39 = ($38|0)==($25|0);
    if ($39) {
     label = 16;
     break;
    } else {
     $30 = $38;
    }
   }
   if ((label|0) == 15) {
    $40 = ___cxa_find_matching_catch_2()|0;
    $41 = tempRet0;
    ___cxa_call_unexpected(($40|0));
    // unreachable;
   }
   else if ((label|0) == 16) {
    $$pre$i7 = HEAP32[$0>>2]|0;
    $42 = $$pre$i7;
    break;
   }
  }
 } while(0);
 __ZdlPv($42);
 ___resumeException($23|0);
 // unreachable;
}
function __ZNSt3__26__treeINS_12__value_typeIfNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEEENS_19__map_value_compareIfS8_NS_4lessIfEELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 }
 $3 = HEAP32[$1>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIfNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEEENS_19__map_value_compareIfS8_NS_4lessIfEELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($0,$3);
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIfNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEEENS_19__map_value_compareIfS8_NS_4lessIfEELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($0,$5);
 $6 = ((($1)) + 20|0);
 $7 = ((($6)) + 11|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = ($8<<24>>24)<(0);
 if ($9) {
  $10 = HEAP32[$6>>2]|0;
  __ZdlPv($10);
 }
 __ZdlPv($1);
 return;
}
function __ZN3osg6ShaderC2ENS0_4TypeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 __ZN3osg10ReferencedC2Ev($0);
 $3 = ((($0)) + 12|0);
 ;HEAP32[$3>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;
 $4 = ((($0)) + 24|0);
 HEAP32[$4>>2] = 2;
 $5 = ((($0)) + 28|0);
 HEAP32[$5>>2] = 0;
 HEAP32[$0>>2] = (65652);
 $6 = ((($0)) + 32|0);
 HEAP32[$6>>2] = $1;
 $7 = ((($0)) + 36|0);
 $8 = ((($0)) + 48|0);
 $9 = ((($0)) + 60|0);
 $10 = ((($0)) + 64|0);
 $11 = ((($0)) + 68|0);
 HEAP32[$11>>2] = 0;
 $12 = ((($0)) + 72|0);
 HEAP32[$12>>2] = 0;
 $13 = ((($0)) + 68|0);
 ;HEAP32[$7>>2]=0|0;HEAP32[$7+4>>2]=0|0;HEAP32[$7+8>>2]=0|0;HEAP32[$7+12>>2]=0|0;HEAP32[$7+16>>2]=0|0;HEAP32[$7+20>>2]=0|0;HEAP32[$7+24>>2]=0|0;
 HEAP32[$10>>2] = $13;
 $14 = ((($0)) + 76|0);
 HEAP32[$14>>2] = 0;
 $15 = ((($0)) + 80|0);
 $16 = ((($0)) + 84|0);
 HEAP32[$16>>2] = 0;
 $17 = ((($0)) + 88|0);
 HEAP32[$17>>2] = 0;
 $18 = ((($0)) + 84|0);
 HEAP32[$15>>2] = $18;
 $19 = ((($0)) + 92|0);
 $20 = ((($0)) + 96|0);
 HEAP32[$20>>2] = 0;
 $21 = ((($0)) + 100|0);
 HEAP32[$21>>2] = 0;
 $22 = ((($0)) + 96|0);
 HEAP32[$19>>2] = $22;
 $23 = ((($0)) + 104|0);
 $24 = ((($0)) + 108|0);
 HEAP32[$24>>2] = 0;
 $25 = ((($0)) + 112|0);
 HEAP32[$25>>2] = 0;
 $26 = ((($0)) + 108|0);
 HEAP32[$23>>2] = $26;
 $27 = ((($0)) + 116|0);
 __THREW__ = 0;
 $28 = (invoke_i(3285)|0);
 $29 = __THREW__; __THREW__ = 0;
 $30 = $29&1;
 do {
  if ($30) {
   label = 13;
  } else {
   $31 = HEAP32[$28>>2]|0;
   __THREW__ = 0;
   $32 = (invoke_ii(3286,($31|0))|0);
   $33 = __THREW__; __THREW__ = 0;
   $34 = $33&1;
   if ($34) {
    label = 13;
   } else {
    HEAP32[$2>>2] = 0;
    __THREW__ = 0;
    invoke_viii(3891,($27|0),($32|0),($2|0));
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     $44 = ___cxa_find_matching_catch_2()|0;
     $45 = tempRet0;
     $46 = HEAP32[$2>>2]|0;
     $47 = ($46|0)==(0|0);
     if (!($47)) {
      $48 = ((($46)) + 8|0);
      $49 = HEAP32[$48>>2]|0;HEAP32[$48>>2] = (($49-1)|0);
      $50 = ($49|0)==(1);
      if ($50) {
       __THREW__ = 0;
       invoke_viii(3262,($46|0),1,1);
       $51 = __THREW__; __THREW__ = 0;
       $52 = $51&1;
       if ($52) {
        $53 = ___cxa_find_matching_catch_3(0|0)|0;
        $54 = tempRet0;
        ___clang_call_terminate($53);
        // unreachable;
       }
      }
     }
     $eh$lpad$body$index2Z2D = $45;$eh$lpad$body$indexZ2D = $44;
     break;
    }
    $37 = HEAP32[$2>>2]|0;
    $38 = ($37|0)==(0|0);
    if ($38) {
     STACKTOP = sp;return;
    }
    $39 = ((($37)) + 8|0);
    $40 = HEAP32[$39>>2]|0;HEAP32[$39>>2] = (($40-1)|0);
    $41 = ($40|0)==(1);
    if (!($41)) {
     STACKTOP = sp;return;
    }
    __THREW__ = 0;
    invoke_viii(3262,($37|0),1,1);
    $42 = __THREW__; __THREW__ = 0;
    $43 = $42&1;
    if ($43) {
     label = 13;
    } else {
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 if ((label|0) == 13) {
  $55 = ___cxa_find_matching_catch_2()|0;
  $56 = tempRet0;
  $eh$lpad$body$index2Z2D = $56;$eh$lpad$body$indexZ2D = $55;
 }
 $57 = HEAP32[$26>>2]|0;
 __ZNSt3__26__treeIPN3osg7ProgramENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($23,$57);
 $58 = HEAP32[$22>>2]|0;
 __ZNSt3__26__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EENS4_IS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($19,$58);
 $59 = HEAP32[$18>>2]|0;
 __ZNSt3__26__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EENS4_IS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($15,$59);
 $60 = HEAP32[$13>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIfNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEEENS_19__map_value_compareIfS8_NS_4lessIfEELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($10,$60);
 $61 = HEAP32[$9>>2]|0;
 $62 = ($61|0)==(0|0);
 if (!($62)) {
  $63 = ((($61)) + 8|0);
  $64 = HEAP32[$63>>2]|0;HEAP32[$63>>2] = (($64-1)|0);
  $65 = ($64|0)==(1);
  if ($65) {
   __THREW__ = 0;
   invoke_viii(3262,($61|0),1,1);
   $66 = __THREW__; __THREW__ = 0;
   $67 = $66&1;
   if ($67) {
    $78 = ___cxa_find_matching_catch_3(0|0)|0;
    $79 = tempRet0;
    ___clang_call_terminate($78);
    // unreachable;
   }
  }
 }
 HEAP32[$9>>2] = 0;
 $68 = ((($8)) + 11|0);
 $69 = HEAP8[$68>>0]|0;
 $70 = ($69<<24>>24)<(0);
 if ($70) {
  $71 = HEAP32[$8>>2]|0;
  __ZdlPv($71);
 }
 $72 = ((($7)) + 11|0);
 $73 = HEAP8[$72>>0]|0;
 $74 = ($73<<24>>24)<(0);
 if ($74) {
  $75 = HEAP32[$7>>2]|0;
  __ZdlPv($75);
 }
 __THREW__ = 0;
 invoke_vi(388,($0|0));
 $76 = __THREW__; __THREW__ = 0;
 $77 = $76&1;
 if ($77) {
  $78 = ___cxa_find_matching_catch_3(0|0)|0;
  $79 = tempRet0;
  ___clang_call_terminate($78);
  // unreachable;
 } else {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
}
function __ZNK3osg6Shader13compileShaderERNS_5StateE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__ZNK3osg6Shader6getPCSERNS_5StateE($0,$1)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  return;
 }
 __ZN3osg6Shader16PerContextShader13compileShaderERNS_5StateE($2,$1);
 return;
}
function __ZN3osg6ShaderC2ENS0_4TypeERKNSt3__212basic_stringIcNS2_11char_traitsIcEENS2_9allocatorIcEEEE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$04 = 0, $$pre$i$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 __ZN3osg10ReferencedC2Ev($0);
 $4 = ((($0)) + 12|0);
 ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;
 $5 = ((($0)) + 24|0);
 HEAP32[$5>>2] = 2;
 $6 = ((($0)) + 28|0);
 HEAP32[$6>>2] = 0;
 HEAP32[$0>>2] = (65652);
 $7 = ((($0)) + 32|0);
 HEAP32[$7>>2] = $1;
 $8 = ((($0)) + 36|0);
 $9 = ((($0)) + 48|0);
 $10 = ((($0)) + 60|0);
 $11 = ((($0)) + 64|0);
 $12 = ((($0)) + 68|0);
 HEAP32[$12>>2] = 0;
 $13 = ((($0)) + 72|0);
 HEAP32[$13>>2] = 0;
 $14 = ((($0)) + 68|0);
 ;HEAP32[$8>>2]=0|0;HEAP32[$8+4>>2]=0|0;HEAP32[$8+8>>2]=0|0;HEAP32[$8+12>>2]=0|0;HEAP32[$8+16>>2]=0|0;HEAP32[$8+20>>2]=0|0;HEAP32[$8+24>>2]=0|0;
 HEAP32[$11>>2] = $14;
 $15 = ((($0)) + 76|0);
 HEAP32[$15>>2] = 0;
 $16 = ((($0)) + 80|0);
 $17 = ((($0)) + 84|0);
 HEAP32[$17>>2] = 0;
 $18 = ((($0)) + 88|0);
 HEAP32[$18>>2] = 0;
 $19 = ((($0)) + 84|0);
 HEAP32[$16>>2] = $19;
 $20 = ((($0)) + 92|0);
 $21 = ((($0)) + 96|0);
 HEAP32[$21>>2] = 0;
 $22 = ((($0)) + 100|0);
 HEAP32[$22>>2] = 0;
 $23 = ((($0)) + 96|0);
 HEAP32[$20>>2] = $23;
 $24 = ((($0)) + 104|0);
 $25 = ((($0)) + 108|0);
 HEAP32[$25>>2] = 0;
 $26 = ((($0)) + 112|0);
 HEAP32[$26>>2] = 0;
 $27 = ((($0)) + 108|0);
 HEAP32[$24>>2] = $27;
 $28 = ((($0)) + 116|0);
 __THREW__ = 0;
 $29 = (invoke_i(3285)|0);
 $30 = __THREW__; __THREW__ = 0;
 $31 = $30&1;
 do {
  if ($31) {
   label = 16;
  } else {
   $32 = HEAP32[$29>>2]|0;
   __THREW__ = 0;
   $33 = (invoke_ii(3286,($32|0))|0);
   $34 = __THREW__; __THREW__ = 0;
   $35 = $34&1;
   if ($35) {
    label = 16;
   } else {
    HEAP32[$3>>2] = 0;
    __THREW__ = 0;
    invoke_viii(3891,($28|0),($33|0),($3|0));
    $36 = __THREW__; __THREW__ = 0;
    $37 = $36&1;
    if ($37) {
     $45 = ___cxa_find_matching_catch_2()|0;
     $46 = tempRet0;
     $47 = HEAP32[$3>>2]|0;
     $48 = ($47|0)==(0|0);
     if (!($48)) {
      $49 = ((($47)) + 8|0);
      $50 = HEAP32[$49>>2]|0;HEAP32[$49>>2] = (($50-1)|0);
      $51 = ($50|0)==(1);
      if ($51) {
       __THREW__ = 0;
       invoke_viii(3262,($47|0),1,1);
       $52 = __THREW__; __THREW__ = 0;
       $53 = $52&1;
       if ($53) {
        $54 = ___cxa_find_matching_catch_3(0|0)|0;
        $55 = tempRet0;
        ___clang_call_terminate($54);
        // unreachable;
       }
      }
     }
     $eh$lpad$body$index2Z2D = $46;$eh$lpad$body$indexZ2D = $45;
     label = 17;
     break;
    }
    $38 = HEAP32[$3>>2]|0;
    $39 = ($38|0)==(0|0);
    if (!($39)) {
     $40 = ((($38)) + 8|0);
     $41 = HEAP32[$40>>2]|0;HEAP32[$40>>2] = (($41-1)|0);
     $42 = ($41|0)==(1);
     if ($42) {
      __THREW__ = 0;
      invoke_viii(3262,($38|0),1,1);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 16;
       break;
      }
     }
    }
    __THREW__ = 0;
    (invoke_iii(3477,($9|0),($2|0))|0);
    $56 = __THREW__; __THREW__ = 0;
    $57 = $56&1;
    if (!($57)) {
     __THREW__ = 0;
     invoke_vi(3892,($0|0));
     $58 = __THREW__; __THREW__ = 0;
     $59 = $58&1;
     if (!($59)) {
      __THREW__ = 0;
      invoke_vi(3893,($0|0));
      $60 = __THREW__; __THREW__ = 0;
      $61 = $60&1;
      if (!($61)) {
       STACKTOP = sp;return;
      }
     }
    }
    $64 = ___cxa_find_matching_catch_2()|0;
    $65 = tempRet0;
    $66 = HEAP32[$28>>2]|0;
    $67 = ($66|0)==(0|0);
    if ($67) {
     $$0 = $65;$$04 = $64;
    } else {
     $68 = ((($0)) + 120|0);
     $69 = HEAP32[$68>>2]|0;
     $70 = ($69|0)==($66|0);
     do {
      if ($70) {
       $84 = $66;
      } else {
       $72 = $69;
       while(1) {
        $71 = ((($72)) + -4|0);
        HEAP32[$68>>2] = $71;
        $73 = HEAP32[$71>>2]|0;
        $74 = ($73|0)==(0|0);
        if (!($74)) {
         $75 = ((($73)) + 8|0);
         $76 = HEAP32[$75>>2]|0;HEAP32[$75>>2] = (($76-1)|0);
         $77 = ($76|0)==(1);
         if ($77) {
          __THREW__ = 0;
          invoke_viii(3262,($73|0),1,1);
          $78 = __THREW__; __THREW__ = 0;
          $79 = $78&1;
          if ($79) {
           label = 24;
           break;
          }
         }
        }
        HEAP32[$71>>2] = 0;
        $80 = HEAP32[$68>>2]|0;
        $81 = ($80|0)==($66|0);
        if ($81) {
         label = 25;
         break;
        } else {
         $72 = $80;
        }
       }
       if ((label|0) == 24) {
        $82 = ___cxa_find_matching_catch_2()|0;
        $83 = tempRet0;
        ___cxa_call_unexpected(($82|0));
        // unreachable;
       }
       else if ((label|0) == 25) {
        $$pre$i$i = HEAP32[$28>>2]|0;
        $84 = $$pre$i$i;
        break;
       }
      }
     } while(0);
     __ZdlPv($84);
     $$0 = $65;$$04 = $64;
    }
   }
  }
 } while(0);
 if ((label|0) == 16) {
  $62 = ___cxa_find_matching_catch_2()|0;
  $63 = tempRet0;
  $eh$lpad$body$index2Z2D = $63;$eh$lpad$body$indexZ2D = $62;
  label = 17;
 }
 if ((label|0) == 17) {
  $$0 = $eh$lpad$body$index2Z2D;$$04 = $eh$lpad$body$indexZ2D;
 }
 $85 = HEAP32[$27>>2]|0;
 __ZNSt3__26__treeIPN3osg7ProgramENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($24,$85);
 $86 = HEAP32[$23>>2]|0;
 __ZNSt3__26__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EENS4_IS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($20,$86);
 $87 = HEAP32[$19>>2]|0;
 __ZNSt3__26__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EENS4_IS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($16,$87);
 $88 = HEAP32[$14>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIfNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEEENS_19__map_value_compareIfS8_NS_4lessIfEELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($11,$88);
 $89 = HEAP32[$10>>2]|0;
 $90 = ($89|0)==(0|0);
 if (!($90)) {
  $91 = ((($89)) + 8|0);
  $92 = HEAP32[$91>>2]|0;HEAP32[$91>>2] = (($92-1)|0);
  $93 = ($92|0)==(1);
  if ($93) {
   __THREW__ = 0;
   invoke_viii(3262,($89|0),1,1);
   $94 = __THREW__; __THREW__ = 0;
   $95 = $94&1;
   if ($95) {
    $106 = ___cxa_find_matching_catch_3(0|0)|0;
    $107 = tempRet0;
    ___clang_call_terminate($106);
    // unreachable;
   }
  }
 }
 HEAP32[$10>>2] = 0;
 $96 = ((($9)) + 11|0);
 $97 = HEAP8[$96>>0]|0;
 $98 = ($97<<24>>24)<(0);
 if ($98) {
  $99 = HEAP32[$9>>2]|0;
  __ZdlPv($99);
 }
 $100 = ((($8)) + 11|0);
 $101 = HEAP8[$100>>0]|0;
 $102 = ($101<<24>>24)<(0);
 if ($102) {
  $103 = HEAP32[$8>>2]|0;
  __ZdlPv($103);
 }
 __THREW__ = 0;
 invoke_vi(388,($0|0));
 $104 = __THREW__; __THREW__ = 0;
 $105 = $104&1;
 if ($105) {
  $106 = ___cxa_find_matching_catch_3(0|0)|0;
  $107 = tempRet0;
  ___clang_call_terminate($106);
  // unreachable;
 } else {
  ___resumeException($$04|0);
  // unreachable;
 }
}
function __ZN3osg6Shader21_computeShaderDefinesEv($0) {
 $0 = $0|0;
 var $$$i$i = 0, $$$i$i53 = 0, $$$i$i65 = 0, $$0 = 0, $$0$i$i$i = 0, $$0$i$i$i114 = 0, $$0$i$i47 = 0, $$0$i$i52 = 0, $$0$i$i64 = 0, $$0$i167 = 0, $$0$i54 = 0, $$0$i67 = 0, $$0$i75 = 0, $$01112$i = 0, $$01112$i50 = 0, $$01112$i62 = 0, $$01112$i73 = 0, $$02729$i$i$i = 0, $$4 = 0, $$444 = 0;
 var $$5 = 0, $$545 = 0, $$pre = 0, $$pre223 = 0, $$sroa$0147$0$be = 0, $$sroa$0147$0214 = 0, $$sroa$0155$0$be = 0, $$sroa$0155$0213 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0;
 var $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0;
 var $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0;
 var $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0;
 var $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0;
 var $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0;
 var $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0;
 var $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0;
 var $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0;
 var $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0;
 var $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0;
 var $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0;
 var $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0;
 var $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0;
 var $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0;
 var $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, $eh$lpad$body137$sink169$index10Z2D = 0, $eh$lpad$body137$sink169$indexZ2D = 0, $eh$lpad$body143$index18Z2D = 0, $eh$lpad$body143$indexZ2D = 0, $not$$i$i = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(64|0);
 $1 = sp + 48|0;
 $2 = sp + 44|0;
 $3 = sp + 40|0;
 $4 = sp + 36|0;
 $5 = sp + 24|0;
 $6 = sp + 12|0;
 $7 = sp;
 $8 = sp + 52|0;
 $9 = ((($0)) + 76|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(1);
 if ($11) {
  STACKTOP = sp;return;
 }
 $12 = ((($0)) + 80|0);
 $13 = ((($0)) + 84|0);
 $14 = HEAP32[$13>>2]|0;
 __ZNSt3__26__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EENS4_IS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($12,$14);
 $15 = ((($0)) + 88|0);
 HEAP32[$15>>2] = 0;
 HEAP32[$12>>2] = $13;
 HEAP32[$13>>2] = 0;
 $16 = ((($0)) + 92|0);
 $17 = ((($0)) + 96|0);
 $18 = HEAP32[$17>>2]|0;
 __ZNSt3__26__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EENS4_IS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($16,$18);
 $19 = ((($0)) + 100|0);
 HEAP32[$19>>2] = 0;
 HEAP32[$16>>2] = $17;
 HEAP32[$17>>2] = 0;
 $20 = ((($0)) + 48|0);
 $21 = ((($20)) + 11|0);
 $22 = ((($0)) + 52|0);
 $23 = ((($5)) + 11|0);
 $24 = ((($5)) + 4|0);
 $25 = ((($6)) + 11|0);
 $26 = ((($6)) + 4|0);
 $27 = ((($7)) + 11|0);
 $$0 = 0;
 L4: while(1) {
  $28 = HEAP8[$21>>0]|0;
  $29 = ($28<<24>>24)<(0);
  if ($29) {
   $30 = HEAP32[$20>>2]|0;
   $31 = HEAP32[$22>>2]|0;
   $33 = $31;$36 = $30;
  } else {
   $32 = $28&255;
   $33 = $32;$36 = $20;
  }
  $34 = ($33>>>0)<($$0>>>0);
  if ($34) {
   label = 162;
   break;
  }
  $35 = (($36) + ($$0)|0);
  $37 = (($36) + ($33)|0);
  $38 = $37;
  $39 = $35;
  $40 = (($38) - ($39))|0;
  $41 = ($40|0)<(7);
  if ($41) {
   label = 162;
   break;
  } else {
   $$02729$i$i$i = $35;$43 = $40;
  }
  while(1) {
   $42 = (($43) + -6)|0;
   $44 = ($42|0)==(0);
   if ($44) {
    label = 162;
    break L4;
   }
   $45 = (_memchr($$02729$i$i$i,35,$42)|0);
   $46 = ($45|0)==(0|0);
   if ($46) {
    label = 162;
    break L4;
   }
   $47 = (_memcmp($45,148083,7)|0);
   $48 = ($47|0)==(0);
   if ($48) {
    break;
   }
   $49 = ((($45)) + 1|0);
   $50 = $49;
   $51 = (($38) - ($50))|0;
   $52 = ($51|0)<(7);
   if ($52) {
    label = 162;
    break L4;
   } else {
    $$02729$i$i$i = $49;$43 = $51;
   }
  }
  $53 = ($45|0)==($37|0);
  $54 = $45;
  $55 = $36;
  $56 = (($54) - ($55))|0;
  $57 = ($56|0)==(-1);
  $or$cond = $53 | $57;
  if ($or$cond) {
   label = 162;
   break;
  }
  $58 = (($56) + 7)|0;
  if ($29) {
   $59 = HEAP32[$22>>2]|0;
   $61 = $59;
  } else {
   $60 = $28&255;
   $61 = $60;
  }
  $62 = ($61>>>0)>($58>>>0);
  L22: do {
   if ($62) {
    $63 = HEAP32[$20>>2]|0;
    $64 = $29 ? $63 : $20;
    $$01112$i = $58;
    while(1) {
     $65 = (($64) + ($$01112$i)|0);
     $66 = HEAP8[$65>>0]|0;
     $$0$i$i47 = 147794;
     while(1) {
      $67 = HEAP8[$$0$i$i47>>0]|0;
      $68 = ($67<<24>>24)!=(0);
      $69 = ($67<<24>>24)!=($66<<24>>24);
      $$$i$i = $68 & $69;
      $70 = ((($$0$i$i47)) + 1|0);
      if ($$$i$i) {
       $$0$i$i47 = $70;
      } else {
       break;
      }
     }
     if ($68) {
      break;
     }
     $71 = (($$01112$i) + 1)|0;
     $72 = ($71>>>0)<($61>>>0);
     if ($72) {
      $$01112$i = $71;
     } else {
      label = 23;
      break L22;
     }
    }
    $73 = ($$01112$i|0)==(-1);
    if ($73) {
     label = 23;
    } else {
     $$0$i167 = $$01112$i;$422 = 0;$76 = $$01112$i;
    }
   } else {
    label = 23;
   }
  } while(0);
  do {
   if ((label|0) == 23) {
    label = 0;
    if ($29) {
     $74 = HEAP32[$22>>2]|0;
     $$0$i167 = -1;$422 = 1;$76 = $74;
     break;
    } else {
     $75 = $28&255;
     $$0$i167 = -1;$422 = 1;$76 = $75;
     break;
    }
   }
  } while(0);
  $77 = ($76>>>0)>($58>>>0);
  L37: do {
   if ($77) {
    $78 = HEAP32[$20>>2]|0;
    $79 = $29 ? $78 : $20;
    $$01112$i50 = $58;
    while(1) {
     $80 = (($79) + ($$01112$i50)|0);
     $81 = HEAP8[$80>>0]|0;
     $$0$i$i52 = 147791;
     while(1) {
      $82 = HEAP8[$$0$i$i52>>0]|0;
      $83 = ($82<<24>>24)==(0);
      $84 = ($82<<24>>24)!=($81<<24>>24);
      $not$$i$i = $83 ^ 1;
      $$$i$i53 = $84 & $not$$i$i;
      $85 = ((($$0$i$i52)) + 1|0);
      if ($$$i$i53) {
       $$0$i$i52 = $85;
      } else {
       break;
      }
     }
     if ($83) {
      $$0$i54 = $$01112$i50;
      break L37;
     }
     $86 = (($$01112$i50) + 1)|0;
     $87 = ($86>>>0)<($76>>>0);
     if ($87) {
      $$01112$i50 = $86;
     } else {
      $$0$i54 = $$0$i167;
      break;
     }
    }
   } else {
    $$0$i54 = $$0$i167;
   }
  } while(0);
  $88 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
  if ($88) {
   $89 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
   $90 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($89,148091,20)|0);
   $91 = (($$0$i167) - ($$0$i54))|0;
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_jjRKS4_($5,$20,$$0$i54,$91,$20);
   $92 = HEAP8[$23>>0]|0;
   $93 = ($92<<24>>24)<(0);
   $94 = HEAP32[$5>>2]|0;
   $95 = $93 ? $94 : $5;
   $96 = HEAP32[$24>>2]|0;
   $97 = $92&255;
   $98 = $93 ? $96 : $97;
   __THREW__ = 0;
   $99 = (invoke_iiii(3267,($90|0),($95|0),($98|0))|0);
   $100 = __THREW__; __THREW__ = 0;
   $101 = $100&1;
   if ($101) {
    label = 47;
    break;
   }
   __THREW__ = 0;
   $102 = (invoke_iiii(3267,($99|0),(149155|0),1)|0);
   $103 = __THREW__; __THREW__ = 0;
   $104 = $103&1;
   if ($104) {
    label = 47;
    break;
   }
   $105 = HEAP32[$102>>2]|0;
   $106 = ((($105)) + -12|0);
   $107 = HEAP32[$106>>2]|0;
   $108 = (($102) + ($107)|0);
   __THREW__ = 0;
   invoke_vii(3257,($4|0),($108|0));
   $109 = __THREW__; __THREW__ = 0;
   $110 = $109&1;
   if ($110) {
    label = 47;
    break;
   }
   __THREW__ = 0;
   $111 = (invoke_iii(3255,($4|0),(215188|0))|0);
   $112 = __THREW__; __THREW__ = 0;
   $113 = $112&1;
   if ($113) {
    label = 39;
    break;
   }
   $114 = HEAP32[$111>>2]|0;
   $115 = ((($114)) + 28|0);
   $116 = HEAP32[$115>>2]|0;
   __THREW__ = 0;
   $117 = (invoke_iii($116|0,($111|0),10)|0);
   $118 = __THREW__; __THREW__ = 0;
   $119 = $118&1;
   if ($119) {
    label = 39;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3263,($4|0));
   $120 = __THREW__; __THREW__ = 0;
   $121 = $120&1;
   if ($121) {
    label = 47;
    break;
   }
   __THREW__ = 0;
   (invoke_iii(3268,($102|0),($117|0))|0);
   $128 = __THREW__; __THREW__ = 0;
   $129 = $128&1;
   if ($129) {
    label = 47;
    break;
   }
   __THREW__ = 0;
   (invoke_ii(3269,($102|0))|0);
   $130 = __THREW__; __THREW__ = 0;
   $131 = $130&1;
   if ($131) {
    label = 47;
    break;
   }
   $132 = HEAP8[$23>>0]|0;
   $133 = ($132<<24>>24)<(0);
   if ($133) {
    $134 = HEAP32[$5>>2]|0;
    __ZdlPv($134);
   }
  }
  $140 = ($$0$i167>>>0)>($$0$i54>>>0);
  if (!($140)) {
   $$0 = $$0$i167;
   continue;
  }
  do {
   if ($422) {
    $141 = HEAP8[$21>>0]|0;
    $142 = ($141<<24>>24)<(0);
    if ($142) {
     $143 = HEAP32[$22>>2]|0;
     $145 = $143;
     break;
    } else {
     $144 = $141&255;
     $145 = $144;
     break;
    }
   } else {
    $145 = $$0$i167;
   }
  } while(0);
  $146 = ($145>>>0)>($$0$i54>>>0);
  L67: do {
   if ($146) {
    $147 = HEAP8[$21>>0]|0;
    $148 = ($147<<24>>24)<(0);
    $149 = HEAP32[$20>>2]|0;
    $150 = $148 ? $149 : $20;
    $$01112$i62 = $$0$i54;
    while(1) {
     $151 = (($150) + ($$01112$i62)|0);
     $152 = HEAP8[$151>>0]|0;
     $$0$i$i64 = 148112;
     while(1) {
      $153 = HEAP8[$$0$i$i64>>0]|0;
      $154 = ($153<<24>>24)!=(0);
      $155 = ($153<<24>>24)!=($152<<24>>24);
      $$$i$i65 = $154 & $155;
      $156 = ((($$0$i$i64)) + 1|0);
      if ($$$i$i65) {
       $$0$i$i64 = $156;
      } else {
       break;
      }
     }
     if ($154) {
      $$0$i67 = $$01112$i62;
      break L67;
     }
     $157 = (($$01112$i62) + 1)|0;
     $158 = ($157>>>0)<($145>>>0);
     if ($158) {
      $$01112$i62 = $157;
     } else {
      $$0$i67 = $$0$i167;
      break;
     }
    }
   } else {
    $$0$i67 = $$0$i167;
   }
  } while(0);
  $159 = (($$0$i67) - ($$0$i54))|0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_jjRKS4_($6,$20,$$0$i54,$159,$20);
  do {
   if ($422) {
    $160 = HEAP8[$21>>0]|0;
    $161 = ($160<<24>>24)<(0);
    if ($161) {
     $162 = HEAP32[$22>>2]|0;
     $164 = $162;
     break;
    } else {
     $163 = $160&255;
     $164 = $163;
     break;
    }
   } else {
    $164 = $$0$i167;
   }
  } while(0);
  $165 = ($164>>>0)>($$0$i67>>>0);
  L82: do {
   if ($165) {
    $166 = HEAP8[$21>>0]|0;
    $167 = ($166<<24>>24)<(0);
    $168 = HEAP32[$20>>2]|0;
    $169 = $167 ? $168 : $20;
    $$01112$i73 = $$0$i67;
    while(1) {
     $170 = (($169) + ($$01112$i73)|0);
     $171 = HEAP8[$170>>0]|0;
     $172 = ($171<<24>>24)==(40);
     if ($172) {
      $$0$i75 = $$01112$i73;
      break L82;
     }
     $173 = (($$01112$i73) + 1)|0;
     $174 = ($173>>>0)<($164>>>0);
     if ($174) {
      $$01112$i73 = $173;
     } else {
      $$0$i75 = $$0$i167;
      break;
     }
    }
   } else {
    $$0$i75 = $$0$i167;
   }
  } while(0);
  $175 = ($$0$i167>>>0)>($$0$i75>>>0);
  if ($175) {
   $176 = (($$0$i75) + 1)|0;
   $177 = (($$0$i167) + -1)|0;
   $178 = (($177) - ($$0$i75))|0;
   __THREW__ = 0;
   invoke_viiiii(3746,($7|0),($20|0),($176|0),($178|0),($8|0));
   $179 = __THREW__; __THREW__ = 0;
   $180 = $179&1;
   if ($180) {
    label = 78;
    break;
   }
   $181 = HEAP8[$25>>0]|0;
   $182 = ($181<<24>>24)<(0);
   $183 = HEAP32[$26>>2]|0;
   $184 = $181&255;
   $185 = $182 ? $183 : $184;
   $186 = ($185|0)==(14);
   do {
    if ($186) {
     __THREW__ = 0;
     $187 = (invoke_iiiiii(3253,($6|0),0,-1,(148116|0),14)|0);
     $188 = __THREW__; __THREW__ = 0;
     $189 = $188&1;
     if ($189) {
      label = 74;
      break L4;
     }
     $192 = ($187|0)==(0);
     if ($192) {
      __THREW__ = 0;
      invoke_viii(3894,0,($7|0),($12|0));
      $193 = __THREW__; __THREW__ = 0;
      $194 = $193&1;
      if ($194) {
       label = 79;
       break L4;
      } else {
       break;
      }
     } else {
      $$pre = HEAP8[$25>>0]|0;
      $$pre223 = HEAP32[$26>>2]|0;
      $199 = $$pre;$202 = $$pre223;
      label = 80;
      break;
     }
    } else {
     $199 = $181;$202 = $183;
     label = 80;
    }
   } while(0);
   L97: do {
    if ((label|0) == 80) {
     label = 0;
     $200 = ($199<<24>>24)<(0);
     $201 = $199&255;
     $203 = $200 ? $202 : $201;
     $204 = ($203|0)==(8);
     do {
      if ($204) {
       __THREW__ = 0;
       $205 = (invoke_iiiiii(3253,($6|0),0,-1,(148131|0),8)|0);
       $206 = __THREW__; __THREW__ = 0;
       $207 = $206&1;
       if ($207) {
        label = 82;
        break L4;
       }
       $210 = ($205|0)==(0);
       if (!($210)) {
        break;
       }
       __THREW__ = 0;
       invoke_viii(3894,0,($7|0),($16|0));
       $211 = __THREW__; __THREW__ = 0;
       $212 = $211&1;
       if ($212) {
        label = 79;
        break L4;
       } else {
        break L97;
       }
      }
     } while(0);
     __THREW__ = 0;
     invoke_viii(3894,0,($7|0),($12|0));
     $213 = __THREW__; __THREW__ = 0;
     $214 = $213&1;
     if ($214) {
      label = 79;
      break L4;
     }
    }
   } while(0);
   $215 = HEAP32[$12>>2]|0;
   $216 = ($215|0)==($13|0);
   if (!($216)) {
    $$sroa$0155$0213 = $215;
    while(1) {
     __THREW__ = 0;
     $219 = (invoke_ii(3265,4)|0);
     $220 = __THREW__; __THREW__ = 0;
     $221 = $220&1;
     if ($221) {
      label = 103;
      break L4;
     }
     if ($219) {
      __THREW__ = 0;
      $222 = (invoke_ii(3266,4)|0);
      $223 = __THREW__; __THREW__ = 0;
      $224 = $223&1;
      if ($224) {
       label = 103;
       break L4;
      }
      __THREW__ = 0;
      $225 = (invoke_iiii(3267,($222|0),(148140|0),14)|0);
      $226 = __THREW__; __THREW__ = 0;
      $227 = $226&1;
      if ($227) {
       label = 103;
       break L4;
      }
      $228 = ((($$sroa$0155$0213)) + 16|0);
      $229 = ((($228)) + 11|0);
      $230 = HEAP8[$229>>0]|0;
      $231 = ($230<<24>>24)<(0);
      $232 = HEAP32[$228>>2]|0;
      $233 = $231 ? $232 : $228;
      $234 = ((($$sroa$0155$0213)) + 20|0);
      $235 = HEAP32[$234>>2]|0;
      $236 = $230&255;
      $237 = $231 ? $235 : $236;
      __THREW__ = 0;
      $238 = (invoke_iiii(3267,($225|0),($233|0),($237|0))|0);
      $239 = __THREW__; __THREW__ = 0;
      $240 = $239&1;
      if ($240) {
       label = 103;
       break L4;
      }
      __THREW__ = 0;
      $241 = (invoke_iiii(3267,($238|0),(149155|0),1)|0);
      $242 = __THREW__; __THREW__ = 0;
      $243 = $242&1;
      if ($243) {
       label = 103;
       break L4;
      }
      $244 = HEAP32[$241>>2]|0;
      $245 = ((($244)) + -12|0);
      $246 = HEAP32[$245>>2]|0;
      $247 = (($241) + ($246)|0);
      __THREW__ = 0;
      invoke_vii(3257,($3|0),($247|0));
      $248 = __THREW__; __THREW__ = 0;
      $249 = $248&1;
      if ($249) {
       label = 103;
       break L4;
      }
      __THREW__ = 0;
      $250 = (invoke_iii(3255,($3|0),(215188|0))|0);
      $251 = __THREW__; __THREW__ = 0;
      $252 = $251&1;
      if ($252) {
       label = 98;
       break L4;
      }
      $253 = HEAP32[$250>>2]|0;
      $254 = ((($253)) + 28|0);
      $255 = HEAP32[$254>>2]|0;
      __THREW__ = 0;
      $256 = (invoke_iii($255|0,($250|0),10)|0);
      $257 = __THREW__; __THREW__ = 0;
      $258 = $257&1;
      if ($258) {
       label = 98;
       break L4;
      }
      __THREW__ = 0;
      invoke_vi(3263,($3|0));
      $259 = __THREW__; __THREW__ = 0;
      $260 = $259&1;
      if ($260) {
       label = 103;
       break L4;
      }
      __THREW__ = 0;
      (invoke_iii(3268,($241|0),($256|0))|0);
      $267 = __THREW__; __THREW__ = 0;
      $268 = $267&1;
      if ($268) {
       label = 103;
       break L4;
      }
      __THREW__ = 0;
      (invoke_ii(3269,($241|0))|0);
      $269 = __THREW__; __THREW__ = 0;
      $270 = $269&1;
      if ($270) {
       label = 103;
       break L4;
      }
     }
     $273 = ((($$sroa$0155$0213)) + 4|0);
     $274 = HEAP32[$273>>2]|0;
     $275 = ($274|0)==(0|0);
     do {
      if ($275) {
       $276 = ((($$sroa$0155$0213)) + 8|0);
       $277 = HEAP32[$276>>2]|0;
       $278 = HEAP32[$277>>2]|0;
       $279 = ($278|0)==($$sroa$0155$0213|0);
       if ($279) {
        $$sroa$0155$0$be = $277;
        break;
       } else {
        $284 = $276;
       }
       while(1) {
        $283 = HEAP32[$284>>2]|0;
        $285 = ((($283)) + 8|0);
        $286 = HEAP32[$285>>2]|0;
        $287 = HEAP32[$286>>2]|0;
        $288 = ($287|0)==($283|0);
        if ($288) {
         $$sroa$0155$0$be = $286;
         break;
        } else {
         $284 = $285;
        }
       }
      } else {
       $$0$i$i$i = $274;
       while(1) {
        $281 = HEAP32[$$0$i$i$i>>2]|0;
        $282 = ($281|0)==(0|0);
        if ($282) {
         break;
        } else {
         $$0$i$i$i = $281;
        }
       }
       $$sroa$0155$0$be = $$0$i$i$i;
      }
     } while(0);
     $280 = ($$sroa$0155$0$be|0)==($13|0);
     if ($280) {
      break;
     } else {
      $$sroa$0155$0213 = $$sroa$0155$0$be;
     }
    }
   }
   $217 = HEAP32[$16>>2]|0;
   $218 = ($217|0)==($17|0);
   if (!($218)) {
    $$sroa$0147$0214 = $217;
    while(1) {
     __THREW__ = 0;
     $292 = (invoke_ii(3265,4)|0);
     $293 = __THREW__; __THREW__ = 0;
     $294 = $293&1;
     if ($294) {
      label = 128;
      break L4;
     }
     if ($292) {
      __THREW__ = 0;
      $295 = (invoke_ii(3266,4)|0);
      $296 = __THREW__; __THREW__ = 0;
      $297 = $296&1;
      if ($297) {
       label = 128;
       break L4;
      }
      __THREW__ = 0;
      $298 = (invoke_iiii(3267,($295|0),(148155|0),20)|0);
      $299 = __THREW__; __THREW__ = 0;
      $300 = $299&1;
      if ($300) {
       label = 128;
       break L4;
      }
      $301 = ((($$sroa$0147$0214)) + 16|0);
      $302 = ((($301)) + 11|0);
      $303 = HEAP8[$302>>0]|0;
      $304 = ($303<<24>>24)<(0);
      $305 = HEAP32[$301>>2]|0;
      $306 = $304 ? $305 : $301;
      $307 = ((($$sroa$0147$0214)) + 20|0);
      $308 = HEAP32[$307>>2]|0;
      $309 = $303&255;
      $310 = $304 ? $308 : $309;
      __THREW__ = 0;
      $311 = (invoke_iiii(3267,($298|0),($306|0),($310|0))|0);
      $312 = __THREW__; __THREW__ = 0;
      $313 = $312&1;
      if ($313) {
       label = 128;
       break L4;
      }
      __THREW__ = 0;
      $314 = (invoke_iiii(3267,($311|0),(149155|0),1)|0);
      $315 = __THREW__; __THREW__ = 0;
      $316 = $315&1;
      if ($316) {
       label = 128;
       break L4;
      }
      $317 = HEAP32[$314>>2]|0;
      $318 = ((($317)) + -12|0);
      $319 = HEAP32[$318>>2]|0;
      $320 = (($314) + ($319)|0);
      __THREW__ = 0;
      invoke_vii(3257,($2|0),($320|0));
      $321 = __THREW__; __THREW__ = 0;
      $322 = $321&1;
      if ($322) {
       label = 128;
       break L4;
      }
      __THREW__ = 0;
      $323 = (invoke_iii(3255,($2|0),(215188|0))|0);
      $324 = __THREW__; __THREW__ = 0;
      $325 = $324&1;
      if ($325) {
       label = 123;
       break L4;
      }
      $326 = HEAP32[$323>>2]|0;
      $327 = ((($326)) + 28|0);
      $328 = HEAP32[$327>>2]|0;
      __THREW__ = 0;
      $329 = (invoke_iii($328|0,($323|0),10)|0);
      $330 = __THREW__; __THREW__ = 0;
      $331 = $330&1;
      if ($331) {
       label = 123;
       break L4;
      }
      __THREW__ = 0;
      invoke_vi(3263,($2|0));
      $332 = __THREW__; __THREW__ = 0;
      $333 = $332&1;
      if ($333) {
       label = 128;
       break L4;
      }
      __THREW__ = 0;
      (invoke_iii(3268,($314|0),($329|0))|0);
      $340 = __THREW__; __THREW__ = 0;
      $341 = $340&1;
      if ($341) {
       label = 128;
       break L4;
      }
      __THREW__ = 0;
      (invoke_ii(3269,($314|0))|0);
      $342 = __THREW__; __THREW__ = 0;
      $343 = $342&1;
      if ($343) {
       label = 128;
       break L4;
      }
     }
     $346 = ((($$sroa$0147$0214)) + 4|0);
     $347 = HEAP32[$346>>2]|0;
     $348 = ($347|0)==(0|0);
     do {
      if ($348) {
       $349 = ((($$sroa$0147$0214)) + 8|0);
       $350 = HEAP32[$349>>2]|0;
       $351 = HEAP32[$350>>2]|0;
       $352 = ($351|0)==($$sroa$0147$0214|0);
       if ($352) {
        $$sroa$0147$0$be = $350;
        break;
       } else {
        $357 = $349;
       }
       while(1) {
        $356 = HEAP32[$357>>2]|0;
        $358 = ((($356)) + 8|0);
        $359 = HEAP32[$358>>2]|0;
        $360 = HEAP32[$359>>2]|0;
        $361 = ($360|0)==($356|0);
        if ($361) {
         $$sroa$0147$0$be = $359;
         break;
        } else {
         $357 = $358;
        }
       }
      } else {
       $$0$i$i$i114 = $347;
       while(1) {
        $354 = HEAP32[$$0$i$i$i114>>2]|0;
        $355 = ($354|0)==(0|0);
        if ($355) {
         break;
        } else {
         $$0$i$i$i114 = $354;
        }
       }
       $$sroa$0147$0$be = $$0$i$i$i114;
      }
     } while(0);
     $353 = ($$sroa$0147$0$be|0)==($17|0);
     if ($353) {
      break;
     } else {
      $$sroa$0147$0214 = $$sroa$0147$0$be;
     }
    }
   }
   $289 = HEAP8[$27>>0]|0;
   $290 = ($289<<24>>24)<(0);
   if ($290) {
    $291 = HEAP32[$7>>2]|0;
    __ZdlPv($291);
   }
  } else {
   __THREW__ = 0;
   $365 = (invoke_ii(3265,4)|0);
   $366 = __THREW__; __THREW__ = 0;
   $367 = $366&1;
   if ($367) {
    label = 153;
    break;
   }
   if ($365) {
    __THREW__ = 0;
    $368 = (invoke_ii(3266,4)|0);
    $369 = __THREW__; __THREW__ = 0;
    $370 = $369&1;
    if ($370) {
     label = 153;
     break;
    }
    __THREW__ = 0;
    $371 = (invoke_iiii(3267,($368|0),(148176|0),19)|0);
    $372 = __THREW__; __THREW__ = 0;
    $373 = $372&1;
    if ($373) {
     label = 153;
     break;
    }
    $374 = HEAP8[$25>>0]|0;
    $375 = ($374<<24>>24)<(0);
    $376 = HEAP32[$6>>2]|0;
    $377 = $375 ? $376 : $6;
    $378 = HEAP32[$26>>2]|0;
    $379 = $374&255;
    $380 = $375 ? $378 : $379;
    __THREW__ = 0;
    $381 = (invoke_iiii(3267,($371|0),($377|0),($380|0))|0);
    $382 = __THREW__; __THREW__ = 0;
    $383 = $382&1;
    if ($383) {
     label = 153;
     break;
    }
    __THREW__ = 0;
    $384 = (invoke_iiii(3267,($381|0),(148196|0),21)|0);
    $385 = __THREW__; __THREW__ = 0;
    $386 = $385&1;
    if ($386) {
     label = 153;
     break;
    }
    $387 = HEAP32[$384>>2]|0;
    $388 = ((($387)) + -12|0);
    $389 = HEAP32[$388>>2]|0;
    $390 = (($384) + ($389)|0);
    __THREW__ = 0;
    invoke_vii(3257,($1|0),($390|0));
    $391 = __THREW__; __THREW__ = 0;
    $392 = $391&1;
    if ($392) {
     label = 153;
     break;
    }
    __THREW__ = 0;
    $393 = (invoke_iii(3255,($1|0),(215188|0))|0);
    $394 = __THREW__; __THREW__ = 0;
    $395 = $394&1;
    if ($395) {
     label = 148;
     break;
    }
    $396 = HEAP32[$393>>2]|0;
    $397 = ((($396)) + 28|0);
    $398 = HEAP32[$397>>2]|0;
    __THREW__ = 0;
    $399 = (invoke_iii($398|0,($393|0),10)|0);
    $400 = __THREW__; __THREW__ = 0;
    $401 = $400&1;
    if ($401) {
     label = 148;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3263,($1|0));
    $402 = __THREW__; __THREW__ = 0;
    $403 = $402&1;
    if ($403) {
     label = 153;
     break;
    }
    __THREW__ = 0;
    (invoke_iii(3268,($384|0),($399|0))|0);
    $410 = __THREW__; __THREW__ = 0;
    $411 = $410&1;
    if ($411) {
     label = 153;
     break;
    }
    __THREW__ = 0;
    (invoke_ii(3269,($384|0))|0);
    $412 = __THREW__; __THREW__ = 0;
    $413 = $412&1;
    if ($413) {
     label = 153;
     break;
    }
   }
  }
  $416 = HEAP8[$25>>0]|0;
  $417 = ($416<<24>>24)<(0);
  if ($417) {
   $418 = HEAP32[$6>>2]|0;
   __ZdlPv($418);
  }
  $$0 = $$0$i167;
 }
 switch (label|0) {
  case 39: {
   $122 = ___cxa_find_matching_catch_2()|0;
   $123 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($4|0));
   $124 = __THREW__; __THREW__ = 0;
   $125 = $124&1;
   if ($125) {
    $126 = ___cxa_find_matching_catch_3(0|0)|0;
    $127 = tempRet0;
    ___clang_call_terminate($126);
    // unreachable;
   } else {
    $eh$lpad$body$index2Z2D = $123;$eh$lpad$body$indexZ2D = $122;
    label = 48;
    break;
   }
   break;
  }
  case 47: {
   $135 = ___cxa_find_matching_catch_2()|0;
   $136 = tempRet0;
   $eh$lpad$body$index2Z2D = $136;$eh$lpad$body$indexZ2D = $135;
   label = 48;
   break;
  }
  case 74: {
   $190 = ___cxa_find_matching_catch_2()|0;
   $191 = tempRet0;
   ___cxa_call_unexpected(($190|0));
   // unreachable;
   break;
  }
  case 78: {
   $195 = ___cxa_find_matching_catch_2()|0;
   $196 = tempRet0;
   $$4 = $195;$$444 = $196;
   break;
  }
  case 79: {
   $197 = ___cxa_find_matching_catch_2()|0;
   $198 = tempRet0;
   $eh$lpad$body137$sink169$index10Z2D = $198;$eh$lpad$body137$sink169$indexZ2D = $197;
   label = 135;
   break;
  }
  case 82: {
   $208 = ___cxa_find_matching_catch_2()|0;
   $209 = tempRet0;
   ___cxa_call_unexpected(($208|0));
   // unreachable;
   break;
  }
  case 98: {
   $261 = ___cxa_find_matching_catch_2()|0;
   $262 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($3|0));
   $263 = __THREW__; __THREW__ = 0;
   $264 = $263&1;
   if ($264) {
    $265 = ___cxa_find_matching_catch_3(0|0)|0;
    $266 = tempRet0;
    ___clang_call_terminate($265);
    // unreachable;
   } else {
    $eh$lpad$body137$sink169$index10Z2D = $262;$eh$lpad$body137$sink169$indexZ2D = $261;
    label = 135;
    break;
   }
   break;
  }
  case 103: {
   $271 = ___cxa_find_matching_catch_2()|0;
   $272 = tempRet0;
   $eh$lpad$body137$sink169$index10Z2D = $272;$eh$lpad$body137$sink169$indexZ2D = $271;
   label = 135;
   break;
  }
  case 123: {
   $334 = ___cxa_find_matching_catch_2()|0;
   $335 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($2|0));
   $336 = __THREW__; __THREW__ = 0;
   $337 = $336&1;
   if ($337) {
    $338 = ___cxa_find_matching_catch_3(0|0)|0;
    $339 = tempRet0;
    ___clang_call_terminate($338);
    // unreachable;
   } else {
    $eh$lpad$body137$sink169$index10Z2D = $335;$eh$lpad$body137$sink169$indexZ2D = $334;
    label = 135;
    break;
   }
   break;
  }
  case 128: {
   $344 = ___cxa_find_matching_catch_2()|0;
   $345 = tempRet0;
   $eh$lpad$body137$sink169$index10Z2D = $345;$eh$lpad$body137$sink169$indexZ2D = $344;
   label = 135;
   break;
  }
  case 148: {
   $404 = ___cxa_find_matching_catch_2()|0;
   $405 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($1|0));
   $406 = __THREW__; __THREW__ = 0;
   $407 = $406&1;
   if ($407) {
    $408 = ___cxa_find_matching_catch_3(0|0)|0;
    $409 = tempRet0;
    ___clang_call_terminate($408);
    // unreachable;
   } else {
    $eh$lpad$body143$index18Z2D = $405;$eh$lpad$body143$indexZ2D = $404;
    label = 154;
    break;
   }
   break;
  }
  case 153: {
   $414 = ___cxa_find_matching_catch_2()|0;
   $415 = tempRet0;
   $eh$lpad$body143$index18Z2D = $415;$eh$lpad$body143$indexZ2D = $414;
   label = 154;
   break;
  }
  case 162: {
   STACKTOP = sp;return;
   break;
  }
 }
 if ((label|0) == 48) {
  $137 = HEAP8[$23>>0]|0;
  $138 = ($137<<24>>24)<(0);
  if ($138) {
   $139 = HEAP32[$5>>2]|0;
   __ZdlPv($139);
  }
  $$5 = $eh$lpad$body$indexZ2D;$$545 = $eh$lpad$body$index2Z2D;
  ___resumeException($$5|0);
  // unreachable;
 }
 else if ((label|0) == 135) {
  $362 = HEAP8[$27>>0]|0;
  $363 = ($362<<24>>24)<(0);
  if ($363) {
   $364 = HEAP32[$7>>2]|0;
   __ZdlPv($364);
  }
  $$4 = $eh$lpad$body137$sink169$indexZ2D;$$444 = $eh$lpad$body137$sink169$index10Z2D;
 }
 else if ((label|0) == 154) {
  $$4 = $eh$lpad$body143$indexZ2D;$$444 = $eh$lpad$body143$index18Z2D;
 }
 $419 = HEAP8[$25>>0]|0;
 $420 = ($419<<24>>24)<(0);
 if ($420) {
  $421 = HEAP32[$6>>2]|0;
  __ZdlPv($421);
 }
 $$5 = $$4;$$545 = $$444;
 ___resumeException($$5|0);
 // unreachable;
}
function __ZN3osg6Shader11dirtyShaderEv($0) {
 $0 = $0|0;
 var $$0$i$i$i = 0, $$011 = 0, $$sink8$i = 0, $$sroa$06$0$be = 0, $$sroa$06$010 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 116|0);
 $2 = ((($0)) + 120|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$1>>2]|0;
 $5 = ($3|0)==($4|0);
 if (!($5)) {
  $$011 = 0;
  while(1) {
   $10 = (__ZN3osg14buffered_valueINS_7ref_ptrINS_6Shader13ShaderObjectsEEEEixEj($1,$$011)|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = ($11|0)==(0|0);
   if (!($12)) {
    $13 = (__ZN3osg14buffered_valueINS_7ref_ptrINS_6Shader13ShaderObjectsEEEEixEj($1,$$011)|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ((($14)) + 20|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = ((($14)) + 24|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = ($16|0)==($18|0);
    if (!($19)) {
     $$sink8$i = $16;
     while(1) {
      $20 = HEAP32[$$sink8$i>>2]|0;
      $21 = ((($20)) + 36|0);
      HEAP8[$21>>0] = 1;
      $22 = ((($20)) + 37|0);
      HEAP8[$22>>0] = 0;
      $23 = ((($$sink8$i)) + 4|0);
      $24 = ($23|0)==($18|0);
      if ($24) {
       break;
      } else {
       $$sink8$i = $23;
      }
     }
    }
   }
   $25 = (($$011) + 1)|0;
   $26 = HEAP32[$2>>2]|0;
   $27 = HEAP32[$1>>2]|0;
   $28 = (($26) - ($27))|0;
   $29 = $28 >> 2;
   $30 = ($25>>>0)<($29>>>0);
   if ($30) {
    $$011 = $25;
   } else {
    break;
   }
  }
 }
 $6 = ((($0)) + 104|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($0)) + 108|0);
 $9 = ($7|0)==($8|0);
 if ($9) {
  return;
 } else {
  $$sroa$06$010 = $7;
 }
 while(1) {
  $31 = ((($$sroa$06$010)) + 16|0);
  $32 = HEAP32[$31>>2]|0;
  __ZN3osg7Program12dirtyProgramEv($32);
  $33 = ((($$sroa$06$010)) + 4|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = ($34|0)==(0|0);
  if ($35) {
   $36 = ((($$sroa$06$010)) + 8|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = HEAP32[$37>>2]|0;
   $39 = ($38|0)==($$sroa$06$010|0);
   if ($39) {
    $$sroa$06$0$be = $37;
   } else {
    $44 = $36;
    while(1) {
     $43 = HEAP32[$44>>2]|0;
     $45 = ((($43)) + 8|0);
     $46 = HEAP32[$45>>2]|0;
     $47 = HEAP32[$46>>2]|0;
     $48 = ($47|0)==($43|0);
     if ($48) {
      $$sroa$06$0$be = $46;
      break;
     } else {
      $44 = $45;
     }
    }
   }
  } else {
   $$0$i$i$i = $34;
   while(1) {
    $41 = HEAP32[$$0$i$i$i>>2]|0;
    $42 = ($41|0)==(0|0);
    if ($42) {
     break;
    } else {
     $$0$i$i$i = $41;
    }
   }
   $$sroa$06$0$be = $$0$i$i$i;
  }
  $40 = ($$sroa$06$0$be|0)==($8|0);
  if ($40) {
   break;
  } else {
   $$sroa$06$010 = $$sroa$06$0$be;
  }
 }
 return;
}
function __ZN3osg6Shader19_parseShaderDefinesERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEERNS1_3setIS7_NS1_4lessIS7_EENS5_IS7_EEEE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$ = 0, $$$i$i = 0, $$$i$i38 = 0, $$0 = 0, $$0$i$i = 0, $$0$i$i37 = 0, $$0$i44$ph = 0, $$01112$i = 0, $$01112$i35 = 0, $$01112$i42116 = 0, $$1 = 0, $$106 = 0, $$phi$trans$insert = 0, $$phi$trans$insert84 = 0, $$pre = 0, $$pre$i$i$i$i = 0, $$pre$phi90Z2D = 0, $$pre$phi92Z2D = 0, $$pre$phi94Z2D = 0, $$pre$phi96Z2D = 0;
 var $$pre82 = 0, $$pre83 = 0, $$pre85 = 0, $$pre86 = 0, $$pre87 = 0, $$pre89 = 0, $$pre91 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index3Z2D = 0, $eh$lpad$body$indexZ2D = 0, $not$$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $3 = sp + 20|0;
 $4 = sp + 16|0;
 $5 = sp + 12|0;
 $6 = sp;
 $7 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
 do {
  if ($7) {
   $8 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
   $9 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($8,148218,28)|0);
   $10 = ((($1)) + 11|0);
   $11 = HEAP8[$10>>0]|0;
   $12 = ($11<<24>>24)<(0);
   $13 = HEAP32[$1>>2]|0;
   $14 = $12 ? $13 : $1;
   $15 = ((($1)) + 4|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = $11&255;
   $18 = $12 ? $16 : $17;
   $19 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($9,$14,$18)|0);
   $20 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($19,174996,1)|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = ((($21)) + -12|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = (($20) + ($23)|0);
   __ZNKSt3__28ios_base6getlocEv($5,$24);
   __THREW__ = 0;
   $25 = (invoke_iii(3255,($5|0),(215188|0))|0);
   $26 = __THREW__; __THREW__ = 0;
   $27 = $26&1;
   if (!($27)) {
    $28 = HEAP32[$25>>2]|0;
    $29 = ((($28)) + 28|0);
    $30 = HEAP32[$29>>2]|0;
    __THREW__ = 0;
    $31 = (invoke_iii($30|0,($25|0),10)|0);
    $32 = __THREW__; __THREW__ = 0;
    $33 = $32&1;
    if (!($33)) {
     __ZNSt3__26localeD2Ev($5);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($20,$31)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($20)|0);
     $$pre$phi90Z2D = $10;$$pre$phi92Z2D = $15;$$pre$phi94Z2D = $1;$$pre$phi96Z2D = $1;
     break;
    }
   }
   $34 = ___cxa_find_matching_catch_2()|0;
   $35 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($5|0));
   $36 = __THREW__; __THREW__ = 0;
   $37 = $36&1;
   if ($37) {
    $38 = ___cxa_find_matching_catch_3(0|0)|0;
    $39 = tempRet0;
    ___clang_call_terminate($38);
    // unreachable;
   } else {
    ___resumeException($34|0);
    // unreachable;
   }
  } else {
   $$pre89 = ((($1)) + 11|0);
   $$pre91 = ((($1)) + 4|0);
   $$pre$phi90Z2D = $$pre89;$$pre$phi92Z2D = $$pre91;$$pre$phi94Z2D = $1;$$pre$phi96Z2D = $1;
  }
 } while(0);
 $40 = ((($2)) + 4|0);
 $41 = ((($2)) + 8|0);
 $42 = ((($6)) + 11|0);
 $43 = ((($6)) + 4|0);
 $$pre = HEAP8[$$pre$phi90Z2D>>0]|0;
 $$pre82 = HEAP32[$$pre$phi92Z2D>>2]|0;
 $$0 = 0;$44 = $$pre;$47 = $$pre82;
 L12: while(1) {
  $45 = ($44<<24>>24)<(0);
  $46 = $44&255;
  $48 = $45 ? $47 : $46;
  $49 = ($48>>>0)>($$0>>>0);
  if (!($49)) {
   label = 61;
   break;
  }
  $50 = HEAP32[$$pre$phi94Z2D>>2]|0;
  $51 = $45 ? $50 : $$pre$phi96Z2D;
  $$01112$i = $$0;
  while(1) {
   $52 = (($51) + ($$01112$i)|0);
   $53 = HEAP8[$52>>0]|0;
   $$0$i$i = 148247;
   while(1) {
    $54 = HEAP8[$$0$i$i>>0]|0;
    $55 = ($54<<24>>24)==(0);
    $56 = ($54<<24>>24)!=($53<<24>>24);
    $not$$i$i = $55 ^ 1;
    $$$i$i = $56 & $not$$i$i;
    $57 = ((($$0$i$i)) + 1|0);
    if ($$$i$i) {
     $$0$i$i = $57;
    } else {
     break;
    }
   }
   if ($55) {
    break;
   }
   $58 = (($$01112$i) + 1)|0;
   $59 = ($58>>>0)<($48>>>0);
   if ($59) {
    $$01112$i = $58;
   } else {
    label = 61;
    break L12;
   }
  }
  $60 = ($$01112$i|0)==(-1);
  if ($60) {
   label = 61;
   break;
  }
  $61 = ($48>>>0)>($$01112$i>>>0);
  L23: do {
   if ($61) {
    $$01112$i35 = $$01112$i;$65 = $53;
    while(1) {
     $$0$i$i37 = 148251;
     while(1) {
      $62 = HEAP8[$$0$i$i37>>0]|0;
      $63 = ($62<<24>>24)!=(0);
      $64 = ($62<<24>>24)!=($65<<24>>24);
      $$$i$i38 = $63 & $64;
      $66 = ((($$0$i$i37)) + 1|0);
      if ($$$i$i38) {
       $$0$i$i37 = $66;
      } else {
       break;
      }
     }
     if ($63) {
      break;
     }
     $67 = (($$01112$i35) + 1)|0;
     $68 = ($67>>>0)<($48>>>0);
     if (!($68)) {
      label = 28;
      break L23;
     }
     $$phi$trans$insert = (($51) + ($67)|0);
     $$pre83 = HEAP8[$$phi$trans$insert>>0]|0;
     $$01112$i35 = $67;$65 = $$pre83;
    }
    $69 = ($$01112$i35|0)==(-1);
    if ($69) {
     label = 28;
    } else {
     $70 = ($53<<24>>24)==(40);
     L33: do {
      if ($70) {
       $$0$i44$ph = $$01112$i;
      } else {
       $$01112$i42116 = $$01112$i;
       while(1) {
        $71 = (($$01112$i42116) + 1)|0;
        $72 = ($71>>>0)<($48>>>0);
        if (!($72)) {
         $$0$i44$ph = -1;
         break L33;
        }
        $$phi$trans$insert84 = (($51) + ($71)|0);
        $$pre85 = HEAP8[$$phi$trans$insert84>>0]|0;
        $73 = ($$pre85<<24>>24)==(40);
        if ($73) {
         $$0$i44$ph = $71;
         break;
        } else {
         $$01112$i42116 = $71;
        }
       }
      }
     } while(0);
     $74 = ($$0$i44$ph>>>0)<($$01112$i35>>>0);
     $75 = $74&1;
     $$ = (($75) + ($$01112$i35))|0;
     $$1 = $$;
    }
   } else {
    label = 28;
   }
  } while(0);
  if ((label|0) == 28) {
   label = 0;
   $$106 = $45 ? $47 : $46;
   $$1 = $$106;
  }
  $76 = ($$1>>>0)>($$01112$i>>>0);
  if ($76) {
   $77 = (($$1) - ($$01112$i))|0;
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_jjRKS4_($6,$1,$$01112$i,$77,$1);
   __THREW__ = 0;
   $78 = (invoke_iiii(3784,($2|0),($4|0),($6|0))|0);
   $79 = __THREW__; __THREW__ = 0;
   $80 = $79&1;
   if ($80) {
    label = 53;
    break;
   }
   $81 = HEAP32[$78>>2]|0;
   $82 = ($81|0)==(0|0);
   if ($82) {
    __THREW__ = 0;
    $83 = (invoke_ii(3276,28)|0);
    $84 = __THREW__; __THREW__ = 0;
    $85 = $84&1;
    if ($85) {
     label = 53;
     break;
    }
    $86 = ((($83)) + 16|0);
    __THREW__ = 0;
    invoke_vii(3457,($86|0),($6|0));
    $87 = __THREW__; __THREW__ = 0;
    $88 = $87&1;
    if ($88) {
     label = 34;
     break;
    }
    $91 = HEAP32[$4>>2]|0;
    HEAP32[$83>>2] = 0;
    $92 = ((($83)) + 4|0);
    HEAP32[$92>>2] = 0;
    $93 = ((($83)) + 8|0);
    HEAP32[$93>>2] = $91;
    HEAP32[$78>>2] = $83;
    $94 = HEAP32[$2>>2]|0;
    $95 = HEAP32[$94>>2]|0;
    $96 = ($95|0)==(0|0);
    if ($96) {
     $99 = $83;
    } else {
     $97 = $95;
     HEAP32[$2>>2] = $97;
     $$pre$i$i$i$i = HEAP32[$78>>2]|0;
     $99 = $$pre$i$i$i$i;
    }
    $98 = HEAP32[$40>>2]|0;
    __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($98,$99);
    $100 = HEAP32[$41>>2]|0;
    $101 = (($100) + 1)|0;
    HEAP32[$41>>2] = $101;
   }
   __THREW__ = 0;
   $102 = (invoke_ii(3265,4)|0);
   $103 = __THREW__; __THREW__ = 0;
   $104 = $103&1;
   if ($104) {
    label = 53;
    break;
   }
   if ($102) {
    __THREW__ = 0;
    $105 = (invoke_ii(3266,4)|0);
    $106 = __THREW__; __THREW__ = 0;
    $107 = $106&1;
    if ($107) {
     label = 53;
     break;
    }
    __THREW__ = 0;
    $108 = (invoke_iiii(3267,($105|0),(148256|0),18)|0);
    $109 = __THREW__; __THREW__ = 0;
    $110 = $109&1;
    if ($110) {
     label = 53;
     break;
    }
    $111 = HEAP8[$42>>0]|0;
    $112 = ($111<<24>>24)<(0);
    $113 = HEAP32[$6>>2]|0;
    $114 = $112 ? $113 : $6;
    $115 = HEAP32[$43>>2]|0;
    $116 = $111&255;
    $117 = $112 ? $115 : $116;
    __THREW__ = 0;
    $118 = (invoke_iiii(3267,($108|0),($114|0),($117|0))|0);
    $119 = __THREW__; __THREW__ = 0;
    $120 = $119&1;
    if ($120) {
     label = 53;
     break;
    }
    __THREW__ = 0;
    $121 = (invoke_iiii(3267,($118|0),(174996|0),1)|0);
    $122 = __THREW__; __THREW__ = 0;
    $123 = $122&1;
    if ($123) {
     label = 53;
     break;
    }
    $124 = HEAP32[$121>>2]|0;
    $125 = ((($124)) + -12|0);
    $126 = HEAP32[$125>>2]|0;
    $127 = (($121) + ($126)|0);
    __THREW__ = 0;
    invoke_vii(3257,($3|0),($127|0));
    $128 = __THREW__; __THREW__ = 0;
    $129 = $128&1;
    if ($129) {
     label = 53;
     break;
    }
    __THREW__ = 0;
    $130 = (invoke_iii(3255,($3|0),(215188|0))|0);
    $131 = __THREW__; __THREW__ = 0;
    $132 = $131&1;
    if ($132) {
     label = 48;
     break;
    }
    $133 = HEAP32[$130>>2]|0;
    $134 = ((($133)) + 28|0);
    $135 = HEAP32[$134>>2]|0;
    __THREW__ = 0;
    $136 = (invoke_iii($135|0,($130|0),10)|0);
    $137 = __THREW__; __THREW__ = 0;
    $138 = $137&1;
    if ($138) {
     label = 48;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3263,($3|0));
    $139 = __THREW__; __THREW__ = 0;
    $140 = $139&1;
    if ($140) {
     label = 53;
     break;
    }
    __THREW__ = 0;
    (invoke_iii(3268,($121|0),($136|0))|0);
    $147 = __THREW__; __THREW__ = 0;
    $148 = $147&1;
    if ($148) {
     label = 53;
     break;
    }
    __THREW__ = 0;
    (invoke_ii(3269,($121|0))|0);
    $149 = __THREW__; __THREW__ = 0;
    $150 = $149&1;
    if ($150) {
     label = 53;
     break;
    }
   }
   $156 = HEAP8[$42>>0]|0;
   $157 = ($156<<24>>24)<(0);
   if ($157) {
    $158 = HEAP32[$6>>2]|0;
    __ZdlPv($158);
   }
   $$pre86 = HEAP8[$$pre$phi90Z2D>>0]|0;
   $$pre87 = HEAP32[$$pre$phi92Z2D>>2]|0;
   $160 = $$pre86;$163 = $$pre87;
  } else {
   $160 = $44;$163 = $47;
  }
  $159 = (($$1) + 1)|0;
  $161 = ($160<<24>>24)<(0);
  $162 = $160&255;
  $164 = $161 ? $163 : $162;
  $165 = ($159>>>0)<($164>>>0);
  if ($165) {
   $$0 = $159;$44 = $160;$47 = $163;
  } else {
   label = 61;
   break;
  }
 }
 do {
  if ((label|0) == 34) {
   $89 = ___cxa_find_matching_catch_2()|0;
   $90 = tempRet0;
   __ZdlPv($83);
   $eh$lpad$body$index3Z2D = $90;$eh$lpad$body$indexZ2D = $89;
  }
  else if ((label|0) == 48) {
   $141 = ___cxa_find_matching_catch_2()|0;
   $142 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($3|0));
   $143 = __THREW__; __THREW__ = 0;
   $144 = $143&1;
   if ($144) {
    $145 = ___cxa_find_matching_catch_3(0|0)|0;
    $146 = tempRet0;
    ___clang_call_terminate($145);
    // unreachable;
   } else {
    $eh$lpad$body$index3Z2D = $142;$eh$lpad$body$indexZ2D = $141;
    break;
   }
  }
  else if ((label|0) == 53) {
   $151 = ___cxa_find_matching_catch_2()|0;
   $152 = tempRet0;
   $eh$lpad$body$index3Z2D = $152;$eh$lpad$body$indexZ2D = $151;
  }
  else if ((label|0) == 61) {
   STACKTOP = sp;return;
  }
 } while(0);
 $153 = HEAP8[$42>>0]|0;
 $154 = ($153<<24>>24)<(0);
 if (!($154)) {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 $155 = HEAP32[$6>>2]|0;
 __ZdlPv($155);
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
}
function __ZNK3osg6Shader7compareERKS0_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$$$i$i$i = 0, $$$i$i$i = 0, $$0 = 0, $$lobit = 0, $$sroa$speculated$i$i$i = 0, $$sroa$speculated$i$i$i12 = 0, $$sroa$speculated$i$i$i18 = 0, $$sroa$speculated$i$i$i24 = 0, $$sroa$speculated$i$i$i30 = 0, $$sroa$speculated$i$i$i36 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($0|0)==($1|0);
 if ($2) {
  $$0 = 0;
  return ($$0|0);
 }
 $3 = ((($0)) + 32|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($1)) + 32|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4|0)<($6|0);
 if ($7) {
  $$0 = -1;
  return ($$0|0);
 }
 $8 = ($6|0)<($4|0);
 if ($8) {
  $$0 = 1;
  return ($$0|0);
 }
 $9 = ((($0)) + 12|0);
 $10 = ((($1)) + 12|0);
 $11 = ((($10)) + 11|0);
 $12 = HEAP8[$11>>0]|0;
 $13 = ($12<<24>>24)<(0);
 $14 = ((($1)) + 16|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = $12&255;
 $17 = $13 ? $15 : $16;
 $18 = ((($9)) + 11|0);
 $19 = HEAP8[$18>>0]|0;
 $20 = ($19<<24>>24)<(0);
 $21 = ((($0)) + 16|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = $19&255;
 $24 = $20 ? $22 : $23;
 $25 = ($17>>>0)<($24>>>0);
 $$sroa$speculated$i$i$i36 = $25 ? $17 : $24;
 $26 = ($$sroa$speculated$i$i$i36|0)==(0);
 if ($26) {
  label = 6;
 } else {
  $27 = HEAP32[$9>>2]|0;
  $28 = $20 ? $27 : $9;
  $29 = HEAP32[$10>>2]|0;
  $30 = $13 ? $29 : $10;
  $31 = (_memcmp($28,$30,$$sroa$speculated$i$i$i36)|0);
  $32 = ($31|0)==(0);
  if ($32) {
   label = 6;
  } else {
   $34 = ($31|0)<(0);
   if ($34) {
    $$0 = -1;
    return ($$0|0);
   }
  }
 }
 if ((label|0) == 6) {
  $33 = ($24>>>0)<($17>>>0);
  if ($33) {
   $$0 = -1;
   return ($$0|0);
  }
 }
 $35 = ($24>>>0)<($17>>>0);
 $$sroa$speculated$i$i$i30 = $35 ? $24 : $17;
 $36 = ($$sroa$speculated$i$i$i30|0)==(0);
 if ($36) {
  label = 10;
 } else {
  $37 = HEAP32[$10>>2]|0;
  $38 = $13 ? $37 : $10;
  $39 = HEAP32[$9>>2]|0;
  $40 = $20 ? $39 : $9;
  $41 = (_memcmp($38,$40,$$sroa$speculated$i$i$i30)|0);
  $42 = ($41|0)==(0);
  if ($42) {
   label = 10;
  } else {
   $43 = ($41|0)<(0);
   if ($43) {
    $$0 = 1;
    return ($$0|0);
   }
  }
 }
 if ((label|0) == 10) {
  if ($25) {
   $$0 = 1;
   return ($$0|0);
  }
 }
 $44 = ((($0)) + 48|0);
 $45 = ((($1)) + 48|0);
 $46 = ((($45)) + 11|0);
 $47 = HEAP8[$46>>0]|0;
 $48 = ($47<<24>>24)<(0);
 $49 = ((($1)) + 52|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = $47&255;
 $52 = $48 ? $50 : $51;
 $53 = ((($44)) + 11|0);
 $54 = HEAP8[$53>>0]|0;
 $55 = ($54<<24>>24)<(0);
 $56 = ((($0)) + 52|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = $54&255;
 $59 = $55 ? $57 : $58;
 $60 = ($52>>>0)<($59>>>0);
 $$sroa$speculated$i$i$i24 = $60 ? $52 : $59;
 $61 = ($$sroa$speculated$i$i$i24|0)==(0);
 if ($61) {
  label = 14;
 } else {
  $62 = HEAP32[$44>>2]|0;
  $63 = $55 ? $62 : $44;
  $64 = HEAP32[$45>>2]|0;
  $65 = $48 ? $64 : $45;
  $66 = (_memcmp($63,$65,$$sroa$speculated$i$i$i24)|0);
  $67 = ($66|0)==(0);
  if ($67) {
   label = 14;
  } else {
   $69 = ($66|0)<(0);
   if ($69) {
    $$0 = -1;
    return ($$0|0);
   }
  }
 }
 if ((label|0) == 14) {
  $68 = ($59>>>0)<($52>>>0);
  if ($68) {
   $$0 = -1;
   return ($$0|0);
  }
 }
 $70 = ($59>>>0)<($52>>>0);
 $$sroa$speculated$i$i$i18 = $70 ? $59 : $52;
 $71 = ($$sroa$speculated$i$i$i18|0)==(0);
 if ($71) {
  label = 18;
 } else {
  $72 = HEAP32[$45>>2]|0;
  $73 = $48 ? $72 : $45;
  $74 = HEAP32[$44>>2]|0;
  $75 = $55 ? $74 : $44;
  $76 = (_memcmp($73,$75,$$sroa$speculated$i$i$i18)|0);
  $77 = ($76|0)==(0);
  if ($77) {
   label = 18;
  } else {
   $78 = ($76|0)<(0);
   if ($78) {
    $$0 = 1;
    return ($$0|0);
   }
  }
 }
 if ((label|0) == 18) {
  if ($60) {
   $$0 = 1;
   return ($$0|0);
  }
 }
 $79 = ((($0)) + 60|0);
 $80 = HEAP32[$79>>2]|0;
 $81 = ((($1)) + 60|0);
 $82 = HEAP32[$81>>2]|0;
 $83 = ($80>>>0)<($82>>>0);
 if ($83) {
  $$0 = -1;
  return ($$0|0);
 }
 $84 = ($82>>>0)<($80>>>0);
 if ($84) {
  $$0 = 1;
  return ($$0|0);
 }
 $85 = ((($0)) + 36|0);
 $86 = ((($1)) + 36|0);
 $87 = ((($86)) + 11|0);
 $88 = HEAP8[$87>>0]|0;
 $89 = ($88<<24>>24)<(0);
 $90 = ((($1)) + 40|0);
 $91 = HEAP32[$90>>2]|0;
 $92 = $88&255;
 $93 = $89 ? $91 : $92;
 $94 = ((($85)) + 11|0);
 $95 = HEAP8[$94>>0]|0;
 $96 = ($95<<24>>24)<(0);
 $97 = ((($0)) + 40|0);
 $98 = HEAP32[$97>>2]|0;
 $99 = $95&255;
 $100 = $96 ? $98 : $99;
 $101 = ($93>>>0)<($100>>>0);
 $$sroa$speculated$i$i$i12 = $101 ? $93 : $100;
 $102 = ($$sroa$speculated$i$i$i12|0)==(0);
 if ($102) {
  label = 24;
 } else {
  $103 = HEAP32[$85>>2]|0;
  $104 = $96 ? $103 : $85;
  $105 = HEAP32[$86>>2]|0;
  $106 = $89 ? $105 : $86;
  $107 = (_memcmp($104,$106,$$sroa$speculated$i$i$i12)|0);
  $108 = ($107|0)==(0);
  if ($108) {
   label = 24;
  } else {
   $110 = ($107|0)<(0);
   if ($110) {
    $$0 = -1;
    return ($$0|0);
   }
  }
 }
 if ((label|0) == 24) {
  $109 = ($100>>>0)<($93>>>0);
  if ($109) {
   $$0 = -1;
   return ($$0|0);
  }
 }
 $111 = ($100>>>0)<($93>>>0);
 $$sroa$speculated$i$i$i = $111 ? $100 : $93;
 $112 = ($$sroa$speculated$i$i$i|0)==(0);
 if ($112) {
  label = 28;
 } else {
  $113 = HEAP32[$86>>2]|0;
  $114 = $89 ? $113 : $86;
  $115 = HEAP32[$85>>2]|0;
  $116 = $96 ? $115 : $85;
  $117 = (_memcmp($114,$116,$$sroa$speculated$i$i$i)|0);
  $118 = ($117|0)==(0);
  if ($118) {
   label = 28;
  } else {
   $119 = $117;
  }
 }
 if ((label|0) == 28) {
  $$$i$i$i = $111&1;
  $$$$i$i$i = $101 ? -1 : $$$i$i$i;
  $119 = $$$$i$i$i;
 }
 $$lobit = $119 >>> 31;
 $$0 = $$lobit;
 return ($$0|0);
}
function __ZN3osg6Shader13addProgramRefEPNS_7ProgramE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$0$i$i$i$i = 0, $$0$ph$i$i$i$i = 0, $$0$ph$lcssa$i$i$i = 0, $$0$ph13$i$i$i = 0, $$024$i$i$i$i = 0, $$025$i$i$i$i = 0, $$036$i$i$i = 0, $$07$ph12$i$i$i = 0, $$0710$i$i$i = 0, $$in$i$i$i$i = 0, $$pre$i$i$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = $1;
 $3 = ((($0)) + 104|0);
 $4 = ((($0)) + 108|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 do {
  if ($6) {
   $$025$i$i$i$i = $4;$$036$i$i$i = $4;
  } else {
   $$0$ph13$i$i$i = $4;$$07$ph12$i$i$i = $5;
   L3: while(1) {
    $$0710$i$i$i = $$07$ph12$i$i$i;
    while(1) {
     $7 = ((($$0710$i$i$i)) + 16|0);
     $8 = HEAP32[$7>>2]|0;
     $9 = ($8>>>0)<($1>>>0);
     if (!($9)) {
      break;
     }
     $12 = ((($$0710$i$i$i)) + 4|0);
     $13 = HEAP32[$12>>2]|0;
     $14 = ($13|0)==(0|0);
     if ($14) {
      $$0$ph$lcssa$i$i$i = $$0$ph13$i$i$i;
      break L3;
     } else {
      $$0710$i$i$i = $13;
     }
    }
    $10 = HEAP32[$$0710$i$i$i>>2]|0;
    $11 = ($10|0)==(0|0);
    if ($11) {
     $$0$ph$lcssa$i$i$i = $$0710$i$i$i;
     break;
    } else {
     $$0$ph13$i$i$i = $$0710$i$i$i;$$07$ph12$i$i$i = $10;
    }
   }
   $15 = ($$0$ph$lcssa$i$i$i|0)==($4|0);
   if (!($15)) {
    $16 = ((($$0$ph$lcssa$i$i$i)) + 16|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = ($17>>>0)>($1>>>0);
    if (!($18)) {
     $$0 = 0;
     return ($$0|0);
    }
   }
   $19 = ((($0)) + 108|0);
   $$0$i$i$i$i = $19;$$024$i$i$i$i = $5;
   while(1) {
    $20 = ((($$024$i$i$i$i)) + 16|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = ($21>>>0)>($1>>>0);
    if ($22) {
     $23 = HEAP32[$$024$i$i$i$i>>2]|0;
     $24 = ($23|0)==(0|0);
     if ($24) {
      label = 12;
      break;
     } else {
      $$0$ph$i$i$i$i = $$024$i$i$i$i;$$in$i$i$i$i = $23;
     }
    } else {
     $25 = ($21>>>0)<($1>>>0);
     if (!($25)) {
      label = 16;
      break;
     }
     $26 = ((($$024$i$i$i$i)) + 4|0);
     $27 = HEAP32[$26>>2]|0;
     $28 = ($27|0)==(0|0);
     if ($28) {
      label = 15;
      break;
     } else {
      $$0$ph$i$i$i$i = $26;$$in$i$i$i$i = $27;
     }
    }
    $$0$i$i$i$i = $$0$ph$i$i$i$i;$$024$i$i$i$i = $$in$i$i$i$i;
   }
   if ((label|0) == 12) {
    $$025$i$i$i$i = $$024$i$i$i$i;$$036$i$i$i = $$024$i$i$i$i;
    break;
   }
   else if ((label|0) == 15) {
    $$025$i$i$i$i = $26;$$036$i$i$i = $$024$i$i$i$i;
    break;
   }
   else if ((label|0) == 16) {
    $$025$i$i$i$i = $$0$i$i$i$i;$$036$i$i$i = $$024$i$i$i$i;
    break;
   }
  }
 } while(0);
 $29 = HEAP32[$$025$i$i$i$i>>2]|0;
 $30 = ($29|0)==(0|0);
 if (!($30)) {
  $$0 = 1;
  return ($$0|0);
 }
 $31 = (__Znwj(20)|0);
 $32 = ((($31)) + 16|0);
 HEAP32[$32>>2] = $2;
 HEAP32[$31>>2] = 0;
 $33 = ((($31)) + 4|0);
 HEAP32[$33>>2] = 0;
 $34 = ((($31)) + 8|0);
 HEAP32[$34>>2] = $$036$i$i$i;
 HEAP32[$$025$i$i$i$i>>2] = $31;
 $35 = HEAP32[$3>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 $37 = ($36|0)==(0|0);
 if ($37) {
  $41 = $31;
 } else {
  $38 = $36;
  HEAP32[$3>>2] = $38;
  $$pre$i$i$i$i = HEAP32[$$025$i$i$i$i>>2]|0;
  $41 = $$pre$i$i$i$i;
 }
 $39 = ((($0)) + 108|0);
 $40 = HEAP32[$39>>2]|0;
 __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($40,$41);
 $42 = ((($0)) + 112|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = (($43) + 1)|0;
 HEAP32[$42>>2] = $44;
 $$0 = 1;
 return ($$0|0);
}
function __ZN3osg6Shader16removeProgramRefEPNS_7ProgramE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$ph$lcssa$i$i$i = 0, $$0$ph13$i$i$i = 0, $$07$ph12$i$i$i = 0, $$0710$i$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 104|0);
 $3 = ((($0)) + 108|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  $$0 = 0;
  return ($$0|0);
 } else {
  $$0$ph13$i$i$i = $3;$$07$ph12$i$i$i = $4;
 }
 L3: while(1) {
  $$0710$i$i$i = $$07$ph12$i$i$i;
  while(1) {
   $6 = ((($$0710$i$i$i)) + 16|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($7>>>0)<($1>>>0);
   if (!($8)) {
    break;
   }
   $11 = ((($$0710$i$i$i)) + 4|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = ($12|0)==(0|0);
   if ($13) {
    $$0$ph$lcssa$i$i$i = $$0$ph13$i$i$i;
    break L3;
   } else {
    $$0710$i$i$i = $12;
   }
  }
  $9 = HEAP32[$$0710$i$i$i>>2]|0;
  $10 = ($9|0)==(0|0);
  if ($10) {
   $$0$ph$lcssa$i$i$i = $$0710$i$i$i;
   break;
  } else {
   $$0$ph13$i$i$i = $$0710$i$i$i;$$07$ph12$i$i$i = $9;
  }
 }
 $14 = ($$0$ph$lcssa$i$i$i|0)==($3|0);
 if ($14) {
  $$0 = 0;
  return ($$0|0);
 }
 $15 = ((($$0$ph$lcssa$i$i$i)) + 16|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16>>>0)>($1>>>0);
 if ($17) {
  $$0 = 0;
  return ($$0|0);
 }
 $18 = ((($$0$ph$lcssa$i$i$i)) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)==(0|0);
 if ($20) {
  $21 = ((($$0$ph$lcssa$i$i$i)) + 8|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = HEAP32[$22>>2]|0;
  $24 = ($23|0)==($$0$ph$lcssa$i$i$i|0);
  if ($24) {
   $$0$i$i$i$i = $22;
  } else {
   $28 = $21;
   while(1) {
    $27 = HEAP32[$28>>2]|0;
    $29 = ((($27)) + 8|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = HEAP32[$30>>2]|0;
    $32 = ($31|0)==($27|0);
    if ($32) {
     $$0$i$i$i$i = $30;
     break;
    } else {
     $28 = $29;
    }
   }
  }
 } else {
  $$0$i$i$i$i$i = $19;
  while(1) {
   $25 = HEAP32[$$0$i$i$i$i$i>>2]|0;
   $26 = ($25|0)==(0|0);
   if ($26) {
    break;
   } else {
    $$0$i$i$i$i$i = $25;
   }
  }
  $$0$i$i$i$i = $$0$i$i$i$i$i;
 }
 $33 = HEAP32[$2>>2]|0;
 $34 = ($33|0)==($$0$ph$lcssa$i$i$i|0);
 if ($34) {
  $35 = $$0$i$i$i$i;
  HEAP32[$2>>2] = $35;
 }
 $36 = ((($0)) + 112|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (($37) + -1)|0;
 HEAP32[$36>>2] = $38;
 __ZNSt3__213__tree_removeIPNS_16__tree_node_baseIPvEEEEvT_S5_($4,$$0$ph$lcssa$i$i$i);
 __ZdlPv($$0$ph$lcssa$i$i$i);
 $$0 = 1;
 return ($$0|0);
}
function __ZNSt3__26vectorINS_4pairIjN3osg5Vec3fEEENS_9allocatorIS4_EEE7reserveEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 4;
 $7 = ($6>>>0)<($1>>>0);
 if (!($7)) {
  return;
 }
 $8 = ((($0)) + 4|0);
 $9 = ($1>>>0)>(268435455);
 if ($9) {
  $10 = (___cxa_allocate_exception(8)|0);
  __THREW__ = 0;
  invoke_vii(3366,($10|0),(204840|0));
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if ($12) {
   $13 = ___cxa_find_matching_catch_2()|0;
   $14 = tempRet0;
   ___cxa_free_exception(($10|0));
   ___resumeException($13|0);
   // unreachable;
  } else {
   HEAP32[$10>>2] = (99824);
   ___cxa_throw(($10|0),(34608|0),(3230|0));
   // unreachable;
  }
 }
 $15 = HEAP32[$8>>2]|0;
 $16 = (($15) - ($4))|0;
 $17 = $16 >> 4;
 $18 = $1 << 4;
 $19 = (__Znwj($18)|0);
 $20 = (($19) + ($17<<4)|0);
 $21 = $20;
 $22 = (($19) + ($1<<4)|0);
 $23 = $22;
 $24 = (0 - ($17))|0;
 $25 = (($20) + ($24<<4)|0);
 $26 = $25;
 $27 = ($16|0)>(0);
 if ($27) {
  $28 = $4;
  _memcpy(($25|0),($28|0),($16|0))|0;
 }
 HEAP32[$0>>2] = $26;
 HEAP32[$8>>2] = $21;
 HEAP32[$2>>2] = $23;
 $29 = ($4|0)==(0);
 if ($29) {
  return;
 }
 $30 = $4;
 __ZdlPv($30);
 return;
}
function __ZNSt3__26vectorINS_4pairIjN3osg5Vec3fEEENS_9allocatorIS4_EEE21__push_back_slow_pathIKS4_EEvRT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 4;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(268435455);
 if ($8) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $9 = ((($0)) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) - ($4))|0;
 $12 = $11 >> 4;
 $13 = ($12>>>0)<(134217727);
 $14 = $11 >> 3;
 $15 = ($14>>>0)<($7>>>0);
 $$sroa$speculated$i = $15 ? $7 : $14;
 $$sroa$speculated$$i = $13 ? $$sroa$speculated$i : 268435455;
 $16 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($16) {
   $26 = 0;
  } else {
   $17 = ($$sroa$speculated$$i>>>0)>(268435455);
   if (!($17)) {
    $23 = $$sroa$speculated$$i << 4;
    $24 = (__Znwj($23)|0);
    $26 = $24;
    break;
   }
   $18 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($18|0),(204840|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if ($20) {
    $21 = ___cxa_find_matching_catch_2()|0;
    $22 = tempRet0;
    ___cxa_free_exception(($18|0));
    ___resumeException($21|0);
    // unreachable;
   } else {
    HEAP32[$18>>2] = (99824);
    ___cxa_throw(($18|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $25 = (($26) + ($6<<4)|0);
 $27 = (($26) + ($$sroa$speculated$$i<<4)|0);
 $28 = $27;
 ;HEAP32[$25>>2]=HEAP32[$1>>2]|0;HEAP32[$25+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$25+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$25+12>>2]=HEAP32[$1+12>>2]|0;
 $29 = ((($25)) + 16|0);
 $30 = $29;
 $31 = (0 - ($6))|0;
 $32 = (($25) + ($31<<4)|0);
 $33 = $32;
 $34 = ($5|0)>(0);
 if ($34) {
  $35 = $4;
  _memcpy(($32|0),($35|0),($5|0))|0;
 }
 HEAP32[$0>>2] = $33;
 HEAP32[$2>>2] = $30;
 HEAP32[$9>>2] = $28;
 $36 = ($4|0)==(0);
 if ($36) {
  return;
 }
 $37 = $4;
 __ZdlPv($37);
 return;
}
function __Z4clipRKN3osg5PlaneERKNSt3__26vectorINS3_4pairIjNS_5Vec3fEEENS3_9allocatorIS7_EEEERSA_j($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$063132 = 0, $$3 = 0, $$362 = 0, $$in = 0, $$in143 = 0, $$pre = 0, $$pre135 = 0, $$pre136 = 0, $$pre137 = 0, $$pre139 = 0, $$sroa$0108$0$$sroa_idx = 0, $$sroa$0125$0133 = 0, $$sroa$084$0$$sroa_idx = 0, $$sroa$5111$0$$sroa_idx114 = 0, $$sroa$587$0$$sroa_idx90 = 0, $$sroa$6$0$$sroa_idx93 = 0, $$sroa$6115$0$$sroa_idx118 = 0, $10 = 0, $100 = 0, $101 = 0;
 var $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0.0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0.0, $117 = 0.0, $118 = 0.0, $119 = 0, $12 = 0;
 var $120 = 0.0, $121 = 0.0, $122 = 0, $123 = 0.0, $124 = 0.0, $125 = 0, $126 = 0.0, $127 = 0.0, $128 = 0.0, $129 = 0, $13 = 0, $130 = 0.0, $131 = 0.0, $132 = 0, $133 = 0.0, $134 = 0.0, $135 = 0, $136 = 0.0, $137 = 0.0, $138 = 0.0;
 var $139 = 0.0, $14 = 0, $140 = 0.0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0.0, $154 = 0, $155 = 0, $156 = 0;
 var $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0.0, $167 = 0.0, $168 = 0, $169 = 0.0, $17 = 0, $170 = 0.0, $171 = 0, $172 = 0.0, $173 = 0.0, $174 = 0;
 var $175 = 0.0, $176 = 0.0, $177 = 0.0, $178 = 0, $179 = 0.0, $18 = 0, $180 = 0.0, $181 = 0, $182 = 0.0, $183 = 0.0, $184 = 0, $185 = 0.0, $186 = 0.0, $187 = 0.0, $188 = 0.0, $189 = 0.0, $19 = 0, $190 = 0, $191 = 0, $192 = 0;
 var $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0;
 var $211 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0.0, $44 = 0, $45 = 0.0, $46 = 0.0, $47 = 0.0, $48 = 0.0, $49 = 0, $5 = 0, $50 = 0.0, $51 = 0.0, $52 = 0.0, $53 = 0.0, $54 = 0.0, $55 = 0, $56 = 0.0, $57 = 0.0, $58 = 0.0;
 var $59 = 0.0, $6 = 0, $60 = 0.0, $61 = 0.0, $62 = 0.0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0.0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i68 = 0, $scevgep$i$i$i71 = 0, $scevgep5$i$i$i = 0, $scevgep5$i$i$i69 = 0, $scevgep5$i$i$i72 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $4 = sp + 36|0;
 $5 = sp + 32|0;
 $6 = sp + 16|0;
 $7 = sp;
 HEAP32[$4>>2] = 0;
 $8 = ((($4)) + 4|0);
 HEAP32[$8>>2] = 0;
 $9 = ((($4)) + 8|0);
 HEAP32[$9>>2] = 0;
 $10 = ((($1)) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = HEAP32[$1>>2]|0;
 $13 = (($11) - ($12))|0;
 $14 = $13 >> 4;
 __THREW__ = 0;
 invoke_vii(3895,($4|0),($14|0));
 $15 = __THREW__; __THREW__ = 0;
 $16 = $15&1;
 L1: do {
  if ($16) {
   $41 = ___cxa_find_matching_catch_2()|0;
   $42 = tempRet0;
   $$3 = $41;$$362 = $42;
  } else {
   $17 = HEAP32[$1>>2]|0;
   $18 = HEAP32[$10>>2]|0;
   $19 = ($17|0)==($18|0);
   $20 = $18;
   L4: do {
    if ($19) {
     $208 = $20;
    } else {
     $21 = ((($0)) + 8|0);
     $22 = ((($0)) + 16|0);
     $23 = ((($0)) + 24|0);
     $24 = ((($4)) + 8|0);
     $$sroa$0125$0133 = $17;$209 = $20;$210 = $18;
     while(1) {
      $43 = +HEAPF64[$0>>3];
      $44 = ((($$sroa$0125$0133)) + 4|0);
      $45 = +HEAPF32[$44>>2];
      $46 = $45;
      $47 = $43 * $46;
      $48 = +HEAPF64[$21>>3];
      $49 = ((($$sroa$0125$0133)) + 8|0);
      $50 = +HEAPF32[$49>>2];
      $51 = $50;
      $52 = $48 * $51;
      $53 = $47 + $52;
      $54 = +HEAPF64[$22>>3];
      $55 = ((($$sroa$0125$0133)) + 12|0);
      $56 = +HEAPF32[$55>>2];
      $57 = $56;
      $58 = $54 * $57;
      $59 = $53 + $58;
      $60 = +HEAPF64[$23>>3];
      $61 = $60 + $59;
      $62 = $61;
      HEAPF32[$5>>2] = $62;
      $63 = HEAP32[$8>>2]|0;
      $64 = HEAP32[$24>>2]|0;
      $65 = ($63|0)==($64|0);
      if ($65) {
       __THREW__ = 0;
       invoke_vii(3896,($4|0),($5|0));
       $67 = __THREW__; __THREW__ = 0;
       $68 = $67&1;
       if ($68) {
        break;
       }
       $$pre = HEAP32[$10>>2]|0;
       $69 = $$pre;
       $211 = $69;$72 = $$pre;
      } else {
       HEAPF32[$63>>2] = $62;
       $66 = ((($63)) + 4|0);
       HEAP32[$8>>2] = $66;
       $211 = $209;$72 = $210;
      }
      $70 = ((($$sroa$0125$0133)) + 16|0);
      $71 = ($70|0)==($72|0);
      if ($71) {
       $208 = $211;
       break L4;
      } else {
       $$sroa$0125$0133 = $70;$209 = $211;$210 = $72;
      }
     }
     $73 = ___cxa_find_matching_catch_2()|0;
     $74 = tempRet0;
     $$3 = $73;$$362 = $74;
     break L1;
    }
   } while(0);
   $25 = HEAP32[$2>>2]|0;
   $26 = ((($2)) + 4|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = ($27|0)==($25|0);
   $29 = $25;
   if ($28) {
    $$in = $27;$36 = $208;
   } else {
    $scevgep$i$i$i68 = ((($27)) + -16|0);
    $30 = $scevgep$i$i$i68;
    $31 = (($30) - ($29))|0;
    $32 = $31 >>> 4;
    $33 = $32 ^ -1;
    $scevgep5$i$i$i69 = (($27) + ($33<<4)|0);
    HEAP32[$26>>2] = $scevgep5$i$i$i69;
    $$pre135 = HEAP32[$10>>2]|0;
    $$in = $scevgep5$i$i$i69;$36 = $$pre135;
   }
   $34 = HEAP32[$1>>2]|0;
   $35 = (($36) - ($34))|0;
   $37 = $35 >> 4;
   $38 = ($37|0)==(0);
   do {
    if ($38) {
     $39 = $$in;
     $76 = $29;$77 = $39;
    } else {
     $$sroa$084$0$$sroa_idx = ((($7)) + 4|0);
     $$sroa$587$0$$sroa_idx90 = ((($7)) + 8|0);
     $$sroa$6$0$$sroa_idx93 = ((($7)) + 12|0);
     $40 = ((($2)) + 8|0);
     $$sroa$0108$0$$sroa_idx = ((($6)) + 4|0);
     $$sroa$5111$0$$sroa_idx114 = ((($6)) + 8|0);
     $$sroa$6115$0$$sroa_idx118 = ((($6)) + 12|0);
     $$063132 = 0;$$in143 = $34;$91 = $37;
     while(1) {
      $88 = $$in143;
      $89 = (($$063132) + 1)|0;
      $90 = (($89>>>0) % ($91>>>0))&-1;
      $92 = HEAP32[$4>>2]|0;
      $93 = (($92) + ($$063132<<2)|0);
      $94 = +HEAPF32[$93>>2];
      $95 = !($94 >= 0.0);
      if ($95) {
       $152 = (($92) + ($90<<2)|0);
       $153 = +HEAPF32[$152>>2];
       $154 = $153 > 0.0;
       if ($154) {
        $160 = (($88) + ($$063132<<4)|0);
        $161 = HEAP32[$160>>2]|0;
        $162 = (($88) + ($90<<4)|0);
        $163 = HEAP32[$162>>2]|0;
        $164 = $163 & $161;
        $165 = $164 | $3;
        $166 = $153 - $94;
        $167 = $153 / $166;
        $168 = (((($88) + ($$063132<<4)|0)) + 4|0);
        $169 = +HEAPF32[$168>>2];
        $170 = $167 * $169;
        $171 = (((($88) + ($$063132<<4)|0)) + 8|0);
        $172 = +HEAPF32[$171>>2];
        $173 = $167 * $172;
        $174 = (((($88) + ($$063132<<4)|0)) + 12|0);
        $175 = +HEAPF32[$174>>2];
        $176 = $167 * $175;
        $177 = 1.0 - $167;
        $178 = (((($88) + ($90<<4)|0)) + 4|0);
        $179 = +HEAPF32[$178>>2];
        $180 = $177 * $179;
        $181 = (((($88) + ($90<<4)|0)) + 8|0);
        $182 = +HEAPF32[$181>>2];
        $183 = $177 * $182;
        $184 = (((($88) + ($90<<4)|0)) + 12|0);
        $185 = +HEAPF32[$184>>2];
        $186 = $177 * $185;
        $187 = $170 + $180;
        $188 = $173 + $183;
        $189 = $176 + $186;
        HEAP32[$7>>2] = $165;
        HEAPF32[$$sroa$084$0$$sroa_idx>>2] = $187;
        HEAPF32[$$sroa$587$0$$sroa_idx90>>2] = $188;
        HEAPF32[$$sroa$6$0$$sroa_idx93>>2] = $189;
        $190 = HEAP32[$26>>2]|0;
        $191 = HEAP32[$40>>2]|0;
        $192 = ($190|0)==($191|0);
        if ($192) {
         __THREW__ = 0;
         invoke_vii(3897,($2|0),($7|0));
         $195 = __THREW__; __THREW__ = 0;
         $196 = $195&1;
         if ($196) {
          label = 40;
          break;
         }
        } else {
         ;HEAP32[$190>>2]=HEAP32[$7>>2]|0;HEAP32[$190+4>>2]=HEAP32[$7+4>>2]|0;HEAP32[$190+8>>2]=HEAP32[$7+8>>2]|0;HEAP32[$190+12>>2]=HEAP32[$7+12>>2]|0;
         $193 = HEAP32[$26>>2]|0;
         $194 = ((($193)) + 16|0);
         HEAP32[$26>>2] = $194;
        }
       }
      } else {
       $96 = (($88) + ($$063132<<4)|0);
       $97 = HEAP32[$26>>2]|0;
       $98 = HEAP32[$40>>2]|0;
       $99 = ($97|0)==($98|0);
       if ($99) {
        __THREW__ = 0;
        invoke_vii(3897,($2|0),($96|0));
        $102 = __THREW__; __THREW__ = 0;
        $103 = $102&1;
        if ($103) {
         label = 32;
         break;
        }
        $$pre136 = HEAP32[$4>>2]|0;
        $105 = $$pre136;
       } else {
        ;HEAP32[$97>>2]=HEAP32[$96>>2]|0;HEAP32[$97+4>>2]=HEAP32[$96+4>>2]|0;HEAP32[$97+8>>2]=HEAP32[$96+8>>2]|0;HEAP32[$97+12>>2]=HEAP32[$96+12>>2]|0;
        $100 = HEAP32[$26>>2]|0;
        $101 = ((($100)) + 16|0);
        HEAP32[$26>>2] = $101;
        $105 = $92;
       }
       $104 = (($105) + ($90<<2)|0);
       $106 = +HEAPF32[$104>>2];
       $107 = $106 < 0.0;
       if ($107) {
        $108 = HEAP32[$1>>2]|0;
        $109 = (($108) + ($$063132<<4)|0);
        $110 = HEAP32[$109>>2]|0;
        $111 = (($108) + ($90<<4)|0);
        $112 = HEAP32[$111>>2]|0;
        $113 = $112 & $110;
        $114 = $113 | $3;
        $115 = (($105) + ($$063132<<2)|0);
        $116 = +HEAPF32[$115>>2];
        $117 = $106 - $116;
        $118 = $106 / $117;
        $119 = (((($108) + ($$063132<<4)|0)) + 4|0);
        $120 = +HEAPF32[$119>>2];
        $121 = $118 * $120;
        $122 = (((($108) + ($$063132<<4)|0)) + 8|0);
        $123 = +HEAPF32[$122>>2];
        $124 = $118 * $123;
        $125 = (((($108) + ($$063132<<4)|0)) + 12|0);
        $126 = +HEAPF32[$125>>2];
        $127 = $118 * $126;
        $128 = 1.0 - $118;
        $129 = (((($108) + ($90<<4)|0)) + 4|0);
        $130 = +HEAPF32[$129>>2];
        $131 = $128 * $130;
        $132 = (((($108) + ($90<<4)|0)) + 8|0);
        $133 = +HEAPF32[$132>>2];
        $134 = $128 * $133;
        $135 = (((($108) + ($90<<4)|0)) + 12|0);
        $136 = +HEAPF32[$135>>2];
        $137 = $128 * $136;
        $138 = $121 + $131;
        $139 = $124 + $134;
        $140 = $127 + $137;
        HEAP32[$6>>2] = $114;
        HEAPF32[$$sroa$0108$0$$sroa_idx>>2] = $138;
        HEAPF32[$$sroa$5111$0$$sroa_idx114>>2] = $139;
        HEAPF32[$$sroa$6115$0$$sroa_idx118>>2] = $140;
        $141 = HEAP32[$26>>2]|0;
        $142 = HEAP32[$40>>2]|0;
        $143 = ($141|0)==($142|0);
        if ($143) {
         __THREW__ = 0;
         invoke_vii(3897,($2|0),($6|0));
         $146 = __THREW__; __THREW__ = 0;
         $147 = $146&1;
         if ($147) {
          label = 33;
          break;
         }
        } else {
         ;HEAP32[$141>>2]=HEAP32[$6>>2]|0;HEAP32[$141+4>>2]=HEAP32[$6+4>>2]|0;HEAP32[$141+8>>2]=HEAP32[$6+8>>2]|0;HEAP32[$141+12>>2]=HEAP32[$6+12>>2]|0;
         $144 = HEAP32[$26>>2]|0;
         $145 = ((($144)) + 16|0);
         HEAP32[$26>>2] = $145;
        }
       }
      }
      $155 = HEAP32[$10>>2]|0;
      $156 = HEAP32[$1>>2]|0;
      $157 = (($155) - ($156))|0;
      $158 = $157 >> 4;
      $159 = ($89>>>0)<($158>>>0);
      if ($159) {
       $$063132 = $89;$$in143 = $156;$91 = $158;
      } else {
       label = 16;
       break;
      }
     }
     if ((label|0) == 16) {
      $$pre137 = HEAP32[$26>>2]|0;
      $$pre139 = HEAP32[$2>>2]|0;
      $76 = $$pre139;$77 = $$pre137;
      break;
     }
     else if ((label|0) == 32) {
      $148 = ___cxa_find_matching_catch_2()|0;
      $149 = tempRet0;
      $$3 = $148;$$362 = $149;
      break L1;
     }
     else if ((label|0) == 33) {
      $150 = ___cxa_find_matching_catch_2()|0;
      $151 = tempRet0;
      $$3 = $150;$$362 = $151;
      break L1;
     }
     else if ((label|0) == 40) {
      $197 = ___cxa_find_matching_catch_2()|0;
      $198 = tempRet0;
      $$3 = $197;$$362 = $198;
      break L1;
     }
    }
   } while(0);
   $75 = (($77) - ($76))|0;
   $78 = $75 >> 4;
   $79 = HEAP32[$4>>2]|0;
   $80 = ($79|0)==(0|0);
   if ($80) {
    STACKTOP = sp;return ($78|0);
   }
   $81 = HEAP32[$8>>2]|0;
   $82 = ($81|0)==($79|0);
   if (!($82)) {
    $scevgep$i$i$i71 = ((($81)) + -4|0);
    $83 = $scevgep$i$i$i71;
    $84 = $79;
    $85 = (($83) - ($84))|0;
    $86 = $85 >>> 2;
    $87 = $86 ^ -1;
    $scevgep5$i$i$i72 = (($81) + ($87<<2)|0);
    HEAP32[$8>>2] = $scevgep5$i$i$i72;
   }
   __ZdlPv($79);
   STACKTOP = sp;return ($78|0);
  }
 } while(0);
 $199 = HEAP32[$4>>2]|0;
 $200 = ($199|0)==(0|0);
 if ($200) {
  ___resumeException($$3|0);
  // unreachable;
 }
 $201 = HEAP32[$8>>2]|0;
 $202 = ($201|0)==($199|0);
 if (!($202)) {
  $scevgep$i$i$i = ((($201)) + -4|0);
  $203 = $scevgep$i$i$i;
  $204 = $199;
  $205 = (($203) - ($204))|0;
  $206 = $205 >>> 2;
  $207 = $206 ^ -1;
  $scevgep5$i$i$i = (($201) + ($207<<2)|0);
  HEAP32[$8>>2] = $scevgep5$i$i$i;
 }
 __ZdlPv($199);
 ___resumeException($$3|0);
 // unreachable;
 return (0)|0;
}
function __Z4clipRKNSt3__26vectorIN3osg5PlaneENS_9allocatorIS2_EEEERKNS0_INS1_5Vec3fENS3_IS8_EEEERNS0_INS_4pairIjS8_EENS3_ISE_EEEE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$01436 = 0, $$119 = 0, $$phi$trans$insert41 = 0, $$phi$trans$insert44 = 0, $$phi$trans$insert47 = 0, $$pre = 0, $$pre$phi51Z2D = 0, $$pre$phi53Z2D = 0, $$pre$phi54Z2D = 0, $$pre$phi57Z2D = 0, $$pre$phi58Z2D = 0, $$pre38 = 0, $$pre40 = 0, $$pre43 = 0, $$pre46 = 0, $$pre49 = 0, $$pre50 = 0, $$sroa$027$035 = 0, $$sroa$07$011$i = 0, $10 = 0;
 var $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i21 = 0, $scevgep5$i$i$i = 0, $scevgep5$i$i$i22 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $3 = sp + 16|0;
 $4 = sp;
 HEAP32[$4>>2] = 0;
 $5 = ((($4)) + 4|0);
 HEAP32[$5>>2] = 0;
 $6 = ((($4)) + 8|0);
 HEAP32[$6>>2] = 0;
 $7 = ((($1)) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$1>>2]|0;
 $10 = (($8) - ($9))|0;
 $11 = (($10|0) / 12)&-1;
 __THREW__ = 0;
 invoke_vii(3898,($4|0),($11|0));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 L1: do {
  if (!($13)) {
   $14 = HEAP32[$1>>2]|0;
   $15 = HEAP32[$7>>2]|0;
   $16 = ($14|0)==($15|0);
   if (!($16)) {
    $17 = ((($3)) + 4|0);
    $18 = ((($4)) + 8|0);
    $$sroa$07$011$i = $14;
    while(1) {
     HEAP32[$3>>2] = 0;
     ;HEAP32[$17>>2]=HEAP32[$$sroa$07$011$i>>2]|0;HEAP32[$17+4>>2]=HEAP32[$$sroa$07$011$i+4>>2]|0;HEAP32[$17+8>>2]=HEAP32[$$sroa$07$011$i+8>>2]|0;
     $19 = HEAP32[$5>>2]|0;
     $20 = HEAP32[$18>>2]|0;
     $21 = ($19|0)==($20|0);
     if ($21) {
      __THREW__ = 0;
      invoke_vii(3897,($4|0),($3|0));
      $23 = __THREW__; __THREW__ = 0;
      $24 = $23&1;
      if ($24) {
       break L1;
      }
     } else {
      ;HEAP32[$19>>2]=HEAP32[$3>>2]|0;HEAP32[$19+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$19+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$19+12>>2]=HEAP32[$3+12>>2]|0;
      $22 = ((($19)) + 16|0);
      HEAP32[$5>>2] = $22;
     }
     $25 = ((($$sroa$07$011$i)) + 12|0);
     $26 = HEAP32[$7>>2]|0;
     $27 = ($25|0)==($26|0);
     if ($27) {
      break;
     } else {
      $$sroa$07$011$i = $25;
     }
    }
   }
   $28 = HEAP32[$0>>2]|0;
   $29 = ((($0)) + 4|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = ($28|0)==($30|0);
   L12: do {
    if ($31) {
     $$pre = HEAP32[$4>>2]|0;
     $$pre38 = HEAP32[$2>>2]|0;
     $$pre40 = HEAP32[$5>>2]|0;
     $$phi$trans$insert41 = ((($2)) + 4|0);
     $$pre43 = HEAP32[$$phi$trans$insert41>>2]|0;
     $$phi$trans$insert44 = ((($4)) + 8|0);
     $$pre46 = HEAP32[$$phi$trans$insert44>>2]|0;
     $$phi$trans$insert47 = ((($2)) + 8|0);
     $$pre49 = HEAP32[$$phi$trans$insert47>>2]|0;
     $$pre$phi51Z2D = $2;$$pre$phi53Z2D = $5;$$pre$phi54Z2D = $$phi$trans$insert41;$$pre$phi57Z2D = $$phi$trans$insert44;$$pre$phi58Z2D = $$phi$trans$insert47;$49 = $$pre38;$50 = $$pre;$51 = $$pre43;$52 = $$pre40;$53 = $$pre49;$54 = $$pre46;
     label = 14;
    } else {
     $32 = ((($2)) + 4|0);
     $33 = ((($4)) + 8|0);
     $34 = ((($2)) + 8|0);
     $$01436 = 1;$$sroa$027$035 = $28;
     while(1) {
      __THREW__ = 0;
      $35 = (invoke_iiiii(3899,($$sroa$027$035|0),($4|0),($2|0),($$01436|0))|0);
      $36 = __THREW__; __THREW__ = 0;
      $37 = $36&1;
      if ($37) {
       break L1;
      }
      $38 = ($35|0)==(0);
      if ($38) {
       break;
      }
      $39 = HEAP32[$4>>2]|0;
      $40 = HEAP32[$2>>2]|0;
      HEAP32[$4>>2] = $40;
      HEAP32[$2>>2] = $39;
      $41 = HEAP32[$5>>2]|0;
      $42 = HEAP32[$32>>2]|0;
      HEAP32[$5>>2] = $42;
      HEAP32[$32>>2] = $41;
      $43 = HEAP32[$33>>2]|0;
      $44 = HEAP32[$34>>2]|0;
      HEAP32[$33>>2] = $44;
      HEAP32[$34>>2] = $43;
      $45 = $$01436 << 1;
      $46 = ((($$sroa$027$035)) + 40|0);
      $47 = HEAP32[$29>>2]|0;
      $48 = ($46|0)==($47|0);
      if ($48) {
       $$pre$phi51Z2D = $2;$$pre$phi53Z2D = $5;$$pre$phi54Z2D = $32;$$pre$phi57Z2D = $33;$$pre$phi58Z2D = $34;$49 = $39;$50 = $40;$51 = $41;$52 = $42;$53 = $43;$54 = $44;
       label = 14;
       break L12;
      } else {
       $$01436 = $45;$$sroa$027$035 = $46;
      }
     }
     $$pre50 = HEAP32[$4>>2]|0;
     $$119 = 0;$58 = $$pre50;
    }
   } while(0);
   if ((label|0) == 14) {
    HEAP32[$4>>2] = $49;
    HEAP32[$$pre$phi51Z2D>>2] = $50;
    HEAP32[$$pre$phi53Z2D>>2] = $51;
    HEAP32[$$pre$phi54Z2D>>2] = $52;
    HEAP32[$$pre$phi57Z2D>>2] = $53;
    HEAP32[$$pre$phi58Z2D>>2] = $54;
    $55 = (($52) - ($50))|0;
    $56 = $55 >> 4;
    $57 = $49;
    $$119 = $56;$58 = $57;
   }
   $59 = ($58|0)==(0|0);
   if ($59) {
    STACKTOP = sp;return ($$119|0);
   }
   $60 = HEAP32[$5>>2]|0;
   $61 = ($60|0)==($58|0);
   if (!($61)) {
    $scevgep$i$i$i21 = ((($60)) + -16|0);
    $62 = $scevgep$i$i$i21;
    $63 = $58;
    $64 = (($62) - ($63))|0;
    $65 = $64 >>> 4;
    $66 = $65 ^ -1;
    $scevgep5$i$i$i22 = (($60) + ($66<<4)|0);
    HEAP32[$5>>2] = $scevgep5$i$i$i22;
   }
   __ZdlPv($58);
   STACKTOP = sp;return ($$119|0);
  }
 } while(0);
 $67 = ___cxa_find_matching_catch_2()|0;
 $68 = tempRet0;
 $69 = HEAP32[$4>>2]|0;
 $70 = ($69|0)==(0|0);
 if ($70) {
  ___resumeException($67|0);
  // unreachable;
 }
 $71 = HEAP32[$5>>2]|0;
 $72 = ($71|0)==($69|0);
 if (!($72)) {
  $scevgep$i$i$i = ((($71)) + -16|0);
  $73 = $scevgep$i$i$i;
  $74 = $69;
  $75 = (($73) - ($74))|0;
  $76 = $75 >>> 4;
  $77 = $76 ^ -1;
  $scevgep5$i$i$i = (($71) + ($77<<4)|0);
  HEAP32[$5>>2] = $scevgep5$i$i$i;
 }
 __ZdlPv($69);
 ___resumeException($67|0);
 // unreachable;
 return (0)|0;
}
function __Z9transformRNSt3__26vectorINS_4pairIjN3osg5Vec3fEEENS_9allocatorIS4_EEEERKNS2_7MatrixdE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$sroa$010$015 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0.0, $25 = 0.0, $26 = 0.0, $27 = 0.0;
 var $28 = 0.0, $29 = 0.0, $3 = 0, $30 = 0.0, $31 = 0.0, $32 = 0.0, $33 = 0.0, $34 = 0.0, $35 = 0.0, $36 = 0.0, $37 = 0, $38 = 0.0, $39 = 0.0, $4 = 0, $40 = 0.0, $41 = 0, $42 = 0.0, $43 = 0.0, $44 = 0.0, $45 = 0.0;
 var $46 = 0, $47 = 0.0, $48 = 0.0, $49 = 0.0, $5 = 0, $50 = 0.0, $51 = 0.0, $52 = 0.0, $53 = 0.0, $54 = 0.0, $55 = 0.0, $56 = 0.0, $57 = 0.0, $58 = 0.0, $59 = 0.0, $6 = 0, $60 = 0.0, $61 = 0.0, $62 = 0.0, $63 = 0.0;
 var $64 = 0.0, $65 = 0.0, $66 = 0.0, $67 = 0.0, $68 = 0.0, $69 = 0.0, $7 = 0, $70 = 0.0, $71 = 0.0, $72 = 0.0, $73 = 0.0, $74 = 0.0, $75 = 0.0, $76 = 0.0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $3 = ((($0)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2|0)==($4|0);
 if ($5) {
  return;
 }
 $6 = ((($1)) + 24|0);
 $7 = ((($1)) + 56|0);
 $8 = ((($1)) + 88|0);
 $9 = ((($1)) + 120|0);
 $10 = ((($1)) + 32|0);
 $11 = ((($1)) + 64|0);
 $12 = ((($1)) + 96|0);
 $13 = ((($1)) + 8|0);
 $14 = ((($1)) + 40|0);
 $15 = ((($1)) + 72|0);
 $16 = ((($1)) + 104|0);
 $17 = ((($1)) + 16|0);
 $18 = ((($1)) + 48|0);
 $19 = ((($1)) + 80|0);
 $20 = ((($1)) + 112|0);
 $21 = +HEAPF64[$6>>3];
 $22 = +HEAPF64[$7>>3];
 $23 = +HEAPF64[$8>>3];
 $24 = +HEAPF64[$9>>3];
 $25 = +HEAPF64[$1>>3];
 $26 = +HEAPF64[$10>>3];
 $27 = +HEAPF64[$11>>3];
 $28 = +HEAPF64[$12>>3];
 $29 = +HEAPF64[$13>>3];
 $30 = +HEAPF64[$14>>3];
 $31 = +HEAPF64[$15>>3];
 $32 = +HEAPF64[$16>>3];
 $33 = +HEAPF64[$17>>3];
 $34 = +HEAPF64[$18>>3];
 $35 = +HEAPF64[$19>>3];
 $36 = +HEAPF64[$20>>3];
 $$sroa$010$015 = $2;
 while(1) {
  $37 = ((($$sroa$010$015)) + 4|0);
  $38 = +HEAPF32[$37>>2];
  $39 = $38;
  $40 = $21 * $39;
  $41 = ((($$sroa$010$015)) + 8|0);
  $42 = +HEAPF32[$41>>2];
  $43 = $42;
  $44 = $22 * $43;
  $45 = $40 + $44;
  $46 = ((($$sroa$010$015)) + 12|0);
  $47 = +HEAPF32[$46>>2];
  $48 = $47;
  $49 = $23 * $48;
  $50 = $45 + $49;
  $51 = $24 + $50;
  $52 = 1.0 / $51;
  $53 = $39 * $25;
  $54 = $43 * $26;
  $55 = $53 + $54;
  $56 = $48 * $27;
  $57 = $55 + $56;
  $58 = $28 + $57;
  $59 = $52 * $58;
  $60 = $59;
  $61 = $39 * $29;
  $62 = $43 * $30;
  $63 = $61 + $62;
  $64 = $48 * $31;
  $65 = $63 + $64;
  $66 = $32 + $65;
  $67 = $52 * $66;
  $68 = $67;
  $69 = $39 * $33;
  $70 = $43 * $34;
  $71 = $69 + $70;
  $72 = $48 * $35;
  $73 = $71 + $72;
  $74 = $36 + $73;
  $75 = $52 * $74;
  $76 = $75;
  HEAPF32[$37>>2] = $60;
  HEAPF32[$41>>2] = $68;
  HEAPF32[$46>>2] = $76;
  $77 = ((($$sroa$010$015)) + 16|0);
  $78 = HEAP32[$3>>2]|0;
  $79 = ($77|0)==($78|0);
  if ($79) {
   break;
  } else {
   $$sroa$010$015 = $77;
  }
 }
 return;
}
function __Z9transformRKNSt3__26vectorINS_4pairIjN3osg5Vec3fEEENS_9allocatorIS4_EEEERS7_RKNS2_7MatrixdE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$sroa$0$0$$sroa_idx = 0, $$sroa$011$016 = 0, $$sroa$4$0$$sroa_idx6 = 0, $$sroa$5$0$$sroa_idx8 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0.0;
 var $26 = 0, $27 = 0.0, $28 = 0.0, $29 = 0.0, $3 = 0, $30 = 0.0, $31 = 0, $32 = 0.0, $33 = 0.0, $34 = 0.0, $35 = 0.0, $36 = 0.0, $37 = 0, $38 = 0.0, $39 = 0.0, $4 = 0, $40 = 0.0, $41 = 0.0, $42 = 0.0, $43 = 0.0;
 var $44 = 0.0, $45 = 0.0, $46 = 0.0, $47 = 0.0, $48 = 0.0, $49 = 0.0, $5 = 0, $50 = 0.0, $51 = 0.0, $52 = 0.0, $53 = 0.0, $54 = 0.0, $55 = 0.0, $56 = 0.0, $57 = 0.0, $58 = 0.0, $59 = 0.0, $6 = 0, $60 = 0.0, $61 = 0.0;
 var $62 = 0.0, $63 = 0.0, $64 = 0.0, $65 = 0.0, $66 = 0.0, $67 = 0.0, $68 = 0.0, $69 = 0.0, $7 = 0, $70 = 0.0, $71 = 0.0, $72 = 0.0, $73 = 0.0, $74 = 0.0, $75 = 0.0, $76 = 0.0, $77 = 0.0, $78 = 0.0, $79 = 0.0, $8 = 0;
 var $80 = 0.0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = HEAP32[$0>>2]|0;
 $5 = ((($0)) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4|0)==($6|0);
 if ($7) {
  STACKTOP = sp;return;
 }
 $8 = ((($2)) + 24|0);
 $9 = ((($2)) + 56|0);
 $10 = ((($2)) + 88|0);
 $11 = ((($2)) + 120|0);
 $12 = ((($2)) + 32|0);
 $13 = ((($2)) + 64|0);
 $14 = ((($2)) + 96|0);
 $15 = ((($2)) + 8|0);
 $16 = ((($2)) + 40|0);
 $17 = ((($2)) + 72|0);
 $18 = ((($2)) + 104|0);
 $19 = ((($2)) + 16|0);
 $20 = ((($2)) + 48|0);
 $21 = ((($2)) + 80|0);
 $22 = ((($2)) + 112|0);
 $$sroa$0$0$$sroa_idx = ((($3)) + 4|0);
 $$sroa$4$0$$sroa_idx6 = ((($3)) + 8|0);
 $$sroa$5$0$$sroa_idx8 = ((($3)) + 12|0);
 $23 = ((($1)) + 4|0);
 $24 = ((($1)) + 8|0);
 $$sroa$011$016 = $4;
 while(1) {
  $25 = +HEAPF64[$8>>3];
  $26 = ((($$sroa$011$016)) + 4|0);
  $27 = +HEAPF32[$26>>2];
  $28 = $27;
  $29 = $25 * $28;
  $30 = +HEAPF64[$9>>3];
  $31 = ((($$sroa$011$016)) + 8|0);
  $32 = +HEAPF32[$31>>2];
  $33 = $32;
  $34 = $30 * $33;
  $35 = $29 + $34;
  $36 = +HEAPF64[$10>>3];
  $37 = ((($$sroa$011$016)) + 12|0);
  $38 = +HEAPF32[$37>>2];
  $39 = $38;
  $40 = $36 * $39;
  $41 = $35 + $40;
  $42 = +HEAPF64[$11>>3];
  $43 = $42 + $41;
  $44 = 1.0 / $43;
  $45 = +HEAPF64[$2>>3];
  $46 = $28 * $45;
  $47 = +HEAPF64[$12>>3];
  $48 = $33 * $47;
  $49 = $46 + $48;
  $50 = +HEAPF64[$13>>3];
  $51 = $39 * $50;
  $52 = $49 + $51;
  $53 = +HEAPF64[$14>>3];
  $54 = $53 + $52;
  $55 = $44 * $54;
  $56 = $55;
  $57 = +HEAPF64[$15>>3];
  $58 = $28 * $57;
  $59 = +HEAPF64[$16>>3];
  $60 = $33 * $59;
  $61 = $58 + $60;
  $62 = +HEAPF64[$17>>3];
  $63 = $39 * $62;
  $64 = $61 + $63;
  $65 = +HEAPF64[$18>>3];
  $66 = $65 + $64;
  $67 = $44 * $66;
  $68 = $67;
  $69 = +HEAPF64[$19>>3];
  $70 = $28 * $69;
  $71 = +HEAPF64[$20>>3];
  $72 = $33 * $71;
  $73 = $70 + $72;
  $74 = +HEAPF64[$21>>3];
  $75 = $39 * $74;
  $76 = $73 + $75;
  $77 = +HEAPF64[$22>>3];
  $78 = $77 + $76;
  $79 = $44 * $78;
  $80 = $79;
  $81 = HEAP32[$$sroa$011$016>>2]|0;
  HEAP32[$3>>2] = $81;
  HEAPF32[$$sroa$0$0$$sroa_idx>>2] = $56;
  HEAPF32[$$sroa$4$0$$sroa_idx6>>2] = $68;
  HEAPF32[$$sroa$5$0$$sroa_idx8>>2] = $80;
  $82 = HEAP32[$23>>2]|0;
  $83 = HEAP32[$24>>2]|0;
  $84 = ($82|0)==($83|0);
  if ($84) {
   __ZNSt3__26vectorINS_4pairIjN3osg5Vec3fEEENS_9allocatorIS4_EEE21__push_back_slow_pathIKS4_EEvRT_($1,$3);
  } else {
   ;HEAP32[$82>>2]=HEAP32[$3>>2]|0;HEAP32[$82+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$82+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$82+12>>2]=HEAP32[$3+12>>2]|0;
   $85 = HEAP32[$23>>2]|0;
   $86 = ((($85)) + 16|0);
   HEAP32[$23>>2] = $86;
  }
  $87 = ((($$sroa$011$016)) + 16|0);
  $88 = HEAP32[$5>>2]|0;
  $89 = ($87|0)==($88|0);
  if ($89) {
   break;
  } else {
   $$sroa$011$016 = $87;
  }
 }
 STACKTOP = sp;return;
}
function __Z13computePlanesRKNSt3__26vectorINS_4pairIjN3osg5Vec3fEEENS_9allocatorIS4_EEEES9_RNS0_INS2_5PlaneENS5_ISA_EEEE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$033 = 0, $$pre = 0, $$pre$pre = 0, $$pre34 = 0, $$pre34$pre = 0, $$sroa$16$0$i$i = 0.0, $$sroa$9$0$i$i = 0.0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0.0, $106 = 0, $107 = 0.0, $108 = 0, $109 = 0.0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0.0, $35 = 0.0, $36 = 0, $37 = 0.0, $38 = 0.0, $39 = 0;
 var $4 = 0, $40 = 0.0, $41 = 0.0, $42 = 0, $43 = 0.0, $44 = 0.0, $45 = 0, $46 = 0.0, $47 = 0.0, $48 = 0, $49 = 0.0, $5 = 0, $50 = 0.0, $51 = 0, $52 = 0, $53 = 0.0, $54 = 0.0, $55 = 0, $56 = 0.0, $57 = 0.0;
 var $58 = 0, $59 = 0.0, $6 = 0, $60 = 0.0, $61 = 0.0, $62 = 0.0, $63 = 0.0, $64 = 0.0, $65 = 0.0, $66 = 0.0, $67 = 0.0, $68 = 0.0, $69 = 0.0, $7 = 0, $70 = 0.0, $71 = 0.0, $72 = 0.0, $73 = 0.0, $74 = 0.0, $75 = 0.0;
 var $76 = 0.0, $77 = 0.0, $78 = 0.0, $79 = 0.0, $8 = 0, $80 = 0.0, $81 = 0.0, $82 = 0, $83 = 0.0, $84 = 0.0, $85 = 0.0, $86 = 0.0, $87 = 0.0, $88 = 0.0, $89 = 0.0, $9 = 0, $90 = 0.0, $91 = 0.0, $92 = 0.0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $3 = sp;
 $4 = ((($0)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$0>>2]|0;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 4;
 $9 = ($8|0)==(0);
 if ($9) {
  STACKTOP = sp;return;
 }
 $10 = ((($3)) + 8|0);
 $11 = ((($3)) + 16|0);
 $12 = ((($3)) + 24|0);
 $13 = ((($3)) + 32|0);
 $14 = ((($3)) + 36|0);
 $15 = ((($2)) + 4|0);
 $16 = ((($2)) + 8|0);
 $$033 = 0;$121 = $5;$17 = $6;$21 = $8;
 while(1) {
  $18 = $17;
  $19 = (($$033) + 1)|0;
  $20 = (($19>>>0) % ($21>>>0))&-1;
  $22 = (($18) + ($$033<<4)|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (($18) + ($20<<4)|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = $25 & $23;
  $27 = ($26|0)==(0);
  if ($27) {
   $33 = (((($18) + ($$033<<4)|0)) + 4|0);
   $34 = +HEAPF32[$33>>2];
   $35 = $34;
   $36 = (((($18) + ($$033<<4)|0)) + 8|0);
   $37 = +HEAPF32[$36>>2];
   $38 = $37;
   $39 = (((($18) + ($$033<<4)|0)) + 12|0);
   $40 = +HEAPF32[$39>>2];
   $41 = $40;
   $42 = (((($18) + ($20<<4)|0)) + 4|0);
   $43 = +HEAPF32[$42>>2];
   $44 = $43;
   $45 = (((($18) + ($20<<4)|0)) + 8|0);
   $46 = +HEAPF32[$45>>2];
   $47 = $46;
   $48 = (((($18) + ($20<<4)|0)) + 12|0);
   $49 = +HEAPF32[$48>>2];
   $50 = $49;
   $51 = HEAP32[$1>>2]|0;
   $52 = (((($51) + ($$033<<4)|0)) + 4|0);
   $53 = +HEAPF32[$52>>2];
   $54 = $53;
   $55 = (((($51) + ($$033<<4)|0)) + 8|0);
   $56 = +HEAPF32[$55>>2];
   $57 = $56;
   $58 = (((($51) + ($$033<<4)|0)) + 12|0);
   $59 = +HEAPF32[$58>>2];
   $60 = $59;
   $61 = $44 - $35;
   $62 = $47 - $38;
   $63 = $50 - $41;
   $64 = $54 - $44;
   $65 = $57 - $47;
   $66 = $60 - $50;
   $67 = $62 * $66;
   $68 = $63 * $65;
   $69 = $67 - $68;
   $70 = $63 * $64;
   $71 = $61 * $66;
   $72 = $70 - $71;
   $73 = $61 * $65;
   $74 = $62 * $64;
   $75 = $73 - $74;
   $76 = $69 * $69;
   $77 = $72 * $72;
   $78 = $76 + $77;
   $79 = $75 * $75;
   $80 = $79 + $78;
   $81 = (+Math_sqrt((+$80)));
   $82 = $81 > 9.9999999999999995E-7;
   if ($82) {
    $83 = $69 / $81;
    $84 = $72 / $81;
    $85 = $75 / $81;
    $$sroa$16$0$i$i = $85;$$sroa$9$0$i$i = $84;$87 = $83;
   } else {
    $$sroa$16$0$i$i = 0.0;$$sroa$9$0$i$i = 0.0;$87 = 0.0;
   }
   $86 = $35 * $87;
   $88 = $38 * $$sroa$9$0$i$i;
   $89 = $86 + $88;
   $90 = $41 * $$sroa$16$0$i$i;
   $91 = $89 + $90;
   $92 = -$91;
   HEAPF64[$3>>3] = $87;
   HEAPF64[$10>>3] = $$sroa$9$0$i$i;
   HEAPF64[$11>>3] = $$sroa$16$0$i$i;
   HEAPF64[$12>>3] = $92;
   $93 = $87 >= 0.0;
   $94 = $93&1;
   $95 = $$sroa$9$0$i$i >= 0.0;
   $96 = $95 ? 2 : 0;
   $97 = $96 | $94;
   $98 = $$sroa$16$0$i$i >= 0.0;
   $99 = $98 ? 4 : 0;
   $100 = $97 | $99;
   HEAP32[$13>>2] = $100;
   $101 = $100 ^ 7;
   HEAP32[$14>>2] = $101;
   $102 = HEAP32[$15>>2]|0;
   $103 = HEAP32[$16>>2]|0;
   $104 = ($102|0)==($103|0);
   if ($104) {
    __ZNSt3__26vectorIN3osg5PlaneENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($2,$3);
    $$pre$pre = HEAP32[$4>>2]|0;
    $$pre34$pre = HEAP32[$0>>2]|0;
    $$pre = $$pre$pre;$$pre34 = $$pre34$pre;
   } else {
    HEAPF64[$102>>3] = $87;
    $105 = +HEAPF64[$10>>3];
    $106 = ((($102)) + 8|0);
    HEAPF64[$106>>3] = $105;
    $107 = +HEAPF64[$11>>3];
    $108 = ((($102)) + 16|0);
    HEAPF64[$108>>3] = $107;
    $109 = +HEAPF64[$12>>3];
    $110 = ((($102)) + 24|0);
    HEAPF64[$110>>3] = $109;
    $111 = $105 >= 0.0;
    $112 = $111 ? 2 : 0;
    $113 = $112 | $94;
    $114 = $107 >= 0.0;
    $115 = $114 ? 4 : 0;
    $116 = $113 | $115;
    $117 = ((($102)) + 32|0);
    HEAP32[$117>>2] = $116;
    $118 = $116 ^ 7;
    $119 = ((($102)) + 36|0);
    HEAP32[$119>>2] = $118;
    $120 = ((($102)) + 40|0);
    HEAP32[$15>>2] = $120;
    $$pre = $121;$$pre34 = $17;
   }
   $29 = $$pre34;$30 = $$pre;
  } else {
   $29 = $17;$30 = $121;
  }
  $28 = (($30) - ($29))|0;
  $31 = $28 >> 4;
  $32 = ($19>>>0)<($31>>>0);
  if ($32) {
   $$033 = $19;$121 = $30;$17 = $29;$21 = $31;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __Z17computeFrontPlaneRKNSt3__26vectorINS_4pairIjN3osg5Vec3fEEENS_9allocatorIS4_EEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$sroa$014$0$i$i = 0.0, $$sroa$16$0$i$i = 0.0, $$sroa$9$0$i$i = 0.0, $10 = 0.0, $11 = 0.0, $12 = 0, $13 = 0.0, $14 = 0.0, $15 = 0, $16 = 0.0, $17 = 0.0, $18 = 0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0, $22 = 0.0, $23 = 0.0, $24 = 0, $25 = 0.0;
 var $26 = 0.0, $27 = 0, $28 = 0.0, $29 = 0.0, $3 = 0, $30 = 0.0, $31 = 0.0, $32 = 0.0, $33 = 0.0, $34 = 0.0, $35 = 0.0, $36 = 0.0, $37 = 0.0, $38 = 0.0, $39 = 0.0, $4 = 0.0, $40 = 0.0, $41 = 0.0, $42 = 0.0, $43 = 0.0;
 var $44 = 0.0, $45 = 0.0, $46 = 0.0, $47 = 0.0, $48 = 0.0, $49 = 0.0, $5 = 0.0, $50 = 0.0, $51 = 0, $52 = 0.0, $53 = 0.0, $54 = 0.0, $55 = 0.0, $56 = 0.0, $57 = 0.0, $58 = 0.0, $59 = 0.0, $6 = 0, $60 = 0.0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0.0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $8 = 0.0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 36|0);
 $4 = +HEAPF32[$3>>2];
 $5 = $4;
 $6 = ((($2)) + 40|0);
 $7 = +HEAPF32[$6>>2];
 $8 = $7;
 $9 = ((($2)) + 44|0);
 $10 = +HEAPF32[$9>>2];
 $11 = $10;
 $12 = ((($2)) + 20|0);
 $13 = +HEAPF32[$12>>2];
 $14 = $13;
 $15 = ((($2)) + 24|0);
 $16 = +HEAPF32[$15>>2];
 $17 = $16;
 $18 = ((($2)) + 28|0);
 $19 = +HEAPF32[$18>>2];
 $20 = $19;
 $21 = ((($2)) + 4|0);
 $22 = +HEAPF32[$21>>2];
 $23 = $22;
 $24 = ((($2)) + 8|0);
 $25 = +HEAPF32[$24>>2];
 $26 = $25;
 $27 = ((($2)) + 12|0);
 $28 = +HEAPF32[$27>>2];
 $29 = $28;
 $30 = $14 - $5;
 $31 = $17 - $8;
 $32 = $20 - $11;
 $33 = $23 - $14;
 $34 = $26 - $17;
 $35 = $29 - $20;
 $36 = $31 * $35;
 $37 = $32 * $34;
 $38 = $36 - $37;
 $39 = $32 * $33;
 $40 = $30 * $35;
 $41 = $39 - $40;
 $42 = $30 * $34;
 $43 = $31 * $33;
 $44 = $42 - $43;
 $45 = $38 * $38;
 $46 = $41 * $41;
 $47 = $45 + $46;
 $48 = $44 * $44;
 $49 = $48 + $47;
 $50 = (+Math_sqrt((+$49)));
 $51 = $50 > 9.9999999999999995E-7;
 if ($51) {
  $52 = $38 / $50;
  $53 = $41 / $50;
  $54 = $44 / $50;
  $$sroa$014$0$i$i = $52;$$sroa$16$0$i$i = $54;$$sroa$9$0$i$i = $53;
 } else {
  $$sroa$014$0$i$i = 0.0;$$sroa$16$0$i$i = 0.0;$$sroa$9$0$i$i = 0.0;
 }
 $55 = $5 * $$sroa$014$0$i$i;
 $56 = $8 * $$sroa$9$0$i$i;
 $57 = $55 + $56;
 $58 = $11 * $$sroa$16$0$i$i;
 $59 = $57 + $58;
 $60 = -$59;
 HEAPF64[$0>>3] = $$sroa$014$0$i$i;
 $61 = ((($0)) + 8|0);
 HEAPF64[$61>>3] = $$sroa$9$0$i$i;
 $62 = ((($0)) + 16|0);
 HEAPF64[$62>>3] = $$sroa$16$0$i$i;
 $63 = ((($0)) + 24|0);
 HEAPF64[$63>>3] = $60;
 $64 = $$sroa$014$0$i$i >= 0.0;
 $65 = $64&1;
 $66 = $$sroa$9$0$i$i >= 0.0;
 $67 = $66 ? 2 : 0;
 $68 = $67 | $65;
 $69 = $$sroa$16$0$i$i >= 0.0;
 $70 = $69 ? 4 : 0;
 $71 = $68 | $70;
 $72 = ((($0)) + 32|0);
 HEAP32[$72>>2] = $71;
 $73 = $71 ^ 7;
 $74 = ((($0)) + 36|0);
 HEAP32[$74>>2] = $73;
 return;
}
function __Z21computePolytopeVolumeRKNSt3__26vectorINS_4pairIjN3osg5Vec3fEEENS_9allocatorIS4_EEEES9_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$017$lcssa = 0.0, $$01731 = 0.0, $$032 = 0, $$phi$trans$insert = 0, $$phi$trans$insert33 = 0, $$phi$trans$insert35 = 0, $$phi$trans$insert37 = 0, $$phi$trans$insert39 = 0, $$phi$trans$insert41 = 0, $$pre = 0.0, $$pre34 = 0.0, $$pre36 = 0.0, $$pre38 = 0.0, $$pre40 = 0.0, $$pre42 = 0.0, $$sroa$0$0$$sroa_idx = 0, $$sroa$0$0$copyload = 0.0, $$sroa$023$0$$sroa_idx = 0, $$sroa$023$0$copyload = 0.0, $$sroa$4$0$$sroa_idx19 = 0;
 var $$sroa$4$0$copyload = 0.0, $$sroa$425$0$$sroa_idx26 = 0, $$sroa$425$0$copyload = 0.0, $$sroa$5$0$$sroa_idx21 = 0, $$sroa$5$0$copyload = 0.0, $$sroa$528$0$$sroa_idx29 = 0, $$sroa$528$0$copyload = 0.0, $10 = 0, $100 = 0.0, $101 = 0.0, $102 = 0.0, $103 = 0.0, $104 = 0.0, $105 = 0, $11 = 0, $12 = 0, $13 = 0.0, $14 = 0.0, $15 = 0.0, $16 = 0;
 var $17 = 0.0, $18 = 0.0, $19 = 0.0, $2 = 0, $20 = 0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0.0, $25 = 0.0, $26 = 0.0, $27 = 0.0, $28 = 0.0, $29 = 0.0, $3 = 0, $30 = 0.0, $31 = 0.0, $32 = 0.0, $33 = 0.0, $34 = 0.0;
 var $35 = 0.0, $36 = 0.0, $37 = 0.0, $38 = 0.0, $39 = 0.0, $4 = 0, $40 = 0.0, $41 = 0.0, $42 = 0.0, $43 = 0.0, $44 = 0.0, $45 = 0, $46 = 0.0, $47 = 0.0, $48 = 0.0, $49 = 0, $5 = 0, $50 = 0.0, $51 = 0.0, $52 = 0.0;
 var $53 = 0, $54 = 0.0, $55 = 0.0, $56 = 0.0, $57 = 0.0, $58 = 0.0, $59 = 0.0, $6 = 0, $60 = 0.0, $61 = 0.0, $62 = 0.0, $63 = 0.0, $64 = 0.0, $65 = 0.0, $66 = 0.0, $67 = 0.0, $68 = 0.0, $69 = 0.0, $7 = 0, $70 = 0.0;
 var $71 = 0.0, $72 = 0.0, $73 = 0.0, $74 = 0.0, $75 = 0.0, $76 = 0.0, $77 = 0.0, $78 = 0.0, $79 = 0.0, $8 = 0, $80 = 0.0, $81 = 0.0, $82 = 0.0, $83 = 0.0, $84 = 0.0, $85 = 0.0, $86 = 0.0, $87 = 0.0, $88 = 0.0, $89 = 0.0;
 var $9 = 0, $90 = 0.0, $91 = 0.0, $92 = 0.0, $93 = 0.0, $94 = 0.0, $95 = 0.0, $96 = 0.0, $97 = 0.0, $98 = 0.0, $99 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $$sroa$023$0$$sroa_idx = ((($2)) + 4|0);
 $$sroa$023$0$copyload = +HEAPF32[$$sroa$023$0$$sroa_idx>>2];
 $$sroa$425$0$$sroa_idx26 = ((($2)) + 8|0);
 $$sroa$425$0$copyload = +HEAPF32[$$sroa$425$0$$sroa_idx26>>2];
 $$sroa$528$0$$sroa_idx29 = ((($2)) + 12|0);
 $$sroa$528$0$copyload = +HEAPF32[$$sroa$528$0$$sroa_idx29>>2];
 $3 = HEAP32[$1>>2]|0;
 $$sroa$0$0$$sroa_idx = ((($3)) + 4|0);
 $$sroa$0$0$copyload = +HEAPF32[$$sroa$0$0$$sroa_idx>>2];
 $$sroa$4$0$$sroa_idx19 = ((($3)) + 8|0);
 $$sroa$4$0$copyload = +HEAPF32[$$sroa$4$0$$sroa_idx19>>2];
 $$sroa$5$0$$sroa_idx21 = ((($3)) + 12|0);
 $$sroa$5$0$copyload = +HEAPF32[$$sroa$5$0$$sroa_idx21>>2];
 $4 = ((($0)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $2;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 4;
 $9 = (($8) + -1)|0;
 $10 = ($9>>>0)>(1);
 if (!($10)) {
  $$017$lcssa = 0.0;
  return (+$$017$lcssa);
 }
 $$phi$trans$insert = ((($2)) + 20|0);
 $$pre = +HEAPF32[$$phi$trans$insert>>2];
 $$phi$trans$insert33 = ((($2)) + 24|0);
 $$pre34 = +HEAPF32[$$phi$trans$insert33>>2];
 $$phi$trans$insert35 = ((($2)) + 28|0);
 $$pre36 = +HEAPF32[$$phi$trans$insert35>>2];
 $$phi$trans$insert37 = ((($3)) + 20|0);
 $$pre38 = +HEAPF32[$$phi$trans$insert37>>2];
 $$phi$trans$insert39 = ((($3)) + 24|0);
 $$pre40 = +HEAPF32[$$phi$trans$insert39>>2];
 $$phi$trans$insert41 = ((($3)) + 28|0);
 $$pre42 = +HEAPF32[$$phi$trans$insert41>>2];
 $$01731 = 0.0;$$032 = 1;$15 = $$pre;$19 = $$pre34;$23 = $$pre36;$48 = $$pre38;$52 = $$pre40;$56 = $$pre42;
 while(1) {
  $11 = (($$032) + 1)|0;
  $12 = (((($2) + ($11<<4)|0)) + 4|0);
  $13 = +HEAPF32[$12>>2];
  $14 = $15 - $13;
  $16 = (((($2) + ($11<<4)|0)) + 8|0);
  $17 = +HEAPF32[$16>>2];
  $18 = $19 - $17;
  $20 = (((($2) + ($11<<4)|0)) + 12|0);
  $21 = +HEAPF32[$20>>2];
  $22 = $23 - $21;
  $24 = $$sroa$023$0$copyload - $15;
  $25 = $$sroa$425$0$copyload - $19;
  $26 = $$sroa$528$0$copyload - $23;
  $27 = $18 * $26;
  $28 = $25 * $22;
  $29 = $27 - $28;
  $30 = $24 * $22;
  $31 = $14 * $26;
  $32 = $30 - $31;
  $33 = $14 * $25;
  $34 = $24 * $18;
  $35 = $33 - $34;
  $36 = $$sroa$0$0$copyload - $15;
  $37 = $$sroa$4$0$copyload - $19;
  $38 = $$sroa$5$0$copyload - $23;
  $39 = $36 * $29;
  $40 = $37 * $32;
  $41 = $39 + $40;
  $42 = $38 * $35;
  $43 = $42 + $41;
  $44 = (+Math_abs((+$43)));
  $45 = (((($3) + ($11<<4)|0)) + 4|0);
  $46 = +HEAPF32[$45>>2];
  $47 = $48 - $46;
  $49 = (((($3) + ($11<<4)|0)) + 8|0);
  $50 = +HEAPF32[$49>>2];
  $51 = $52 - $50;
  $53 = (((($3) + ($11<<4)|0)) + 12|0);
  $54 = +HEAPF32[$53>>2];
  $55 = $56 - $54;
  $57 = $$sroa$0$0$copyload - $48;
  $58 = $$sroa$4$0$copyload - $52;
  $59 = $$sroa$5$0$copyload - $56;
  $60 = $51 * $59;
  $61 = $58 * $55;
  $62 = $60 - $61;
  $63 = $57 * $55;
  $64 = $47 * $59;
  $65 = $63 - $64;
  $66 = $47 * $58;
  $67 = $57 * $51;
  $68 = $66 - $67;
  $69 = $15 - $48;
  $70 = $19 - $52;
  $71 = $23 - $56;
  $72 = $69 * $62;
  $73 = $70 * $65;
  $74 = $72 + $73;
  $75 = $71 * $68;
  $76 = $75 + $74;
  $77 = (+Math_abs((+$76)));
  $78 = $44 + $77;
  $79 = $46 - $15;
  $80 = $50 - $19;
  $81 = $54 - $23;
  $82 = $$sroa$0$0$copyload - $46;
  $83 = $$sroa$4$0$copyload - $50;
  $84 = $$sroa$5$0$copyload - $54;
  $85 = $80 * $84;
  $86 = $83 * $81;
  $87 = $85 - $86;
  $88 = $82 * $81;
  $89 = $79 * $84;
  $90 = $88 - $89;
  $91 = $79 * $83;
  $92 = $82 * $80;
  $93 = $91 - $92;
  $94 = $13 - $46;
  $95 = $17 - $50;
  $96 = $21 - $54;
  $97 = $94 * $87;
  $98 = $95 * $90;
  $99 = $97 + $98;
  $100 = $93 * $96;
  $101 = $100 + $99;
  $102 = (+Math_abs((+$101)));
  $103 = $78 + $102;
  $104 = $$01731 + $103;
  $105 = ($11>>>0)<($9>>>0);
  if ($105) {
   $$01731 = $104;$$032 = $11;$15 = $13;$19 = $17;$23 = $21;$48 = $46;$52 = $50;$56 = $54;
  } else {
   $$017$lcssa = $104;
   break;
  }
 }
 return (+$$017$lcssa);
}
function __ZN3osg20ShadowVolumeOccluder15computeOccluderERKNSt3__26vectorIPNS_4NodeENS1_9allocatorIS4_EEEERKNS_20ConvexPlanarOccluderERNS_9CullStackEb($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0 = 0, $$03$i = 0, $$03$i$i = 0, $$03$i112 = 0, $$1 = 0, $$10 = 0, $$1054 = 0, $$14 = 0, $$145 = 0, $$1458 = 0, $$4 = 0, $$448 = 0, $$7 = 0, $$751 = 0, $$8 = 0, $$852 = 0, $$pre$i = 0.0, $$pre$i$i$i = 0, $$pre$i$i111 = 0, $$pre$i98 = 0;
 var $$sink$i = 0, $$sink$i59 = 0, $$sroa$010$015$i = 0, $$sroa$010$015$i129 = 0, $$sroa$0154$0179 = 0, $$sroa$02$06$i = 0, $$sroa$02$06$i106 = 0, $$sroa$03$07$i = 0, $$sroa$03$07$i132 = 0, $$sroa$06$010$i = 0, $$sroa$06$010$i117 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0.0, $109 = 0.0, $11 = 0, $110 = 0.0, $111 = 0.0, $112 = 0.0, $113 = 0.0, $114 = 0.0, $115 = 0.0, $116 = 0.0, $117 = 0.0, $118 = 0.0, $119 = 0.0, $12 = 0, $120 = 0.0, $121 = 0.0, $122 = 0.0, $123 = 0.0, $124 = 0, $125 = 0.0;
 var $126 = 0.0, $127 = 0.0, $128 = 0, $129 = 0.0, $13 = 0, $130 = 0.0, $131 = 0.0, $132 = 0.0, $133 = 0, $134 = 0.0, $135 = 0.0, $136 = 0.0, $137 = 0.0, $138 = 0.0, $139 = 0.0, $14 = 0, $140 = 0.0, $141 = 0.0, $142 = 0.0, $143 = 0.0;
 var $144 = 0.0, $145 = 0.0, $146 = 0.0, $147 = 0.0, $148 = 0.0, $149 = 0.0, $15 = 0, $150 = 0.0, $151 = 0.0, $152 = 0.0, $153 = 0.0, $154 = 0.0, $155 = 0.0, $156 = 0.0, $157 = 0.0, $158 = 0.0, $159 = 0.0, $16 = 0, $160 = 0.0, $161 = 0.0;
 var $162 = 0.0, $163 = 0.0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0;
 var $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0;
 var $199 = 0, $20 = 0, $200 = 0.0, $201 = 0, $202 = 0.0, $203 = 0, $204 = 0, $205 = 0.0, $206 = 0, $207 = 0, $208 = 0.0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0;
 var $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0;
 var $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0;
 var $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0;
 var $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0.0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0.0, $287 = 0.0, $288 = 0, $289 = 0.0;
 var $29 = 0, $290 = 0.0, $291 = 0, $292 = 0.0, $293 = 0.0, $294 = 0, $295 = 0.0, $296 = 0.0, $297 = 0, $298 = 0, $299 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0;
 var $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0.0, $321 = 0, $322 = 0, $323 = 0.0, $324 = 0.0, $325 = 0;
 var $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0;
 var $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0;
 var $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0;
 var $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0;
 var $399 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0;
 var $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0.0, $425 = 0.0, $426 = 0.0, $427 = 0.0, $428 = 0.0, $429 = 0.0, $43 = 0, $430 = 0.0, $431 = 0.0, $432 = 0.0, $433 = 0.0, $434 = 0.0;
 var $435 = 0.0, $436 = 0.0, $437 = 0.0, $438 = 0.0, $439 = 0.0, $44 = 0.0, $440 = 0, $441 = 0.0, $442 = 0.0, $443 = 0.0, $444 = 0, $445 = 0.0, $446 = 0.0, $447 = 0.0, $448 = 0.0, $449 = 0, $45 = 0, $450 = 0.0, $451 = 0.0, $452 = 0.0;
 var $453 = 0.0, $454 = 0.0, $455 = 0.0, $456 = 0.0, $457 = 0.0, $458 = 0.0, $459 = 0.0, $46 = 0, $460 = 0.0, $461 = 0.0, $462 = 0.0, $463 = 0.0, $464 = 0.0, $465 = 0.0, $466 = 0.0, $467 = 0.0, $468 = 0.0, $469 = 0.0, $47 = 0.0, $470 = 0.0;
 var $471 = 0.0, $472 = 0.0, $473 = 0.0, $474 = 0.0, $475 = 0.0, $476 = 0.0, $477 = 0.0, $478 = 0.0, $479 = 0.0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0;
 var $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0.0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0;
 var $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0;
 var $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0.0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0.0, $542 = 0;
 var $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0.0, $548 = 0.0, $549 = 0, $55 = 0, $550 = 0.0, $551 = 0.0, $552 = 0, $553 = 0.0, $554 = 0.0, $555 = 0, $556 = 0.0, $557 = 0.0, $558 = 0, $559 = 0, $56 = 0, $560 = 0;
 var $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0;
 var $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0;
 var $598 = 0, $599 = 0, $6 = 0, $60 = 0.0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0.0, $607 = 0, $608 = 0, $609 = 0.0, $61 = 0, $610 = 0.0, $611 = 0.0, $612 = 0, $613 = 0, $614 = 0;
 var $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0;
 var $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0;
 var $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0;
 var $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i145 = 0, $scevgep$i$i$i$i135 = 0, $scevgep$i$i$i122 = 0, $scevgep$i$i$i3$i = 0, $scevgep$i$i$i3$i140 = 0, $scevgep$i$i$i60 = 0, $scevgep$i$i$i69 = 0, $scevgep$i$i$i74 = 0, $scevgep$i$i$i79 = 0, $scevgep$i$i$i84 = 0, $scevgep$i$i$i89 = 0, $scevgep5$i$i$i = 0, $scevgep5$i$i$i$i = 0;
 var $scevgep5$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i146 = 0, $scevgep5$i$i$i$i136 = 0, $scevgep5$i$i$i123 = 0, $scevgep5$i$i$i4$i = 0, $scevgep5$i$i$i4$i141 = 0, $scevgep5$i$i$i61 = 0, $scevgep5$i$i$i70 = 0, $scevgep5$i$i$i75 = 0, $scevgep5$i$i$i80 = 0, $scevgep5$i$i$i85 = 0, $scevgep5$i$i$i90 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 448|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(448|0);
 $5 = sp + 208|0;
 $6 = sp + 80|0;
 $7 = sp + 424|0;
 $8 = sp + 412|0;
 $9 = sp + 40|0;
 $10 = sp + 400|0;
 $11 = sp + 352|0;
 $12 = sp + 336|0;
 $13 = sp;
 $14 = ((($3)) + 280|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ((($3)) + 112|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==(0);
 $19 = ((($3)) + 96|0);
 $20 = ((($3)) + 296|0);
 $$sink$i = $18 ? $20 : $19;
 $21 = HEAP32[$$sink$i>>2]|0;
 $22 = ((($3)) + 92|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)==(0);
 $25 = ((($3)) + 76|0);
 $$sink$i59 = $24 ? $20 : $25;
 $26 = HEAP32[$$sink$i59>>2]|0;
 $27 = ((($0)) + 4|0);
 $28 = ($27|0)==($1|0);
 if (!($28)) {
  $29 = HEAP32[$1>>2]|0;
  $30 = ((($1)) + 4|0);
  $31 = HEAP32[$30>>2]|0;
  __ZNSt3__26vectorIPN3osg4NodeENS_9allocatorIS3_EEE6assignIPS3_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS3_NS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_($27,$29,$31);
 }
 $32 = ((($0)) + 16|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ($33|0)==($26|0);
 if (!($34)) {
  HEAP32[$32>>2] = $26;
  $35 = ($26|0)==(0|0);
  if (!($35)) {
   $36 = ((($26)) + 8|0);
   $37 = HEAP32[$36>>2]|0;HEAP32[$36>>2] = (($37+1)|0);
  }
  $38 = ($33|0)==(0|0);
  if (!($38)) {
   $39 = ((($33)) + 8|0);
   $40 = HEAP32[$39>>2]|0;HEAP32[$39>>2] = (($40-1)|0);
   $41 = ($40|0)==(1);
   if ($41) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($33,1,1);
   }
  }
 }
 HEAPF32[$0>>2] = 0.0;
 __ZN3osg7Matrixd12makeIdentityEv($5);
 $42 = ((($26)) + 32|0);
 $43 = ((($26)) + 56|0);
 $44 = +HEAPF64[$43>>3];
 $45 = $44 == 0.0;
 if ($45) {
  $46 = ((($26)) + 88|0);
  $47 = +HEAPF64[$46>>3];
  $48 = $47 == 0.0;
  if ($48) {
   $49 = ((($26)) + 120|0);
   $50 = +HEAPF64[$49>>3];
   $51 = $50 == 0.0;
   if ($51) {
    $52 = ((($26)) + 152|0);
    $53 = +HEAPF64[$52>>3];
    $54 = $53 == 1.0;
    if ($54) {
     __THREW__ = 0;
     (invoke_iii(3303,($5|0),($42|0))|0);
     $55 = __THREW__; __THREW__ = 0;
     $56 = $55&1;
     if (!($56)) {
      label = 15;
     }
    } else {
     label = 14;
    }
   } else {
    label = 14;
   }
  } else {
   label = 14;
  }
 } else {
  label = 14;
 }
 if ((label|0) == 14) {
  __THREW__ = 0;
  (invoke_iii(3304,($5|0),($42|0))|0);
  $57 = __THREW__; __THREW__ = 0;
  $58 = $57&1;
  if (!($58)) {
   label = 15;
  }
 }
 do {
  if ((label|0) == 15) {
   $59 = ((($3)) + 284|0);
   $60 = +HEAPF32[$59>>2];
   $61 = $60 < 0.0;
   if ($61) {
    __THREW__ = 0;
    invoke_vi(3900,($3|0));
    $62 = __THREW__; __THREW__ = 0;
    $63 = $62&1;
    if ($63) {
     break;
    }
    $$pre$i = +HEAPF32[$59>>2];
    $324 = $$pre$i;
   } else {
    $324 = $60;
   }
   $64 = ((($21)) + 32|0);
   __THREW__ = 0;
   invoke_vi(3299,($6|0));
   $65 = __THREW__; __THREW__ = 0;
   $66 = $65&1;
   if (!($66)) {
    __THREW__ = 0;
    invoke_viii(3300,($6|0),($64|0),($42|0));
    $67 = __THREW__; __THREW__ = 0;
    $68 = $67&1;
    if (!($68)) {
     $69 = ((($2)) + 32|0);
     HEAP32[$7>>2] = 0;
     $70 = ((($7)) + 4|0);
     HEAP32[$70>>2] = 0;
     $71 = ((($7)) + 8|0);
     HEAP32[$71>>2] = 0;
     $72 = ((($15)) + 40|0);
     __THREW__ = 0;
     $73 = (invoke_iiii(3901,($72|0),($69|0),($7|0))|0);
     $74 = __THREW__; __THREW__ = 0;
     $75 = $74&1;
     L28: do {
      if ($75) {
       $314 = ___cxa_find_matching_catch_2()|0;
       $315 = tempRet0;
       $$10 = $314;$$1054 = $315;
      } else {
       $76 = ($73>>>0)>(2);
       L31: do {
        if ($76) {
         HEAP32[$8>>2] = 0;
         $77 = ((($8)) + 4|0);
         HEAP32[$77>>2] = 0;
         $78 = ((($8)) + 8|0);
         HEAP32[$78>>2] = 0;
         $79 = HEAP32[$70>>2]|0;
         $80 = HEAP32[$7>>2]|0;
         $81 = (($79) - ($80))|0;
         $82 = $81 >> 4;
         __THREW__ = 0;
         invoke_vii(3898,($8|0),($82|0));
         $83 = __THREW__; __THREW__ = 0;
         $84 = $83&1;
         L33: do {
          if ($84) {
           label = 65;
          } else {
           __THREW__ = 0;
           invoke_viii(3902,($7|0),($8|0),($6|0));
           $85 = __THREW__; __THREW__ = 0;
           $86 = $85&1;
           if ($86) {
            label = 65;
           } else {
            $87 = HEAP32[$8>>2]|0;
            $88 = HEAP32[$77>>2]|0;
            $89 = ($87|0)==($88|0);
            if (!($89)) {
             $$sroa$03$07$i = $87;
             while(1) {
              $90 = ((($$sroa$03$07$i)) + 12|0);
              HEAPF32[$90>>2] = 1.0;
              $91 = ((($$sroa$03$07$i)) + 16|0);
              $92 = ($91|0)==($88|0);
              if ($92) {
               break;
              } else {
               $$sroa$03$07$i = $91;
              }
             }
             if (!($89)) {
              $93 = ((($5)) + 24|0);
              $94 = ((($5)) + 56|0);
              $95 = ((($5)) + 88|0);
              $96 = ((($5)) + 120|0);
              $97 = ((($5)) + 32|0);
              $98 = ((($5)) + 64|0);
              $99 = ((($5)) + 96|0);
              $100 = ((($5)) + 8|0);
              $101 = ((($5)) + 40|0);
              $102 = ((($5)) + 72|0);
              $103 = ((($5)) + 104|0);
              $104 = ((($5)) + 16|0);
              $105 = ((($5)) + 48|0);
              $106 = ((($5)) + 80|0);
              $107 = ((($5)) + 112|0);
              $108 = +HEAPF64[$93>>3];
              $109 = +HEAPF64[$94>>3];
              $110 = +HEAPF64[$95>>3];
              $111 = +HEAPF64[$96>>3];
              $112 = +HEAPF64[$5>>3];
              $113 = +HEAPF64[$97>>3];
              $114 = +HEAPF64[$98>>3];
              $115 = +HEAPF64[$99>>3];
              $116 = +HEAPF64[$100>>3];
              $117 = +HEAPF64[$101>>3];
              $118 = +HEAPF64[$102>>3];
              $119 = +HEAPF64[$103>>3];
              $120 = +HEAPF64[$104>>3];
              $121 = +HEAPF64[$105>>3];
              $122 = +HEAPF64[$106>>3];
              $123 = +HEAPF64[$107>>3];
              $$sroa$010$015$i = $87;
              while(1) {
               $124 = ((($$sroa$010$015$i)) + 4|0);
               $125 = +HEAPF32[$124>>2];
               $126 = $125;
               $127 = $108 * $126;
               $128 = ((($$sroa$010$015$i)) + 8|0);
               $129 = +HEAPF32[$128>>2];
               $130 = $129;
               $131 = $109 * $130;
               $132 = $127 + $131;
               $133 = ((($$sroa$010$015$i)) + 12|0);
               $134 = +HEAPF32[$133>>2];
               $135 = $134;
               $136 = $110 * $135;
               $137 = $132 + $136;
               $138 = $111 + $137;
               $139 = 1.0 / $138;
               $140 = $112 * $126;
               $141 = $113 * $130;
               $142 = $140 + $141;
               $143 = $114 * $135;
               $144 = $142 + $143;
               $145 = $115 + $144;
               $146 = $145 * $139;
               $147 = $146;
               $148 = $116 * $126;
               $149 = $117 * $130;
               $150 = $148 + $149;
               $151 = $118 * $135;
               $152 = $150 + $151;
               $153 = $119 + $152;
               $154 = $153 * $139;
               $155 = $154;
               $156 = $120 * $126;
               $157 = $121 * $130;
               $158 = $156 + $157;
               $159 = $122 * $135;
               $160 = $158 + $159;
               $161 = $123 + $160;
               $162 = $161 * $139;
               $163 = $162;
               HEAPF32[$124>>2] = $147;
               HEAPF32[$128>>2] = $155;
               HEAPF32[$133>>2] = $163;
               $164 = ((($$sroa$010$015$i)) + 16|0);
               $165 = HEAP32[$77>>2]|0;
               $166 = ($164|0)==($165|0);
               if ($166) {
                break;
               } else {
                $$sroa$010$015$i = $164;
               }
              }
             }
            }
            __THREW__ = 0;
            invoke_vii(3903,($7|0),($64|0));
            $167 = __THREW__; __THREW__ = 0;
            $168 = $167&1;
            if ($168) {
             label = 65;
            } else {
             $169 = ((($0)) + 56|0);
             $170 = HEAP32[$70>>2]|0;
             $171 = HEAP32[$7>>2]|0;
             $172 = (($170) - ($171))|0;
             $173 = $172 >> 4;
             __THREW__ = 0;
             invoke_vii(3904,($169|0),($173|0));
             $174 = __THREW__; __THREW__ = 0;
             $175 = $174&1;
             if ($175) {
              label = 65;
             } else {
              $176 = HEAP32[$7>>2]|0;
              $177 = HEAP32[$70>>2]|0;
              $178 = ($176|0)==($177|0);
              if (!($178)) {
               $179 = ((($0)) + 60|0);
               $180 = ((($0)) + 64|0);
               $$sroa$06$010$i = $176;
               while(1) {
                $181 = ((($$sroa$06$010$i)) + 4|0);
                $182 = HEAP32[$179>>2]|0;
                $183 = HEAP32[$180>>2]|0;
                $184 = ($182|0)==($183|0);
                if ($184) {
                 __THREW__ = 0;
                 invoke_vii(3736,($169|0),($181|0));
                 $187 = __THREW__; __THREW__ = 0;
                 $188 = $187&1;
                 if ($188) {
                  label = 65;
                  break L33;
                 }
                } else {
                 ;HEAP32[$182>>2]=HEAP32[$181>>2]|0;HEAP32[$182+4>>2]=HEAP32[$181+4>>2]|0;HEAP32[$182+8>>2]=HEAP32[$181+8>>2]|0;
                 $185 = HEAP32[$179>>2]|0;
                 $186 = ((($185)) + 12|0);
                 HEAP32[$179>>2] = $186;
                }
                $189 = ((($$sroa$06$010$i)) + 16|0);
                $190 = HEAP32[$70>>2]|0;
                $191 = ($189|0)==($190|0);
                if ($191) {
                 break;
                } else {
                 $$sroa$06$010$i = $189;
                }
               }
              }
              __THREW__ = 0;
              invoke_vii(3905,($9|0),($7|0));
              $192 = __THREW__; __THREW__ = 0;
              $193 = $192&1;
              if ($193) {
               label = 65;
              } else {
               $194 = ((($0)) + 44|0);
               $195 = ((($0)) + 48|0);
               $196 = HEAP32[$195>>2]|0;
               $197 = ((($0)) + 52|0);
               $198 = HEAP32[$197>>2]|0;
               $199 = ($196|0)==($198|0);
               do {
                if ($199) {
                 __THREW__ = 0;
                 invoke_vii(3906,($194|0),($9|0));
                 $223 = __THREW__; __THREW__ = 0;
                 $224 = $223&1;
                 if ($224) {
                  label = 66;
                  break;
                 }
                 $$pre$i98 = HEAP32[$195>>2]|0;
                 $227 = $$pre$i98;
                 label = 42;
                } else {
                 $200 = +HEAPF64[$9>>3];
                 HEAPF64[$196>>3] = $200;
                 $201 = ((($9)) + 8|0);
                 $202 = +HEAPF64[$201>>3];
                 $203 = ((($196)) + 8|0);
                 HEAPF64[$203>>3] = $202;
                 $204 = ((($9)) + 16|0);
                 $205 = +HEAPF64[$204>>3];
                 $206 = ((($196)) + 16|0);
                 HEAPF64[$206>>3] = $205;
                 $207 = ((($9)) + 24|0);
                 $208 = +HEAPF64[$207>>3];
                 $209 = ((($196)) + 24|0);
                 HEAPF64[$209>>3] = $208;
                 $210 = $200 >= 0.0;
                 $211 = $210&1;
                 $212 = $202 >= 0.0;
                 $213 = $212 ? 2 : 0;
                 $214 = $213 | $211;
                 $215 = $205 >= 0.0;
                 $216 = $215 ? 4 : 0;
                 $217 = $214 | $216;
                 $218 = ((($196)) + 32|0);
                 HEAP32[$218>>2] = $217;
                 $219 = $217 ^ 7;
                 $220 = ((($196)) + 36|0);
                 HEAP32[$220>>2] = $219;
                 $221 = ((($196)) + 40|0);
                 HEAP32[$195>>2] = $221;
                 $222 = $221;
                 $227 = $222;
                 label = 42;
                }
               } while(0);
               L60: do {
                if ((label|0) == 42) {
                 $225 = ((($0)) + 40|0);
                 HEAP32[$225>>2] = 0;
                 $226 = HEAP32[$194>>2]|0;
                 $228 = ($227|0)==($226|0);
                 if (!($228)) {
                  $229 = (($227) - ($226))|0;
                  $230 = (($229|0) / 40)&-1;
                  $$03$i$i = 0;$246 = 0;
                  while(1) {
                   $245 = $246 << 1;
                   $231 = $245 | 1;
                   $247 = (($$03$i$i) + 1)|0;
                   $248 = ($247>>>0)<($230>>>0);
                   if ($248) {
                    $$03$i$i = $247;$246 = $231;
                   } else {
                    break;
                   }
                  }
                  HEAP32[$225>>2] = $231;
                 }
                 $232 = ((($0)) + 36|0);
                 $233 = HEAP32[$232>>2]|0;
                 $234 = ($233|0)==(0);
                 $$pre$i$i$i = ((($0)) + 20|0);
                 do {
                  if (!($234)) {
                   $235 = ((($0)) + 28|0);
                   $236 = HEAP32[$235>>2]|0;
                   $237 = ((($0)) + 32|0);
                   $238 = HEAP32[$237>>2]|0;
                   $239 = ($236|0)==($238|0);
                   if ($239) {
                    $242 = ((($0)) + 24|0);
                    __THREW__ = 0;
                    invoke_vii(3437,($242|0),($$pre$i$i$i|0));
                    $243 = __THREW__; __THREW__ = 0;
                    $244 = $243&1;
                    if ($244) {
                     label = 66;
                     break L60;
                    } else {
                     break;
                    }
                   } else {
                    $240 = HEAP32[$$pre$i$i$i>>2]|0;
                    HEAP32[$236>>2] = $240;
                    $241 = ((($236)) + 4|0);
                    HEAP32[$235>>2] = $241;
                    break;
                   }
                  }
                 } while(0);
                 $249 = HEAP32[$225>>2]|0;
                 HEAP32[$$pre$i$i$i>>2] = $249;
                 $250 = HEAP32[$232>>2]|0;
                 $251 = (($250) + 1)|0;
                 HEAP32[$232>>2] = $251;
                 __THREW__ = 0;
                 invoke_viii(3907,($7|0),($8|0),($194|0));
                 $252 = __THREW__; __THREW__ = 0;
                 $253 = $252&1;
                 if ($253) {
                  label = 66;
                  break;
                 }
                 HEAP32[$225>>2] = 0;
                 $254 = HEAP32[$195>>2]|0;
                 $255 = HEAP32[$194>>2]|0;
                 $256 = ($254|0)==($255|0);
                 if (!($256)) {
                  $257 = (($254) - ($255))|0;
                  $258 = (($257|0) / 40)&-1;
                  $$03$i = 0;$273 = 0;
                  while(1) {
                   $272 = $273 << 1;
                   $259 = $272 | 1;
                   $274 = (($$03$i) + 1)|0;
                   $275 = ($274>>>0)<($258>>>0);
                   if ($275) {
                    $$03$i = $274;$273 = $259;
                   } else {
                    break;
                   }
                  }
                  HEAP32[$225>>2] = $259;
                 }
                 $260 = HEAP32[$232>>2]|0;
                 $261 = ($260|0)==(0);
                 do {
                  if (!($261)) {
                   $262 = ((($0)) + 28|0);
                   $263 = HEAP32[$262>>2]|0;
                   $264 = ((($0)) + 32|0);
                   $265 = HEAP32[$264>>2]|0;
                   $266 = ($263|0)==($265|0);
                   if ($266) {
                    $269 = ((($0)) + 24|0);
                    __THREW__ = 0;
                    invoke_vii(3437,($269|0),($$pre$i$i$i|0));
                    $270 = __THREW__; __THREW__ = 0;
                    $271 = $270&1;
                    if ($271) {
                     label = 66;
                     break L60;
                    } else {
                     break;
                    }
                   } else {
                    $267 = HEAP32[$$pre$i$i$i>>2]|0;
                    HEAP32[$263>>2] = $267;
                    $268 = ((($263)) + 4|0);
                    HEAP32[$262>>2] = $268;
                    break;
                   }
                  }
                 } while(0);
                 $276 = HEAP32[$225>>2]|0;
                 HEAP32[$$pre$i$i$i>>2] = $276;
                 $277 = HEAP32[$232>>2]|0;
                 $278 = (($277) + 1)|0;
                 HEAP32[$232>>2] = $278;
                 $279 = ((($9)) + 24|0);
                 $280 = +HEAPF64[$279>>3];
                 $281 = $280 > 0.0;
                 do {
                  if ($281) {
                   $282 = ((($0)) + 44|0);
                   $283 = HEAP32[$282>>2]|0;
                   $284 = HEAP32[$195>>2]|0;
                   $285 = ($283|0)==($284|0);
                   if ($285) {
                    break;
                   } else {
                    $$sroa$02$06$i = $283;
                   }
                   while(1) {
                    $286 = +HEAPF64[$$sroa$02$06$i>>3];
                    $287 = -$286;
                    HEAPF64[$$sroa$02$06$i>>3] = $287;
                    $288 = ((($$sroa$02$06$i)) + 8|0);
                    $289 = +HEAPF64[$288>>3];
                    $290 = -$289;
                    HEAPF64[$288>>3] = $290;
                    $291 = ((($$sroa$02$06$i)) + 16|0);
                    $292 = +HEAPF64[$291>>3];
                    $293 = -$292;
                    HEAPF64[$291>>3] = $293;
                    $294 = ((($$sroa$02$06$i)) + 24|0);
                    $295 = +HEAPF64[$294>>3];
                    $296 = -$295;
                    HEAPF64[$294>>3] = $296;
                    $297 = $286 <= -0.0;
                    $298 = $297&1;
                    $299 = $289 <= -0.0;
                    $300 = $299 ? 2 : 0;
                    $301 = $300 | $298;
                    $302 = $292 <= -0.0;
                    $303 = $302 ? 4 : 0;
                    $304 = $301 | $303;
                    $305 = ((($$sroa$02$06$i)) + 32|0);
                    HEAP32[$305>>2] = $304;
                    $306 = $304 ^ 7;
                    $307 = ((($$sroa$02$06$i)) + 36|0);
                    HEAP32[$307>>2] = $306;
                    $308 = ((($$sroa$02$06$i)) + 40|0);
                    $309 = ($308|0)==($284|0);
                    if ($309) {
                     break;
                    } else {
                     $$sroa$02$06$i = $308;
                    }
                   }
                  }
                 } while(0);
                 __THREW__ = 0;
                 $320 = (+invoke_dii(3908,($7|0),($8|0)));
                 $321 = __THREW__; __THREW__ = 0;
                 $322 = $321&1;
                 if ($322) {
                  label = 66;
                  break;
                 }
                 $323 = $320 / $324;
                 HEAPF32[$0>>2] = $323;
                 $325 = ((($2)) + 44|0);
                 $326 = HEAP32[$325>>2]|0;
                 $327 = ((($2)) + 48|0);
                 $328 = HEAP32[$327>>2]|0;
                 $329 = ($326|0)==($328|0);
                 L93: do {
                  if (!($329)) {
                   $330 = ((($10)) + 4|0);
                   $331 = ((($10)) + 8|0);
                   $332 = ((($11)) + 16|0);
                   $333 = ((($0)) + 72|0);
                   $334 = ((($0)) + 76|0);
                   $335 = ((($0)) + 68|0);
                   $336 = ((($11)) + 36|0);
                   $337 = ((($11)) + 24|0);
                   $338 = ((($11)) + 4|0);
                   $339 = ((($12)) + 4|0);
                   $340 = ((($12)) + 8|0);
                   $341 = ((($13)) + 24|0);
                   $342 = ((($5)) + 24|0);
                   $343 = ((($5)) + 56|0);
                   $344 = ((($5)) + 88|0);
                   $345 = ((($5)) + 120|0);
                   $346 = ((($5)) + 32|0);
                   $347 = ((($5)) + 64|0);
                   $348 = ((($5)) + 96|0);
                   $349 = ((($5)) + 8|0);
                   $350 = ((($5)) + 40|0);
                   $351 = ((($5)) + 72|0);
                   $352 = ((($5)) + 104|0);
                   $353 = ((($5)) + 16|0);
                   $354 = ((($5)) + 48|0);
                   $355 = ((($5)) + 80|0);
                   $356 = ((($5)) + 112|0);
                   $357 = ((($11)) + 8|0);
                   $358 = ((($11)) + 28|0);
                   $359 = ((($11)) + 40|0);
                   $$sroa$0154$0179 = $326;
                   L95: while(1) {
                    HEAP32[$10>>2] = 0;
                    HEAP32[$330>>2] = 0;
                    HEAP32[$331>>2] = 0;
                    __THREW__ = 0;
                    $369 = (invoke_iiii(3901,($72|0),($$sroa$0154$0179|0),($10|0))|0);
                    $370 = __THREW__; __THREW__ = 0;
                    $371 = $370&1;
                    if ($371) {
                     label = 120;
                     break;
                    }
                    $372 = ($369>>>0)>(2);
                    if ($372) {
                     dest=$11; stop=dest+48|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
                     HEAP32[$332>>2] = 1;
                     $373 = HEAP32[$333>>2]|0;
                     $374 = HEAP32[$334>>2]|0;
                     $375 = ($373|0)==($374|0);
                     if ($375) {
                      __THREW__ = 0;
                      invoke_vii(3909,($335|0),($11|0));
                      $380 = __THREW__; __THREW__ = 0;
                      $381 = $380&1;
                      if ($381) {
                       label = 121;
                       break;
                      }
                     } else {
                      __THREW__ = 0;
                      invoke_vii(3596,($373|0),($11|0));
                      $376 = __THREW__; __THREW__ = 0;
                      $377 = $376&1;
                      if ($377) {
                       label = 121;
                       break;
                      }
                      $378 = HEAP32[$333>>2]|0;
                      $379 = ((($378)) + 48|0);
                      HEAP32[$333>>2] = $379;
                     }
                     $382 = HEAP32[$336>>2]|0;
                     $383 = ($382|0)==(0|0);
                     if (!($383)) {
                      $384 = HEAP32[$359>>2]|0;
                      $385 = ($384|0)==($382|0);
                      if (!($385)) {
                       $scevgep$i$i$i$i135 = ((($384)) + -12|0);
                       $386 = $scevgep$i$i$i$i135;
                       $387 = $382;
                       $388 = (($386) - ($387))|0;
                       $389 = (($388>>>0) / 12)&-1;
                       $390 = $389 ^ -1;
                       $scevgep5$i$i$i$i136 = (($384) + (($390*12)|0)|0);
                       HEAP32[$359>>2] = $scevgep5$i$i$i$i136;
                      }
                      __ZdlPv($382);
                     }
                     $391 = HEAP32[$337>>2]|0;
                     $392 = ($391|0)==(0|0);
                     if (!($392)) {
                      $393 = HEAP32[$358>>2]|0;
                      $394 = ($393|0)==($391|0);
                      if (!($394)) {
                       $scevgep$i$i$i3$i140 = ((($393)) + -40|0);
                       $395 = $scevgep$i$i$i3$i140;
                       $396 = $391;
                       $397 = (($395) - ($396))|0;
                       $398 = (($397>>>0) / 40)&-1;
                       $399 = $398 ^ -1;
                       $scevgep5$i$i$i4$i141 = (($393) + (($399*40)|0)|0);
                       HEAP32[$358>>2] = $scevgep5$i$i$i4$i141;
                      }
                      __ZdlPv($391);
                     }
                     $400 = HEAP32[$338>>2]|0;
                     $401 = ($400|0)==(0|0);
                     if (!($401)) {
                      $402 = HEAP32[$357>>2]|0;
                      $403 = ($402|0)==($400|0);
                      if (!($403)) {
                       $scevgep$i$i$i$i$i145 = ((($402)) + -4|0);
                       $404 = $scevgep$i$i$i$i$i145;
                       $405 = $400;
                       $406 = (($404) - ($405))|0;
                       $407 = $406 >>> 2;
                       $408 = $407 ^ -1;
                       $scevgep5$i$i$i$i$i146 = (($402) + ($408<<2)|0);
                       HEAP32[$357>>2] = $scevgep5$i$i$i$i$i146;
                      }
                      __ZdlPv($400);
                     }
                     $409 = HEAP32[$333>>2]|0;
                     HEAP32[$12>>2] = 0;
                     HEAP32[$339>>2] = 0;
                     HEAP32[$340>>2] = 0;
                     $410 = HEAP32[$330>>2]|0;
                     $411 = HEAP32[$10>>2]|0;
                     $412 = (($410) - ($411))|0;
                     $413 = $412 >> 4;
                     __THREW__ = 0;
                     invoke_vii(3898,($12|0),($413|0));
                     $414 = __THREW__; __THREW__ = 0;
                     $415 = $414&1;
                     if ($415) {
                      label = 134;
                      break;
                     }
                     __THREW__ = 0;
                     invoke_viii(3902,($10|0),($12|0),($6|0));
                     $416 = __THREW__; __THREW__ = 0;
                     $417 = $416&1;
                     if ($417) {
                      label = 134;
                      break;
                     }
                     $418 = HEAP32[$12>>2]|0;
                     $419 = HEAP32[$339>>2]|0;
                     $420 = ($418|0)==($419|0);
                     do {
                      if (!($420)) {
                       $$sroa$03$07$i132 = $418;
                       while(1) {
                        $421 = ((($$sroa$03$07$i132)) + 12|0);
                        HEAPF32[$421>>2] = 1.0;
                        $422 = ((($$sroa$03$07$i132)) + 16|0);
                        $423 = ($422|0)==($419|0);
                        if ($423) {
                         break;
                        } else {
                         $$sroa$03$07$i132 = $422;
                        }
                       }
                       if ($420) {
                        break;
                       }
                       $424 = +HEAPF64[$342>>3];
                       $425 = +HEAPF64[$343>>3];
                       $426 = +HEAPF64[$344>>3];
                       $427 = +HEAPF64[$345>>3];
                       $428 = +HEAPF64[$5>>3];
                       $429 = +HEAPF64[$346>>3];
                       $430 = +HEAPF64[$347>>3];
                       $431 = +HEAPF64[$348>>3];
                       $432 = +HEAPF64[$349>>3];
                       $433 = +HEAPF64[$350>>3];
                       $434 = +HEAPF64[$351>>3];
                       $435 = +HEAPF64[$352>>3];
                       $436 = +HEAPF64[$353>>3];
                       $437 = +HEAPF64[$354>>3];
                       $438 = +HEAPF64[$355>>3];
                       $439 = +HEAPF64[$356>>3];
                       $$sroa$010$015$i129 = $418;
                       while(1) {
                        $440 = ((($$sroa$010$015$i129)) + 4|0);
                        $441 = +HEAPF32[$440>>2];
                        $442 = $441;
                        $443 = $424 * $442;
                        $444 = ((($$sroa$010$015$i129)) + 8|0);
                        $445 = +HEAPF32[$444>>2];
                        $446 = $445;
                        $447 = $425 * $446;
                        $448 = $443 + $447;
                        $449 = ((($$sroa$010$015$i129)) + 12|0);
                        $450 = +HEAPF32[$449>>2];
                        $451 = $450;
                        $452 = $426 * $451;
                        $453 = $448 + $452;
                        $454 = $427 + $453;
                        $455 = 1.0 / $454;
                        $456 = $428 * $442;
                        $457 = $429 * $446;
                        $458 = $456 + $457;
                        $459 = $430 * $451;
                        $460 = $458 + $459;
                        $461 = $431 + $460;
                        $462 = $461 * $455;
                        $463 = $462;
                        $464 = $432 * $442;
                        $465 = $433 * $446;
                        $466 = $464 + $465;
                        $467 = $434 * $451;
                        $468 = $466 + $467;
                        $469 = $435 + $468;
                        $470 = $469 * $455;
                        $471 = $470;
                        $472 = $436 * $442;
                        $473 = $437 * $446;
                        $474 = $472 + $473;
                        $475 = $438 * $451;
                        $476 = $474 + $475;
                        $477 = $439 + $476;
                        $478 = $477 * $455;
                        $479 = $478;
                        HEAPF32[$440>>2] = $463;
                        HEAPF32[$444>>2] = $471;
                        HEAPF32[$449>>2] = $479;
                        $480 = ((($$sroa$010$015$i129)) + 16|0);
                        $481 = HEAP32[$339>>2]|0;
                        $482 = ($480|0)==($481|0);
                        if ($482) {
                         break;
                        } else {
                         $$sroa$010$015$i129 = $480;
                        }
                       }
                      }
                     } while(0);
                     __THREW__ = 0;
                     invoke_vii(3903,($10|0),($64|0));
                     $483 = __THREW__; __THREW__ = 0;
                     $484 = $483&1;
                     if ($484) {
                      label = 134;
                      break;
                     }
                     $485 = ((($409)) + -12|0);
                     $486 = HEAP32[$330>>2]|0;
                     $487 = HEAP32[$10>>2]|0;
                     $488 = (($486) - ($487))|0;
                     $489 = $488 >> 4;
                     __THREW__ = 0;
                     invoke_vii(3904,($485|0),($489|0));
                     $490 = __THREW__; __THREW__ = 0;
                     $491 = $490&1;
                     if ($491) {
                      label = 134;
                      break;
                     }
                     $492 = HEAP32[$10>>2]|0;
                     $493 = HEAP32[$330>>2]|0;
                     $494 = ($492|0)==($493|0);
                     if (!($494)) {
                      $495 = ((($409)) + -8|0);
                      $496 = ((($409)) + -4|0);
                      $$sroa$06$010$i117 = $492;
                      while(1) {
                       $497 = ((($$sroa$06$010$i117)) + 4|0);
                       $498 = HEAP32[$495>>2]|0;
                       $499 = HEAP32[$496>>2]|0;
                       $500 = ($498|0)==($499|0);
                       if ($500) {
                        __THREW__ = 0;
                        invoke_vii(3736,($485|0),($497|0));
                        $503 = __THREW__; __THREW__ = 0;
                        $504 = $503&1;
                        if ($504) {
                         label = 134;
                         break L95;
                        }
                       } else {
                        ;HEAP32[$498>>2]=HEAP32[$497>>2]|0;HEAP32[$498+4>>2]=HEAP32[$497+4>>2]|0;HEAP32[$498+8>>2]=HEAP32[$497+8>>2]|0;
                        $501 = HEAP32[$495>>2]|0;
                        $502 = ((($501)) + 12|0);
                        HEAP32[$495>>2] = $502;
                       }
                       $505 = ((($$sroa$06$010$i117)) + 16|0);
                       $506 = HEAP32[$330>>2]|0;
                       $507 = ($505|0)==($506|0);
                       if ($507) {
                        break;
                       } else {
                        $$sroa$06$010$i117 = $505;
                       }
                      }
                     }
                     __THREW__ = 0;
                     invoke_vii(3905,($13|0),($10|0));
                     $508 = __THREW__; __THREW__ = 0;
                     $509 = $508&1;
                     if ($509) {
                      label = 134;
                      break;
                     }
                     $510 = ((($409)) + -24|0);
                     __THREW__ = 0;
                     invoke_viii(3907,($10|0),($12|0),($510|0));
                     $511 = __THREW__; __THREW__ = 0;
                     $512 = $511&1;
                     if ($512) {
                      label = 135;
                      break;
                     }
                     $513 = ((($409)) + -28|0);
                     HEAP32[$513>>2] = 0;
                     $514 = ((($409)) + -20|0);
                     $515 = HEAP32[$514>>2]|0;
                     $516 = HEAP32[$510>>2]|0;
                     $517 = ($515|0)==($516|0);
                     if (!($517)) {
                      $518 = (($515) - ($516))|0;
                      $519 = (($518|0) / 40)&-1;
                      $$03$i112 = 0;$535 = 0;
                      while(1) {
                       $534 = $535 << 1;
                       $520 = $534 | 1;
                       $536 = (($$03$i112) + 1)|0;
                       $537 = ($536>>>0)<($519>>>0);
                       if ($537) {
                        $$03$i112 = $536;$535 = $520;
                       } else {
                        break;
                       }
                      }
                      HEAP32[$513>>2] = $520;
                     }
                     $521 = ((($409)) + -32|0);
                     $522 = HEAP32[$521>>2]|0;
                     $523 = ($522|0)==(0);
                     $$pre$i$i111 = ((($409)) + -48|0);
                     do {
                      if (!($523)) {
                       $524 = ((($409)) + -40|0);
                       $525 = HEAP32[$524>>2]|0;
                       $526 = ((($409)) + -36|0);
                       $527 = HEAP32[$526>>2]|0;
                       $528 = ($525|0)==($527|0);
                       if ($528) {
                        $531 = ((($409)) + -44|0);
                        __THREW__ = 0;
                        invoke_vii(3437,($531|0),($$pre$i$i111|0));
                        $532 = __THREW__; __THREW__ = 0;
                        $533 = $532&1;
                        if ($533) {
                         label = 135;
                         break L95;
                        } else {
                         break;
                        }
                       } else {
                        $529 = HEAP32[$$pre$i$i111>>2]|0;
                        HEAP32[$525>>2] = $529;
                        $530 = ((($525)) + 4|0);
                        HEAP32[$524>>2] = $530;
                        break;
                       }
                      }
                     } while(0);
                     $538 = HEAP32[$513>>2]|0;
                     HEAP32[$$pre$i$i111>>2] = $538;
                     $539 = HEAP32[$521>>2]|0;
                     $540 = (($539) + 1)|0;
                     HEAP32[$521>>2] = $540;
                     $541 = +HEAPF64[$341>>3];
                     $542 = $541 > 0.0;
                     do {
                      if ($542) {
                       $543 = ((($409)) + -24|0);
                       $544 = HEAP32[$543>>2]|0;
                       $545 = HEAP32[$514>>2]|0;
                       $546 = ($544|0)==($545|0);
                       if ($546) {
                        break;
                       } else {
                        $$sroa$02$06$i106 = $544;
                       }
                       while(1) {
                        $547 = +HEAPF64[$$sroa$02$06$i106>>3];
                        $548 = -$547;
                        HEAPF64[$$sroa$02$06$i106>>3] = $548;
                        $549 = ((($$sroa$02$06$i106)) + 8|0);
                        $550 = +HEAPF64[$549>>3];
                        $551 = -$550;
                        HEAPF64[$549>>3] = $551;
                        $552 = ((($$sroa$02$06$i106)) + 16|0);
                        $553 = +HEAPF64[$552>>3];
                        $554 = -$553;
                        HEAPF64[$552>>3] = $554;
                        $555 = ((($$sroa$02$06$i106)) + 24|0);
                        $556 = +HEAPF64[$555>>3];
                        $557 = -$556;
                        HEAPF64[$555>>3] = $557;
                        $558 = $547 <= -0.0;
                        $559 = $558&1;
                        $560 = $550 <= -0.0;
                        $561 = $560 ? 2 : 0;
                        $562 = $561 | $559;
                        $563 = $553 <= -0.0;
                        $564 = $563 ? 4 : 0;
                        $565 = $562 | $564;
                        $566 = ((($$sroa$02$06$i106)) + 32|0);
                        HEAP32[$566>>2] = $565;
                        $567 = $565 ^ 7;
                        $568 = ((($$sroa$02$06$i106)) + 36|0);
                        HEAP32[$568>>2] = $567;
                        $569 = ((($$sroa$02$06$i106)) + 40|0);
                        $570 = ($569|0)==($545|0);
                        if ($570) {
                         break;
                        } else {
                         $$sroa$02$06$i106 = $569;
                        }
                       }
                      }
                     } while(0);
                     __THREW__ = 0;
                     $606 = (+invoke_dii(3908,($10|0),($12|0)));
                     $607 = __THREW__; __THREW__ = 0;
                     $608 = $607&1;
                     if ($608) {
                      label = 135;
                      break;
                     }
                     $609 = $606 / $324;
                     $610 = +HEAPF32[$0>>2];
                     $611 = $610 - $609;
                     HEAPF32[$0>>2] = $611;
                     $612 = HEAP32[$12>>2]|0;
                     $613 = ($612|0)==(0|0);
                     if (!($613)) {
                      $614 = HEAP32[$339>>2]|0;
                      $615 = ($614|0)==($612|0);
                      if (!($615)) {
                       $scevgep$i$i$i89 = ((($614)) + -16|0);
                       $616 = $scevgep$i$i$i89;
                       $617 = $612;
                       $618 = (($616) - ($617))|0;
                       $619 = $618 >>> 4;
                       $620 = $619 ^ -1;
                       $scevgep5$i$i$i90 = (($614) + ($620<<4)|0);
                       HEAP32[$339>>2] = $scevgep5$i$i$i90;
                      }
                      __ZdlPv($612);
                     }
                    }
                    $630 = HEAP32[$10>>2]|0;
                    $631 = ($630|0)==(0|0);
                    if (!($631)) {
                     $632 = HEAP32[$330>>2]|0;
                     $633 = ($632|0)==($630|0);
                     if (!($633)) {
                      $scevgep$i$i$i79 = ((($632)) + -16|0);
                      $634 = $scevgep$i$i$i79;
                      $635 = $630;
                      $636 = (($634) - ($635))|0;
                      $637 = $636 >>> 4;
                      $638 = $637 ^ -1;
                      $scevgep5$i$i$i80 = (($632) + ($638<<4)|0);
                      HEAP32[$330>>2] = $scevgep5$i$i$i80;
                     }
                     __ZdlPv($630);
                    }
                    $639 = ((($$sroa$0154$0179)) + 12|0);
                    $640 = HEAP32[$327>>2]|0;
                    $641 = ($639|0)==($640|0);
                    if ($641) {
                     break L93;
                    } else {
                     $$sroa$0154$0179 = $639;
                    }
                   }
                   if ((label|0) == 120) {
                    $571 = ___cxa_find_matching_catch_2()|0;
                    $572 = tempRet0;
                    $$4 = $571;$$448 = $572;
                   }
                   else if ((label|0) == 121) {
                    $573 = ___cxa_find_matching_catch_2()|0;
                    $574 = tempRet0;
                    $575 = HEAP32[$336>>2]|0;
                    $576 = ($575|0)==(0|0);
                    if (!($576)) {
                     $577 = HEAP32[$359>>2]|0;
                     $578 = ($577|0)==($575|0);
                     if (!($578)) {
                      $scevgep$i$i$i$i = ((($577)) + -12|0);
                      $579 = $scevgep$i$i$i$i;
                      $580 = $575;
                      $581 = (($579) - ($580))|0;
                      $582 = (($581>>>0) / 12)&-1;
                      $583 = $582 ^ -1;
                      $scevgep5$i$i$i$i = (($577) + (($583*12)|0)|0);
                      HEAP32[$359>>2] = $scevgep5$i$i$i$i;
                     }
                     __ZdlPv($575);
                    }
                    $584 = HEAP32[$337>>2]|0;
                    $585 = ($584|0)==(0|0);
                    if (!($585)) {
                     $586 = HEAP32[$358>>2]|0;
                     $587 = ($586|0)==($584|0);
                     if (!($587)) {
                      $scevgep$i$i$i3$i = ((($586)) + -40|0);
                      $588 = $scevgep$i$i$i3$i;
                      $589 = $584;
                      $590 = (($588) - ($589))|0;
                      $591 = (($590>>>0) / 40)&-1;
                      $592 = $591 ^ -1;
                      $scevgep5$i$i$i4$i = (($586) + (($592*40)|0)|0);
                      HEAP32[$358>>2] = $scevgep5$i$i$i4$i;
                     }
                     __ZdlPv($584);
                    }
                    $593 = HEAP32[$338>>2]|0;
                    $594 = ($593|0)==(0|0);
                    if (!($594)) {
                     $595 = HEAP32[$357>>2]|0;
                     $596 = ($595|0)==($593|0);
                     if (!($596)) {
                      $scevgep$i$i$i$i$i = ((($595)) + -4|0);
                      $597 = $scevgep$i$i$i$i$i;
                      $598 = $593;
                      $599 = (($597) - ($598))|0;
                      $600 = $599 >>> 2;
                      $601 = $600 ^ -1;
                      $scevgep5$i$i$i$i$i = (($595) + ($601<<2)|0);
                      HEAP32[$357>>2] = $scevgep5$i$i$i$i$i;
                     }
                     __ZdlPv($593);
                    }
                    $$4 = $573;$$448 = $574;
                   }
                   else if ((label|0) == 134) {
                    $602 = ___cxa_find_matching_catch_2()|0;
                    $603 = tempRet0;
                    $$1 = $602;$$145 = $603;
                    label = 142;
                   }
                   else if ((label|0) == 135) {
                    $604 = ___cxa_find_matching_catch_2()|0;
                    $605 = tempRet0;
                    $$1 = $604;$$145 = $605;
                    label = 142;
                   }
                   if ((label|0) == 142) {
                    $621 = HEAP32[$12>>2]|0;
                    $622 = ($621|0)==(0|0);
                    if (!($622)) {
                     $623 = HEAP32[$339>>2]|0;
                     $624 = ($623|0)==($621|0);
                     if (!($624)) {
                      $scevgep$i$i$i84 = ((($623)) + -16|0);
                      $625 = $scevgep$i$i$i84;
                      $626 = $621;
                      $627 = (($625) - ($626))|0;
                      $628 = $627 >>> 4;
                      $629 = $628 ^ -1;
                      $scevgep5$i$i$i85 = (($623) + ($629<<4)|0);
                      HEAP32[$339>>2] = $scevgep5$i$i$i85;
                     }
                     __ZdlPv($621);
                    }
                    $$4 = $$1;$$448 = $$145;
                   }
                   $642 = HEAP32[$10>>2]|0;
                   $643 = ($642|0)==(0|0);
                   if (!($643)) {
                    $644 = HEAP32[$330>>2]|0;
                    $645 = ($644|0)==($642|0);
                    if (!($645)) {
                     $scevgep$i$i$i74 = ((($644)) + -16|0);
                     $646 = $scevgep$i$i$i74;
                     $647 = $642;
                     $648 = (($646) - ($647))|0;
                     $649 = $648 >>> 4;
                     $650 = $649 ^ -1;
                     $scevgep5$i$i$i75 = (($644) + ($650<<4)|0);
                     HEAP32[$330>>2] = $scevgep5$i$i$i75;
                    }
                    __ZdlPv($642);
                   }
                   $$7 = $$4;$$751 = $$448;
                   break L60;
                  }
                 } while(0);
                 $360 = HEAP32[$8>>2]|0;
                 $361 = ($360|0)==(0|0);
                 if (!($361)) {
                  $362 = HEAP32[$77>>2]|0;
                  $363 = ($362|0)==($360|0);
                  if (!($363)) {
                   $scevgep$i$i$i122 = ((($362)) + -16|0);
                   $364 = $scevgep$i$i$i122;
                   $365 = $360;
                   $366 = (($364) - ($365))|0;
                   $367 = $366 >>> 4;
                   $368 = $367 ^ -1;
                   $scevgep5$i$i$i123 = (($362) + ($368<<4)|0);
                   HEAP32[$77>>2] = $scevgep5$i$i$i123;
                  }
                  __ZdlPv($360);
                 }
                 $$0 = 1;
                 break L31;
                }
               } while(0);
               if ((label|0) == 66) {
                $318 = ___cxa_find_matching_catch_2()|0;
                $319 = tempRet0;
                $$7 = $318;$$751 = $319;
               }
               $$8 = $$7;$$852 = $$751;
              }
             }
            }
           }
          }
         } while(0);
         if ((label|0) == 65) {
          $316 = ___cxa_find_matching_catch_2()|0;
          $317 = tempRet0;
          $$8 = $316;$$852 = $317;
         }
         $651 = HEAP32[$8>>2]|0;
         $652 = ($651|0)==(0|0);
         if (!($652)) {
          $653 = HEAP32[$77>>2]|0;
          $654 = ($653|0)==($651|0);
          if (!($654)) {
           $scevgep$i$i$i69 = ((($653)) + -16|0);
           $655 = $scevgep$i$i$i69;
           $656 = $651;
           $657 = (($655) - ($656))|0;
           $658 = $657 >>> 4;
           $659 = $658 ^ -1;
           $scevgep5$i$i$i70 = (($653) + ($659<<4)|0);
           HEAP32[$77>>2] = $scevgep5$i$i$i70;
          }
          __ZdlPv($651);
         }
         $$10 = $$8;$$1054 = $$852;
         break L28;
        } else {
         $$0 = 0;
        }
       } while(0);
       $660 = HEAP32[$7>>2]|0;
       $661 = ($660|0)==(0|0);
       if ($661) {
        STACKTOP = sp;return ($$0|0);
       }
       $662 = HEAP32[$70>>2]|0;
       $663 = ($662|0)==($660|0);
       if (!($663)) {
        $scevgep$i$i$i60 = ((($662)) + -16|0);
        $664 = $scevgep$i$i$i60;
        $665 = $660;
        $666 = (($664) - ($665))|0;
        $667 = $666 >>> 4;
        $668 = $667 ^ -1;
        $scevgep5$i$i$i61 = (($662) + ($668<<4)|0);
        HEAP32[$70>>2] = $scevgep5$i$i$i61;
       }
       __ZdlPv($660);
       STACKTOP = sp;return ($$0|0);
      }
     } while(0);
     $669 = HEAP32[$7>>2]|0;
     $670 = ($669|0)==(0|0);
     if (!($670)) {
      $671 = HEAP32[$70>>2]|0;
      $672 = ($671|0)==($669|0);
      if (!($672)) {
       $scevgep$i$i$i = ((($671)) + -16|0);
       $673 = $scevgep$i$i$i;
       $674 = $669;
       $675 = (($673) - ($674))|0;
       $676 = $675 >>> 4;
       $677 = $676 ^ -1;
       $scevgep5$i$i$i = (($671) + ($677<<4)|0);
       HEAP32[$70>>2] = $scevgep5$i$i$i;
      }
      __ZdlPv($669);
     }
     $$14 = $$10;$$1458 = $$1054;
     ___resumeException($$14|0);
     // unreachable;
    }
   }
   $312 = ___cxa_find_matching_catch_2()|0;
   $313 = tempRet0;
   $$14 = $312;$$1458 = $313;
   ___resumeException($$14|0);
   // unreachable;
  }
 } while(0);
 $310 = ___cxa_find_matching_catch_2()|0;
 $311 = tempRet0;
 $$14 = $310;$$1458 = $311;
 ___resumeException($$14|0);
 // unreachable;
 return (0)|0;
}
function __ZNSt3__26vectorIN3osg8PolytopeENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$06$i$i = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$phi11$iZ2D = 0, $$pre8$i = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $2 = sp;
 $3 = ((($0)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$0>>2]|0;
 $6 = (($4) - ($5))|0;
 $7 = (($6|0) / 48)&-1;
 $8 = (($7) + 1)|0;
 $9 = ($8>>>0)>(89478485);
 if ($9) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $10 = ((($0)) + 8|0);
 $11 = ((($0)) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) - ($5))|0;
 $14 = (($13|0) / 48)&-1;
 $15 = ($14>>>0)<(44739242);
 $16 = $14 << 1;
 $17 = ($16>>>0)<($8>>>0);
 $$sroa$speculated$i = $17 ? $8 : $16;
 $$sroa$speculated$$i = $15 ? $$sroa$speculated$i : 89478485;
 $18 = ((($2)) + 12|0);
 HEAP32[$18>>2] = 0;
 $19 = ((($2)) + 16|0);
 HEAP32[$19>>2] = $10;
 $20 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($20) {
   $29 = 0;
  } else {
   $21 = ($$sroa$speculated$$i>>>0)>(89478485);
   if (!($21)) {
    $27 = ($$sroa$speculated$$i*48)|0;
    $28 = (__Znwj($27)|0);
    $29 = $28;
    break;
   }
   $22 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($22|0),(204840|0));
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if ($24) {
    $25 = ___cxa_find_matching_catch_2()|0;
    $26 = tempRet0;
    ___cxa_free_exception(($22|0));
    ___resumeException($25|0);
    // unreachable;
   } else {
    HEAP32[$22>>2] = (99824);
    ___cxa_throw(($22|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 HEAP32[$2>>2] = $29;
 $30 = (($29) + (($7*48)|0)|0);
 $31 = ((($2)) + 8|0);
 HEAP32[$31>>2] = $30;
 $32 = ((($2)) + 4|0);
 HEAP32[$32>>2] = $30;
 $33 = (($29) + (($$sroa$speculated$$i*48)|0)|0);
 $34 = ((($2)) + 12|0);
 HEAP32[$34>>2] = $33;
 __THREW__ = 0;
 invoke_vii(3596,($30|0),($1|0));
 $35 = __THREW__; __THREW__ = 0;
 $36 = $35&1;
 L13: do {
  if (!($36)) {
   $37 = HEAP32[$31>>2]|0;
   $38 = ((($37)) + 48|0);
   HEAP32[$31>>2] = $38;
   $39 = HEAP32[$0>>2]|0;
   $40 = HEAP32[$3>>2]|0;
   $41 = ($40|0)==($39|0);
   if ($41) {
    $42 = $40;
    $43 = $39;
    $$pre8$i = HEAP32[$32>>2]|0;
    $$pre$phi11$iZ2D = $32;$53 = $$pre8$i;$54 = $43;$56 = $42;
    HEAP32[$0>>2] = $53;
    HEAP32[$$pre$phi11$iZ2D>>2] = $54;
    $55 = HEAP32[$31>>2]|0;
    HEAP32[$3>>2] = $55;
    HEAP32[$31>>2] = $56;
    $57 = HEAP32[$11>>2]|0;
    $58 = HEAP32[$34>>2]|0;
    HEAP32[$11>>2] = $58;
    HEAP32[$34>>2] = $57;
    $59 = HEAP32[$$pre$phi11$iZ2D>>2]|0;
    HEAP32[$2>>2] = $59;
    __ZNSt3__214__split_bufferIN3osg8PolytopeERNS_9allocatorIS2_EEED2Ev($2);
    STACKTOP = sp;return;
   }
   $$pre$i$i = HEAP32[$32>>2]|0;
   $$06$i$i = $40;$45 = $$pre$i$i;
   while(1) {
    $44 = ((($45)) + -48|0);
    $46 = ((($$06$i$i)) + -48|0);
    __THREW__ = 0;
    invoke_vii(3596,($44|0),($46|0));
    $47 = __THREW__; __THREW__ = 0;
    $48 = $47&1;
    if ($48) {
     break L13;
    }
    $49 = HEAP32[$32>>2]|0;
    $50 = ((($49)) + -48|0);
    HEAP32[$32>>2] = $50;
    $51 = ($46|0)==($39|0);
    if ($51) {
     break;
    } else {
     $$06$i$i = $46;$45 = $50;
    }
   }
   $52 = $50;
   $$pre$i = HEAP32[$0>>2]|0;
   $$pre = HEAP32[$3>>2]|0;
   $$pre$phi11$iZ2D = $32;$53 = $52;$54 = $$pre$i;$56 = $$pre;
   HEAP32[$0>>2] = $53;
   HEAP32[$$pre$phi11$iZ2D>>2] = $54;
   $55 = HEAP32[$31>>2]|0;
   HEAP32[$3>>2] = $55;
   HEAP32[$31>>2] = $56;
   $57 = HEAP32[$11>>2]|0;
   $58 = HEAP32[$34>>2]|0;
   HEAP32[$11>>2] = $58;
   HEAP32[$34>>2] = $57;
   $59 = HEAP32[$$pre$phi11$iZ2D>>2]|0;
   HEAP32[$2>>2] = $59;
   __ZNSt3__214__split_bufferIN3osg8PolytopeERNS_9allocatorIS2_EEED2Ev($2);
   STACKTOP = sp;return;
  }
 } while(0);
 $60 = ___cxa_find_matching_catch_2()|0;
 $61 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3910,($2|0));
 $62 = __THREW__; __THREW__ = 0;
 $63 = $62&1;
 if ($63) {
  $64 = ___cxa_find_matching_catch_3(0|0)|0;
  $65 = tempRet0;
  ___clang_call_terminate($64);
  // unreachable;
 } else {
  ___resumeException($60|0);
  // unreachable;
 }
}
function __ZNSt3__214__split_bufferIN3osg8PolytopeERNS_9allocatorIS2_EEED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i$i$i$i = 0, $scevgep$i$i$i3$i$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i$i$i$i$i$i = 0, $scevgep5$i$i$i4$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==($2|0);
 if (!($5)) {
  $7 = $4;
  while(1) {
   $6 = ((($7)) + -48|0);
   HEAP32[$3>>2] = $6;
   $8 = ((($7)) + -12|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = ($9|0)==(0|0);
   if (!($10)) {
    $11 = ((($7)) + -8|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ($12|0)==($9|0);
    if (!($13)) {
     $scevgep$i$i$i$i$i$i$i$i$i = ((($12)) + -12|0);
     $14 = $scevgep$i$i$i$i$i$i$i$i$i;
     $15 = $9;
     $16 = (($14) - ($15))|0;
     $17 = (($16>>>0) / 12)&-1;
     $18 = $17 ^ -1;
     $scevgep5$i$i$i$i$i$i$i$i$i = (($12) + (($18*12)|0)|0);
     HEAP32[$11>>2] = $scevgep5$i$i$i$i$i$i$i$i$i;
    }
    __ZdlPv($9);
   }
   $19 = ((($7)) + -24|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = ($20|0)==(0|0);
   if (!($21)) {
    $22 = ((($7)) + -20|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = ($23|0)==($20|0);
    if (!($24)) {
     $scevgep$i$i$i3$i$i$i$i$i$i = ((($23)) + -40|0);
     $25 = $scevgep$i$i$i3$i$i$i$i$i$i;
     $26 = $20;
     $27 = (($25) - ($26))|0;
     $28 = (($27>>>0) / 40)&-1;
     $29 = $28 ^ -1;
     $scevgep5$i$i$i4$i$i$i$i$i$i = (($23) + (($29*40)|0)|0);
     HEAP32[$22>>2] = $scevgep5$i$i$i4$i$i$i$i$i$i;
    }
    __ZdlPv($20);
   }
   $30 = ((($7)) + -44|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = ($31|0)==(0|0);
   if (!($32)) {
    $35 = ((($7)) + -40|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = ($36|0)==($31|0);
    if (!($37)) {
     $scevgep$i$i$i$i$i$i$i$i$i$i = ((($36)) + -4|0);
     $38 = $scevgep$i$i$i$i$i$i$i$i$i$i;
     $39 = $31;
     $40 = (($38) - ($39))|0;
     $41 = $40 >>> 2;
     $42 = $41 ^ -1;
     $scevgep5$i$i$i$i$i$i$i$i$i$i = (($36) + ($42<<2)|0);
     HEAP32[$35>>2] = $scevgep5$i$i$i$i$i$i$i$i$i$i;
    }
    __ZdlPv($31);
   }
   $33 = HEAP32[$3>>2]|0;
   $34 = ($33|0)==($2|0);
   if ($34) {
    break;
   } else {
    $7 = $33;
   }
  }
 }
 $43 = HEAP32[$0>>2]|0;
 $44 = ($43|0)==(0|0);
 if ($44) {
  return;
 }
 __ZdlPv($43);
 return;
}
function __ZN3osg20ShadowVolumeOccluder8containsERKNSt3__26vectorINS_5Vec3fENS1_9allocatorIS3_EEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$01424$i = 0, $$01424$us$i = 0, $$02031$i$i = 0, $$02230$i$i = 0, $$121$i$i = 0, $$123$i$i = 0, $$18 = 0, $$sink23$i = 0, $$sink23$us$i = 0, $$sroa$016$024 = 0, $$sroa$025$029$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0.0, $25 = 0, $26 = 0.0, $27 = 0, $28 = 0.0, $29 = 0, $3 = 0, $30 = 0.0, $31 = 0, $32 = 0, $33 = 0.0, $34 = 0.0, $35 = 0.0, $36 = 0;
 var $37 = 0.0, $38 = 0.0, $39 = 0.0, $4 = 0, $40 = 0.0, $41 = 0, $42 = 0.0, $43 = 0.0, $44 = 0.0, $45 = 0.0, $46 = 0.0, $47 = 0.0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $or$cond$i = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i10 = 0, $scevgep5$i$i$i = 0, $scevgep5$i$i$i11 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = ((($0)) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 if ($5) {
  $$18 = 0;
  STACKTOP = sp;return ($$18|0);
 }
 $6 = ((($0)) + 40|0);
 HEAP32[$6>>2] = $4;
 $7 = ((($0)) + 44|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($0)) + 48|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8|0)==($10|0);
 L4: do {
  if (!($11)) {
   $12 = HEAP32[$1>>2]|0;
   $13 = ((($1)) + 4|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = ($12|0)==($14|0);
   if ($15) {
    $$01424$us$i = 1;$$sink23$us$i = $8;
    while(1) {
     $16 = $$01424$us$i & $4;
     $17 = ($16|0)==(0);
     if (!($17)) {
      $$18 = 0;
      break;
     }
     $18 = $$01424$us$i << 1;
     $19 = ((($$sink23$us$i)) + 40|0);
     $20 = ($19|0)==($10|0);
     if ($20) {
      break L4;
     } else {
      $$01424$us$i = $18;$$sink23$us$i = $19;
     }
    }
    STACKTOP = sp;return ($$18|0);
   } else {
    $$01424$i = 1;$$sink23$i = $8;$22 = $4;
   }
   while(1) {
    $21 = $$01424$i & $22;
    $23 = ($21|0)==(0);
    if ($23) {
     $93 = $22;
    } else {
     $24 = +HEAPF64[$$sink23$i>>3];
     $25 = ((($$sink23$i)) + 8|0);
     $26 = +HEAPF64[$25>>3];
     $27 = ((($$sink23$i)) + 16|0);
     $28 = +HEAPF64[$27>>3];
     $29 = ((($$sink23$i)) + 24|0);
     $30 = +HEAPF64[$29>>3];
     $$02031$i$i = 0;$$02230$i$i = 0;$$sroa$025$029$i$i = $12;
     while(1) {
      $33 = +HEAPF32[$$sroa$025$029$i$i>>2];
      $34 = $33;
      $35 = $24 * $34;
      $36 = ((($$sroa$025$029$i$i)) + 4|0);
      $37 = +HEAPF32[$36>>2];
      $38 = $37;
      $39 = $26 * $38;
      $40 = $35 + $39;
      $41 = ((($$sroa$025$029$i$i)) + 8|0);
      $42 = +HEAPF32[$41>>2];
      $43 = $42;
      $44 = $28 * $43;
      $45 = $40 + $44;
      $46 = $30 + $45;
      $47 = $46;
      $48 = $47 > 0.0;
      if ($48) {
       $49 = (($$02230$i$i) + 1)|0;
       $$121$i$i = $$02031$i$i;$$123$i$i = $49;
      } else {
       $50 = $47 < 0.0;
       if ($50) {
        $51 = (($$02031$i$i) + 1)|0;
        $$121$i$i = $51;$$123$i$i = $$02230$i$i;
       } else {
        $$121$i$i = $$02031$i$i;$$123$i$i = $$02230$i$i;
       }
      }
      $52 = ((($$sroa$025$029$i$i)) + 12|0);
      $53 = ($52|0)==($14|0);
      if ($53) {
       break;
      } else {
       $$02031$i$i = $$121$i$i;$$02230$i$i = $$123$i$i;$$sroa$025$029$i$i = $52;
      }
     }
     $31 = ($$123$i$i|0)<(1);
     $32 = ($$121$i$i|0)>(0);
     $or$cond$i = $31 | $32;
     if ($or$cond$i) {
      $$18 = 0;
      break;
     }
     $54 = $$01424$i ^ $22;
     HEAP32[$6>>2] = $54;
     $93 = $54;
    }
    $55 = $$01424$i << 1;
    $56 = ((($$sink23$i)) + 40|0);
    $57 = ($56|0)==($10|0);
    if ($57) {
     break L4;
    } else {
     $$01424$i = $55;$$sink23$i = $56;$22 = $93;
    }
   }
   STACKTOP = sp;return ($$18|0);
  }
 } while(0);
 $58 = ((($0)) + 68|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = ((($0)) + 72|0);
 $61 = HEAP32[$60>>2]|0;
 $62 = ($59|0)==($61|0);
 if ($62) {
  $$18 = 1;
  STACKTOP = sp;return ($$18|0);
 }
 $63 = ((($2)) + 4|0);
 $64 = ((($2)) + 8|0);
 $$sroa$016$024 = $59;
 while(1) {
  HEAP32[$2>>2] = 0;
  HEAP32[$63>>2] = 0;
  HEAP32[$64>>2] = 0;
  $68 = ((($$sroa$016$024)) + 24|0);
  __THREW__ = 0;
  $69 = (invoke_iiii(3901,($68|0),($1|0),($2|0))|0);
  $70 = __THREW__; __THREW__ = 0;
  $71 = $70&1;
  if ($71) {
   label = 25;
   break;
  }
  $72 = ($69>>>0)>(2);
  $73 = HEAP32[$2>>2]|0;
  $74 = ($73|0)==(0|0);
  if (!($74)) {
   $75 = HEAP32[$63>>2]|0;
   $76 = ($75|0)==($73|0);
   if (!($76)) {
    $scevgep$i$i$i10 = ((($75)) + -16|0);
    $77 = $scevgep$i$i$i10;
    $78 = $73;
    $79 = (($77) - ($78))|0;
    $80 = $79 >>> 4;
    $81 = $80 ^ -1;
    $scevgep5$i$i$i11 = (($75) + ($81<<4)|0);
    HEAP32[$63>>2] = $scevgep5$i$i$i11;
   }
   __ZdlPv($73);
  }
  $66 = ((($$sroa$016$024)) + 48|0);
  if ($72) {
   $$18 = 0;
   label = 30;
   break;
  }
  $65 = HEAP32[$60>>2]|0;
  $67 = ($66|0)==($65|0);
  if ($67) {
   $$18 = 1;
   label = 30;
   break;
  } else {
   $$sroa$016$024 = $66;
  }
 }
 if ((label|0) == 25) {
  $82 = ___cxa_find_matching_catch_2()|0;
  $83 = tempRet0;
  $84 = HEAP32[$2>>2]|0;
  $85 = ($84|0)==(0|0);
  if ($85) {
   ___resumeException($82|0);
   // unreachable;
  }
  $86 = HEAP32[$63>>2]|0;
  $87 = ($86|0)==($84|0);
  if (!($87)) {
   $scevgep$i$i$i = ((($86)) + -16|0);
   $88 = $scevgep$i$i$i;
   $89 = $84;
   $90 = (($88) - ($89))|0;
   $91 = $90 >>> 4;
   $92 = $91 ^ -1;
   $scevgep5$i$i$i = (($86) + ($92<<4)|0);
   HEAP32[$63>>2] = $scevgep5$i$i$i;
  }
  __ZdlPv($84);
  ___resumeException($82|0);
  // unreachable;
 }
 else if ((label|0) == 30) {
  STACKTOP = sp;return ($$18|0);
 }
 return (0)|0;
}
function __ZN3osg20ShadowVolumeOccluder8containsERKNS_18BoundingSphereImplINS_5Vec3fEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$$i$i = 0, $$0$i$i = 0, $$01424$i = 0, $$01525$i = 0, $$sink23$i = 0, $$sink24$i = 0, $$sroa$09$015 = 0, $10 = 0, $11 = 0.0, $12 = 0.0, $13 = 0, $14 = 0.0, $15 = 0.0, $16 = 0, $17 = 0.0, $18 = 0.0, $19 = 0, $2 = 0, $20 = 0.0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0.0, $25 = 0.0, $26 = 0, $27 = 0.0, $28 = 0.0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0.0, $32 = 0.0, $33 = 0.0, $34 = 0, $35 = 0.0, $36 = 0.0, $37 = 0.0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0.0;
 var $59 = 0.0, $6 = 0, $60 = 0.0, $61 = 0.0, $62 = 0.0, $63 = 0.0, $64 = 0.0, $65 = 0.0, $66 = 0, $67 = 0, $68 = 0, $69 = 0.0, $7 = 0, $70 = 0.0, $71 = 0, $72 = 0.0, $73 = 0.0, $74 = 0.0, $75 = 0, $76 = 0.0;
 var $77 = 0.0, $78 = 0.0, $79 = 0, $8 = 0, $80 = 0.0, $81 = 0.0, $82 = 0.0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $not$$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 20|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  $93 = 0;
  return ($93|0);
 }
 $5 = ((($0)) + 40|0);
 HEAP32[$5>>2] = $3;
 $6 = ((($0)) + 44|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($0)) + 48|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($7|0)==($9|0);
 L4: do {
  if (!($10)) {
   $11 = +HEAPF32[$1>>2];
   $12 = $11;
   $13 = ((($1)) + 4|0);
   $14 = +HEAPF32[$13>>2];
   $15 = $14;
   $16 = ((($1)) + 8|0);
   $17 = +HEAPF32[$16>>2];
   $18 = $17;
   $19 = ((($1)) + 12|0);
   $20 = +HEAPF32[$19>>2];
   $$01424$i = 1;$$sink23$i = $7;$22 = $3;
   while(1) {
    $21 = $$01424$i & $22;
    $23 = ($21|0)==(0);
    if ($23) {
     $94 = $22;
    } else {
     $24 = +HEAPF64[$$sink23$i>>3];
     $25 = $12 * $24;
     $26 = ((($$sink23$i)) + 8|0);
     $27 = +HEAPF64[$26>>3];
     $28 = $15 * $27;
     $29 = $25 + $28;
     $30 = ((($$sink23$i)) + 16|0);
     $31 = +HEAPF64[$30>>3];
     $32 = $18 * $31;
     $33 = $29 + $32;
     $34 = ((($$sink23$i)) + 24|0);
     $35 = +HEAPF64[$34>>3];
     $36 = $35 + $33;
     $37 = $36;
     $not$$i = !($37 > $20);
     if ($not$$i) {
      $93 = 0;
      break;
     }
     $38 = $$01424$i ^ $22;
     HEAP32[$5>>2] = $38;
     $94 = $38;
    }
    $39 = $$01424$i << 1;
    $40 = ((($$sink23$i)) + 40|0);
    $41 = ($40|0)==($9|0);
    if ($41) {
     break L4;
    } else {
     $$01424$i = $39;$$sink23$i = $40;$22 = $94;
    }
   }
   return ($93|0);
  }
 } while(0);
 $42 = ((($0)) + 68|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = ((($0)) + 72|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = ($43|0)==($45|0);
 if ($46) {
  $93 = 1;
  return ($93|0);
 }
 $47 = ((($1)) + 4|0);
 $48 = ((($1)) + 8|0);
 $49 = ((($1)) + 12|0);
 $$sroa$09$015 = $43;
 L17: while(1) {
  $50 = HEAP32[$$sroa$09$015>>2]|0;
  $51 = ($50|0)==(0);
  if ($51) {
   $93 = 0;
   label = 19;
   break;
  }
  $52 = ((($$sroa$09$015)) + 20|0);
  HEAP32[$52>>2] = $50;
  $53 = ((($$sroa$09$015)) + 24|0);
  $54 = HEAP32[$53>>2]|0;
  $55 = ((($$sroa$09$015)) + 28|0);
  $56 = HEAP32[$55>>2]|0;
  $57 = ($54|0)==($56|0);
  if ($57) {
   $93 = 0;
   label = 19;
   break;
  }
  $58 = +HEAPF32[$1>>2];
  $59 = $58;
  $60 = +HEAPF32[$47>>2];
  $61 = $60;
  $62 = +HEAPF32[$48>>2];
  $63 = $62;
  $64 = +HEAPF32[$49>>2];
  $65 = -$64;
  $$01525$i = 1;$$sink24$i = $54;$67 = $50;
  while(1) {
   $66 = $$01525$i & $67;
   $68 = ($66|0)==(0);
   if ($68) {
    $95 = $67;
   } else {
    $69 = +HEAPF64[$$sink24$i>>3];
    $70 = $59 * $69;
    $71 = ((($$sink24$i)) + 8|0);
    $72 = +HEAPF64[$71>>3];
    $73 = $61 * $72;
    $74 = $70 + $73;
    $75 = ((($$sink24$i)) + 16|0);
    $76 = +HEAPF64[$75>>3];
    $77 = $63 * $76;
    $78 = $74 + $77;
    $79 = ((($$sink24$i)) + 24|0);
    $80 = +HEAPF64[$79>>3];
    $81 = $80 + $78;
    $82 = $81;
    $83 = $82 > $64;
    $84 = $82 < $65;
    $$$i$i = $84 << 31 >> 31;
    $$0$i$i = $83 ? 1 : $$$i$i;
    $85 = ($$0$i$i|0)<(0);
    if ($85) {
     break;
    }
    $86 = ($$0$i$i|0)==(0);
    $87 = $$01525$i ^ $67;
    if ($86) {
     $95 = $67;
    } else {
     HEAP32[$52>>2] = $87;
     $95 = $87;
    }
   }
   $88 = $$01525$i << 1;
   $89 = ((($$sink24$i)) + 40|0);
   $90 = ($89|0)==($56|0);
   if ($90) {
    $93 = 0;
    label = 19;
    break L17;
   } else {
    $$01525$i = $88;$$sink24$i = $89;$67 = $95;
   }
  }
  $91 = ((($$sroa$09$015)) + 48|0);
  $92 = ($91|0)==($45|0);
  if ($92) {
   $93 = 1;
   label = 19;
   break;
  } else {
   $$sroa$09$015 = $91;
  }
 }
 if ((label|0) == 19) {
  return ($93|0);
 }
 return (0)|0;
}
function __ZN3osg20ShadowVolumeOccluder8containsERKNS_15BoundingBoxImplINS_5Vec3fEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$01424$i = 0, $$01527$i = 0, $$sink$i$i$i = 0, $$sink$i$i$i6 = 0, $$sink$i3$i$i = 0, $$sink1$i$i$i = 0, $$sink1$i$i$i7 = 0, $$sink1$i4$i$i = 0, $$sink2$i$i$i = 0, $$sink2$i$i$i8 = 0, $$sink2$i5$i$i = 0, $$sink23$i = 0, $$sink26$i = 0, $$sroa$011$017 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0.0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0.0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0.0, $111 = 0.0, $112 = 0.0, $113 = 0.0, $114 = 0.0, $115 = 0.0, $116 = 0.0, $117 = 0.0, $118 = 0.0, $119 = 0.0, $12 = 0, $120 = 0.0, $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0.0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0.0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0.0, $28 = 0.0, $29 = 0.0, $3 = 0, $30 = 0.0, $31 = 0, $32 = 0.0, $33 = 0.0, $34 = 0.0, $35 = 0.0, $36 = 0, $37 = 0.0, $38 = 0.0, $39 = 0.0, $4 = 0, $40 = 0.0, $41 = 0;
 var $42 = 0.0, $43 = 0.0, $44 = 0.0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0.0, $72 = 0, $73 = 0, $74 = 0, $75 = 0.0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0.0, $8 = 0, $80 = 0.0, $81 = 0.0, $82 = 0.0, $83 = 0, $84 = 0.0, $85 = 0.0, $86 = 0.0, $87 = 0.0, $88 = 0, $89 = 0.0, $9 = 0, $90 = 0.0, $91 = 0.0, $92 = 0.0, $93 = 0, $94 = 0.0, $95 = 0.0, $96 = 0.0;
 var $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 20|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  $128 = 0;
  return ($128|0);
 }
 $5 = ((($0)) + 40|0);
 HEAP32[$5>>2] = $3;
 $6 = ((($0)) + 44|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($0)) + 48|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($7|0)==($9|0);
 L4: do {
  if (!($10)) {
   $11 = ((($1)) + 12|0);
   $$01424$i = 1;$$sink23$i = $7;$13 = $3;
   while(1) {
    $12 = $$01424$i & $13;
    $14 = ($12|0)==(0);
    if ($14) {
     $129 = $13;
    } else {
     $15 = ((($$sink23$i)) + 36|0);
     $16 = HEAP32[$15>>2]|0;
     $17 = $16 & 1;
     $18 = ($17|0)!=(0);
     $$sink$i$i$i = $18 ? $11 : $1;
     $19 = +HEAPF32[$$sink$i$i$i>>2];
     $20 = $16 & 2;
     $21 = ($20|0)!=(0);
     $$sink1$i$i$i = $21 ? $11 : $1;
     $22 = ((($$sink1$i$i$i)) + 4|0);
     $23 = +HEAPF32[$22>>2];
     $24 = $16 & 4;
     $25 = ($24|0)!=(0);
     $$sink2$i$i$i = $25 ? $11 : $1;
     $26 = ((($$sink2$i$i$i)) + 8|0);
     $27 = +HEAPF32[$26>>2];
     $28 = +HEAPF64[$$sink23$i>>3];
     $29 = $19;
     $30 = $29 * $28;
     $31 = ((($$sink23$i)) + 8|0);
     $32 = +HEAPF64[$31>>3];
     $33 = $23;
     $34 = $33 * $32;
     $35 = $30 + $34;
     $36 = ((($$sink23$i)) + 16|0);
     $37 = +HEAPF64[$36>>3];
     $38 = $27;
     $39 = $38 * $37;
     $40 = $35 + $39;
     $41 = ((($$sink23$i)) + 24|0);
     $42 = +HEAPF64[$41>>3];
     $43 = $42 + $40;
     $44 = $43;
     $45 = $44 > 0.0;
     if (!($45)) {
      $128 = 0;
      break;
     }
     $46 = $$01424$i ^ $13;
     HEAP32[$5>>2] = $46;
     $129 = $46;
    }
    $47 = $$01424$i << 1;
    $48 = ((($$sink23$i)) + 40|0);
    $49 = ($48|0)==($9|0);
    if ($49) {
     break L4;
    } else {
     $$01424$i = $47;$$sink23$i = $48;$13 = $129;
    }
   }
   return ($128|0);
  }
 } while(0);
 $50 = ((($0)) + 68|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = ((($0)) + 72|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = ($51|0)==($53|0);
 if ($54) {
  $128 = 1;
  return ($128|0);
 }
 $55 = ((($1)) + 12|0);
 $$sroa$011$017 = $51;
 L17: while(1) {
  $56 = HEAP32[$$sroa$011$017>>2]|0;
  $57 = ($56|0)==(0);
  if ($57) {
   $128 = 0;
   label = 18;
   break;
  }
  $58 = ((($$sroa$011$017)) + 20|0);
  HEAP32[$58>>2] = $56;
  $59 = ((($$sroa$011$017)) + 24|0);
  $60 = HEAP32[$59>>2]|0;
  $61 = ((($$sroa$011$017)) + 28|0);
  $62 = HEAP32[$61>>2]|0;
  $63 = ($60|0)==($62|0);
  if ($63) {
   $128 = 0;
   label = 18;
   break;
  } else {
   $$01527$i = 1;$$sink26$i = $60;$65 = $56;
  }
  L20: while(1) {
   $64 = $$01527$i & $65;
   $66 = ($64|0)==(0);
   do {
    if ($66) {
     $130 = $65;
    } else {
     $67 = ((($$sink26$i)) + 36|0);
     $68 = HEAP32[$67>>2]|0;
     $69 = $68 & 1;
     $70 = ($69|0)!=(0);
     $$sink$i$i$i6 = $70 ? $55 : $1;
     $71 = +HEAPF32[$$sink$i$i$i6>>2];
     $72 = $68 & 2;
     $73 = ($72|0)!=(0);
     $$sink1$i$i$i7 = $73 ? $55 : $1;
     $74 = ((($$sink1$i$i$i7)) + 4|0);
     $75 = +HEAPF32[$74>>2];
     $76 = $68 & 4;
     $77 = ($76|0)!=(0);
     $$sink2$i$i$i8 = $77 ? $55 : $1;
     $78 = ((($$sink2$i$i$i8)) + 8|0);
     $79 = +HEAPF32[$78>>2];
     $80 = +HEAPF64[$$sink26$i>>3];
     $81 = $71;
     $82 = $81 * $80;
     $83 = ((($$sink26$i)) + 8|0);
     $84 = +HEAPF64[$83>>3];
     $85 = $75;
     $86 = $85 * $84;
     $87 = $82 + $86;
     $88 = ((($$sink26$i)) + 16|0);
     $89 = +HEAPF64[$88>>3];
     $90 = $79;
     $91 = $90 * $89;
     $92 = $87 + $91;
     $93 = ((($$sink26$i)) + 24|0);
     $94 = +HEAPF64[$93>>3];
     $95 = $94 + $92;
     $96 = $95;
     $97 = $96 > 0.0;
     if ($97) {
      $122 = $$01527$i ^ $65;
      HEAP32[$58>>2] = $122;
      $130 = $122;
      break;
     } else {
      $98 = ((($$sink26$i)) + 32|0);
      $99 = HEAP32[$98>>2]|0;
      $100 = $99 & 1;
      $101 = ($100|0)!=(0);
      $$sink$i3$i$i = $101 ? $55 : $1;
      $102 = +HEAPF32[$$sink$i3$i$i>>2];
      $103 = $99 & 2;
      $104 = ($103|0)!=(0);
      $$sink1$i4$i$i = $104 ? $55 : $1;
      $105 = ((($$sink1$i4$i$i)) + 4|0);
      $106 = +HEAPF32[$105>>2];
      $107 = $99 & 4;
      $108 = ($107|0)!=(0);
      $$sink2$i5$i$i = $108 ? $55 : $1;
      $109 = ((($$sink2$i5$i$i)) + 8|0);
      $110 = +HEAPF32[$109>>2];
      $111 = $102;
      $112 = $80 * $111;
      $113 = $106;
      $114 = $84 * $113;
      $115 = $112 + $114;
      $116 = $110;
      $117 = $89 * $116;
      $118 = $115 + $117;
      $119 = $94 + $118;
      $120 = $119;
      $121 = $120 < 0.0;
      if ($121) {
       break L20;
      } else {
       $130 = $65;
       break;
      }
     }
    }
   } while(0);
   $123 = $$01527$i << 1;
   $124 = ((($$sink26$i)) + 40|0);
   $125 = ($124|0)==($62|0);
   if ($125) {
    $128 = 0;
    label = 18;
    break L17;
   } else {
    $$01527$i = $123;$$sink26$i = $124;$65 = $130;
   }
  }
  $126 = ((($$sroa$011$017)) + 48|0);
  $127 = ($126|0)==($53|0);
  if ($127) {
   $128 = 1;
   label = 18;
   break;
  } else {
   $$sroa$011$017 = $126;
  }
 }
 if ((label|0) == 18) {
  return ($128|0);
 }
 return (0)|0;
}
function __ZN3osg25BuildShapeGeometryVisitorD2Ev($0) {
 $0 = $0|0;
 var $$0 = 0, $$02 = 0, $$1 = 0, $$13 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (65800);
 $1 = ((($0)) + 20|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  label = 4;
 } else {
  $4 = ((($2)) + 8|0);
  $5 = HEAP32[$4>>2]|0;HEAP32[$4>>2] = (($5-1)|0);
  $6 = ($5|0)==(1);
  if ($6) {
   __THREW__ = 0;
   invoke_viii(3262,($2|0),1,1);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $25 = ___cxa_find_matching_catch_2()|0;
    $26 = tempRet0;
    $27 = ((($0)) + 16|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = ($28|0)==(0|0);
    if (!($29)) {
     $30 = ((($28)) + 8|0);
     $31 = HEAP32[$30>>2]|0;HEAP32[$30>>2] = (($31-1)|0);
     $32 = ($31|0)==(1);
     if ($32) {
      __THREW__ = 0;
      invoke_viii(3262,($28|0),1,1);
      $33 = __THREW__; __THREW__ = 0;
      $34 = $33&1;
      if ($34) {
       $47 = ___cxa_find_matching_catch_3(0|0)|0;
       $48 = tempRet0;
       ___clang_call_terminate($47);
       // unreachable;
      }
     }
    }
    HEAP32[$27>>2] = 0;
    $$0 = $26;$$02 = $25;
   } else {
    label = 4;
   }
  } else {
   label = 4;
  }
 }
 do {
  if ((label|0) == 4) {
   HEAP32[$1>>2] = 0;
   $9 = ((($0)) + 16|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($10|0)==(0|0);
   if (!($11)) {
    $12 = ((($10)) + 8|0);
    $13 = HEAP32[$12>>2]|0;HEAP32[$12>>2] = (($13-1)|0);
    $14 = ($13|0)==(1);
    if ($14) {
     __THREW__ = 0;
     invoke_viii(3262,($10|0),1,1);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      $35 = ___cxa_find_matching_catch_2()|0;
      $36 = tempRet0;
      $$0 = $36;$$02 = $35;
      break;
     }
    }
   }
   HEAP32[$9>>2] = 0;
   $17 = ((($0)) + 12|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = ($18|0)==(0|0);
   if ($19) {
    HEAP32[$17>>2] = 0;
    return;
   }
   $20 = ((($18)) + 8|0);
   $21 = HEAP32[$20>>2]|0;HEAP32[$20>>2] = (($21-1)|0);
   $22 = ($21|0)==(1);
   if (!($22)) {
    HEAP32[$17>>2] = 0;
    return;
   }
   __THREW__ = 0;
   invoke_viii(3262,($18|0),1,1);
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if (!($24)) {
    HEAP32[$17>>2] = 0;
    return;
   }
   $37 = ___cxa_find_matching_catch_2()|0;
   $38 = tempRet0;
   $$1 = $38;$$13 = $37;
   ___resumeException($$13|0);
   // unreachable;
  }
 } while(0);
 $39 = ((($0)) + 12|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ($40|0)==(0|0);
 if (!($41)) {
  $42 = ((($40)) + 8|0);
  $43 = HEAP32[$42>>2]|0;HEAP32[$42>>2] = (($43-1)|0);
  $44 = ($43|0)==(1);
  if ($44) {
   __THREW__ = 0;
   invoke_viii(3262,($40|0),1,1);
   $45 = __THREW__; __THREW__ = 0;
   $46 = $45&1;
   if ($46) {
    $47 = ___cxa_find_matching_catch_3(0|0)|0;
    $48 = tempRet0;
    ___clang_call_terminate($47);
    // unreachable;
   }
  }
 }
 HEAP32[$39>>2] = 0;
 $$1 = $$0;$$13 = $$02;
 ___resumeException($$13|0);
 // unreachable;
}
function __ZN3osg25BuildShapeGeometryVisitorD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(2226,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZN3osg17ConstShapeVisitor5applyERKNS_5ShapeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN3osg25BuildShapeGeometryVisitor5applyERKNS_6SphereE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$ = 0, $$0 = 0, $$0232 = 0, $$0233286 = 0, $$0234285 = 0.0, $$0235284 = 0.0, $$0236314 = 0.0, $$0237312 = 0.0, $$0238310 = 0.0, $$0239308 = 0.0, $$0240307 = 0.0, $$0241305 = 0.0, $$0242295 = 0, $$0243293 = 0.0, $$0244292 = 0.0, $$0245291 = 0.0, $$0246290 = 0.0, $$0247288 = 0.0, $$0248287 = 0.0, $$0249304 = 0;
 var $$0250300 = 0, $$0251299 = 0.0, $$0252298 = 0.0, $$2 = 0, $$pre = 0.0, $$pre320 = 0.0, $10 = 0, $100 = 0.0, $101 = 0.0, $102 = 0.0, $103 = 0.0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0.0;
 var $112 = 0.0, $113 = 0.0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0.0, $152 = 0.0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0.0, $192 = 0.0, $193 = 0.0, $194 = 0.0, $195 = 0.0, $196 = 0.0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0;
 var $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0;
 var $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0.0, $226 = 0.0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0.0, $237 = 0.0, $238 = 0;
 var $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0;
 var $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0.0, $267 = 0.0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0;
 var $275 = 0, $276 = 0, $277 = 0, $278 = 0.0, $279 = 0.0, $28 = 0, $280 = 0, $281 = 0, $282 = 0.0, $283 = 0.0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0;
 var $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0;
 var $310 = 0.0, $311 = 0.0, $312 = 0.0, $313 = 0.0, $314 = 0.0, $315 = 0.0, $316 = 0.0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0;
 var $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0;
 var $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0;
 var $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0.0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0.0, $380 = 0, $381 = 0, $382 = 0;
 var $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0.0, $4 = 0, $40 = 0.0;
 var $400 = 0.0, $401 = 0.0, $402 = 0.0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0.0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0;
 var $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0.0, $430 = 0, $431 = 0.0, $432 = 0.0, $433 = 0, $434 = 0, $435 = 0, $436 = 0;
 var $437 = 0, $438 = 0, $439 = 0, $44 = 0.0, $440 = 0, $441 = 0, $442 = 0.0, $443 = 0.0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0;
 var $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0.0;
 var $473 = 0.0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0.0, $485 = 0.0, $486 = 0, $487 = 0, $49 = 0, $5 = 0, $50 = 0.0, $51 = 0;
 var $52 = 0, $53 = 0.0, $54 = 0, $55 = 0, $56 = 0.0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0.0, $62 = 0.0, $63 = 0.0, $64 = 0.0, $65 = 0.0, $66 = 0.0, $67 = 0, $68 = 0, $69 = 0.0, $7 = 0;
 var $70 = 0.0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0.0, $98 = 0.0, $99 = 0.0, $exitcond = 0, $exitcond317 = 0, $exitcond318 = 0, $exitcond319 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 384|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(384|0);
 $2 = sp + 184|0;
 $3 = sp + 372|0;
 $4 = sp + 360|0;
 $5 = sp + 176|0;
 $6 = sp + 348|0;
 $7 = sp + 336|0;
 $8 = sp + 168|0;
 $9 = sp + 324|0;
 $10 = sp + 312|0;
 $11 = sp + 160|0;
 $12 = sp + 300|0;
 $13 = sp + 288|0;
 $14 = sp + 276|0;
 $15 = sp + 152|0;
 $16 = sp + 264|0;
 $17 = sp + 252|0;
 $18 = sp + 144|0;
 $19 = sp + 240|0;
 $20 = sp + 228|0;
 $21 = sp + 136|0;
 $22 = sp + 216|0;
 $23 = sp + 204|0;
 $24 = sp + 128|0;
 $25 = sp + 192|0;
 $26 = sp;
 $27 = ((($0)) + 8|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = ($28|0)==(0|0);
 if ($29) {
  $486 = 1;$487 = 0;
 } else {
  $30 = ((($28)) + 44|0);
  $31 = HEAP8[$30>>0]|0;
  $32 = ($31<<24>>24)!=(0);
  $33 = ((($28)) + 45|0);
  $34 = HEAP8[$33>>0]|0;
  $35 = ($34<<24>>24)!=(0);
  $486 = $32;$487 = $35;
 }
 $36 = ((($1)) + 32|0);
 $37 = +HEAPF32[$36>>2];
 $38 = $37;
 $39 = ((($1)) + 36|0);
 $40 = +HEAPF32[$39>>2];
 $41 = $40;
 $42 = ((($1)) + 40|0);
 $43 = +HEAPF32[$42>>2];
 $44 = $43;
 __ZN3osg7Matrixd12makeIdentityEv($26);
 __ZN3osg7Matrixd13makeTranslateEddd($26,$38,$41,$44);
 __THREW__ = 0;
 invoke_vii(3911,($0|0),($26|0));
 $45 = __THREW__; __THREW__ = 0;
 $46 = $45&1;
 if ($46) {
  $59 = ___cxa_find_matching_catch_2()|0;
  $60 = tempRet0;
  ___resumeException($59|0);
  // unreachable;
 }
 $47 = HEAP32[$27>>2]|0;
 $48 = ($47|0)==(0|0);
 if ($48) {
  $$0 = 40;$$0232 = 20;
 } else {
  $49 = ((($47)) + 36|0);
  $50 = +HEAPF32[$49>>2];
  $51 = $50 > 0.0;
  $52 = $50 != 1.0;
  $or$cond = $51 & $52;
  if ($or$cond) {
   $53 = $50 * 20.0;
   $54 = (~~(($53))>>>0);
   $55 = ($54>>>0)>(3);
   $$ = $55 ? $54 : 3;
   $56 = $50 * 40.0;
   $57 = (~~(($56))>>>0);
   $58 = ($57>>>0)>(5);
   $$2 = $58 ? $57 : 5;
   $$0 = $$2;$$0232 = $$;
  } else {
   $$0 = 40;$$0232 = 20;
  }
 }
 $61 = (+($$0232>>>0));
 $62 = 3.1415927410125732 / $61;
 $63 = 1.0 / $61;
 $64 = (+($$0>>>0));
 $65 = 6.2831854820251465 / $64;
 $66 = 1.0 / $64;
 L11: do {
  if ($487) {
   $67 = ((($1)) + 44|0);
   $68 = ($$0232|0)==(0);
   if (!($68)) {
    $69 = +HEAPF32[$67>>2];
    $70 = -$69;
    $71 = ((($0)) + 24|0);
    $72 = ((($0)) + 12|0);
    $73 = ((($0)) + 28|0);
    $74 = ($$0|0)==(0);
    $75 = ((($0)) + 16|0);
    $76 = ((($12)) + 4|0);
    $77 = ((($12)) + 8|0);
    $78 = ((($0)) + 20|0);
    $79 = ((($11)) + 4|0);
    $80 = ((($10)) + 4|0);
    $81 = ((($10)) + 8|0);
    $82 = ((($9)) + 4|0);
    $83 = ((($9)) + 8|0);
    $84 = ((($8)) + 4|0);
    $85 = ((($7)) + 4|0);
    $86 = ((($7)) + 8|0);
    $87 = ((($6)) + 4|0);
    $88 = ((($6)) + 8|0);
    $89 = ((($5)) + 4|0);
    $90 = ((($4)) + 4|0);
    $91 = ((($4)) + 8|0);
    $92 = ((($3)) + 4|0);
    $93 = ((($3)) + 8|0);
    $94 = ((($2)) + 4|0);
    $95 = ((($13)) + 4|0);
    $96 = ((($13)) + 8|0);
    $$0236314 = -1.5707963705062866;$$0237312 = 0.0;$$0238310 = $70;$$0239308 = 0.0;$$0240307 = -1.0;$$0241305 = 0.0;$$0249304 = 0;$100 = $69;
    while(1) {
     $97 = $62 + $$0236314;
     $98 = (+Math_cos((+$97)));
     $99 = $98 * $100;
     $101 = (+Math_sin((+$97)));
     $102 = $100 * $101;
     $103 = $63 + $$0239308;
     HEAP32[$71>>2] = 8;
     $104 = HEAP32[$72>>2]|0;
     $105 = ((($104)) + 76|0);
     $106 = ((($104)) + 80|0);
     $107 = HEAP32[$106>>2]|0;
     $108 = HEAP32[$105>>2]|0;
     $109 = (($107) - ($108))|0;
     $110 = (($109|0) / 12)&-1;
     HEAP32[$73>>2] = $110;
     $111 = -$$0240307;
     if (!($74)) {
      $112 = -$101;
      $$0250300 = 0;$$0251299 = 0.0;$$0252298 = 0.0;
      while(1) {
       $191 = (+Math_cos((+$$0252298)));
       $192 = (+Math_sin((+$$0252298)));
       $193 = -$191;
       $194 = $$0241305 * $193;
       $195 = -$192;
       $196 = $$0241305 * $195;
       $197 = HEAP32[$75>>2]|0;
       HEAPF32[$6>>2] = $194;
       HEAPF32[$87>>2] = $196;
       HEAPF32[$88>>2] = $111;
       $198 = ((($197)) + 80|0);
       $199 = HEAP32[$198>>2]|0;
       $200 = ((($197)) + 84|0);
       $201 = HEAP32[$200>>2]|0;
       $202 = ($199|0)==($201|0);
       if ($202) {
        $205 = ((($197)) + 76|0);
        __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($205,$6);
       } else {
        ;HEAP32[$199>>2]=HEAP32[$6>>2]|0;HEAP32[$199+4>>2]=HEAP32[$6+4>>2]|0;HEAP32[$199+8>>2]=HEAP32[$6+8>>2]|0;
        $203 = HEAP32[$198>>2]|0;
        $204 = ((($203)) + 12|0);
        HEAP32[$198>>2] = $204;
       }
       $206 = HEAP32[$78>>2]|0;
       HEAPF32[$5>>2] = $$0251299;
       HEAPF32[$89>>2] = $$0239308;
       $207 = ((($206)) + 80|0);
       $208 = HEAP32[$207>>2]|0;
       $209 = ((($206)) + 84|0);
       $210 = HEAP32[$209>>2]|0;
       $211 = ($208|0)==($210|0);
       if ($211) {
        $224 = ((($206)) + 76|0);
        __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($224,$5);
       } else {
        $212 = $5;
        $213 = $212;
        $214 = HEAP32[$213>>2]|0;
        $215 = (($212) + 4)|0;
        $216 = $215;
        $217 = HEAP32[$216>>2]|0;
        $218 = $208;
        $219 = $218;
        HEAP32[$219>>2] = $214;
        $220 = (($218) + 4)|0;
        $221 = $220;
        HEAP32[$221>>2] = $217;
        $222 = HEAP32[$207>>2]|0;
        $223 = ((($222)) + 8|0);
        HEAP32[$207>>2] = $223;
       }
       $225 = $$0237312 * $191;
       $226 = $$0237312 * $192;
       $227 = HEAP32[$72>>2]|0;
       HEAPF32[$4>>2] = $225;
       HEAPF32[$90>>2] = $226;
       HEAPF32[$91>>2] = $$0238310;
       $228 = ((($227)) + 80|0);
       $229 = HEAP32[$228>>2]|0;
       $230 = ((($227)) + 84|0);
       $231 = HEAP32[$230>>2]|0;
       $232 = ($229|0)==($231|0);
       if ($232) {
        $235 = ((($227)) + 76|0);
        __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($235,$4);
       } else {
        ;HEAP32[$229>>2]=HEAP32[$4>>2]|0;HEAP32[$229+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$229+8>>2]=HEAP32[$4+8>>2]|0;
        $233 = HEAP32[$228>>2]|0;
        $234 = ((($233)) + 12|0);
        HEAP32[$228>>2] = $234;
       }
       $236 = $98 * $193;
       $237 = $98 * $195;
       $238 = HEAP32[$75>>2]|0;
       HEAPF32[$3>>2] = $236;
       HEAPF32[$92>>2] = $237;
       HEAPF32[$93>>2] = $112;
       $239 = ((($238)) + 80|0);
       $240 = HEAP32[$239>>2]|0;
       $241 = ((($238)) + 84|0);
       $242 = HEAP32[$241>>2]|0;
       $243 = ($240|0)==($242|0);
       if ($243) {
        $246 = ((($238)) + 76|0);
        __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($246,$3);
       } else {
        ;HEAP32[$240>>2]=HEAP32[$3>>2]|0;HEAP32[$240+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$240+8>>2]=HEAP32[$3+8>>2]|0;
        $244 = HEAP32[$239>>2]|0;
        $245 = ((($244)) + 12|0);
        HEAP32[$239>>2] = $245;
       }
       $247 = HEAP32[$78>>2]|0;
       HEAPF32[$2>>2] = $$0251299;
       HEAPF32[$94>>2] = $103;
       $248 = ((($247)) + 80|0);
       $249 = HEAP32[$248>>2]|0;
       $250 = ((($247)) + 84|0);
       $251 = HEAP32[$250>>2]|0;
       $252 = ($249|0)==($251|0);
       if ($252) {
        $265 = ((($247)) + 76|0);
        __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($265,$2);
       } else {
        $253 = $2;
        $254 = $253;
        $255 = HEAP32[$254>>2]|0;
        $256 = (($253) + 4)|0;
        $257 = $256;
        $258 = HEAP32[$257>>2]|0;
        $259 = $249;
        $260 = $259;
        HEAP32[$260>>2] = $255;
        $261 = (($259) + 4)|0;
        $262 = $261;
        HEAP32[$262>>2] = $258;
        $263 = HEAP32[$248>>2]|0;
        $264 = ((($263)) + 8|0);
        HEAP32[$248>>2] = $264;
       }
       $266 = $99 * $191;
       $267 = $99 * $192;
       $268 = HEAP32[$72>>2]|0;
       HEAPF32[$13>>2] = $266;
       HEAPF32[$95>>2] = $267;
       HEAPF32[$96>>2] = $102;
       $269 = ((($268)) + 80|0);
       $270 = HEAP32[$269>>2]|0;
       $271 = ((($268)) + 84|0);
       $272 = HEAP32[$271>>2]|0;
       $273 = ($270|0)==($272|0);
       if ($273) {
        $276 = ((($268)) + 76|0);
        __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($276,$13);
       } else {
        ;HEAP32[$270>>2]=HEAP32[$13>>2]|0;HEAP32[$270+4>>2]=HEAP32[$13+4>>2]|0;HEAP32[$270+8>>2]=HEAP32[$13+8>>2]|0;
        $274 = HEAP32[$269>>2]|0;
        $275 = ((($274)) + 12|0);
        HEAP32[$269>>2] = $275;
       }
       $277 = (($$0250300) + 1)|0;
       $278 = $65 + $$0252298;
       $279 = $66 + $$0251299;
       $exitcond318 = ($277|0)==($$0|0);
       if ($exitcond318) {
        break;
       } else {
        $$0250300 = $277;$$0251299 = $279;$$0252298 = $278;
       }
      }
     }
     $113 = -$$0241305;
     $114 = HEAP32[$75>>2]|0;
     HEAPF32[$12>>2] = $113;
     HEAPF32[$76>>2] = 0.0;
     HEAPF32[$77>>2] = $111;
     $115 = ((($114)) + 80|0);
     $116 = HEAP32[$115>>2]|0;
     $117 = ((($114)) + 84|0);
     $118 = HEAP32[$117>>2]|0;
     $119 = ($116|0)==($118|0);
     if ($119) {
      $122 = ((($114)) + 76|0);
      __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($122,$12);
     } else {
      ;HEAP32[$116>>2]=HEAP32[$12>>2]|0;HEAP32[$116+4>>2]=HEAP32[$12+4>>2]|0;HEAP32[$116+8>>2]=HEAP32[$12+8>>2]|0;
      $120 = HEAP32[$115>>2]|0;
      $121 = ((($120)) + 12|0);
      HEAP32[$115>>2] = $121;
     }
     $123 = HEAP32[$78>>2]|0;
     HEAPF32[$11>>2] = 1.0;
     HEAPF32[$79>>2] = $$0239308;
     $124 = ((($123)) + 80|0);
     $125 = HEAP32[$124>>2]|0;
     $126 = ((($123)) + 84|0);
     $127 = HEAP32[$126>>2]|0;
     $128 = ($125|0)==($127|0);
     if ($128) {
      $141 = ((($123)) + 76|0);
      __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($141,$11);
     } else {
      $129 = $11;
      $130 = $129;
      $131 = HEAP32[$130>>2]|0;
      $132 = (($129) + 4)|0;
      $133 = $132;
      $134 = HEAP32[$133>>2]|0;
      $135 = $125;
      $136 = $135;
      HEAP32[$136>>2] = $131;
      $137 = (($135) + 4)|0;
      $138 = $137;
      HEAP32[$138>>2] = $134;
      $139 = HEAP32[$124>>2]|0;
      $140 = ((($139)) + 8|0);
      HEAP32[$124>>2] = $140;
     }
     $142 = HEAP32[$72>>2]|0;
     HEAPF32[$10>>2] = $$0237312;
     HEAPF32[$80>>2] = 0.0;
     HEAPF32[$81>>2] = $$0238310;
     $143 = ((($142)) + 80|0);
     $144 = HEAP32[$143>>2]|0;
     $145 = ((($142)) + 84|0);
     $146 = HEAP32[$145>>2]|0;
     $147 = ($144|0)==($146|0);
     if ($147) {
      $150 = ((($142)) + 76|0);
      __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($150,$10);
     } else {
      ;HEAP32[$144>>2]=HEAP32[$10>>2]|0;HEAP32[$144+4>>2]=HEAP32[$10+4>>2]|0;HEAP32[$144+8>>2]=HEAP32[$10+8>>2]|0;
      $148 = HEAP32[$143>>2]|0;
      $149 = ((($148)) + 12|0);
      HEAP32[$143>>2] = $149;
     }
     $151 = -$98;
     $152 = -$101;
     $153 = HEAP32[$75>>2]|0;
     HEAPF32[$9>>2] = $151;
     HEAPF32[$82>>2] = 0.0;
     HEAPF32[$83>>2] = $152;
     $154 = ((($153)) + 80|0);
     $155 = HEAP32[$154>>2]|0;
     $156 = ((($153)) + 84|0);
     $157 = HEAP32[$156>>2]|0;
     $158 = ($155|0)==($157|0);
     if ($158) {
      $161 = ((($153)) + 76|0);
      __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($161,$9);
     } else {
      ;HEAP32[$155>>2]=HEAP32[$9>>2]|0;HEAP32[$155+4>>2]=HEAP32[$9+4>>2]|0;HEAP32[$155+8>>2]=HEAP32[$9+8>>2]|0;
      $159 = HEAP32[$154>>2]|0;
      $160 = ((($159)) + 12|0);
      HEAP32[$154>>2] = $160;
     }
     $162 = HEAP32[$78>>2]|0;
     HEAPF32[$8>>2] = 1.0;
     HEAPF32[$84>>2] = $103;
     $163 = ((($162)) + 80|0);
     $164 = HEAP32[$163>>2]|0;
     $165 = ((($162)) + 84|0);
     $166 = HEAP32[$165>>2]|0;
     $167 = ($164|0)==($166|0);
     if ($167) {
      $180 = ((($162)) + 76|0);
      __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($180,$8);
     } else {
      $168 = $8;
      $169 = $168;
      $170 = HEAP32[$169>>2]|0;
      $171 = (($168) + 4)|0;
      $172 = $171;
      $173 = HEAP32[$172>>2]|0;
      $174 = $164;
      $175 = $174;
      HEAP32[$175>>2] = $170;
      $176 = (($174) + 4)|0;
      $177 = $176;
      HEAP32[$177>>2] = $173;
      $178 = HEAP32[$163>>2]|0;
      $179 = ((($178)) + 8|0);
      HEAP32[$163>>2] = $179;
     }
     $181 = HEAP32[$72>>2]|0;
     HEAPF32[$7>>2] = $99;
     HEAPF32[$85>>2] = 0.0;
     HEAPF32[$86>>2] = $102;
     $182 = ((($181)) + 80|0);
     $183 = HEAP32[$182>>2]|0;
     $184 = ((($181)) + 84|0);
     $185 = HEAP32[$184>>2]|0;
     $186 = ($183|0)==($185|0);
     if ($186) {
      $189 = ((($181)) + 76|0);
      __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($189,$7);
     } else {
      ;HEAP32[$183>>2]=HEAP32[$7>>2]|0;HEAP32[$183+4>>2]=HEAP32[$7+4>>2]|0;HEAP32[$183+8>>2]=HEAP32[$7+8>>2]|0;
      $187 = HEAP32[$182>>2]|0;
      $188 = ((($187)) + 12|0);
      HEAP32[$182>>2] = $188;
     }
     __ZN3osg25BuildShapeGeometryVisitor3EndEv($0);
     $190 = (($$0249304) + 1)|0;
     $exitcond319 = ($190|0)==($$0232|0);
     if ($exitcond319) {
      break L11;
     }
     $$pre = +HEAPF32[$67>>2];
     $$0236314 = $97;$$0237312 = $99;$$0238310 = $102;$$0239308 = $103;$$0240307 = $101;$$0241305 = $98;$$0249304 = $190;$100 = $$pre;
    }
   }
  }
 } while(0);
 if (!($486)) {
  STACKTOP = sp;return;
 }
 $280 = ((($1)) + 44|0);
 $281 = ($$0232|0)==(0);
 if ($281) {
  STACKTOP = sp;return;
 }
 $282 = +HEAPF32[$280>>2];
 $283 = -$282;
 $284 = ((($0)) + 24|0);
 $285 = ((($0)) + 12|0);
 $286 = ((($0)) + 28|0);
 $287 = ($$0|0)==(0);
 $288 = ((($0)) + 16|0);
 $289 = ((($14)) + 4|0);
 $290 = ((($14)) + 8|0);
 $291 = ((($0)) + 20|0);
 $292 = ((($15)) + 4|0);
 $293 = ((($16)) + 4|0);
 $294 = ((($16)) + 8|0);
 $295 = ((($17)) + 4|0);
 $296 = ((($17)) + 8|0);
 $297 = ((($18)) + 4|0);
 $298 = ((($19)) + 4|0);
 $299 = ((($19)) + 8|0);
 $300 = ((($20)) + 4|0);
 $301 = ((($20)) + 8|0);
 $302 = ((($21)) + 4|0);
 $303 = ((($22)) + 4|0);
 $304 = ((($22)) + 8|0);
 $305 = ((($23)) + 4|0);
 $306 = ((($23)) + 8|0);
 $307 = ((($24)) + 4|0);
 $308 = ((($25)) + 4|0);
 $309 = ((($25)) + 8|0);
 $$0242295 = 0;$$0243293 = 0.0;$$0244292 = -1.0;$$0245291 = 0.0;$$0246290 = $283;$$0247288 = 0.0;$$0248287 = -1.5707963705062866;$313 = $282;
 while(1) {
  $310 = $62 + $$0248287;
  $311 = (+Math_cos((+$310)));
  $312 = $311 * $313;
  $314 = (+Math_sin((+$310)));
  $315 = $313 * $314;
  $316 = $63 + $$0245291;
  HEAP32[$284>>2] = 8;
  $317 = HEAP32[$285>>2]|0;
  $318 = ((($317)) + 76|0);
  $319 = ((($317)) + 80|0);
  $320 = HEAP32[$319>>2]|0;
  $321 = HEAP32[$318>>2]|0;
  $322 = (($320) - ($321))|0;
  $323 = (($322|0) / 12)&-1;
  HEAP32[$286>>2] = $323;
  if (!($287)) {
   $$0233286 = 0;$$0234285 = 0.0;$$0235284 = 0.0;
   while(1) {
    $399 = (+Math_cos((+$$0235284)));
    $400 = (+Math_sin((+$$0235284)));
    $401 = $311 * $399;
    $402 = $311 * $400;
    $403 = HEAP32[$288>>2]|0;
    HEAPF32[$20>>2] = $401;
    HEAPF32[$300>>2] = $402;
    HEAPF32[$301>>2] = $314;
    $404 = ((($403)) + 80|0);
    $405 = HEAP32[$404>>2]|0;
    $406 = ((($403)) + 84|0);
    $407 = HEAP32[$406>>2]|0;
    $408 = ($405|0)==($407|0);
    if ($408) {
     $411 = ((($403)) + 76|0);
     __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($411,$20);
    } else {
     ;HEAP32[$405>>2]=HEAP32[$20>>2]|0;HEAP32[$405+4>>2]=HEAP32[$20+4>>2]|0;HEAP32[$405+8>>2]=HEAP32[$20+8>>2]|0;
     $409 = HEAP32[$404>>2]|0;
     $410 = ((($409)) + 12|0);
     HEAP32[$404>>2] = $410;
    }
    $412 = HEAP32[$291>>2]|0;
    HEAPF32[$21>>2] = $$0234285;
    HEAPF32[$302>>2] = $316;
    $413 = ((($412)) + 80|0);
    $414 = HEAP32[$413>>2]|0;
    $415 = ((($412)) + 84|0);
    $416 = HEAP32[$415>>2]|0;
    $417 = ($414|0)==($416|0);
    if ($417) {
     $430 = ((($412)) + 76|0);
     __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($430,$21);
    } else {
     $418 = $21;
     $419 = $418;
     $420 = HEAP32[$419>>2]|0;
     $421 = (($418) + 4)|0;
     $422 = $421;
     $423 = HEAP32[$422>>2]|0;
     $424 = $414;
     $425 = $424;
     HEAP32[$425>>2] = $420;
     $426 = (($424) + 4)|0;
     $427 = $426;
     HEAP32[$427>>2] = $423;
     $428 = HEAP32[$413>>2]|0;
     $429 = ((($428)) + 8|0);
     HEAP32[$413>>2] = $429;
    }
    $431 = $312 * $399;
    $432 = $312 * $400;
    $433 = HEAP32[$285>>2]|0;
    HEAPF32[$22>>2] = $431;
    HEAPF32[$303>>2] = $432;
    HEAPF32[$304>>2] = $315;
    $434 = ((($433)) + 80|0);
    $435 = HEAP32[$434>>2]|0;
    $436 = ((($433)) + 84|0);
    $437 = HEAP32[$436>>2]|0;
    $438 = ($435|0)==($437|0);
    if ($438) {
     $441 = ((($433)) + 76|0);
     __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($441,$22);
    } else {
     ;HEAP32[$435>>2]=HEAP32[$22>>2]|0;HEAP32[$435+4>>2]=HEAP32[$22+4>>2]|0;HEAP32[$435+8>>2]=HEAP32[$22+8>>2]|0;
     $439 = HEAP32[$434>>2]|0;
     $440 = ((($439)) + 12|0);
     HEAP32[$434>>2] = $440;
    }
    $442 = $$0243293 * $399;
    $443 = $$0243293 * $400;
    $444 = HEAP32[$288>>2]|0;
    HEAPF32[$23>>2] = $442;
    HEAPF32[$305>>2] = $443;
    HEAPF32[$306>>2] = $$0244292;
    $445 = ((($444)) + 80|0);
    $446 = HEAP32[$445>>2]|0;
    $447 = ((($444)) + 84|0);
    $448 = HEAP32[$447>>2]|0;
    $449 = ($446|0)==($448|0);
    if ($449) {
     $452 = ((($444)) + 76|0);
     __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($452,$23);
    } else {
     ;HEAP32[$446>>2]=HEAP32[$23>>2]|0;HEAP32[$446+4>>2]=HEAP32[$23+4>>2]|0;HEAP32[$446+8>>2]=HEAP32[$23+8>>2]|0;
     $450 = HEAP32[$445>>2]|0;
     $451 = ((($450)) + 12|0);
     HEAP32[$445>>2] = $451;
    }
    $453 = HEAP32[$291>>2]|0;
    HEAPF32[$24>>2] = $$0234285;
    HEAPF32[$307>>2] = $$0245291;
    $454 = ((($453)) + 80|0);
    $455 = HEAP32[$454>>2]|0;
    $456 = ((($453)) + 84|0);
    $457 = HEAP32[$456>>2]|0;
    $458 = ($455|0)==($457|0);
    if ($458) {
     $471 = ((($453)) + 76|0);
     __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($471,$24);
    } else {
     $459 = $24;
     $460 = $459;
     $461 = HEAP32[$460>>2]|0;
     $462 = (($459) + 4)|0;
     $463 = $462;
     $464 = HEAP32[$463>>2]|0;
     $465 = $455;
     $466 = $465;
     HEAP32[$466>>2] = $461;
     $467 = (($465) + 4)|0;
     $468 = $467;
     HEAP32[$468>>2] = $464;
     $469 = HEAP32[$454>>2]|0;
     $470 = ((($469)) + 8|0);
     HEAP32[$454>>2] = $470;
    }
    $472 = $$0247288 * $399;
    $473 = $$0247288 * $400;
    $474 = HEAP32[$285>>2]|0;
    HEAPF32[$25>>2] = $472;
    HEAPF32[$308>>2] = $473;
    HEAPF32[$309>>2] = $$0246290;
    $475 = ((($474)) + 80|0);
    $476 = HEAP32[$475>>2]|0;
    $477 = ((($474)) + 84|0);
    $478 = HEAP32[$477>>2]|0;
    $479 = ($476|0)==($478|0);
    if ($479) {
     $482 = ((($474)) + 76|0);
     __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($482,$25);
    } else {
     ;HEAP32[$476>>2]=HEAP32[$25>>2]|0;HEAP32[$476+4>>2]=HEAP32[$25+4>>2]|0;HEAP32[$476+8>>2]=HEAP32[$25+8>>2]|0;
     $480 = HEAP32[$475>>2]|0;
     $481 = ((($480)) + 12|0);
     HEAP32[$475>>2] = $481;
    }
    $483 = (($$0233286) + 1)|0;
    $484 = $65 + $$0235284;
    $485 = $66 + $$0234285;
    $exitcond = ($483|0)==($$0|0);
    if ($exitcond) {
     break;
    } else {
     $$0233286 = $483;$$0234285 = $485;$$0235284 = $484;
    }
   }
  }
  $324 = HEAP32[$288>>2]|0;
  HEAPF32[$14>>2] = $311;
  HEAPF32[$289>>2] = 0.0;
  HEAPF32[$290>>2] = $314;
  $325 = ((($324)) + 80|0);
  $326 = HEAP32[$325>>2]|0;
  $327 = ((($324)) + 84|0);
  $328 = HEAP32[$327>>2]|0;
  $329 = ($326|0)==($328|0);
  if ($329) {
   $332 = ((($324)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($332,$14);
  } else {
   ;HEAP32[$326>>2]=HEAP32[$14>>2]|0;HEAP32[$326+4>>2]=HEAP32[$14+4>>2]|0;HEAP32[$326+8>>2]=HEAP32[$14+8>>2]|0;
   $330 = HEAP32[$325>>2]|0;
   $331 = ((($330)) + 12|0);
   HEAP32[$325>>2] = $331;
  }
  $333 = HEAP32[$291>>2]|0;
  HEAPF32[$15>>2] = 1.0;
  HEAPF32[$292>>2] = $316;
  $334 = ((($333)) + 80|0);
  $335 = HEAP32[$334>>2]|0;
  $336 = ((($333)) + 84|0);
  $337 = HEAP32[$336>>2]|0;
  $338 = ($335|0)==($337|0);
  if ($338) {
   $351 = ((($333)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($351,$15);
  } else {
   $339 = $15;
   $340 = $339;
   $341 = HEAP32[$340>>2]|0;
   $342 = (($339) + 4)|0;
   $343 = $342;
   $344 = HEAP32[$343>>2]|0;
   $345 = $335;
   $346 = $345;
   HEAP32[$346>>2] = $341;
   $347 = (($345) + 4)|0;
   $348 = $347;
   HEAP32[$348>>2] = $344;
   $349 = HEAP32[$334>>2]|0;
   $350 = ((($349)) + 8|0);
   HEAP32[$334>>2] = $350;
  }
  $352 = HEAP32[$285>>2]|0;
  HEAPF32[$16>>2] = $312;
  HEAPF32[$293>>2] = 0.0;
  HEAPF32[$294>>2] = $315;
  $353 = ((($352)) + 80|0);
  $354 = HEAP32[$353>>2]|0;
  $355 = ((($352)) + 84|0);
  $356 = HEAP32[$355>>2]|0;
  $357 = ($354|0)==($356|0);
  if ($357) {
   $360 = ((($352)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($360,$16);
  } else {
   ;HEAP32[$354>>2]=HEAP32[$16>>2]|0;HEAP32[$354+4>>2]=HEAP32[$16+4>>2]|0;HEAP32[$354+8>>2]=HEAP32[$16+8>>2]|0;
   $358 = HEAP32[$353>>2]|0;
   $359 = ((($358)) + 12|0);
   HEAP32[$353>>2] = $359;
  }
  $361 = HEAP32[$288>>2]|0;
  HEAPF32[$17>>2] = $$0243293;
  HEAPF32[$295>>2] = 0.0;
  HEAPF32[$296>>2] = $$0244292;
  $362 = ((($361)) + 80|0);
  $363 = HEAP32[$362>>2]|0;
  $364 = ((($361)) + 84|0);
  $365 = HEAP32[$364>>2]|0;
  $366 = ($363|0)==($365|0);
  if ($366) {
   $369 = ((($361)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($369,$17);
  } else {
   ;HEAP32[$363>>2]=HEAP32[$17>>2]|0;HEAP32[$363+4>>2]=HEAP32[$17+4>>2]|0;HEAP32[$363+8>>2]=HEAP32[$17+8>>2]|0;
   $367 = HEAP32[$362>>2]|0;
   $368 = ((($367)) + 12|0);
   HEAP32[$362>>2] = $368;
  }
  $370 = HEAP32[$291>>2]|0;
  HEAPF32[$18>>2] = 1.0;
  HEAPF32[$297>>2] = $$0245291;
  $371 = ((($370)) + 80|0);
  $372 = HEAP32[$371>>2]|0;
  $373 = ((($370)) + 84|0);
  $374 = HEAP32[$373>>2]|0;
  $375 = ($372|0)==($374|0);
  if ($375) {
   $388 = ((($370)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($388,$18);
  } else {
   $376 = $18;
   $377 = $376;
   $378 = HEAP32[$377>>2]|0;
   $379 = (($376) + 4)|0;
   $380 = $379;
   $381 = HEAP32[$380>>2]|0;
   $382 = $372;
   $383 = $382;
   HEAP32[$383>>2] = $378;
   $384 = (($382) + 4)|0;
   $385 = $384;
   HEAP32[$385>>2] = $381;
   $386 = HEAP32[$371>>2]|0;
   $387 = ((($386)) + 8|0);
   HEAP32[$371>>2] = $387;
  }
  $389 = HEAP32[$285>>2]|0;
  HEAPF32[$19>>2] = $$0247288;
  HEAPF32[$298>>2] = 0.0;
  HEAPF32[$299>>2] = $$0246290;
  $390 = ((($389)) + 80|0);
  $391 = HEAP32[$390>>2]|0;
  $392 = ((($389)) + 84|0);
  $393 = HEAP32[$392>>2]|0;
  $394 = ($391|0)==($393|0);
  if ($394) {
   $397 = ((($389)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($397,$19);
  } else {
   ;HEAP32[$391>>2]=HEAP32[$19>>2]|0;HEAP32[$391+4>>2]=HEAP32[$19+4>>2]|0;HEAP32[$391+8>>2]=HEAP32[$19+8>>2]|0;
   $395 = HEAP32[$390>>2]|0;
   $396 = ((($395)) + 12|0);
   HEAP32[$390>>2] = $396;
  }
  __ZN3osg25BuildShapeGeometryVisitor3EndEv($0);
  $398 = (($$0242295) + 1)|0;
  $exitcond317 = ($398|0)==($$0232|0);
  if ($exitcond317) {
   break;
  }
  $$pre320 = +HEAPF32[$280>>2];
  $$0242295 = $398;$$0243293 = $311;$$0244292 = $314;$$0245291 = $316;$$0246290 = $315;$$0247288 = $312;$$0248287 = $310;$313 = $$pre320;
 }
 STACKTOP = sp;return;
}
function __ZN3osg25BuildShapeGeometryVisitor5applyERKNS_3BoxE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $100 = 0, $1000 = 0, $1001 = 0, $1002 = 0, $1003 = 0, $1004 = 0, $1005 = 0, $1006 = 0, $1007 = 0, $1008 = 0, $1009 = 0.0, $101 = 0.0, $1010 = 0, $1011 = 0, $1012 = 0, $1013 = 0, $1014 = 0, $1015 = 0, $1016 = 0;
 var $1017 = 0, $1018 = 0, $1019 = 0, $102 = 0, $1020 = 0, $1021 = 0, $1022 = 0, $1023 = 0, $1024 = 0, $1025 = 0, $1026 = 0, $1027 = 0, $1028 = 0, $1029 = 0, $103 = 0, $1030 = 0, $1031 = 0, $1032 = 0, $1033 = 0, $1034 = 0;
 var $1035 = 0, $1036 = 0, $1037 = 0, $1038 = 0, $1039 = 0, $104 = 0.0, $1040 = 0, $1041 = 0, $1042 = 0, $1043 = 0, $1044 = 0, $1045 = 0, $1046 = 0, $1047 = 0, $1048 = 0, $1049 = 0, $105 = 0.0, $1050 = 0, $1051 = 0, $1052 = 0.0;
 var $1053 = 0, $1054 = 0, $1055 = 0, $1056 = 0, $1057 = 0, $1058 = 0, $1059 = 0, $106 = 0.0, $1060 = 0, $1061 = 0, $1062 = 0, $1063 = 0, $1064 = 0, $1065 = 0, $1066 = 0, $1067 = 0, $1068 = 0, $1069 = 0, $107 = 0, $1070 = 0;
 var $1071 = 0, $1072 = 0, $1073 = 0, $1074 = 0, $1075 = 0, $1076 = 0, $1077 = 0, $1078 = 0, $1079 = 0, $108 = 0, $1080 = 0, $1081 = 0, $1082 = 0, $1083 = 0, $1084 = 0, $1085 = 0, $1086 = 0, $1087 = 0, $1088 = 0, $1089 = 0;
 var $109 = 0, $1090 = 0, $1091 = 0, $1092 = 0, $1093 = 0, $1094 = 0, $1095 = 0.0, $1096 = 0, $1097 = 0, $1098 = 0, $1099 = 0, $11 = 0, $110 = 0, $1100 = 0, $1101 = 0, $1102 = 0, $1103 = 0, $1104 = 0, $1105 = 0, $1106 = 0;
 var $1107 = 0, $1108 = 0, $1109 = 0, $111 = 0, $1110 = 0, $1111 = 0, $1112 = 0, $1113 = 0, $1114 = 0, $1115 = 0, $1116 = 0, $1117 = 0, $1118 = 0, $1119 = 0, $112 = 0, $1120 = 0, $1121 = 0, $1122 = 0, $1123 = 0, $1124 = 0;
 var $1125 = 0, $1126 = 0, $1127 = 0, $1128 = 0, $1129 = 0, $113 = 0, $1130 = 0, $1131 = 0, $1132 = 0, $1133 = 0, $1134 = 0, $1135 = 0, $1136 = 0, $1137 = 0, $1138 = 0, $1139 = 0, $114 = 0, $1140 = 0, $1141 = 0, $1142 = 0;
 var $1143 = 0, $1144 = 0, $1145 = 0, $1146 = 0, $1147 = 0, $1148 = 0, $1149 = 0, $115 = 0, $1150 = 0, $1151 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0;
 var $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0.0, $159 = 0.0, $16 = 0, $160 = 0;
 var $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0;
 var $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0;
 var $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0.0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0;
 var $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0;
 var $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0;
 var $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0;
 var $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0;
 var $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0;
 var $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0;
 var $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0;
 var $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0;
 var $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0;
 var $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0;
 var $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0;
 var $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0;
 var $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0;
 var $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0;
 var $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0;
 var $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0;
 var $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0;
 var $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0;
 var $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0;
 var $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0;
 var $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0;
 var $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0;
 var $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0;
 var $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0;
 var $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0;
 var $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0;
 var $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0;
 var $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0;
 var $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0;
 var $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0;
 var $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0;
 var $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0;
 var $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0;
 var $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0;
 var $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = 0, $834 = 0, $835 = 0, $836 = 0, $837 = 0.0, $838 = 0, $839 = 0, $84 = 0, $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0;
 var $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0, $850 = 0, $851 = 0, $852 = 0, $853 = 0, $854 = 0, $855 = 0, $856 = 0, $857 = 0, $858 = 0, $859 = 0, $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0;
 var $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0, $869 = 0, $87 = 0, $870 = 0, $871 = 0, $872 = 0, $873 = 0, $874 = 0, $875 = 0, $876 = 0, $877 = 0, $878 = 0, $879 = 0, $88 = 0, $880 = 0.0, $881 = 0;
 var $882 = 0, $883 = 0, $884 = 0, $885 = 0, $886 = 0, $887 = 0, $888 = 0, $889 = 0, $89 = 0, $890 = 0, $891 = 0, $892 = 0, $893 = 0, $894 = 0, $895 = 0, $896 = 0, $897 = 0, $898 = 0, $899 = 0, $9 = 0;
 var $90 = 0.0, $900 = 0, $901 = 0, $902 = 0, $903 = 0, $904 = 0, $905 = 0, $906 = 0, $907 = 0, $908 = 0, $909 = 0, $91 = 0, $910 = 0, $911 = 0, $912 = 0, $913 = 0, $914 = 0, $915 = 0, $916 = 0, $917 = 0;
 var $918 = 0, $919 = 0, $92 = 0.0, $920 = 0, $921 = 0, $922 = 0, $923 = 0, $924 = 0, $925 = 0, $926 = 0, $927 = 0, $928 = 0, $929 = 0, $93 = 0, $930 = 0, $931 = 0, $932 = 0, $933 = 0, $934 = 0, $935 = 0;
 var $936 = 0, $937 = 0, $938 = 0, $939 = 0, $94 = 0.0, $940 = 0, $941 = 0, $942 = 0, $943 = 0, $944 = 0, $945 = 0, $946 = 0, $947 = 0, $948 = 0, $949 = 0, $95 = 0, $950 = 0, $951 = 0, $952 = 0, $953 = 0;
 var $954 = 0, $955 = 0, $956 = 0, $957 = 0, $958 = 0, $959 = 0, $96 = 0, $960 = 0, $961 = 0, $962 = 0, $963 = 0, $964 = 0, $965 = 0, $966 = 0, $967 = 0, $968 = 0, $969 = 0, $97 = 0.0, $970 = 0, $971 = 0;
 var $972 = 0, $973 = 0, $974 = 0, $975 = 0, $976 = 0, $977 = 0, $978 = 0, $979 = 0, $98 = 0, $980 = 0, $981 = 0, $982 = 0, $983 = 0, $984 = 0, $985 = 0, $986 = 0, $987 = 0, $988 = 0, $989 = 0, $99 = 0.0;
 var $990 = 0, $991 = 0, $992 = 0, $993 = 0, $994 = 0, $995 = 0, $996 = 0, $997 = 0, $998 = 0, $999 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1152|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(1152|0);
 $2 = sp + 1140|0;
 $3 = sp + 1128|0;
 $4 = sp + 568|0;
 $5 = sp + 1116|0;
 $6 = sp + 1104|0;
 $7 = sp + 560|0;
 $8 = sp + 1092|0;
 $9 = sp + 1080|0;
 $10 = sp + 552|0;
 $11 = sp + 1068|0;
 $12 = sp + 544|0;
 $13 = sp + 1056|0;
 $14 = sp + 1044|0;
 $15 = sp + 1032|0;
 $16 = sp + 536|0;
 $17 = sp + 1020|0;
 $18 = sp + 1008|0;
 $19 = sp + 528|0;
 $20 = sp + 996|0;
 $21 = sp + 984|0;
 $22 = sp + 520|0;
 $23 = sp + 972|0;
 $24 = sp + 960|0;
 $25 = sp + 512|0;
 $26 = sp + 948|0;
 $27 = sp + 936|0;
 $28 = sp + 504|0;
 $29 = sp + 924|0;
 $30 = sp + 912|0;
 $31 = sp + 496|0;
 $32 = sp + 900|0;
 $33 = sp + 888|0;
 $34 = sp + 488|0;
 $35 = sp + 876|0;
 $36 = sp + 864|0;
 $37 = sp + 480|0;
 $38 = sp + 852|0;
 $39 = sp + 840|0;
 $40 = sp + 472|0;
 $41 = sp + 828|0;
 $42 = sp + 816|0;
 $43 = sp + 464|0;
 $44 = sp + 804|0;
 $45 = sp + 792|0;
 $46 = sp + 456|0;
 $47 = sp + 780|0;
 $48 = sp + 768|0;
 $49 = sp + 448|0;
 $50 = sp + 756|0;
 $51 = sp + 744|0;
 $52 = sp + 440|0;
 $53 = sp + 732|0;
 $54 = sp + 720|0;
 $55 = sp + 432|0;
 $56 = sp + 708|0;
 $57 = sp + 696|0;
 $58 = sp + 424|0;
 $59 = sp + 684|0;
 $60 = sp + 672|0;
 $61 = sp + 416|0;
 $62 = sp + 660|0;
 $63 = sp + 408|0;
 $64 = sp + 648|0;
 $65 = sp + 636|0;
 $66 = sp + 400|0;
 $67 = sp + 624|0;
 $68 = sp + 612|0;
 $69 = sp + 392|0;
 $70 = sp + 600|0;
 $71 = sp + 588|0;
 $72 = sp + 384|0;
 $73 = sp + 576|0;
 $74 = sp + 256|0;
 $75 = sp + 128|0;
 $76 = sp;
 $77 = ((($0)) + 8|0);
 $78 = HEAP32[$77>>2]|0;
 $79 = ($78|0)==(0|0);
 if ($79) {
  $1149 = 1;$1150 = 1;$1151 = 1;
 } else {
  $80 = ((($78)) + 49|0);
  $81 = HEAP8[$80>>0]|0;
  $82 = ($81<<24>>24)!=(0);
  $83 = ((($78)) + 48|0);
  $84 = HEAP8[$83>>0]|0;
  $85 = ($84<<24>>24)!=(0);
  $86 = ((($78)) + 50|0);
  $87 = HEAP8[$86>>0]|0;
  $88 = ($87<<24>>24)!=(0);
  $1149 = $85;$1150 = $82;$1151 = $88;
 }
 $89 = ((($1)) + 44|0);
 $90 = +HEAPF32[$89>>2];
 $91 = ((($1)) + 48|0);
 $92 = +HEAPF32[$91>>2];
 $93 = ((($1)) + 52|0);
 $94 = +HEAPF32[$93>>2];
 $95 = ((($1)) + 56|0);
 __ZN3osg7Matrixd10makeRotateERKNS_4QuatE($75,$95);
 $96 = ((($1)) + 32|0);
 $97 = +HEAPF32[$96>>2];
 $98 = ((($1)) + 36|0);
 $99 = +HEAPF32[$98>>2];
 $100 = ((($1)) + 40|0);
 $101 = +HEAPF32[$100>>2];
 __THREW__ = 0;
 invoke_vi(3299,($76|0));
 $102 = __THREW__; __THREW__ = 0;
 $103 = $102&1;
 if ($103) {
  $802 = ___cxa_find_matching_catch_2()|0;
  $803 = tempRet0;
  ___resumeException($802|0);
  // unreachable;
 }
 $104 = $101;
 $105 = $99;
 $106 = $97;
 __THREW__ = 0;
 invoke_viddd(3306,($76|0),(+$106),(+$105),(+$104));
 $107 = __THREW__; __THREW__ = 0;
 $108 = $107&1;
 if ($108) {
  $802 = ___cxa_find_matching_catch_2()|0;
  $803 = tempRet0;
  ___resumeException($802|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_vi(3299,($74|0));
 $109 = __THREW__; __THREW__ = 0;
 $110 = $109&1;
 if ($110) {
  $802 = ___cxa_find_matching_catch_2()|0;
  $803 = tempRet0;
  ___resumeException($802|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(3300,($74|0),($75|0),($76|0));
 $111 = __THREW__; __THREW__ = 0;
 $112 = $111&1;
 if ($112) {
  $802 = ___cxa_find_matching_catch_2()|0;
  $803 = tempRet0;
  ___resumeException($802|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_vii(3911,($0|0),($74|0));
 $113 = __THREW__; __THREW__ = 0;
 $114 = $113&1;
 if ($114) {
  $802 = ___cxa_find_matching_catch_2()|0;
  $803 = tempRet0;
  ___resumeException($802|0);
  // unreachable;
 }
 $115 = ((($0)) + 24|0);
 HEAP32[$115>>2] = 7;
 $116 = ((($0)) + 12|0);
 $117 = HEAP32[$116>>2]|0;
 $118 = ((($117)) + 76|0);
 $119 = ((($117)) + 80|0);
 $120 = HEAP32[$119>>2]|0;
 $121 = HEAP32[$118>>2]|0;
 $122 = (($120) - ($121))|0;
 $123 = (($122|0) / 12)&-1;
 $124 = ((($0)) + 28|0);
 HEAP32[$124>>2] = $123;
 if ($1150) {
  $125 = ((($0)) + 16|0);
  $126 = HEAP32[$125>>2]|0;
  HEAPF32[$62>>2] = 0.0;
  $127 = ((($62)) + 4|0);
  HEAPF32[$127>>2] = -1.0;
  $128 = ((($62)) + 8|0);
  HEAPF32[$128>>2] = 0.0;
  $129 = ((($126)) + 80|0);
  $130 = HEAP32[$129>>2]|0;
  $131 = ((($126)) + 84|0);
  $132 = HEAP32[$131>>2]|0;
  $133 = ($130|0)==($132|0);
  if ($133) {
   $136 = ((($126)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($136,$62);
  } else {
   ;HEAP32[$130>>2]=HEAP32[$62>>2]|0;HEAP32[$130+4>>2]=HEAP32[$62+4>>2]|0;HEAP32[$130+8>>2]=HEAP32[$62+8>>2]|0;
   $134 = HEAP32[$129>>2]|0;
   $135 = ((($134)) + 12|0);
   HEAP32[$129>>2] = $135;
  }
  $137 = ((($0)) + 20|0);
  $138 = HEAP32[$137>>2]|0;
  HEAPF32[$61>>2] = 0.0;
  $139 = ((($61)) + 4|0);
  HEAPF32[$139>>2] = 1.0;
  $140 = ((($138)) + 80|0);
  $141 = HEAP32[$140>>2]|0;
  $142 = ((($138)) + 84|0);
  $143 = HEAP32[$142>>2]|0;
  $144 = ($141|0)==($143|0);
  if ($144) {
   $157 = ((($138)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($157,$61);
  } else {
   $145 = $61;
   $146 = $145;
   $147 = HEAP32[$146>>2]|0;
   $148 = (($145) + 4)|0;
   $149 = $148;
   $150 = HEAP32[$149>>2]|0;
   $151 = $141;
   $152 = $151;
   HEAP32[$152>>2] = $147;
   $153 = (($151) + 4)|0;
   $154 = $153;
   HEAP32[$154>>2] = $150;
   $155 = HEAP32[$140>>2]|0;
   $156 = ((($155)) + 8|0);
   HEAP32[$140>>2] = $156;
  }
  $158 = -$90;
  $159 = -$92;
  $160 = HEAP32[$116>>2]|0;
  HEAPF32[$60>>2] = $158;
  $161 = ((($60)) + 4|0);
  HEAPF32[$161>>2] = $159;
  $162 = ((($60)) + 8|0);
  HEAPF32[$162>>2] = $94;
  $163 = ((($160)) + 80|0);
  $164 = HEAP32[$163>>2]|0;
  $165 = ((($160)) + 84|0);
  $166 = HEAP32[$165>>2]|0;
  $167 = ($164|0)==($166|0);
  if ($167) {
   $170 = ((($160)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($170,$60);
  } else {
   ;HEAP32[$164>>2]=HEAP32[$60>>2]|0;HEAP32[$164+4>>2]=HEAP32[$60+4>>2]|0;HEAP32[$164+8>>2]=HEAP32[$60+8>>2]|0;
   $168 = HEAP32[$163>>2]|0;
   $169 = ((($168)) + 12|0);
   HEAP32[$163>>2] = $169;
  }
  $171 = HEAP32[$125>>2]|0;
  HEAPF32[$59>>2] = 0.0;
  $172 = ((($59)) + 4|0);
  HEAPF32[$172>>2] = -1.0;
  $173 = ((($59)) + 8|0);
  HEAPF32[$173>>2] = 0.0;
  $174 = ((($171)) + 80|0);
  $175 = HEAP32[$174>>2]|0;
  $176 = ((($171)) + 84|0);
  $177 = HEAP32[$176>>2]|0;
  $178 = ($175|0)==($177|0);
  if ($178) {
   $181 = ((($171)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($181,$59);
  } else {
   ;HEAP32[$175>>2]=HEAP32[$59>>2]|0;HEAP32[$175+4>>2]=HEAP32[$59+4>>2]|0;HEAP32[$175+8>>2]=HEAP32[$59+8>>2]|0;
   $179 = HEAP32[$174>>2]|0;
   $180 = ((($179)) + 12|0);
   HEAP32[$174>>2] = $180;
  }
  $182 = HEAP32[$137>>2]|0;
  HEAPF32[$58>>2] = 0.0;
  $183 = ((($58)) + 4|0);
  HEAPF32[$183>>2] = 0.0;
  $184 = ((($182)) + 80|0);
  $185 = HEAP32[$184>>2]|0;
  $186 = ((($182)) + 84|0);
  $187 = HEAP32[$186>>2]|0;
  $188 = ($185|0)==($187|0);
  if ($188) {
   $201 = ((($182)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($201,$58);
  } else {
   $189 = $58;
   $190 = $189;
   $191 = HEAP32[$190>>2]|0;
   $192 = (($189) + 4)|0;
   $193 = $192;
   $194 = HEAP32[$193>>2]|0;
   $195 = $185;
   $196 = $195;
   HEAP32[$196>>2] = $191;
   $197 = (($195) + 4)|0;
   $198 = $197;
   HEAP32[$198>>2] = $194;
   $199 = HEAP32[$184>>2]|0;
   $200 = ((($199)) + 8|0);
   HEAP32[$184>>2] = $200;
  }
  $202 = -$94;
  $203 = HEAP32[$116>>2]|0;
  HEAPF32[$57>>2] = $158;
  $204 = ((($57)) + 4|0);
  HEAPF32[$204>>2] = $159;
  $205 = ((($57)) + 8|0);
  HEAPF32[$205>>2] = $202;
  $206 = ((($203)) + 80|0);
  $207 = HEAP32[$206>>2]|0;
  $208 = ((($203)) + 84|0);
  $209 = HEAP32[$208>>2]|0;
  $210 = ($207|0)==($209|0);
  if ($210) {
   $213 = ((($203)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($213,$57);
  } else {
   ;HEAP32[$207>>2]=HEAP32[$57>>2]|0;HEAP32[$207+4>>2]=HEAP32[$57+4>>2]|0;HEAP32[$207+8>>2]=HEAP32[$57+8>>2]|0;
   $211 = HEAP32[$206>>2]|0;
   $212 = ((($211)) + 12|0);
   HEAP32[$206>>2] = $212;
  }
  $214 = HEAP32[$125>>2]|0;
  HEAPF32[$56>>2] = 0.0;
  $215 = ((($56)) + 4|0);
  HEAPF32[$215>>2] = -1.0;
  $216 = ((($56)) + 8|0);
  HEAPF32[$216>>2] = 0.0;
  $217 = ((($214)) + 80|0);
  $218 = HEAP32[$217>>2]|0;
  $219 = ((($214)) + 84|0);
  $220 = HEAP32[$219>>2]|0;
  $221 = ($218|0)==($220|0);
  if ($221) {
   $224 = ((($214)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($224,$56);
  } else {
   ;HEAP32[$218>>2]=HEAP32[$56>>2]|0;HEAP32[$218+4>>2]=HEAP32[$56+4>>2]|0;HEAP32[$218+8>>2]=HEAP32[$56+8>>2]|0;
   $222 = HEAP32[$217>>2]|0;
   $223 = ((($222)) + 12|0);
   HEAP32[$217>>2] = $223;
  }
  $225 = HEAP32[$137>>2]|0;
  HEAPF32[$55>>2] = 1.0;
  $226 = ((($55)) + 4|0);
  HEAPF32[$226>>2] = 0.0;
  $227 = ((($225)) + 80|0);
  $228 = HEAP32[$227>>2]|0;
  $229 = ((($225)) + 84|0);
  $230 = HEAP32[$229>>2]|0;
  $231 = ($228|0)==($230|0);
  if ($231) {
   $244 = ((($225)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($244,$55);
  } else {
   $232 = $55;
   $233 = $232;
   $234 = HEAP32[$233>>2]|0;
   $235 = (($232) + 4)|0;
   $236 = $235;
   $237 = HEAP32[$236>>2]|0;
   $238 = $228;
   $239 = $238;
   HEAP32[$239>>2] = $234;
   $240 = (($238) + 4)|0;
   $241 = $240;
   HEAP32[$241>>2] = $237;
   $242 = HEAP32[$227>>2]|0;
   $243 = ((($242)) + 8|0);
   HEAP32[$227>>2] = $243;
  }
  $245 = HEAP32[$116>>2]|0;
  HEAPF32[$54>>2] = $90;
  $246 = ((($54)) + 4|0);
  HEAPF32[$246>>2] = $159;
  $247 = ((($54)) + 8|0);
  HEAPF32[$247>>2] = $202;
  $248 = ((($245)) + 80|0);
  $249 = HEAP32[$248>>2]|0;
  $250 = ((($245)) + 84|0);
  $251 = HEAP32[$250>>2]|0;
  $252 = ($249|0)==($251|0);
  if ($252) {
   $255 = ((($245)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($255,$54);
  } else {
   ;HEAP32[$249>>2]=HEAP32[$54>>2]|0;HEAP32[$249+4>>2]=HEAP32[$54+4>>2]|0;HEAP32[$249+8>>2]=HEAP32[$54+8>>2]|0;
   $253 = HEAP32[$248>>2]|0;
   $254 = ((($253)) + 12|0);
   HEAP32[$248>>2] = $254;
  }
  $256 = HEAP32[$125>>2]|0;
  HEAPF32[$53>>2] = 0.0;
  $257 = ((($53)) + 4|0);
  HEAPF32[$257>>2] = -1.0;
  $258 = ((($53)) + 8|0);
  HEAPF32[$258>>2] = 0.0;
  $259 = ((($256)) + 80|0);
  $260 = HEAP32[$259>>2]|0;
  $261 = ((($256)) + 84|0);
  $262 = HEAP32[$261>>2]|0;
  $263 = ($260|0)==($262|0);
  if ($263) {
   $266 = ((($256)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($266,$53);
  } else {
   ;HEAP32[$260>>2]=HEAP32[$53>>2]|0;HEAP32[$260+4>>2]=HEAP32[$53+4>>2]|0;HEAP32[$260+8>>2]=HEAP32[$53+8>>2]|0;
   $264 = HEAP32[$259>>2]|0;
   $265 = ((($264)) + 12|0);
   HEAP32[$259>>2] = $265;
  }
  $267 = HEAP32[$137>>2]|0;
  HEAPF32[$52>>2] = 1.0;
  $268 = ((($52)) + 4|0);
  HEAPF32[$268>>2] = 1.0;
  $269 = ((($267)) + 80|0);
  $270 = HEAP32[$269>>2]|0;
  $271 = ((($267)) + 84|0);
  $272 = HEAP32[$271>>2]|0;
  $273 = ($270|0)==($272|0);
  if ($273) {
   $286 = ((($267)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($286,$52);
  } else {
   $274 = $52;
   $275 = $274;
   $276 = HEAP32[$275>>2]|0;
   $277 = (($274) + 4)|0;
   $278 = $277;
   $279 = HEAP32[$278>>2]|0;
   $280 = $270;
   $281 = $280;
   HEAP32[$281>>2] = $276;
   $282 = (($280) + 4)|0;
   $283 = $282;
   HEAP32[$283>>2] = $279;
   $284 = HEAP32[$269>>2]|0;
   $285 = ((($284)) + 8|0);
   HEAP32[$269>>2] = $285;
  }
  $287 = HEAP32[$116>>2]|0;
  HEAPF32[$51>>2] = $90;
  $288 = ((($51)) + 4|0);
  HEAPF32[$288>>2] = $159;
  $289 = ((($51)) + 8|0);
  HEAPF32[$289>>2] = $94;
  $290 = ((($287)) + 80|0);
  $291 = HEAP32[$290>>2]|0;
  $292 = ((($287)) + 84|0);
  $293 = HEAP32[$292>>2]|0;
  $294 = ($291|0)==($293|0);
  if ($294) {
   $297 = ((($287)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($297,$51);
  } else {
   ;HEAP32[$291>>2]=HEAP32[$51>>2]|0;HEAP32[$291+4>>2]=HEAP32[$51+4>>2]|0;HEAP32[$291+8>>2]=HEAP32[$51+8>>2]|0;
   $295 = HEAP32[$290>>2]|0;
   $296 = ((($295)) + 12|0);
   HEAP32[$290>>2] = $296;
  }
  $298 = HEAP32[$125>>2]|0;
  HEAPF32[$50>>2] = 0.0;
  $299 = ((($50)) + 4|0);
  HEAPF32[$299>>2] = 1.0;
  $300 = ((($50)) + 8|0);
  HEAPF32[$300>>2] = 0.0;
  $301 = ((($298)) + 80|0);
  $302 = HEAP32[$301>>2]|0;
  $303 = ((($298)) + 84|0);
  $304 = HEAP32[$303>>2]|0;
  $305 = ($302|0)==($304|0);
  if ($305) {
   $308 = ((($298)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($308,$50);
  } else {
   ;HEAP32[$302>>2]=HEAP32[$50>>2]|0;HEAP32[$302+4>>2]=HEAP32[$50+4>>2]|0;HEAP32[$302+8>>2]=HEAP32[$50+8>>2]|0;
   $306 = HEAP32[$301>>2]|0;
   $307 = ((($306)) + 12|0);
   HEAP32[$301>>2] = $307;
  }
  $309 = HEAP32[$137>>2]|0;
  HEAPF32[$49>>2] = 0.0;
  $310 = ((($49)) + 4|0);
  HEAPF32[$310>>2] = 1.0;
  $311 = ((($309)) + 80|0);
  $312 = HEAP32[$311>>2]|0;
  $313 = ((($309)) + 84|0);
  $314 = HEAP32[$313>>2]|0;
  $315 = ($312|0)==($314|0);
  if ($315) {
   $328 = ((($309)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($328,$49);
  } else {
   $316 = $49;
   $317 = $316;
   $318 = HEAP32[$317>>2]|0;
   $319 = (($316) + 4)|0;
   $320 = $319;
   $321 = HEAP32[$320>>2]|0;
   $322 = $312;
   $323 = $322;
   HEAP32[$323>>2] = $318;
   $324 = (($322) + 4)|0;
   $325 = $324;
   HEAP32[$325>>2] = $321;
   $326 = HEAP32[$311>>2]|0;
   $327 = ((($326)) + 8|0);
   HEAP32[$311>>2] = $327;
  }
  $329 = HEAP32[$116>>2]|0;
  HEAPF32[$48>>2] = $90;
  $330 = ((($48)) + 4|0);
  HEAPF32[$330>>2] = $92;
  $331 = ((($48)) + 8|0);
  HEAPF32[$331>>2] = $94;
  $332 = ((($329)) + 80|0);
  $333 = HEAP32[$332>>2]|0;
  $334 = ((($329)) + 84|0);
  $335 = HEAP32[$334>>2]|0;
  $336 = ($333|0)==($335|0);
  if ($336) {
   $339 = ((($329)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($339,$48);
  } else {
   ;HEAP32[$333>>2]=HEAP32[$48>>2]|0;HEAP32[$333+4>>2]=HEAP32[$48+4>>2]|0;HEAP32[$333+8>>2]=HEAP32[$48+8>>2]|0;
   $337 = HEAP32[$332>>2]|0;
   $338 = ((($337)) + 12|0);
   HEAP32[$332>>2] = $338;
  }
  $340 = HEAP32[$125>>2]|0;
  HEAPF32[$47>>2] = 0.0;
  $341 = ((($47)) + 4|0);
  HEAPF32[$341>>2] = 1.0;
  $342 = ((($47)) + 8|0);
  HEAPF32[$342>>2] = 0.0;
  $343 = ((($340)) + 80|0);
  $344 = HEAP32[$343>>2]|0;
  $345 = ((($340)) + 84|0);
  $346 = HEAP32[$345>>2]|0;
  $347 = ($344|0)==($346|0);
  if ($347) {
   $350 = ((($340)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($350,$47);
  } else {
   ;HEAP32[$344>>2]=HEAP32[$47>>2]|0;HEAP32[$344+4>>2]=HEAP32[$47+4>>2]|0;HEAP32[$344+8>>2]=HEAP32[$47+8>>2]|0;
   $348 = HEAP32[$343>>2]|0;
   $349 = ((($348)) + 12|0);
   HEAP32[$343>>2] = $349;
  }
  $351 = HEAP32[$137>>2]|0;
  HEAPF32[$46>>2] = 0.0;
  $352 = ((($46)) + 4|0);
  HEAPF32[$352>>2] = 0.0;
  $353 = ((($351)) + 80|0);
  $354 = HEAP32[$353>>2]|0;
  $355 = ((($351)) + 84|0);
  $356 = HEAP32[$355>>2]|0;
  $357 = ($354|0)==($356|0);
  if ($357) {
   $370 = ((($351)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($370,$46);
  } else {
   $358 = $46;
   $359 = $358;
   $360 = HEAP32[$359>>2]|0;
   $361 = (($358) + 4)|0;
   $362 = $361;
   $363 = HEAP32[$362>>2]|0;
   $364 = $354;
   $365 = $364;
   HEAP32[$365>>2] = $360;
   $366 = (($364) + 4)|0;
   $367 = $366;
   HEAP32[$367>>2] = $363;
   $368 = HEAP32[$353>>2]|0;
   $369 = ((($368)) + 8|0);
   HEAP32[$353>>2] = $369;
  }
  $371 = HEAP32[$116>>2]|0;
  HEAPF32[$45>>2] = $90;
  $372 = ((($45)) + 4|0);
  HEAPF32[$372>>2] = $92;
  $373 = ((($45)) + 8|0);
  HEAPF32[$373>>2] = $202;
  $374 = ((($371)) + 80|0);
  $375 = HEAP32[$374>>2]|0;
  $376 = ((($371)) + 84|0);
  $377 = HEAP32[$376>>2]|0;
  $378 = ($375|0)==($377|0);
  if ($378) {
   $381 = ((($371)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($381,$45);
  } else {
   ;HEAP32[$375>>2]=HEAP32[$45>>2]|0;HEAP32[$375+4>>2]=HEAP32[$45+4>>2]|0;HEAP32[$375+8>>2]=HEAP32[$45+8>>2]|0;
   $379 = HEAP32[$374>>2]|0;
   $380 = ((($379)) + 12|0);
   HEAP32[$374>>2] = $380;
  }
  $382 = HEAP32[$125>>2]|0;
  HEAPF32[$44>>2] = 0.0;
  $383 = ((($44)) + 4|0);
  HEAPF32[$383>>2] = 1.0;
  $384 = ((($44)) + 8|0);
  HEAPF32[$384>>2] = 0.0;
  $385 = ((($382)) + 80|0);
  $386 = HEAP32[$385>>2]|0;
  $387 = ((($382)) + 84|0);
  $388 = HEAP32[$387>>2]|0;
  $389 = ($386|0)==($388|0);
  if ($389) {
   $392 = ((($382)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($392,$44);
  } else {
   ;HEAP32[$386>>2]=HEAP32[$44>>2]|0;HEAP32[$386+4>>2]=HEAP32[$44+4>>2]|0;HEAP32[$386+8>>2]=HEAP32[$44+8>>2]|0;
   $390 = HEAP32[$385>>2]|0;
   $391 = ((($390)) + 12|0);
   HEAP32[$385>>2] = $391;
  }
  $393 = HEAP32[$137>>2]|0;
  HEAPF32[$43>>2] = 1.0;
  $394 = ((($43)) + 4|0);
  HEAPF32[$394>>2] = 0.0;
  $395 = ((($393)) + 80|0);
  $396 = HEAP32[$395>>2]|0;
  $397 = ((($393)) + 84|0);
  $398 = HEAP32[$397>>2]|0;
  $399 = ($396|0)==($398|0);
  if ($399) {
   $412 = ((($393)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($412,$43);
  } else {
   $400 = $43;
   $401 = $400;
   $402 = HEAP32[$401>>2]|0;
   $403 = (($400) + 4)|0;
   $404 = $403;
   $405 = HEAP32[$404>>2]|0;
   $406 = $396;
   $407 = $406;
   HEAP32[$407>>2] = $402;
   $408 = (($406) + 4)|0;
   $409 = $408;
   HEAP32[$409>>2] = $405;
   $410 = HEAP32[$395>>2]|0;
   $411 = ((($410)) + 8|0);
   HEAP32[$395>>2] = $411;
  }
  $413 = HEAP32[$116>>2]|0;
  HEAPF32[$42>>2] = $158;
  $414 = ((($42)) + 4|0);
  HEAPF32[$414>>2] = $92;
  $415 = ((($42)) + 8|0);
  HEAPF32[$415>>2] = $202;
  $416 = ((($413)) + 80|0);
  $417 = HEAP32[$416>>2]|0;
  $418 = ((($413)) + 84|0);
  $419 = HEAP32[$418>>2]|0;
  $420 = ($417|0)==($419|0);
  if ($420) {
   $423 = ((($413)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($423,$42);
  } else {
   ;HEAP32[$417>>2]=HEAP32[$42>>2]|0;HEAP32[$417+4>>2]=HEAP32[$42+4>>2]|0;HEAP32[$417+8>>2]=HEAP32[$42+8>>2]|0;
   $421 = HEAP32[$416>>2]|0;
   $422 = ((($421)) + 12|0);
   HEAP32[$416>>2] = $422;
  }
  $424 = HEAP32[$125>>2]|0;
  HEAPF32[$41>>2] = 0.0;
  $425 = ((($41)) + 4|0);
  HEAPF32[$425>>2] = 1.0;
  $426 = ((($41)) + 8|0);
  HEAPF32[$426>>2] = 0.0;
  $427 = ((($424)) + 80|0);
  $428 = HEAP32[$427>>2]|0;
  $429 = ((($424)) + 84|0);
  $430 = HEAP32[$429>>2]|0;
  $431 = ($428|0)==($430|0);
  if ($431) {
   $434 = ((($424)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($434,$41);
  } else {
   ;HEAP32[$428>>2]=HEAP32[$41>>2]|0;HEAP32[$428+4>>2]=HEAP32[$41+4>>2]|0;HEAP32[$428+8>>2]=HEAP32[$41+8>>2]|0;
   $432 = HEAP32[$427>>2]|0;
   $433 = ((($432)) + 12|0);
   HEAP32[$427>>2] = $433;
  }
  $435 = HEAP32[$137>>2]|0;
  HEAPF32[$40>>2] = 1.0;
  $436 = ((($40)) + 4|0);
  HEAPF32[$436>>2] = 1.0;
  $437 = ((($435)) + 80|0);
  $438 = HEAP32[$437>>2]|0;
  $439 = ((($435)) + 84|0);
  $440 = HEAP32[$439>>2]|0;
  $441 = ($438|0)==($440|0);
  if ($441) {
   $454 = ((($435)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($454,$40);
  } else {
   $442 = $40;
   $443 = $442;
   $444 = HEAP32[$443>>2]|0;
   $445 = (($442) + 4)|0;
   $446 = $445;
   $447 = HEAP32[$446>>2]|0;
   $448 = $438;
   $449 = $448;
   HEAP32[$449>>2] = $444;
   $450 = (($448) + 4)|0;
   $451 = $450;
   HEAP32[$451>>2] = $447;
   $452 = HEAP32[$437>>2]|0;
   $453 = ((($452)) + 8|0);
   HEAP32[$437>>2] = $453;
  }
  $455 = HEAP32[$116>>2]|0;
  HEAPF32[$39>>2] = $158;
  $456 = ((($39)) + 4|0);
  HEAPF32[$456>>2] = $92;
  $457 = ((($39)) + 8|0);
  HEAPF32[$457>>2] = $94;
  $458 = ((($455)) + 80|0);
  $459 = HEAP32[$458>>2]|0;
  $460 = ((($455)) + 84|0);
  $461 = HEAP32[$460>>2]|0;
  $462 = ($459|0)==($461|0);
  if ($462) {
   $465 = ((($455)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($465,$39);
  } else {
   ;HEAP32[$459>>2]=HEAP32[$39>>2]|0;HEAP32[$459+4>>2]=HEAP32[$39+4>>2]|0;HEAP32[$459+8>>2]=HEAP32[$39+8>>2]|0;
   $463 = HEAP32[$458>>2]|0;
   $464 = ((($463)) + 12|0);
   HEAP32[$458>>2] = $464;
  }
  $466 = HEAP32[$125>>2]|0;
  HEAPF32[$38>>2] = 1.0;
  $467 = ((($38)) + 4|0);
  HEAPF32[$467>>2] = 0.0;
  $468 = ((($38)) + 8|0);
  HEAPF32[$468>>2] = 0.0;
  $469 = ((($466)) + 80|0);
  $470 = HEAP32[$469>>2]|0;
  $471 = ((($466)) + 84|0);
  $472 = HEAP32[$471>>2]|0;
  $473 = ($470|0)==($472|0);
  if ($473) {
   $476 = ((($466)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($476,$38);
  } else {
   ;HEAP32[$470>>2]=HEAP32[$38>>2]|0;HEAP32[$470+4>>2]=HEAP32[$38+4>>2]|0;HEAP32[$470+8>>2]=HEAP32[$38+8>>2]|0;
   $474 = HEAP32[$469>>2]|0;
   $475 = ((($474)) + 12|0);
   HEAP32[$469>>2] = $475;
  }
  $477 = HEAP32[$137>>2]|0;
  HEAPF32[$37>>2] = 0.0;
  $478 = ((($37)) + 4|0);
  HEAPF32[$478>>2] = 1.0;
  $479 = ((($477)) + 80|0);
  $480 = HEAP32[$479>>2]|0;
  $481 = ((($477)) + 84|0);
  $482 = HEAP32[$481>>2]|0;
  $483 = ($480|0)==($482|0);
  if ($483) {
   $496 = ((($477)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($496,$37);
  } else {
   $484 = $37;
   $485 = $484;
   $486 = HEAP32[$485>>2]|0;
   $487 = (($484) + 4)|0;
   $488 = $487;
   $489 = HEAP32[$488>>2]|0;
   $490 = $480;
   $491 = $490;
   HEAP32[$491>>2] = $486;
   $492 = (($490) + 4)|0;
   $493 = $492;
   HEAP32[$493>>2] = $489;
   $494 = HEAP32[$479>>2]|0;
   $495 = ((($494)) + 8|0);
   HEAP32[$479>>2] = $495;
  }
  $497 = HEAP32[$116>>2]|0;
  HEAPF32[$36>>2] = $90;
  $498 = ((($36)) + 4|0);
  HEAPF32[$498>>2] = $159;
  $499 = ((($36)) + 8|0);
  HEAPF32[$499>>2] = $94;
  $500 = ((($497)) + 80|0);
  $501 = HEAP32[$500>>2]|0;
  $502 = ((($497)) + 84|0);
  $503 = HEAP32[$502>>2]|0;
  $504 = ($501|0)==($503|0);
  if ($504) {
   $507 = ((($497)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($507,$36);
  } else {
   ;HEAP32[$501>>2]=HEAP32[$36>>2]|0;HEAP32[$501+4>>2]=HEAP32[$36+4>>2]|0;HEAP32[$501+8>>2]=HEAP32[$36+8>>2]|0;
   $505 = HEAP32[$500>>2]|0;
   $506 = ((($505)) + 12|0);
   HEAP32[$500>>2] = $506;
  }
  $508 = HEAP32[$125>>2]|0;
  HEAPF32[$35>>2] = 1.0;
  $509 = ((($35)) + 4|0);
  HEAPF32[$509>>2] = 0.0;
  $510 = ((($35)) + 8|0);
  HEAPF32[$510>>2] = 0.0;
  $511 = ((($508)) + 80|0);
  $512 = HEAP32[$511>>2]|0;
  $513 = ((($508)) + 84|0);
  $514 = HEAP32[$513>>2]|0;
  $515 = ($512|0)==($514|0);
  if ($515) {
   $518 = ((($508)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($518,$35);
  } else {
   ;HEAP32[$512>>2]=HEAP32[$35>>2]|0;HEAP32[$512+4>>2]=HEAP32[$35+4>>2]|0;HEAP32[$512+8>>2]=HEAP32[$35+8>>2]|0;
   $516 = HEAP32[$511>>2]|0;
   $517 = ((($516)) + 12|0);
   HEAP32[$511>>2] = $517;
  }
  $519 = HEAP32[$137>>2]|0;
  HEAPF32[$34>>2] = 0.0;
  $520 = ((($34)) + 4|0);
  HEAPF32[$520>>2] = 0.0;
  $521 = ((($519)) + 80|0);
  $522 = HEAP32[$521>>2]|0;
  $523 = ((($519)) + 84|0);
  $524 = HEAP32[$523>>2]|0;
  $525 = ($522|0)==($524|0);
  if ($525) {
   $538 = ((($519)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($538,$34);
  } else {
   $526 = $34;
   $527 = $526;
   $528 = HEAP32[$527>>2]|0;
   $529 = (($526) + 4)|0;
   $530 = $529;
   $531 = HEAP32[$530>>2]|0;
   $532 = $522;
   $533 = $532;
   HEAP32[$533>>2] = $528;
   $534 = (($532) + 4)|0;
   $535 = $534;
   HEAP32[$535>>2] = $531;
   $536 = HEAP32[$521>>2]|0;
   $537 = ((($536)) + 8|0);
   HEAP32[$521>>2] = $537;
  }
  $539 = HEAP32[$116>>2]|0;
  HEAPF32[$33>>2] = $90;
  $540 = ((($33)) + 4|0);
  HEAPF32[$540>>2] = $159;
  $541 = ((($33)) + 8|0);
  HEAPF32[$541>>2] = $202;
  $542 = ((($539)) + 80|0);
  $543 = HEAP32[$542>>2]|0;
  $544 = ((($539)) + 84|0);
  $545 = HEAP32[$544>>2]|0;
  $546 = ($543|0)==($545|0);
  if ($546) {
   $549 = ((($539)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($549,$33);
  } else {
   ;HEAP32[$543>>2]=HEAP32[$33>>2]|0;HEAP32[$543+4>>2]=HEAP32[$33+4>>2]|0;HEAP32[$543+8>>2]=HEAP32[$33+8>>2]|0;
   $547 = HEAP32[$542>>2]|0;
   $548 = ((($547)) + 12|0);
   HEAP32[$542>>2] = $548;
  }
  $550 = HEAP32[$125>>2]|0;
  HEAPF32[$32>>2] = 1.0;
  $551 = ((($32)) + 4|0);
  HEAPF32[$551>>2] = 0.0;
  $552 = ((($32)) + 8|0);
  HEAPF32[$552>>2] = 0.0;
  $553 = ((($550)) + 80|0);
  $554 = HEAP32[$553>>2]|0;
  $555 = ((($550)) + 84|0);
  $556 = HEAP32[$555>>2]|0;
  $557 = ($554|0)==($556|0);
  if ($557) {
   $560 = ((($550)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($560,$32);
  } else {
   ;HEAP32[$554>>2]=HEAP32[$32>>2]|0;HEAP32[$554+4>>2]=HEAP32[$32+4>>2]|0;HEAP32[$554+8>>2]=HEAP32[$32+8>>2]|0;
   $558 = HEAP32[$553>>2]|0;
   $559 = ((($558)) + 12|0);
   HEAP32[$553>>2] = $559;
  }
  $561 = HEAP32[$137>>2]|0;
  HEAPF32[$31>>2] = 1.0;
  $562 = ((($31)) + 4|0);
  HEAPF32[$562>>2] = 0.0;
  $563 = ((($561)) + 80|0);
  $564 = HEAP32[$563>>2]|0;
  $565 = ((($561)) + 84|0);
  $566 = HEAP32[$565>>2]|0;
  $567 = ($564|0)==($566|0);
  if ($567) {
   $580 = ((($561)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($580,$31);
  } else {
   $568 = $31;
   $569 = $568;
   $570 = HEAP32[$569>>2]|0;
   $571 = (($568) + 4)|0;
   $572 = $571;
   $573 = HEAP32[$572>>2]|0;
   $574 = $564;
   $575 = $574;
   HEAP32[$575>>2] = $570;
   $576 = (($574) + 4)|0;
   $577 = $576;
   HEAP32[$577>>2] = $573;
   $578 = HEAP32[$563>>2]|0;
   $579 = ((($578)) + 8|0);
   HEAP32[$563>>2] = $579;
  }
  $581 = HEAP32[$116>>2]|0;
  HEAPF32[$30>>2] = $90;
  $582 = ((($30)) + 4|0);
  HEAPF32[$582>>2] = $92;
  $583 = ((($30)) + 8|0);
  HEAPF32[$583>>2] = $202;
  $584 = ((($581)) + 80|0);
  $585 = HEAP32[$584>>2]|0;
  $586 = ((($581)) + 84|0);
  $587 = HEAP32[$586>>2]|0;
  $588 = ($585|0)==($587|0);
  if ($588) {
   $591 = ((($581)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($591,$30);
  } else {
   ;HEAP32[$585>>2]=HEAP32[$30>>2]|0;HEAP32[$585+4>>2]=HEAP32[$30+4>>2]|0;HEAP32[$585+8>>2]=HEAP32[$30+8>>2]|0;
   $589 = HEAP32[$584>>2]|0;
   $590 = ((($589)) + 12|0);
   HEAP32[$584>>2] = $590;
  }
  $592 = HEAP32[$125>>2]|0;
  HEAPF32[$29>>2] = 1.0;
  $593 = ((($29)) + 4|0);
  HEAPF32[$593>>2] = 0.0;
  $594 = ((($29)) + 8|0);
  HEAPF32[$594>>2] = 0.0;
  $595 = ((($592)) + 80|0);
  $596 = HEAP32[$595>>2]|0;
  $597 = ((($592)) + 84|0);
  $598 = HEAP32[$597>>2]|0;
  $599 = ($596|0)==($598|0);
  if ($599) {
   $602 = ((($592)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($602,$29);
  } else {
   ;HEAP32[$596>>2]=HEAP32[$29>>2]|0;HEAP32[$596+4>>2]=HEAP32[$29+4>>2]|0;HEAP32[$596+8>>2]=HEAP32[$29+8>>2]|0;
   $600 = HEAP32[$595>>2]|0;
   $601 = ((($600)) + 12|0);
   HEAP32[$595>>2] = $601;
  }
  $603 = HEAP32[$137>>2]|0;
  HEAPF32[$28>>2] = 1.0;
  $604 = ((($28)) + 4|0);
  HEAPF32[$604>>2] = 1.0;
  $605 = ((($603)) + 80|0);
  $606 = HEAP32[$605>>2]|0;
  $607 = ((($603)) + 84|0);
  $608 = HEAP32[$607>>2]|0;
  $609 = ($606|0)==($608|0);
  if ($609) {
   $622 = ((($603)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($622,$28);
  } else {
   $610 = $28;
   $611 = $610;
   $612 = HEAP32[$611>>2]|0;
   $613 = (($610) + 4)|0;
   $614 = $613;
   $615 = HEAP32[$614>>2]|0;
   $616 = $606;
   $617 = $616;
   HEAP32[$617>>2] = $612;
   $618 = (($616) + 4)|0;
   $619 = $618;
   HEAP32[$619>>2] = $615;
   $620 = HEAP32[$605>>2]|0;
   $621 = ((($620)) + 8|0);
   HEAP32[$605>>2] = $621;
  }
  $623 = HEAP32[$116>>2]|0;
  HEAPF32[$27>>2] = $90;
  $624 = ((($27)) + 4|0);
  HEAPF32[$624>>2] = $92;
  $625 = ((($27)) + 8|0);
  HEAPF32[$625>>2] = $94;
  $626 = ((($623)) + 80|0);
  $627 = HEAP32[$626>>2]|0;
  $628 = ((($623)) + 84|0);
  $629 = HEAP32[$628>>2]|0;
  $630 = ($627|0)==($629|0);
  if ($630) {
   $633 = ((($623)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($633,$27);
  } else {
   ;HEAP32[$627>>2]=HEAP32[$27>>2]|0;HEAP32[$627+4>>2]=HEAP32[$27+4>>2]|0;HEAP32[$627+8>>2]=HEAP32[$27+8>>2]|0;
   $631 = HEAP32[$626>>2]|0;
   $632 = ((($631)) + 12|0);
   HEAP32[$626>>2] = $632;
  }
  $634 = HEAP32[$125>>2]|0;
  HEAPF32[$26>>2] = -1.0;
  $635 = ((($26)) + 4|0);
  HEAPF32[$635>>2] = 0.0;
  $636 = ((($26)) + 8|0);
  HEAPF32[$636>>2] = 0.0;
  $637 = ((($634)) + 80|0);
  $638 = HEAP32[$637>>2]|0;
  $639 = ((($634)) + 84|0);
  $640 = HEAP32[$639>>2]|0;
  $641 = ($638|0)==($640|0);
  if ($641) {
   $644 = ((($634)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($644,$26);
  } else {
   ;HEAP32[$638>>2]=HEAP32[$26>>2]|0;HEAP32[$638+4>>2]=HEAP32[$26+4>>2]|0;HEAP32[$638+8>>2]=HEAP32[$26+8>>2]|0;
   $642 = HEAP32[$637>>2]|0;
   $643 = ((($642)) + 12|0);
   HEAP32[$637>>2] = $643;
  }
  $645 = HEAP32[$137>>2]|0;
  HEAPF32[$25>>2] = 0.0;
  $646 = ((($25)) + 4|0);
  HEAPF32[$646>>2] = 1.0;
  $647 = ((($645)) + 80|0);
  $648 = HEAP32[$647>>2]|0;
  $649 = ((($645)) + 84|0);
  $650 = HEAP32[$649>>2]|0;
  $651 = ($648|0)==($650|0);
  if ($651) {
   $664 = ((($645)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($664,$25);
  } else {
   $652 = $25;
   $653 = $652;
   $654 = HEAP32[$653>>2]|0;
   $655 = (($652) + 4)|0;
   $656 = $655;
   $657 = HEAP32[$656>>2]|0;
   $658 = $648;
   $659 = $658;
   HEAP32[$659>>2] = $654;
   $660 = (($658) + 4)|0;
   $661 = $660;
   HEAP32[$661>>2] = $657;
   $662 = HEAP32[$647>>2]|0;
   $663 = ((($662)) + 8|0);
   HEAP32[$647>>2] = $663;
  }
  $665 = HEAP32[$116>>2]|0;
  HEAPF32[$24>>2] = $158;
  $666 = ((($24)) + 4|0);
  HEAPF32[$666>>2] = $92;
  $667 = ((($24)) + 8|0);
  HEAPF32[$667>>2] = $94;
  $668 = ((($665)) + 80|0);
  $669 = HEAP32[$668>>2]|0;
  $670 = ((($665)) + 84|0);
  $671 = HEAP32[$670>>2]|0;
  $672 = ($669|0)==($671|0);
  if ($672) {
   $675 = ((($665)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($675,$24);
  } else {
   ;HEAP32[$669>>2]=HEAP32[$24>>2]|0;HEAP32[$669+4>>2]=HEAP32[$24+4>>2]|0;HEAP32[$669+8>>2]=HEAP32[$24+8>>2]|0;
   $673 = HEAP32[$668>>2]|0;
   $674 = ((($673)) + 12|0);
   HEAP32[$668>>2] = $674;
  }
  $676 = HEAP32[$125>>2]|0;
  HEAPF32[$23>>2] = -1.0;
  $677 = ((($23)) + 4|0);
  HEAPF32[$677>>2] = 0.0;
  $678 = ((($23)) + 8|0);
  HEAPF32[$678>>2] = 0.0;
  $679 = ((($676)) + 80|0);
  $680 = HEAP32[$679>>2]|0;
  $681 = ((($676)) + 84|0);
  $682 = HEAP32[$681>>2]|0;
  $683 = ($680|0)==($682|0);
  if ($683) {
   $686 = ((($676)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($686,$23);
  } else {
   ;HEAP32[$680>>2]=HEAP32[$23>>2]|0;HEAP32[$680+4>>2]=HEAP32[$23+4>>2]|0;HEAP32[$680+8>>2]=HEAP32[$23+8>>2]|0;
   $684 = HEAP32[$679>>2]|0;
   $685 = ((($684)) + 12|0);
   HEAP32[$679>>2] = $685;
  }
  $687 = HEAP32[$137>>2]|0;
  HEAPF32[$22>>2] = 0.0;
  $688 = ((($22)) + 4|0);
  HEAPF32[$688>>2] = 0.0;
  $689 = ((($687)) + 80|0);
  $690 = HEAP32[$689>>2]|0;
  $691 = ((($687)) + 84|0);
  $692 = HEAP32[$691>>2]|0;
  $693 = ($690|0)==($692|0);
  if ($693) {
   $706 = ((($687)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($706,$22);
  } else {
   $694 = $22;
   $695 = $694;
   $696 = HEAP32[$695>>2]|0;
   $697 = (($694) + 4)|0;
   $698 = $697;
   $699 = HEAP32[$698>>2]|0;
   $700 = $690;
   $701 = $700;
   HEAP32[$701>>2] = $696;
   $702 = (($700) + 4)|0;
   $703 = $702;
   HEAP32[$703>>2] = $699;
   $704 = HEAP32[$689>>2]|0;
   $705 = ((($704)) + 8|0);
   HEAP32[$689>>2] = $705;
  }
  $707 = HEAP32[$116>>2]|0;
  HEAPF32[$21>>2] = $158;
  $708 = ((($21)) + 4|0);
  HEAPF32[$708>>2] = $92;
  $709 = ((($21)) + 8|0);
  HEAPF32[$709>>2] = $202;
  $710 = ((($707)) + 80|0);
  $711 = HEAP32[$710>>2]|0;
  $712 = ((($707)) + 84|0);
  $713 = HEAP32[$712>>2]|0;
  $714 = ($711|0)==($713|0);
  if ($714) {
   $717 = ((($707)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($717,$21);
  } else {
   ;HEAP32[$711>>2]=HEAP32[$21>>2]|0;HEAP32[$711+4>>2]=HEAP32[$21+4>>2]|0;HEAP32[$711+8>>2]=HEAP32[$21+8>>2]|0;
   $715 = HEAP32[$710>>2]|0;
   $716 = ((($715)) + 12|0);
   HEAP32[$710>>2] = $716;
  }
  $718 = HEAP32[$125>>2]|0;
  HEAPF32[$20>>2] = -1.0;
  $719 = ((($20)) + 4|0);
  HEAPF32[$719>>2] = 0.0;
  $720 = ((($20)) + 8|0);
  HEAPF32[$720>>2] = 0.0;
  $721 = ((($718)) + 80|0);
  $722 = HEAP32[$721>>2]|0;
  $723 = ((($718)) + 84|0);
  $724 = HEAP32[$723>>2]|0;
  $725 = ($722|0)==($724|0);
  if ($725) {
   $728 = ((($718)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($728,$20);
  } else {
   ;HEAP32[$722>>2]=HEAP32[$20>>2]|0;HEAP32[$722+4>>2]=HEAP32[$20+4>>2]|0;HEAP32[$722+8>>2]=HEAP32[$20+8>>2]|0;
   $726 = HEAP32[$721>>2]|0;
   $727 = ((($726)) + 12|0);
   HEAP32[$721>>2] = $727;
  }
  $729 = HEAP32[$137>>2]|0;
  HEAPF32[$19>>2] = 1.0;
  $730 = ((($19)) + 4|0);
  HEAPF32[$730>>2] = 0.0;
  $731 = ((($729)) + 80|0);
  $732 = HEAP32[$731>>2]|0;
  $733 = ((($729)) + 84|0);
  $734 = HEAP32[$733>>2]|0;
  $735 = ($732|0)==($734|0);
  if ($735) {
   $748 = ((($729)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($748,$19);
  } else {
   $736 = $19;
   $737 = $736;
   $738 = HEAP32[$737>>2]|0;
   $739 = (($736) + 4)|0;
   $740 = $739;
   $741 = HEAP32[$740>>2]|0;
   $742 = $732;
   $743 = $742;
   HEAP32[$743>>2] = $738;
   $744 = (($742) + 4)|0;
   $745 = $744;
   HEAP32[$745>>2] = $741;
   $746 = HEAP32[$731>>2]|0;
   $747 = ((($746)) + 8|0);
   HEAP32[$731>>2] = $747;
  }
  $749 = HEAP32[$116>>2]|0;
  HEAPF32[$18>>2] = $158;
  $750 = ((($18)) + 4|0);
  HEAPF32[$750>>2] = $159;
  $751 = ((($18)) + 8|0);
  HEAPF32[$751>>2] = $202;
  $752 = ((($749)) + 80|0);
  $753 = HEAP32[$752>>2]|0;
  $754 = ((($749)) + 84|0);
  $755 = HEAP32[$754>>2]|0;
  $756 = ($753|0)==($755|0);
  if ($756) {
   $759 = ((($749)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($759,$18);
  } else {
   ;HEAP32[$753>>2]=HEAP32[$18>>2]|0;HEAP32[$753+4>>2]=HEAP32[$18+4>>2]|0;HEAP32[$753+8>>2]=HEAP32[$18+8>>2]|0;
   $757 = HEAP32[$752>>2]|0;
   $758 = ((($757)) + 12|0);
   HEAP32[$752>>2] = $758;
  }
  $760 = HEAP32[$125>>2]|0;
  HEAPF32[$17>>2] = -1.0;
  $761 = ((($17)) + 4|0);
  HEAPF32[$761>>2] = 0.0;
  $762 = ((($17)) + 8|0);
  HEAPF32[$762>>2] = 0.0;
  $763 = ((($760)) + 80|0);
  $764 = HEAP32[$763>>2]|0;
  $765 = ((($760)) + 84|0);
  $766 = HEAP32[$765>>2]|0;
  $767 = ($764|0)==($766|0);
  if ($767) {
   $770 = ((($760)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($770,$17);
  } else {
   ;HEAP32[$764>>2]=HEAP32[$17>>2]|0;HEAP32[$764+4>>2]=HEAP32[$17+4>>2]|0;HEAP32[$764+8>>2]=HEAP32[$17+8>>2]|0;
   $768 = HEAP32[$763>>2]|0;
   $769 = ((($768)) + 12|0);
   HEAP32[$763>>2] = $769;
  }
  $771 = HEAP32[$137>>2]|0;
  HEAPF32[$16>>2] = 1.0;
  $772 = ((($16)) + 4|0);
  HEAPF32[$772>>2] = 1.0;
  $773 = ((($771)) + 80|0);
  $774 = HEAP32[$773>>2]|0;
  $775 = ((($771)) + 84|0);
  $776 = HEAP32[$775>>2]|0;
  $777 = ($774|0)==($776|0);
  if ($777) {
   $790 = ((($771)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($790,$16);
  } else {
   $778 = $16;
   $779 = $778;
   $780 = HEAP32[$779>>2]|0;
   $781 = (($778) + 4)|0;
   $782 = $781;
   $783 = HEAP32[$782>>2]|0;
   $784 = $774;
   $785 = $784;
   HEAP32[$785>>2] = $780;
   $786 = (($784) + 4)|0;
   $787 = $786;
   HEAP32[$787>>2] = $783;
   $788 = HEAP32[$773>>2]|0;
   $789 = ((($788)) + 8|0);
   HEAP32[$773>>2] = $789;
  }
  $791 = HEAP32[$116>>2]|0;
  HEAPF32[$15>>2] = $158;
  $792 = ((($15)) + 4|0);
  HEAPF32[$792>>2] = $159;
  $793 = ((($15)) + 8|0);
  HEAPF32[$793>>2] = $94;
  $794 = ((($791)) + 80|0);
  $795 = HEAP32[$794>>2]|0;
  $796 = ((($791)) + 84|0);
  $797 = HEAP32[$796>>2]|0;
  $798 = ($795|0)==($797|0);
  if ($798) {
   $801 = ((($791)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($801,$15);
  } else {
   ;HEAP32[$795>>2]=HEAP32[$15>>2]|0;HEAP32[$795+4>>2]=HEAP32[$15+4>>2]|0;HEAP32[$795+8>>2]=HEAP32[$15+8>>2]|0;
   $799 = HEAP32[$794>>2]|0;
   $800 = ((($799)) + 12|0);
   HEAP32[$794>>2] = $800;
  }
 }
 if ($1149) {
  $804 = ((($0)) + 16|0);
  $805 = HEAP32[$804>>2]|0;
  HEAPF32[$11>>2] = 0.0;
  $806 = ((($11)) + 4|0);
  HEAPF32[$806>>2] = 0.0;
  $807 = ((($11)) + 8|0);
  HEAPF32[$807>>2] = 1.0;
  $808 = ((($805)) + 80|0);
  $809 = HEAP32[$808>>2]|0;
  $810 = ((($805)) + 84|0);
  $811 = HEAP32[$810>>2]|0;
  $812 = ($809|0)==($811|0);
  if ($812) {
   $815 = ((($805)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($815,$11);
  } else {
   ;HEAP32[$809>>2]=HEAP32[$11>>2]|0;HEAP32[$809+4>>2]=HEAP32[$11+4>>2]|0;HEAP32[$809+8>>2]=HEAP32[$11+8>>2]|0;
   $813 = HEAP32[$808>>2]|0;
   $814 = ((($813)) + 12|0);
   HEAP32[$808>>2] = $814;
  }
  $816 = ((($0)) + 20|0);
  $817 = HEAP32[$816>>2]|0;
  HEAPF32[$10>>2] = 0.0;
  $818 = ((($10)) + 4|0);
  HEAPF32[$818>>2] = 1.0;
  $819 = ((($817)) + 80|0);
  $820 = HEAP32[$819>>2]|0;
  $821 = ((($817)) + 84|0);
  $822 = HEAP32[$821>>2]|0;
  $823 = ($820|0)==($822|0);
  if ($823) {
   $836 = ((($817)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($836,$10);
  } else {
   $824 = $10;
   $825 = $824;
   $826 = HEAP32[$825>>2]|0;
   $827 = (($824) + 4)|0;
   $828 = $827;
   $829 = HEAP32[$828>>2]|0;
   $830 = $820;
   $831 = $830;
   HEAP32[$831>>2] = $826;
   $832 = (($830) + 4)|0;
   $833 = $832;
   HEAP32[$833>>2] = $829;
   $834 = HEAP32[$819>>2]|0;
   $835 = ((($834)) + 8|0);
   HEAP32[$819>>2] = $835;
  }
  $837 = -$90;
  $838 = HEAP32[$116>>2]|0;
  HEAPF32[$9>>2] = $837;
  $839 = ((($9)) + 4|0);
  HEAPF32[$839>>2] = $92;
  $840 = ((($9)) + 8|0);
  HEAPF32[$840>>2] = $94;
  $841 = ((($838)) + 80|0);
  $842 = HEAP32[$841>>2]|0;
  $843 = ((($838)) + 84|0);
  $844 = HEAP32[$843>>2]|0;
  $845 = ($842|0)==($844|0);
  if ($845) {
   $848 = ((($838)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($848,$9);
  } else {
   ;HEAP32[$842>>2]=HEAP32[$9>>2]|0;HEAP32[$842+4>>2]=HEAP32[$9+4>>2]|0;HEAP32[$842+8>>2]=HEAP32[$9+8>>2]|0;
   $846 = HEAP32[$841>>2]|0;
   $847 = ((($846)) + 12|0);
   HEAP32[$841>>2] = $847;
  }
  $849 = HEAP32[$804>>2]|0;
  HEAPF32[$8>>2] = 0.0;
  $850 = ((($8)) + 4|0);
  HEAPF32[$850>>2] = 0.0;
  $851 = ((($8)) + 8|0);
  HEAPF32[$851>>2] = 1.0;
  $852 = ((($849)) + 80|0);
  $853 = HEAP32[$852>>2]|0;
  $854 = ((($849)) + 84|0);
  $855 = HEAP32[$854>>2]|0;
  $856 = ($853|0)==($855|0);
  if ($856) {
   $859 = ((($849)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($859,$8);
  } else {
   ;HEAP32[$853>>2]=HEAP32[$8>>2]|0;HEAP32[$853+4>>2]=HEAP32[$8+4>>2]|0;HEAP32[$853+8>>2]=HEAP32[$8+8>>2]|0;
   $857 = HEAP32[$852>>2]|0;
   $858 = ((($857)) + 12|0);
   HEAP32[$852>>2] = $858;
  }
  $860 = HEAP32[$816>>2]|0;
  HEAPF32[$7>>2] = 0.0;
  $861 = ((($7)) + 4|0);
  HEAPF32[$861>>2] = 0.0;
  $862 = ((($860)) + 80|0);
  $863 = HEAP32[$862>>2]|0;
  $864 = ((($860)) + 84|0);
  $865 = HEAP32[$864>>2]|0;
  $866 = ($863|0)==($865|0);
  if ($866) {
   $879 = ((($860)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($879,$7);
  } else {
   $867 = $7;
   $868 = $867;
   $869 = HEAP32[$868>>2]|0;
   $870 = (($867) + 4)|0;
   $871 = $870;
   $872 = HEAP32[$871>>2]|0;
   $873 = $863;
   $874 = $873;
   HEAP32[$874>>2] = $869;
   $875 = (($873) + 4)|0;
   $876 = $875;
   HEAP32[$876>>2] = $872;
   $877 = HEAP32[$862>>2]|0;
   $878 = ((($877)) + 8|0);
   HEAP32[$862>>2] = $878;
  }
  $880 = -$92;
  $881 = HEAP32[$116>>2]|0;
  HEAPF32[$6>>2] = $837;
  $882 = ((($6)) + 4|0);
  HEAPF32[$882>>2] = $880;
  $883 = ((($6)) + 8|0);
  HEAPF32[$883>>2] = $94;
  $884 = ((($881)) + 80|0);
  $885 = HEAP32[$884>>2]|0;
  $886 = ((($881)) + 84|0);
  $887 = HEAP32[$886>>2]|0;
  $888 = ($885|0)==($887|0);
  if ($888) {
   $891 = ((($881)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($891,$6);
  } else {
   ;HEAP32[$885>>2]=HEAP32[$6>>2]|0;HEAP32[$885+4>>2]=HEAP32[$6+4>>2]|0;HEAP32[$885+8>>2]=HEAP32[$6+8>>2]|0;
   $889 = HEAP32[$884>>2]|0;
   $890 = ((($889)) + 12|0);
   HEAP32[$884>>2] = $890;
  }
  $892 = HEAP32[$804>>2]|0;
  HEAPF32[$5>>2] = 0.0;
  $893 = ((($5)) + 4|0);
  HEAPF32[$893>>2] = 0.0;
  $894 = ((($5)) + 8|0);
  HEAPF32[$894>>2] = 1.0;
  $895 = ((($892)) + 80|0);
  $896 = HEAP32[$895>>2]|0;
  $897 = ((($892)) + 84|0);
  $898 = HEAP32[$897>>2]|0;
  $899 = ($896|0)==($898|0);
  if ($899) {
   $902 = ((($892)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($902,$5);
  } else {
   ;HEAP32[$896>>2]=HEAP32[$5>>2]|0;HEAP32[$896+4>>2]=HEAP32[$5+4>>2]|0;HEAP32[$896+8>>2]=HEAP32[$5+8>>2]|0;
   $900 = HEAP32[$895>>2]|0;
   $901 = ((($900)) + 12|0);
   HEAP32[$895>>2] = $901;
  }
  $903 = HEAP32[$816>>2]|0;
  HEAPF32[$4>>2] = 1.0;
  $904 = ((($4)) + 4|0);
  HEAPF32[$904>>2] = 0.0;
  $905 = ((($903)) + 80|0);
  $906 = HEAP32[$905>>2]|0;
  $907 = ((($903)) + 84|0);
  $908 = HEAP32[$907>>2]|0;
  $909 = ($906|0)==($908|0);
  if ($909) {
   $922 = ((($903)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($922,$4);
  } else {
   $910 = $4;
   $911 = $910;
   $912 = HEAP32[$911>>2]|0;
   $913 = (($910) + 4)|0;
   $914 = $913;
   $915 = HEAP32[$914>>2]|0;
   $916 = $906;
   $917 = $916;
   HEAP32[$917>>2] = $912;
   $918 = (($916) + 4)|0;
   $919 = $918;
   HEAP32[$919>>2] = $915;
   $920 = HEAP32[$905>>2]|0;
   $921 = ((($920)) + 8|0);
   HEAP32[$905>>2] = $921;
  }
  $923 = HEAP32[$116>>2]|0;
  HEAPF32[$3>>2] = $90;
  $924 = ((($3)) + 4|0);
  HEAPF32[$924>>2] = $880;
  $925 = ((($3)) + 8|0);
  HEAPF32[$925>>2] = $94;
  $926 = ((($923)) + 80|0);
  $927 = HEAP32[$926>>2]|0;
  $928 = ((($923)) + 84|0);
  $929 = HEAP32[$928>>2]|0;
  $930 = ($927|0)==($929|0);
  if ($930) {
   $933 = ((($923)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($933,$3);
  } else {
   ;HEAP32[$927>>2]=HEAP32[$3>>2]|0;HEAP32[$927+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$927+8>>2]=HEAP32[$3+8>>2]|0;
   $931 = HEAP32[$926>>2]|0;
   $932 = ((($931)) + 12|0);
   HEAP32[$926>>2] = $932;
  }
  $934 = HEAP32[$804>>2]|0;
  HEAPF32[$2>>2] = 0.0;
  $935 = ((($2)) + 4|0);
  HEAPF32[$935>>2] = 0.0;
  $936 = ((($2)) + 8|0);
  HEAPF32[$936>>2] = 1.0;
  $937 = ((($934)) + 80|0);
  $938 = HEAP32[$937>>2]|0;
  $939 = ((($934)) + 84|0);
  $940 = HEAP32[$939>>2]|0;
  $941 = ($938|0)==($940|0);
  if ($941) {
   $944 = ((($934)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($944,$2);
  } else {
   ;HEAP32[$938>>2]=HEAP32[$2>>2]|0;HEAP32[$938+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$938+8>>2]=HEAP32[$2+8>>2]|0;
   $942 = HEAP32[$937>>2]|0;
   $943 = ((($942)) + 12|0);
   HEAP32[$937>>2] = $943;
  }
  $945 = HEAP32[$816>>2]|0;
  HEAPF32[$12>>2] = 1.0;
  $946 = ((($12)) + 4|0);
  HEAPF32[$946>>2] = 1.0;
  $947 = ((($945)) + 80|0);
  $948 = HEAP32[$947>>2]|0;
  $949 = ((($945)) + 84|0);
  $950 = HEAP32[$949>>2]|0;
  $951 = ($948|0)==($950|0);
  if ($951) {
   $964 = ((($945)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($964,$12);
  } else {
   $952 = $12;
   $953 = $952;
   $954 = HEAP32[$953>>2]|0;
   $955 = (($952) + 4)|0;
   $956 = $955;
   $957 = HEAP32[$956>>2]|0;
   $958 = $948;
   $959 = $958;
   HEAP32[$959>>2] = $954;
   $960 = (($958) + 4)|0;
   $961 = $960;
   HEAP32[$961>>2] = $957;
   $962 = HEAP32[$947>>2]|0;
   $963 = ((($962)) + 8|0);
   HEAP32[$947>>2] = $963;
  }
  $965 = HEAP32[$116>>2]|0;
  HEAPF32[$13>>2] = $90;
  $966 = ((($13)) + 4|0);
  HEAPF32[$966>>2] = $92;
  $967 = ((($13)) + 8|0);
  HEAPF32[$967>>2] = $94;
  $968 = ((($965)) + 80|0);
  $969 = HEAP32[$968>>2]|0;
  $970 = ((($965)) + 84|0);
  $971 = HEAP32[$970>>2]|0;
  $972 = ($969|0)==($971|0);
  if ($972) {
   $975 = ((($965)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($975,$13);
  } else {
   ;HEAP32[$969>>2]=HEAP32[$13>>2]|0;HEAP32[$969+4>>2]=HEAP32[$13+4>>2]|0;HEAP32[$969+8>>2]=HEAP32[$13+8>>2]|0;
   $973 = HEAP32[$968>>2]|0;
   $974 = ((($973)) + 12|0);
   HEAP32[$968>>2] = $974;
  }
 }
 if (!($1151)) {
  __ZN3osg25BuildShapeGeometryVisitor3EndEv($0);
  STACKTOP = sp;return;
 }
 $976 = ((($0)) + 16|0);
 $977 = HEAP32[$976>>2]|0;
 HEAPF32[$14>>2] = 0.0;
 $978 = ((($14)) + 4|0);
 HEAPF32[$978>>2] = 0.0;
 $979 = ((($14)) + 8|0);
 HEAPF32[$979>>2] = -1.0;
 $980 = ((($977)) + 80|0);
 $981 = HEAP32[$980>>2]|0;
 $982 = ((($977)) + 84|0);
 $983 = HEAP32[$982>>2]|0;
 $984 = ($981|0)==($983|0);
 if ($984) {
  $987 = ((($977)) + 76|0);
  __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($987,$14);
 } else {
  ;HEAP32[$981>>2]=HEAP32[$14>>2]|0;HEAP32[$981+4>>2]=HEAP32[$14+4>>2]|0;HEAP32[$981+8>>2]=HEAP32[$14+8>>2]|0;
  $985 = HEAP32[$980>>2]|0;
  $986 = ((($985)) + 12|0);
  HEAP32[$980>>2] = $986;
 }
 $988 = ((($0)) + 20|0);
 $989 = HEAP32[$988>>2]|0;
 HEAPF32[$63>>2] = 0.0;
 $990 = ((($63)) + 4|0);
 HEAPF32[$990>>2] = 1.0;
 $991 = ((($989)) + 80|0);
 $992 = HEAP32[$991>>2]|0;
 $993 = ((($989)) + 84|0);
 $994 = HEAP32[$993>>2]|0;
 $995 = ($992|0)==($994|0);
 if ($995) {
  $1008 = ((($989)) + 76|0);
  __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($1008,$63);
 } else {
  $996 = $63;
  $997 = $996;
  $998 = HEAP32[$997>>2]|0;
  $999 = (($996) + 4)|0;
  $1000 = $999;
  $1001 = HEAP32[$1000>>2]|0;
  $1002 = $992;
  $1003 = $1002;
  HEAP32[$1003>>2] = $998;
  $1004 = (($1002) + 4)|0;
  $1005 = $1004;
  HEAP32[$1005>>2] = $1001;
  $1006 = HEAP32[$991>>2]|0;
  $1007 = ((($1006)) + 8|0);
  HEAP32[$991>>2] = $1007;
 }
 $1009 = -$94;
 $1010 = HEAP32[$116>>2]|0;
 HEAPF32[$64>>2] = $90;
 $1011 = ((($64)) + 4|0);
 HEAPF32[$1011>>2] = $92;
 $1012 = ((($64)) + 8|0);
 HEAPF32[$1012>>2] = $1009;
 $1013 = ((($1010)) + 80|0);
 $1014 = HEAP32[$1013>>2]|0;
 $1015 = ((($1010)) + 84|0);
 $1016 = HEAP32[$1015>>2]|0;
 $1017 = ($1014|0)==($1016|0);
 if ($1017) {
  $1020 = ((($1010)) + 76|0);
  __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($1020,$64);
 } else {
  ;HEAP32[$1014>>2]=HEAP32[$64>>2]|0;HEAP32[$1014+4>>2]=HEAP32[$64+4>>2]|0;HEAP32[$1014+8>>2]=HEAP32[$64+8>>2]|0;
  $1018 = HEAP32[$1013>>2]|0;
  $1019 = ((($1018)) + 12|0);
  HEAP32[$1013>>2] = $1019;
 }
 $1021 = HEAP32[$976>>2]|0;
 HEAPF32[$65>>2] = 0.0;
 $1022 = ((($65)) + 4|0);
 HEAPF32[$1022>>2] = 0.0;
 $1023 = ((($65)) + 8|0);
 HEAPF32[$1023>>2] = -1.0;
 $1024 = ((($1021)) + 80|0);
 $1025 = HEAP32[$1024>>2]|0;
 $1026 = ((($1021)) + 84|0);
 $1027 = HEAP32[$1026>>2]|0;
 $1028 = ($1025|0)==($1027|0);
 if ($1028) {
  $1031 = ((($1021)) + 76|0);
  __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($1031,$65);
 } else {
  ;HEAP32[$1025>>2]=HEAP32[$65>>2]|0;HEAP32[$1025+4>>2]=HEAP32[$65+4>>2]|0;HEAP32[$1025+8>>2]=HEAP32[$65+8>>2]|0;
  $1029 = HEAP32[$1024>>2]|0;
  $1030 = ((($1029)) + 12|0);
  HEAP32[$1024>>2] = $1030;
 }
 $1032 = HEAP32[$988>>2]|0;
 HEAPF32[$66>>2] = 0.0;
 $1033 = ((($66)) + 4|0);
 HEAPF32[$1033>>2] = 0.0;
 $1034 = ((($1032)) + 80|0);
 $1035 = HEAP32[$1034>>2]|0;
 $1036 = ((($1032)) + 84|0);
 $1037 = HEAP32[$1036>>2]|0;
 $1038 = ($1035|0)==($1037|0);
 if ($1038) {
  $1051 = ((($1032)) + 76|0);
  __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($1051,$66);
 } else {
  $1039 = $66;
  $1040 = $1039;
  $1041 = HEAP32[$1040>>2]|0;
  $1042 = (($1039) + 4)|0;
  $1043 = $1042;
  $1044 = HEAP32[$1043>>2]|0;
  $1045 = $1035;
  $1046 = $1045;
  HEAP32[$1046>>2] = $1041;
  $1047 = (($1045) + 4)|0;
  $1048 = $1047;
  HEAP32[$1048>>2] = $1044;
  $1049 = HEAP32[$1034>>2]|0;
  $1050 = ((($1049)) + 8|0);
  HEAP32[$1034>>2] = $1050;
 }
 $1052 = -$92;
 $1053 = HEAP32[$116>>2]|0;
 HEAPF32[$67>>2] = $90;
 $1054 = ((($67)) + 4|0);
 HEAPF32[$1054>>2] = $1052;
 $1055 = ((($67)) + 8|0);
 HEAPF32[$1055>>2] = $1009;
 $1056 = ((($1053)) + 80|0);
 $1057 = HEAP32[$1056>>2]|0;
 $1058 = ((($1053)) + 84|0);
 $1059 = HEAP32[$1058>>2]|0;
 $1060 = ($1057|0)==($1059|0);
 if ($1060) {
  $1063 = ((($1053)) + 76|0);
  __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($1063,$67);
 } else {
  ;HEAP32[$1057>>2]=HEAP32[$67>>2]|0;HEAP32[$1057+4>>2]=HEAP32[$67+4>>2]|0;HEAP32[$1057+8>>2]=HEAP32[$67+8>>2]|0;
  $1061 = HEAP32[$1056>>2]|0;
  $1062 = ((($1061)) + 12|0);
  HEAP32[$1056>>2] = $1062;
 }
 $1064 = HEAP32[$976>>2]|0;
 HEAPF32[$68>>2] = 0.0;
 $1065 = ((($68)) + 4|0);
 HEAPF32[$1065>>2] = 0.0;
 $1066 = ((($68)) + 8|0);
 HEAPF32[$1066>>2] = -1.0;
 $1067 = ((($1064)) + 80|0);
 $1068 = HEAP32[$1067>>2]|0;
 $1069 = ((($1064)) + 84|0);
 $1070 = HEAP32[$1069>>2]|0;
 $1071 = ($1068|0)==($1070|0);
 if ($1071) {
  $1074 = ((($1064)) + 76|0);
  __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($1074,$68);
 } else {
  ;HEAP32[$1068>>2]=HEAP32[$68>>2]|0;HEAP32[$1068+4>>2]=HEAP32[$68+4>>2]|0;HEAP32[$1068+8>>2]=HEAP32[$68+8>>2]|0;
  $1072 = HEAP32[$1067>>2]|0;
  $1073 = ((($1072)) + 12|0);
  HEAP32[$1067>>2] = $1073;
 }
 $1075 = HEAP32[$988>>2]|0;
 HEAPF32[$69>>2] = 1.0;
 $1076 = ((($69)) + 4|0);
 HEAPF32[$1076>>2] = 0.0;
 $1077 = ((($1075)) + 80|0);
 $1078 = HEAP32[$1077>>2]|0;
 $1079 = ((($1075)) + 84|0);
 $1080 = HEAP32[$1079>>2]|0;
 $1081 = ($1078|0)==($1080|0);
 if ($1081) {
  $1094 = ((($1075)) + 76|0);
  __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($1094,$69);
 } else {
  $1082 = $69;
  $1083 = $1082;
  $1084 = HEAP32[$1083>>2]|0;
  $1085 = (($1082) + 4)|0;
  $1086 = $1085;
  $1087 = HEAP32[$1086>>2]|0;
  $1088 = $1078;
  $1089 = $1088;
  HEAP32[$1089>>2] = $1084;
  $1090 = (($1088) + 4)|0;
  $1091 = $1090;
  HEAP32[$1091>>2] = $1087;
  $1092 = HEAP32[$1077>>2]|0;
  $1093 = ((($1092)) + 8|0);
  HEAP32[$1077>>2] = $1093;
 }
 $1095 = -$90;
 $1096 = HEAP32[$116>>2]|0;
 HEAPF32[$70>>2] = $1095;
 $1097 = ((($70)) + 4|0);
 HEAPF32[$1097>>2] = $1052;
 $1098 = ((($70)) + 8|0);
 HEAPF32[$1098>>2] = $1009;
 $1099 = ((($1096)) + 80|0);
 $1100 = HEAP32[$1099>>2]|0;
 $1101 = ((($1096)) + 84|0);
 $1102 = HEAP32[$1101>>2]|0;
 $1103 = ($1100|0)==($1102|0);
 if ($1103) {
  $1106 = ((($1096)) + 76|0);
  __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($1106,$70);
 } else {
  ;HEAP32[$1100>>2]=HEAP32[$70>>2]|0;HEAP32[$1100+4>>2]=HEAP32[$70+4>>2]|0;HEAP32[$1100+8>>2]=HEAP32[$70+8>>2]|0;
  $1104 = HEAP32[$1099>>2]|0;
  $1105 = ((($1104)) + 12|0);
  HEAP32[$1099>>2] = $1105;
 }
 $1107 = HEAP32[$976>>2]|0;
 HEAPF32[$71>>2] = 0.0;
 $1108 = ((($71)) + 4|0);
 HEAPF32[$1108>>2] = 0.0;
 $1109 = ((($71)) + 8|0);
 HEAPF32[$1109>>2] = -1.0;
 $1110 = ((($1107)) + 80|0);
 $1111 = HEAP32[$1110>>2]|0;
 $1112 = ((($1107)) + 84|0);
 $1113 = HEAP32[$1112>>2]|0;
 $1114 = ($1111|0)==($1113|0);
 if ($1114) {
  $1117 = ((($1107)) + 76|0);
  __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($1117,$71);
 } else {
  ;HEAP32[$1111>>2]=HEAP32[$71>>2]|0;HEAP32[$1111+4>>2]=HEAP32[$71+4>>2]|0;HEAP32[$1111+8>>2]=HEAP32[$71+8>>2]|0;
  $1115 = HEAP32[$1110>>2]|0;
  $1116 = ((($1115)) + 12|0);
  HEAP32[$1110>>2] = $1116;
 }
 $1118 = HEAP32[$988>>2]|0;
 HEAPF32[$72>>2] = 1.0;
 $1119 = ((($72)) + 4|0);
 HEAPF32[$1119>>2] = 1.0;
 $1120 = ((($1118)) + 80|0);
 $1121 = HEAP32[$1120>>2]|0;
 $1122 = ((($1118)) + 84|0);
 $1123 = HEAP32[$1122>>2]|0;
 $1124 = ($1121|0)==($1123|0);
 if ($1124) {
  $1137 = ((($1118)) + 76|0);
  __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($1137,$72);
 } else {
  $1125 = $72;
  $1126 = $1125;
  $1127 = HEAP32[$1126>>2]|0;
  $1128 = (($1125) + 4)|0;
  $1129 = $1128;
  $1130 = HEAP32[$1129>>2]|0;
  $1131 = $1121;
  $1132 = $1131;
  HEAP32[$1132>>2] = $1127;
  $1133 = (($1131) + 4)|0;
  $1134 = $1133;
  HEAP32[$1134>>2] = $1130;
  $1135 = HEAP32[$1120>>2]|0;
  $1136 = ((($1135)) + 8|0);
  HEAP32[$1120>>2] = $1136;
 }
 $1138 = HEAP32[$116>>2]|0;
 HEAPF32[$73>>2] = $1095;
 $1139 = ((($73)) + 4|0);
 HEAPF32[$1139>>2] = $92;
 $1140 = ((($73)) + 8|0);
 HEAPF32[$1140>>2] = $1009;
 $1141 = ((($1138)) + 80|0);
 $1142 = HEAP32[$1141>>2]|0;
 $1143 = ((($1138)) + 84|0);
 $1144 = HEAP32[$1143>>2]|0;
 $1145 = ($1142|0)==($1144|0);
 if ($1145) {
  $1148 = ((($1138)) + 76|0);
  __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($1148,$73);
 } else {
  ;HEAP32[$1142>>2]=HEAP32[$73>>2]|0;HEAP32[$1142+4>>2]=HEAP32[$73+4>>2]|0;HEAP32[$1142+8>>2]=HEAP32[$73+8>>2]|0;
  $1146 = HEAP32[$1141>>2]|0;
  $1147 = ((($1146)) + 12|0);
  HEAP32[$1141>>2] = $1147;
 }
 __ZN3osg25BuildShapeGeometryVisitor3EndEv($0);
 STACKTOP = sp;return;
}
function __ZN3osg25BuildShapeGeometryVisitor5applyERKNS_4ConeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$ = 0, $$0171223 = 0, $$0172 = 0, $$0173 = 0, $$0174226 = 0, $$0175238 = 0, $$0176225 = 0.0, $$0178224 = 0.0, $$0180239 = 0.0, $$0181236 = 0.0, $$0182240 = 0.0, $$0184233 = 0.0, $$0184233$phi = 0.0, $$1179222 = 0.0, $$2 = 0, $$not = 0, $$pn = 0.0, $$pn242 = 0.0, $10 = 0, $100 = 0;
 var $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0;
 var $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0;
 var $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0;
 var $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0;
 var $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0;
 var $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0.0, $201 = 0.0, $202 = 0.0, $203 = 0.0, $204 = 0.0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0;
 var $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0;
 var $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0.0, $234 = 0.0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0;
 var $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0;
 var $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0.0, $273 = 0.0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0.0, $280 = 0, $281 = 0;
 var $282 = 0, $283 = 0, $284 = 0.0, $285 = 0.0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0.0, $297 = 0.0, $298 = 0.0, $299 = 0, $3 = 0;
 var $30 = 0.0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0;
 var $318 = 0, $319 = 0, $32 = 0.0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0;
 var $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0.0, $350 = 0, $351 = 0, $352 = 0, $353 = 0;
 var $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0.0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0.0, $370 = 0, $371 = 0;
 var $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0;
 var $390 = 0, $391 = 0.0, $392 = 0.0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0.0, $403 = 0.0, $404 = 0.0, $405 = 0.0, $406 = 0, $407 = 0;
 var $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0.0;
 var $426 = 0.0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0.0, $438 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0.0, $57 = 0, $58 = 0, $59 = 0.0, $6 = 0, $60 = 0, $61 = 0, $62 = 0.0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0.0, $69 = 0, $7 = 0, $70 = 0.0, $71 = 0.0, $72 = 0.0, $73 = 0.0, $74 = 0.0, $75 = 0.0, $76 = 0.0, $77 = 0.0, $78 = 0.0, $79 = 0.0, $8 = 0, $80 = 0.0, $81 = 0.0, $82 = 0.0, $83 = 0.0, $84 = 0.0, $85 = 0.0;
 var $86 = 0.0, $87 = 0.0, $88 = 0, $89 = 0, $9 = 0, $90 = 0.0, $91 = 0.0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $exitcond243 = 0, $exitcond244 = 0, $or$cond = 0, $or$cond245 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 608|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(608|0);
 $2 = sp + 596|0;
 $3 = sp + 584|0;
 $4 = sp + 432|0;
 $5 = sp + 572|0;
 $6 = sp + 560|0;
 $7 = sp + 424|0;
 $8 = sp + 548|0;
 $9 = sp + 416|0;
 $10 = sp + 536|0;
 $11 = sp + 524|0;
 $12 = sp + 408|0;
 $13 = sp + 512|0;
 $14 = sp + 500|0;
 $15 = sp + 400|0;
 $16 = sp + 488|0;
 $17 = sp + 476|0;
 $18 = sp + 392|0;
 $19 = sp + 464|0;
 $20 = sp + 452|0;
 $21 = sp + 384|0;
 $22 = sp + 440|0;
 $23 = sp + 256|0;
 $24 = sp + 128|0;
 $25 = sp;
 $26 = ((($1)) + 56|0);
 __ZN3osg7Matrixd10makeRotateERKNS_4QuatE($24,$26);
 $27 = ((($1)) + 32|0);
 $28 = +HEAPF32[$27>>2];
 $29 = ((($1)) + 36|0);
 $30 = +HEAPF32[$29>>2];
 $31 = ((($1)) + 40|0);
 $32 = +HEAPF32[$31>>2];
 __THREW__ = 0;
 invoke_vi(3299,($25|0));
 $33 = __THREW__; __THREW__ = 0;
 $34 = $33&1;
 if ($34) {
  $65 = ___cxa_find_matching_catch_2()|0;
  $66 = tempRet0;
  ___resumeException($65|0);
  // unreachable;
 }
 $35 = $32;
 $36 = $30;
 $37 = $28;
 __THREW__ = 0;
 invoke_viddd(3306,($25|0),(+$37),(+$36),(+$35));
 $38 = __THREW__; __THREW__ = 0;
 $39 = $38&1;
 if ($39) {
  $65 = ___cxa_find_matching_catch_2()|0;
  $66 = tempRet0;
  ___resumeException($65|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_vi(3299,($23|0));
 $40 = __THREW__; __THREW__ = 0;
 $41 = $40&1;
 if ($41) {
  $65 = ___cxa_find_matching_catch_2()|0;
  $66 = tempRet0;
  ___resumeException($65|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(3300,($23|0),($24|0),($25|0));
 $42 = __THREW__; __THREW__ = 0;
 $43 = $42&1;
 if ($43) {
  $65 = ___cxa_find_matching_catch_2()|0;
  $66 = tempRet0;
  ___resumeException($65|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_vii(3911,($0|0),($23|0));
 $44 = __THREW__; __THREW__ = 0;
 $45 = $44&1;
 if ($45) {
  $65 = ___cxa_find_matching_catch_2()|0;
  $66 = tempRet0;
  ___resumeException($65|0);
  // unreachable;
 }
 $46 = ((($0)) + 8|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = ($47|0)==(0|0);
 if ($48) {
  $$0172 = 40;$$0173 = 10;$438 = 1;$88 = 1;
 } else {
  $49 = ((($47)) + 49|0);
  $50 = HEAP8[$49>>0]|0;
  $51 = ($50<<24>>24)!=(0);
  $52 = ((($47)) + 50|0);
  $53 = HEAP8[$52>>0]|0;
  $54 = ($53<<24>>24)!=(0);
  $55 = ((($47)) + 36|0);
  $56 = +HEAPF32[$55>>2];
  $57 = $56 > 0.0;
  $58 = $56 != 1.0;
  $or$cond = $57 & $58;
  if ($or$cond) {
   $59 = $56 * 10.0;
   $60 = (~~(($59))>>>0);
   $61 = ($60>>>0)>(3);
   $$ = $61 ? $60 : 3;
   $62 = $56 * 40.0;
   $63 = (~~(($62))>>>0);
   $64 = ($63>>>0)>(5);
   $$2 = $64 ? $63 : 5;
   $$0172 = $$2;$$0173 = $$;$438 = $54;$88 = $51;
  } else {
   $$0172 = 40;$$0173 = 10;$438 = $54;$88 = $51;
  }
 }
 $67 = ((($1)) + 44|0);
 $68 = +HEAPF32[$67>>2];
 $69 = ((($1)) + 48|0);
 $70 = +HEAPF32[$69>>2];
 $71 = $68 * $68;
 $72 = $70 * $70;
 $73 = $71 + $72;
 $74 = (+Math_sqrt((+$73)));
 $75 = $68 / $74;
 $76 = $75 * $75;
 $77 = $76 + 1.0;
 $78 = (+Math_sqrt((+$77)));
 $79 = 1.0 / $78;
 $80 = $75 * $79;
 $81 = (+($$0172>>>0));
 $82 = 6.2831854820251465 / $81;
 $83 = 1.0 / $81;
 $84 = (+($$0173>>>0));
 $85 = 1.0 / $84;
 $86 = $70 / $84;
 $87 = $68 / $84;
 $$not = $88 ^ 1;
 $89 = ($$0173|0)==(0);
 $or$cond245 = $89 | $$not;
 if (!($or$cond245)) {
  $90 = $70 * 0.25;
  $91 = $70 - $90;
  $92 = ((($0)) + 24|0);
  $93 = ((($0)) + 12|0);
  $94 = ((($0)) + 28|0);
  $95 = ($$0172|0)==(0);
  $96 = ((($0)) + 16|0);
  $97 = ((($8)) + 4|0);
  $98 = ((($8)) + 8|0);
  $99 = ((($0)) + 20|0);
  $100 = ((($7)) + 4|0);
  $101 = ((($6)) + 4|0);
  $102 = ((($6)) + 8|0);
  $103 = ((($5)) + 4|0);
  $104 = ((($5)) + 8|0);
  $105 = ((($4)) + 4|0);
  $106 = ((($3)) + 4|0);
  $107 = ((($3)) + 8|0);
  $108 = ((($2)) + 4|0);
  $109 = ((($2)) + 8|0);
  $110 = ((($9)) + 4|0);
  $111 = ((($10)) + 4|0);
  $112 = ((($10)) + 8|0);
  $113 = ((($11)) + 4|0);
  $114 = ((($11)) + 8|0);
  $115 = ((($12)) + 4|0);
  $116 = ((($13)) + 4|0);
  $117 = ((($13)) + 8|0);
  $$0175238 = 0;$$0181236 = $87;$$0184233 = 0.0;$$pn = $91;$$pn242 = 1.0;
  while(1) {
   $$0180239 = $$pn242 - $85;
   $$0182240 = $$pn - $86;
   HEAP32[$92>>2] = 8;
   $118 = HEAP32[$93>>2]|0;
   $119 = ((($118)) + 76|0);
   $120 = ((($118)) + 80|0);
   $121 = HEAP32[$120>>2]|0;
   $122 = HEAP32[$119>>2]|0;
   $123 = (($121) - ($122))|0;
   $124 = (($123|0) / 12)&-1;
   HEAP32[$94>>2] = $124;
   if (!($95)) {
    $$0174226 = 0;$$0176225 = 0.0;$$0178224 = 0.0;
    while(1) {
     $201 = (+Math_cos((+$$0178224)));
     $202 = (+Math_sin((+$$0178224)));
     $203 = $79 * $201;
     $204 = $79 * $202;
     $205 = HEAP32[$96>>2]|0;
     HEAPF32[$2>>2] = $203;
     HEAPF32[$108>>2] = $204;
     HEAPF32[$109>>2] = $80;
     $206 = ((($205)) + 80|0);
     $207 = HEAP32[$206>>2]|0;
     $208 = ((($205)) + 84|0);
     $209 = HEAP32[$208>>2]|0;
     $210 = ($207|0)==($209|0);
     if ($210) {
      $213 = ((($205)) + 76|0);
      __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($213,$2);
     } else {
      ;HEAP32[$207>>2]=HEAP32[$2>>2]|0;HEAP32[$207+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$207+8>>2]=HEAP32[$2+8>>2]|0;
      $211 = HEAP32[$206>>2]|0;
      $212 = ((($211)) + 12|0);
      HEAP32[$206>>2] = $212;
     }
     $214 = HEAP32[$99>>2]|0;
     HEAPF32[$9>>2] = $$0176225;
     HEAPF32[$110>>2] = $$pn242;
     $215 = ((($214)) + 80|0);
     $216 = HEAP32[$215>>2]|0;
     $217 = ((($214)) + 84|0);
     $218 = HEAP32[$217>>2]|0;
     $219 = ($216|0)==($218|0);
     if ($219) {
      $232 = ((($214)) + 76|0);
      __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($232,$9);
     } else {
      $220 = $9;
      $221 = $220;
      $222 = HEAP32[$221>>2]|0;
      $223 = (($220) + 4)|0;
      $224 = $223;
      $225 = HEAP32[$224>>2]|0;
      $226 = $216;
      $227 = $226;
      HEAP32[$227>>2] = $222;
      $228 = (($226) + 4)|0;
      $229 = $228;
      HEAP32[$229>>2] = $225;
      $230 = HEAP32[$215>>2]|0;
      $231 = ((($230)) + 8|0);
      HEAP32[$215>>2] = $231;
     }
     $233 = $$0184233 * $201;
     $234 = $$0184233 * $202;
     $235 = HEAP32[$93>>2]|0;
     HEAPF32[$10>>2] = $233;
     HEAPF32[$111>>2] = $234;
     HEAPF32[$112>>2] = $$pn;
     $236 = ((($235)) + 80|0);
     $237 = HEAP32[$236>>2]|0;
     $238 = ((($235)) + 84|0);
     $239 = HEAP32[$238>>2]|0;
     $240 = ($237|0)==($239|0);
     if ($240) {
      $243 = ((($235)) + 76|0);
      __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($243,$10);
     } else {
      ;HEAP32[$237>>2]=HEAP32[$10>>2]|0;HEAP32[$237+4>>2]=HEAP32[$10+4>>2]|0;HEAP32[$237+8>>2]=HEAP32[$10+8>>2]|0;
      $241 = HEAP32[$236>>2]|0;
      $242 = ((($241)) + 12|0);
      HEAP32[$236>>2] = $242;
     }
     $244 = HEAP32[$96>>2]|0;
     HEAPF32[$11>>2] = $203;
     HEAPF32[$113>>2] = $204;
     HEAPF32[$114>>2] = $80;
     $245 = ((($244)) + 80|0);
     $246 = HEAP32[$245>>2]|0;
     $247 = ((($244)) + 84|0);
     $248 = HEAP32[$247>>2]|0;
     $249 = ($246|0)==($248|0);
     if ($249) {
      $252 = ((($244)) + 76|0);
      __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($252,$11);
     } else {
      ;HEAP32[$246>>2]=HEAP32[$11>>2]|0;HEAP32[$246+4>>2]=HEAP32[$11+4>>2]|0;HEAP32[$246+8>>2]=HEAP32[$11+8>>2]|0;
      $250 = HEAP32[$245>>2]|0;
      $251 = ((($250)) + 12|0);
      HEAP32[$245>>2] = $251;
     }
     $253 = HEAP32[$99>>2]|0;
     HEAPF32[$12>>2] = $$0176225;
     HEAPF32[$115>>2] = $$0180239;
     $254 = ((($253)) + 80|0);
     $255 = HEAP32[$254>>2]|0;
     $256 = ((($253)) + 84|0);
     $257 = HEAP32[$256>>2]|0;
     $258 = ($255|0)==($257|0);
     if ($258) {
      $271 = ((($253)) + 76|0);
      __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($271,$12);
     } else {
      $259 = $12;
      $260 = $259;
      $261 = HEAP32[$260>>2]|0;
      $262 = (($259) + 4)|0;
      $263 = $262;
      $264 = HEAP32[$263>>2]|0;
      $265 = $255;
      $266 = $265;
      HEAP32[$266>>2] = $261;
      $267 = (($265) + 4)|0;
      $268 = $267;
      HEAP32[$268>>2] = $264;
      $269 = HEAP32[$254>>2]|0;
      $270 = ((($269)) + 8|0);
      HEAP32[$254>>2] = $270;
     }
     $272 = $$0181236 * $201;
     $273 = $$0181236 * $202;
     $274 = HEAP32[$93>>2]|0;
     HEAPF32[$13>>2] = $272;
     HEAPF32[$116>>2] = $273;
     HEAPF32[$117>>2] = $$0182240;
     $275 = ((($274)) + 80|0);
     $276 = HEAP32[$275>>2]|0;
     $277 = ((($274)) + 84|0);
     $278 = HEAP32[$277>>2]|0;
     $279 = ($276|0)==($278|0);
     if ($279) {
      $282 = ((($274)) + 76|0);
      __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($282,$13);
     } else {
      ;HEAP32[$276>>2]=HEAP32[$13>>2]|0;HEAP32[$276+4>>2]=HEAP32[$13+4>>2]|0;HEAP32[$276+8>>2]=HEAP32[$13+8>>2]|0;
      $280 = HEAP32[$275>>2]|0;
      $281 = ((($280)) + 12|0);
      HEAP32[$275>>2] = $281;
     }
     $283 = (($$0174226) + 1)|0;
     $284 = $82 + $$0178224;
     $285 = $83 + $$0176225;
     $exitcond243 = ($283|0)==($$0172|0);
     if ($exitcond243) {
      break;
     } else {
      $$0174226 = $283;$$0176225 = $285;$$0178224 = $284;
     }
    }
   }
   $125 = HEAP32[$96>>2]|0;
   HEAPF32[$8>>2] = $79;
   HEAPF32[$97>>2] = 0.0;
   HEAPF32[$98>>2] = $80;
   $126 = ((($125)) + 80|0);
   $127 = HEAP32[$126>>2]|0;
   $128 = ((($125)) + 84|0);
   $129 = HEAP32[$128>>2]|0;
   $130 = ($127|0)==($129|0);
   if ($130) {
    $133 = ((($125)) + 76|0);
    __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($133,$8);
   } else {
    ;HEAP32[$127>>2]=HEAP32[$8>>2]|0;HEAP32[$127+4>>2]=HEAP32[$8+4>>2]|0;HEAP32[$127+8>>2]=HEAP32[$8+8>>2]|0;
    $131 = HEAP32[$126>>2]|0;
    $132 = ((($131)) + 12|0);
    HEAP32[$126>>2] = $132;
   }
   $134 = HEAP32[$99>>2]|0;
   HEAPF32[$7>>2] = 1.0;
   HEAPF32[$100>>2] = $$pn242;
   $135 = ((($134)) + 80|0);
   $136 = HEAP32[$135>>2]|0;
   $137 = ((($134)) + 84|0);
   $138 = HEAP32[$137>>2]|0;
   $139 = ($136|0)==($138|0);
   if ($139) {
    $152 = ((($134)) + 76|0);
    __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($152,$7);
   } else {
    $140 = $7;
    $141 = $140;
    $142 = HEAP32[$141>>2]|0;
    $143 = (($140) + 4)|0;
    $144 = $143;
    $145 = HEAP32[$144>>2]|0;
    $146 = $136;
    $147 = $146;
    HEAP32[$147>>2] = $142;
    $148 = (($146) + 4)|0;
    $149 = $148;
    HEAP32[$149>>2] = $145;
    $150 = HEAP32[$135>>2]|0;
    $151 = ((($150)) + 8|0);
    HEAP32[$135>>2] = $151;
   }
   $153 = HEAP32[$93>>2]|0;
   HEAPF32[$6>>2] = $$0184233;
   HEAPF32[$101>>2] = 0.0;
   HEAPF32[$102>>2] = $$pn;
   $154 = ((($153)) + 80|0);
   $155 = HEAP32[$154>>2]|0;
   $156 = ((($153)) + 84|0);
   $157 = HEAP32[$156>>2]|0;
   $158 = ($155|0)==($157|0);
   if ($158) {
    $161 = ((($153)) + 76|0);
    __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($161,$6);
   } else {
    ;HEAP32[$155>>2]=HEAP32[$6>>2]|0;HEAP32[$155+4>>2]=HEAP32[$6+4>>2]|0;HEAP32[$155+8>>2]=HEAP32[$6+8>>2]|0;
    $159 = HEAP32[$154>>2]|0;
    $160 = ((($159)) + 12|0);
    HEAP32[$154>>2] = $160;
   }
   $162 = HEAP32[$96>>2]|0;
   HEAPF32[$5>>2] = $79;
   HEAPF32[$103>>2] = 0.0;
   HEAPF32[$104>>2] = $80;
   $163 = ((($162)) + 80|0);
   $164 = HEAP32[$163>>2]|0;
   $165 = ((($162)) + 84|0);
   $166 = HEAP32[$165>>2]|0;
   $167 = ($164|0)==($166|0);
   if ($167) {
    $170 = ((($162)) + 76|0);
    __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($170,$5);
   } else {
    ;HEAP32[$164>>2]=HEAP32[$5>>2]|0;HEAP32[$164+4>>2]=HEAP32[$5+4>>2]|0;HEAP32[$164+8>>2]=HEAP32[$5+8>>2]|0;
    $168 = HEAP32[$163>>2]|0;
    $169 = ((($168)) + 12|0);
    HEAP32[$163>>2] = $169;
   }
   $171 = HEAP32[$99>>2]|0;
   HEAPF32[$4>>2] = 1.0;
   HEAPF32[$105>>2] = $$0180239;
   $172 = ((($171)) + 80|0);
   $173 = HEAP32[$172>>2]|0;
   $174 = ((($171)) + 84|0);
   $175 = HEAP32[$174>>2]|0;
   $176 = ($173|0)==($175|0);
   if ($176) {
    $189 = ((($171)) + 76|0);
    __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($189,$4);
   } else {
    $177 = $4;
    $178 = $177;
    $179 = HEAP32[$178>>2]|0;
    $180 = (($177) + 4)|0;
    $181 = $180;
    $182 = HEAP32[$181>>2]|0;
    $183 = $173;
    $184 = $183;
    HEAP32[$184>>2] = $179;
    $185 = (($183) + 4)|0;
    $186 = $185;
    HEAP32[$186>>2] = $182;
    $187 = HEAP32[$172>>2]|0;
    $188 = ((($187)) + 8|0);
    HEAP32[$172>>2] = $188;
   }
   $190 = HEAP32[$93>>2]|0;
   HEAPF32[$3>>2] = $$0181236;
   HEAPF32[$106>>2] = 0.0;
   HEAPF32[$107>>2] = $$0182240;
   $191 = ((($190)) + 80|0);
   $192 = HEAP32[$191>>2]|0;
   $193 = ((($190)) + 84|0);
   $194 = HEAP32[$193>>2]|0;
   $195 = ($192|0)==($194|0);
   if ($195) {
    $198 = ((($190)) + 76|0);
    __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($198,$3);
   } else {
    ;HEAP32[$192>>2]=HEAP32[$3>>2]|0;HEAP32[$192+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$192+8>>2]=HEAP32[$3+8>>2]|0;
    $196 = HEAP32[$191>>2]|0;
    $197 = ((($196)) + 12|0);
    HEAP32[$191>>2] = $197;
   }
   __ZN3osg25BuildShapeGeometryVisitor3EndEv($0);
   $199 = (($$0175238) + 1)|0;
   $200 = $87 + $$0181236;
   $exitcond244 = ($199|0)==($$0173|0);
   if ($exitcond244) {
    break;
   } else {
    $$0184233$phi = $$0181236;$$0175238 = $199;$$0181236 = $200;$$pn = $$0182240;$$pn242 = $$0180239;$$0184233 = $$0184233$phi;
   }
  }
 }
 if (!($438)) {
  STACKTOP = sp;return;
 }
 $286 = ((($0)) + 24|0);
 HEAP32[$286>>2] = 6;
 $287 = ((($0)) + 12|0);
 $288 = HEAP32[$287>>2]|0;
 $289 = ((($288)) + 76|0);
 $290 = ((($288)) + 80|0);
 $291 = HEAP32[$290>>2]|0;
 $292 = HEAP32[$289>>2]|0;
 $293 = (($291) - ($292))|0;
 $294 = (($293|0) / 12)&-1;
 $295 = ((($0)) + 28|0);
 HEAP32[$295>>2] = $294;
 $296 = +HEAPF32[$69>>2];
 $297 = $296 * 0.25;
 $298 = -$297;
 $299 = ((($0)) + 16|0);
 $300 = HEAP32[$299>>2]|0;
 HEAPF32[$14>>2] = 0.0;
 $301 = ((($14)) + 4|0);
 HEAPF32[$301>>2] = 0.0;
 $302 = ((($14)) + 8|0);
 HEAPF32[$302>>2] = -1.0;
 $303 = ((($300)) + 80|0);
 $304 = HEAP32[$303>>2]|0;
 $305 = ((($300)) + 84|0);
 $306 = HEAP32[$305>>2]|0;
 $307 = ($304|0)==($306|0);
 if ($307) {
  $310 = ((($300)) + 76|0);
  __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($310,$14);
 } else {
  ;HEAP32[$304>>2]=HEAP32[$14>>2]|0;HEAP32[$304+4>>2]=HEAP32[$14+4>>2]|0;HEAP32[$304+8>>2]=HEAP32[$14+8>>2]|0;
  $308 = HEAP32[$303>>2]|0;
  $309 = ((($308)) + 12|0);
  HEAP32[$303>>2] = $309;
 }
 $311 = ((($0)) + 20|0);
 $312 = HEAP32[$311>>2]|0;
 HEAPF32[$15>>2] = 0.5;
 $313 = ((($15)) + 4|0);
 HEAPF32[$313>>2] = 0.5;
 $314 = ((($312)) + 80|0);
 $315 = HEAP32[$314>>2]|0;
 $316 = ((($312)) + 84|0);
 $317 = HEAP32[$316>>2]|0;
 $318 = ($315|0)==($317|0);
 if ($318) {
  $331 = ((($312)) + 76|0);
  __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($331,$15);
 } else {
  $319 = $15;
  $320 = $319;
  $321 = HEAP32[$320>>2]|0;
  $322 = (($319) + 4)|0;
  $323 = $322;
  $324 = HEAP32[$323>>2]|0;
  $325 = $315;
  $326 = $325;
  HEAP32[$326>>2] = $321;
  $327 = (($325) + 4)|0;
  $328 = $327;
  HEAP32[$328>>2] = $324;
  $329 = HEAP32[$314>>2]|0;
  $330 = ((($329)) + 8|0);
  HEAP32[$314>>2] = $330;
 }
 $332 = HEAP32[$287>>2]|0;
 HEAPF32[$16>>2] = 0.0;
 $333 = ((($16)) + 4|0);
 HEAPF32[$333>>2] = 0.0;
 $334 = ((($16)) + 8|0);
 HEAPF32[$334>>2] = $298;
 $335 = ((($332)) + 80|0);
 $336 = HEAP32[$335>>2]|0;
 $337 = ((($332)) + 84|0);
 $338 = HEAP32[$337>>2]|0;
 $339 = ($336|0)==($338|0);
 if ($339) {
  $342 = ((($332)) + 76|0);
  __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($342,$16);
 } else {
  ;HEAP32[$336>>2]=HEAP32[$16>>2]|0;HEAP32[$336+4>>2]=HEAP32[$16+4>>2]|0;HEAP32[$336+8>>2]=HEAP32[$16+8>>2]|0;
  $340 = HEAP32[$335>>2]|0;
  $341 = ((($340)) + 12|0);
  HEAP32[$335>>2] = $341;
 }
 $343 = ($$0172|0)==(0);
 if (!($343)) {
  $344 = ((($20)) + 4|0);
  $345 = ((($20)) + 8|0);
  $346 = ((($21)) + 4|0);
  $347 = ((($22)) + 4|0);
  $348 = ((($22)) + 8|0);
  $$0171223 = 0;$$1179222 = 6.2831854820251465;
  while(1) {
   $391 = (+Math_cos((+$$1179222)));
   $392 = (+Math_sin((+$$1179222)));
   $393 = HEAP32[$299>>2]|0;
   HEAPF32[$20>>2] = 0.0;
   HEAPF32[$344>>2] = 0.0;
   HEAPF32[$345>>2] = -1.0;
   $394 = ((($393)) + 80|0);
   $395 = HEAP32[$394>>2]|0;
   $396 = ((($393)) + 84|0);
   $397 = HEAP32[$396>>2]|0;
   $398 = ($395|0)==($397|0);
   if ($398) {
    $401 = ((($393)) + 76|0);
    __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($401,$20);
   } else {
    ;HEAP32[$395>>2]=HEAP32[$20>>2]|0;HEAP32[$395+4>>2]=HEAP32[$20+4>>2]|0;HEAP32[$395+8>>2]=HEAP32[$20+8>>2]|0;
    $399 = HEAP32[$394>>2]|0;
    $400 = ((($399)) + 12|0);
    HEAP32[$394>>2] = $400;
   }
   $402 = $391 * 0.5;
   $403 = $402 + 0.5;
   $404 = $392 * 0.5;
   $405 = $404 + 0.5;
   $406 = HEAP32[$311>>2]|0;
   HEAPF32[$21>>2] = $403;
   HEAPF32[$346>>2] = $405;
   $407 = ((($406)) + 80|0);
   $408 = HEAP32[$407>>2]|0;
   $409 = ((($406)) + 84|0);
   $410 = HEAP32[$409>>2]|0;
   $411 = ($408|0)==($410|0);
   if ($411) {
    $424 = ((($406)) + 76|0);
    __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($424,$21);
   } else {
    $412 = $21;
    $413 = $412;
    $414 = HEAP32[$413>>2]|0;
    $415 = (($412) + 4)|0;
    $416 = $415;
    $417 = HEAP32[$416>>2]|0;
    $418 = $408;
    $419 = $418;
    HEAP32[$419>>2] = $414;
    $420 = (($418) + 4)|0;
    $421 = $420;
    HEAP32[$421>>2] = $417;
    $422 = HEAP32[$407>>2]|0;
    $423 = ((($422)) + 8|0);
    HEAP32[$407>>2] = $423;
   }
   $425 = $68 * $391;
   $426 = $68 * $392;
   $427 = HEAP32[$287>>2]|0;
   HEAPF32[$22>>2] = $425;
   HEAPF32[$347>>2] = $426;
   HEAPF32[$348>>2] = $298;
   $428 = ((($427)) + 80|0);
   $429 = HEAP32[$428>>2]|0;
   $430 = ((($427)) + 84|0);
   $431 = HEAP32[$430>>2]|0;
   $432 = ($429|0)==($431|0);
   if ($432) {
    $435 = ((($427)) + 76|0);
    __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($435,$22);
   } else {
    ;HEAP32[$429>>2]=HEAP32[$22>>2]|0;HEAP32[$429+4>>2]=HEAP32[$22+4>>2]|0;HEAP32[$429+8>>2]=HEAP32[$22+8>>2]|0;
    $433 = HEAP32[$428>>2]|0;
    $434 = ((($433)) + 12|0);
    HEAP32[$428>>2] = $434;
   }
   $436 = (($$0171223) + 1)|0;
   $437 = $$1179222 - $82;
   $exitcond = ($436|0)==($$0172|0);
   if ($exitcond) {
    break;
   } else {
    $$0171223 = $436;$$1179222 = $437;
   }
  }
 }
 $349 = HEAP32[$299>>2]|0;
 HEAPF32[$17>>2] = 0.0;
 $350 = ((($17)) + 4|0);
 HEAPF32[$350>>2] = 0.0;
 $351 = ((($17)) + 8|0);
 HEAPF32[$351>>2] = -1.0;
 $352 = ((($349)) + 80|0);
 $353 = HEAP32[$352>>2]|0;
 $354 = ((($349)) + 84|0);
 $355 = HEAP32[$354>>2]|0;
 $356 = ($353|0)==($355|0);
 if ($356) {
  $359 = ((($349)) + 76|0);
  __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($359,$17);
 } else {
  ;HEAP32[$353>>2]=HEAP32[$17>>2]|0;HEAP32[$353+4>>2]=HEAP32[$17+4>>2]|0;HEAP32[$353+8>>2]=HEAP32[$17+8>>2]|0;
  $357 = HEAP32[$352>>2]|0;
  $358 = ((($357)) + 12|0);
  HEAP32[$352>>2] = $358;
 }
 $360 = HEAP32[$311>>2]|0;
 HEAPF32[$18>>2] = 1.0;
 $361 = ((($18)) + 4|0);
 HEAPF32[$361>>2] = 0.0;
 $362 = ((($360)) + 80|0);
 $363 = HEAP32[$362>>2]|0;
 $364 = ((($360)) + 84|0);
 $365 = HEAP32[$364>>2]|0;
 $366 = ($363|0)==($365|0);
 if ($366) {
  $379 = ((($360)) + 76|0);
  __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($379,$18);
 } else {
  $367 = $18;
  $368 = $367;
  $369 = HEAP32[$368>>2]|0;
  $370 = (($367) + 4)|0;
  $371 = $370;
  $372 = HEAP32[$371>>2]|0;
  $373 = $363;
  $374 = $373;
  HEAP32[$374>>2] = $369;
  $375 = (($373) + 4)|0;
  $376 = $375;
  HEAP32[$376>>2] = $372;
  $377 = HEAP32[$362>>2]|0;
  $378 = ((($377)) + 8|0);
  HEAP32[$362>>2] = $378;
 }
 $380 = HEAP32[$287>>2]|0;
 HEAPF32[$19>>2] = $68;
 $381 = ((($19)) + 4|0);
 HEAPF32[$381>>2] = 0.0;
 $382 = ((($19)) + 8|0);
 HEAPF32[$382>>2] = $298;
 $383 = ((($380)) + 80|0);
 $384 = HEAP32[$383>>2]|0;
 $385 = ((($380)) + 84|0);
 $386 = HEAP32[$385>>2]|0;
 $387 = ($384|0)==($386|0);
 if ($387) {
  $390 = ((($380)) + 76|0);
  __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($390,$19);
 } else {
  ;HEAP32[$384>>2]=HEAP32[$19>>2]|0;HEAP32[$384+4>>2]=HEAP32[$19+4>>2]|0;HEAP32[$384+8>>2]=HEAP32[$19+8>>2]|0;
  $388 = HEAP32[$383>>2]|0;
  $389 = ((($388)) + 12|0);
  HEAP32[$383>>2] = $389;
 }
 __ZN3osg25BuildShapeGeometryVisitor3EndEv($0);
 STACKTOP = sp;return;
}
function __ZN3osg25BuildShapeGeometryVisitor5applyERKNS_8CylinderE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$ = 0, $$$ = 0, $$093135 = 0, $$095137 = 0.0, $$097136 = 0, $$196134 = 0.0, $$pre$phi142Z2D = 0, $$pre141 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0;
 var $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0.0, $178 = 0.0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0;
 var $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0.0, $189 = 0.0, $19 = 0, $190 = 0.0, $191 = 0.0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0;
 var $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0.0, $212 = 0.0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0;
 var $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0.0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0;
 var $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0.0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0;
 var $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0.0, $270 = 0, $271 = 0, $272 = 0;
 var $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0.0, $290 = 0;
 var $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0;
 var $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0.0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0.0;
 var $327 = 0.0, $328 = 0, $329 = 0, $33 = 0.0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0.0, $338 = 0.0, $339 = 0.0, $34 = 0.0, $340 = 0.0, $341 = 0, $342 = 0, $343 = 0, $344 = 0;
 var $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0.0, $361 = 0.0, $362 = 0;
 var $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0.0, $373 = 0, $374 = 0, $375 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0.0, $57 = 0, $58 = 0.0, $59 = 0, $6 = 0, $60 = 0.0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0.0, $67 = 0, $68 = 0.0, $69 = 0.0, $7 = 0, $70 = 0.0, $71 = 0.0, $72 = 0.0, $73 = 0.0, $74 = 0.0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $exitcond = 0, $exitcond140 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 576|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(576|0);
 $2 = sp + 564|0;
 $3 = sp + 424|0;
 $4 = sp + 552|0;
 $5 = sp + 540|0;
 $6 = sp + 416|0;
 $7 = sp + 528|0;
 $8 = sp + 516|0;
 $9 = sp + 408|0;
 $10 = sp + 504|0;
 $11 = sp + 492|0;
 $12 = sp + 400|0;
 $13 = sp + 480|0;
 $14 = sp + 468|0;
 $15 = sp + 392|0;
 $16 = sp + 456|0;
 $17 = sp + 444|0;
 $18 = sp + 384|0;
 $19 = sp + 432|0;
 $20 = sp + 256|0;
 $21 = sp + 128|0;
 $22 = sp;
 $23 = ((($1)) + 56|0);
 __ZN3osg7Matrixd10makeRotateERKNS_4QuatE($21,$23);
 $24 = ((($1)) + 32|0);
 $25 = +HEAPF32[$24>>2];
 $26 = ((($1)) + 36|0);
 $27 = +HEAPF32[$26>>2];
 $28 = ((($1)) + 40|0);
 $29 = +HEAPF32[$28>>2];
 __THREW__ = 0;
 invoke_vi(3299,($22|0));
 $30 = __THREW__; __THREW__ = 0;
 $31 = $30&1;
 if ($31) {
  $64 = ___cxa_find_matching_catch_2()|0;
  $65 = tempRet0;
  ___resumeException($64|0);
  // unreachable;
 }
 $32 = $29;
 $33 = $27;
 $34 = $25;
 __THREW__ = 0;
 invoke_viddd(3306,($22|0),(+$34),(+$33),(+$32));
 $35 = __THREW__; __THREW__ = 0;
 $36 = $35&1;
 if ($36) {
  $64 = ___cxa_find_matching_catch_2()|0;
  $65 = tempRet0;
  ___resumeException($64|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_vi(3299,($20|0));
 $37 = __THREW__; __THREW__ = 0;
 $38 = $37&1;
 if ($38) {
  $64 = ___cxa_find_matching_catch_2()|0;
  $65 = tempRet0;
  ___resumeException($64|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(3300,($20|0),($21|0),($22|0));
 $39 = __THREW__; __THREW__ = 0;
 $40 = $39&1;
 if ($40) {
  $64 = ___cxa_find_matching_catch_2()|0;
  $65 = tempRet0;
  ___resumeException($64|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_vii(3911,($0|0),($20|0));
 $41 = __THREW__; __THREW__ = 0;
 $42 = $41&1;
 if ($42) {
  $64 = ___cxa_find_matching_catch_2()|0;
  $65 = tempRet0;
  ___resumeException($64|0);
  // unreachable;
 }
 $43 = ((($0)) + 8|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = ($44|0)==(0|0);
 if ($45) {
  $373 = 1;$374 = 1;$375 = 1;$58 = 1.0;
 } else {
  $46 = ((($44)) + 49|0);
  $47 = HEAP8[$46>>0]|0;
  $48 = ($47<<24>>24)!=(0);
  $49 = ((($44)) + 48|0);
  $50 = HEAP8[$49>>0]|0;
  $51 = ($50<<24>>24)!=(0);
  $52 = ((($44)) + 50|0);
  $53 = HEAP8[$52>>0]|0;
  $54 = ($53<<24>>24)!=(0);
  $55 = ((($44)) + 36|0);
  $56 = +HEAPF32[$55>>2];
  $373 = $54;$374 = $48;$375 = $51;$58 = $56;
 }
 $57 = $58 > 0.0;
 $59 = $58 != 1.0;
 $or$cond = $57 & $59;
 $60 = $58 * 40.0;
 $61 = (~~(($60))>>>0);
 $62 = ($61>>>0)>(5);
 $$ = $62 ? $61 : 5;
 $$$ = $or$cond ? $$ : 40;
 $63 = ((($1)) + 44|0);
 if ($374) {
  $66 = +HEAPF32[$63>>2];
  $67 = ((($1)) + 48|0);
  $68 = +HEAPF32[$67>>2];
  __ZN3osg25BuildShapeGeometryVisitor16drawCylinderBodyEjff($0,$$$,$66,$68);
  $$pre$phi142Z2D = $67;
 } else {
  $$pre141 = ((($1)) + 48|0);
  $$pre$phi142Z2D = $$pre141;
 }
 $69 = (+($$$>>>0));
 $70 = 6.2831854820251465 / $69;
 $71 = +HEAPF32[$63>>2];
 $72 = +HEAPF32[$$pre$phi142Z2D>>2];
 $73 = $72 * -0.5;
 $74 = $72 * 0.5;
 if ($375) {
  $75 = ((($0)) + 24|0);
  HEAP32[$75>>2] = 6;
  $76 = ((($0)) + 12|0);
  $77 = HEAP32[$76>>2]|0;
  $78 = ((($77)) + 76|0);
  $79 = ((($77)) + 80|0);
  $80 = HEAP32[$79>>2]|0;
  $81 = HEAP32[$78>>2]|0;
  $82 = (($80) - ($81))|0;
  $83 = (($82|0) / 12)&-1;
  $84 = ((($0)) + 28|0);
  HEAP32[$84>>2] = $83;
  $85 = ((($0)) + 16|0);
  $86 = HEAP32[$85>>2]|0;
  HEAPF32[$7>>2] = 0.0;
  $87 = ((($7)) + 4|0);
  HEAPF32[$87>>2] = 0.0;
  $88 = ((($7)) + 8|0);
  HEAPF32[$88>>2] = 1.0;
  $89 = ((($86)) + 80|0);
  $90 = HEAP32[$89>>2]|0;
  $91 = ((($86)) + 84|0);
  $92 = HEAP32[$91>>2]|0;
  $93 = ($90|0)==($92|0);
  if ($93) {
   $96 = ((($86)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($96,$7);
  } else {
   ;HEAP32[$90>>2]=HEAP32[$7>>2]|0;HEAP32[$90+4>>2]=HEAP32[$7+4>>2]|0;HEAP32[$90+8>>2]=HEAP32[$7+8>>2]|0;
   $94 = HEAP32[$89>>2]|0;
   $95 = ((($94)) + 12|0);
   HEAP32[$89>>2] = $95;
  }
  $97 = ((($0)) + 20|0);
  $98 = HEAP32[$97>>2]|0;
  HEAPF32[$6>>2] = 0.5;
  $99 = ((($6)) + 4|0);
  HEAPF32[$99>>2] = 0.5;
  $100 = ((($98)) + 80|0);
  $101 = HEAP32[$100>>2]|0;
  $102 = ((($98)) + 84|0);
  $103 = HEAP32[$102>>2]|0;
  $104 = ($101|0)==($103|0);
  if ($104) {
   $117 = ((($98)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($117,$6);
  } else {
   $105 = $6;
   $106 = $105;
   $107 = HEAP32[$106>>2]|0;
   $108 = (($105) + 4)|0;
   $109 = $108;
   $110 = HEAP32[$109>>2]|0;
   $111 = $101;
   $112 = $111;
   HEAP32[$112>>2] = $107;
   $113 = (($111) + 4)|0;
   $114 = $113;
   HEAP32[$114>>2] = $110;
   $115 = HEAP32[$100>>2]|0;
   $116 = ((($115)) + 8|0);
   HEAP32[$100>>2] = $116;
  }
  $118 = HEAP32[$76>>2]|0;
  HEAPF32[$5>>2] = 0.0;
  $119 = ((($5)) + 4|0);
  HEAPF32[$119>>2] = 0.0;
  $120 = ((($5)) + 8|0);
  HEAPF32[$120>>2] = $74;
  $121 = ((($118)) + 80|0);
  $122 = HEAP32[$121>>2]|0;
  $123 = ((($118)) + 84|0);
  $124 = HEAP32[$123>>2]|0;
  $125 = ($122|0)==($124|0);
  if ($125) {
   $128 = ((($118)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($128,$5);
  } else {
   ;HEAP32[$122>>2]=HEAP32[$5>>2]|0;HEAP32[$122+4>>2]=HEAP32[$5+4>>2]|0;HEAP32[$122+8>>2]=HEAP32[$5+8>>2]|0;
   $126 = HEAP32[$121>>2]|0;
   $127 = ((($126)) + 12|0);
   HEAP32[$121>>2] = $127;
  }
  $129 = ($$$|0)==(0);
  if (!($129)) {
   $130 = ((($8)) + 4|0);
   $131 = ((($8)) + 8|0);
   $132 = ((($9)) + 4|0);
   $133 = ((($10)) + 4|0);
   $134 = ((($10)) + 8|0);
   $$095137 = 0.0;$$097136 = 0;
   while(1) {
    $177 = (+Math_cos((+$$095137)));
    $178 = (+Math_sin((+$$095137)));
    $179 = HEAP32[$85>>2]|0;
    HEAPF32[$8>>2] = 0.0;
    HEAPF32[$130>>2] = 0.0;
    HEAPF32[$131>>2] = 1.0;
    $180 = ((($179)) + 80|0);
    $181 = HEAP32[$180>>2]|0;
    $182 = ((($179)) + 84|0);
    $183 = HEAP32[$182>>2]|0;
    $184 = ($181|0)==($183|0);
    if ($184) {
     $187 = ((($179)) + 76|0);
     __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($187,$8);
    } else {
     ;HEAP32[$181>>2]=HEAP32[$8>>2]|0;HEAP32[$181+4>>2]=HEAP32[$8+4>>2]|0;HEAP32[$181+8>>2]=HEAP32[$8+8>>2]|0;
     $185 = HEAP32[$180>>2]|0;
     $186 = ((($185)) + 12|0);
     HEAP32[$180>>2] = $186;
    }
    $188 = $177 * 0.5;
    $189 = $188 + 0.5;
    $190 = $178 * 0.5;
    $191 = $190 + 0.5;
    $192 = HEAP32[$97>>2]|0;
    HEAPF32[$9>>2] = $189;
    HEAPF32[$132>>2] = $191;
    $193 = ((($192)) + 80|0);
    $194 = HEAP32[$193>>2]|0;
    $195 = ((($192)) + 84|0);
    $196 = HEAP32[$195>>2]|0;
    $197 = ($194|0)==($196|0);
    if ($197) {
     $210 = ((($192)) + 76|0);
     __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($210,$9);
    } else {
     $198 = $9;
     $199 = $198;
     $200 = HEAP32[$199>>2]|0;
     $201 = (($198) + 4)|0;
     $202 = $201;
     $203 = HEAP32[$202>>2]|0;
     $204 = $194;
     $205 = $204;
     HEAP32[$205>>2] = $200;
     $206 = (($204) + 4)|0;
     $207 = $206;
     HEAP32[$207>>2] = $203;
     $208 = HEAP32[$193>>2]|0;
     $209 = ((($208)) + 8|0);
     HEAP32[$193>>2] = $209;
    }
    $211 = $71 * $177;
    $212 = $71 * $178;
    $213 = HEAP32[$76>>2]|0;
    HEAPF32[$10>>2] = $211;
    HEAPF32[$133>>2] = $212;
    HEAPF32[$134>>2] = $74;
    $214 = ((($213)) + 80|0);
    $215 = HEAP32[$214>>2]|0;
    $216 = ((($213)) + 84|0);
    $217 = HEAP32[$216>>2]|0;
    $218 = ($215|0)==($217|0);
    if ($218) {
     $221 = ((($213)) + 76|0);
     __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($221,$10);
    } else {
     ;HEAP32[$215>>2]=HEAP32[$10>>2]|0;HEAP32[$215+4>>2]=HEAP32[$10+4>>2]|0;HEAP32[$215+8>>2]=HEAP32[$10+8>>2]|0;
     $219 = HEAP32[$214>>2]|0;
     $220 = ((($219)) + 12|0);
     HEAP32[$214>>2] = $220;
    }
    $222 = (($$097136) + 1)|0;
    $223 = $70 + $$095137;
    $exitcond140 = ($222|0)==($$$|0);
    if ($exitcond140) {
     break;
    } else {
     $$095137 = $223;$$097136 = $222;
    }
   }
  }
  $135 = HEAP32[$85>>2]|0;
  HEAPF32[$4>>2] = 0.0;
  $136 = ((($4)) + 4|0);
  HEAPF32[$136>>2] = 0.0;
  $137 = ((($4)) + 8|0);
  HEAPF32[$137>>2] = 1.0;
  $138 = ((($135)) + 80|0);
  $139 = HEAP32[$138>>2]|0;
  $140 = ((($135)) + 84|0);
  $141 = HEAP32[$140>>2]|0;
  $142 = ($139|0)==($141|0);
  if ($142) {
   $145 = ((($135)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($145,$4);
  } else {
   ;HEAP32[$139>>2]=HEAP32[$4>>2]|0;HEAP32[$139+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$139+8>>2]=HEAP32[$4+8>>2]|0;
   $143 = HEAP32[$138>>2]|0;
   $144 = ((($143)) + 12|0);
   HEAP32[$138>>2] = $144;
  }
  $146 = HEAP32[$97>>2]|0;
  HEAPF32[$3>>2] = 1.0;
  $147 = ((($3)) + 4|0);
  HEAPF32[$147>>2] = 0.5;
  $148 = ((($146)) + 80|0);
  $149 = HEAP32[$148>>2]|0;
  $150 = ((($146)) + 84|0);
  $151 = HEAP32[$150>>2]|0;
  $152 = ($149|0)==($151|0);
  if ($152) {
   $165 = ((($146)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($165,$3);
  } else {
   $153 = $3;
   $154 = $153;
   $155 = HEAP32[$154>>2]|0;
   $156 = (($153) + 4)|0;
   $157 = $156;
   $158 = HEAP32[$157>>2]|0;
   $159 = $149;
   $160 = $159;
   HEAP32[$160>>2] = $155;
   $161 = (($159) + 4)|0;
   $162 = $161;
   HEAP32[$162>>2] = $158;
   $163 = HEAP32[$148>>2]|0;
   $164 = ((($163)) + 8|0);
   HEAP32[$148>>2] = $164;
  }
  $166 = HEAP32[$76>>2]|0;
  HEAPF32[$2>>2] = $71;
  $167 = ((($2)) + 4|0);
  HEAPF32[$167>>2] = 0.0;
  $168 = ((($2)) + 8|0);
  HEAPF32[$168>>2] = $74;
  $169 = ((($166)) + 80|0);
  $170 = HEAP32[$169>>2]|0;
  $171 = ((($166)) + 84|0);
  $172 = HEAP32[$171>>2]|0;
  $173 = ($170|0)==($172|0);
  if ($173) {
   $176 = ((($166)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($176,$2);
  } else {
   ;HEAP32[$170>>2]=HEAP32[$2>>2]|0;HEAP32[$170+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$170+8>>2]=HEAP32[$2+8>>2]|0;
   $174 = HEAP32[$169>>2]|0;
   $175 = ((($174)) + 12|0);
   HEAP32[$169>>2] = $175;
  }
  __ZN3osg25BuildShapeGeometryVisitor3EndEv($0);
 }
 if (!($373)) {
  STACKTOP = sp;return;
 }
 $224 = ((($0)) + 24|0);
 HEAP32[$224>>2] = 6;
 $225 = ((($0)) + 12|0);
 $226 = HEAP32[$225>>2]|0;
 $227 = ((($226)) + 76|0);
 $228 = ((($226)) + 80|0);
 $229 = HEAP32[$228>>2]|0;
 $230 = HEAP32[$227>>2]|0;
 $231 = (($229) - ($230))|0;
 $232 = (($231|0) / 12)&-1;
 $233 = ((($0)) + 28|0);
 HEAP32[$233>>2] = $232;
 $234 = ((($0)) + 16|0);
 $235 = HEAP32[$234>>2]|0;
 HEAPF32[$11>>2] = 0.0;
 $236 = ((($11)) + 4|0);
 HEAPF32[$236>>2] = 0.0;
 $237 = ((($11)) + 8|0);
 HEAPF32[$237>>2] = -1.0;
 $238 = ((($235)) + 80|0);
 $239 = HEAP32[$238>>2]|0;
 $240 = ((($235)) + 84|0);
 $241 = HEAP32[$240>>2]|0;
 $242 = ($239|0)==($241|0);
 if ($242) {
  $245 = ((($235)) + 76|0);
  __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($245,$11);
 } else {
  ;HEAP32[$239>>2]=HEAP32[$11>>2]|0;HEAP32[$239+4>>2]=HEAP32[$11+4>>2]|0;HEAP32[$239+8>>2]=HEAP32[$11+8>>2]|0;
  $243 = HEAP32[$238>>2]|0;
  $244 = ((($243)) + 12|0);
  HEAP32[$238>>2] = $244;
 }
 $246 = ((($0)) + 20|0);
 $247 = HEAP32[$246>>2]|0;
 HEAPF32[$12>>2] = 0.5;
 $248 = ((($12)) + 4|0);
 HEAPF32[$248>>2] = 0.5;
 $249 = ((($247)) + 80|0);
 $250 = HEAP32[$249>>2]|0;
 $251 = ((($247)) + 84|0);
 $252 = HEAP32[$251>>2]|0;
 $253 = ($250|0)==($252|0);
 if ($253) {
  $266 = ((($247)) + 76|0);
  __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($266,$12);
 } else {
  $254 = $12;
  $255 = $254;
  $256 = HEAP32[$255>>2]|0;
  $257 = (($254) + 4)|0;
  $258 = $257;
  $259 = HEAP32[$258>>2]|0;
  $260 = $250;
  $261 = $260;
  HEAP32[$261>>2] = $256;
  $262 = (($260) + 4)|0;
  $263 = $262;
  HEAP32[$263>>2] = $259;
  $264 = HEAP32[$249>>2]|0;
  $265 = ((($264)) + 8|0);
  HEAP32[$249>>2] = $265;
 }
 $267 = HEAP32[$225>>2]|0;
 HEAPF32[$13>>2] = 0.0;
 $268 = ((($13)) + 4|0);
 HEAPF32[$268>>2] = 0.0;
 $269 = ((($13)) + 8|0);
 HEAPF32[$269>>2] = $73;
 $270 = ((($267)) + 80|0);
 $271 = HEAP32[$270>>2]|0;
 $272 = ((($267)) + 84|0);
 $273 = HEAP32[$272>>2]|0;
 $274 = ($271|0)==($273|0);
 if ($274) {
  $277 = ((($267)) + 76|0);
  __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($277,$13);
 } else {
  ;HEAP32[$271>>2]=HEAP32[$13>>2]|0;HEAP32[$271+4>>2]=HEAP32[$13+4>>2]|0;HEAP32[$271+8>>2]=HEAP32[$13+8>>2]|0;
  $275 = HEAP32[$270>>2]|0;
  $276 = ((($275)) + 12|0);
  HEAP32[$270>>2] = $276;
 }
 $278 = ($$$|0)==(0);
 if (!($278)) {
  $279 = ((($17)) + 4|0);
  $280 = ((($17)) + 8|0);
  $281 = ((($18)) + 4|0);
  $282 = ((($19)) + 4|0);
  $283 = ((($19)) + 8|0);
  $$093135 = 0;$$196134 = 6.2831854820251465;
  while(1) {
   $326 = (+Math_cos((+$$196134)));
   $327 = (+Math_sin((+$$196134)));
   $328 = HEAP32[$234>>2]|0;
   HEAPF32[$17>>2] = 0.0;
   HEAPF32[$279>>2] = 0.0;
   HEAPF32[$280>>2] = -1.0;
   $329 = ((($328)) + 80|0);
   $330 = HEAP32[$329>>2]|0;
   $331 = ((($328)) + 84|0);
   $332 = HEAP32[$331>>2]|0;
   $333 = ($330|0)==($332|0);
   if ($333) {
    $336 = ((($328)) + 76|0);
    __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($336,$17);
   } else {
    ;HEAP32[$330>>2]=HEAP32[$17>>2]|0;HEAP32[$330+4>>2]=HEAP32[$17+4>>2]|0;HEAP32[$330+8>>2]=HEAP32[$17+8>>2]|0;
    $334 = HEAP32[$329>>2]|0;
    $335 = ((($334)) + 12|0);
    HEAP32[$329>>2] = $335;
   }
   $337 = $326 * 0.5;
   $338 = $337 + 0.5;
   $339 = $327 * 0.5;
   $340 = $339 + 0.5;
   $341 = HEAP32[$246>>2]|0;
   HEAPF32[$18>>2] = $338;
   HEAPF32[$281>>2] = $340;
   $342 = ((($341)) + 80|0);
   $343 = HEAP32[$342>>2]|0;
   $344 = ((($341)) + 84|0);
   $345 = HEAP32[$344>>2]|0;
   $346 = ($343|0)==($345|0);
   if ($346) {
    $359 = ((($341)) + 76|0);
    __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($359,$18);
   } else {
    $347 = $18;
    $348 = $347;
    $349 = HEAP32[$348>>2]|0;
    $350 = (($347) + 4)|0;
    $351 = $350;
    $352 = HEAP32[$351>>2]|0;
    $353 = $343;
    $354 = $353;
    HEAP32[$354>>2] = $349;
    $355 = (($353) + 4)|0;
    $356 = $355;
    HEAP32[$356>>2] = $352;
    $357 = HEAP32[$342>>2]|0;
    $358 = ((($357)) + 8|0);
    HEAP32[$342>>2] = $358;
   }
   $360 = $71 * $326;
   $361 = $71 * $327;
   $362 = HEAP32[$225>>2]|0;
   HEAPF32[$19>>2] = $360;
   HEAPF32[$282>>2] = $361;
   HEAPF32[$283>>2] = $73;
   $363 = ((($362)) + 80|0);
   $364 = HEAP32[$363>>2]|0;
   $365 = ((($362)) + 84|0);
   $366 = HEAP32[$365>>2]|0;
   $367 = ($364|0)==($366|0);
   if ($367) {
    $370 = ((($362)) + 76|0);
    __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($370,$19);
   } else {
    ;HEAP32[$364>>2]=HEAP32[$19>>2]|0;HEAP32[$364+4>>2]=HEAP32[$19+4>>2]|0;HEAP32[$364+8>>2]=HEAP32[$19+8>>2]|0;
    $368 = HEAP32[$363>>2]|0;
    $369 = ((($368)) + 12|0);
    HEAP32[$363>>2] = $369;
   }
   $371 = (($$093135) + 1)|0;
   $372 = $$196134 - $70;
   $exitcond = ($371|0)==($$$|0);
   if ($exitcond) {
    break;
   } else {
    $$093135 = $371;$$196134 = $372;
   }
  }
 }
 $284 = HEAP32[$234>>2]|0;
 HEAPF32[$14>>2] = 0.0;
 $285 = ((($14)) + 4|0);
 HEAPF32[$285>>2] = 0.0;
 $286 = ((($14)) + 8|0);
 HEAPF32[$286>>2] = -1.0;
 $287 = ((($284)) + 80|0);
 $288 = HEAP32[$287>>2]|0;
 $289 = ((($284)) + 84|0);
 $290 = HEAP32[$289>>2]|0;
 $291 = ($288|0)==($290|0);
 if ($291) {
  $294 = ((($284)) + 76|0);
  __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($294,$14);
 } else {
  ;HEAP32[$288>>2]=HEAP32[$14>>2]|0;HEAP32[$288+4>>2]=HEAP32[$14+4>>2]|0;HEAP32[$288+8>>2]=HEAP32[$14+8>>2]|0;
  $292 = HEAP32[$287>>2]|0;
  $293 = ((($292)) + 12|0);
  HEAP32[$287>>2] = $293;
 }
 $295 = HEAP32[$246>>2]|0;
 HEAPF32[$15>>2] = 1.0;
 $296 = ((($15)) + 4|0);
 HEAPF32[$296>>2] = 0.5;
 $297 = ((($295)) + 80|0);
 $298 = HEAP32[$297>>2]|0;
 $299 = ((($295)) + 84|0);
 $300 = HEAP32[$299>>2]|0;
 $301 = ($298|0)==($300|0);
 if ($301) {
  $314 = ((($295)) + 76|0);
  __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($314,$15);
 } else {
  $302 = $15;
  $303 = $302;
  $304 = HEAP32[$303>>2]|0;
  $305 = (($302) + 4)|0;
  $306 = $305;
  $307 = HEAP32[$306>>2]|0;
  $308 = $298;
  $309 = $308;
  HEAP32[$309>>2] = $304;
  $310 = (($308) + 4)|0;
  $311 = $310;
  HEAP32[$311>>2] = $307;
  $312 = HEAP32[$297>>2]|0;
  $313 = ((($312)) + 8|0);
  HEAP32[$297>>2] = $313;
 }
 $315 = HEAP32[$225>>2]|0;
 HEAPF32[$16>>2] = $71;
 $316 = ((($16)) + 4|0);
 HEAPF32[$316>>2] = 0.0;
 $317 = ((($16)) + 8|0);
 HEAPF32[$317>>2] = $73;
 $318 = ((($315)) + 80|0);
 $319 = HEAP32[$318>>2]|0;
 $320 = ((($315)) + 84|0);
 $321 = HEAP32[$320>>2]|0;
 $322 = ($319|0)==($321|0);
 if ($322) {
  $325 = ((($315)) + 76|0);
  __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($325,$16);
 } else {
  ;HEAP32[$319>>2]=HEAP32[$16>>2]|0;HEAP32[$319+4>>2]=HEAP32[$16+4>>2]|0;HEAP32[$319+8>>2]=HEAP32[$16+8>>2]|0;
  $323 = HEAP32[$318>>2]|0;
  $324 = ((($323)) + 12|0);
  HEAP32[$318>>2] = $324;
 }
 __ZN3osg25BuildShapeGeometryVisitor3EndEv($0);
 STACKTOP = sp;return;
}
function __ZN3osg25BuildShapeGeometryVisitor5applyERKNS_7CapsuleE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$ = 0, $$035$56 = 0, $$035$59 = 0, $$035$5961 = 0, $$035$596166 = 0, $$035$5962 = 0, $$035$60 = 0, $$03757 = 0, $$03758 = 0, $$0375863 = 0, $$0375864 = 0, $$037586465 = 0, $$2 = 0, $$pre = 0, $$pre$phi72Z2D = 0, $$pre$phiZ2D = 0, $$pre71 = 0, $10 = 0, $11 = 0.0, $12 = 0;
 var $13 = 0, $14 = 0.0, $15 = 0.0, $16 = 0.0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0.0, $39 = 0, $4 = 0, $40 = 0, $41 = 0.0, $42 = 0, $43 = 0, $44 = 0.0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0.0, $52 = 0, $53 = 0.0, $54 = 0, $55 = 0.0, $56 = 0, $57 = 0.0, $58 = 0.0, $59 = 0.0, $6 = 0, $60 = 0.0, $61 = 0.0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $7 = 0.0, $8 = 0;
 var $9 = 0.0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 384|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(384|0);
 $2 = sp + 256|0;
 $3 = sp + 128|0;
 $4 = sp;
 $5 = ((($1)) + 56|0);
 __ZN3osg7Matrixd10makeRotateERKNS_4QuatE($3,$5);
 $6 = ((($1)) + 32|0);
 $7 = +HEAPF32[$6>>2];
 $8 = ((($1)) + 36|0);
 $9 = +HEAPF32[$8>>2];
 $10 = ((($1)) + 40|0);
 $11 = +HEAPF32[$10>>2];
 __THREW__ = 0;
 invoke_vi(3299,($4|0));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $48 = ___cxa_find_matching_catch_2()|0;
  $49 = tempRet0;
  ___resumeException($48|0);
  // unreachable;
 }
 $14 = $11;
 $15 = $9;
 $16 = $7;
 __THREW__ = 0;
 invoke_viddd(3306,($4|0),(+$16),(+$15),(+$14));
 $17 = __THREW__; __THREW__ = 0;
 $18 = $17&1;
 if ($18) {
  $48 = ___cxa_find_matching_catch_2()|0;
  $49 = tempRet0;
  ___resumeException($48|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_vi(3299,($2|0));
 $19 = __THREW__; __THREW__ = 0;
 $20 = $19&1;
 if ($20) {
  $48 = ___cxa_find_matching_catch_2()|0;
  $49 = tempRet0;
  ___resumeException($48|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(3300,($2|0),($3|0),($4|0));
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if ($22) {
  $48 = ___cxa_find_matching_catch_2()|0;
  $49 = tempRet0;
  ___resumeException($48|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_vii(3911,($0|0),($2|0));
 $23 = __THREW__; __THREW__ = 0;
 $24 = $23&1;
 if ($24) {
  $48 = ___cxa_find_matching_catch_2()|0;
  $49 = tempRet0;
  ___resumeException($48|0);
  // unreachable;
 }
 $25 = ((($0)) + 8|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($26|0)==(0|0);
 do {
  if ($27) {
   $$035$60 = 20;$$03757 = 40;$62 = 1;$63 = 1;
   label = 11;
  } else {
   $28 = ((($26)) + 49|0);
   $29 = HEAP8[$28>>0]|0;
   $30 = ($29<<24>>24)!=(0);
   $31 = ((($26)) + 48|0);
   $32 = HEAP8[$31>>0]|0;
   $33 = ($32<<24>>24)!=(0);
   $34 = ((($26)) + 50|0);
   $35 = HEAP8[$34>>0]|0;
   $36 = ($35<<24>>24)!=(0);
   $37 = ((($26)) + 36|0);
   $38 = +HEAPF32[$37>>2];
   $39 = $38 > 0.0;
   $40 = $38 != 1.0;
   $or$cond = $39 & $40;
   if ($or$cond) {
    $41 = $38 * 40.0;
    $42 = (~~(($41))>>>0);
    $43 = ($42>>>0)>(5);
    $$ = $43 ? $42 : 5;
    $44 = $38 * 20.0;
    $45 = (~~(($44))>>>0);
    $46 = ($45>>>0)>(3);
    $$2 = $46 ? $45 : 3;
    $47 = $$2 & 1;
    $$035$56 = (($47) + ($$2))|0;
    if ($30) {
     $$035$60 = $$035$56;$$03757 = $$;$62 = $36;$63 = $33;
     label = 11;
     break;
    } else {
     $$035$59 = $$035$56;$$03758 = $$;
    }
   } else {
    if ($30) {
     $$035$60 = 20;$$03757 = 40;$62 = $36;$63 = $33;
     label = 11;
     break;
    } else {
     $$035$59 = 20;$$03758 = 40;
    }
   }
   if ($33) {
    $$035$5962 = $$035$59;$$0375863 = $$03758;$64 = $36;
    label = 13;
   } else {
    $$035$5961 = $$035$59;$$0375864 = $$03758;$65 = $36;
    label = 14;
   }
  }
 } while(0);
 if ((label|0) == 11) {
  $50 = ((($1)) + 44|0);
  $51 = +HEAPF32[$50>>2];
  $52 = ((($1)) + 48|0);
  $53 = +HEAPF32[$52>>2];
  __ZN3osg25BuildShapeGeometryVisitor16drawCylinderBodyEjff($0,$$03757,$51,$53);
  if ($63) {
   $$035$5962 = $$035$60;$$0375863 = $$03757;$64 = $62;
   label = 13;
  } else {
   $$035$5961 = $$035$60;$$0375864 = $$03757;$65 = $62;
   label = 14;
  }
 }
 do {
  if ((label|0) == 13) {
   $54 = ((($1)) + 44|0);
   $55 = +HEAPF32[$54>>2];
   $56 = ((($1)) + 48|0);
   $57 = +HEAPF32[$56>>2];
   $58 = $57 * 0.5;
   __ZN3osg25BuildShapeGeometryVisitor14drawHalfSphereEjjfNS0_10SphereHalfEf($0,$$0375863,$$035$5962,$55,0,$58);
   if ($64) {
    $$035$596166 = $$035$5962;$$037586465 = $$0375863;$$pre$phi72Z2D = $56;$$pre$phiZ2D = $54;
   } else {
    STACKTOP = sp;return;
   }
  }
  else if ((label|0) == 14) {
   if ($65) {
    $$pre = ((($1)) + 44|0);
    $$pre71 = ((($1)) + 48|0);
    $$035$596166 = $$035$5961;$$037586465 = $$0375864;$$pre$phi72Z2D = $$pre71;$$pre$phiZ2D = $$pre;
    break;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $59 = +HEAPF32[$$pre$phiZ2D>>2];
 $60 = +HEAPF32[$$pre$phi72Z2D>>2];
 $61 = $60 * -0.5;
 __ZN3osg25BuildShapeGeometryVisitor14drawHalfSphereEjjfNS0_10SphereHalfEf($0,$$037586465,$$035$596166,$59,1,$61);
 STACKTOP = sp;return;
}
function __ZN3osg25BuildShapeGeometryVisitor5applyERKNS_13InfinitePlaneE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $4 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
 $5 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($4,148308,91)|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($6)) + -12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($5) + ($8)|0);
 __ZNKSt3__28ios_base6getlocEv($2,$9);
 __THREW__ = 0;
 $10 = (invoke_iii(3255,($2|0),(215188|0))|0);
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if (!($12)) {
  $13 = HEAP32[$10>>2]|0;
  $14 = ((($13)) + 28|0);
  $15 = HEAP32[$14>>2]|0;
  __THREW__ = 0;
  $16 = (invoke_iii($15|0,($10|0),10)|0);
  $17 = __THREW__; __THREW__ = 0;
  $18 = $17&1;
  if (!($18)) {
   __ZNSt3__26localeD2Ev($2);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($5,$16)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($5)|0);
   STACKTOP = sp;return;
  }
 }
 $19 = ___cxa_find_matching_catch_2()|0;
 $20 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($2|0));
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if ($22) {
  $23 = ___cxa_find_matching_catch_3(0|0)|0;
  $24 = tempRet0;
  ___clang_call_terminate($23);
  // unreachable;
 } else {
  ___resumeException($19|0);
  // unreachable;
 }
}
function __ZN3osg25BuildShapeGeometryVisitor5applyERKNS_12TriangleMeshE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$044 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0;
 var $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0;
 var $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0.0, $49 = 0.0, $5 = 0, $50 = 0.0, $51 = 0, $52 = 0.0, $53 = 0, $54 = 0.0;
 var $55 = 0.0, $56 = 0, $57 = 0.0, $58 = 0, $59 = 0.0, $6 = 0, $60 = 0.0, $61 = 0.0, $62 = 0.0, $63 = 0, $64 = 0.0, $65 = 0.0, $66 = 0, $67 = 0.0, $68 = 0.0, $69 = 0.0, $7 = 0, $70 = 0.0, $71 = 0.0, $72 = 0.0;
 var $73 = 0.0, $74 = 0.0, $75 = 0.0, $76 = 0.0, $77 = 0.0, $78 = 0.0, $79 = 0.0, $8 = 0, $80 = 0.0, $81 = 0.0, $82 = 0.0, $83 = 0.0, $84 = 0, $85 = 0.0, $86 = 0.0, $87 = 0.0, $88 = 0.0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = ((($1)) + 32|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($1)) + 36|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4|0)!=(0|0);
 $8 = ($6|0)!=(0|0);
 $or$cond = $7 & $8;
 if (!($or$cond)) {
  STACKTOP = sp;return;
 }
 $9 = ((($0)) + 24|0);
 HEAP32[$9>>2] = 4;
 $10 = ((($0)) + 12|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11)) + 76|0);
 $13 = ((($11)) + 80|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP32[$12>>2]|0;
 $16 = (($14) - ($15))|0;
 $17 = (($16|0) / 12)&-1;
 $18 = ((($0)) + 28|0);
 HEAP32[$18>>2] = $17;
 $19 = HEAP32[$6>>2]|0;
 $20 = ((($19)) + 200|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (FUNCTION_TABLE_ii[$21 & 8191]($6)|0);
 $23 = ($22>>>0)>(2);
 if ($23) {
  $24 = ((($4)) + 76|0);
  $25 = ((($2)) + 4|0);
  $26 = ((($2)) + 8|0);
  $27 = ((($0)) + 16|0);
  $$044 = 0;$44 = 2;
  while(1) {
   $28 = HEAP32[$6>>2]|0;
   $29 = ((($28)) + 216|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = (FUNCTION_TABLE_iii[$30 & 8191]($6,$$044)|0);
   $32 = HEAP32[$24>>2]|0;
   $33 = (($32) + (($31*12)|0)|0);
   $34 = HEAP32[$6>>2]|0;
   $35 = ((($34)) + 216|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($$044) + 1)|0;
   $38 = (FUNCTION_TABLE_iii[$36 & 8191]($6,$37)|0);
   $39 = HEAP32[$24>>2]|0;
   $40 = (($39) + (($38*12)|0)|0);
   $41 = HEAP32[$6>>2]|0;
   $42 = ((($41)) + 216|0);
   $43 = HEAP32[$42>>2]|0;
   $45 = (FUNCTION_TABLE_iii[$43 & 8191]($6,$44)|0);
   $46 = HEAP32[$24>>2]|0;
   $47 = (($46) + (($45*12)|0)|0);
   $48 = +HEAPF32[$40>>2];
   $49 = +HEAPF32[$33>>2];
   $50 = $48 - $49;
   $51 = (((($39) + (($38*12)|0)|0)) + 4|0);
   $52 = +HEAPF32[$51>>2];
   $53 = (((($32) + (($31*12)|0)|0)) + 4|0);
   $54 = +HEAPF32[$53>>2];
   $55 = $52 - $54;
   $56 = (((($39) + (($38*12)|0)|0)) + 8|0);
   $57 = +HEAPF32[$56>>2];
   $58 = (((($32) + (($31*12)|0)|0)) + 8|0);
   $59 = +HEAPF32[$58>>2];
   $60 = $57 - $59;
   $61 = +HEAPF32[$47>>2];
   $62 = $61 - $48;
   $63 = (((($46) + (($45*12)|0)|0)) + 4|0);
   $64 = +HEAPF32[$63>>2];
   $65 = $64 - $52;
   $66 = (((($46) + (($45*12)|0)|0)) + 8|0);
   $67 = +HEAPF32[$66>>2];
   $68 = $67 - $57;
   $69 = $55 * $68;
   $70 = $60 * $65;
   $71 = $69 - $70;
   $72 = $60 * $62;
   $73 = $50 * $68;
   $74 = $72 - $73;
   $75 = $50 * $65;
   $76 = $55 * $62;
   $77 = $75 - $76;
   HEAPF32[$2>>2] = $71;
   HEAPF32[$25>>2] = $74;
   HEAPF32[$26>>2] = $77;
   $78 = $71 * $71;
   $79 = $74 * $74;
   $80 = $78 + $79;
   $81 = $77 * $77;
   $82 = $81 + $80;
   $83 = (+Math_sqrt((+$82)));
   $84 = $83 > 0.0;
   $85 = 1.0 / $83;
   if ($84) {
    $86 = $77 * $85;
    $87 = $74 * $85;
    $88 = $71 * $85;
    HEAPF32[$2>>2] = $88;
    HEAPF32[$25>>2] = $87;
    HEAPF32[$26>>2] = $86;
   }
   $89 = HEAP32[$27>>2]|0;
   $90 = ((($89)) + 80|0);
   $91 = HEAP32[$90>>2]|0;
   $92 = ((($89)) + 84|0);
   $93 = HEAP32[$92>>2]|0;
   $94 = ($91|0)==($93|0);
   if ($94) {
    $97 = ((($89)) + 76|0);
    __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($97,$2);
   } else {
    ;HEAP32[$91>>2]=HEAP32[$2>>2]|0;HEAP32[$91+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$91+8>>2]=HEAP32[$2+8>>2]|0;
    $95 = HEAP32[$90>>2]|0;
    $96 = ((($95)) + 12|0);
    HEAP32[$90>>2] = $96;
   }
   $98 = HEAP32[$10>>2]|0;
   $99 = ((($98)) + 80|0);
   $100 = HEAP32[$99>>2]|0;
   $101 = ((($98)) + 84|0);
   $102 = HEAP32[$101>>2]|0;
   $103 = ($100|0)==($102|0);
   if ($103) {
    $106 = ((($98)) + 76|0);
    __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($106,$33);
   } else {
    ;HEAP32[$100>>2]=HEAP32[$33>>2]|0;HEAP32[$100+4>>2]=HEAP32[$33+4>>2]|0;HEAP32[$100+8>>2]=HEAP32[$33+8>>2]|0;
    $104 = HEAP32[$99>>2]|0;
    $105 = ((($104)) + 12|0);
    HEAP32[$99>>2] = $105;
   }
   $107 = HEAP32[$27>>2]|0;
   $108 = ((($107)) + 80|0);
   $109 = HEAP32[$108>>2]|0;
   $110 = ((($107)) + 84|0);
   $111 = HEAP32[$110>>2]|0;
   $112 = ($109|0)==($111|0);
   if ($112) {
    $115 = ((($107)) + 76|0);
    __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($115,$2);
   } else {
    ;HEAP32[$109>>2]=HEAP32[$2>>2]|0;HEAP32[$109+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$109+8>>2]=HEAP32[$2+8>>2]|0;
    $113 = HEAP32[$108>>2]|0;
    $114 = ((($113)) + 12|0);
    HEAP32[$108>>2] = $114;
   }
   $116 = HEAP32[$10>>2]|0;
   $117 = ((($116)) + 80|0);
   $118 = HEAP32[$117>>2]|0;
   $119 = ((($116)) + 84|0);
   $120 = HEAP32[$119>>2]|0;
   $121 = ($118|0)==($120|0);
   if ($121) {
    $124 = ((($116)) + 76|0);
    __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($124,$40);
   } else {
    ;HEAP32[$118>>2]=HEAP32[$40>>2]|0;HEAP32[$118+4>>2]=HEAP32[$40+4>>2]|0;HEAP32[$118+8>>2]=HEAP32[$40+8>>2]|0;
    $122 = HEAP32[$117>>2]|0;
    $123 = ((($122)) + 12|0);
    HEAP32[$117>>2] = $123;
   }
   $125 = HEAP32[$27>>2]|0;
   $126 = ((($125)) + 80|0);
   $127 = HEAP32[$126>>2]|0;
   $128 = ((($125)) + 84|0);
   $129 = HEAP32[$128>>2]|0;
   $130 = ($127|0)==($129|0);
   if ($130) {
    $133 = ((($125)) + 76|0);
    __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($133,$2);
   } else {
    ;HEAP32[$127>>2]=HEAP32[$2>>2]|0;HEAP32[$127+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$127+8>>2]=HEAP32[$2+8>>2]|0;
    $131 = HEAP32[$126>>2]|0;
    $132 = ((($131)) + 12|0);
    HEAP32[$126>>2] = $132;
   }
   $134 = HEAP32[$10>>2]|0;
   $135 = ((($134)) + 80|0);
   $136 = HEAP32[$135>>2]|0;
   $137 = ((($134)) + 84|0);
   $138 = HEAP32[$137>>2]|0;
   $139 = ($136|0)==($138|0);
   if ($139) {
    $142 = ((($134)) + 76|0);
    __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($142,$47);
   } else {
    ;HEAP32[$136>>2]=HEAP32[$47>>2]|0;HEAP32[$136+4>>2]=HEAP32[$47+4>>2]|0;HEAP32[$136+8>>2]=HEAP32[$47+8>>2]|0;
    $140 = HEAP32[$135>>2]|0;
    $141 = ((($140)) + 12|0);
    HEAP32[$135>>2] = $141;
   }
   $143 = (($$044) + 3)|0;
   $144 = (($$044) + 5)|0;
   $145 = HEAP32[$6>>2]|0;
   $146 = ((($145)) + 200|0);
   $147 = HEAP32[$146>>2]|0;
   $148 = (FUNCTION_TABLE_ii[$147 & 8191]($6)|0);
   $149 = ($144>>>0)<($148>>>0);
   if ($149) {
    $$044 = $143;$44 = $144;
   } else {
    break;
   }
  }
 }
 __ZN3osg25BuildShapeGeometryVisitor3EndEv($0);
 STACKTOP = sp;return;
}
function __ZN3osg25BuildShapeGeometryVisitor5applyERKNS_10ConvexHullE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $3 = ((($2)) + 36|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 8191]($0,$1);
 return;
}
function __ZN3osg25BuildShapeGeometryVisitor5applyERKNS_11HeightFieldE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0129$lcssa = 0.0, $$0129198 = 0.0, $$0131203 = 0, $$0134212 = 0, $$0136211 = 0.0, $$0138200 = 0.0, $$0199 = 0, $$1135207 = 0, $$1137206 = 0.0, $$pre = 0, $$pre$phi216Z2D = 0, $$pre$phiZ2D = 0, $$sink$i = 0.0, $$sink31$i = 0.0, $$sink31$i173 = 0.0, $$sroa$0$0$v = 0.0, $$sroa$0185$0$v = 0.0, $$sroa$0191$0$v = 0.0, $$sroa$5$0$v = 0.0, $$sroa$5187$0$v = 0.0;
 var $$sroa$5193$0$v = 0.0, $$sroa$8$0 = 0, $$sroa$8189$0 = 0, $$sroa$8195$0 = 0, $10 = 0, $100 = 0.0, $101 = 0, $102 = 0, $103 = 0.0, $104 = 0, $105 = 0, $106 = 0.0, $107 = 0.0, $108 = 0, $109 = 0, $11 = 0, $110 = 0.0, $111 = 0, $112 = 0, $113 = 0.0;
 var $114 = 0.0, $115 = 0.0, $116 = 0.0, $117 = 0.0, $118 = 0, $119 = 0, $12 = 0, $120 = 0.0, $121 = 0.0, $122 = 0.0, $123 = 0.0, $124 = 0.0, $125 = 0.0, $126 = 0.0, $127 = 0.0, $128 = 0.0, $129 = 0.0, $13 = 0, $130 = 0.0, $131 = 0.0;
 var $132 = 0, $133 = 0.0, $134 = 0.0, $135 = 0.0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0.0, $175 = 0.0, $176 = 0.0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0.0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0;
 var $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0.0, $23 = 0, $230 = 0.0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0;
 var $240 = 0, $241 = 0, $242 = 0.0, $243 = 0.0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0;
 var $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0;
 var $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0.0, $286 = 0.0, $287 = 0.0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0;
 var $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0.0, $310 = 0, $311 = 0;
 var $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0.0;
 var $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0.0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0;
 var $349 = 0, $35 = 0.0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0.0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0.0, $365 = 0, $366 = 0;
 var $367 = 0.0, $368 = 0.0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0.0, $376 = 0.0, $377 = 0, $378 = 0, $379 = 0.0, $38 = 0.0, $380 = 0.0, $381 = 0.0, $382 = 0.0, $383 = 0.0, $384 = 0;
 var $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0.0, $39 = 0.0, $390 = 0.0, $391 = 0, $392 = 0, $393 = 0, $394 = 0.0, $395 = 0, $396 = 0, $397 = 0.0, $398 = 0.0, $399 = 0.0, $4 = 0, $40 = 0.0, $400 = 0.0, $401 = 0.0;
 var $402 = 0.0, $403 = 0.0, $404 = 0.0, $405 = 0.0, $406 = 0.0, $407 = 0.0, $408 = 0.0, $409 = 0, $41 = 0, $410 = 0.0, $411 = 0.0, $412 = 0.0, $413 = 0, $414 = 0.0, $415 = 0.0, $416 = 0.0, $417 = 0.0, $418 = 0, $419 = 0, $42 = 0;
 var $420 = 0.0, $421 = 0.0, $422 = 0.0, $423 = 0.0, $424 = 0, $425 = 0, $426 = 0.0, $427 = 0.0, $428 = 0.0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0.0, $436 = 0.0, $437 = 0.0, $438 = 0;
 var $439 = 0, $44 = 0, $440 = 0, $441 = 0.0, $442 = 0.0, $443 = 0.0, $444 = 0.0, $445 = 0.0, $446 = 0.0, $447 = 0.0, $448 = 0.0, $449 = 0.0, $45 = 0, $450 = 0.0, $451 = 0.0, $452 = 0, $453 = 0.0, $454 = 0.0, $455 = 0.0, $456 = 0;
 var $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0;
 var $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0;
 var $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0.0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0;
 var $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0.0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0;
 var $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0.0, $535 = 0.0, $536 = 0.0, $537 = 0.0, $538 = 0.0, $539 = 0, $54 = 0.0, $540 = 0.0, $541 = 0.0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0;
 var $547 = 0, $548 = 0, $549 = 0, $55 = 0.0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0.0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0;
 var $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0.0, $580 = 0, $581 = 0, $582 = 0;
 var $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0.0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0.0;
 var $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0;
 var $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0;
 var $637 = 0, $638 = 0, $639 = 0.0, $64 = 0, $640 = 0, $641 = 0, $642 = 0.0, $643 = 0.0, $644 = 0.0, $645 = 0.0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0;
 var $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0;
 var $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0;
 var $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0.0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0;
 var $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0.0, $89 = 0.0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0.0, $99 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 560|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(560|0);
 $2 = sp + 456|0;
 $3 = sp + 548|0;
 $4 = sp + 448|0;
 $5 = sp + 440|0;
 $6 = sp + 432|0;
 $7 = sp + 424|0;
 $8 = sp + 416|0;
 $9 = sp + 408|0;
 $10 = sp + 400|0;
 $11 = sp + 392|0;
 $12 = sp + 384|0;
 $13 = sp + 256|0;
 $14 = sp + 128|0;
 $15 = sp;
 $16 = sp + 536|0;
 $17 = sp + 524|0;
 $18 = sp + 512|0;
 $19 = sp + 500|0;
 $20 = sp + 488|0;
 $21 = sp + 476|0;
 $22 = sp + 464|0;
 $23 = ((($1)) + 32|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)==(0);
 if ($25) {
  STACKTOP = sp;return;
 }
 $26 = ((($1)) + 36|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ($27|0)==(0);
 if ($28) {
  STACKTOP = sp;return;
 }
 $29 = ((($1)) + 72|0);
 __ZN3osg7Matrixd10makeRotateERKNS_4QuatE($14,$29);
 $30 = ((($1)) + 40|0);
 $31 = +HEAPF32[$30>>2];
 $32 = ((($1)) + 44|0);
 $33 = +HEAPF32[$32>>2];
 $34 = ((($1)) + 48|0);
 $35 = +HEAPF32[$34>>2];
 __THREW__ = 0;
 invoke_vi(3299,($15|0));
 $36 = __THREW__; __THREW__ = 0;
 $37 = $36&1;
 if ($37) {
  $218 = ___cxa_find_matching_catch_2()|0;
  $219 = tempRet0;
  ___resumeException($218|0);
  // unreachable;
 }
 $38 = $35;
 $39 = $33;
 $40 = $31;
 __THREW__ = 0;
 invoke_viddd(3306,($15|0),(+$40),(+$39),(+$38));
 $41 = __THREW__; __THREW__ = 0;
 $42 = $41&1;
 if ($42) {
  $218 = ___cxa_find_matching_catch_2()|0;
  $219 = tempRet0;
  ___resumeException($218|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_vi(3299,($13|0));
 $43 = __THREW__; __THREW__ = 0;
 $44 = $43&1;
 if ($44) {
  $218 = ___cxa_find_matching_catch_2()|0;
  $219 = tempRet0;
  ___resumeException($218|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(3300,($13|0),($14|0),($15|0));
 $45 = __THREW__; __THREW__ = 0;
 $46 = $45&1;
 if ($46) {
  $218 = ___cxa_find_matching_catch_2()|0;
  $219 = tempRet0;
  ___resumeException($218|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_vii(3911,($0|0),($13|0));
 $47 = __THREW__; __THREW__ = 0;
 $48 = $47&1;
 if ($48) {
  $218 = ___cxa_find_matching_catch_2()|0;
  $219 = tempRet0;
  ___resumeException($218|0);
  // unreachable;
 }
 $49 = ((($1)) + 52|0);
 $50 = +HEAPF32[$49>>2];
 $51 = ((($1)) + 56|0);
 $52 = +HEAPF32[$51>>2];
 $53 = HEAP32[$23>>2]|0;
 $54 = (+($53>>>0));
 $55 = $54 + -1.0;
 $56 = 1.0 / $55;
 $57 = HEAP32[$26>>2]|0;
 $58 = (+($57>>>0));
 $59 = $58 + -1.0;
 $60 = 1.0 / $59;
 HEAPF32[$16>>2] = 0.0;
 $61 = ((($16)) + 4|0);
 HEAPF32[$61>>2] = 0.0;
 $62 = ((($16)) + 8|0);
 HEAPF32[$62>>2] = 0.0;
 HEAPF32[$17>>2] = 0.0;
 $63 = ((($17)) + 4|0);
 HEAPF32[$63>>2] = 0.0;
 $64 = ((($17)) + 8|0);
 HEAPF32[$64>>2] = 0.0;
 HEAPF32[$18>>2] = 0.0;
 $65 = ((($18)) + 4|0);
 HEAPF32[$65>>2] = 0.0;
 $66 = ((($18)) + 8|0);
 HEAPF32[$66>>2] = 0.0;
 HEAPF32[$19>>2] = 0.0;
 $67 = ((($19)) + 4|0);
 HEAPF32[$67>>2] = 0.0;
 $68 = ((($19)) + 8|0);
 HEAPF32[$68>>2] = 0.0;
 $69 = ((($1)) + 60|0);
 $70 = +HEAPF32[$69>>2];
 $71 = $70 != 0.0;
 if ($71) {
  $72 = ((($0)) + 24|0);
  HEAP32[$72>>2] = 8;
  $73 = ((($0)) + 12|0);
  $74 = HEAP32[$73>>2]|0;
  $75 = ((($74)) + 76|0);
  $76 = ((($74)) + 80|0);
  $77 = HEAP32[$76>>2]|0;
  $78 = HEAP32[$75>>2]|0;
  $79 = (($77) - ($78))|0;
  $80 = (($79|0) / 12)&-1;
  $81 = ((($0)) + 28|0);
  HEAP32[$81>>2] = $80;
  HEAPF32[$61>>2] = 0.0;
  $82 = ($53|0)==(0);
  if (!($82)) {
   $83 = ((($1)) + 104|0);
   $84 = ((($0)) + 20|0);
   $85 = ((($7)) + 4|0);
   $86 = ((($0)) + 16|0);
   $87 = ((($5)) + 4|0);
   $$0134212 = 0;$$0136211 = 0.0;
   while(1) {
    $88 = (+($$0134212>>>0));
    $89 = $50 * $88;
    HEAPF32[$16>>2] = $89;
    $90 = HEAP32[$83>>2]|0;
    $91 = ((($90)) + 76|0);
    $92 = HEAP32[$91>>2]|0;
    $93 = (($92) + ($$0134212<<2)|0);
    $94 = HEAP32[$93>>2]|0;
    HEAP32[$62>>2] = $94;
    $95 = ($$0134212|0)==(0);
    $96 = HEAP32[$23>>2]|0;
    do {
     if ($95) {
      $97 = ((($92)) + 4|0);
      $98 = +HEAPF32[$97>>2];
      $99 = +HEAPF32[$92>>2];
      $100 = $98 - $99;
      $$sink$i = $100;
     } else {
      $101 = (($96) + -1)|0;
      $102 = ($101|0)==($$0134212|0);
      if ($102) {
       $103 = +HEAPF32[$93>>2];
       $104 = (($$0134212) + -1)|0;
       $105 = (($92) + ($104<<2)|0);
       $106 = +HEAPF32[$105>>2];
       $107 = $103 - $106;
       $$sink$i = $107;
       break;
      } else {
       $108 = (($$0134212) + 1)|0;
       $109 = (($92) + ($108<<2)|0);
       $110 = +HEAPF32[$109>>2];
       $111 = (($$0134212) + -1)|0;
       $112 = (($92) + ($111<<2)|0);
       $113 = +HEAPF32[$112>>2];
       $114 = $110 - $113;
       $115 = $114 * 0.5;
       $$sink$i = $115;
       break;
      }
     }
    } while(0);
    $116 = +HEAPF32[$49>>2];
    $117 = $$sink$i / $116;
    $118 = (($96) + ($$0134212))|0;
    $119 = (($92) + ($118<<2)|0);
    $120 = +HEAPF32[$119>>2];
    $121 = +HEAPF32[$93>>2];
    $122 = $120 - $121;
    $123 = +HEAPF32[$51>>2];
    $124 = $122 / $123;
    $125 = -$117;
    $126 = -$124;
    $127 = $117 * $117;
    $128 = $124 * $124;
    $129 = $127 + $128;
    $130 = $129 + 1.0;
    $131 = (+Math_sqrt((+$130)));
    $132 = $131 > 0.0;
    $133 = 1.0 / $131;
    $134 = $133 * $126;
    $135 = $133 * $125;
    $136 = (HEAPF32[tempDoublePtr>>2]=$133,HEAP32[tempDoublePtr>>2]|0);
    $$sroa$8195$0 = $132 ? $136 : 1065353216;
    $$sroa$5193$0$v = $132 ? $134 : $126;
    $$sroa$0191$0$v = $132 ? $135 : $125;
    HEAPF32[$17>>2] = $$sroa$0191$0$v;
    HEAPF32[$63>>2] = $$sroa$5193$0$v;
    HEAP32[$64>>2] = $$sroa$8195$0;
    $137 = HEAP32[$84>>2]|0;
    HEAPF32[$7>>2] = $$0136211;
    HEAPF32[$85>>2] = 0.0;
    $138 = ((($137)) + 80|0);
    $139 = HEAP32[$138>>2]|0;
    $140 = ((($137)) + 84|0);
    $141 = HEAP32[$140>>2]|0;
    $142 = ($139|0)==($141|0);
    if ($142) {
     $155 = ((($137)) + 76|0);
     __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($155,$7);
    } else {
     $143 = $7;
     $144 = $143;
     $145 = HEAP32[$144>>2]|0;
     $146 = (($143) + 4)|0;
     $147 = $146;
     $148 = HEAP32[$147>>2]|0;
     $149 = $139;
     $150 = $149;
     HEAP32[$150>>2] = $145;
     $151 = (($149) + 4)|0;
     $152 = $151;
     HEAP32[$152>>2] = $148;
     $153 = HEAP32[$138>>2]|0;
     $154 = ((($153)) + 8|0);
     HEAP32[$138>>2] = $154;
    }
    $156 = HEAP32[$86>>2]|0;
    $157 = ((($156)) + 80|0);
    $158 = HEAP32[$157>>2]|0;
    $159 = ((($156)) + 84|0);
    $160 = HEAP32[$159>>2]|0;
    $161 = ($158|0)==($160|0);
    if ($161) {
     $164 = ((($156)) + 76|0);
     __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($164,$17);
    } else {
     ;HEAP32[$158>>2]=HEAP32[$17>>2]|0;HEAP32[$158+4>>2]=HEAP32[$17+4>>2]|0;HEAP32[$158+8>>2]=HEAP32[$17+8>>2]|0;
     $162 = HEAP32[$157>>2]|0;
     $163 = ((($162)) + 12|0);
     HEAP32[$157>>2] = $163;
    }
    $165 = HEAP32[$73>>2]|0;
    $166 = ((($165)) + 80|0);
    $167 = HEAP32[$166>>2]|0;
    $168 = ((($165)) + 84|0);
    $169 = HEAP32[$168>>2]|0;
    $170 = ($167|0)==($169|0);
    if ($170) {
     $173 = ((($165)) + 76|0);
     __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($173,$16);
    } else {
     ;HEAP32[$167>>2]=HEAP32[$16>>2]|0;HEAP32[$167+4>>2]=HEAP32[$16+4>>2]|0;HEAP32[$167+8>>2]=HEAP32[$16+8>>2]|0;
     $171 = HEAP32[$166>>2]|0;
     $172 = ((($171)) + 12|0);
     HEAP32[$166>>2] = $172;
    }
    $174 = +HEAPF32[$69>>2];
    $175 = +HEAPF32[$62>>2];
    $176 = $175 - $174;
    HEAPF32[$62>>2] = $176;
    $177 = HEAP32[$84>>2]|0;
    HEAPF32[$5>>2] = $$0136211;
    HEAPF32[$87>>2] = 0.0;
    $178 = ((($177)) + 80|0);
    $179 = HEAP32[$178>>2]|0;
    $180 = ((($177)) + 84|0);
    $181 = HEAP32[$180>>2]|0;
    $182 = ($179|0)==($181|0);
    if ($182) {
     $195 = ((($177)) + 76|0);
     __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($195,$5);
    } else {
     $183 = $5;
     $184 = $183;
     $185 = HEAP32[$184>>2]|0;
     $186 = (($183) + 4)|0;
     $187 = $186;
     $188 = HEAP32[$187>>2]|0;
     $189 = $179;
     $190 = $189;
     HEAP32[$190>>2] = $185;
     $191 = (($189) + 4)|0;
     $192 = $191;
     HEAP32[$192>>2] = $188;
     $193 = HEAP32[$178>>2]|0;
     $194 = ((($193)) + 8|0);
     HEAP32[$178>>2] = $194;
    }
    $196 = HEAP32[$86>>2]|0;
    $197 = ((($196)) + 80|0);
    $198 = HEAP32[$197>>2]|0;
    $199 = ((($196)) + 84|0);
    $200 = HEAP32[$199>>2]|0;
    $201 = ($198|0)==($200|0);
    if ($201) {
     $204 = ((($196)) + 76|0);
     __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($204,$17);
    } else {
     ;HEAP32[$198>>2]=HEAP32[$17>>2]|0;HEAP32[$198+4>>2]=HEAP32[$17+4>>2]|0;HEAP32[$198+8>>2]=HEAP32[$17+8>>2]|0;
     $202 = HEAP32[$197>>2]|0;
     $203 = ((($202)) + 12|0);
     HEAP32[$197>>2] = $203;
    }
    $205 = HEAP32[$73>>2]|0;
    $206 = ((($205)) + 80|0);
    $207 = HEAP32[$206>>2]|0;
    $208 = ((($205)) + 84|0);
    $209 = HEAP32[$208>>2]|0;
    $210 = ($207|0)==($209|0);
    if ($210) {
     $213 = ((($205)) + 76|0);
     __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($213,$16);
    } else {
     ;HEAP32[$207>>2]=HEAP32[$16>>2]|0;HEAP32[$207+4>>2]=HEAP32[$16+4>>2]|0;HEAP32[$207+8>>2]=HEAP32[$16+8>>2]|0;
     $211 = HEAP32[$206>>2]|0;
     $212 = ((($211)) + 12|0);
     HEAP32[$206>>2] = $212;
    }
    $214 = (($$0134212) + 1)|0;
    $215 = $56 + $$0136211;
    $216 = HEAP32[$23>>2]|0;
    $217 = ($214>>>0)<($216>>>0);
    if ($217) {
     $$0134212 = $214;$$0136211 = $215;
    } else {
     break;
    }
   }
  }
  __ZN3osg25BuildShapeGeometryVisitor3EndEv($0);
  HEAP32[$72>>2] = 8;
  $220 = HEAP32[$73>>2]|0;
  $221 = ((($220)) + 76|0);
  $222 = ((($220)) + 80|0);
  $223 = HEAP32[$222>>2]|0;
  $224 = HEAP32[$221>>2]|0;
  $225 = (($223) - ($224))|0;
  $226 = (($225|0) / 12)&-1;
  HEAP32[$81>>2] = $226;
  $227 = HEAP32[$26>>2]|0;
  $228 = (($227) + -1)|0;
  $229 = (+($228>>>0));
  $230 = $52 * $229;
  HEAPF32[$61>>2] = $230;
  $231 = HEAP32[$23>>2]|0;
  $232 = ($231|0)==(0);
  if (!($232)) {
   $233 = ((($1)) + 104|0);
   $234 = ((($20)) + 4|0);
   $235 = ((($20)) + 8|0);
   $236 = ((($0)) + 20|0);
   $237 = ((($2)) + 4|0);
   $238 = ((($0)) + 16|0);
   $239 = ((($3)) + 4|0);
   $240 = ((($3)) + 8|0);
   $241 = ((($4)) + 4|0);
   $$1135207 = 0;$$1137206 = 0.0;$246 = $231;
   while(1) {
    $242 = (+($$1135207>>>0));
    $243 = $50 * $242;
    HEAPF32[$16>>2] = $243;
    $244 = HEAP32[$233>>2]|0;
    $245 = Math_imul($246, $228)|0;
    $247 = (($245) + ($$1135207))|0;
    $248 = ((($244)) + 76|0);
    $249 = HEAP32[$248>>2]|0;
    $250 = (($249) + ($247<<2)|0);
    $251 = HEAP32[$250>>2]|0;
    HEAP32[$62>>2] = $251;
    __ZNK3osg11HeightField9getNormalEjj($20,$1,$$1135207,$228);
    $252 = HEAP32[$20>>2]|0;
    HEAP32[$17>>2] = $252;
    $253 = HEAP32[$234>>2]|0;
    HEAP32[$63>>2] = $253;
    $254 = HEAP32[$235>>2]|0;
    HEAP32[$64>>2] = $254;
    $255 = HEAP32[$236>>2]|0;
    HEAPF32[$2>>2] = $$1137206;
    HEAPF32[$237>>2] = 1.0;
    $256 = ((($255)) + 80|0);
    $257 = HEAP32[$256>>2]|0;
    $258 = ((($255)) + 84|0);
    $259 = HEAP32[$258>>2]|0;
    $260 = ($257|0)==($259|0);
    if ($260) {
     $273 = ((($255)) + 76|0);
     __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($273,$2);
    } else {
     $261 = $2;
     $262 = $261;
     $263 = HEAP32[$262>>2]|0;
     $264 = (($261) + 4)|0;
     $265 = $264;
     $266 = HEAP32[$265>>2]|0;
     $267 = $257;
     $268 = $267;
     HEAP32[$268>>2] = $263;
     $269 = (($267) + 4)|0;
     $270 = $269;
     HEAP32[$270>>2] = $266;
     $271 = HEAP32[$256>>2]|0;
     $272 = ((($271)) + 8|0);
     HEAP32[$256>>2] = $272;
    }
    $274 = HEAP32[$238>>2]|0;
    $275 = ((($274)) + 80|0);
    $276 = HEAP32[$275>>2]|0;
    $277 = ((($274)) + 84|0);
    $278 = HEAP32[$277>>2]|0;
    $279 = ($276|0)==($278|0);
    if ($279) {
     $282 = ((($274)) + 76|0);
     __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($282,$17);
    } else {
     ;HEAP32[$276>>2]=HEAP32[$17>>2]|0;HEAP32[$276+4>>2]=HEAP32[$17+4>>2]|0;HEAP32[$276+8>>2]=HEAP32[$17+8>>2]|0;
     $280 = HEAP32[$275>>2]|0;
     $281 = ((($280)) + 12|0);
     HEAP32[$275>>2] = $281;
    }
    $283 = HEAP32[$16>>2]|0;
    $284 = HEAP32[$61>>2]|0;
    $285 = +HEAPF32[$62>>2];
    $286 = +HEAPF32[$69>>2];
    $287 = $285 - $286;
    $288 = HEAP32[$73>>2]|0;
    HEAP32[$3>>2] = $283;
    HEAP32[$239>>2] = $284;
    HEAPF32[$240>>2] = $287;
    $289 = ((($288)) + 80|0);
    $290 = HEAP32[$289>>2]|0;
    $291 = ((($288)) + 84|0);
    $292 = HEAP32[$291>>2]|0;
    $293 = ($290|0)==($292|0);
    if ($293) {
     $296 = ((($288)) + 76|0);
     __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($296,$3);
    } else {
     ;HEAP32[$290>>2]=HEAP32[$3>>2]|0;HEAP32[$290+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$290+8>>2]=HEAP32[$3+8>>2]|0;
     $294 = HEAP32[$289>>2]|0;
     $295 = ((($294)) + 12|0);
     HEAP32[$289>>2] = $295;
    }
    $297 = HEAP32[$236>>2]|0;
    HEAPF32[$4>>2] = $$1137206;
    HEAPF32[$241>>2] = 1.0;
    $298 = ((($297)) + 80|0);
    $299 = HEAP32[$298>>2]|0;
    $300 = ((($297)) + 84|0);
    $301 = HEAP32[$300>>2]|0;
    $302 = ($299|0)==($301|0);
    if ($302) {
     $315 = ((($297)) + 76|0);
     __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($315,$4);
    } else {
     $303 = $4;
     $304 = $303;
     $305 = HEAP32[$304>>2]|0;
     $306 = (($303) + 4)|0;
     $307 = $306;
     $308 = HEAP32[$307>>2]|0;
     $309 = $299;
     $310 = $309;
     HEAP32[$310>>2] = $305;
     $311 = (($309) + 4)|0;
     $312 = $311;
     HEAP32[$312>>2] = $308;
     $313 = HEAP32[$298>>2]|0;
     $314 = ((($313)) + 8|0);
     HEAP32[$298>>2] = $314;
    }
    $316 = HEAP32[$238>>2]|0;
    $317 = ((($316)) + 80|0);
    $318 = HEAP32[$317>>2]|0;
    $319 = ((($316)) + 84|0);
    $320 = HEAP32[$319>>2]|0;
    $321 = ($318|0)==($320|0);
    if ($321) {
     $324 = ((($316)) + 76|0);
     __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($324,$17);
    } else {
     ;HEAP32[$318>>2]=HEAP32[$17>>2]|0;HEAP32[$318+4>>2]=HEAP32[$17+4>>2]|0;HEAP32[$318+8>>2]=HEAP32[$17+8>>2]|0;
     $322 = HEAP32[$317>>2]|0;
     $323 = ((($322)) + 12|0);
     HEAP32[$317>>2] = $323;
    }
    $325 = HEAP32[$73>>2]|0;
    $326 = ((($325)) + 80|0);
    $327 = HEAP32[$326>>2]|0;
    $328 = ((($325)) + 84|0);
    $329 = HEAP32[$328>>2]|0;
    $330 = ($327|0)==($329|0);
    if ($330) {
     $333 = ((($325)) + 76|0);
     __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($333,$16);
    } else {
     ;HEAP32[$327>>2]=HEAP32[$16>>2]|0;HEAP32[$327+4>>2]=HEAP32[$16+4>>2]|0;HEAP32[$327+8>>2]=HEAP32[$16+8>>2]|0;
     $331 = HEAP32[$326>>2]|0;
     $332 = ((($331)) + 12|0);
     HEAP32[$326>>2] = $332;
    }
    $334 = (($$1135207) + 1)|0;
    $335 = $56 + $$1137206;
    $336 = HEAP32[$23>>2]|0;
    $337 = ($334>>>0)<($336>>>0);
    if ($337) {
     $$1135207 = $334;$$1137206 = $335;$246 = $336;
    } else {
     break;
    }
   }
  }
  __ZN3osg25BuildShapeGeometryVisitor3EndEv($0);
  $$pre = HEAP32[$26>>2]|0;
  $338 = $$pre;
 } else {
  $338 = $57;
 }
 $339 = ($338|0)==(1);
 if (!($339)) {
  $340 = ((($0)) + 24|0);
  $341 = ((($0)) + 12|0);
  $342 = ((($0)) + 28|0);
  $343 = ((($1)) + 104|0);
  $344 = ((($0)) + 20|0);
  $345 = ((($6)) + 4|0);
  $346 = ((($0)) + 16|0);
  $347 = ((($8)) + 4|0);
  $348 = ((($11)) + 4|0);
  $349 = ((($12)) + 4|0);
  $350 = ((($21)) + 4|0);
  $351 = ((($21)) + 8|0);
  $352 = ((($22)) + 4|0);
  $353 = ((($22)) + 8|0);
  $354 = ((($9)) + 4|0);
  $355 = ((($10)) + 4|0);
  $$0131203 = 0;$$0138200 = 0.0;$385 = $338;
  while(1) {
   $356 = $60 + $$0138200;
   HEAP32[$340>>2] = 8;
   $357 = HEAP32[$341>>2]|0;
   $358 = ((($357)) + 76|0);
   $359 = ((($357)) + 80|0);
   $360 = HEAP32[$359>>2]|0;
   $361 = HEAP32[$358>>2]|0;
   $362 = (($360) - ($361))|0;
   $363 = (($362|0) / 12)&-1;
   HEAP32[$342>>2] = $363;
   $364 = +HEAPF32[$69>>2];
   $365 = $364 != 0.0;
   do {
    if ($365) {
     $366 = (($$0131203) + 1)|0;
     $367 = (+($366>>>0));
     $368 = $52 * $367;
     $369 = HEAP32[$343>>2]|0;
     $370 = HEAP32[$23>>2]|0;
     $371 = Math_imul($370, $366)|0;
     $372 = ((($369)) + 76|0);
     $373 = HEAP32[$372>>2]|0;
     $374 = (($373) + ($371<<2)|0);
     $375 = +HEAPF32[$374>>2];
     $376 = $375 - $364;
     HEAPF32[$16>>2] = 0.0;
     HEAPF32[$61>>2] = $368;
     HEAPF32[$62>>2] = $376;
     $377 = (($371) + 1)|0;
     $378 = (($373) + ($377<<2)|0);
     $379 = +HEAPF32[$378>>2];
     $380 = +HEAPF32[$374>>2];
     $381 = $379 - $380;
     $382 = +HEAPF32[$49>>2];
     $383 = $381 / $382;
     $384 = (($385) + -1)|0;
     $386 = ($384|0)==($366|0);
     if ($386) {
      $387 = Math_imul($370, $$0131203)|0;
      $388 = (($373) + ($387<<2)|0);
      $389 = +HEAPF32[$388>>2];
      $390 = $380 - $389;
      $$pre$phi216Z2D = $388;$$pre$phiZ2D = $387;$$sink31$i173 = $390;
     } else {
      $391 = (($$0131203) + 2)|0;
      $392 = Math_imul($370, $391)|0;
      $393 = (($373) + ($392<<2)|0);
      $394 = +HEAPF32[$393>>2];
      $395 = Math_imul($370, $$0131203)|0;
      $396 = (($373) + ($395<<2)|0);
      $397 = +HEAPF32[$396>>2];
      $398 = $394 - $397;
      $399 = $398 * 0.5;
      $$pre$phi216Z2D = $396;$$pre$phiZ2D = $395;$$sink31$i173 = $399;
     }
     $400 = +HEAPF32[$51>>2];
     $401 = $$sink31$i173 / $400;
     $402 = -$383;
     $403 = -$401;
     $404 = $383 * $383;
     $405 = $401 * $401;
     $406 = $404 + $405;
     $407 = $406 + 1.0;
     $408 = (+Math_sqrt((+$407)));
     $409 = $408 > 0.0;
     $410 = 1.0 / $408;
     $411 = $410 * $403;
     $412 = $410 * $402;
     $413 = (HEAPF32[tempDoublePtr>>2]=$410,HEAP32[tempDoublePtr>>2]|0);
     $$sroa$8189$0 = $409 ? $413 : 1065353216;
     $$sroa$5187$0$v = $409 ? $411 : $403;
     $$sroa$0185$0$v = $409 ? $412 : $402;
     HEAPF32[$17>>2] = $$sroa$0185$0$v;
     HEAPF32[$63>>2] = $$sroa$5187$0$v;
     HEAP32[$64>>2] = $$sroa$8189$0;
     $414 = (+($$0131203>>>0));
     $415 = $52 * $414;
     $416 = +HEAPF32[$$pre$phi216Z2D>>2];
     $417 = $416 - $364;
     HEAPF32[$18>>2] = 0.0;
     HEAPF32[$65>>2] = $415;
     HEAPF32[$66>>2] = $417;
     $418 = (($$pre$phiZ2D) + 1)|0;
     $419 = (($373) + ($418<<2)|0);
     $420 = +HEAPF32[$419>>2];
     $421 = +HEAPF32[$$pre$phi216Z2D>>2];
     $422 = $420 - $421;
     $423 = $422 / $382;
     $424 = ($$0131203|0)==(0);
     do {
      if ($424) {
       $425 = (($373) + ($370<<2)|0);
       $426 = +HEAPF32[$425>>2];
       $427 = +HEAPF32[$373>>2];
       $428 = $426 - $427;
       $$sink31$i = $428;
      } else {
       $429 = HEAP32[$26>>2]|0;
       $430 = (($429) + -1)|0;
       $431 = ($430|0)==($$0131203|0);
       if ($431) {
        $432 = (($$0131203) + -1)|0;
        $433 = Math_imul($370, $432)|0;
        $434 = (($373) + ($433<<2)|0);
        $435 = +HEAPF32[$434>>2];
        $436 = $421 - $435;
        $$sink31$i = $436;
        break;
       } else {
        $437 = +HEAPF32[$374>>2];
        $438 = (($$0131203) + -1)|0;
        $439 = Math_imul($370, $438)|0;
        $440 = (($373) + ($439<<2)|0);
        $441 = +HEAPF32[$440>>2];
        $442 = $437 - $441;
        $443 = $442 * 0.5;
        $$sink31$i = $443;
        break;
       }
      }
     } while(0);
     $444 = $$sink31$i / $400;
     $445 = -$423;
     $446 = -$444;
     $447 = $423 * $423;
     $448 = $444 * $444;
     $449 = $447 + $448;
     $450 = $449 + 1.0;
     $451 = (+Math_sqrt((+$450)));
     $452 = $451 > 0.0;
     $453 = 1.0 / $451;
     $454 = $453 * $446;
     $455 = $453 * $445;
     $456 = (HEAPF32[tempDoublePtr>>2]=$453,HEAP32[tempDoublePtr>>2]|0);
     $$sroa$8$0 = $452 ? $456 : 1065353216;
     $$sroa$5$0$v = $452 ? $454 : $446;
     $$sroa$0$0$v = $452 ? $455 : $445;
     HEAPF32[$19>>2] = $$sroa$0$0$v;
     HEAPF32[$67>>2] = $$sroa$5$0$v;
     HEAP32[$68>>2] = $$sroa$8$0;
     $457 = HEAP32[$344>>2]|0;
     HEAPF32[$6>>2] = 0.0;
     HEAPF32[$345>>2] = $356;
     $458 = ((($457)) + 80|0);
     $459 = HEAP32[$458>>2]|0;
     $460 = ((($457)) + 84|0);
     $461 = HEAP32[$460>>2]|0;
     $462 = ($459|0)==($461|0);
     if ($462) {
      $475 = ((($457)) + 76|0);
      __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($475,$6);
     } else {
      $463 = $6;
      $464 = $463;
      $465 = HEAP32[$464>>2]|0;
      $466 = (($463) + 4)|0;
      $467 = $466;
      $468 = HEAP32[$467>>2]|0;
      $469 = $459;
      $470 = $469;
      HEAP32[$470>>2] = $465;
      $471 = (($469) + 4)|0;
      $472 = $471;
      HEAP32[$472>>2] = $468;
      $473 = HEAP32[$458>>2]|0;
      $474 = ((($473)) + 8|0);
      HEAP32[$458>>2] = $474;
     }
     $476 = HEAP32[$346>>2]|0;
     $477 = ((($476)) + 80|0);
     $478 = HEAP32[$477>>2]|0;
     $479 = ((($476)) + 84|0);
     $480 = HEAP32[$479>>2]|0;
     $481 = ($478|0)==($480|0);
     if ($481) {
      $484 = ((($476)) + 76|0);
      __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($484,$17);
     } else {
      ;HEAP32[$478>>2]=HEAP32[$17>>2]|0;HEAP32[$478+4>>2]=HEAP32[$17+4>>2]|0;HEAP32[$478+8>>2]=HEAP32[$17+8>>2]|0;
      $482 = HEAP32[$477>>2]|0;
      $483 = ((($482)) + 12|0);
      HEAP32[$477>>2] = $483;
     }
     $485 = HEAP32[$341>>2]|0;
     $486 = ((($485)) + 80|0);
     $487 = HEAP32[$486>>2]|0;
     $488 = ((($485)) + 84|0);
     $489 = HEAP32[$488>>2]|0;
     $490 = ($487|0)==($489|0);
     if ($490) {
      $493 = ((($485)) + 76|0);
      __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($493,$16);
     } else {
      ;HEAP32[$487>>2]=HEAP32[$16>>2]|0;HEAP32[$487+4>>2]=HEAP32[$16+4>>2]|0;HEAP32[$487+8>>2]=HEAP32[$16+8>>2]|0;
      $491 = HEAP32[$486>>2]|0;
      $492 = ((($491)) + 12|0);
      HEAP32[$486>>2] = $492;
     }
     $494 = HEAP32[$344>>2]|0;
     HEAPF32[$8>>2] = 0.0;
     HEAPF32[$347>>2] = $$0138200;
     $495 = ((($494)) + 80|0);
     $496 = HEAP32[$495>>2]|0;
     $497 = ((($494)) + 84|0);
     $498 = HEAP32[$497>>2]|0;
     $499 = ($496|0)==($498|0);
     if ($499) {
      $512 = ((($494)) + 76|0);
      __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($512,$8);
     } else {
      $500 = $8;
      $501 = $500;
      $502 = HEAP32[$501>>2]|0;
      $503 = (($500) + 4)|0;
      $504 = $503;
      $505 = HEAP32[$504>>2]|0;
      $506 = $496;
      $507 = $506;
      HEAP32[$507>>2] = $502;
      $508 = (($506) + 4)|0;
      $509 = $508;
      HEAP32[$509>>2] = $505;
      $510 = HEAP32[$495>>2]|0;
      $511 = ((($510)) + 8|0);
      HEAP32[$495>>2] = $511;
     }
     $513 = HEAP32[$346>>2]|0;
     $514 = ((($513)) + 80|0);
     $515 = HEAP32[$514>>2]|0;
     $516 = ((($513)) + 84|0);
     $517 = HEAP32[$516>>2]|0;
     $518 = ($515|0)==($517|0);
     if ($518) {
      $521 = ((($513)) + 76|0);
      __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($521,$19);
     } else {
      ;HEAP32[$515>>2]=HEAP32[$19>>2]|0;HEAP32[$515+4>>2]=HEAP32[$19+4>>2]|0;HEAP32[$515+8>>2]=HEAP32[$19+8>>2]|0;
      $519 = HEAP32[$514>>2]|0;
      $520 = ((($519)) + 12|0);
      HEAP32[$514>>2] = $520;
     }
     $522 = HEAP32[$341>>2]|0;
     $523 = ((($522)) + 80|0);
     $524 = HEAP32[$523>>2]|0;
     $525 = ((($522)) + 84|0);
     $526 = HEAP32[$525>>2]|0;
     $527 = ($524|0)==($526|0);
     if ($527) {
      $530 = ((($522)) + 76|0);
      __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($530,$18);
      break;
     } else {
      ;HEAP32[$524>>2]=HEAP32[$18>>2]|0;HEAP32[$524+4>>2]=HEAP32[$18+4>>2]|0;HEAP32[$524+8>>2]=HEAP32[$18+8>>2]|0;
      $528 = HEAP32[$523>>2]|0;
      $529 = ((($528)) + 12|0);
      HEAP32[$523>>2] = $529;
      break;
     }
    }
   } while(0);
   $531 = HEAP32[$23>>2]|0;
   $532 = ($531|0)==(0);
   if ($532) {
    $$0129$lcssa = 0.0;
   } else {
    $533 = (($$0131203) + 1)|0;
    $534 = (+($533>>>0));
    $535 = $52 * $534;
    $536 = (+($$0131203>>>0));
    $537 = $52 * $536;
    $$0129198 = 0.0;$$0199 = 0;$544 = $531;
    while(1) {
     $540 = (+($$0199>>>0));
     $541 = $50 * $540;
     $542 = HEAP32[$343>>2]|0;
     $543 = Math_imul($544, $533)|0;
     $545 = (($543) + ($$0199))|0;
     $546 = ((($542)) + 76|0);
     $547 = HEAP32[$546>>2]|0;
     $548 = (($547) + ($545<<2)|0);
     $549 = HEAP32[$548>>2]|0;
     HEAPF32[$16>>2] = $541;
     HEAPF32[$61>>2] = $535;
     HEAP32[$62>>2] = $549;
     __ZNK3osg11HeightField9getNormalEjj($21,$1,$$0199,$533);
     $550 = HEAP32[$21>>2]|0;
     HEAP32[$17>>2] = $550;
     $551 = HEAP32[$350>>2]|0;
     HEAP32[$63>>2] = $551;
     $552 = HEAP32[$351>>2]|0;
     HEAP32[$64>>2] = $552;
     $553 = HEAP32[$343>>2]|0;
     $554 = HEAP32[$23>>2]|0;
     $555 = Math_imul($554, $$0131203)|0;
     $556 = (($555) + ($$0199))|0;
     $557 = ((($553)) + 76|0);
     $558 = HEAP32[$557>>2]|0;
     $559 = (($558) + ($556<<2)|0);
     $560 = HEAP32[$559>>2]|0;
     HEAPF32[$18>>2] = $541;
     HEAPF32[$65>>2] = $537;
     HEAP32[$66>>2] = $560;
     __ZNK3osg11HeightField9getNormalEjj($22,$1,$$0199,$$0131203);
     $561 = HEAP32[$22>>2]|0;
     HEAP32[$19>>2] = $561;
     $562 = HEAP32[$352>>2]|0;
     HEAP32[$67>>2] = $562;
     $563 = HEAP32[$353>>2]|0;
     HEAP32[$68>>2] = $563;
     $564 = HEAP32[$344>>2]|0;
     HEAPF32[$9>>2] = $$0129198;
     HEAPF32[$354>>2] = $356;
     $565 = ((($564)) + 80|0);
     $566 = HEAP32[$565>>2]|0;
     $567 = ((($564)) + 84|0);
     $568 = HEAP32[$567>>2]|0;
     $569 = ($566|0)==($568|0);
     if ($569) {
      $582 = ((($564)) + 76|0);
      __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($582,$9);
     } else {
      $570 = $9;
      $571 = $570;
      $572 = HEAP32[$571>>2]|0;
      $573 = (($570) + 4)|0;
      $574 = $573;
      $575 = HEAP32[$574>>2]|0;
      $576 = $566;
      $577 = $576;
      HEAP32[$577>>2] = $572;
      $578 = (($576) + 4)|0;
      $579 = $578;
      HEAP32[$579>>2] = $575;
      $580 = HEAP32[$565>>2]|0;
      $581 = ((($580)) + 8|0);
      HEAP32[$565>>2] = $581;
     }
     $583 = HEAP32[$346>>2]|0;
     $584 = ((($583)) + 80|0);
     $585 = HEAP32[$584>>2]|0;
     $586 = ((($583)) + 84|0);
     $587 = HEAP32[$586>>2]|0;
     $588 = ($585|0)==($587|0);
     if ($588) {
      $591 = ((($583)) + 76|0);
      __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($591,$17);
     } else {
      ;HEAP32[$585>>2]=HEAP32[$17>>2]|0;HEAP32[$585+4>>2]=HEAP32[$17+4>>2]|0;HEAP32[$585+8>>2]=HEAP32[$17+8>>2]|0;
      $589 = HEAP32[$584>>2]|0;
      $590 = ((($589)) + 12|0);
      HEAP32[$584>>2] = $590;
     }
     $592 = HEAP32[$341>>2]|0;
     $593 = ((($592)) + 80|0);
     $594 = HEAP32[$593>>2]|0;
     $595 = ((($592)) + 84|0);
     $596 = HEAP32[$595>>2]|0;
     $597 = ($594|0)==($596|0);
     if ($597) {
      $600 = ((($592)) + 76|0);
      __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($600,$16);
     } else {
      ;HEAP32[$594>>2]=HEAP32[$16>>2]|0;HEAP32[$594+4>>2]=HEAP32[$16+4>>2]|0;HEAP32[$594+8>>2]=HEAP32[$16+8>>2]|0;
      $598 = HEAP32[$593>>2]|0;
      $599 = ((($598)) + 12|0);
      HEAP32[$593>>2] = $599;
     }
     $601 = HEAP32[$344>>2]|0;
     HEAPF32[$10>>2] = $$0129198;
     HEAPF32[$355>>2] = $$0138200;
     $602 = ((($601)) + 80|0);
     $603 = HEAP32[$602>>2]|0;
     $604 = ((($601)) + 84|0);
     $605 = HEAP32[$604>>2]|0;
     $606 = ($603|0)==($605|0);
     if ($606) {
      $619 = ((($601)) + 76|0);
      __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($619,$10);
     } else {
      $607 = $10;
      $608 = $607;
      $609 = HEAP32[$608>>2]|0;
      $610 = (($607) + 4)|0;
      $611 = $610;
      $612 = HEAP32[$611>>2]|0;
      $613 = $603;
      $614 = $613;
      HEAP32[$614>>2] = $609;
      $615 = (($613) + 4)|0;
      $616 = $615;
      HEAP32[$616>>2] = $612;
      $617 = HEAP32[$602>>2]|0;
      $618 = ((($617)) + 8|0);
      HEAP32[$602>>2] = $618;
     }
     $620 = HEAP32[$346>>2]|0;
     $621 = ((($620)) + 80|0);
     $622 = HEAP32[$621>>2]|0;
     $623 = ((($620)) + 84|0);
     $624 = HEAP32[$623>>2]|0;
     $625 = ($622|0)==($624|0);
     if ($625) {
      $628 = ((($620)) + 76|0);
      __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($628,$19);
     } else {
      ;HEAP32[$622>>2]=HEAP32[$19>>2]|0;HEAP32[$622+4>>2]=HEAP32[$19+4>>2]|0;HEAP32[$622+8>>2]=HEAP32[$19+8>>2]|0;
      $626 = HEAP32[$621>>2]|0;
      $627 = ((($626)) + 12|0);
      HEAP32[$621>>2] = $627;
     }
     $629 = HEAP32[$341>>2]|0;
     $630 = ((($629)) + 80|0);
     $631 = HEAP32[$630>>2]|0;
     $632 = ((($629)) + 84|0);
     $633 = HEAP32[$632>>2]|0;
     $634 = ($631|0)==($633|0);
     if ($634) {
      $637 = ((($629)) + 76|0);
      __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($637,$18);
     } else {
      ;HEAP32[$631>>2]=HEAP32[$18>>2]|0;HEAP32[$631+4>>2]=HEAP32[$18+4>>2]|0;HEAP32[$631+8>>2]=HEAP32[$18+8>>2]|0;
      $635 = HEAP32[$630>>2]|0;
      $636 = ((($635)) + 12|0);
      HEAP32[$630>>2] = $636;
     }
     $638 = (($$0199) + 1)|0;
     $639 = $56 + $$0129198;
     $640 = HEAP32[$23>>2]|0;
     $641 = ($638>>>0)<($640>>>0);
     if ($641) {
      $$0129198 = $639;$$0199 = $638;$544 = $640;
     } else {
      $$0129$lcssa = $639;
      break;
     }
    }
   }
   $538 = +HEAPF32[$69>>2];
   $539 = $538 != 0.0;
   do {
    if ($539) {
     $642 = +HEAPF32[$66>>2];
     $643 = $642 - $538;
     HEAPF32[$66>>2] = $643;
     $644 = +HEAPF32[$62>>2];
     $645 = $644 - $538;
     HEAPF32[$62>>2] = $645;
     $646 = HEAP32[$344>>2]|0;
     HEAPF32[$11>>2] = $$0129$lcssa;
     HEAPF32[$348>>2] = $356;
     $647 = ((($646)) + 80|0);
     $648 = HEAP32[$647>>2]|0;
     $649 = ((($646)) + 84|0);
     $650 = HEAP32[$649>>2]|0;
     $651 = ($648|0)==($650|0);
     if ($651) {
      $664 = ((($646)) + 76|0);
      __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($664,$11);
     } else {
      $652 = $11;
      $653 = $652;
      $654 = HEAP32[$653>>2]|0;
      $655 = (($652) + 4)|0;
      $656 = $655;
      $657 = HEAP32[$656>>2]|0;
      $658 = $648;
      $659 = $658;
      HEAP32[$659>>2] = $654;
      $660 = (($658) + 4)|0;
      $661 = $660;
      HEAP32[$661>>2] = $657;
      $662 = HEAP32[$647>>2]|0;
      $663 = ((($662)) + 8|0);
      HEAP32[$647>>2] = $663;
     }
     $665 = HEAP32[$346>>2]|0;
     $666 = ((($665)) + 80|0);
     $667 = HEAP32[$666>>2]|0;
     $668 = ((($665)) + 84|0);
     $669 = HEAP32[$668>>2]|0;
     $670 = ($667|0)==($669|0);
     if ($670) {
      $673 = ((($665)) + 76|0);
      __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($673,$17);
     } else {
      ;HEAP32[$667>>2]=HEAP32[$17>>2]|0;HEAP32[$667+4>>2]=HEAP32[$17+4>>2]|0;HEAP32[$667+8>>2]=HEAP32[$17+8>>2]|0;
      $671 = HEAP32[$666>>2]|0;
      $672 = ((($671)) + 12|0);
      HEAP32[$666>>2] = $672;
     }
     $674 = HEAP32[$341>>2]|0;
     $675 = ((($674)) + 80|0);
     $676 = HEAP32[$675>>2]|0;
     $677 = ((($674)) + 84|0);
     $678 = HEAP32[$677>>2]|0;
     $679 = ($676|0)==($678|0);
     if ($679) {
      $682 = ((($674)) + 76|0);
      __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($682,$16);
     } else {
      ;HEAP32[$676>>2]=HEAP32[$16>>2]|0;HEAP32[$676+4>>2]=HEAP32[$16+4>>2]|0;HEAP32[$676+8>>2]=HEAP32[$16+8>>2]|0;
      $680 = HEAP32[$675>>2]|0;
      $681 = ((($680)) + 12|0);
      HEAP32[$675>>2] = $681;
     }
     $683 = HEAP32[$344>>2]|0;
     HEAPF32[$12>>2] = $$0129$lcssa;
     HEAPF32[$349>>2] = $$0138200;
     $684 = ((($683)) + 80|0);
     $685 = HEAP32[$684>>2]|0;
     $686 = ((($683)) + 84|0);
     $687 = HEAP32[$686>>2]|0;
     $688 = ($685|0)==($687|0);
     if ($688) {
      $701 = ((($683)) + 76|0);
      __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($701,$12);
     } else {
      $689 = $12;
      $690 = $689;
      $691 = HEAP32[$690>>2]|0;
      $692 = (($689) + 4)|0;
      $693 = $692;
      $694 = HEAP32[$693>>2]|0;
      $695 = $685;
      $696 = $695;
      HEAP32[$696>>2] = $691;
      $697 = (($695) + 4)|0;
      $698 = $697;
      HEAP32[$698>>2] = $694;
      $699 = HEAP32[$684>>2]|0;
      $700 = ((($699)) + 8|0);
      HEAP32[$684>>2] = $700;
     }
     $702 = HEAP32[$346>>2]|0;
     $703 = ((($702)) + 80|0);
     $704 = HEAP32[$703>>2]|0;
     $705 = ((($702)) + 84|0);
     $706 = HEAP32[$705>>2]|0;
     $707 = ($704|0)==($706|0);
     if ($707) {
      $710 = ((($702)) + 76|0);
      __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($710,$19);
     } else {
      ;HEAP32[$704>>2]=HEAP32[$19>>2]|0;HEAP32[$704+4>>2]=HEAP32[$19+4>>2]|0;HEAP32[$704+8>>2]=HEAP32[$19+8>>2]|0;
      $708 = HEAP32[$703>>2]|0;
      $709 = ((($708)) + 12|0);
      HEAP32[$703>>2] = $709;
     }
     $711 = HEAP32[$341>>2]|0;
     $712 = ((($711)) + 80|0);
     $713 = HEAP32[$712>>2]|0;
     $714 = ((($711)) + 84|0);
     $715 = HEAP32[$714>>2]|0;
     $716 = ($713|0)==($715|0);
     if ($716) {
      $719 = ((($711)) + 76|0);
      __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($719,$18);
      break;
     } else {
      ;HEAP32[$713>>2]=HEAP32[$18>>2]|0;HEAP32[$713+4>>2]=HEAP32[$18+4>>2]|0;HEAP32[$713+8>>2]=HEAP32[$18+8>>2]|0;
      $717 = HEAP32[$712>>2]|0;
      $718 = ((($717)) + 12|0);
      HEAP32[$712>>2] = $718;
      break;
     }
    }
   } while(0);
   __ZN3osg25BuildShapeGeometryVisitor3EndEv($0);
   $720 = (($$0131203) + 1)|0;
   $721 = HEAP32[$26>>2]|0;
   $722 = (($721) + -1)|0;
   $723 = ($720>>>0)<($722>>>0);
   if ($723) {
    $$0131203 = $720;$$0138200 = $356;$385 = $721;
   } else {
    break;
   }
  }
 }
 STACKTOP = sp;return;
}
function __ZN3osg25BuildShapeGeometryVisitor5applyERKNS_14CompositeShapeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$06 = 0, $$in = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 36|0);
 $3 = ((($1)) + 40|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$2>>2]|0;
 $6 = ($4|0)==($5|0);
 if ($6) {
  return;
 }
 $$06 = 0;$$in = $5;
 while(1) {
  $7 = $$in;
  $8 = (($7) + ($$06<<2)|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = HEAP32[$9>>2]|0;
  $11 = ((($10)) + 144|0);
  $12 = HEAP32[$11>>2]|0;
  FUNCTION_TABLE_vii[$12 & 8191]($9,$0);
  $13 = (($$06) + 1)|0;
  $14 = HEAP32[$3>>2]|0;
  $15 = HEAP32[$2>>2]|0;
  $16 = (($14) - ($15))|0;
  $17 = $16 >> 2;
  $18 = ($13>>>0)<($17>>>0);
  if ($18) {
   $$06 = $13;$$in = $15;
  } else {
   break;
  }
 }
 return;
}
function __ZN3osg25BuildShapeGeometryVisitor9setMatrixERKNS_7MatrixdE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$pre = 0, $$pre$phiZ2D = 0, $10 = 0, $11 = 0, $12 = 0.0, $13 = 0, $14 = 0, $15 = 0.0, $16 = 0, $17 = 0, $18 = 0.0, $19 = 0, $2 = 0, $20 = 0, $21 = 0.0, $22 = 0, $23 = 0, $24 = 0.0, $25 = 0, $26 = 0;
 var $27 = 0.0, $28 = 0, $29 = 0, $3 = 0, $30 = 0.0, $31 = 0, $32 = 0, $33 = 0.0, $34 = 0, $35 = 0, $36 = 0.0, $37 = 0, $38 = 0, $39 = 0.0, $4 = 0.0, $40 = 0, $41 = 0, $42 = 0.0, $43 = 0, $44 = 0;
 var $45 = 0.0, $46 = 0, $47 = 0, $48 = 0.0, $49 = 0, $5 = 0, $50 = 0, $51 = 0.0, $52 = 0, $53 = 0, $54 = 0.0, $55 = 0, $56 = 0, $57 = 0.0, $58 = 0, $59 = 0, $6 = 0.0, $60 = 0.0, $61 = 0, $7 = 0;
 var $8 = 0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 32|0);
 $3 = ($2|0)==($1|0);
 if ($3) {
  $$pre = ((($1)) + 24|0);
  $$pre$phiZ2D = $$pre;
 } else {
  $4 = +HEAPF64[$1>>3];
  HEAPF64[$2>>3] = $4;
  $5 = ((($1)) + 8|0);
  $6 = +HEAPF64[$5>>3];
  $7 = ((($0)) + 40|0);
  HEAPF64[$7>>3] = $6;
  $8 = ((($1)) + 16|0);
  $9 = +HEAPF64[$8>>3];
  $10 = ((($0)) + 48|0);
  HEAPF64[$10>>3] = $9;
  $11 = ((($1)) + 24|0);
  $12 = +HEAPF64[$11>>3];
  $13 = ((($0)) + 56|0);
  HEAPF64[$13>>3] = $12;
  $14 = ((($1)) + 32|0);
  $15 = +HEAPF64[$14>>3];
  $16 = ((($0)) + 64|0);
  HEAPF64[$16>>3] = $15;
  $17 = ((($1)) + 40|0);
  $18 = +HEAPF64[$17>>3];
  $19 = ((($0)) + 72|0);
  HEAPF64[$19>>3] = $18;
  $20 = ((($1)) + 48|0);
  $21 = +HEAPF64[$20>>3];
  $22 = ((($0)) + 80|0);
  HEAPF64[$22>>3] = $21;
  $23 = ((($1)) + 56|0);
  $24 = +HEAPF64[$23>>3];
  $25 = ((($0)) + 88|0);
  HEAPF64[$25>>3] = $24;
  $26 = ((($1)) + 64|0);
  $27 = +HEAPF64[$26>>3];
  $28 = ((($0)) + 96|0);
  HEAPF64[$28>>3] = $27;
  $29 = ((($1)) + 72|0);
  $30 = +HEAPF64[$29>>3];
  $31 = ((($0)) + 104|0);
  HEAPF64[$31>>3] = $30;
  $32 = ((($1)) + 80|0);
  $33 = +HEAPF64[$32>>3];
  $34 = ((($0)) + 112|0);
  HEAPF64[$34>>3] = $33;
  $35 = ((($1)) + 88|0);
  $36 = +HEAPF64[$35>>3];
  $37 = ((($0)) + 120|0);
  HEAPF64[$37>>3] = $36;
  $38 = ((($1)) + 96|0);
  $39 = +HEAPF64[$38>>3];
  $40 = ((($0)) + 128|0);
  HEAPF64[$40>>3] = $39;
  $41 = ((($1)) + 104|0);
  $42 = +HEAPF64[$41>>3];
  $43 = ((($0)) + 136|0);
  HEAPF64[$43>>3] = $42;
  $44 = ((($1)) + 112|0);
  $45 = +HEAPF64[$44>>3];
  $46 = ((($0)) + 144|0);
  HEAPF64[$46>>3] = $45;
  $47 = ((($1)) + 120|0);
  $48 = +HEAPF64[$47>>3];
  $49 = ((($0)) + 152|0);
  HEAPF64[$49>>3] = $48;
  $$pre$phiZ2D = $11;
 }
 $50 = ((($0)) + 160|0);
 $51 = +HEAPF64[$$pre$phiZ2D>>3];
 $52 = $51 == 0.0;
 if ($52) {
  $53 = ((($1)) + 56|0);
  $54 = +HEAPF64[$53>>3];
  $55 = $54 == 0.0;
  if ($55) {
   $56 = ((($1)) + 88|0);
   $57 = +HEAPF64[$56>>3];
   $58 = $57 == 0.0;
   if ($58) {
    $59 = ((($1)) + 120|0);
    $60 = +HEAPF64[$59>>3];
    $61 = $60 == 1.0;
    if ($61) {
     (__ZN3osg7Matrixd10invert_4x3ERKS0_($50,$1)|0);
     __ZN3osg7Matrixd8setTransEddd($50,0.0,0.0,0.0);
     return;
    }
   }
  }
 }
 (__ZN3osg7Matrixd10invert_4x4ERKS0_($50,$1)|0);
 __ZN3osg7Matrixd8setTransEddd($50,0.0,0.0,0.0);
 return;
}
function __ZN3osg25BuildShapeGeometryVisitor3EndEv($0) {
 $0 = $0|0;
 var $$080133 = 0, $$084134 = 0, $$085 = 0, $$2 = 0, $$283 = 0, $$lcssa = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0;
 var $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0;
 var $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0.0, $226 = 0, $227 = 0.0, $228 = 0, $229 = 0.0, $23 = 0, $230 = 0, $231 = 0.0, $232 = 0, $233 = 0.0, $234 = 0, $235 = 0.0, $236 = 0, $237 = 0.0;
 var $238 = 0, $239 = 0.0, $24 = 0, $240 = 0, $241 = 0.0, $242 = 0, $243 = 0.0, $244 = 0, $245 = 0.0, $246 = 0, $247 = 0.0, $248 = 0, $249 = 0.0, $25 = 0, $250 = 0, $251 = 0.0, $252 = 0, $253 = 0.0, $254 = 0, $255 = 0.0;
 var $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0;
 var $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0;
 var $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0;
 var $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0;
 var $328 = 0, $329 = 0.0, $33 = 0, $330 = 0.0, $331 = 0.0, $332 = 0, $333 = 0.0, $334 = 0.0, $335 = 0.0, $336 = 0.0, $337 = 0, $338 = 0.0, $339 = 0.0, $34 = 0, $340 = 0.0, $341 = 0.0, $342 = 0.0, $343 = 0.0, $344 = 0.0, $345 = 0.0;
 var $346 = 0.0, $347 = 0.0, $348 = 0.0, $349 = 0.0, $35 = 0, $350 = 0.0, $351 = 0.0, $352 = 0.0, $353 = 0.0, $354 = 0.0, $355 = 0.0, $356 = 0.0, $357 = 0.0, $358 = 0.0, $359 = 0.0, $36 = 0, $360 = 0.0, $361 = 0.0, $362 = 0.0, $363 = 0.0;
 var $364 = 0.0, $365 = 0.0, $366 = 0.0, $367 = 0.0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0.0, $372 = 0, $373 = 0.0, $374 = 0.0, $375 = 0.0, $376 = 0.0, $377 = 0, $378 = 0.0, $379 = 0.0, $38 = 0, $380 = 0.0, $381 = 0.0;
 var $382 = 0.0, $383 = 0, $384 = 0.0, $385 = 0.0, $386 = 0.0, $387 = 0.0, $388 = 0.0, $389 = 0.0, $39 = 0, $390 = 0.0, $391 = 0.0, $392 = 0.0, $393 = 0.0, $394 = 0.0, $395 = 0.0, $396 = 0.0, $397 = 0.0, $398 = 0.0, $399 = 0.0, $4 = 0;
 var $40 = 0, $400 = 0.0, $401 = 0.0, $402 = 0.0, $403 = 0.0, $404 = 0.0, $405 = 0.0, $406 = 0.0, $407 = 0.0, $408 = 0.0, $409 = 0.0, $41 = 0, $410 = 0.0, $411 = 0.0, $412 = 0.0, $413 = 0.0, $414 = 0.0, $415 = 0.0, $416 = 0.0, $417 = 0.0;
 var $418 = 0.0, $419 = 0.0, $42 = 0, $420 = 0.0, $421 = 0.0, $422 = 0.0, $423 = 0.0, $424 = 0.0, $425 = 0.0, $426 = 0.0, $427 = 0.0, $428 = 0.0, $429 = 0.0, $43 = 0, $430 = 0.0, $431 = 0.0, $432 = 0.0, $433 = 0, $434 = 0.0, $435 = 0.0;
 var $436 = 0.0, $437 = 0.0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($4)) + 76|0);
 $6 = ((($4)) + 80|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$5>>2]|0;
 $9 = (($7) - ($8))|0;
 $10 = (($9|0) / 12)&-1;
 $11 = ($2>>>0)<($10>>>0);
 if (!($11)) {
  return;
 }
 $12 = ($10>>>0)<(65536);
 $13 = ((($0)) + 24|0);
 $14 = HEAP32[$13>>2]|0;
 L4: do {
  switch ($14|0) {
  case 7:  {
   $15 = (__Znwj(80)|0);
   do {
    if ($12) {
     __THREW__ = 0;
     invoke_vii(3435,($15|0),1);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if (!($17)) {
      $18 = ((($15)) + 12|0);
      ;HEAP32[$18>>2]=0|0;HEAP32[$18+4>>2]=0|0;HEAP32[$18+8>>2]=0|0;
      $19 = ((($15)) + 24|0);
      HEAP32[$19>>2] = 2;
      $20 = ((($15)) + 28|0);
      ;HEAP32[$20>>2]=0|0;HEAP32[$20+4>>2]=0|0;HEAP32[$20+8>>2]=0|0;HEAP32[$20+12>>2]=0|0;HEAP32[$20+16>>2]=0|0;HEAP32[$20+20>>2]=0|0;
      $21 = ((($15)) + 52|0);
      HEAP32[$21>>2] = 4;
      $22 = ((($15)) + 56|0);
      HEAP32[$22>>2] = 0;
      $23 = ((($15)) + 60|0);
      HEAP32[$23>>2] = 4;
      $24 = ((($15)) + 64|0);
      $25 = ((($15)) + 68|0);
      HEAP32[$25>>2] = 0;
      $26 = ((($15)) + 72|0);
      HEAP32[$26>>2] = 0;
      $27 = ((($15)) + 76|0);
      HEAP32[$27>>2] = 0;
      HEAP32[$15>>2] = (64316);
      HEAP32[$24>>2] = (64564);
      break;
     }
     $57 = ___cxa_find_matching_catch_2()|0;
     $58 = tempRet0;
     __ZdlPv($15);
     $$2 = $57;$$283 = $58;
     ___resumeException($$2|0);
     // unreachable;
    } else {
     __THREW__ = 0;
     invoke_vii(3435,($15|0),1);
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if (!($29)) {
      $30 = ((($15)) + 12|0);
      ;HEAP32[$30>>2]=0|0;HEAP32[$30+4>>2]=0|0;HEAP32[$30+8>>2]=0|0;
      $31 = ((($15)) + 24|0);
      HEAP32[$31>>2] = 2;
      $32 = ((($15)) + 28|0);
      ;HEAP32[$32>>2]=0|0;HEAP32[$32+4>>2]=0|0;HEAP32[$32+8>>2]=0|0;HEAP32[$32+12>>2]=0|0;HEAP32[$32+16>>2]=0|0;HEAP32[$32+20>>2]=0|0;
      $33 = ((($15)) + 52|0);
      HEAP32[$33>>2] = 5;
      $34 = ((($15)) + 56|0);
      HEAP32[$34>>2] = 0;
      $35 = ((($15)) + 60|0);
      HEAP32[$35>>2] = 4;
      $36 = ((($15)) + 64|0);
      $37 = ((($15)) + 68|0);
      HEAP32[$37>>2] = 0;
      $38 = ((($15)) + 72|0);
      HEAP32[$38>>2] = 0;
      $39 = ((($15)) + 76|0);
      HEAP32[$39>>2] = 0;
      HEAP32[$15>>2] = (64580);
      HEAP32[$36>>2] = (64828);
      break;
     }
     $59 = ___cxa_find_matching_catch_2()|0;
     $60 = tempRet0;
     __ZdlPv($15);
     $$2 = $59;$$283 = $60;
     ___resumeException($$2|0);
     // unreachable;
    }
   } while(0);
   $40 = ((($15)) + 8|0);
   $41 = HEAP32[$40>>2]|0;HEAP32[$40>>2] = (($41+1)|0);
   $42 = ((($0)) + 4|0);
   $43 = HEAP32[$42>>2]|0;
   __THREW__ = 0;
   (invoke_iii(3494,($43|0),($15|0))|0);
   $44 = __THREW__; __THREW__ = 0;
   $45 = $44&1;
   L23: do {
    if (!($45)) {
     $46 = HEAP32[$1>>2]|0;
     $47 = HEAP32[$3>>2]|0;
     $48 = ((($47)) + 76|0);
     $49 = ((($47)) + 80|0);
     $50 = HEAP32[$49>>2]|0;
     $51 = HEAP32[$48>>2]|0;
     $52 = (($50) - ($51))|0;
     $53 = (($52|0) / 12)&-1;
     $54 = ($46>>>0)<($53>>>0);
     if ($54) {
      $$084134 = $46;
      while(1) {
       $61 = (($$084134) + 1)|0;
       $62 = (($$084134) + 2)|0;
       $63 = (($$084134) + 3)|0;
       $64 = HEAP32[$15>>2]|0;
       $65 = ((($64)) + 236|0);
       $66 = HEAP32[$65>>2]|0;
       __THREW__ = 0;
       invoke_vii($66|0,($15|0),($$084134|0));
       $67 = __THREW__; __THREW__ = 0;
       $68 = $67&1;
       if ($68) {
        break L23;
       }
       $69 = HEAP32[$15>>2]|0;
       $70 = ((($69)) + 236|0);
       $71 = HEAP32[$70>>2]|0;
       __THREW__ = 0;
       invoke_vii($71|0,($15|0),($61|0));
       $72 = __THREW__; __THREW__ = 0;
       $73 = $72&1;
       if ($73) {
        break L23;
       }
       $74 = HEAP32[$15>>2]|0;
       $75 = ((($74)) + 236|0);
       $76 = HEAP32[$75>>2]|0;
       __THREW__ = 0;
       invoke_vii($76|0,($15|0),($63|0));
       $77 = __THREW__; __THREW__ = 0;
       $78 = $77&1;
       if ($78) {
        break L23;
       }
       $79 = HEAP32[$15>>2]|0;
       $80 = ((($79)) + 236|0);
       $81 = HEAP32[$80>>2]|0;
       __THREW__ = 0;
       invoke_vii($81|0,($15|0),($61|0));
       $82 = __THREW__; __THREW__ = 0;
       $83 = $82&1;
       if ($83) {
        break L23;
       }
       $84 = HEAP32[$15>>2]|0;
       $85 = ((($84)) + 236|0);
       $86 = HEAP32[$85>>2]|0;
       __THREW__ = 0;
       invoke_vii($86|0,($15|0),($62|0));
       $87 = __THREW__; __THREW__ = 0;
       $88 = $87&1;
       if ($88) {
        break L23;
       }
       $89 = HEAP32[$15>>2]|0;
       $90 = ((($89)) + 236|0);
       $91 = HEAP32[$90>>2]|0;
       __THREW__ = 0;
       invoke_vii($91|0,($15|0),($63|0));
       $92 = __THREW__; __THREW__ = 0;
       $93 = $92&1;
       if ($93) {
        break L23;
       }
       $94 = (($$084134) + 4)|0;
       $95 = HEAP32[$3>>2]|0;
       $96 = ((($95)) + 76|0);
       $97 = ((($95)) + 80|0);
       $98 = HEAP32[$97>>2]|0;
       $99 = HEAP32[$96>>2]|0;
       $100 = (($98) - ($99))|0;
       $101 = (($100|0) / 12)&-1;
       $102 = ($94>>>0)<($101>>>0);
       if ($102) {
        $$084134 = $94;
       } else {
        break;
       }
      }
     }
     $55 = HEAP32[$40>>2]|0;HEAP32[$40>>2] = (($55-1)|0);
     $56 = ($55|0)==(1);
     if (!($56)) {
      break L4;
     }
     __ZNK3osg10Referenced24signalObserversAndDeleteEbb($15,1,1);
     break L4;
    }
   } while(0);
   $103 = ___cxa_find_matching_catch_2()|0;
   $104 = tempRet0;
   $105 = HEAP32[$40>>2]|0;HEAP32[$40>>2] = (($105-1)|0);
   $106 = ($105|0)==(1);
   if (!($106)) {
    $$2 = $103;$$283 = $104;
    ___resumeException($$2|0);
    // unreachable;
   }
   __THREW__ = 0;
   invoke_viii(3262,($15|0),1,1);
   $107 = __THREW__; __THREW__ = 0;
   $108 = $107&1;
   if ($108) {
    $447 = ___cxa_find_matching_catch_3(0|0)|0;
    $448 = tempRet0;
    ___clang_call_terminate($447);
    // unreachable;
   } else {
    $$2 = $103;$$283 = $104;
    ___resumeException($$2|0);
    // unreachable;
   }
   break;
  }
  case 8:  {
   $109 = (__Znwj(80)|0);
   do {
    if ($12) {
     __THREW__ = 0;
     invoke_vii(3435,($109|0),1);
     $110 = __THREW__; __THREW__ = 0;
     $111 = $110&1;
     if (!($111)) {
      $112 = ((($109)) + 12|0);
      ;HEAP32[$112>>2]=0|0;HEAP32[$112+4>>2]=0|0;HEAP32[$112+8>>2]=0|0;
      $113 = ((($109)) + 24|0);
      HEAP32[$113>>2] = 2;
      $114 = ((($109)) + 28|0);
      ;HEAP32[$114>>2]=0|0;HEAP32[$114+4>>2]=0|0;HEAP32[$114+8>>2]=0|0;HEAP32[$114+12>>2]=0|0;HEAP32[$114+16>>2]=0|0;HEAP32[$114+20>>2]=0|0;
      $115 = ((($109)) + 52|0);
      HEAP32[$115>>2] = 4;
      $116 = ((($109)) + 56|0);
      HEAP32[$116>>2] = 0;
      $117 = ((($109)) + 60|0);
      HEAP32[$117>>2] = 4;
      $118 = ((($109)) + 64|0);
      $119 = ((($109)) + 68|0);
      HEAP32[$119>>2] = 0;
      $120 = ((($109)) + 72|0);
      HEAP32[$120>>2] = 0;
      $121 = ((($109)) + 76|0);
      HEAP32[$121>>2] = 0;
      HEAP32[$109>>2] = (64316);
      HEAP32[$118>>2] = (64564);
      break;
     }
     $152 = ___cxa_find_matching_catch_2()|0;
     $153 = tempRet0;
     __ZdlPv($109);
     $$2 = $152;$$283 = $153;
     ___resumeException($$2|0);
     // unreachable;
    } else {
     __THREW__ = 0;
     invoke_vii(3435,($109|0),1);
     $122 = __THREW__; __THREW__ = 0;
     $123 = $122&1;
     if (!($123)) {
      $124 = ((($109)) + 12|0);
      ;HEAP32[$124>>2]=0|0;HEAP32[$124+4>>2]=0|0;HEAP32[$124+8>>2]=0|0;
      $125 = ((($109)) + 24|0);
      HEAP32[$125>>2] = 2;
      $126 = ((($109)) + 28|0);
      ;HEAP32[$126>>2]=0|0;HEAP32[$126+4>>2]=0|0;HEAP32[$126+8>>2]=0|0;HEAP32[$126+12>>2]=0|0;HEAP32[$126+16>>2]=0|0;HEAP32[$126+20>>2]=0|0;
      $127 = ((($109)) + 52|0);
      HEAP32[$127>>2] = 5;
      $128 = ((($109)) + 56|0);
      HEAP32[$128>>2] = 0;
      $129 = ((($109)) + 60|0);
      HEAP32[$129>>2] = 4;
      $130 = ((($109)) + 64|0);
      $131 = ((($109)) + 68|0);
      HEAP32[$131>>2] = 0;
      $132 = ((($109)) + 72|0);
      HEAP32[$132>>2] = 0;
      $133 = ((($109)) + 76|0);
      HEAP32[$133>>2] = 0;
      HEAP32[$109>>2] = (64580);
      HEAP32[$130>>2] = (64828);
      break;
     }
     $154 = ___cxa_find_matching_catch_2()|0;
     $155 = tempRet0;
     __ZdlPv($109);
     $$2 = $154;$$283 = $155;
     ___resumeException($$2|0);
     // unreachable;
    }
   } while(0);
   $134 = ((($109)) + 8|0);
   $135 = HEAP32[$134>>2]|0;HEAP32[$134>>2] = (($135+1)|0);
   $136 = ((($0)) + 4|0);
   $137 = HEAP32[$136>>2]|0;
   __THREW__ = 0;
   (invoke_iii(3494,($137|0),($109|0))|0);
   $138 = __THREW__; __THREW__ = 0;
   $139 = $138&1;
   L57: do {
    if (!($139)) {
     $140 = HEAP32[$1>>2]|0;
     $$085 = $140;
     while(1) {
      $141 = HEAP32[$3>>2]|0;
      $142 = ((($141)) + 76|0);
      $143 = ((($141)) + 80|0);
      $144 = HEAP32[$143>>2]|0;
      $145 = HEAP32[$142>>2]|0;
      $146 = (($144) - ($145))|0;
      $147 = (($146|0) / 12)&-1;
      $148 = (($147) + -2)|0;
      $149 = ($$085>>>0)<($148>>>0);
      if (!($149)) {
       break;
      }
      $156 = (($$085) + 1)|0;
      $157 = (($$085) + 2)|0;
      $158 = (($$085) + 3)|0;
      $159 = HEAP32[$109>>2]|0;
      $160 = ((($159)) + 236|0);
      $161 = HEAP32[$160>>2]|0;
      __THREW__ = 0;
      invoke_vii($161|0,($109|0),($$085|0));
      $162 = __THREW__; __THREW__ = 0;
      $163 = $162&1;
      if ($163) {
       break L57;
      }
      $164 = HEAP32[$109>>2]|0;
      $165 = ((($164)) + 236|0);
      $166 = HEAP32[$165>>2]|0;
      __THREW__ = 0;
      invoke_vii($166|0,($109|0),($156|0));
      $167 = __THREW__; __THREW__ = 0;
      $168 = $167&1;
      if ($168) {
       break L57;
      }
      $169 = HEAP32[$109>>2]|0;
      $170 = ((($169)) + 236|0);
      $171 = HEAP32[$170>>2]|0;
      __THREW__ = 0;
      invoke_vii($171|0,($109|0),($157|0));
      $172 = __THREW__; __THREW__ = 0;
      $173 = $172&1;
      if ($173) {
       break L57;
      }
      $174 = HEAP32[$109>>2]|0;
      $175 = ((($174)) + 236|0);
      $176 = HEAP32[$175>>2]|0;
      __THREW__ = 0;
      invoke_vii($176|0,($109|0),($156|0));
      $177 = __THREW__; __THREW__ = 0;
      $178 = $177&1;
      if ($178) {
       break L57;
      }
      $179 = HEAP32[$109>>2]|0;
      $180 = ((($179)) + 236|0);
      $181 = HEAP32[$180>>2]|0;
      __THREW__ = 0;
      invoke_vii($181|0,($109|0),($158|0));
      $182 = __THREW__; __THREW__ = 0;
      $183 = $182&1;
      if ($183) {
       break L57;
      }
      $184 = HEAP32[$109>>2]|0;
      $185 = ((($184)) + 236|0);
      $186 = HEAP32[$185>>2]|0;
      __THREW__ = 0;
      invoke_vii($186|0,($109|0),($157|0));
      $187 = __THREW__; __THREW__ = 0;
      $188 = $187&1;
      if ($188) {
       break L57;
      } else {
       $$085 = $157;
      }
     }
     $150 = HEAP32[$134>>2]|0;HEAP32[$134>>2] = (($150-1)|0);
     $151 = ($150|0)==(1);
     if (!($151)) {
      break L4;
     }
     __ZNK3osg10Referenced24signalObserversAndDeleteEbb($109,1,1);
     break L4;
    }
   } while(0);
   $189 = ___cxa_find_matching_catch_2()|0;
   $190 = tempRet0;
   $191 = HEAP32[$134>>2]|0;HEAP32[$134>>2] = (($191-1)|0);
   $192 = ($191|0)==(1);
   if (!($192)) {
    $$2 = $189;$$283 = $190;
    ___resumeException($$2|0);
    // unreachable;
   }
   __THREW__ = 0;
   invoke_viii(3262,($109|0),1,1);
   $193 = __THREW__; __THREW__ = 0;
   $194 = $193&1;
   if ($194) {
    $447 = ___cxa_find_matching_catch_3(0|0)|0;
    $448 = tempRet0;
    ___clang_call_terminate($447);
    // unreachable;
   } else {
    $$2 = $189;$$283 = $190;
    ___resumeException($$2|0);
    // unreachable;
   }
   break;
  }
  default: {
   $195 = ((($0)) + 4|0);
   $196 = HEAP32[$195>>2]|0;
   $197 = (__Znwj(72)|0);
   $198 = HEAP32[$6>>2]|0;
   $199 = HEAP32[$5>>2]|0;
   __THREW__ = 0;
   invoke_vii(3435,($197|0),1);
   $200 = __THREW__; __THREW__ = 0;
   $201 = $200&1;
   if (!($201)) {
    $202 = (($198) - ($199))|0;
    $203 = (($202|0) / 12)&-1;
    $204 = (($203) - ($2))|0;
    $205 = ((($197)) + 12|0);
    ;HEAP32[$205>>2]=0|0;HEAP32[$205+4>>2]=0|0;HEAP32[$205+8>>2]=0|0;
    $206 = ((($197)) + 24|0);
    HEAP32[$206>>2] = 2;
    $207 = ((($197)) + 28|0);
    ;HEAP32[$207>>2]=0|0;HEAP32[$207+4>>2]=0|0;HEAP32[$207+8>>2]=0|0;HEAP32[$207+12>>2]=0|0;HEAP32[$207+16>>2]=0|0;HEAP32[$207+20>>2]=0|0;
    $208 = ((($197)) + 52|0);
    HEAP32[$208>>2] = 1;
    $209 = ((($197)) + 56|0);
    HEAP32[$209>>2] = 0;
    $210 = ((($197)) + 60|0);
    HEAP32[$210>>2] = $14;
    HEAP32[$197>>2] = (64844);
    $211 = ((($197)) + 64|0);
    HEAP32[$211>>2] = $2;
    $212 = ((($197)) + 68|0);
    HEAP32[$212>>2] = $204;
    (__ZN3osg8Geometry15addPrimitiveSetEPNS_12PrimitiveSetE($196,$197)|0);
    break L4;
   }
   $213 = ___cxa_find_matching_catch_2()|0;
   $214 = tempRet0;
   __ZdlPv($197);
   $$2 = $213;$$283 = $214;
   ___resumeException($$2|0);
   // unreachable;
  }
  }
 } while(0);
 $215 = HEAP32[$1>>2]|0;
 $216 = HEAP32[$3>>2]|0;
 $217 = ((($216)) + 76|0);
 $218 = ((($216)) + 80|0);
 $219 = HEAP32[$218>>2]|0;
 $220 = HEAP32[$217>>2]|0;
 $221 = (($219) - ($220))|0;
 $222 = (($221|0) / 12)&-1;
 $223 = ($215>>>0)<($222>>>0);
 if ($223) {
  $224 = ((($0)) + 56|0);
  $225 = +HEAPF64[$224>>3];
  $226 = ((($0)) + 88|0);
  $227 = +HEAPF64[$226>>3];
  $228 = ((($0)) + 120|0);
  $229 = +HEAPF64[$228>>3];
  $230 = ((($0)) + 152|0);
  $231 = +HEAPF64[$230>>3];
  $232 = ((($0)) + 32|0);
  $233 = +HEAPF64[$232>>3];
  $234 = ((($0)) + 64|0);
  $235 = +HEAPF64[$234>>3];
  $236 = ((($0)) + 96|0);
  $237 = +HEAPF64[$236>>3];
  $238 = ((($0)) + 128|0);
  $239 = +HEAPF64[$238>>3];
  $240 = ((($0)) + 40|0);
  $241 = +HEAPF64[$240>>3];
  $242 = ((($0)) + 72|0);
  $243 = +HEAPF64[$242>>3];
  $244 = ((($0)) + 104|0);
  $245 = +HEAPF64[$244>>3];
  $246 = ((($0)) + 136|0);
  $247 = +HEAPF64[$246>>3];
  $248 = ((($0)) + 48|0);
  $249 = +HEAPF64[$248>>3];
  $250 = ((($0)) + 80|0);
  $251 = +HEAPF64[$250>>3];
  $252 = ((($0)) + 112|0);
  $253 = +HEAPF64[$252>>3];
  $254 = ((($0)) + 144|0);
  $255 = +HEAPF64[$254>>3];
  $256 = ((($0)) + 16|0);
  $257 = ((($0)) + 256|0);
  $258 = ((($0)) + 264|0);
  $259 = ((($0)) + 272|0);
  $260 = ((($0)) + 280|0);
  $261 = ((($0)) + 160|0);
  $262 = ((($0)) + 168|0);
  $263 = ((($0)) + 176|0);
  $264 = ((($0)) + 184|0);
  $265 = ((($0)) + 192|0);
  $266 = ((($0)) + 200|0);
  $267 = ((($0)) + 208|0);
  $268 = ((($0)) + 216|0);
  $269 = ((($0)) + 224|0);
  $270 = ((($0)) + 232|0);
  $271 = ((($0)) + 240|0);
  $272 = ((($0)) + 248|0);
  $$080133 = $215;$326 = $216;
  while(1) {
   $325 = ((($326)) + 76|0);
   $327 = HEAP32[$325>>2]|0;
   $328 = (($327) + (($$080133*12)|0)|0);
   $329 = +HEAPF32[$328>>2];
   $330 = $329;
   $331 = $225 * $330;
   $332 = (((($327) + (($$080133*12)|0)|0)) + 4|0);
   $333 = +HEAPF32[$332>>2];
   $334 = $333;
   $335 = $227 * $334;
   $336 = $331 + $335;
   $337 = (((($327) + (($$080133*12)|0)|0)) + 8|0);
   $338 = +HEAPF32[$337>>2];
   $339 = $338;
   $340 = $229 * $339;
   $341 = $336 + $340;
   $342 = $231 + $341;
   $343 = 1.0 / $342;
   $344 = $330 * $233;
   $345 = $334 * $235;
   $346 = $344 + $345;
   $347 = $339 * $237;
   $348 = $346 + $347;
   $349 = $239 + $348;
   $350 = $343 * $349;
   $351 = $350;
   $352 = $330 * $241;
   $353 = $334 * $243;
   $354 = $352 + $353;
   $355 = $339 * $245;
   $356 = $354 + $355;
   $357 = $247 + $356;
   $358 = $343 * $357;
   $359 = $358;
   $360 = $330 * $249;
   $361 = $334 * $251;
   $362 = $360 + $361;
   $363 = $339 * $253;
   $364 = $362 + $363;
   $365 = $255 + $364;
   $366 = $343 * $365;
   $367 = $366;
   HEAPF32[$328>>2] = $351;
   HEAPF32[$332>>2] = $359;
   HEAPF32[$337>>2] = $367;
   $368 = HEAP32[$256>>2]|0;
   $369 = ((($368)) + 76|0);
   $370 = HEAP32[$369>>2]|0;
   $371 = +HEAPF64[$257>>3];
   $372 = (($370) + (($$080133*12)|0)|0);
   $373 = +HEAPF32[$372>>2];
   $374 = $373;
   $375 = $371 * $374;
   $376 = +HEAPF64[$258>>3];
   $377 = (((($370) + (($$080133*12)|0)|0)) + 4|0);
   $378 = +HEAPF32[$377>>2];
   $379 = $378;
   $380 = $376 * $379;
   $381 = $375 + $380;
   $382 = +HEAPF64[$259>>3];
   $383 = (((($370) + (($$080133*12)|0)|0)) + 8|0);
   $384 = +HEAPF32[$383>>2];
   $385 = $384;
   $386 = $382 * $385;
   $387 = $381 + $386;
   $388 = +HEAPF64[$260>>3];
   $389 = $388 + $387;
   $390 = 1.0 / $389;
   $391 = +HEAPF64[$261>>3];
   $392 = $374 * $391;
   $393 = +HEAPF64[$262>>3];
   $394 = $379 * $393;
   $395 = $392 + $394;
   $396 = +HEAPF64[$263>>3];
   $397 = $385 * $396;
   $398 = $395 + $397;
   $399 = +HEAPF64[$264>>3];
   $400 = $399 + $398;
   $401 = $390 * $400;
   $402 = $401;
   $403 = +HEAPF64[$265>>3];
   $404 = $374 * $403;
   $405 = +HEAPF64[$266>>3];
   $406 = $379 * $405;
   $407 = $404 + $406;
   $408 = +HEAPF64[$267>>3];
   $409 = $385 * $408;
   $410 = $407 + $409;
   $411 = +HEAPF64[$268>>3];
   $412 = $411 + $410;
   $413 = $390 * $412;
   $414 = $413;
   $415 = +HEAPF64[$269>>3];
   $416 = $374 * $415;
   $417 = +HEAPF64[$270>>3];
   $418 = $379 * $417;
   $419 = $416 + $418;
   $420 = +HEAPF64[$271>>3];
   $421 = $385 * $420;
   $422 = $419 + $421;
   $423 = +HEAPF64[$272>>3];
   $424 = $423 + $422;
   $425 = $390 * $424;
   $426 = $425;
   HEAPF32[$372>>2] = $402;
   HEAPF32[$377>>2] = $414;
   HEAPF32[$383>>2] = $426;
   $427 = $402 * $402;
   $428 = $414 * $414;
   $429 = $427 + $428;
   $430 = $426 * $426;
   $431 = $429 + $430;
   $432 = (+Math_sqrt((+$431)));
   $433 = $432 > 0.0;
   $434 = 1.0 / $432;
   if ($433) {
    $435 = $426 * $434;
    $436 = $414 * $434;
    $437 = $402 * $434;
    HEAPF32[$372>>2] = $437;
    HEAPF32[$377>>2] = $436;
    HEAPF32[$383>>2] = $435;
   }
   $438 = (($$080133) + 1)|0;
   $439 = HEAP32[$3>>2]|0;
   $440 = ((($439)) + 76|0);
   $441 = ((($439)) + 80|0);
   $442 = HEAP32[$441>>2]|0;
   $443 = HEAP32[$440>>2]|0;
   $444 = (($442) - ($443))|0;
   $445 = (($444|0) / 12)&-1;
   $446 = ($438>>>0)<($445>>>0);
   if ($446) {
    $$080133 = $438;$326 = $439;
   } else {
    $$lcssa = $439;
    break;
   }
  }
 } else {
  $$lcssa = $216;
 }
 $273 = ((($$lcssa)) + 32|0);
 $274 = HEAP32[$273>>2]|0;
 $275 = (($274) + 1)|0;
 HEAP32[$273>>2] = $275;
 $276 = ((($$lcssa)) + 44|0);
 $277 = HEAP32[$276>>2]|0;
 $278 = ($277|0)==(0|0);
 if (!($278)) {
  $279 = HEAP32[$277>>2]|0;
  $280 = ((($279)) + 20|0);
  $281 = HEAP32[$280>>2]|0;
  FUNCTION_TABLE_vii[$281 & 8191]($277,$$lcssa);
 }
 $282 = ((($$lcssa)) + 40|0);
 $283 = HEAP32[$282>>2]|0;
 $284 = ($283|0)==(0|0);
 if (!($284)) {
  __ZN3osg12BufferObject5dirtyEv($283);
 }
 $285 = ((($0)) + 16|0);
 $286 = HEAP32[$285>>2]|0;
 $287 = ((($286)) + 32|0);
 $288 = HEAP32[$287>>2]|0;
 $289 = (($288) + 1)|0;
 HEAP32[$287>>2] = $289;
 $290 = ((($286)) + 44|0);
 $291 = HEAP32[$290>>2]|0;
 $292 = ($291|0)==(0|0);
 if (!($292)) {
  $293 = HEAP32[$291>>2]|0;
  $294 = ((($293)) + 20|0);
  $295 = HEAP32[$294>>2]|0;
  FUNCTION_TABLE_vii[$295 & 8191]($291,$286);
 }
 $296 = ((($286)) + 40|0);
 $297 = HEAP32[$296>>2]|0;
 $298 = ($297|0)==(0|0);
 if (!($298)) {
  __ZN3osg12BufferObject5dirtyEv($297);
 }
 $299 = ((($0)) + 20|0);
 $300 = HEAP32[$299>>2]|0;
 $301 = ((($300)) + 32|0);
 $302 = HEAP32[$301>>2]|0;
 $303 = (($302) + 1)|0;
 HEAP32[$301>>2] = $303;
 $304 = ((($300)) + 44|0);
 $305 = HEAP32[$304>>2]|0;
 $306 = ($305|0)==(0|0);
 if (!($306)) {
  $307 = HEAP32[$305>>2]|0;
  $308 = ((($307)) + 20|0);
  $309 = HEAP32[$308>>2]|0;
  FUNCTION_TABLE_vii[$309 & 8191]($305,$300);
 }
 $310 = ((($300)) + 40|0);
 $311 = HEAP32[$310>>2]|0;
 $312 = ($311|0)==(0|0);
 if (!($312)) {
  __ZN3osg12BufferObject5dirtyEv($311);
 }
 $313 = ((($0)) + 4|0);
 $314 = HEAP32[$313>>2]|0;
 $315 = HEAP32[$314>>2]|0;
 $316 = ((($315)) + 220|0);
 $317 = HEAP32[$316>>2]|0;
 FUNCTION_TABLE_vi[$317 & 8191]($314);
 $318 = HEAP32[$3>>2]|0;
 $319 = ((($318)) + 76|0);
 $320 = ((($318)) + 80|0);
 $321 = HEAP32[$320>>2]|0;
 $322 = HEAP32[$319>>2]|0;
 $323 = (($321) - ($322))|0;
 $324 = (($323|0) / 12)&-1;
 HEAP32[$1>>2] = $324;
 return;
}
function __ZNK3osg11HeightField9getNormalEjj($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$sink = 0.0, $$sink31 = 0.0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0.0, $15 = 0, $16 = 0.0, $17 = 0.0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0.0, $30 = 0, $31 = 0, $32 = 0, $33 = 0.0, $34 = 0.0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0.0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0.0, $44 = 0.0, $45 = 0.0, $46 = 0;
 var $47 = 0.0, $48 = 0.0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0.0, $55 = 0, $56 = 0.0, $57 = 0.0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0.0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0.0, $71 = 0.0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0.0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0.0, $82 = 0.0;
 var $83 = 0.0, $84 = 0, $85 = 0.0, $86 = 0.0, $87 = 0.0, $88 = 0.0, $89 = 0, $9 = 0, $90 = 0, $91 = 0.0, $92 = 0.0, $93 = 0.0, $94 = 0.0, $95 = 0.0, $96 = 0, $97 = 0.0, $98 = 0.0, $99 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ($2|0)==(0);
 do {
  if ($4) {
   $5 = ((($1)) + 104|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ((($1)) + 32|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = Math_imul($8, $3)|0;
   $10 = (($9) + 1)|0;
   $11 = ((($6)) + 76|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = (($12) + ($10<<2)|0);
   $14 = +HEAPF32[$13>>2];
   $15 = (($12) + ($9<<2)|0);
   $16 = +HEAPF32[$15>>2];
   $17 = $14 - $16;
   $$sink = $17;$51 = $8;$53 = $12;
  } else {
   $18 = ((($1)) + 32|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($19) + -1)|0;
   $21 = ($20|0)==($2|0);
   $22 = ((($1)) + 104|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = ((($23)) + 76|0);
   $25 = HEAP32[$24>>2]|0;
   if ($21) {
    $26 = Math_imul($19, $3)|0;
    $27 = (($26) + ($2))|0;
    $28 = (($25) + ($27<<2)|0);
    $29 = +HEAPF32[$28>>2];
    $30 = (($2) + -1)|0;
    $31 = (($30) + ($26))|0;
    $32 = (($25) + ($31<<2)|0);
    $33 = +HEAPF32[$32>>2];
    $34 = $29 - $33;
    $$sink = $34;$51 = $19;$53 = $25;
    break;
   } else {
    $35 = (($2) + 1)|0;
    $36 = Math_imul($19, $3)|0;
    $37 = (($35) + ($36))|0;
    $38 = (($25) + ($37<<2)|0);
    $39 = +HEAPF32[$38>>2];
    $40 = (($2) + -1)|0;
    $41 = (($40) + ($36))|0;
    $42 = (($25) + ($41<<2)|0);
    $43 = +HEAPF32[$42>>2];
    $44 = $39 - $43;
    $45 = $44 * 0.5;
    $$sink = $45;$51 = $19;$53 = $25;
    break;
   }
  }
 } while(0);
 $46 = ((($1)) + 52|0);
 $47 = +HEAPF32[$46>>2];
 $48 = $$sink / $47;
 $49 = ($3|0)==(0);
 do {
  if ($49) {
   $50 = (($51) + ($2))|0;
   $52 = (($53) + ($50<<2)|0);
   $54 = +HEAPF32[$52>>2];
   $55 = (($53) + ($2<<2)|0);
   $56 = +HEAPF32[$55>>2];
   $57 = $54 - $56;
   $$sink31 = $57;
  } else {
   $58 = ((($1)) + 36|0);
   $59 = HEAP32[$58>>2]|0;
   $60 = (($59) + -1)|0;
   $61 = ($60|0)==($3|0);
   if ($61) {
    $62 = Math_imul($51, $3)|0;
    $63 = (($62) + ($2))|0;
    $64 = (($53) + ($63<<2)|0);
    $65 = +HEAPF32[$64>>2];
    $66 = (($3) + -1)|0;
    $67 = Math_imul($51, $66)|0;
    $68 = (($67) + ($2))|0;
    $69 = (($53) + ($68<<2)|0);
    $70 = +HEAPF32[$69>>2];
    $71 = $65 - $70;
    $$sink31 = $71;
    break;
   } else {
    $72 = (($3) + 1)|0;
    $73 = Math_imul($51, $72)|0;
    $74 = (($73) + ($2))|0;
    $75 = (($53) + ($74<<2)|0);
    $76 = +HEAPF32[$75>>2];
    $77 = (($3) + -1)|0;
    $78 = Math_imul($51, $77)|0;
    $79 = (($78) + ($2))|0;
    $80 = (($53) + ($79<<2)|0);
    $81 = +HEAPF32[$80>>2];
    $82 = $76 - $81;
    $83 = $82 * 0.5;
    $$sink31 = $83;
    break;
   }
  }
 } while(0);
 $84 = ((($1)) + 56|0);
 $85 = +HEAPF32[$84>>2];
 $86 = $$sink31 / $85;
 $87 = -$48;
 $88 = -$86;
 HEAPF32[$0>>2] = $87;
 $89 = ((($0)) + 4|0);
 HEAPF32[$89>>2] = $88;
 $90 = ((($0)) + 8|0);
 HEAPF32[$90>>2] = 1.0;
 $91 = $48 * $48;
 $92 = $86 * $86;
 $93 = $91 + $92;
 $94 = $93 + 1.0;
 $95 = (+Math_sqrt((+$94)));
 $96 = $95 > 0.0;
 $97 = 1.0 / $95;
 if (!($96)) {
  return;
 }
 $98 = $97 * $88;
 $99 = $97 * $87;
 HEAPF32[$0>>2] = $99;
 HEAPF32[$89>>2] = $98;
 HEAPF32[$90>>2] = $97;
 return;
}
function __ZN3osg25BuildShapeGeometryVisitor16drawCylinderBodyEjff($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = +$2;
 $3 = +$3;
 var $$0$lcssa = 0.0, $$0128 = 0.0, $$089$lcssa = 0.0, $$089127 = 0.0, $$092123 = 0, $$093126 = 0, $$1 = 0.0, $$190 = 0.0, $$2125 = 0.0, $$291124 = 0.0, $$pre = 0, $$pre$phi135Z2D = 0, $$pre$phiZ2D = 0, $$pre134 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0;
 var $141 = 0, $142 = 0.0, $143 = 0.0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0;
 var $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0.0, $173 = 0.0, $174 = 0, $175 = 0, $176 = 0, $177 = 0;
 var $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0;
 var $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0;
 var $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0.0, $222 = 0.0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0;
 var $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0.0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0.0;
 var $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0.0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0;
 var $269 = 0, $27 = 0.0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0.0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0;
 var $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0;
 var $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0.0, $318 = 0.0, $319 = 0.0, $32 = 0, $320 = 0.0, $321 = 0, $322 = 0;
 var $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0;
 var $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0.0, $35 = 0, $350 = 0.0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0;
 var $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0;
 var $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0;
 var $396 = 0, $397 = 0, $398 = 0.0, $399 = 0.0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $exitcond133 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 208|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(208|0);
 $4 = sp + 196|0;
 $5 = sp + 56|0;
 $6 = sp + 184|0;
 $7 = sp + 48|0;
 $8 = sp + 40|0;
 $9 = sp + 172|0;
 $10 = sp + 32|0;
 $11 = sp + 160|0;
 $12 = sp + 24|0;
 $13 = sp + 148|0;
 $14 = sp + 136|0;
 $15 = sp + 16|0;
 $16 = sp + 124|0;
 $17 = sp + 8|0;
 $18 = sp;
 $19 = sp + 112|0;
 $20 = sp + 100|0;
 $21 = sp + 88|0;
 $22 = sp + 76|0;
 $23 = sp + 64|0;
 $24 = (+($1>>>0));
 $25 = 6.2831854820251465 / $24;
 $26 = 1.0 / $24;
 $27 = $3 * -0.5;
 $28 = $3 * 0.5;
 $29 = ((($0)) + 8|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ($30|0)==(0|0);
 if ($31) {
  $400 = 1;$401 = 0;
 } else {
  $32 = ((($30)) + 44|0);
  $33 = HEAP8[$32>>0]|0;
  $34 = ($33<<24>>24)!=(0);
  $35 = ((($30)) + 45|0);
  $36 = HEAP8[$35>>0]|0;
  $37 = ($36<<24>>24)!=(0);
  $400 = $34;$401 = $37;
 }
 $38 = ((($0)) + 24|0);
 HEAP32[$38>>2] = 8;
 $39 = ((($0)) + 12|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ((($40)) + 76|0);
 $42 = ((($40)) + 80|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = HEAP32[$41>>2]|0;
 $45 = (($43) - ($44))|0;
 $46 = (($45|0) / 12)&-1;
 $47 = ((($0)) + 28|0);
 HEAP32[$47>>2] = $46;
 if ($400) {
  $48 = ($1|0)==(0);
  if ($48) {
   $$pre = ((($0)) + 16|0);
   $$0$lcssa = 0.0;$$089$lcssa = 0.0;$$pre$phiZ2D = $$pre;
  } else {
   $49 = ((($20)) + 4|0);
   $50 = ((($20)) + 8|0);
   $51 = ((($0)) + 16|0);
   $52 = ((($0)) + 20|0);
   $53 = ((($12)) + 4|0);
   $54 = ((($11)) + 4|0);
   $55 = ((($11)) + 8|0);
   $56 = ((($10)) + 4|0);
   $57 = ((($9)) + 4|0);
   $58 = ((($9)) + 8|0);
   $$0128 = 0.0;$$089127 = 0.0;$$093126 = 0;
   while(1) {
    $142 = (+Math_cos((+$$0128)));
    $143 = (+Math_sin((+$$0128)));
    HEAPF32[$20>>2] = $142;
    HEAPF32[$49>>2] = $143;
    HEAPF32[$50>>2] = 0.0;
    $144 = HEAP32[$51>>2]|0;
    $145 = ((($144)) + 80|0);
    $146 = HEAP32[$145>>2]|0;
    $147 = ((($144)) + 84|0);
    $148 = HEAP32[$147>>2]|0;
    $149 = ($146|0)==($148|0);
    if ($149) {
     $152 = ((($144)) + 76|0);
     __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($152,$20);
    } else {
     ;HEAP32[$146>>2]=HEAP32[$20>>2]|0;HEAP32[$146+4>>2]=HEAP32[$20+4>>2]|0;HEAP32[$146+8>>2]=HEAP32[$20+8>>2]|0;
     $150 = HEAP32[$145>>2]|0;
     $151 = ((($150)) + 12|0);
     HEAP32[$145>>2] = $151;
    }
    $153 = HEAP32[$52>>2]|0;
    HEAPF32[$12>>2] = $$089127;
    HEAPF32[$53>>2] = 1.0;
    $154 = ((($153)) + 80|0);
    $155 = HEAP32[$154>>2]|0;
    $156 = ((($153)) + 84|0);
    $157 = HEAP32[$156>>2]|0;
    $158 = ($155|0)==($157|0);
    if ($158) {
     $171 = ((($153)) + 76|0);
     __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($171,$12);
    } else {
     $159 = $12;
     $160 = $159;
     $161 = HEAP32[$160>>2]|0;
     $162 = (($159) + 4)|0;
     $163 = $162;
     $164 = HEAP32[$163>>2]|0;
     $165 = $155;
     $166 = $165;
     HEAP32[$166>>2] = $161;
     $167 = (($165) + 4)|0;
     $168 = $167;
     HEAP32[$168>>2] = $164;
     $169 = HEAP32[$154>>2]|0;
     $170 = ((($169)) + 8|0);
     HEAP32[$154>>2] = $170;
    }
    $172 = $142 * $2;
    $173 = $143 * $2;
    $174 = HEAP32[$39>>2]|0;
    HEAPF32[$11>>2] = $172;
    HEAPF32[$54>>2] = $173;
    HEAPF32[$55>>2] = $28;
    $175 = ((($174)) + 80|0);
    $176 = HEAP32[$175>>2]|0;
    $177 = ((($174)) + 84|0);
    $178 = HEAP32[$177>>2]|0;
    $179 = ($176|0)==($178|0);
    if ($179) {
     $182 = ((($174)) + 76|0);
     __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($182,$11);
    } else {
     ;HEAP32[$176>>2]=HEAP32[$11>>2]|0;HEAP32[$176+4>>2]=HEAP32[$11+4>>2]|0;HEAP32[$176+8>>2]=HEAP32[$11+8>>2]|0;
     $180 = HEAP32[$175>>2]|0;
     $181 = ((($180)) + 12|0);
     HEAP32[$175>>2] = $181;
    }
    $183 = HEAP32[$51>>2]|0;
    $184 = ((($183)) + 80|0);
    $185 = HEAP32[$184>>2]|0;
    $186 = ((($183)) + 84|0);
    $187 = HEAP32[$186>>2]|0;
    $188 = ($185|0)==($187|0);
    if ($188) {
     $191 = ((($183)) + 76|0);
     __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($191,$20);
    } else {
     ;HEAP32[$185>>2]=HEAP32[$20>>2]|0;HEAP32[$185+4>>2]=HEAP32[$20+4>>2]|0;HEAP32[$185+8>>2]=HEAP32[$20+8>>2]|0;
     $189 = HEAP32[$184>>2]|0;
     $190 = ((($189)) + 12|0);
     HEAP32[$184>>2] = $190;
    }
    $192 = HEAP32[$52>>2]|0;
    HEAPF32[$10>>2] = $$089127;
    HEAPF32[$56>>2] = 0.0;
    $193 = ((($192)) + 80|0);
    $194 = HEAP32[$193>>2]|0;
    $195 = ((($192)) + 84|0);
    $196 = HEAP32[$195>>2]|0;
    $197 = ($194|0)==($196|0);
    if ($197) {
     $210 = ((($192)) + 76|0);
     __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($210,$10);
    } else {
     $198 = $10;
     $199 = $198;
     $200 = HEAP32[$199>>2]|0;
     $201 = (($198) + 4)|0;
     $202 = $201;
     $203 = HEAP32[$202>>2]|0;
     $204 = $194;
     $205 = $204;
     HEAP32[$205>>2] = $200;
     $206 = (($204) + 4)|0;
     $207 = $206;
     HEAP32[$207>>2] = $203;
     $208 = HEAP32[$193>>2]|0;
     $209 = ((($208)) + 8|0);
     HEAP32[$193>>2] = $209;
    }
    $211 = HEAP32[$39>>2]|0;
    HEAPF32[$9>>2] = $172;
    HEAPF32[$57>>2] = $173;
    HEAPF32[$58>>2] = $27;
    $212 = ((($211)) + 80|0);
    $213 = HEAP32[$212>>2]|0;
    $214 = ((($211)) + 84|0);
    $215 = HEAP32[$214>>2]|0;
    $216 = ($213|0)==($215|0);
    if ($216) {
     $219 = ((($211)) + 76|0);
     __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($219,$9);
    } else {
     ;HEAP32[$213>>2]=HEAP32[$9>>2]|0;HEAP32[$213+4>>2]=HEAP32[$9+4>>2]|0;HEAP32[$213+8>>2]=HEAP32[$9+8>>2]|0;
     $217 = HEAP32[$212>>2]|0;
     $218 = ((($217)) + 12|0);
     HEAP32[$212>>2] = $218;
    }
    $220 = (($$093126) + 1)|0;
    $221 = $25 + $$0128;
    $222 = $26 + $$089127;
    $exitcond133 = ($220|0)==($1|0);
    if ($exitcond133) {
     $$0$lcssa = $221;$$089$lcssa = $222;$$pre$phiZ2D = $51;
     break;
    } else {
     $$0128 = $221;$$089127 = $222;$$093126 = $220;
    }
   }
  }
  HEAPF32[$21>>2] = 1.0;
  $59 = ((($21)) + 4|0);
  HEAPF32[$59>>2] = 0.0;
  $60 = ((($21)) + 8|0);
  HEAPF32[$60>>2] = 0.0;
  $61 = HEAP32[$$pre$phiZ2D>>2]|0;
  $62 = ((($61)) + 80|0);
  $63 = HEAP32[$62>>2]|0;
  $64 = ((($61)) + 84|0);
  $65 = HEAP32[$64>>2]|0;
  $66 = ($63|0)==($65|0);
  if ($66) {
   $69 = ((($61)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($69,$21);
  } else {
   ;HEAP32[$63>>2]=HEAP32[$21>>2]|0;HEAP32[$63+4>>2]=HEAP32[$21+4>>2]|0;HEAP32[$63+8>>2]=HEAP32[$21+8>>2]|0;
   $67 = HEAP32[$62>>2]|0;
   $68 = ((($67)) + 12|0);
   HEAP32[$62>>2] = $68;
  }
  $70 = ((($0)) + 20|0);
  $71 = HEAP32[$70>>2]|0;
  HEAPF32[$17>>2] = 1.0;
  $72 = ((($17)) + 4|0);
  HEAPF32[$72>>2] = 1.0;
  $73 = ((($71)) + 80|0);
  $74 = HEAP32[$73>>2]|0;
  $75 = ((($71)) + 84|0);
  $76 = HEAP32[$75>>2]|0;
  $77 = ($74|0)==($76|0);
  if ($77) {
   $90 = ((($71)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($90,$17);
  } else {
   $78 = $17;
   $79 = $78;
   $80 = HEAP32[$79>>2]|0;
   $81 = (($78) + 4)|0;
   $82 = $81;
   $83 = HEAP32[$82>>2]|0;
   $84 = $74;
   $85 = $84;
   HEAP32[$85>>2] = $80;
   $86 = (($84) + 4)|0;
   $87 = $86;
   HEAP32[$87>>2] = $83;
   $88 = HEAP32[$73>>2]|0;
   $89 = ((($88)) + 8|0);
   HEAP32[$73>>2] = $89;
  }
  $91 = HEAP32[$39>>2]|0;
  HEAPF32[$16>>2] = $2;
  $92 = ((($16)) + 4|0);
  HEAPF32[$92>>2] = 0.0;
  $93 = ((($16)) + 8|0);
  HEAPF32[$93>>2] = $28;
  $94 = ((($91)) + 80|0);
  $95 = HEAP32[$94>>2]|0;
  $96 = ((($91)) + 84|0);
  $97 = HEAP32[$96>>2]|0;
  $98 = ($95|0)==($97|0);
  if ($98) {
   $101 = ((($91)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($101,$16);
  } else {
   ;HEAP32[$95>>2]=HEAP32[$16>>2]|0;HEAP32[$95+4>>2]=HEAP32[$16+4>>2]|0;HEAP32[$95+8>>2]=HEAP32[$16+8>>2]|0;
   $99 = HEAP32[$94>>2]|0;
   $100 = ((($99)) + 12|0);
   HEAP32[$94>>2] = $100;
  }
  $102 = HEAP32[$$pre$phiZ2D>>2]|0;
  $103 = ((($102)) + 80|0);
  $104 = HEAP32[$103>>2]|0;
  $105 = ((($102)) + 84|0);
  $106 = HEAP32[$105>>2]|0;
  $107 = ($104|0)==($106|0);
  if ($107) {
   $110 = ((($102)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($110,$21);
  } else {
   ;HEAP32[$104>>2]=HEAP32[$21>>2]|0;HEAP32[$104+4>>2]=HEAP32[$21+4>>2]|0;HEAP32[$104+8>>2]=HEAP32[$21+8>>2]|0;
   $108 = HEAP32[$103>>2]|0;
   $109 = ((($108)) + 12|0);
   HEAP32[$103>>2] = $109;
  }
  $111 = HEAP32[$70>>2]|0;
  HEAPF32[$15>>2] = 1.0;
  $112 = ((($15)) + 4|0);
  HEAPF32[$112>>2] = 0.0;
  $113 = ((($111)) + 80|0);
  $114 = HEAP32[$113>>2]|0;
  $115 = ((($111)) + 84|0);
  $116 = HEAP32[$115>>2]|0;
  $117 = ($114|0)==($116|0);
  if ($117) {
   $130 = ((($111)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($130,$15);
  } else {
   $118 = $15;
   $119 = $118;
   $120 = HEAP32[$119>>2]|0;
   $121 = (($118) + 4)|0;
   $122 = $121;
   $123 = HEAP32[$122>>2]|0;
   $124 = $114;
   $125 = $124;
   HEAP32[$125>>2] = $120;
   $126 = (($124) + 4)|0;
   $127 = $126;
   HEAP32[$127>>2] = $123;
   $128 = HEAP32[$113>>2]|0;
   $129 = ((($128)) + 8|0);
   HEAP32[$113>>2] = $129;
  }
  $131 = HEAP32[$39>>2]|0;
  HEAPF32[$14>>2] = $2;
  $132 = ((($14)) + 4|0);
  HEAPF32[$132>>2] = 0.0;
  $133 = ((($14)) + 8|0);
  HEAPF32[$133>>2] = $27;
  $134 = ((($131)) + 80|0);
  $135 = HEAP32[$134>>2]|0;
  $136 = ((($131)) + 84|0);
  $137 = HEAP32[$136>>2]|0;
  $138 = ($135|0)==($137|0);
  if ($138) {
   $141 = ((($131)) + 76|0);
   __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($141,$14);
  } else {
   ;HEAP32[$135>>2]=HEAP32[$14>>2]|0;HEAP32[$135+4>>2]=HEAP32[$14+4>>2]|0;HEAP32[$135+8>>2]=HEAP32[$14+8>>2]|0;
   $139 = HEAP32[$134>>2]|0;
   $140 = ((($139)) + 12|0);
   HEAP32[$134>>2] = $140;
  }
  $$1 = $$0$lcssa;$$190 = $$089$lcssa;
 } else {
  $$1 = 0.0;$$190 = 0.0;
 }
 if (!($401)) {
  __ZN3osg25BuildShapeGeometryVisitor3EndEv($0);
  STACKTOP = sp;return;
 }
 $223 = ($1|0)==(0);
 if ($223) {
  $$pre134 = ((($0)) + 16|0);
  $$pre$phi135Z2D = $$pre134;
 } else {
  $224 = ((($22)) + 4|0);
  $225 = ((($22)) + 8|0);
  $226 = ((($0)) + 16|0);
  $227 = ((($0)) + 20|0);
  $228 = ((($8)) + 4|0);
  $229 = ((($13)) + 4|0);
  $230 = ((($13)) + 8|0);
  $231 = ((($18)) + 4|0);
  $232 = ((($19)) + 4|0);
  $233 = ((($19)) + 8|0);
  $$092123 = 0;$$2125 = $$1;$$291124 = $$190;
  while(1) {
   $317 = (+Math_cos((+$$2125)));
   $318 = (+Math_sin((+$$2125)));
   $319 = -$317;
   $320 = -$318;
   HEAPF32[$22>>2] = $319;
   HEAPF32[$224>>2] = $320;
   HEAPF32[$225>>2] = 0.0;
   $321 = HEAP32[$226>>2]|0;
   $322 = ((($321)) + 80|0);
   $323 = HEAP32[$322>>2]|0;
   $324 = ((($321)) + 84|0);
   $325 = HEAP32[$324>>2]|0;
   $326 = ($323|0)==($325|0);
   if ($326) {
    $329 = ((($321)) + 76|0);
    __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($329,$22);
   } else {
    ;HEAP32[$323>>2]=HEAP32[$22>>2]|0;HEAP32[$323+4>>2]=HEAP32[$22+4>>2]|0;HEAP32[$323+8>>2]=HEAP32[$22+8>>2]|0;
    $327 = HEAP32[$322>>2]|0;
    $328 = ((($327)) + 12|0);
    HEAP32[$322>>2] = $328;
   }
   $330 = HEAP32[$227>>2]|0;
   HEAPF32[$8>>2] = $$291124;
   HEAPF32[$228>>2] = 0.0;
   $331 = ((($330)) + 80|0);
   $332 = HEAP32[$331>>2]|0;
   $333 = ((($330)) + 84|0);
   $334 = HEAP32[$333>>2]|0;
   $335 = ($332|0)==($334|0);
   if ($335) {
    $348 = ((($330)) + 76|0);
    __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($348,$8);
   } else {
    $336 = $8;
    $337 = $336;
    $338 = HEAP32[$337>>2]|0;
    $339 = (($336) + 4)|0;
    $340 = $339;
    $341 = HEAP32[$340>>2]|0;
    $342 = $332;
    $343 = $342;
    HEAP32[$343>>2] = $338;
    $344 = (($342) + 4)|0;
    $345 = $344;
    HEAP32[$345>>2] = $341;
    $346 = HEAP32[$331>>2]|0;
    $347 = ((($346)) + 8|0);
    HEAP32[$331>>2] = $347;
   }
   $349 = $317 * $2;
   $350 = $318 * $2;
   $351 = HEAP32[$39>>2]|0;
   HEAPF32[$13>>2] = $349;
   HEAPF32[$229>>2] = $350;
   HEAPF32[$230>>2] = $27;
   $352 = ((($351)) + 80|0);
   $353 = HEAP32[$352>>2]|0;
   $354 = ((($351)) + 84|0);
   $355 = HEAP32[$354>>2]|0;
   $356 = ($353|0)==($355|0);
   if ($356) {
    $359 = ((($351)) + 76|0);
    __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($359,$13);
   } else {
    ;HEAP32[$353>>2]=HEAP32[$13>>2]|0;HEAP32[$353+4>>2]=HEAP32[$13+4>>2]|0;HEAP32[$353+8>>2]=HEAP32[$13+8>>2]|0;
    $357 = HEAP32[$352>>2]|0;
    $358 = ((($357)) + 12|0);
    HEAP32[$352>>2] = $358;
   }
   $360 = HEAP32[$226>>2]|0;
   $361 = ((($360)) + 80|0);
   $362 = HEAP32[$361>>2]|0;
   $363 = ((($360)) + 84|0);
   $364 = HEAP32[$363>>2]|0;
   $365 = ($362|0)==($364|0);
   if ($365) {
    $368 = ((($360)) + 76|0);
    __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($368,$22);
   } else {
    ;HEAP32[$362>>2]=HEAP32[$22>>2]|0;HEAP32[$362+4>>2]=HEAP32[$22+4>>2]|0;HEAP32[$362+8>>2]=HEAP32[$22+8>>2]|0;
    $366 = HEAP32[$361>>2]|0;
    $367 = ((($366)) + 12|0);
    HEAP32[$361>>2] = $367;
   }
   $369 = HEAP32[$227>>2]|0;
   HEAPF32[$18>>2] = $$291124;
   HEAPF32[$231>>2] = 1.0;
   $370 = ((($369)) + 80|0);
   $371 = HEAP32[$370>>2]|0;
   $372 = ((($369)) + 84|0);
   $373 = HEAP32[$372>>2]|0;
   $374 = ($371|0)==($373|0);
   if ($374) {
    $387 = ((($369)) + 76|0);
    __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($387,$18);
   } else {
    $375 = $18;
    $376 = $375;
    $377 = HEAP32[$376>>2]|0;
    $378 = (($375) + 4)|0;
    $379 = $378;
    $380 = HEAP32[$379>>2]|0;
    $381 = $371;
    $382 = $381;
    HEAP32[$382>>2] = $377;
    $383 = (($381) + 4)|0;
    $384 = $383;
    HEAP32[$384>>2] = $380;
    $385 = HEAP32[$370>>2]|0;
    $386 = ((($385)) + 8|0);
    HEAP32[$370>>2] = $386;
   }
   $388 = HEAP32[$39>>2]|0;
   HEAPF32[$19>>2] = $349;
   HEAPF32[$232>>2] = $350;
   HEAPF32[$233>>2] = $28;
   $389 = ((($388)) + 80|0);
   $390 = HEAP32[$389>>2]|0;
   $391 = ((($388)) + 84|0);
   $392 = HEAP32[$391>>2]|0;
   $393 = ($390|0)==($392|0);
   if ($393) {
    $396 = ((($388)) + 76|0);
    __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($396,$19);
   } else {
    ;HEAP32[$390>>2]=HEAP32[$19>>2]|0;HEAP32[$390+4>>2]=HEAP32[$19+4>>2]|0;HEAP32[$390+8>>2]=HEAP32[$19+8>>2]|0;
    $394 = HEAP32[$389>>2]|0;
    $395 = ((($394)) + 12|0);
    HEAP32[$389>>2] = $395;
   }
   $397 = (($$092123) + 1)|0;
   $398 = $25 + $$2125;
   $399 = $26 + $$291124;
   $exitcond = ($397|0)==($1|0);
   if ($exitcond) {
    $$pre$phi135Z2D = $226;
    break;
   } else {
    $$092123 = $397;$$2125 = $398;$$291124 = $399;
   }
  }
 }
 HEAPF32[$23>>2] = -1.0;
 $234 = ((($23)) + 4|0);
 HEAPF32[$234>>2] = 0.0;
 $235 = ((($23)) + 8|0);
 HEAPF32[$235>>2] = 0.0;
 $236 = HEAP32[$$pre$phi135Z2D>>2]|0;
 $237 = ((($236)) + 80|0);
 $238 = HEAP32[$237>>2]|0;
 $239 = ((($236)) + 84|0);
 $240 = HEAP32[$239>>2]|0;
 $241 = ($238|0)==($240|0);
 if ($241) {
  $244 = ((($236)) + 76|0);
  __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($244,$23);
 } else {
  ;HEAP32[$238>>2]=HEAP32[$23>>2]|0;HEAP32[$238+4>>2]=HEAP32[$23+4>>2]|0;HEAP32[$238+8>>2]=HEAP32[$23+8>>2]|0;
  $242 = HEAP32[$237>>2]|0;
  $243 = ((($242)) + 12|0);
  HEAP32[$237>>2] = $243;
 }
 $245 = ((($0)) + 20|0);
 $246 = HEAP32[$245>>2]|0;
 HEAPF32[$7>>2] = 1.0;
 $247 = ((($7)) + 4|0);
 HEAPF32[$247>>2] = 0.0;
 $248 = ((($246)) + 80|0);
 $249 = HEAP32[$248>>2]|0;
 $250 = ((($246)) + 84|0);
 $251 = HEAP32[$250>>2]|0;
 $252 = ($249|0)==($251|0);
 if ($252) {
  $265 = ((($246)) + 76|0);
  __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($265,$7);
 } else {
  $253 = $7;
  $254 = $253;
  $255 = HEAP32[$254>>2]|0;
  $256 = (($253) + 4)|0;
  $257 = $256;
  $258 = HEAP32[$257>>2]|0;
  $259 = $249;
  $260 = $259;
  HEAP32[$260>>2] = $255;
  $261 = (($259) + 4)|0;
  $262 = $261;
  HEAP32[$262>>2] = $258;
  $263 = HEAP32[$248>>2]|0;
  $264 = ((($263)) + 8|0);
  HEAP32[$248>>2] = $264;
 }
 $266 = HEAP32[$39>>2]|0;
 HEAPF32[$6>>2] = $2;
 $267 = ((($6)) + 4|0);
 HEAPF32[$267>>2] = 0.0;
 $268 = ((($6)) + 8|0);
 HEAPF32[$268>>2] = $27;
 $269 = ((($266)) + 80|0);
 $270 = HEAP32[$269>>2]|0;
 $271 = ((($266)) + 84|0);
 $272 = HEAP32[$271>>2]|0;
 $273 = ($270|0)==($272|0);
 if ($273) {
  $276 = ((($266)) + 76|0);
  __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($276,$6);
 } else {
  ;HEAP32[$270>>2]=HEAP32[$6>>2]|0;HEAP32[$270+4>>2]=HEAP32[$6+4>>2]|0;HEAP32[$270+8>>2]=HEAP32[$6+8>>2]|0;
  $274 = HEAP32[$269>>2]|0;
  $275 = ((($274)) + 12|0);
  HEAP32[$269>>2] = $275;
 }
 $277 = HEAP32[$$pre$phi135Z2D>>2]|0;
 $278 = ((($277)) + 80|0);
 $279 = HEAP32[$278>>2]|0;
 $280 = ((($277)) + 84|0);
 $281 = HEAP32[$280>>2]|0;
 $282 = ($279|0)==($281|0);
 if ($282) {
  $285 = ((($277)) + 76|0);
  __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($285,$23);
 } else {
  ;HEAP32[$279>>2]=HEAP32[$23>>2]|0;HEAP32[$279+4>>2]=HEAP32[$23+4>>2]|0;HEAP32[$279+8>>2]=HEAP32[$23+8>>2]|0;
  $283 = HEAP32[$278>>2]|0;
  $284 = ((($283)) + 12|0);
  HEAP32[$278>>2] = $284;
 }
 $286 = HEAP32[$245>>2]|0;
 HEAPF32[$5>>2] = 1.0;
 $287 = ((($5)) + 4|0);
 HEAPF32[$287>>2] = 1.0;
 $288 = ((($286)) + 80|0);
 $289 = HEAP32[$288>>2]|0;
 $290 = ((($286)) + 84|0);
 $291 = HEAP32[$290>>2]|0;
 $292 = ($289|0)==($291|0);
 if ($292) {
  $305 = ((($286)) + 76|0);
  __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($305,$5);
 } else {
  $293 = $5;
  $294 = $293;
  $295 = HEAP32[$294>>2]|0;
  $296 = (($293) + 4)|0;
  $297 = $296;
  $298 = HEAP32[$297>>2]|0;
  $299 = $289;
  $300 = $299;
  HEAP32[$300>>2] = $295;
  $301 = (($299) + 4)|0;
  $302 = $301;
  HEAP32[$302>>2] = $298;
  $303 = HEAP32[$288>>2]|0;
  $304 = ((($303)) + 8|0);
  HEAP32[$288>>2] = $304;
 }
 $306 = HEAP32[$39>>2]|0;
 HEAPF32[$4>>2] = $2;
 $307 = ((($4)) + 4|0);
 HEAPF32[$307>>2] = 0.0;
 $308 = ((($4)) + 8|0);
 HEAPF32[$308>>2] = $28;
 $309 = ((($306)) + 80|0);
 $310 = HEAP32[$309>>2]|0;
 $311 = ((($306)) + 84|0);
 $312 = HEAP32[$311>>2]|0;
 $313 = ($310|0)==($312|0);
 if ($313) {
  $316 = ((($306)) + 76|0);
  __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($316,$4);
 } else {
  ;HEAP32[$310>>2]=HEAP32[$4>>2]|0;HEAP32[$310+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$310+8>>2]=HEAP32[$4+8>>2]|0;
  $314 = HEAP32[$309>>2]|0;
  $315 = ((($314)) + 12|0);
  HEAP32[$309>>2] = $315;
 }
 __ZN3osg25BuildShapeGeometryVisitor3EndEv($0);
 STACKTOP = sp;return;
}
function __ZN3osg25BuildShapeGeometryVisitor14drawHalfSphereEjjfNS0_10SphereHalfEf($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = +$3;
 $4 = $4|0;
 $5 = +$5;
 var $$ = 0, $$0195262 = 0.0, $$0196247 = 0, $$0197261 = 0.0, $$0198259 = 0.0, $$0199243 = 0, $$0200$lcssa = 0.0, $$0200242 = 0.0, $$0201$lcssa = 0.0, $$0201241 = 0.0, $$0204256 = 0.0, $$0205252 = 0.0, $$0206251 = 0, $$0266 = 0.0, $$1 = 0.0, $$1202 = 0.0, $$2203245 = 0.0, $$2246 = 0.0, $10 = 0, $100 = 0;
 var $101 = 0, $102 = 0, $103 = 0.0, $104 = 0.0, $105 = 0.0, $106 = 0.0, $107 = 0.0, $108 = 0.0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0.0, $117 = 0.0, $118 = 0, $119 = 0;
 var $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0;
 var $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0.0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0;
 var $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0;
 var $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0.0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0;
 var $192 = 0, $193 = 0, $194 = 0.0, $195 = 0.0, $196 = 0.0, $197 = 0.0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0;
 var $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0.0, $227 = 0.0, $228 = 0;
 var $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0.0, $238 = 0.0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0;
 var $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0;
 var $265 = 0, $266 = 0, $267 = 0.0, $268 = 0.0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0.0, $28 = 0, $280 = 0.0, $281 = 0.0, $282 = 0.0;
 var $283 = 0.0, $284 = 0.0, $285 = 0.0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $30 = 0.0, $300 = 0;
 var $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0.0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0.0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0;
 var $32 = 0.0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0.0, $325 = 0.0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0;
 var $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0.0, $355 = 0;
 var $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0.0, $365 = 0.0, $366 = 0.0, $367 = 0.0, $368 = 0.0, $369 = 0.0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0;
 var $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0;
 var $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0.0, $399 = 0.0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0.0, $41 = 0;
 var $410 = 0.0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0;
 var $429 = 0, $43 = 0.0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0.0, $44 = 0.0, $440 = 0.0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0;
 var $447 = 0, $448 = 0, $449 = 0, $45 = 0.0, $450 = 0, $451 = 0.0, $452 = 0.0, $453 = 0, $454 = 0, $455 = 0, $456 = 0.0, $457 = 0.0, $458 = 0.0, $459 = 0.0, $46 = 0, $460 = 0.0, $461 = 0.0, $47 = 0.0, $48 = 0.0, $49 = 0.0;
 var $50 = 0.0, $51 = 0.0, $52 = 0.0, $53 = 0.0, $54 = 0.0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $exitcond271 = 0, $exitcond272 = 0, $phitmp = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 256|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(256|0);
 $6 = sp + 244|0;
 $7 = sp + 232|0;
 $8 = sp + 56|0;
 $9 = sp + 220|0;
 $10 = sp + 208|0;
 $11 = sp + 48|0;
 $12 = sp + 196|0;
 $13 = sp + 184|0;
 $14 = sp + 40|0;
 $15 = sp + 172|0;
 $16 = sp + 160|0;
 $17 = sp + 32|0;
 $18 = sp + 148|0;
 $19 = sp + 136|0;
 $20 = sp + 24|0;
 $21 = sp + 124|0;
 $22 = sp + 112|0;
 $23 = sp + 16|0;
 $24 = sp + 100|0;
 $25 = sp + 88|0;
 $26 = sp + 8|0;
 $27 = sp + 76|0;
 $28 = sp;
 $29 = sp + 64|0;
 $30 = (+($2>>>0));
 $31 = 3.1415927410125732 / $30;
 $32 = 1.0 / $30;
 $33 = ($4|0)==(0);
 $34 = ((($0)) + 8|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = ($35|0)==(0|0);
 if ($36) {
  $454 = 1;$455 = 0;
 } else {
  $37 = ((($35)) + 44|0);
  $38 = HEAP8[$37>>0]|0;
  $39 = ($38<<24>>24)!=(0);
  $40 = ((($35)) + 45|0);
  $41 = HEAP8[$40>>0]|0;
  $42 = ($41<<24>>24)!=(0);
  $454 = $39;$455 = $42;
 }
 $43 = (+($1>>>0));
 $44 = 6.2831854820251465 / $43;
 $45 = 1.0 / $43;
 $46 = $2 >>> 1;
 $47 = (+($46>>>0));
 $48 = $31 * $47;
 $phitmp = $48 + -1.5707963705062866;
 if ($33) {
  $50 = (+Math_cos((+$phitmp)));
  $51 = $50 * $3;
  $52 = (+Math_sin((+$phitmp)));
  $53 = $52 * $3;
  $54 = $32 * $47;
  $456 = $52;$457 = $53;$458 = $phitmp;$459 = $51;$460 = $54;$461 = $50;
 } else {
  $49 = -$3;
  $456 = -1.0;$457 = $49;$458 = -1.5707963705062866;$459 = 0.0;$460 = 0.0;$461 = 0.0;
 }
 $$ = $33 ? $46 : 0;
 $55 = $33 ? $2 : $46;
 $56 = ($$>>>0)<($55>>>0);
 if (!($56)) {
  STACKTOP = sp;return;
 }
 $57 = ((($0)) + 24|0);
 $58 = ((($0)) + 12|0);
 $59 = ((($0)) + 28|0);
 $60 = ($1|0)==(0);
 $61 = ((($0)) + 16|0);
 $62 = ((($15)) + 4|0);
 $63 = ((($15)) + 8|0);
 $64 = ((($0)) + 20|0);
 $65 = ((($14)) + 4|0);
 $66 = ((($13)) + 4|0);
 $67 = ((($13)) + 8|0);
 $68 = ((($12)) + 4|0);
 $69 = ((($12)) + 8|0);
 $70 = ((($11)) + 4|0);
 $71 = ((($10)) + 4|0);
 $72 = ((($10)) + 8|0);
 $73 = ((($9)) + 4|0);
 $74 = ((($9)) + 8|0);
 $75 = ((($8)) + 4|0);
 $76 = ((($7)) + 4|0);
 $77 = ((($7)) + 8|0);
 $78 = ((($6)) + 4|0);
 $79 = ((($6)) + 8|0);
 $80 = ((($28)) + 4|0);
 $81 = ((($29)) + 4|0);
 $82 = ((($29)) + 8|0);
 $83 = ((($27)) + 4|0);
 $84 = ((($27)) + 8|0);
 $85 = ((($26)) + 4|0);
 $86 = ((($25)) + 4|0);
 $87 = ((($25)) + 8|0);
 $88 = ((($24)) + 4|0);
 $89 = ((($24)) + 8|0);
 $90 = ((($23)) + 4|0);
 $91 = ((($22)) + 4|0);
 $92 = ((($22)) + 8|0);
 $93 = ((($21)) + 4|0);
 $94 = ((($21)) + 8|0);
 $95 = ((($20)) + 4|0);
 $96 = ((($19)) + 4|0);
 $97 = ((($19)) + 8|0);
 $98 = ((($18)) + 4|0);
 $99 = ((($18)) + 8|0);
 $100 = ((($17)) + 4|0);
 $101 = ((($16)) + 4|0);
 $102 = ((($16)) + 8|0);
 $$0195262 = $459;$$0197261 = $457;$$0198259 = $460;$$0204256 = $456;$$0205252 = $461;$$0206251 = $$;$$0266 = $458;
 while(1) {
  $103 = $31 + $$0266;
  $104 = (+Math_cos((+$103)));
  $105 = $104 * $3;
  $106 = (+Math_sin((+$103)));
  $107 = $106 * $3;
  $108 = $32 + $$0198259;
  HEAP32[$57>>2] = 8;
  $109 = HEAP32[$58>>2]|0;
  $110 = ((($109)) + 76|0);
  $111 = ((($109)) + 80|0);
  $112 = HEAP32[$111>>2]|0;
  $113 = HEAP32[$110>>2]|0;
  $114 = (($112) - ($113))|0;
  $115 = (($114|0) / 12)&-1;
  HEAP32[$59>>2] = $115;
  if ($454) {
   if ($60) {
    $$0200$lcssa = 0.0;$$0201$lcssa = 0.0;
   } else {
    $116 = $107 + $5;
    $117 = $$0197261 + $5;
    $$0199243 = 0;$$0200242 = 0.0;$$0201241 = 0.0;
    while(1) {
     $194 = (+Math_cos((+$$0201241)));
     $195 = (+Math_sin((+$$0201241)));
     $196 = $104 * $194;
     $197 = $104 * $195;
     $198 = HEAP32[$61>>2]|0;
     HEAPF32[$21>>2] = $196;
     HEAPF32[$93>>2] = $197;
     HEAPF32[$94>>2] = $106;
     $199 = ((($198)) + 80|0);
     $200 = HEAP32[$199>>2]|0;
     $201 = ((($198)) + 84|0);
     $202 = HEAP32[$201>>2]|0;
     $203 = ($200|0)==($202|0);
     if ($203) {
      $206 = ((($198)) + 76|0);
      __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($206,$21);
     } else {
      ;HEAP32[$200>>2]=HEAP32[$21>>2]|0;HEAP32[$200+4>>2]=HEAP32[$21+4>>2]|0;HEAP32[$200+8>>2]=HEAP32[$21+8>>2]|0;
      $204 = HEAP32[$199>>2]|0;
      $205 = ((($204)) + 12|0);
      HEAP32[$199>>2] = $205;
     }
     $207 = HEAP32[$64>>2]|0;
     HEAPF32[$20>>2] = $$0200242;
     HEAPF32[$95>>2] = $108;
     $208 = ((($207)) + 80|0);
     $209 = HEAP32[$208>>2]|0;
     $210 = ((($207)) + 84|0);
     $211 = HEAP32[$210>>2]|0;
     $212 = ($209|0)==($211|0);
     if ($212) {
      $225 = ((($207)) + 76|0);
      __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($225,$20);
     } else {
      $213 = $20;
      $214 = $213;
      $215 = HEAP32[$214>>2]|0;
      $216 = (($213) + 4)|0;
      $217 = $216;
      $218 = HEAP32[$217>>2]|0;
      $219 = $209;
      $220 = $219;
      HEAP32[$220>>2] = $215;
      $221 = (($219) + 4)|0;
      $222 = $221;
      HEAP32[$222>>2] = $218;
      $223 = HEAP32[$208>>2]|0;
      $224 = ((($223)) + 8|0);
      HEAP32[$208>>2] = $224;
     }
     $226 = $105 * $194;
     $227 = $105 * $195;
     $228 = HEAP32[$58>>2]|0;
     HEAPF32[$19>>2] = $226;
     HEAPF32[$96>>2] = $227;
     HEAPF32[$97>>2] = $116;
     $229 = ((($228)) + 80|0);
     $230 = HEAP32[$229>>2]|0;
     $231 = ((($228)) + 84|0);
     $232 = HEAP32[$231>>2]|0;
     $233 = ($230|0)==($232|0);
     if ($233) {
      $236 = ((($228)) + 76|0);
      __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($236,$19);
     } else {
      ;HEAP32[$230>>2]=HEAP32[$19>>2]|0;HEAP32[$230+4>>2]=HEAP32[$19+4>>2]|0;HEAP32[$230+8>>2]=HEAP32[$19+8>>2]|0;
      $234 = HEAP32[$229>>2]|0;
      $235 = ((($234)) + 12|0);
      HEAP32[$229>>2] = $235;
     }
     $237 = $$0205252 * $194;
     $238 = $$0205252 * $195;
     $239 = HEAP32[$61>>2]|0;
     HEAPF32[$18>>2] = $237;
     HEAPF32[$98>>2] = $238;
     HEAPF32[$99>>2] = $$0204256;
     $240 = ((($239)) + 80|0);
     $241 = HEAP32[$240>>2]|0;
     $242 = ((($239)) + 84|0);
     $243 = HEAP32[$242>>2]|0;
     $244 = ($241|0)==($243|0);
     if ($244) {
      $247 = ((($239)) + 76|0);
      __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($247,$18);
     } else {
      ;HEAP32[$241>>2]=HEAP32[$18>>2]|0;HEAP32[$241+4>>2]=HEAP32[$18+4>>2]|0;HEAP32[$241+8>>2]=HEAP32[$18+8>>2]|0;
      $245 = HEAP32[$240>>2]|0;
      $246 = ((($245)) + 12|0);
      HEAP32[$240>>2] = $246;
     }
     $248 = HEAP32[$64>>2]|0;
     HEAPF32[$17>>2] = $$0200242;
     HEAPF32[$100>>2] = $$0198259;
     $249 = ((($248)) + 80|0);
     $250 = HEAP32[$249>>2]|0;
     $251 = ((($248)) + 84|0);
     $252 = HEAP32[$251>>2]|0;
     $253 = ($250|0)==($252|0);
     if ($253) {
      $266 = ((($248)) + 76|0);
      __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($266,$17);
     } else {
      $254 = $17;
      $255 = $254;
      $256 = HEAP32[$255>>2]|0;
      $257 = (($254) + 4)|0;
      $258 = $257;
      $259 = HEAP32[$258>>2]|0;
      $260 = $250;
      $261 = $260;
      HEAP32[$261>>2] = $256;
      $262 = (($260) + 4)|0;
      $263 = $262;
      HEAP32[$263>>2] = $259;
      $264 = HEAP32[$249>>2]|0;
      $265 = ((($264)) + 8|0);
      HEAP32[$249>>2] = $265;
     }
     $267 = $$0195262 * $194;
     $268 = $$0195262 * $195;
     $269 = HEAP32[$58>>2]|0;
     HEAPF32[$16>>2] = $267;
     HEAPF32[$101>>2] = $268;
     HEAPF32[$102>>2] = $117;
     $270 = ((($269)) + 80|0);
     $271 = HEAP32[$270>>2]|0;
     $272 = ((($269)) + 84|0);
     $273 = HEAP32[$272>>2]|0;
     $274 = ($271|0)==($273|0);
     if ($274) {
      $277 = ((($269)) + 76|0);
      __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($277,$16);
     } else {
      ;HEAP32[$271>>2]=HEAP32[$16>>2]|0;HEAP32[$271+4>>2]=HEAP32[$16+4>>2]|0;HEAP32[$271+8>>2]=HEAP32[$16+8>>2]|0;
      $275 = HEAP32[$270>>2]|0;
      $276 = ((($275)) + 12|0);
      HEAP32[$270>>2] = $276;
     }
     $278 = (($$0199243) + 1)|0;
     $279 = $44 + $$0201241;
     $280 = $45 + $$0200242;
     $exitcond = ($278|0)==($1|0);
     if ($exitcond) {
      $$0200$lcssa = $280;$$0201$lcssa = $279;
      break;
     } else {
      $$0199243 = $278;$$0200242 = $280;$$0201241 = $279;
     }
    }
   }
   $118 = HEAP32[$61>>2]|0;
   HEAPF32[$27>>2] = $104;
   HEAPF32[$83>>2] = 0.0;
   HEAPF32[$84>>2] = $106;
   $119 = ((($118)) + 80|0);
   $120 = HEAP32[$119>>2]|0;
   $121 = ((($118)) + 84|0);
   $122 = HEAP32[$121>>2]|0;
   $123 = ($120|0)==($122|0);
   if ($123) {
    $126 = ((($118)) + 76|0);
    __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($126,$27);
   } else {
    ;HEAP32[$120>>2]=HEAP32[$27>>2]|0;HEAP32[$120+4>>2]=HEAP32[$27+4>>2]|0;HEAP32[$120+8>>2]=HEAP32[$27+8>>2]|0;
    $124 = HEAP32[$119>>2]|0;
    $125 = ((($124)) + 12|0);
    HEAP32[$119>>2] = $125;
   }
   $127 = HEAP32[$64>>2]|0;
   HEAPF32[$26>>2] = 1.0;
   HEAPF32[$85>>2] = $108;
   $128 = ((($127)) + 80|0);
   $129 = HEAP32[$128>>2]|0;
   $130 = ((($127)) + 84|0);
   $131 = HEAP32[$130>>2]|0;
   $132 = ($129|0)==($131|0);
   if ($132) {
    $145 = ((($127)) + 76|0);
    __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($145,$26);
   } else {
    $133 = $26;
    $134 = $133;
    $135 = HEAP32[$134>>2]|0;
    $136 = (($133) + 4)|0;
    $137 = $136;
    $138 = HEAP32[$137>>2]|0;
    $139 = $129;
    $140 = $139;
    HEAP32[$140>>2] = $135;
    $141 = (($139) + 4)|0;
    $142 = $141;
    HEAP32[$142>>2] = $138;
    $143 = HEAP32[$128>>2]|0;
    $144 = ((($143)) + 8|0);
    HEAP32[$128>>2] = $144;
   }
   $146 = $107 + $5;
   $147 = HEAP32[$58>>2]|0;
   HEAPF32[$25>>2] = $105;
   HEAPF32[$86>>2] = 0.0;
   HEAPF32[$87>>2] = $146;
   $148 = ((($147)) + 80|0);
   $149 = HEAP32[$148>>2]|0;
   $150 = ((($147)) + 84|0);
   $151 = HEAP32[$150>>2]|0;
   $152 = ($149|0)==($151|0);
   if ($152) {
    $155 = ((($147)) + 76|0);
    __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($155,$25);
   } else {
    ;HEAP32[$149>>2]=HEAP32[$25>>2]|0;HEAP32[$149+4>>2]=HEAP32[$25+4>>2]|0;HEAP32[$149+8>>2]=HEAP32[$25+8>>2]|0;
    $153 = HEAP32[$148>>2]|0;
    $154 = ((($153)) + 12|0);
    HEAP32[$148>>2] = $154;
   }
   $156 = HEAP32[$61>>2]|0;
   HEAPF32[$24>>2] = $$0205252;
   HEAPF32[$88>>2] = 0.0;
   HEAPF32[$89>>2] = $$0204256;
   $157 = ((($156)) + 80|0);
   $158 = HEAP32[$157>>2]|0;
   $159 = ((($156)) + 84|0);
   $160 = HEAP32[$159>>2]|0;
   $161 = ($158|0)==($160|0);
   if ($161) {
    $164 = ((($156)) + 76|0);
    __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($164,$24);
   } else {
    ;HEAP32[$158>>2]=HEAP32[$24>>2]|0;HEAP32[$158+4>>2]=HEAP32[$24+4>>2]|0;HEAP32[$158+8>>2]=HEAP32[$24+8>>2]|0;
    $162 = HEAP32[$157>>2]|0;
    $163 = ((($162)) + 12|0);
    HEAP32[$157>>2] = $163;
   }
   $165 = HEAP32[$64>>2]|0;
   HEAPF32[$23>>2] = 1.0;
   HEAPF32[$90>>2] = $$0198259;
   $166 = ((($165)) + 80|0);
   $167 = HEAP32[$166>>2]|0;
   $168 = ((($165)) + 84|0);
   $169 = HEAP32[$168>>2]|0;
   $170 = ($167|0)==($169|0);
   if ($170) {
    $183 = ((($165)) + 76|0);
    __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($183,$23);
   } else {
    $171 = $23;
    $172 = $171;
    $173 = HEAP32[$172>>2]|0;
    $174 = (($171) + 4)|0;
    $175 = $174;
    $176 = HEAP32[$175>>2]|0;
    $177 = $167;
    $178 = $177;
    HEAP32[$178>>2] = $173;
    $179 = (($177) + 4)|0;
    $180 = $179;
    HEAP32[$180>>2] = $176;
    $181 = HEAP32[$166>>2]|0;
    $182 = ((($181)) + 8|0);
    HEAP32[$166>>2] = $182;
   }
   $184 = $$0197261 + $5;
   $185 = HEAP32[$58>>2]|0;
   HEAPF32[$22>>2] = $$0195262;
   HEAPF32[$91>>2] = 0.0;
   HEAPF32[$92>>2] = $184;
   $186 = ((($185)) + 80|0);
   $187 = HEAP32[$186>>2]|0;
   $188 = ((($185)) + 84|0);
   $189 = HEAP32[$188>>2]|0;
   $190 = ($187|0)==($189|0);
   if ($190) {
    $193 = ((($185)) + 76|0);
    __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($193,$22);
   } else {
    ;HEAP32[$187>>2]=HEAP32[$22>>2]|0;HEAP32[$187+4>>2]=HEAP32[$22+4>>2]|0;HEAP32[$187+8>>2]=HEAP32[$22+8>>2]|0;
    $191 = HEAP32[$186>>2]|0;
    $192 = ((($191)) + 12|0);
    HEAP32[$186>>2] = $192;
   }
   $$1 = $$0200$lcssa;$$1202 = $$0201$lcssa;
  } else {
   $$1 = 0.0;$$1202 = 0.0;
  }
  if ($455) {
   $281 = -$$0204256;
   if (!($60)) {
    $282 = $$0197261 + $5;
    $283 = -$106;
    $284 = $107 + $5;
    $$0196247 = 0;$$2203245 = $$1202;$$2246 = $$1;
    while(1) {
     $364 = (+Math_cos((+$$2203245)));
     $365 = (+Math_sin((+$$2203245)));
     $366 = -$364;
     $367 = $$0205252 * $366;
     $368 = -$365;
     $369 = $$0205252 * $368;
     $370 = HEAP32[$61>>2]|0;
     HEAPF32[$9>>2] = $367;
     HEAPF32[$73>>2] = $369;
     HEAPF32[$74>>2] = $281;
     $371 = ((($370)) + 80|0);
     $372 = HEAP32[$371>>2]|0;
     $373 = ((($370)) + 84|0);
     $374 = HEAP32[$373>>2]|0;
     $375 = ($372|0)==($374|0);
     if ($375) {
      $378 = ((($370)) + 76|0);
      __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($378,$9);
     } else {
      ;HEAP32[$372>>2]=HEAP32[$9>>2]|0;HEAP32[$372+4>>2]=HEAP32[$9+4>>2]|0;HEAP32[$372+8>>2]=HEAP32[$9+8>>2]|0;
      $376 = HEAP32[$371>>2]|0;
      $377 = ((($376)) + 12|0);
      HEAP32[$371>>2] = $377;
     }
     $379 = HEAP32[$64>>2]|0;
     HEAPF32[$8>>2] = $$2246;
     HEAPF32[$75>>2] = $$0198259;
     $380 = ((($379)) + 80|0);
     $381 = HEAP32[$380>>2]|0;
     $382 = ((($379)) + 84|0);
     $383 = HEAP32[$382>>2]|0;
     $384 = ($381|0)==($383|0);
     if ($384) {
      $397 = ((($379)) + 76|0);
      __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($397,$8);
     } else {
      $385 = $8;
      $386 = $385;
      $387 = HEAP32[$386>>2]|0;
      $388 = (($385) + 4)|0;
      $389 = $388;
      $390 = HEAP32[$389>>2]|0;
      $391 = $381;
      $392 = $391;
      HEAP32[$392>>2] = $387;
      $393 = (($391) + 4)|0;
      $394 = $393;
      HEAP32[$394>>2] = $390;
      $395 = HEAP32[$380>>2]|0;
      $396 = ((($395)) + 8|0);
      HEAP32[$380>>2] = $396;
     }
     $398 = $$0195262 * $364;
     $399 = $$0195262 * $365;
     $400 = HEAP32[$58>>2]|0;
     HEAPF32[$7>>2] = $398;
     HEAPF32[$76>>2] = $399;
     HEAPF32[$77>>2] = $282;
     $401 = ((($400)) + 80|0);
     $402 = HEAP32[$401>>2]|0;
     $403 = ((($400)) + 84|0);
     $404 = HEAP32[$403>>2]|0;
     $405 = ($402|0)==($404|0);
     if ($405) {
      $408 = ((($400)) + 76|0);
      __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($408,$7);
     } else {
      ;HEAP32[$402>>2]=HEAP32[$7>>2]|0;HEAP32[$402+4>>2]=HEAP32[$7+4>>2]|0;HEAP32[$402+8>>2]=HEAP32[$7+8>>2]|0;
      $406 = HEAP32[$401>>2]|0;
      $407 = ((($406)) + 12|0);
      HEAP32[$401>>2] = $407;
     }
     $409 = $104 * $366;
     $410 = $104 * $368;
     $411 = HEAP32[$61>>2]|0;
     HEAPF32[$6>>2] = $409;
     HEAPF32[$78>>2] = $410;
     HEAPF32[$79>>2] = $283;
     $412 = ((($411)) + 80|0);
     $413 = HEAP32[$412>>2]|0;
     $414 = ((($411)) + 84|0);
     $415 = HEAP32[$414>>2]|0;
     $416 = ($413|0)==($415|0);
     if ($416) {
      $419 = ((($411)) + 76|0);
      __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($419,$6);
     } else {
      ;HEAP32[$413>>2]=HEAP32[$6>>2]|0;HEAP32[$413+4>>2]=HEAP32[$6+4>>2]|0;HEAP32[$413+8>>2]=HEAP32[$6+8>>2]|0;
      $417 = HEAP32[$412>>2]|0;
      $418 = ((($417)) + 12|0);
      HEAP32[$412>>2] = $418;
     }
     $420 = HEAP32[$64>>2]|0;
     HEAPF32[$28>>2] = $$2246;
     HEAPF32[$80>>2] = $108;
     $421 = ((($420)) + 80|0);
     $422 = HEAP32[$421>>2]|0;
     $423 = ((($420)) + 84|0);
     $424 = HEAP32[$423>>2]|0;
     $425 = ($422|0)==($424|0);
     if ($425) {
      $438 = ((($420)) + 76|0);
      __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($438,$28);
     } else {
      $426 = $28;
      $427 = $426;
      $428 = HEAP32[$427>>2]|0;
      $429 = (($426) + 4)|0;
      $430 = $429;
      $431 = HEAP32[$430>>2]|0;
      $432 = $422;
      $433 = $432;
      HEAP32[$433>>2] = $428;
      $434 = (($432) + 4)|0;
      $435 = $434;
      HEAP32[$435>>2] = $431;
      $436 = HEAP32[$421>>2]|0;
      $437 = ((($436)) + 8|0);
      HEAP32[$421>>2] = $437;
     }
     $439 = $105 * $364;
     $440 = $105 * $365;
     $441 = HEAP32[$58>>2]|0;
     HEAPF32[$29>>2] = $439;
     HEAPF32[$81>>2] = $440;
     HEAPF32[$82>>2] = $284;
     $442 = ((($441)) + 80|0);
     $443 = HEAP32[$442>>2]|0;
     $444 = ((($441)) + 84|0);
     $445 = HEAP32[$444>>2]|0;
     $446 = ($443|0)==($445|0);
     if ($446) {
      $449 = ((($441)) + 76|0);
      __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($449,$29);
     } else {
      ;HEAP32[$443>>2]=HEAP32[$29>>2]|0;HEAP32[$443+4>>2]=HEAP32[$29+4>>2]|0;HEAP32[$443+8>>2]=HEAP32[$29+8>>2]|0;
      $447 = HEAP32[$442>>2]|0;
      $448 = ((($447)) + 12|0);
      HEAP32[$442>>2] = $448;
     }
     $450 = (($$0196247) + 1)|0;
     $451 = $44 + $$2203245;
     $452 = $45 + $$2246;
     $exitcond271 = ($450|0)==($1|0);
     if ($exitcond271) {
      break;
     } else {
      $$0196247 = $450;$$2203245 = $451;$$2246 = $452;
     }
    }
   }
   $285 = -$$0205252;
   $286 = HEAP32[$61>>2]|0;
   HEAPF32[$15>>2] = $285;
   HEAPF32[$62>>2] = 0.0;
   HEAPF32[$63>>2] = $281;
   $287 = ((($286)) + 80|0);
   $288 = HEAP32[$287>>2]|0;
   $289 = ((($286)) + 84|0);
   $290 = HEAP32[$289>>2]|0;
   $291 = ($288|0)==($290|0);
   if ($291) {
    $294 = ((($286)) + 76|0);
    __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($294,$15);
   } else {
    ;HEAP32[$288>>2]=HEAP32[$15>>2]|0;HEAP32[$288+4>>2]=HEAP32[$15+4>>2]|0;HEAP32[$288+8>>2]=HEAP32[$15+8>>2]|0;
    $292 = HEAP32[$287>>2]|0;
    $293 = ((($292)) + 12|0);
    HEAP32[$287>>2] = $293;
   }
   $295 = HEAP32[$64>>2]|0;
   HEAPF32[$14>>2] = 1.0;
   HEAPF32[$65>>2] = $$0198259;
   $296 = ((($295)) + 80|0);
   $297 = HEAP32[$296>>2]|0;
   $298 = ((($295)) + 84|0);
   $299 = HEAP32[$298>>2]|0;
   $300 = ($297|0)==($299|0);
   if ($300) {
    $313 = ((($295)) + 76|0);
    __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($313,$14);
   } else {
    $301 = $14;
    $302 = $301;
    $303 = HEAP32[$302>>2]|0;
    $304 = (($301) + 4)|0;
    $305 = $304;
    $306 = HEAP32[$305>>2]|0;
    $307 = $297;
    $308 = $307;
    HEAP32[$308>>2] = $303;
    $309 = (($307) + 4)|0;
    $310 = $309;
    HEAP32[$310>>2] = $306;
    $311 = HEAP32[$296>>2]|0;
    $312 = ((($311)) + 8|0);
    HEAP32[$296>>2] = $312;
   }
   $314 = $$0197261 + $5;
   $315 = HEAP32[$58>>2]|0;
   HEAPF32[$13>>2] = $$0195262;
   HEAPF32[$66>>2] = 0.0;
   HEAPF32[$67>>2] = $314;
   $316 = ((($315)) + 80|0);
   $317 = HEAP32[$316>>2]|0;
   $318 = ((($315)) + 84|0);
   $319 = HEAP32[$318>>2]|0;
   $320 = ($317|0)==($319|0);
   if ($320) {
    $323 = ((($315)) + 76|0);
    __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($323,$13);
   } else {
    ;HEAP32[$317>>2]=HEAP32[$13>>2]|0;HEAP32[$317+4>>2]=HEAP32[$13+4>>2]|0;HEAP32[$317+8>>2]=HEAP32[$13+8>>2]|0;
    $321 = HEAP32[$316>>2]|0;
    $322 = ((($321)) + 12|0);
    HEAP32[$316>>2] = $322;
   }
   $324 = -$104;
   $325 = -$106;
   $326 = HEAP32[$61>>2]|0;
   HEAPF32[$12>>2] = $324;
   HEAPF32[$68>>2] = 0.0;
   HEAPF32[$69>>2] = $325;
   $327 = ((($326)) + 80|0);
   $328 = HEAP32[$327>>2]|0;
   $329 = ((($326)) + 84|0);
   $330 = HEAP32[$329>>2]|0;
   $331 = ($328|0)==($330|0);
   if ($331) {
    $334 = ((($326)) + 76|0);
    __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($334,$12);
   } else {
    ;HEAP32[$328>>2]=HEAP32[$12>>2]|0;HEAP32[$328+4>>2]=HEAP32[$12+4>>2]|0;HEAP32[$328+8>>2]=HEAP32[$12+8>>2]|0;
    $332 = HEAP32[$327>>2]|0;
    $333 = ((($332)) + 12|0);
    HEAP32[$327>>2] = $333;
   }
   $335 = HEAP32[$64>>2]|0;
   HEAPF32[$11>>2] = 1.0;
   HEAPF32[$70>>2] = $108;
   $336 = ((($335)) + 80|0);
   $337 = HEAP32[$336>>2]|0;
   $338 = ((($335)) + 84|0);
   $339 = HEAP32[$338>>2]|0;
   $340 = ($337|0)==($339|0);
   if ($340) {
    $353 = ((($335)) + 76|0);
    __ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($353,$11);
   } else {
    $341 = $11;
    $342 = $341;
    $343 = HEAP32[$342>>2]|0;
    $344 = (($341) + 4)|0;
    $345 = $344;
    $346 = HEAP32[$345>>2]|0;
    $347 = $337;
    $348 = $347;
    HEAP32[$348>>2] = $343;
    $349 = (($347) + 4)|0;
    $350 = $349;
    HEAP32[$350>>2] = $346;
    $351 = HEAP32[$336>>2]|0;
    $352 = ((($351)) + 8|0);
    HEAP32[$336>>2] = $352;
   }
   $354 = $107 + $5;
   $355 = HEAP32[$58>>2]|0;
   HEAPF32[$10>>2] = $105;
   HEAPF32[$71>>2] = 0.0;
   HEAPF32[$72>>2] = $354;
   $356 = ((($355)) + 80|0);
   $357 = HEAP32[$356>>2]|0;
   $358 = ((($355)) + 84|0);
   $359 = HEAP32[$358>>2]|0;
   $360 = ($357|0)==($359|0);
   if ($360) {
    $363 = ((($355)) + 76|0);
    __ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($363,$10);
   } else {
    ;HEAP32[$357>>2]=HEAP32[$10>>2]|0;HEAP32[$357+4>>2]=HEAP32[$10+4>>2]|0;HEAP32[$357+8>>2]=HEAP32[$10+8>>2]|0;
    $361 = HEAP32[$356>>2]|0;
    $362 = ((($361)) + 12|0);
    HEAP32[$356>>2] = $362;
   }
  }
  __ZN3osg25BuildShapeGeometryVisitor3EndEv($0);
  $453 = (($$0206251) + 1)|0;
  $exitcond272 = ($453|0)==($55|0);
  if ($exitcond272) {
   break;
  } else {
   $$0195262 = $105;$$0197261 = $107;$$0198259 = $108;$$0204256 = $106;$$0205252 = $104;$$0206251 = $453;$$0266 = $103;
  }
 }
 STACKTOP = sp;return;
}
function __ZN3osg5ShapeD2Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg6ObjectD2Ev($0);
 return;
}
function __ZN3osg5ShapeD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(388,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK3osg5Shape12isSameKindAsEPKNS_6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,26560,0)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK3osg5Shape11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175113|0);
}
function __ZNK3osg5Shape9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (148460|0);
}
function __ZN3osg6SphereD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(388,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK3osg6Sphere9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(48)|0);
 __THREW__ = 0;
 invoke_vi(3282,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $11 = ___cxa_find_matching_catch_2()|0;
  $12 = tempRet0;
  __ZdlPv($1);
  ___resumeException($11|0);
  // unreachable;
 } else {
  $4 = ((($1)) + 12|0);
  ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;
  $5 = ((($1)) + 24|0);
  HEAP32[$5>>2] = 2;
  $6 = ((($1)) + 28|0);
  HEAP32[$6>>2] = 0;
  HEAP32[$1>>2] = (66016);
  $7 = ((($1)) + 32|0);
  HEAPF32[$7>>2] = 0.0;
  $8 = ((($1)) + 36|0);
  HEAPF32[$8>>2] = 0.0;
  $9 = ((($1)) + 40|0);
  HEAPF32[$9>>2] = 0.0;
  $10 = ((($1)) + 44|0);
  HEAPF32[$10>>2] = 1.0;
  return ($1|0);
 }
 return (0)|0;
}
function __ZNK3osg6Sphere5cloneERKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(48)|0);
 __THREW__ = 0;
 invoke_viii(3468,($2|0),($0|0),($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $10 = ___cxa_find_matching_catch_2()|0;
  $11 = tempRet0;
  __ZdlPv($2);
  ___resumeException($10|0);
  // unreachable;
 } else {
  HEAP32[$2>>2] = (66016);
  $5 = ((($2)) + 32|0);
  $6 = ((($0)) + 32|0);
  ;HEAP32[$5>>2]=HEAP32[$6>>2]|0;HEAP32[$5+4>>2]=HEAP32[$6+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$6+8>>2]|0;
  $7 = ((($2)) + 44|0);
  $8 = ((($0)) + 44|0);
  $9 = HEAP32[$8>>2]|0;
  HEAP32[$7>>2] = $9;
  return ($2|0);
 }
 return (0)|0;
}
function __ZNK3osg6Sphere12isSameKindAsEPKNS_6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,26616,0)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK3osg6Sphere11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175113|0);
}
function __ZNK3osg6Sphere9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (148466|0);
}
function __ZN3osg6Sphere6acceptERNS_12ShapeVisitorE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 8191]($1,$0);
 return;
}
function __ZNK3osg6Sphere6acceptERNS_17ConstShapeVisitorE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 8191]($1,$0);
 return;
}
function __ZN3osg25BuildShapeGeometryVisitorC2EPNS_8GeometryEPKNS_17TessellationHintsE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$off0 = 0, $$1$off0 = 0, $$3 = 0, $$314 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0;
 var $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0;
 var $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0;
 var $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0;
 var $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0;
 var $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0;
 var $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 HEAP32[$0>>2] = (65800);
 $4 = ((($0)) + 4|0);
 HEAP32[$4>>2] = $1;
 $5 = ((($0)) + 8|0);
 HEAP32[$5>>2] = $2;
 $6 = ((($0)) + 12|0);
 HEAP32[$6>>2] = 0;
 $7 = ((($0)) + 16|0);
 HEAP32[$7>>2] = 0;
 $8 = ((($0)) + 20|0);
 HEAP32[$8>>2] = 0;
 $9 = ((($0)) + 32|0);
 __THREW__ = 0;
 invoke_vi(3299,($9|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 L1: do {
  if ($11) {
   $19 = ___cxa_find_matching_catch_2()|0;
   $20 = tempRet0;
   $$3 = $20;$$314 = $19;
  } else {
   $12 = ((($0)) + 160|0);
   __THREW__ = 0;
   invoke_vi(3299,($12|0));
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if ($14) {
    $21 = ___cxa_find_matching_catch_2()|0;
    $22 = tempRet0;
    $$3 = $22;$$314 = $21;
    break;
   }
   $15 = ((($1)) + 228|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ($16|0)==(0|0);
   if ($17) {
    $27 = 0;
   } else {
    $18 = (___dynamic_cast($16,23016,5496,0)|0);
    $27 = $18;
   }
   $25 = HEAP32[$6>>2]|0;
   $26 = ($25|0)==($27|0);
   if ($26) {
    label = 14;
   } else {
    HEAP32[$6>>2] = $27;
    $28 = ($27|0)==(0|0);
    if (!($28)) {
     $29 = ((($27)) + 8|0);
     $30 = HEAP32[$29>>2]|0;HEAP32[$29>>2] = (($30+1)|0);
    }
    $31 = ($25|0)==(0|0);
    if ($31) {
     label = 14;
    } else {
     $32 = ((($25)) + 8|0);
     $33 = HEAP32[$32>>2]|0;HEAP32[$32>>2] = (($33-1)|0);
     $34 = ($33|0)==(1);
     if ($34) {
      __THREW__ = 0;
      invoke_viii(3262,($25|0),1,1);
      $35 = __THREW__; __THREW__ = 0;
      $36 = $35&1;
      if (!($36)) {
       label = 14;
      }
     } else {
      label = 14;
     }
    }
   }
   do {
    if ((label|0) == 14) {
     $37 = ((($1)) + 232|0);
     $38 = HEAP32[$37>>2]|0;
     $39 = ($38|0)==(0|0);
     if ($39) {
      $43 = 0;
     } else {
      $40 = (___dynamic_cast($38,23016,5496,0)|0);
      $43 = $40;
     }
     $41 = HEAP32[$7>>2]|0;
     $42 = ($41|0)==($43|0);
     if (!($42)) {
      HEAP32[$7>>2] = $43;
      $44 = ($43|0)==(0|0);
      if (!($44)) {
       $45 = ((($43)) + 8|0);
       $46 = HEAP32[$45>>2]|0;HEAP32[$45>>2] = (($46+1)|0);
      }
      $47 = ($41|0)==(0|0);
      if (!($47)) {
       $48 = ((($41)) + 8|0);
       $49 = HEAP32[$48>>2]|0;HEAP32[$48>>2] = (($49-1)|0);
       $50 = ($49|0)==(1);
       if ($50) {
        __THREW__ = 0;
        invoke_viii(3262,($41|0),1,1);
        $51 = __THREW__; __THREW__ = 0;
        $52 = $51&1;
        if ($52) {
         break;
        }
       }
      }
     }
     __THREW__ = 0;
     $53 = (invoke_iii(3912,($1|0),0)|0);
     $54 = __THREW__; __THREW__ = 0;
     $55 = $54&1;
     if (!($55)) {
      $56 = ($53|0)==(0|0);
      if ($56) {
       $60 = 0;
      } else {
       $57 = (___dynamic_cast($53,23016,5456,0)|0);
       $60 = $57;
      }
      $58 = HEAP32[$8>>2]|0;
      $59 = ($58|0)==($60|0);
      if (!($59)) {
       HEAP32[$8>>2] = $60;
       $61 = ($60|0)==(0|0);
       if (!($61)) {
        $62 = ((($60)) + 8|0);
        $63 = HEAP32[$62>>2]|0;HEAP32[$62>>2] = (($63+1)|0);
       }
       $64 = ($58|0)==(0|0);
       if (!($64)) {
        $65 = ((($58)) + 8|0);
        $66 = HEAP32[$65>>2]|0;HEAP32[$65>>2] = (($66-1)|0);
        $67 = ($66|0)==(1);
        if ($67) {
         __THREW__ = 0;
         invoke_viii(3262,($58|0),1,1);
         $68 = __THREW__; __THREW__ = 0;
         $69 = $68&1;
         if ($69) {
          break;
         }
        }
       }
      }
      $70 = HEAP32[$6>>2]|0;
      $71 = ($70|0)==(0|0);
      if ($71) {
       label = 33;
      } else {
       $72 = ((($70)) + 64|0);
       $73 = HEAP32[$72>>2]|0;
       $74 = ($73|0)==(4);
       if ($74) {
        $$0$off0 = 0;
        label = 43;
       } else {
        label = 33;
       }
      }
      do {
       if ((label|0) == 33) {
        __THREW__ = 0;
        $75 = (invoke_ii(3276,88)|0);
        $76 = __THREW__; __THREW__ = 0;
        $77 = $76&1;
        if ($77) {
         label = 40;
        } else {
         __THREW__ = 0;
         invoke_vii(3435,($75|0),1);
         $78 = __THREW__; __THREW__ = 0;
         $79 = $78&1;
         if ($79) {
          $109 = ___cxa_find_matching_catch_2()|0;
          $110 = tempRet0;
          __ZdlPv($75);
          $$3 = $110;$$314 = $109;
          break L1;
         }
         $80 = ((($75)) + 12|0);
         ;HEAP32[$80>>2]=0|0;HEAP32[$80+4>>2]=0|0;HEAP32[$80+8>>2]=0|0;
         $81 = ((($75)) + 24|0);
         HEAP32[$81>>2] = 2;
         $82 = ((($75)) + 28|0);
         ;HEAP32[$82>>2]=0|0;HEAP32[$82+4>>2]=0|0;HEAP32[$82+8>>2]=0|0;HEAP32[$82+12>>2]=0|0;HEAP32[$82+16>>2]=0|0;HEAP32[$82+20>>2]=0|0;
         $83 = ((($75)) + 52|0);
         HEAP32[$83>>2] = 28;
         $84 = ((($75)) + 56|0);
         HEAP32[$84>>2] = 3;
         $85 = ((($75)) + 60|0);
         HEAP32[$85>>2] = 5126;
         $86 = ((($75)) + 64|0);
         HEAP32[$86>>2] = 4;
         $87 = ((($75)) + 68|0);
         HEAP8[$87>>0] = 0;
         $88 = ((($75)) + 69|0);
         HEAP8[$88>>0] = 0;
         $89 = ((($75)) + 72|0);
         $90 = ((($75)) + 76|0);
         HEAP32[$90>>2] = 0;
         $91 = ((($75)) + 80|0);
         HEAP32[$91>>2] = 0;
         $92 = ((($75)) + 84|0);
         HEAP32[$92>>2] = 0;
         HEAP32[$75>>2] = (37800);
         HEAP32[$89>>2] = (38024);
         $93 = HEAP32[$6>>2]|0;
         $94 = ($93|0)==($75|0);
         if (!($94)) {
          HEAP32[$6>>2] = $75;
          $95 = ((($75)) + 8|0);
          $96 = HEAP32[$95>>2]|0;HEAP32[$95>>2] = (($96+1)|0);
          $97 = ($93|0)==(0|0);
          if (!($97)) {
           $98 = ((($93)) + 8|0);
           $99 = HEAP32[$98>>2]|0;HEAP32[$98>>2] = (($99-1)|0);
           $100 = ($99|0)==(1);
           if ($100) {
            __THREW__ = 0;
            invoke_viii(3262,($93|0),1,1);
            $101 = __THREW__; __THREW__ = 0;
            $102 = $101&1;
            if ($102) {
             label = 40;
             break;
            }
           }
          }
         }
         $103 = HEAP32[$4>>2]|0;
         $104 = HEAP32[$6>>2]|0;
         __THREW__ = 0;
         invoke_vii(3490,($103|0),($104|0));
         $105 = __THREW__; __THREW__ = 0;
         $106 = $105&1;
         if ($106) {
          label = 40;
         } else {
          $$0$off0 = 1;
          label = 43;
         }
        }
       }
      } while(0);
      L55: do {
       if ((label|0) == 43) {
        $111 = HEAP32[$7>>2]|0;
        $112 = ($111|0)==(0|0);
        if ($112) {
         label = 46;
        } else {
         $113 = ((($111)) + 64|0);
         $114 = HEAP32[$113>>2]|0;
         $115 = ($114|0)==(4);
         if ($115) {
          $116 = HEAP32[$6>>2]|0;
          $117 = ((($116)) + 76|0);
          $118 = ((($116)) + 80|0);
          $119 = HEAP32[$118>>2]|0;
          $120 = HEAP32[$117>>2]|0;
          $121 = (($119) - ($120))|0;
          $122 = ((($111)) + 76|0);
          $123 = ((($111)) + 80|0);
          $124 = HEAP32[$123>>2]|0;
          $125 = HEAP32[$122>>2]|0;
          $126 = (($124) - ($125))|0;
          $127 = ($121|0)==($126|0);
          if ($127) {
           $$1$off0 = $$0$off0;
          } else {
           label = 46;
          }
         } else {
          label = 46;
         }
        }
        if ((label|0) == 46) {
         __THREW__ = 0;
         $128 = (invoke_ii(3276,88)|0);
         $129 = __THREW__; __THREW__ = 0;
         $130 = $129&1;
         if ($130) {
          label = 40;
          break;
         }
         __THREW__ = 0;
         invoke_vii(3435,($128|0),1);
         $131 = __THREW__; __THREW__ = 0;
         $132 = $131&1;
         if ($132) {
          $160 = ___cxa_find_matching_catch_2()|0;
          $161 = tempRet0;
          __ZdlPv($128);
          $$3 = $161;$$314 = $160;
          break L1;
         }
         $133 = ((($128)) + 12|0);
         ;HEAP32[$133>>2]=0|0;HEAP32[$133+4>>2]=0|0;HEAP32[$133+8>>2]=0|0;
         $134 = ((($128)) + 24|0);
         HEAP32[$134>>2] = 2;
         $135 = ((($128)) + 28|0);
         ;HEAP32[$135>>2]=0|0;HEAP32[$135+4>>2]=0|0;HEAP32[$135+8>>2]=0|0;HEAP32[$135+12>>2]=0|0;HEAP32[$135+16>>2]=0|0;HEAP32[$135+20>>2]=0|0;
         $136 = ((($128)) + 52|0);
         HEAP32[$136>>2] = 28;
         $137 = ((($128)) + 56|0);
         HEAP32[$137>>2] = 3;
         $138 = ((($128)) + 60|0);
         HEAP32[$138>>2] = 5126;
         $139 = ((($128)) + 64|0);
         HEAP32[$139>>2] = 4;
         $140 = ((($128)) + 68|0);
         HEAP8[$140>>0] = 0;
         $141 = ((($128)) + 69|0);
         HEAP8[$141>>0] = 0;
         $142 = ((($128)) + 72|0);
         $143 = ((($128)) + 76|0);
         HEAP32[$143>>2] = 0;
         $144 = ((($128)) + 80|0);
         HEAP32[$144>>2] = 0;
         $145 = ((($128)) + 84|0);
         HEAP32[$145>>2] = 0;
         HEAP32[$128>>2] = (37800);
         HEAP32[$142>>2] = (38024);
         $146 = HEAP32[$7>>2]|0;
         $147 = ($146|0)==($128|0);
         do {
          if (!($147)) {
           HEAP32[$7>>2] = $128;
           $148 = ((($128)) + 8|0);
           $149 = HEAP32[$148>>2]|0;HEAP32[$148>>2] = (($149+1)|0);
           $150 = ($146|0)==(0|0);
           if (!($150)) {
            $151 = ((($146)) + 8|0);
            $152 = HEAP32[$151>>2]|0;HEAP32[$151>>2] = (($152-1)|0);
            $153 = ($152|0)==(1);
            if (!($153)) {
             break;
            }
            __THREW__ = 0;
            invoke_viii(3262,($146|0),1,1);
            $154 = __THREW__; __THREW__ = 0;
            $155 = $154&1;
            if ($155) {
             label = 40;
             break L55;
            }
           }
          }
         } while(0);
         $156 = HEAP32[$4>>2]|0;
         $157 = HEAP32[$7>>2]|0;
         __THREW__ = 0;
         invoke_viii(3913,($156|0),($157|0),-1);
         $158 = __THREW__; __THREW__ = 0;
         $159 = $158&1;
         if ($159) {
          label = 40;
          break;
         } else {
          $$1$off0 = 1;
         }
        }
        $162 = HEAP32[$8>>2]|0;
        $163 = ($162|0)==(0|0);
        if ($163) {
         label = 57;
        } else {
         $164 = ((($162)) + 64|0);
         $165 = HEAP32[$164>>2]|0;
         $166 = ($165|0)==(4);
         if ($166) {
          $167 = HEAP32[$6>>2]|0;
          $168 = ((($167)) + 76|0);
          $169 = ((($167)) + 80|0);
          $170 = HEAP32[$169>>2]|0;
          $171 = HEAP32[$168>>2]|0;
          $172 = (($170) - ($171))|0;
          $173 = (($172|0) / 12)&-1;
          $174 = ((($162)) + 76|0);
          $175 = ((($162)) + 80|0);
          $176 = HEAP32[$175>>2]|0;
          $177 = HEAP32[$174>>2]|0;
          $178 = (($176) - ($177))|0;
          $179 = $178 >> 3;
          $180 = ($173|0)==($179|0);
          if ($180) {
           if (!($$1$off0)) {
            $276 = ((($0)) + 24|0);
            HEAP32[$276>>2] = 0;
            $277 = ((($0)) + 28|0);
            HEAP32[$277>>2] = 0;
            STACKTOP = sp;return;
           }
          } else {
           label = 57;
          }
         } else {
          label = 57;
         }
        }
        if ((label|0) == 57) {
         __THREW__ = 0;
         $181 = (invoke_ii(3276,88)|0);
         $182 = __THREW__; __THREW__ = 0;
         $183 = $182&1;
         if ($183) {
          label = 40;
          break;
         }
         __THREW__ = 0;
         invoke_vii(3435,($181|0),1);
         $184 = __THREW__; __THREW__ = 0;
         $185 = $184&1;
         if ($185) {
          $213 = ___cxa_find_matching_catch_2()|0;
          $214 = tempRet0;
          __ZdlPv($181);
          $$3 = $214;$$314 = $213;
          break L1;
         }
         $186 = ((($181)) + 12|0);
         ;HEAP32[$186>>2]=0|0;HEAP32[$186+4>>2]=0|0;HEAP32[$186+8>>2]=0|0;
         $187 = ((($181)) + 24|0);
         HEAP32[$187>>2] = 2;
         $188 = ((($181)) + 28|0);
         ;HEAP32[$188>>2]=0|0;HEAP32[$188+4>>2]=0|0;HEAP32[$188+8>>2]=0|0;HEAP32[$188+12>>2]=0|0;HEAP32[$188+16>>2]=0|0;HEAP32[$188+20>>2]=0|0;
         $189 = ((($181)) + 52|0);
         HEAP32[$189>>2] = 27;
         $190 = ((($181)) + 56|0);
         HEAP32[$190>>2] = 2;
         $191 = ((($181)) + 60|0);
         HEAP32[$191>>2] = 5126;
         $192 = ((($181)) + 64|0);
         HEAP32[$192>>2] = 4;
         $193 = ((($181)) + 68|0);
         HEAP8[$193>>0] = 0;
         $194 = ((($181)) + 69|0);
         HEAP8[$194>>0] = 0;
         $195 = ((($181)) + 72|0);
         $196 = ((($181)) + 76|0);
         HEAP32[$196>>2] = 0;
         $197 = ((($181)) + 80|0);
         HEAP32[$197>>2] = 0;
         $198 = ((($181)) + 84|0);
         HEAP32[$198>>2] = 0;
         HEAP32[$181>>2] = (38040);
         HEAP32[$195>>2] = (38264);
         $199 = HEAP32[$8>>2]|0;
         $200 = ($199|0)==($181|0);
         do {
          if (!($200)) {
           HEAP32[$8>>2] = $181;
           $201 = ((($181)) + 8|0);
           $202 = HEAP32[$201>>2]|0;HEAP32[$201>>2] = (($202+1)|0);
           $203 = ($199|0)==(0|0);
           if ($203) {
            break;
           }
           $204 = ((($199)) + 8|0);
           $205 = HEAP32[$204>>2]|0;HEAP32[$204>>2] = (($205-1)|0);
           $206 = ($205|0)==(1);
           if (!($206)) {
            break;
           }
           __THREW__ = 0;
           invoke_viii(3262,($199|0),1,1);
           $207 = __THREW__; __THREW__ = 0;
           $208 = $207&1;
           if ($208) {
            label = 40;
            break L55;
           }
          }
         } while(0);
         $209 = HEAP32[$4>>2]|0;
         $210 = HEAP32[$8>>2]|0;
         __THREW__ = 0;
         invoke_viiii(3491,($209|0),0,($210|0),-1);
         $211 = __THREW__; __THREW__ = 0;
         $212 = $211&1;
         if ($212) {
          label = 40;
          break;
         }
        }
        $215 = HEAP32[$4>>2]|0;
        $216 = ((($215)) + 216|0);
        $217 = HEAP32[$216>>2]|0;
        $218 = ((($215)) + 220|0);
        $219 = HEAP32[$218>>2]|0;
        $220 = ($217|0)==($219|0);
        if ($220) {
         $276 = ((($0)) + 24|0);
         HEAP32[$276>>2] = 0;
         $277 = ((($0)) + 28|0);
         HEAP32[$277>>2] = 0;
         STACKTOP = sp;return;
        }
        __THREW__ = 0;
        $221 = (invoke_ii(3265,3)|0);
        $222 = __THREW__; __THREW__ = 0;
        $223 = $222&1;
        if ($223) {
         label = 40;
        } else {
         L93: do {
          if ($221) {
           __THREW__ = 0;
           $224 = (invoke_ii(3266,3)|0);
           $225 = __THREW__; __THREW__ = 0;
           $226 = $225&1;
           if ($226) {
            label = 40;
            break L55;
           }
           __THREW__ = 0;
           $227 = (invoke_iiii(3267,($224|0),(148487|0),103)|0);
           $228 = __THREW__; __THREW__ = 0;
           $229 = $228&1;
           if ($229) {
            label = 40;
            break L55;
           }
           $230 = HEAP32[$227>>2]|0;
           $231 = ((($230)) + -12|0);
           $232 = HEAP32[$231>>2]|0;
           $233 = (($227) + ($232)|0);
           __THREW__ = 0;
           invoke_vii(3257,($3|0),($233|0));
           $234 = __THREW__; __THREW__ = 0;
           $235 = $234&1;
           if ($235) {
            label = 40;
            break L55;
           }
           __THREW__ = 0;
           $236 = (invoke_iii(3255,($3|0),(215188|0))|0);
           $237 = __THREW__; __THREW__ = 0;
           $238 = $237&1;
           do {
            if (!($238)) {
             $239 = HEAP32[$236>>2]|0;
             $240 = ((($239)) + 28|0);
             $241 = HEAP32[$240>>2]|0;
             __THREW__ = 0;
             $242 = (invoke_iii($241|0,($236|0),10)|0);
             $243 = __THREW__; __THREW__ = 0;
             $244 = $243&1;
             if ($244) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3263,($3|0));
             $245 = __THREW__; __THREW__ = 0;
             $246 = $245&1;
             if ($246) {
              label = 40;
              break L55;
             }
             __THREW__ = 0;
             (invoke_iii(3268,($227|0),($242|0))|0);
             $253 = __THREW__; __THREW__ = 0;
             $254 = $253&1;
             if ($254) {
              label = 40;
              break L55;
             }
             __THREW__ = 0;
             (invoke_ii(3269,($227|0))|0);
             $255 = __THREW__; __THREW__ = 0;
             $256 = $255&1;
             if ($256) {
              label = 40;
              break L55;
             } else {
              break L93;
             }
            }
           } while(0);
           $247 = ___cxa_find_matching_catch_2()|0;
           $248 = tempRet0;
           __THREW__ = 0;
           invoke_vi(3263,($3|0));
           $249 = __THREW__; __THREW__ = 0;
           $250 = $249&1;
           if ($250) {
            $251 = ___cxa_find_matching_catch_3(0|0)|0;
            $252 = tempRet0;
            ___clang_call_terminate($251);
            // unreachable;
           } else {
            $eh$lpad$body$index2Z2D = $248;$eh$lpad$body$indexZ2D = $247;
            break L55;
           }
          }
         } while(0);
         $257 = HEAP32[$4>>2]|0;
         $258 = ((($257)) + 216|0);
         $259 = HEAP32[$258>>2]|0;
         $260 = ((($257)) + 220|0);
         $261 = HEAP32[$260>>2]|0;
         $262 = ($261|0)==($259|0);
         if ($262) {
          $276 = ((($0)) + 24|0);
          HEAP32[$276>>2] = 0;
          $277 = ((($0)) + 28|0);
          HEAP32[$277>>2] = 0;
          STACKTOP = sp;return;
         } else {
          $264 = $261;
         }
         L110: while(1) {
          $263 = ((($264)) + -4|0);
          HEAP32[$260>>2] = $263;
          $265 = HEAP32[$263>>2]|0;
          $266 = ($265|0)==(0|0);
          do {
           if (!($266)) {
            $267 = ((($265)) + 8|0);
            $268 = HEAP32[$267>>2]|0;HEAP32[$267>>2] = (($268-1)|0);
            $269 = ($268|0)==(1);
            if (!($269)) {
             break;
            }
            __THREW__ = 0;
            invoke_viii(3262,($265|0),1,1);
            $270 = __THREW__; __THREW__ = 0;
            $271 = $270&1;
            if ($271) {
             label = 85;
             break L110;
            }
           }
          } while(0);
          HEAP32[$263>>2] = 0;
          $272 = HEAP32[$260>>2]|0;
          $273 = ($272|0)==($259|0);
          if ($273) {
           label = 86;
           break;
          } else {
           $264 = $272;
          }
         }
         if ((label|0) == 85) {
          $274 = ___cxa_find_matching_catch_2()|0;
          $275 = tempRet0;
          ___cxa_call_unexpected(($274|0));
          // unreachable;
         }
         else if ((label|0) == 86) {
          $276 = ((($0)) + 24|0);
          HEAP32[$276>>2] = 0;
          $277 = ((($0)) + 28|0);
          HEAP32[$277>>2] = 0;
          STACKTOP = sp;return;
         }
        }
       }
      } while(0);
      if ((label|0) == 40) {
       $107 = ___cxa_find_matching_catch_2()|0;
       $108 = tempRet0;
       $eh$lpad$body$index2Z2D = $108;$eh$lpad$body$indexZ2D = $107;
      }
      $$3 = $eh$lpad$body$index2Z2D;$$314 = $eh$lpad$body$indexZ2D;
      break L1;
     }
    }
   } while(0);
   $23 = ___cxa_find_matching_catch_2()|0;
   $24 = tempRet0;
   $$3 = $24;$$314 = $23;
  }
 } while(0);
 $278 = HEAP32[$8>>2]|0;
 $279 = ($278|0)==(0|0);
 if (!($279)) {
  $280 = ((($278)) + 8|0);
  $281 = HEAP32[$280>>2]|0;HEAP32[$280>>2] = (($281-1)|0);
  $282 = ($281|0)==(1);
  if ($282) {
   __THREW__ = 0;
   invoke_viii(3262,($278|0),1,1);
   $283 = __THREW__; __THREW__ = 0;
   $284 = $283&1;
   if ($284) {
    $299 = ___cxa_find_matching_catch_3(0|0)|0;
    $300 = tempRet0;
    ___clang_call_terminate($299);
    // unreachable;
   }
  }
 }
 HEAP32[$8>>2] = 0;
 $285 = HEAP32[$7>>2]|0;
 $286 = ($285|0)==(0|0);
 if (!($286)) {
  $287 = ((($285)) + 8|0);
  $288 = HEAP32[$287>>2]|0;HEAP32[$287>>2] = (($288-1)|0);
  $289 = ($288|0)==(1);
  if ($289) {
   __THREW__ = 0;
   invoke_viii(3262,($285|0),1,1);
   $290 = __THREW__; __THREW__ = 0;
   $291 = $290&1;
   if ($291) {
    $299 = ___cxa_find_matching_catch_3(0|0)|0;
    $300 = tempRet0;
    ___clang_call_terminate($299);
    // unreachable;
   }
  }
 }
 HEAP32[$7>>2] = 0;
 $292 = HEAP32[$6>>2]|0;
 $293 = ($292|0)==(0|0);
 if ($293) {
  HEAP32[$6>>2] = 0;
  ___resumeException($$314|0);
  // unreachable;
 }
 $294 = ((($292)) + 8|0);
 $295 = HEAP32[$294>>2]|0;HEAP32[$294>>2] = (($295-1)|0);
 $296 = ($295|0)==(1);
 if (!($296)) {
  HEAP32[$6>>2] = 0;
  ___resumeException($$314|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(3262,($292|0),1,1);
 $297 = __THREW__; __THREW__ = 0;
 $298 = $297&1;
 if ($298) {
  $299 = ___cxa_find_matching_catch_3(0|0)|0;
  $300 = tempRet0;
  ___clang_call_terminate($299);
  // unreachable;
 } else {
  HEAP32[$6>>2] = 0;
  ___resumeException($$314|0);
  // unreachable;
 }
}
function __ZN3osg14StateAttributeC2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg10ReferencedC2Eb($0,1);
 $1 = ((($0)) + 12|0);
 ;HEAP32[$1>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;
 $2 = ((($0)) + 24|0);
 HEAP32[$2>>2] = 2;
 $3 = ((($0)) + 28|0);
 HEAP32[$3>>2] = 0;
 HEAP32[$0>>2] = (57384);
 $4 = ((($0)) + 32|0);
 ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;HEAP32[$4+12>>2]=0|0;HEAP32[$4+16>>2]=0|0;HEAP32[$4+20>>2]=0|0;
 return;
}
function __ZN3osg14StateAttribute9addParentEPNS_8StateSetE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp + 4|0;
 $3 = sp;
 HEAP32[$3>>2] = $1;
 $4 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(6)|0);
 do {
  if ($4) {
   $5 = (__ZN3osg6notifyENS_14NotifySeverityE(6)|0);
   $6 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($5,148591,13)|0);
   $7 = (__ZN3osg10Referenced24getGlobalReferencedMutexEv()|0);
   $8 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEPKv($6,$7)|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = ((($9)) + -12|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (($8) + ($11)|0);
   __ZNKSt3__28ios_base6getlocEv($2,$12);
   __THREW__ = 0;
   $13 = (invoke_iii(3255,($2|0),(215188|0))|0);
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if (!($15)) {
    $16 = HEAP32[$13>>2]|0;
    $17 = ((($16)) + 28|0);
    $18 = HEAP32[$17>>2]|0;
    __THREW__ = 0;
    $19 = (invoke_iii($18|0,($13|0),10)|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if (!($21)) {
     __ZNSt3__26localeD2Ev($2);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($8,$19)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($8)|0);
     break;
    }
   }
   $22 = ___cxa_find_matching_catch_2()|0;
   $23 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($2|0));
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   if ($25) {
    $26 = ___cxa_find_matching_catch_3(0|0)|0;
    $27 = tempRet0;
    ___clang_call_terminate($26);
    // unreachable;
   } else {
    ___resumeException($22|0);
    // unreachable;
   }
  }
 } while(0);
 $28 = (__ZN3osg10Referenced24getGlobalReferencedMutexEv()|0);
 $29 = ($28|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$28>>2]|0;
  $31 = ((($30)) + 8|0);
  $32 = HEAP32[$31>>2]|0;
  (FUNCTION_TABLE_ii[$32 & 8191]($28)|0);
 }
 $33 = ((($0)) + 36|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ((($0)) + 40|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = ($34|0)==($36|0);
 if ($37) {
  $41 = ((($0)) + 32|0);
  __THREW__ = 0;
  invoke_vii(3914,($41|0),($3|0));
  $42 = __THREW__; __THREW__ = 0;
  $43 = $42&1;
  if ($43) {
   $47 = ___cxa_find_matching_catch_2()|0;
   $48 = tempRet0;
   if ($29) {
    ___resumeException($47|0);
    // unreachable;
   }
   $49 = HEAP32[$28>>2]|0;
   $50 = ((($49)) + 12|0);
   $51 = HEAP32[$50>>2]|0;
   __THREW__ = 0;
   (invoke_ii($51|0,($28|0))|0);
   $52 = __THREW__; __THREW__ = 0;
   $53 = $52&1;
   if ($53) {
    $54 = ___cxa_find_matching_catch_3(0|0)|0;
    $55 = tempRet0;
    ___clang_call_terminate($54);
    // unreachable;
   } else {
    ___resumeException($47|0);
    // unreachable;
   }
  }
 } else {
  $38 = HEAP32[$3>>2]|0;
  HEAP32[$34>>2] = $38;
  $39 = HEAP32[$33>>2]|0;
  $40 = ((($39)) + 4|0);
  HEAP32[$33>>2] = $40;
 }
 if ($29) {
  STACKTOP = sp;return;
 }
 $44 = HEAP32[$28>>2]|0;
 $45 = ((($44)) + 12|0);
 $46 = HEAP32[$45>>2]|0;
 (FUNCTION_TABLE_ii[$46 & 8191]($28)|0);
 STACKTOP = sp;return;
}
function __ZN3osg14StateAttribute12removeParentEPNS_8StateSetE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$pre$i = 0, $$sroa$0$0$copyload$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i = 0, $scevgep5$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__ZN3osg10Referenced24getGlobalReferencedMutexEv()|0);
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = HEAP32[$2>>2]|0;
  $5 = ((($4)) + 8|0);
  $6 = HEAP32[$5>>2]|0;
  (FUNCTION_TABLE_ii[$6 & 8191]($2)|0);
 }
 $7 = ((($0)) + 32|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($0)) + 36|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8|0)==($10|0);
 $12 = $10;
 L4: do {
  if ($11) {
   $$sroa$0$0$copyload$i = $8;
   label = 6;
  } else {
   $14 = $8;
   while(1) {
    $13 = HEAP32[$14>>2]|0;
    $15 = ($13|0)==($1|0);
    if ($15) {
     $$sroa$0$0$copyload$i = $14;
     label = 6;
     break L4;
    }
    $16 = ((($14)) + 4|0);
    $17 = ($16|0)==($10|0);
    if ($17) {
     break;
    } else {
     $14 = $16;
    }
   }
  }
 } while(0);
 if ((label|0) == 6) {
  $18 = ($$sroa$0$0$copyload$i|0)==($10|0);
  if (!($18)) {
   $19 = ((($$sroa$0$0$copyload$i)) + 4|0);
   $20 = $19;
   $21 = (($12) - ($20))|0;
   $22 = $21 >> 2;
   $23 = ($22|0)==(0);
   if ($23) {
    $25 = $10;
   } else {
    _memmove(($$sroa$0$0$copyload$i|0),($19|0),($21|0))|0;
    $$pre$i = HEAP32[$9>>2]|0;
    $25 = $$pre$i;
   }
   $24 = (($$sroa$0$0$copyload$i) + ($22<<2)|0);
   $26 = ($25|0)==($24|0);
   if (!($26)) {
    $scevgep$i$i$i = ((($25)) + -4|0);
    $27 = $scevgep$i$i$i;
    $28 = $24;
    $29 = (($27) - ($28))|0;
    $30 = $29 >>> 2;
    $31 = $30 ^ -1;
    $scevgep5$i$i$i = (($25) + ($31<<2)|0);
    HEAP32[$9>>2] = $scevgep5$i$i$i;
   }
  }
 }
 if ($3) {
  return;
 }
 $32 = HEAP32[$2>>2]|0;
 $33 = ((($32)) + 12|0);
 $34 = HEAP32[$33>>2]|0;
 (FUNCTION_TABLE_ii[$34 & 8191]($2)|0);
 return;
}
function __ZN3osg14StateAttribute17setUpdateCallbackEPNS_22StateAttributeCallbackE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$ = 0, $$1 = 0, $$sroa$09$014 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $not$ = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(5)|0);
 do {
  if ($3) {
   $4 = (__ZN3osg6notifyENS_14NotifySeverityE(5)|0);
   $5 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($4,148605,40)|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ((($6)) + -12|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($5) + ($8)|0);
   __ZNKSt3__28ios_base6getlocEv($2,$9);
   __THREW__ = 0;
   $10 = (invoke_iii(3255,($2|0),(215188|0))|0);
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if (!($12)) {
    $13 = HEAP32[$10>>2]|0;
    $14 = ((($13)) + 28|0);
    $15 = HEAP32[$14>>2]|0;
    __THREW__ = 0;
    $16 = (invoke_iii($15|0,($10|0),10)|0);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if (!($18)) {
     __ZNSt3__26localeD2Ev($2);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($5,$16)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($5)|0);
     break;
    }
   }
   $19 = ___cxa_find_matching_catch_2()|0;
   $20 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($2|0));
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if ($22) {
    $23 = ___cxa_find_matching_catch_3(0|0)|0;
    $24 = tempRet0;
    ___clang_call_terminate($23);
    // unreachable;
   } else {
    ___resumeException($19|0);
    // unreachable;
   }
  }
 } while(0);
 $25 = ((($0)) + 48|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($26|0)==($1|0);
 if ($27) {
  STACKTOP = sp;return;
 }
 $28 = ($26|0)!=(0|0);
 $$ = $28 << 31 >> 31;
 $29 = ($1|0)==(0|0);
 $not$ = $29 ^ 1;
 $30 = $not$&1;
 $$1 = (($$) + ($30))|0;
 HEAP32[$25>>2] = $1;
 if (!($29)) {
  $31 = HEAP32[$1>>2]|0;
  $32 = ((($31)) + -16|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = (($1) + ($33)|0);
  $35 = ((($34)) + 8|0);
  $36 = HEAP32[$35>>2]|0;HEAP32[$35>>2] = (($36+1)|0);
 }
 $37 = ($26|0)==(0|0);
 if (!($37)) {
  $38 = HEAP32[$26>>2]|0;
  $39 = ((($38)) + -16|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = (($26) + ($40)|0);
  $42 = ((($41)) + 8|0);
  $43 = HEAP32[$42>>2]|0;HEAP32[$42>>2] = (($43-1)|0);
  $44 = ($43|0)==(1);
  if ($44) {
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($41,1,1);
  }
 }
 $45 = ($$1|0)==(0);
 if ($45) {
  STACKTOP = sp;return;
 }
 $46 = ((($0)) + 32|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = ((($0)) + 36|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = ($47|0)==($49|0);
 if ($50) {
  STACKTOP = sp;return;
 } else {
  $$sroa$09$014 = $47;
 }
 while(1) {
  $51 = HEAP32[$$sroa$09$014>>2]|0;
  $52 = ((($51)) + 148|0);
  $53 = HEAP32[$52>>2]|0;
  $54 = (($53) + ($$1))|0;
  __ZN3osg8StateSet38setNumChildrenRequiringUpdateTraversalEj($51,$54);
  $55 = ((($$sroa$09$014)) + 4|0);
  $56 = HEAP32[$48>>2]|0;
  $57 = ($55|0)==($56|0);
  if ($57) {
   break;
  } else {
   $$sroa$09$014 = $55;
  }
 }
 STACKTOP = sp;return;
}
function __ZN3osg14StateAttribute17ReassignToParentsC2EPS0_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$sroa$022$028 = 0, $10 = 0, $100 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $eh$lpad$body$sink27$index3Z2D = 0, $eh$lpad$body$sink27$indexZ2D = 0, $scevgep$i$i$i = 0, $scevgep5$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = ((($0)) + 4|0);
 $4 = ((($0)) + 8|0);
 ;HEAP32[$0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
 $5 = HEAP32[$1>>2]|0;
 $6 = ((($5)) + 156|0);
 $7 = HEAP32[$6>>2]|0;
 __THREW__ = 0;
 $8 = (invoke_ii($7|0,($1|0))|0);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 do {
  if ($10) {
   label = 12;
  } else {
   if ($8) {
    STACKTOP = sp;return;
   }
   $11 = ((($1)) + 32|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = ((($1)) + 36|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = ($12|0)==($14|0);
   if ($15) {
    STACKTOP = sp;return;
   }
   $16 = HEAP32[$0>>2]|0;
   $17 = ($16|0)==($1|0);
   if (!($17)) {
    HEAP32[$0>>2] = $1;
    $18 = ((($1)) + 8|0);
    $19 = HEAP32[$18>>2]|0;HEAP32[$18>>2] = (($19+1)|0);
    $20 = ($16|0)==(0|0);
    if (!($20)) {
     $21 = ((($16)) + 8|0);
     $22 = HEAP32[$21>>2]|0;HEAP32[$21>>2] = (($22-1)|0);
     $23 = ($22|0)==(1);
     if ($23) {
      __THREW__ = 0;
      invoke_viii(3262,($16|0),1,1);
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if ($25) {
       label = 12;
       break;
      }
     }
    }
   }
   $26 = ($3|0)==($11|0);
   if (!($26)) {
    $27 = HEAP32[$11>>2]|0;
    $28 = HEAP32[$13>>2]|0;
    __THREW__ = 0;
    invoke_viii(3915,($3|0),($27|0),($28|0));
    $29 = __THREW__; __THREW__ = 0;
    $30 = $29&1;
    if ($30) {
     label = 12;
     break;
    }
   }
   $31 = HEAP32[$3>>2]|0;
   $32 = HEAP32[$4>>2]|0;
   $33 = ($31|0)==($32|0);
   if ($33) {
    STACKTOP = sp;return;
   }
   $$sroa$022$028 = $31;
   while(1) {
    $36 = HEAP32[$$sroa$022$028>>2]|0;
    __THREW__ = 0;
    invoke_vii(3916,($36|0),($1|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     label = 28;
     break;
    }
    __THREW__ = 0;
    $39 = (invoke_ii(3265,3)|0);
    $40 = __THREW__; __THREW__ = 0;
    $41 = $40&1;
    if ($41) {
     label = 28;
     break;
    }
    if ($39) {
     __THREW__ = 0;
     $42 = (invoke_ii(3266,3)|0);
     $43 = __THREW__; __THREW__ = 0;
     $44 = $43&1;
     if ($44) {
      label = 28;
      break;
     }
     __THREW__ = 0;
     $45 = (invoke_iiii(3267,($42|0),(148646|0),22)|0);
     $46 = __THREW__; __THREW__ = 0;
     $47 = $46&1;
     if ($47) {
      label = 28;
      break;
     }
     __THREW__ = 0;
     $48 = (invoke_iii(3275,($45|0),($36|0))|0);
     $49 = __THREW__; __THREW__ = 0;
     $50 = $49&1;
     if ($50) {
      label = 28;
      break;
     }
     $51 = HEAP32[$48>>2]|0;
     $52 = ((($51)) + -12|0);
     $53 = HEAP32[$52>>2]|0;
     $54 = (($48) + ($53)|0);
     __THREW__ = 0;
     invoke_vii(3257,($2|0),($54|0));
     $55 = __THREW__; __THREW__ = 0;
     $56 = $55&1;
     if ($56) {
      label = 28;
      break;
     }
     __THREW__ = 0;
     $57 = (invoke_iii(3255,($2|0),(215188|0))|0);
     $58 = __THREW__; __THREW__ = 0;
     $59 = $58&1;
     if ($59) {
      label = 22;
      break;
     }
     $60 = HEAP32[$57>>2]|0;
     $61 = ((($60)) + 28|0);
     $62 = HEAP32[$61>>2]|0;
     __THREW__ = 0;
     $63 = (invoke_iii($62|0,($57|0),10)|0);
     $64 = __THREW__; __THREW__ = 0;
     $65 = $64&1;
     if ($65) {
      label = 22;
      break;
     }
     __THREW__ = 0;
     invoke_vi(3263,($2|0));
     $72 = __THREW__; __THREW__ = 0;
     $73 = $72&1;
     if ($73) {
      label = 28;
      break;
     }
     __THREW__ = 0;
     (invoke_iii(3268,($48|0),($63|0))|0);
     $74 = __THREW__; __THREW__ = 0;
     $75 = $74&1;
     if ($75) {
      label = 28;
      break;
     }
     __THREW__ = 0;
     (invoke_ii(3269,($48|0))|0);
     $76 = __THREW__; __THREW__ = 0;
     $77 = $76&1;
     if ($77) {
      label = 28;
      break;
     }
    }
    $80 = ((($$sroa$022$028)) + 4|0);
    $81 = HEAP32[$4>>2]|0;
    $82 = ($80|0)==($81|0);
    if ($82) {
     label = 30;
     break;
    } else {
     $$sroa$022$028 = $80;
    }
   }
   if ((label|0) == 22) {
    $66 = ___cxa_find_matching_catch_2()|0;
    $67 = tempRet0;
    __THREW__ = 0;
    invoke_vi(3263,($2|0));
    $68 = __THREW__; __THREW__ = 0;
    $69 = $68&1;
    if ($69) {
     $70 = ___cxa_find_matching_catch_3(0|0)|0;
     $71 = tempRet0;
     ___clang_call_terminate($70);
     // unreachable;
    } else {
     $eh$lpad$body$sink27$index3Z2D = $67;$eh$lpad$body$sink27$indexZ2D = $66;
     break;
    }
   }
   else if ((label|0) == 28) {
    $78 = ___cxa_find_matching_catch_2()|0;
    $79 = tempRet0;
    $eh$lpad$body$sink27$index3Z2D = $79;$eh$lpad$body$sink27$indexZ2D = $78;
    break;
   }
   else if ((label|0) == 30) {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 12) {
  $34 = ___cxa_find_matching_catch_2()|0;
  $35 = tempRet0;
  $eh$lpad$body$sink27$index3Z2D = $35;$eh$lpad$body$sink27$indexZ2D = $34;
 }
 $83 = HEAP32[$3>>2]|0;
 $84 = ($83|0)==(0|0);
 if (!($84)) {
  $85 = HEAP32[$4>>2]|0;
  $86 = ($85|0)==($83|0);
  if (!($86)) {
   $scevgep$i$i$i = ((($85)) + -4|0);
   $87 = $scevgep$i$i$i;
   $88 = $83;
   $89 = (($87) - ($88))|0;
   $90 = $89 >>> 2;
   $91 = $90 ^ -1;
   $scevgep5$i$i$i = (($85) + ($91<<2)|0);
   HEAP32[$4>>2] = $scevgep5$i$i$i;
  }
  __ZdlPv($83);
 }
 $92 = HEAP32[$0>>2]|0;
 $93 = ($92|0)==(0|0);
 if ($93) {
  HEAP32[$0>>2] = 0;
  ___resumeException($eh$lpad$body$sink27$indexZ2D|0);
  // unreachable;
 }
 $94 = ((($92)) + 8|0);
 $95 = HEAP32[$94>>2]|0;HEAP32[$94>>2] = (($95-1)|0);
 $96 = ($95|0)==(1);
 if (!($96)) {
  HEAP32[$0>>2] = 0;
  ___resumeException($eh$lpad$body$sink27$indexZ2D|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(3262,($92|0),1,1);
 $97 = __THREW__; __THREW__ = 0;
 $98 = $97&1;
 if ($98) {
  $99 = ___cxa_find_matching_catch_3(0|0)|0;
  $100 = tempRet0;
  ___clang_call_terminate($99);
  // unreachable;
 } else {
  HEAP32[$0>>2] = 0;
  ___resumeException($eh$lpad$body$sink27$indexZ2D|0);
  // unreachable;
 }
}
function __ZNSt3__26vectorIPN3osg8StateSetENS_9allocatorIS3_EEE6assignIPS3_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS3_NS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$ = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $scevgep$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep5$i$i = 0, $scevgep5$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = $2;
 $4 = $1;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 $7 = ((($0)) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$0>>2]|0;
 $10 = (($8) - ($9))|0;
 $11 = $10 >> 2;
 $12 = ($6>>>0)>($11>>>0);
 $13 = $9;
 if (!($12)) {
  $14 = ((($0)) + 4|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (($15) - ($9))|0;
  $17 = $16 >> 2;
  $18 = ($6>>>0)>($17>>>0);
  $19 = (($1) + ($17<<2)|0);
  $$ = $18 ? $19 : $2;
  $20 = $$;
  $21 = (($20) - ($4))|0;
  $22 = $21 >> 2;
  $23 = ($22|0)==(0);
  if (!($23)) {
   $24 = $9;
   _memmove(($24|0),($1|0),($21|0))|0;
  }
  $25 = (($13) + ($22<<2)|0);
  if ($18) {
   $26 = (($3) - ($20))|0;
   $27 = ($26|0)>(0);
   if (!($27)) {
    return;
   }
   $28 = $26 >>> 2;
   $29 = HEAP32[$14>>2]|0;
   _memcpy(($29|0),($$|0),($26|0))|0;
   $30 = HEAP32[$14>>2]|0;
   $31 = (($30) + ($28<<2)|0);
   HEAP32[$14>>2] = $31;
   return;
  } else {
   $32 = HEAP32[$14>>2]|0;
   $33 = ($32|0)==($25|0);
   if ($33) {
    return;
   }
   $scevgep$i$i = ((($32)) + -4|0);
   $34 = $scevgep$i$i;
   $35 = $25;
   $36 = (($34) - ($35))|0;
   $37 = $36 >>> 2;
   $38 = $37 ^ -1;
   $scevgep5$i$i = (($32) + ($38<<2)|0);
   HEAP32[$14>>2] = $scevgep5$i$i;
   return;
  }
 }
 $39 = ($9|0)==(0);
 $40 = $9;
 if ($39) {
  $50 = $8;
 } else {
  $41 = ((($0)) + 4|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = ($42|0)==($13|0);
  if (!($43)) {
   $scevgep$i$i$i$i = ((($42)) + -4|0);
   $44 = $scevgep$i$i$i$i;
   $45 = (($44) - ($9))|0;
   $46 = $45 >>> 2;
   $47 = $46 ^ -1;
   $scevgep5$i$i$i$i = (($42) + ($47<<2)|0);
   HEAP32[$41>>2] = $scevgep5$i$i$i$i;
  }
  __ZdlPv($40);
  HEAP32[$7>>2] = 0;
  HEAP32[$41>>2] = 0;
  HEAP32[$0>>2] = 0;
  $50 = 0;
 }
 $48 = ($6>>>0)>(1073741823);
 if ($48) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $49 = $50 >> 2;
 $51 = ($49>>>0)<(536870911);
 $52 = $50 >> 1;
 $53 = ($52>>>0)<($6>>>0);
 $$sroa$speculated$i = $53 ? $6 : $52;
 $$sroa$speculated$$i = $51 ? $$sroa$speculated$i : 1073741823;
 $54 = ($$sroa$speculated$$i>>>0)>(1073741823);
 if ($54) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $55 = $$sroa$speculated$$i << 2;
 $56 = (__Znwj($55)|0);
 $57 = ((($0)) + 4|0);
 HEAP32[$57>>2] = $56;
 HEAP32[$0>>2] = $56;
 $58 = (($56) + ($$sroa$speculated$$i<<2)|0);
 HEAP32[$7>>2] = $58;
 $59 = ($5|0)>(0);
 if (!($59)) {
  return;
 }
 $60 = $5 >>> 2;
 _memcpy(($56|0),($1|0),($5|0))|0;
 $61 = (($56) + ($60<<2)|0);
 HEAP32[$57>>2] = $61;
 return;
}
function __ZN3osg14StateAttribute17ReassignToParentsD2Ev($0) {
 $0 = $0|0;
 var $$pre = 0, $$sroa$020$027 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i8 = 0, $scevgep5$i$i$i = 0, $scevgep5$i$i$i9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 L1: do {
  if ($6) {
   $7 = $3;$9 = $3;
  } else {
   $$sroa$020$027 = $3;
   while(1) {
    $16 = HEAP32[$$sroa$020$027>>2]|0;
    $17 = HEAP32[$0>>2]|0;
    __THREW__ = 0;
    invoke_viii(3357,($16|0),($17|0),0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     label = 23;
     break;
    }
    __THREW__ = 0;
    $20 = (invoke_ii(3265,3)|0);
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if ($22) {
     label = 23;
     break;
    }
    if ($20) {
     __THREW__ = 0;
     $23 = (invoke_ii(3266,3)|0);
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if ($25) {
      label = 23;
      break;
     }
     __THREW__ = 0;
     $26 = (invoke_iiii(3267,($23|0),(148669|0),24)|0);
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     if ($28) {
      label = 23;
      break;
     }
     __THREW__ = 0;
     $29 = (invoke_iii(3275,($26|0),($16|0))|0);
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      label = 23;
      break;
     }
     $32 = HEAP32[$29>>2]|0;
     $33 = ((($32)) + -12|0);
     $34 = HEAP32[$33>>2]|0;
     $35 = (($29) + ($34)|0);
     __THREW__ = 0;
     invoke_vii(3257,($1|0),($35|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if ($37) {
      label = 23;
      break;
     }
     __THREW__ = 0;
     $38 = (invoke_iii(3255,($1|0),(215188|0))|0);
     $39 = __THREW__; __THREW__ = 0;
     $40 = $39&1;
     if ($40) {
      label = 17;
      break;
     }
     $41 = HEAP32[$38>>2]|0;
     $42 = ((($41)) + 28|0);
     $43 = HEAP32[$42>>2]|0;
     __THREW__ = 0;
     $44 = (invoke_iii($43|0,($38|0),10)|0);
     $45 = __THREW__; __THREW__ = 0;
     $46 = $45&1;
     if ($46) {
      label = 17;
      break;
     }
     __THREW__ = 0;
     invoke_vi(3263,($1|0));
     $53 = __THREW__; __THREW__ = 0;
     $54 = $53&1;
     if ($54) {
      label = 23;
      break;
     }
     __THREW__ = 0;
     (invoke_iii(3268,($29|0),($44|0))|0);
     $55 = __THREW__; __THREW__ = 0;
     $56 = $55&1;
     if ($56) {
      label = 23;
      break;
     }
     __THREW__ = 0;
     (invoke_ii(3269,($29|0))|0);
     $57 = __THREW__; __THREW__ = 0;
     $58 = $57&1;
     if ($58) {
      label = 23;
      break;
     }
    }
    $70 = ((($$sroa$020$027)) + 4|0);
    $71 = HEAP32[$4>>2]|0;
    $72 = ($70|0)==($71|0);
    if ($72) {
     label = 3;
     break;
    } else {
     $$sroa$020$027 = $70;
    }
   }
   do {
    if ((label|0) == 3) {
     $$pre = HEAP32[$2>>2]|0;
     $7 = $$pre;$9 = $70;
     break L1;
    }
    else if ((label|0) == 17) {
     $47 = ___cxa_find_matching_catch_2()|0;
     $48 = tempRet0;
     __THREW__ = 0;
     invoke_vi(3263,($1|0));
     $49 = __THREW__; __THREW__ = 0;
     $50 = $49&1;
     if ($50) {
      $51 = ___cxa_find_matching_catch_3(0|0)|0;
      $52 = tempRet0;
      ___clang_call_terminate($51);
      // unreachable;
     } else {
      $eh$lpad$body$index2Z2D = $48;$eh$lpad$body$indexZ2D = $47;
      break;
     }
    }
    else if ((label|0) == 23) {
     $59 = ___cxa_find_matching_catch_2()|0;
     $60 = tempRet0;
     $eh$lpad$body$index2Z2D = $60;$eh$lpad$body$indexZ2D = $59;
    }
   } while(0);
   $61 = HEAP32[$2>>2]|0;
   $62 = ($61|0)==(0|0);
   if (!($62)) {
    $63 = HEAP32[$4>>2]|0;
    $64 = ($63|0)==($61|0);
    if (!($64)) {
     $scevgep$i$i$i8 = ((($63)) + -4|0);
     $65 = $scevgep$i$i$i8;
     $66 = $61;
     $67 = (($65) - ($66))|0;
     $68 = $67 >>> 2;
     $69 = $68 ^ -1;
     $scevgep5$i$i$i9 = (($63) + ($69<<2)|0);
     HEAP32[$4>>2] = $scevgep5$i$i$i9;
    }
    __ZdlPv($61);
   }
   $78 = HEAP32[$0>>2]|0;
   $79 = ($78|0)==(0|0);
   if ($79) {
    HEAP32[$0>>2] = 0;
    ___resumeException($eh$lpad$body$indexZ2D|0);
    // unreachable;
   }
   $80 = ((($78)) + 8|0);
   $81 = HEAP32[$80>>2]|0;HEAP32[$80>>2] = (($81-1)|0);
   $82 = ($81|0)==(1);
   if (!($82)) {
    HEAP32[$0>>2] = 0;
    ___resumeException($eh$lpad$body$indexZ2D|0);
    // unreachable;
   }
   __THREW__ = 0;
   invoke_viii(3262,($78|0),1,1);
   $83 = __THREW__; __THREW__ = 0;
   $84 = $83&1;
   if ($84) {
    $85 = ___cxa_find_matching_catch_3(0|0)|0;
    $86 = tempRet0;
    ___clang_call_terminate($85);
    // unreachable;
   } else {
    HEAP32[$0>>2] = 0;
    ___resumeException($eh$lpad$body$indexZ2D|0);
    // unreachable;
   }
  }
 } while(0);
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $10 = ($9|0)==($7|0);
  if (!($10)) {
   $scevgep$i$i$i = ((($9)) + -4|0);
   $11 = $scevgep$i$i$i;
   $12 = $7;
   $13 = (($11) - ($12))|0;
   $14 = $13 >>> 2;
   $15 = $14 ^ -1;
   $scevgep5$i$i$i = (($9) + ($15<<2)|0);
   HEAP32[$4>>2] = $scevgep5$i$i$i;
  }
  __ZdlPv($7);
 }
 $73 = HEAP32[$0>>2]|0;
 $74 = ($73|0)==(0|0);
 if ($74) {
  HEAP32[$0>>2] = 0;
  STACKTOP = sp;return;
 }
 $75 = ((($73)) + 8|0);
 $76 = HEAP32[$75>>2]|0;HEAP32[$75>>2] = (($76-1)|0);
 $77 = ($76|0)==(1);
 if (!($77)) {
  HEAP32[$0>>2] = 0;
  STACKTOP = sp;return;
 }
 __ZNK3osg10Referenced24signalObserversAndDeleteEbb($73,1,1);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN3osg5StateD2Ev($0) {
 $0 = $0|0;
 var $$1 = 0, $$110 = 0, $$19 = 0, $$1928 = 0, $$2 = 0, $$20 = 0, $$2029 = 0, $$21 = 0, $$211 = 0, $$2130 = 0, $$22 = 0, $$2231 = 0, $$23 = 0, $$2332 = 0, $$24 = 0, $$2433 = 0, $$25 = 0, $$2534 = 0, $$26 = 0, $$2635 = 0;
 var $$27 = 0, $$2736 = 0, $$28 = 0, $$2837 = 0, $$29 = 0, $$2938 = 0, $$3 = 0, $$31 = 0, $$312 = 0, $$3140 = 0, $$32 = 0, $$3241 = 0, $$4 = 0, $$413 = 0, $$pre$i = 0, $$pre$i105 = 0, $$pre$i111 = 0, $$pre$i120 = 0, $$pre$i51 = 0, $$pre$i54 = 0;
 var $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0;
 var $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0;
 var $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0;
 var $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0;
 var $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0;
 var $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0;
 var $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0;
 var $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0;
 var $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0;
 var $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0;
 var $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0;
 var $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0;
 var $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0;
 var $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0;
 var $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0;
 var $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0;
 var $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0;
 var $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0;
 var $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0;
 var $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0;
 var $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0;
 var $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0;
 var $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0;
 var $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0;
 var $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0;
 var $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0;
 var $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0;
 var $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0;
 var $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0;
 var $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0;
 var $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0;
 var $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0;
 var $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0;
 var $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0;
 var $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0;
 var $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0;
 var $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0;
 var $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0;
 var $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = 0, $800 = 0;
 var $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0;
 var $82 = 0, $820 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $scevgep$i$i$i = 0, $scevgep$i$i$i170 = 0, $scevgep$i$i$i170$1 = 0, $scevgep$i$i$i170$2 = 0, $scevgep$i$i$i170$3 = 0, $scevgep$i$i$i180 = 0, $scevgep$i$i$i180$1 = 0, $scevgep$i$i$i180$2 = 0, $scevgep$i$i$i180$3 = 0, $scevgep$i$i$i86 = 0, $scevgep$i$i$i86$1 = 0, $scevgep$i$i$i86$2 = 0, $scevgep$i$i$i86$3 = 0, $scevgep$i$i$i89 = 0, $scevgep$i$i$i89$1 = 0, $scevgep$i$i$i89$2 = 0, $scevgep$i$i$i89$3 = 0, $scevgep$i$i$i98 = 0, $scevgep5$i$i$i = 0, $scevgep5$i$i$i171 = 0;
 var $scevgep5$i$i$i171$1 = 0, $scevgep5$i$i$i171$2 = 0, $scevgep5$i$i$i171$3 = 0, $scevgep5$i$i$i181 = 0, $scevgep5$i$i$i181$1 = 0, $scevgep5$i$i$i181$2 = 0, $scevgep5$i$i$i181$3 = 0, $scevgep5$i$i$i87 = 0, $scevgep5$i$i$i87$1 = 0, $scevgep5$i$i$i87$2 = 0, $scevgep5$i$i$i87$3 = 0, $scevgep5$i$i$i90 = 0, $scevgep5$i$i$i90$1 = 0, $scevgep5$i$i$i90$2 = 0, $scevgep5$i$i$i90$3 = 0, $scevgep5$i$i$i99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (66172);
 $1 = ((($0)) + 784|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 do {
  if ($3) {
   label = 8;
  } else {
   HEAP32[$1>>2] = 0;
   $4 = ((($2)) + 8|0);
   $5 = HEAP32[$4>>2]|0;HEAP32[$4>>2] = (($5-1)|0);
   $6 = ($5|0)==(1);
   if ($6) {
    __THREW__ = 0;
    invoke_viii(3262,($2|0),1,1);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     label = 4;
    }
   } else {
    label = 4;
   }
   if ((label|0) == 4) {
    $9 = ((($0)) + 124|0);
    $10 = HEAP32[$9>>2]|0;
    __THREW__ = 0;
    $11 = (invoke_iii(3718,($10|0),0)|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     $14 = ($11|0)==(0|0);
     if ($14) {
      label = 8;
      break;
     }
     /* fence */;
     $15 = ((($11)) + 8|0);
     $16 = HEAP32[$15>>2]|0;
     $17 = ($16|0)==(1);
     if (!($17)) {
      label = 8;
      break;
     }
     $18 = HEAP32[$9>>2]|0;
     __THREW__ = 0;
     invoke_vii(3917,($18|0),(0|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if (!($20)) {
      label = 8;
      break;
     }
    }
   }
   $338 = ___cxa_find_matching_catch_2()|0;
   $339 = tempRet0;
   $340 = ((($0)) + 860|0);
   $341 = HEAP32[$340>>2]|0;
   $342 = ($341|0)==(0|0);
   if (!($342)) {
    $343 = ((($341)) + 8|0);
    $344 = HEAP32[$343>>2]|0;HEAP32[$343>>2] = (($344-1)|0);
    $345 = ($344|0)==(1);
    if ($345) {
     __THREW__ = 0;
     invoke_viii(3262,($341|0),1,1);
     $346 = __THREW__; __THREW__ = 0;
     $347 = $346&1;
     if ($347) {
      $687 = ___cxa_find_matching_catch_3(0|0)|0;
      $688 = tempRet0;
      ___clang_call_terminate($687);
      // unreachable;
     }
    }
   }
   HEAP32[$340>>2] = 0;
   $$1 = $338;$$110 = $339;
   label = 127;
  }
 } while(0);
 L16: do {
  if ((label|0) == 8) {
   $21 = ((($0)) + 860|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = ($22|0)==(0|0);
   if (!($23)) {
    $24 = ((($22)) + 8|0);
    $25 = HEAP32[$24>>2]|0;HEAP32[$24>>2] = (($25-1)|0);
    $26 = ($25|0)==(1);
    if ($26) {
     __THREW__ = 0;
     invoke_viii(3262,($22|0),1,1);
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     if ($28) {
      $336 = ___cxa_find_matching_catch_2()|0;
      $337 = tempRet0;
      $$1 = $336;$$110 = $337;
      label = 127;
      break;
     }
    }
   }
   HEAP32[$21>>2] = 0;
   $29 = ((($0)) + 796|0);
   __THREW__ = 0;
   invoke_vi(2450,($29|0));
   $30 = __THREW__; __THREW__ = 0;
   $31 = $30&1;
   if ($31) {
    $348 = ___cxa_find_matching_catch_2()|0;
    $349 = tempRet0;
    $$2 = $348;$$211 = $349;
    label = 129;
    break;
   }
   $32 = ((($0)) + 792|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = ($33|0)==(0|0);
   if (!($34)) {
    $35 = ((($33)) + 8|0);
    $36 = HEAP32[$35>>2]|0;HEAP32[$35>>2] = (($36-1)|0);
    $37 = ($36|0)==(1);
    if ($37) {
     __THREW__ = 0;
     invoke_viii(3262,($33|0),1,1);
     $38 = __THREW__; __THREW__ = 0;
     $39 = $38&1;
     if ($39) {
      $353 = ___cxa_find_matching_catch_2()|0;
      $354 = tempRet0;
      $$3 = $353;$$312 = $354;
      label = 134;
      break;
     }
    }
   }
   HEAP32[$32>>2] = 0;
   $40 = HEAP32[$1>>2]|0;
   $41 = ($40|0)==(0|0);
   if (!($41)) {
    $42 = ((($40)) + 8|0);
    $43 = HEAP32[$42>>2]|0;HEAP32[$42>>2] = (($43-1)|0);
    $44 = ($43|0)==(1);
    if ($44) {
     __THREW__ = 0;
     invoke_viii(3262,($40|0),1,1);
     $45 = __THREW__; __THREW__ = 0;
     $46 = $45&1;
     if ($46) {
      $363 = ___cxa_find_matching_catch_2()|0;
      $364 = tempRet0;
      $$4 = $363;$$413 = $364;
      label = 138;
      break;
     }
    }
   }
   HEAP32[$1>>2] = 0;
   $47 = ((($0)) + 668|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = ($48|0)==(0|0);
   if (!($49)) {
    $50 = ((($0)) + 672|0);
    $51 = HEAP32[$50>>2]|0;
    $52 = ($51|0)==($48|0);
    if (!($52)) {
     $scevgep$i$i$i = ((($51)) + -4|0);
     $53 = $scevgep$i$i$i;
     $54 = $48;
     $55 = (($53) - ($54))|0;
     $56 = $55 >>> 2;
     $57 = $56 ^ -1;
     $scevgep5$i$i$i = (($51) + ($57<<2)|0);
     HEAP32[$50>>2] = $scevgep5$i$i$i;
    }
    __ZdlPv($48);
   }
   $58 = ((($0)) + 652|0);
   $59 = HEAP32[$58>>2]|0;
   $60 = ($59|0)==(0|0);
   if (!($60)) {
    $61 = ((($0)) + 656|0);
    $62 = HEAP32[$61>>2]|0;
    $63 = ($62|0)==($59|0);
    if ($63) {
     $70 = $59;
    } else {
     $65 = $62;
     while(1) {
      $64 = ((($65)) + -12|0);
      HEAP32[$61>>2] = $64;
      $66 = ((($65)) + -8|0);
      $67 = HEAP32[$66>>2]|0;
      __ZNSt3__26__treeINS_12__value_typeINS_4pairIN3osg14StateAttribute4TypeEjEENS3_5State14AttributeStackEEENS_19__map_value_compareIS6_S9_NS_4lessIS6_EELb1EEENS_9allocatorIS9_EEE7destroyEPNS_11__tree_nodeIS9_PvEE($64,$67);
      $68 = HEAP32[$61>>2]|0;
      $69 = ($68|0)==($59|0);
      if ($69) {
       break;
      } else {
       $65 = $68;
      }
     }
     $$pre$i = HEAP32[$58>>2]|0;
     $70 = $$pre$i;
    }
    __ZdlPv($70);
   }
   $71 = ((($0)) + 640|0);
   $72 = HEAP32[$71>>2]|0;
   $73 = ($72|0)==(0|0);
   if (!($73)) {
    $74 = ((($0)) + 644|0);
    $75 = HEAP32[$74>>2]|0;
    $76 = ($75|0)==($72|0);
    if ($76) {
     $83 = $72;
    } else {
     $78 = $75;
     while(1) {
      $77 = ((($78)) + -12|0);
      HEAP32[$74>>2] = $77;
      $79 = ((($78)) + -8|0);
      $80 = HEAP32[$79>>2]|0;
      __ZNSt3__26__treeINS_12__value_typeIjN3osg5State9ModeStackEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($77,$80);
      $81 = HEAP32[$74>>2]|0;
      $82 = ($81|0)==($72|0);
      if ($82) {
       break;
      } else {
       $78 = $81;
      }
     }
     $$pre$i51 = HEAP32[$71>>2]|0;
     $83 = $$pre$i51;
    }
    __ZdlPv($83);
   }
   $84 = ((($0)) + 628|0);
   $85 = ((($0)) + 632|0);
   $86 = HEAP32[$85>>2]|0;
   __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4pairIS7_jEEEENS_19__map_value_compareIS7_SA_NS_4lessIS7_EELb1EEENS5_ISA_EEE7destroyEPNS_11__tree_nodeISA_PvEE($84,$86);
   $87 = ((($0)) + 612|0);
   $88 = ((($0)) + 616|0);
   $89 = HEAP32[$88>>2]|0;
   __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg5State11DefineStackEEENS_19__map_value_compareIS7_SB_NS_4lessIS7_EELb1EEENS5_ISB_EEE7destroyEPNS_11__tree_nodeISB_PvEE($87,$89);
   $90 = ((($0)) + 600|0);
   $91 = ((($0)) + 604|0);
   $92 = HEAP32[$91>>2]|0;
   __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg5State12UniformStackEEENS_19__map_value_compareIS7_SB_NS_4lessIS7_EELb1EEENS5_ISB_EEE7destroyEPNS_11__tree_nodeISB_PvEE($90,$92);
   $93 = ((($0)) + 588|0);
   $94 = ((($0)) + 592|0);
   $95 = HEAP32[$94>>2]|0;
   __ZNSt3__26__treeINS_12__value_typeINS_4pairIN3osg14StateAttribute4TypeEjEENS3_5State14AttributeStackEEENS_19__map_value_compareIS6_S9_NS_4lessIS6_EELb1EEENS_9allocatorIS9_EEE7destroyEPNS_11__tree_nodeIS9_PvEE($93,$95);
   $96 = ((($0)) + 576|0);
   $97 = ((($0)) + 580|0);
   $98 = HEAP32[$97>>2]|0;
   __ZNSt3__26__treeINS_12__value_typeIjN3osg5State9ModeStackEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($96,$98);
   $99 = ((($0)) + 564|0);
   $100 = ((($0)) + 568|0);
   $101 = HEAP32[$100>>2]|0;
   __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEjEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($99,$101);
   $102 = ((($0)) + 552|0);
   $103 = HEAP32[$102>>2]|0;
   $104 = ($103|0)==(0|0);
   if (!($104)) {
    $105 = ((($0)) + 556|0);
    $106 = HEAP32[$105>>2]|0;
    $107 = ($106|0)==($103|0);
    if ($107) {
     $127 = $103;
    } else {
     $109 = $106;
     while(1) {
      $108 = ((($109)) + -40|0);
      HEAP32[$105>>2] = $108;
      $110 = ((($109)) + -12|0);
      $111 = ((($110)) + 11|0);
      $112 = HEAP8[$111>>0]|0;
      $113 = ($112<<24>>24)<(0);
      if ($113) {
       $114 = HEAP32[$110>>2]|0;
       __ZdlPv($114);
      }
      $115 = ((($109)) + -24|0);
      $116 = ((($115)) + 11|0);
      $117 = HEAP8[$116>>0]|0;
      $118 = ($117<<24>>24)<(0);
      if ($118) {
       $119 = HEAP32[$115>>2]|0;
       __ZdlPv($119);
      }
      $120 = ((($109)) + -36|0);
      $121 = ((($120)) + 11|0);
      $122 = HEAP8[$121>>0]|0;
      $123 = ($122<<24>>24)<(0);
      if ($123) {
       $126 = HEAP32[$120>>2]|0;
       __ZdlPv($126);
      }
      $124 = HEAP32[$105>>2]|0;
      $125 = ($124|0)==($103|0);
      if ($125) {
       break;
      } else {
       $109 = $124;
      }
     }
     $$pre$i54 = HEAP32[$102>>2]|0;
     $127 = $$pre$i54;
    }
    __ZdlPv($127);
   }
   $128 = ((($0)) + 540|0);
   $129 = ((($128)) + 11|0);
   $130 = HEAP8[$129>>0]|0;
   $131 = ($130<<24>>24)<(0);
   if ($131) {
    $132 = HEAP32[$128>>2]|0;
    __ZdlPv($132);
   }
   $133 = ((($0)) + 528|0);
   $134 = ((($133)) + 11|0);
   $135 = HEAP8[$134>>0]|0;
   $136 = ($135<<24>>24)<(0);
   if ($136) {
    $137 = HEAP32[$133>>2]|0;
    __ZdlPv($137);
   }
   $138 = ((($0)) + 516|0);
   $139 = ((($138)) + 11|0);
   $140 = HEAP8[$139>>0]|0;
   $141 = ($140<<24>>24)<(0);
   if ($141) {
    $142 = HEAP32[$138>>2]|0;
    __ZdlPv($142);
   }
   $143 = ((($0)) + 500|0);
   $144 = ((($143)) + 11|0);
   $145 = HEAP8[$144>>0]|0;
   $146 = ($145<<24>>24)<(0);
   if ($146) {
    $147 = HEAP32[$143>>2]|0;
    __ZdlPv($147);
   }
   $148 = ((($0)) + 488|0);
   $149 = ((($148)) + 11|0);
   $150 = HEAP8[$149>>0]|0;
   $151 = ($150<<24>>24)<(0);
   if ($151) {
    $152 = HEAP32[$148>>2]|0;
    __ZdlPv($152);
   }
   $153 = ((($0)) + 476|0);
   $154 = ((($153)) + 11|0);
   $155 = HEAP8[$154>>0]|0;
   $156 = ($155<<24>>24)<(0);
   if ($156) {
    $157 = HEAP32[$153>>2]|0;
    __ZdlPv($157);
   }
   $158 = ((($0)) + 460|0);
   $159 = ((($158)) + 11|0);
   $160 = HEAP8[$159>>0]|0;
   $161 = ($160<<24>>24)<(0);
   if ($161) {
    $162 = HEAP32[$158>>2]|0;
    __ZdlPv($162);
   }
   $163 = ((($0)) + 448|0);
   $164 = ((($163)) + 11|0);
   $165 = HEAP8[$164>>0]|0;
   $166 = ($165<<24>>24)<(0);
   if ($166) {
    $167 = HEAP32[$163>>2]|0;
    __ZdlPv($167);
   }
   $168 = ((($0)) + 436|0);
   $169 = ((($168)) + 11|0);
   $170 = HEAP8[$169>>0]|0;
   $171 = ($170<<24>>24)<(0);
   if ($171) {
    $172 = HEAP32[$168>>2]|0;
    __ZdlPv($172);
   }
   $173 = ((($0)) + 420|0);
   $174 = ((($173)) + 11|0);
   $175 = HEAP8[$174>>0]|0;
   $176 = ($175<<24>>24)<(0);
   if ($176) {
    $177 = HEAP32[$173>>2]|0;
    __ZdlPv($177);
   }
   $178 = ((($0)) + 408|0);
   $179 = ((($178)) + 11|0);
   $180 = HEAP8[$179>>0]|0;
   $181 = ($180<<24>>24)<(0);
   if ($181) {
    $182 = HEAP32[$178>>2]|0;
    __ZdlPv($182);
   }
   $183 = ((($0)) + 396|0);
   $184 = ((($183)) + 11|0);
   $185 = HEAP8[$184>>0]|0;
   $186 = ($185<<24>>24)<(0);
   if ($186) {
    $187 = HEAP32[$183>>2]|0;
    __ZdlPv($187);
   }
   $188 = ((($0)) + 380|0);
   $189 = ((($188)) + 11|0);
   $190 = HEAP8[$189>>0]|0;
   $191 = ($190<<24>>24)<(0);
   if ($191) {
    $192 = HEAP32[$188>>2]|0;
    __ZdlPv($192);
   }
   $193 = ((($0)) + 368|0);
   $194 = ((($193)) + 11|0);
   $195 = HEAP8[$194>>0]|0;
   $196 = ($195<<24>>24)<(0);
   if ($196) {
    $197 = HEAP32[$193>>2]|0;
    __ZdlPv($197);
   }
   $198 = ((($0)) + 356|0);
   $199 = ((($198)) + 11|0);
   $200 = HEAP8[$199>>0]|0;
   $201 = ($200<<24>>24)<(0);
   if ($201) {
    $202 = HEAP32[$198>>2]|0;
    __ZdlPv($202);
   }
   $203 = ((($0)) + 336|0);
   $204 = HEAP32[$203>>2]|0;
   $205 = ($204|0)==(0|0);
   do {
    if (!($205)) {
     $206 = ((($204)) + 8|0);
     $207 = HEAP32[$206>>2]|0;HEAP32[$206>>2] = (($207-1)|0);
     $208 = ($207|0)==(1);
     if (!($208)) {
      break;
     }
     __THREW__ = 0;
     invoke_viii(3262,($204|0),1,1);
     $209 = __THREW__; __THREW__ = 0;
     $210 = $209&1;
     if (!($210)) {
      break;
     }
     $528 = ___cxa_find_matching_catch_2()|0;
     $529 = tempRet0;
     $$19 = $528;$$1928 = $529;
     label = 198;
     break L16;
    }
   } while(0);
   HEAP32[$203>>2] = 0;
   $211 = ((($0)) + 200|0);
   $212 = HEAP32[$211>>2]|0;
   $213 = ($212|0)==(0|0);
   do {
    if (!($213)) {
     $214 = ((($212)) + 8|0);
     $215 = HEAP32[$214>>2]|0;HEAP32[$214>>2] = (($215-1)|0);
     $216 = ($215|0)==(1);
     if (!($216)) {
      break;
     }
     __THREW__ = 0;
     invoke_viii(3262,($212|0),1,1);
     $217 = __THREW__; __THREW__ = 0;
     $218 = $217&1;
     if (!($218)) {
      break;
     }
     $546 = ___cxa_find_matching_catch_2()|0;
     $547 = tempRet0;
     $$20 = $546;$$2029 = $547;
     label = 204;
     break L16;
    }
   } while(0);
   HEAP32[$211>>2] = 0;
   $219 = ((($0)) + 196|0);
   $220 = HEAP32[$219>>2]|0;
   $221 = ($220|0)==(0|0);
   do {
    if (!($221)) {
     $222 = ((($220)) + 8|0);
     $223 = HEAP32[$222>>2]|0;HEAP32[$222>>2] = (($223-1)|0);
     $224 = ($223|0)==(1);
     if (!($224)) {
      break;
     }
     __THREW__ = 0;
     invoke_viii(3262,($220|0),1,1);
     $225 = __THREW__; __THREW__ = 0;
     $226 = $225&1;
     if (!($226)) {
      break;
     }
     $548 = ___cxa_find_matching_catch_2()|0;
     $549 = tempRet0;
     $$21 = $548;$$2130 = $549;
     label = 209;
     break L16;
    }
   } while(0);
   HEAP32[$219>>2] = 0;
   $227 = ((($0)) + 192|0);
   $228 = HEAP32[$227>>2]|0;
   $229 = ($228|0)==(0|0);
   do {
    if (!($229)) {
     $230 = ((($228)) + 8|0);
     $231 = HEAP32[$230>>2]|0;HEAP32[$230>>2] = (($231-1)|0);
     $232 = ($231|0)==(1);
     if (!($232)) {
      break;
     }
     __THREW__ = 0;
     invoke_viii(3262,($228|0),1,1);
     $233 = __THREW__; __THREW__ = 0;
     $234 = $233&1;
     if (!($234)) {
      break;
     }
     $558 = ___cxa_find_matching_catch_2()|0;
     $559 = tempRet0;
     $$22 = $558;$$2231 = $559;
     label = 214;
     break L16;
    }
   } while(0);
   HEAP32[$227>>2] = 0;
   $235 = ((($0)) + 188|0);
   $236 = HEAP32[$235>>2]|0;
   $237 = ($236|0)==(0|0);
   do {
    if (!($237)) {
     $238 = ((($236)) + 8|0);
     $239 = HEAP32[$238>>2]|0;HEAP32[$238>>2] = (($239-1)|0);
     $240 = ($239|0)==(1);
     if (!($240)) {
      break;
     }
     __THREW__ = 0;
     invoke_viii(3262,($236|0),1,1);
     $241 = __THREW__; __THREW__ = 0;
     $242 = $241&1;
     if (!($242)) {
      break;
     }
     $568 = ___cxa_find_matching_catch_2()|0;
     $569 = tempRet0;
     $$23 = $568;$$2332 = $569;
     label = 219;
     break L16;
    }
   } while(0);
   HEAP32[$235>>2] = 0;
   $243 = ((($0)) + 180|0);
   $244 = HEAP32[$243>>2]|0;
   $245 = ($244|0)==(0|0);
   do {
    if (!($245)) {
     $246 = ((($244)) + 8|0);
     $247 = HEAP32[$246>>2]|0;HEAP32[$246>>2] = (($247-1)|0);
     $248 = ($247|0)==(1);
     if (!($248)) {
      break;
     }
     __THREW__ = 0;
     invoke_viii(3262,($244|0),1,1);
     $249 = __THREW__; __THREW__ = 0;
     $250 = $249&1;
     if (!($250)) {
      break;
     }
     $578 = ___cxa_find_matching_catch_2()|0;
     $579 = tempRet0;
     $$24 = $578;$$2433 = $579;
     label = 224;
     break L16;
    }
   } while(0);
   HEAP32[$243>>2] = 0;
   $251 = ((($0)) + 176|0);
   $252 = HEAP32[$251>>2]|0;
   $253 = ($252|0)==(0|0);
   do {
    if (!($253)) {
     $254 = ((($252)) + 8|0);
     $255 = HEAP32[$254>>2]|0;HEAP32[$254>>2] = (($255-1)|0);
     $256 = ($255|0)==(1);
     if (!($256)) {
      break;
     }
     __THREW__ = 0;
     invoke_viii(3262,($252|0),1,1);
     $257 = __THREW__; __THREW__ = 0;
     $258 = $257&1;
     if (!($258)) {
      break;
     }
     $588 = ___cxa_find_matching_catch_2()|0;
     $589 = tempRet0;
     $$25 = $588;$$2534 = $589;
     label = 229;
     break L16;
    }
   } while(0);
   HEAP32[$251>>2] = 0;
   $259 = ((($0)) + 172|0);
   $260 = HEAP32[$259>>2]|0;
   $261 = ($260|0)==(0|0);
   do {
    if (!($261)) {
     $262 = ((($260)) + 8|0);
     $263 = HEAP32[$262>>2]|0;HEAP32[$262>>2] = (($263-1)|0);
     $264 = ($263|0)==(1);
     if (!($264)) {
      break;
     }
     __THREW__ = 0;
     invoke_viii(3262,($260|0),1,1);
     $265 = __THREW__; __THREW__ = 0;
     $266 = $265&1;
     if (!($266)) {
      break;
     }
     $598 = ___cxa_find_matching_catch_2()|0;
     $599 = tempRet0;
     $$26 = $598;$$2635 = $599;
     label = 234;
     break L16;
    }
   } while(0);
   HEAP32[$259>>2] = 0;
   $267 = ((($0)) + 168|0);
   $268 = HEAP32[$267>>2]|0;
   $269 = ($268|0)==(0|0);
   do {
    if (!($269)) {
     $270 = ((($268)) + 8|0);
     $271 = HEAP32[$270>>2]|0;HEAP32[$270>>2] = (($271-1)|0);
     $272 = ($271|0)==(1);
     if (!($272)) {
      break;
     }
     __THREW__ = 0;
     invoke_viii(3262,($268|0),1,1);
     $273 = __THREW__; __THREW__ = 0;
     $274 = $273&1;
     if (!($274)) {
      break;
     }
     $608 = ___cxa_find_matching_catch_2()|0;
     $609 = tempRet0;
     $$27 = $608;$$2736 = $609;
     label = 239;
     break L16;
    }
   } while(0);
   HEAP32[$267>>2] = 0;
   $275 = ((($0)) + 164|0);
   $276 = HEAP32[$275>>2]|0;
   $277 = ($276|0)==(0|0);
   do {
    if (!($277)) {
     $278 = ((($276)) + 8|0);
     $279 = HEAP32[$278>>2]|0;HEAP32[$278>>2] = (($279-1)|0);
     $280 = ($279|0)==(1);
     if (!($280)) {
      break;
     }
     __THREW__ = 0;
     invoke_viii(3262,($276|0),1,1);
     $281 = __THREW__; __THREW__ = 0;
     $282 = $281&1;
     if (!($282)) {
      break;
     }
     $618 = ___cxa_find_matching_catch_2()|0;
     $619 = tempRet0;
     $$28 = $618;$$2837 = $619;
     label = 244;
     break L16;
    }
   } while(0);
   HEAP32[$275>>2] = 0;
   $283 = ((($0)) + 160|0);
   $284 = HEAP32[$283>>2]|0;
   $285 = ($284|0)==(0|0);
   do {
    if (!($285)) {
     $286 = ((($284)) + 8|0);
     $287 = HEAP32[$286>>2]|0;HEAP32[$286>>2] = (($287-1)|0);
     $288 = ($287|0)==(1);
     if (!($288)) {
      break;
     }
     __THREW__ = 0;
     invoke_viii(3262,($284|0),1,1);
     $289 = __THREW__; __THREW__ = 0;
     $290 = $289&1;
     if (!($290)) {
      break;
     }
     $628 = ___cxa_find_matching_catch_2()|0;
     $629 = tempRet0;
     $$29 = $628;$$2938 = $629;
     label = 249;
     break L16;
    }
   } while(0);
   HEAP32[$283>>2] = 0;
   $291 = ((($0)) + 148|0);
   $292 = ((($0)) + 152|0);
   $293 = HEAP32[$292>>2]|0;
   __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4pairIN3osg7ref_ptrINS9_7UniformEEEjEEEENS_19__map_value_compareIS7_SE_NS_4lessIS7_EELb1EEENS5_ISE_EEE7destroyEPNS_11__tree_nodeISE_PvEE($291,$293);
   $294 = ((($0)) + 140|0);
   $295 = HEAP32[$294>>2]|0;
   $296 = ($295|0)==(0|0);
   do {
    if (!($296)) {
     $297 = ((($295)) + 8|0);
     $298 = HEAP32[$297>>2]|0;HEAP32[$297>>2] = (($298-1)|0);
     $299 = ($298|0)==(1);
     if (!($299)) {
      break;
     }
     __THREW__ = 0;
     invoke_viii(3262,($295|0),1,1);
     $300 = __THREW__; __THREW__ = 0;
     $301 = $300&1;
     if (!($301)) {
      break;
     }
     $638 = ___cxa_find_matching_catch_2()|0;
     $639 = tempRet0;
     $$31 = $638;$$3140 = $639;
     label = 254;
     break L16;
    }
   } while(0);
   HEAP32[$294>>2] = 0;
   $302 = ((($0)) + 128|0);
   $303 = HEAP32[$302>>2]|0;
   $304 = ($303|0)==(0|0);
   do {
    if (!($304)) {
     $305 = ((($303)) + 8|0);
     $306 = HEAP32[$305>>2]|0;HEAP32[$305>>2] = (($306-1)|0);
     $307 = ($306|0)==(1);
     if (!($307)) {
      break;
     }
     __THREW__ = 0;
     invoke_viii(3262,($303|0),1,1);
     $308 = __THREW__; __THREW__ = 0;
     $309 = $308&1;
     if (!($309)) {
      break;
     }
     $651 = ___cxa_find_matching_catch_2()|0;
     $652 = tempRet0;
     $$32 = $651;$$3241 = $652;
     break L16;
    }
   } while(0);
   HEAP32[$302>>2] = 0;
   $310 = ((($0)) + 108|0);
   $311 = HEAP32[$310>>2]|0;
   $312 = ($311|0)==(0|0);
   if (!($312)) {
    $313 = ((($0)) + 112|0);
    $314 = HEAP32[$313>>2]|0;
    $315 = ($314|0)==($311|0);
    if (!($315)) {
     $scevgep$i$i$i86 = ((($314)) + -4|0);
     $316 = $scevgep$i$i$i86;
     $317 = $311;
     $318 = (($316) - ($317))|0;
     $319 = $318 >>> 2;
     $320 = $319 ^ -1;
     $scevgep5$i$i$i87 = (($314) + ($320<<2)|0);
     HEAP32[$313>>2] = $scevgep5$i$i$i87;
    }
    __ZdlPv($311);
   }
   $321 = ((($0)) + 96|0);
   $322 = HEAP32[$321>>2]|0;
   $323 = ($322|0)==(0|0);
   if (!($323)) {
    $722 = ((($0)) + 100|0);
    $723 = HEAP32[$722>>2]|0;
    $724 = ($723|0)==($322|0);
    if (!($724)) {
     $scevgep$i$i$i86$1 = ((($723)) + -4|0);
     $725 = $scevgep$i$i$i86$1;
     $726 = $322;
     $727 = (($725) - ($726))|0;
     $728 = $727 >>> 2;
     $729 = $728 ^ -1;
     $scevgep5$i$i$i87$1 = (($723) + ($729<<2)|0);
     HEAP32[$722>>2] = $scevgep5$i$i$i87$1;
    }
    __ZdlPv($322);
   }
   $730 = ((($0)) + 84|0);
   $731 = HEAP32[$730>>2]|0;
   $732 = ($731|0)==(0|0);
   if (!($732)) {
    $733 = ((($0)) + 88|0);
    $734 = HEAP32[$733>>2]|0;
    $735 = ($734|0)==($731|0);
    if (!($735)) {
     $scevgep$i$i$i86$2 = ((($734)) + -4|0);
     $736 = $scevgep$i$i$i86$2;
     $737 = $731;
     $738 = (($736) - ($737))|0;
     $739 = $738 >>> 2;
     $740 = $739 ^ -1;
     $scevgep5$i$i$i87$2 = (($734) + ($740<<2)|0);
     HEAP32[$733>>2] = $scevgep5$i$i$i87$2;
    }
    __ZdlPv($731);
   }
   $741 = ((($0)) + 72|0);
   $742 = HEAP32[$741>>2]|0;
   $743 = ($742|0)==(0|0);
   if (!($743)) {
    $744 = ((($0)) + 76|0);
    $745 = HEAP32[$744>>2]|0;
    $746 = ($745|0)==($742|0);
    if (!($746)) {
     $scevgep$i$i$i86$3 = ((($745)) + -4|0);
     $747 = $scevgep$i$i$i86$3;
     $748 = $742;
     $749 = (($747) - ($748))|0;
     $750 = $749 >>> 2;
     $751 = $750 ^ -1;
     $scevgep5$i$i$i87$3 = (($745) + ($751<<2)|0);
     HEAP32[$744>>2] = $scevgep5$i$i$i87$3;
    }
    __ZdlPv($742);
   }
   $752 = ((($0)) + 60|0);
   $327 = HEAP32[$752>>2]|0;
   $753 = ($327|0)==(0|0);
   if (!($753)) {
    $324 = ((($0)) + 64|0);
    $325 = HEAP32[$324>>2]|0;
    $326 = ($325|0)==($327|0);
    if (!($326)) {
     $scevgep$i$i$i89 = ((($325)) + -2|0);
     $328 = $scevgep$i$i$i89;
     $329 = $327;
     $330 = (($328) - ($329))|0;
     $331 = $330 >>> 1;
     $332 = $331 ^ -1;
     $scevgep5$i$i$i90 = (($325) + ($332<<1)|0);
     HEAP32[$324>>2] = $scevgep5$i$i$i90;
    }
    __ZdlPv($327);
   }
   $333 = ((($0)) + 48|0);
   $334 = HEAP32[$333>>2]|0;
   $335 = ($334|0)==(0|0);
   if (!($335)) {
    $689 = ((($0)) + 52|0);
    $690 = HEAP32[$689>>2]|0;
    $691 = ($690|0)==($334|0);
    if (!($691)) {
     $scevgep$i$i$i89$1 = ((($690)) + -2|0);
     $692 = $scevgep$i$i$i89$1;
     $693 = $334;
     $694 = (($692) - ($693))|0;
     $695 = $694 >>> 1;
     $696 = $695 ^ -1;
     $scevgep5$i$i$i90$1 = (($690) + ($696<<1)|0);
     HEAP32[$689>>2] = $scevgep5$i$i$i90$1;
    }
    __ZdlPv($334);
   }
   $697 = ((($0)) + 36|0);
   $698 = HEAP32[$697>>2]|0;
   $699 = ($698|0)==(0|0);
   if (!($699)) {
    $700 = ((($0)) + 40|0);
    $701 = HEAP32[$700>>2]|0;
    $702 = ($701|0)==($698|0);
    if (!($702)) {
     $scevgep$i$i$i89$2 = ((($701)) + -2|0);
     $703 = $scevgep$i$i$i89$2;
     $704 = $698;
     $705 = (($703) - ($704))|0;
     $706 = $705 >>> 1;
     $707 = $706 ^ -1;
     $scevgep5$i$i$i90$2 = (($701) + ($707<<1)|0);
     HEAP32[$700>>2] = $scevgep5$i$i$i90$2;
    }
    __ZdlPv($698);
   }
   $708 = ((($0)) + 24|0);
   $709 = HEAP32[$708>>2]|0;
   $710 = ($709|0)==(0|0);
   if ($710) {
    $719 = ((($0)) + 12|0);
    $720 = ((($0)) + 16|0);
    $721 = HEAP32[$720>>2]|0;
    __ZNSt3__26__treeINS_12__value_typeIPKSt9type_infoN3osg7ref_ptrINS5_10ReferencedEEEEENS_19__map_value_compareIS4_S9_NS_4lessIS4_EELb1EEENS_9allocatorIS9_EEE7destroyEPNS_11__tree_nodeIS9_PvEE($719,$721);
    __ZN3osg10ReferencedD2Ev($0);
    return;
   }
   $711 = ((($0)) + 28|0);
   $712 = HEAP32[$711>>2]|0;
   $713 = ($712|0)==($709|0);
   if (!($713)) {
    $scevgep$i$i$i89$3 = ((($712)) + -2|0);
    $714 = $scevgep$i$i$i89$3;
    $715 = $709;
    $716 = (($714) - ($715))|0;
    $717 = $716 >>> 1;
    $718 = $717 ^ -1;
    $scevgep5$i$i$i90$3 = (($712) + ($718<<1)|0);
    HEAP32[$711>>2] = $scevgep5$i$i$i90$3;
   }
   __ZdlPv($709);
   $719 = ((($0)) + 12|0);
   $720 = ((($0)) + 16|0);
   $721 = HEAP32[$720>>2]|0;
   __ZNSt3__26__treeINS_12__value_typeIPKSt9type_infoN3osg7ref_ptrINS5_10ReferencedEEEEENS_19__map_value_compareIS4_S9_NS_4lessIS4_EELb1EEENS_9allocatorIS9_EEE7destroyEPNS_11__tree_nodeIS9_PvEE($719,$721);
   __ZN3osg10ReferencedD2Ev($0);
   return;
  }
 } while(0);
 if ((label|0) == 127) {
  $350 = ((($0)) + 796|0);
  __THREW__ = 0;
  invoke_vi(2450,($350|0));
  $351 = __THREW__; __THREW__ = 0;
  $352 = $351&1;
  if ($352) {
   $687 = ___cxa_find_matching_catch_3(0|0)|0;
   $688 = tempRet0;
   ___clang_call_terminate($687);
   // unreachable;
  } else {
   $$2 = $$1;$$211 = $$110;
   label = 129;
  }
 }
 if ((label|0) == 129) {
  $355 = ((($0)) + 792|0);
  $356 = HEAP32[$355>>2]|0;
  $357 = ($356|0)==(0|0);
  if (!($357)) {
   $358 = ((($356)) + 8|0);
   $359 = HEAP32[$358>>2]|0;HEAP32[$358>>2] = (($359-1)|0);
   $360 = ($359|0)==(1);
   if ($360) {
    __THREW__ = 0;
    invoke_viii(3262,($356|0),1,1);
    $361 = __THREW__; __THREW__ = 0;
    $362 = $361&1;
    if ($362) {
     $687 = ___cxa_find_matching_catch_3(0|0)|0;
     $688 = tempRet0;
     ___clang_call_terminate($687);
     // unreachable;
    }
   }
  }
  HEAP32[$355>>2] = 0;
  $$3 = $$2;$$312 = $$211;
  label = 134;
 }
 if ((label|0) == 134) {
  $365 = HEAP32[$1>>2]|0;
  $366 = ($365|0)==(0|0);
  if (!($366)) {
   $367 = ((($365)) + 8|0);
   $368 = HEAP32[$367>>2]|0;HEAP32[$367>>2] = (($368-1)|0);
   $369 = ($368|0)==(1);
   if ($369) {
    __THREW__ = 0;
    invoke_viii(3262,($365|0),1,1);
    $370 = __THREW__; __THREW__ = 0;
    $371 = $370&1;
    if ($371) {
     $687 = ___cxa_find_matching_catch_3(0|0)|0;
     $688 = tempRet0;
     ___clang_call_terminate($687);
     // unreachable;
    }
   }
  }
  HEAP32[$1>>2] = 0;
  $$4 = $$3;$$413 = $$312;
  label = 138;
 }
 if ((label|0) == 138) {
  $372 = ((($0)) + 668|0);
  $373 = HEAP32[$372>>2]|0;
  $374 = ($373|0)==(0|0);
  if (!($374)) {
   $375 = ((($0)) + 672|0);
   $376 = HEAP32[$375>>2]|0;
   $377 = ($376|0)==($373|0);
   if (!($377)) {
    $scevgep$i$i$i98 = ((($376)) + -4|0);
    $378 = $scevgep$i$i$i98;
    $379 = $373;
    $380 = (($378) - ($379))|0;
    $381 = $380 >>> 2;
    $382 = $381 ^ -1;
    $scevgep5$i$i$i99 = (($376) + ($382<<2)|0);
    HEAP32[$375>>2] = $scevgep5$i$i$i99;
   }
   __ZdlPv($373);
  }
  $383 = ((($0)) + 652|0);
  $384 = HEAP32[$383>>2]|0;
  $385 = ($384|0)==(0|0);
  if (!($385)) {
   $386 = ((($0)) + 656|0);
   $387 = HEAP32[$386>>2]|0;
   $388 = ($387|0)==($384|0);
   if ($388) {
    $395 = $384;
   } else {
    $390 = $387;
    while(1) {
     $389 = ((($390)) + -12|0);
     HEAP32[$386>>2] = $389;
     $391 = ((($390)) + -8|0);
     $392 = HEAP32[$391>>2]|0;
     __ZNSt3__26__treeINS_12__value_typeINS_4pairIN3osg14StateAttribute4TypeEjEENS3_5State14AttributeStackEEENS_19__map_value_compareIS6_S9_NS_4lessIS6_EELb1EEENS_9allocatorIS9_EEE7destroyEPNS_11__tree_nodeIS9_PvEE($389,$392);
     $393 = HEAP32[$386>>2]|0;
     $394 = ($393|0)==($384|0);
     if ($394) {
      break;
     } else {
      $390 = $393;
     }
    }
    $$pre$i105 = HEAP32[$383>>2]|0;
    $395 = $$pre$i105;
   }
   __ZdlPv($395);
  }
  $396 = ((($0)) + 640|0);
  $397 = HEAP32[$396>>2]|0;
  $398 = ($397|0)==(0|0);
  if (!($398)) {
   $399 = ((($0)) + 644|0);
   $400 = HEAP32[$399>>2]|0;
   $401 = ($400|0)==($397|0);
   if ($401) {
    $408 = $397;
   } else {
    $403 = $400;
    while(1) {
     $402 = ((($403)) + -12|0);
     HEAP32[$399>>2] = $402;
     $404 = ((($403)) + -8|0);
     $405 = HEAP32[$404>>2]|0;
     __ZNSt3__26__treeINS_12__value_typeIjN3osg5State9ModeStackEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($402,$405);
     $406 = HEAP32[$399>>2]|0;
     $407 = ($406|0)==($397|0);
     if ($407) {
      break;
     } else {
      $403 = $406;
     }
    }
    $$pre$i111 = HEAP32[$396>>2]|0;
    $408 = $$pre$i111;
   }
   __ZdlPv($408);
  }
  $409 = ((($0)) + 628|0);
  $410 = ((($0)) + 632|0);
  $411 = HEAP32[$410>>2]|0;
  __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4pairIS7_jEEEENS_19__map_value_compareIS7_SA_NS_4lessIS7_EELb1EEENS5_ISA_EEE7destroyEPNS_11__tree_nodeISA_PvEE($409,$411);
  $412 = ((($0)) + 612|0);
  $413 = ((($0)) + 616|0);
  $414 = HEAP32[$413>>2]|0;
  __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg5State11DefineStackEEENS_19__map_value_compareIS7_SB_NS_4lessIS7_EELb1EEENS5_ISB_EEE7destroyEPNS_11__tree_nodeISB_PvEE($412,$414);
  $415 = ((($0)) + 600|0);
  $416 = ((($0)) + 604|0);
  $417 = HEAP32[$416>>2]|0;
  __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg5State12UniformStackEEENS_19__map_value_compareIS7_SB_NS_4lessIS7_EELb1EEENS5_ISB_EEE7destroyEPNS_11__tree_nodeISB_PvEE($415,$417);
  $418 = ((($0)) + 588|0);
  $419 = ((($0)) + 592|0);
  $420 = HEAP32[$419>>2]|0;
  __ZNSt3__26__treeINS_12__value_typeINS_4pairIN3osg14StateAttribute4TypeEjEENS3_5State14AttributeStackEEENS_19__map_value_compareIS6_S9_NS_4lessIS6_EELb1EEENS_9allocatorIS9_EEE7destroyEPNS_11__tree_nodeIS9_PvEE($418,$420);
  $421 = ((($0)) + 576|0);
  $422 = ((($0)) + 580|0);
  $423 = HEAP32[$422>>2]|0;
  __ZNSt3__26__treeINS_12__value_typeIjN3osg5State9ModeStackEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($421,$423);
  $424 = ((($0)) + 564|0);
  $425 = ((($0)) + 568|0);
  $426 = HEAP32[$425>>2]|0;
  __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEjEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($424,$426);
  $427 = ((($0)) + 552|0);
  $428 = HEAP32[$427>>2]|0;
  $429 = ($428|0)==(0|0);
  if (!($429)) {
   $430 = ((($0)) + 556|0);
   $431 = HEAP32[$430>>2]|0;
   $432 = ($431|0)==($428|0);
   if ($432) {
    $452 = $428;
   } else {
    $434 = $431;
    while(1) {
     $433 = ((($434)) + -40|0);
     HEAP32[$430>>2] = $433;
     $435 = ((($434)) + -12|0);
     $436 = ((($435)) + 11|0);
     $437 = HEAP8[$436>>0]|0;
     $438 = ($437<<24>>24)<(0);
     if ($438) {
      $439 = HEAP32[$435>>2]|0;
      __ZdlPv($439);
     }
     $440 = ((($434)) + -24|0);
     $441 = ((($440)) + 11|0);
     $442 = HEAP8[$441>>0]|0;
     $443 = ($442<<24>>24)<(0);
     if ($443) {
      $444 = HEAP32[$440>>2]|0;
      __ZdlPv($444);
     }
     $445 = ((($434)) + -36|0);
     $446 = ((($445)) + 11|0);
     $447 = HEAP8[$446>>0]|0;
     $448 = ($447<<24>>24)<(0);
     if ($448) {
      $451 = HEAP32[$445>>2]|0;
      __ZdlPv($451);
     }
     $449 = HEAP32[$430>>2]|0;
     $450 = ($449|0)==($428|0);
     if ($450) {
      break;
     } else {
      $434 = $449;
     }
    }
    $$pre$i120 = HEAP32[$427>>2]|0;
    $452 = $$pre$i120;
   }
   __ZdlPv($452);
  }
  $453 = ((($0)) + 540|0);
  $454 = ((($453)) + 11|0);
  $455 = HEAP8[$454>>0]|0;
  $456 = ($455<<24>>24)<(0);
  if ($456) {
   $457 = HEAP32[$453>>2]|0;
   __ZdlPv($457);
  }
  $458 = ((($0)) + 528|0);
  $459 = ((($458)) + 11|0);
  $460 = HEAP8[$459>>0]|0;
  $461 = ($460<<24>>24)<(0);
  if ($461) {
   $462 = HEAP32[$458>>2]|0;
   __ZdlPv($462);
  }
  $463 = ((($0)) + 516|0);
  $464 = ((($463)) + 11|0);
  $465 = HEAP8[$464>>0]|0;
  $466 = ($465<<24>>24)<(0);
  if ($466) {
   $467 = HEAP32[$463>>2]|0;
   __ZdlPv($467);
  }
  $468 = ((($0)) + 500|0);
  $469 = ((($468)) + 11|0);
  $470 = HEAP8[$469>>0]|0;
  $471 = ($470<<24>>24)<(0);
  if ($471) {
   $472 = HEAP32[$468>>2]|0;
   __ZdlPv($472);
  }
  $473 = ((($0)) + 488|0);
  $474 = ((($473)) + 11|0);
  $475 = HEAP8[$474>>0]|0;
  $476 = ($475<<24>>24)<(0);
  if ($476) {
   $477 = HEAP32[$473>>2]|0;
   __ZdlPv($477);
  }
  $478 = ((($0)) + 476|0);
  $479 = ((($478)) + 11|0);
  $480 = HEAP8[$479>>0]|0;
  $481 = ($480<<24>>24)<(0);
  if ($481) {
   $482 = HEAP32[$478>>2]|0;
   __ZdlPv($482);
  }
  $483 = ((($0)) + 460|0);
  $484 = ((($483)) + 11|0);
  $485 = HEAP8[$484>>0]|0;
  $486 = ($485<<24>>24)<(0);
  if ($486) {
   $487 = HEAP32[$483>>2]|0;
   __ZdlPv($487);
  }
  $488 = ((($0)) + 448|0);
  $489 = ((($488)) + 11|0);
  $490 = HEAP8[$489>>0]|0;
  $491 = ($490<<24>>24)<(0);
  if ($491) {
   $492 = HEAP32[$488>>2]|0;
   __ZdlPv($492);
  }
  $493 = ((($0)) + 436|0);
  $494 = ((($493)) + 11|0);
  $495 = HEAP8[$494>>0]|0;
  $496 = ($495<<24>>24)<(0);
  if ($496) {
   $497 = HEAP32[$493>>2]|0;
   __ZdlPv($497);
  }
  $498 = ((($0)) + 420|0);
  $499 = ((($498)) + 11|0);
  $500 = HEAP8[$499>>0]|0;
  $501 = ($500<<24>>24)<(0);
  if ($501) {
   $502 = HEAP32[$498>>2]|0;
   __ZdlPv($502);
  }
  $503 = ((($0)) + 408|0);
  $504 = ((($503)) + 11|0);
  $505 = HEAP8[$504>>0]|0;
  $506 = ($505<<24>>24)<(0);
  if ($506) {
   $507 = HEAP32[$503>>2]|0;
   __ZdlPv($507);
  }
  $508 = ((($0)) + 396|0);
  $509 = ((($508)) + 11|0);
  $510 = HEAP8[$509>>0]|0;
  $511 = ($510<<24>>24)<(0);
  if ($511) {
   $512 = HEAP32[$508>>2]|0;
   __ZdlPv($512);
  }
  $513 = ((($0)) + 380|0);
  $514 = ((($513)) + 11|0);
  $515 = HEAP8[$514>>0]|0;
  $516 = ($515<<24>>24)<(0);
  if ($516) {
   $517 = HEAP32[$513>>2]|0;
   __ZdlPv($517);
  }
  $518 = ((($0)) + 368|0);
  $519 = ((($518)) + 11|0);
  $520 = HEAP8[$519>>0]|0;
  $521 = ($520<<24>>24)<(0);
  if ($521) {
   $522 = HEAP32[$518>>2]|0;
   __ZdlPv($522);
  }
  $523 = ((($0)) + 356|0);
  $524 = ((($523)) + 11|0);
  $525 = HEAP8[$524>>0]|0;
  $526 = ($525<<24>>24)<(0);
  if ($526) {
   $527 = HEAP32[$523>>2]|0;
   __ZdlPv($527);
  }
  $530 = ((($0)) + 336|0);
  $531 = HEAP32[$530>>2]|0;
  $532 = ($531|0)==(0|0);
  do {
   if (!($532)) {
    $533 = ((($531)) + 8|0);
    $534 = HEAP32[$533>>2]|0;HEAP32[$533>>2] = (($534-1)|0);
    $535 = ($534|0)==(1);
    if (!($535)) {
     break;
    }
    __THREW__ = 0;
    invoke_viii(3262,($531|0),1,1);
    $536 = __THREW__; __THREW__ = 0;
    $537 = $536&1;
    if (!($537)) {
     break;
    }
    $687 = ___cxa_find_matching_catch_3(0|0)|0;
    $688 = tempRet0;
    ___clang_call_terminate($687);
    // unreachable;
   }
  } while(0);
  HEAP32[$530>>2] = 0;
  $$19 = $$4;$$1928 = $$413;
  label = 198;
 }
 if ((label|0) == 198) {
  $538 = ((($0)) + 200|0);
  $539 = HEAP32[$538>>2]|0;
  $540 = ($539|0)==(0|0);
  if (!($540)) {
   $541 = ((($539)) + 8|0);
   $542 = HEAP32[$541>>2]|0;HEAP32[$541>>2] = (($542-1)|0);
   $543 = ($542|0)==(1);
   if ($543) {
    __THREW__ = 0;
    invoke_viii(3262,($539|0),1,1);
    $544 = __THREW__; __THREW__ = 0;
    $545 = $544&1;
    if ($545) {
     $687 = ___cxa_find_matching_catch_3(0|0)|0;
     $688 = tempRet0;
     ___clang_call_terminate($687);
     // unreachable;
    }
   }
  }
  HEAP32[$538>>2] = 0;
  $$20 = $$19;$$2029 = $$1928;
  label = 204;
 }
 if ((label|0) == 204) {
  $550 = ((($0)) + 196|0);
  $551 = HEAP32[$550>>2]|0;
  $552 = ($551|0)==(0|0);
  if (!($552)) {
   $553 = ((($551)) + 8|0);
   $554 = HEAP32[$553>>2]|0;HEAP32[$553>>2] = (($554-1)|0);
   $555 = ($554|0)==(1);
   if ($555) {
    __THREW__ = 0;
    invoke_viii(3262,($551|0),1,1);
    $556 = __THREW__; __THREW__ = 0;
    $557 = $556&1;
    if ($557) {
     $687 = ___cxa_find_matching_catch_3(0|0)|0;
     $688 = tempRet0;
     ___clang_call_terminate($687);
     // unreachable;
    }
   }
  }
  HEAP32[$550>>2] = 0;
  $$21 = $$20;$$2130 = $$2029;
  label = 209;
 }
 if ((label|0) == 209) {
  $560 = ((($0)) + 192|0);
  $561 = HEAP32[$560>>2]|0;
  $562 = ($561|0)==(0|0);
  if (!($562)) {
   $563 = ((($561)) + 8|0);
   $564 = HEAP32[$563>>2]|0;HEAP32[$563>>2] = (($564-1)|0);
   $565 = ($564|0)==(1);
   if ($565) {
    __THREW__ = 0;
    invoke_viii(3262,($561|0),1,1);
    $566 = __THREW__; __THREW__ = 0;
    $567 = $566&1;
    if ($567) {
     $687 = ___cxa_find_matching_catch_3(0|0)|0;
     $688 = tempRet0;
     ___clang_call_terminate($687);
     // unreachable;
    }
   }
  }
  HEAP32[$560>>2] = 0;
  $$22 = $$21;$$2231 = $$2130;
  label = 214;
 }
 if ((label|0) == 214) {
  $570 = ((($0)) + 188|0);
  $571 = HEAP32[$570>>2]|0;
  $572 = ($571|0)==(0|0);
  if (!($572)) {
   $573 = ((($571)) + 8|0);
   $574 = HEAP32[$573>>2]|0;HEAP32[$573>>2] = (($574-1)|0);
   $575 = ($574|0)==(1);
   if ($575) {
    __THREW__ = 0;
    invoke_viii(3262,($571|0),1,1);
    $576 = __THREW__; __THREW__ = 0;
    $577 = $576&1;
    if ($577) {
     $687 = ___cxa_find_matching_catch_3(0|0)|0;
     $688 = tempRet0;
     ___clang_call_terminate($687);
     // unreachable;
    }
   }
  }
  HEAP32[$570>>2] = 0;
  $$23 = $$22;$$2332 = $$2231;
  label = 219;
 }
 if ((label|0) == 219) {
  $580 = ((($0)) + 180|0);
  $581 = HEAP32[$580>>2]|0;
  $582 = ($581|0)==(0|0);
  if (!($582)) {
   $583 = ((($581)) + 8|0);
   $584 = HEAP32[$583>>2]|0;HEAP32[$583>>2] = (($584-1)|0);
   $585 = ($584|0)==(1);
   if ($585) {
    __THREW__ = 0;
    invoke_viii(3262,($581|0),1,1);
    $586 = __THREW__; __THREW__ = 0;
    $587 = $586&1;
    if ($587) {
     $687 = ___cxa_find_matching_catch_3(0|0)|0;
     $688 = tempRet0;
     ___clang_call_terminate($687);
     // unreachable;
    }
   }
  }
  HEAP32[$580>>2] = 0;
  $$24 = $$23;$$2433 = $$2332;
  label = 224;
 }
 if ((label|0) == 224) {
  $590 = ((($0)) + 176|0);
  $591 = HEAP32[$590>>2]|0;
  $592 = ($591|0)==(0|0);
  if (!($592)) {
   $593 = ((($591)) + 8|0);
   $594 = HEAP32[$593>>2]|0;HEAP32[$593>>2] = (($594-1)|0);
   $595 = ($594|0)==(1);
   if ($595) {
    __THREW__ = 0;
    invoke_viii(3262,($591|0),1,1);
    $596 = __THREW__; __THREW__ = 0;
    $597 = $596&1;
    if ($597) {
     $687 = ___cxa_find_matching_catch_3(0|0)|0;
     $688 = tempRet0;
     ___clang_call_terminate($687);
     // unreachable;
    }
   }
  }
  HEAP32[$590>>2] = 0;
  $$25 = $$24;$$2534 = $$2433;
  label = 229;
 }
 if ((label|0) == 229) {
  $600 = ((($0)) + 172|0);
  $601 = HEAP32[$600>>2]|0;
  $602 = ($601|0)==(0|0);
  if (!($602)) {
   $603 = ((($601)) + 8|0);
   $604 = HEAP32[$603>>2]|0;HEAP32[$603>>2] = (($604-1)|0);
   $605 = ($604|0)==(1);
   if ($605) {
    __THREW__ = 0;
    invoke_viii(3262,($601|0),1,1);
    $606 = __THREW__; __THREW__ = 0;
    $607 = $606&1;
    if ($607) {
     $687 = ___cxa_find_matching_catch_3(0|0)|0;
     $688 = tempRet0;
     ___clang_call_terminate($687);
     // unreachable;
    }
   }
  }
  HEAP32[$600>>2] = 0;
  $$26 = $$25;$$2635 = $$2534;
  label = 234;
 }
 if ((label|0) == 234) {
  $610 = ((($0)) + 168|0);
  $611 = HEAP32[$610>>2]|0;
  $612 = ($611|0)==(0|0);
  if (!($612)) {
   $613 = ((($611)) + 8|0);
   $614 = HEAP32[$613>>2]|0;HEAP32[$613>>2] = (($614-1)|0);
   $615 = ($614|0)==(1);
   if ($615) {
    __THREW__ = 0;
    invoke_viii(3262,($611|0),1,1);
    $616 = __THREW__; __THREW__ = 0;
    $617 = $616&1;
    if ($617) {
     $687 = ___cxa_find_matching_catch_3(0|0)|0;
     $688 = tempRet0;
     ___clang_call_terminate($687);
     // unreachable;
    }
   }
  }
  HEAP32[$610>>2] = 0;
  $$27 = $$26;$$2736 = $$2635;
  label = 239;
 }
 if ((label|0) == 239) {
  $620 = ((($0)) + 164|0);
  $621 = HEAP32[$620>>2]|0;
  $622 = ($621|0)==(0|0);
  if (!($622)) {
   $623 = ((($621)) + 8|0);
   $624 = HEAP32[$623>>2]|0;HEAP32[$623>>2] = (($624-1)|0);
   $625 = ($624|0)==(1);
   if ($625) {
    __THREW__ = 0;
    invoke_viii(3262,($621|0),1,1);
    $626 = __THREW__; __THREW__ = 0;
    $627 = $626&1;
    if ($627) {
     $687 = ___cxa_find_matching_catch_3(0|0)|0;
     $688 = tempRet0;
     ___clang_call_terminate($687);
     // unreachable;
    }
   }
  }
  HEAP32[$620>>2] = 0;
  $$28 = $$27;$$2837 = $$2736;
  label = 244;
 }
 if ((label|0) == 244) {
  $630 = ((($0)) + 160|0);
  $631 = HEAP32[$630>>2]|0;
  $632 = ($631|0)==(0|0);
  if (!($632)) {
   $633 = ((($631)) + 8|0);
   $634 = HEAP32[$633>>2]|0;HEAP32[$633>>2] = (($634-1)|0);
   $635 = ($634|0)==(1);
   if ($635) {
    __THREW__ = 0;
    invoke_viii(3262,($631|0),1,1);
    $636 = __THREW__; __THREW__ = 0;
    $637 = $636&1;
    if ($637) {
     $687 = ___cxa_find_matching_catch_3(0|0)|0;
     $688 = tempRet0;
     ___clang_call_terminate($687);
     // unreachable;
    }
   }
  }
  HEAP32[$630>>2] = 0;
  $$29 = $$28;$$2938 = $$2837;
  label = 249;
 }
 if ((label|0) == 249) {
  $640 = ((($0)) + 148|0);
  $641 = ((($0)) + 152|0);
  $642 = HEAP32[$641>>2]|0;
  __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4pairIN3osg7ref_ptrINS9_7UniformEEEjEEEENS_19__map_value_compareIS7_SE_NS_4lessIS7_EELb1EEENS5_ISE_EEE7destroyEPNS_11__tree_nodeISE_PvEE($640,$642);
  $643 = ((($0)) + 140|0);
  $644 = HEAP32[$643>>2]|0;
  $645 = ($644|0)==(0|0);
  if (!($645)) {
   $646 = ((($644)) + 8|0);
   $647 = HEAP32[$646>>2]|0;HEAP32[$646>>2] = (($647-1)|0);
   $648 = ($647|0)==(1);
   if ($648) {
    __THREW__ = 0;
    invoke_viii(3262,($644|0),1,1);
    $649 = __THREW__; __THREW__ = 0;
    $650 = $649&1;
    if ($650) {
     $687 = ___cxa_find_matching_catch_3(0|0)|0;
     $688 = tempRet0;
     ___clang_call_terminate($687);
     // unreachable;
    }
   }
  }
  HEAP32[$643>>2] = 0;
  $$31 = $$29;$$3140 = $$2938;
  label = 254;
 }
 if ((label|0) == 254) {
  $653 = ((($0)) + 128|0);
  $654 = HEAP32[$653>>2]|0;
  $655 = ($654|0)==(0|0);
  if (!($655)) {
   $656 = ((($654)) + 8|0);
   $657 = HEAP32[$656>>2]|0;HEAP32[$656>>2] = (($657-1)|0);
   $658 = ($657|0)==(1);
   if ($658) {
    __THREW__ = 0;
    invoke_viii(3262,($654|0),1,1);
    $659 = __THREW__; __THREW__ = 0;
    $660 = $659&1;
    if ($660) {
     $687 = ___cxa_find_matching_catch_3(0|0)|0;
     $688 = tempRet0;
     ___clang_call_terminate($687);
     // unreachable;
    }
   }
  }
  HEAP32[$653>>2] = 0;
  $$32 = $$31;$$3241 = $$3140;
 }
 $661 = ((($0)) + 108|0);
 $662 = HEAP32[$661>>2]|0;
 $663 = ($662|0)==(0|0);
 if (!($663)) {
  $664 = ((($0)) + 112|0);
  $665 = HEAP32[$664>>2]|0;
  $666 = ($665|0)==($662|0);
  if (!($666)) {
   $scevgep$i$i$i170 = ((($665)) + -4|0);
   $667 = $scevgep$i$i$i170;
   $668 = $662;
   $669 = (($667) - ($668))|0;
   $670 = $669 >>> 2;
   $671 = $670 ^ -1;
   $scevgep5$i$i$i171 = (($665) + ($671<<2)|0);
   HEAP32[$664>>2] = $scevgep5$i$i$i171;
  }
  __ZdlPv($662);
 }
 $672 = ((($0)) + 96|0);
 $673 = HEAP32[$672>>2]|0;
 $674 = ($673|0)==(0|0);
 if (!($674)) {
  $789 = ((($0)) + 100|0);
  $790 = HEAP32[$789>>2]|0;
  $791 = ($790|0)==($673|0);
  if (!($791)) {
   $scevgep$i$i$i170$1 = ((($790)) + -4|0);
   $792 = $scevgep$i$i$i170$1;
   $793 = $673;
   $794 = (($792) - ($793))|0;
   $795 = $794 >>> 2;
   $796 = $795 ^ -1;
   $scevgep5$i$i$i171$1 = (($790) + ($796<<2)|0);
   HEAP32[$789>>2] = $scevgep5$i$i$i171$1;
  }
  __ZdlPv($673);
 }
 $797 = ((($0)) + 84|0);
 $798 = HEAP32[$797>>2]|0;
 $799 = ($798|0)==(0|0);
 if (!($799)) {
  $800 = ((($0)) + 88|0);
  $801 = HEAP32[$800>>2]|0;
  $802 = ($801|0)==($798|0);
  if (!($802)) {
   $scevgep$i$i$i170$2 = ((($801)) + -4|0);
   $803 = $scevgep$i$i$i170$2;
   $804 = $798;
   $805 = (($803) - ($804))|0;
   $806 = $805 >>> 2;
   $807 = $806 ^ -1;
   $scevgep5$i$i$i171$2 = (($801) + ($807<<2)|0);
   HEAP32[$800>>2] = $scevgep5$i$i$i171$2;
  }
  __ZdlPv($798);
 }
 $808 = ((($0)) + 72|0);
 $809 = HEAP32[$808>>2]|0;
 $810 = ($809|0)==(0|0);
 if (!($810)) {
  $811 = ((($0)) + 76|0);
  $812 = HEAP32[$811>>2]|0;
  $813 = ($812|0)==($809|0);
  if (!($813)) {
   $scevgep$i$i$i170$3 = ((($812)) + -4|0);
   $814 = $scevgep$i$i$i170$3;
   $815 = $809;
   $816 = (($814) - ($815))|0;
   $817 = $816 >>> 2;
   $818 = $817 ^ -1;
   $scevgep5$i$i$i171$3 = (($812) + ($818<<2)|0);
   HEAP32[$811>>2] = $scevgep5$i$i$i171$3;
  }
  __ZdlPv($809);
 }
 $819 = ((($0)) + 60|0);
 $678 = HEAP32[$819>>2]|0;
 $820 = ($678|0)==(0|0);
 if (!($820)) {
  $675 = ((($0)) + 64|0);
  $676 = HEAP32[$675>>2]|0;
  $677 = ($676|0)==($678|0);
  if (!($677)) {
   $scevgep$i$i$i180 = ((($676)) + -2|0);
   $679 = $scevgep$i$i$i180;
   $680 = $678;
   $681 = (($679) - ($680))|0;
   $682 = $681 >>> 1;
   $683 = $682 ^ -1;
   $scevgep5$i$i$i181 = (($676) + ($683<<1)|0);
   HEAP32[$675>>2] = $scevgep5$i$i$i181;
  }
  __ZdlPv($678);
 }
 $684 = ((($0)) + 48|0);
 $685 = HEAP32[$684>>2]|0;
 $686 = ($685|0)==(0|0);
 if (!($686)) {
  $754 = ((($0)) + 52|0);
  $755 = HEAP32[$754>>2]|0;
  $756 = ($755|0)==($685|0);
  if (!($756)) {
   $scevgep$i$i$i180$1 = ((($755)) + -2|0);
   $757 = $scevgep$i$i$i180$1;
   $758 = $685;
   $759 = (($757) - ($758))|0;
   $760 = $759 >>> 1;
   $761 = $760 ^ -1;
   $scevgep5$i$i$i181$1 = (($755) + ($761<<1)|0);
   HEAP32[$754>>2] = $scevgep5$i$i$i181$1;
  }
  __ZdlPv($685);
 }
 $762 = ((($0)) + 36|0);
 $763 = HEAP32[$762>>2]|0;
 $764 = ($763|0)==(0|0);
 if (!($764)) {
  $765 = ((($0)) + 40|0);
  $766 = HEAP32[$765>>2]|0;
  $767 = ($766|0)==($763|0);
  if (!($767)) {
   $scevgep$i$i$i180$2 = ((($766)) + -2|0);
   $768 = $scevgep$i$i$i180$2;
   $769 = $763;
   $770 = (($768) - ($769))|0;
   $771 = $770 >>> 1;
   $772 = $771 ^ -1;
   $scevgep5$i$i$i181$2 = (($766) + ($772<<1)|0);
   HEAP32[$765>>2] = $scevgep5$i$i$i181$2;
  }
  __ZdlPv($763);
 }
 $773 = ((($0)) + 24|0);
 $774 = HEAP32[$773>>2]|0;
 $775 = ($774|0)==(0|0);
 if (!($775)) {
  $776 = ((($0)) + 28|0);
  $777 = HEAP32[$776>>2]|0;
  $778 = ($777|0)==($774|0);
  if (!($778)) {
   $scevgep$i$i$i180$3 = ((($777)) + -2|0);
   $779 = $scevgep$i$i$i180$3;
   $780 = $774;
   $781 = (($779) - ($780))|0;
   $782 = $781 >>> 1;
   $783 = $782 ^ -1;
   $scevgep5$i$i$i181$3 = (($777) + ($783<<1)|0);
   HEAP32[$776>>2] = $scevgep5$i$i$i181$3;
  }
  __ZdlPv($774);
 }
 $784 = ((($0)) + 12|0);
 $785 = ((($0)) + 16|0);
 $786 = HEAP32[$785>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIPKSt9type_infoN3osg7ref_ptrINS5_10ReferencedEEEEENS_19__map_value_compareIS4_S9_NS_4lessIS4_EELb1EEENS_9allocatorIS9_EEE7destroyEPNS_11__tree_nodeIS9_PvEE($784,$786);
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $787 = __THREW__; __THREW__ = 0;
 $788 = $787&1;
 if ($788) {
  $687 = ___cxa_find_matching_catch_3(0|0)|0;
  $688 = tempRet0;
  ___clang_call_terminate($687);
  // unreachable;
 } else {
  ___resumeException($$32|0);
  // unreachable;
 }
}
function __ZN3osg5StateD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1119,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZN3osg5State14frameCompletedEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $2 = ((($0)) + 888|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = ((($0)) + 784|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($6)) + 948|0);
 $8 = HEAP32[$7>>2]|0;
 FUNCTION_TABLE_vii[$8 & 8191](36392,$1);
 $9 = (__ZN3osg5Timer8instanceEv()|0);
 $10 = (__ZNK3osg5Timer4tickEv($9)|0);
 $11 = tempRet0;
 $12 = $1;
 $13 = $12;
 $14 = HEAP32[$13>>2]|0;
 $15 = (($12) + 4)|0;
 $16 = $15;
 $17 = HEAP32[$16>>2]|0;
 $18 = ((($0)) + 872|0);
 $19 = $18;
 $20 = $19;
 HEAP32[$20>>2] = $10;
 $21 = (($19) + 4)|0;
 $22 = $21;
 HEAP32[$22>>2] = $11;
 $23 = ((($0)) + 880|0);
 $24 = $23;
 $25 = $24;
 HEAP32[$25>>2] = $14;
 $26 = (($24) + 4)|0;
 $27 = $26;
 HEAP32[$27>>2] = $17;
 STACKTOP = sp;return;
}
function __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4pairIS7_jEEEENS_19__map_value_compareIS7_SA_NS_4lessIS7_EELb1EEENS5_ISA_EEE7destroyEPNS_11__tree_nodeISA_PvEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 }
 $3 = HEAP32[$1>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4pairIS7_jEEEENS_19__map_value_compareIS7_SA_NS_4lessIS7_EELb1EEENS5_ISA_EEE7destroyEPNS_11__tree_nodeISA_PvEE($0,$3);
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4pairIS7_jEEEENS_19__map_value_compareIS7_SA_NS_4lessIS7_EELb1EEENS5_ISA_EEE7destroyEPNS_11__tree_nodeISA_PvEE($0,$5);
 $6 = ((($1)) + 16|0);
 $7 = ((($1)) + 28|0);
 $8 = ((($7)) + 11|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = ($9<<24>>24)<(0);
 if ($10) {
  $11 = HEAP32[$7>>2]|0;
  __ZdlPv($11);
 }
 $12 = ((($6)) + 11|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = ($13<<24>>24)<(0);
 if ($14) {
  $15 = HEAP32[$6>>2]|0;
  __ZdlPv($15);
 }
 __ZdlPv($1);
 return;
}
function __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg5State11DefineStackEEENS_19__map_value_compareIS7_SB_NS_4lessIS7_EELb1EEENS5_ISB_EEE7destroyEPNS_11__tree_nodeISB_PvEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$pre$i$i$i$i$i = 0, $$pre$i$i$i$i$i$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 }
 $3 = HEAP32[$1>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg5State11DefineStackEEENS_19__map_value_compareIS7_SB_NS_4lessIS7_EELb1EEENS5_ISB_EEE7destroyEPNS_11__tree_nodeISB_PvEE($0,$3);
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg5State11DefineStackEEENS_19__map_value_compareIS7_SB_NS_4lessIS7_EELb1EEENS5_ISB_EEE7destroyEPNS_11__tree_nodeISB_PvEE($0,$5);
 $6 = ((($1)) + 16|0);
 $7 = ((($1)) + 32|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if (!($9)) {
  $10 = ((($1)) + 36|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($11|0)==($8|0);
  if ($12) {
   $21 = $8;
  } else {
   $14 = $11;
   while(1) {
    $13 = ((($14)) + -16|0);
    HEAP32[$10>>2] = $13;
    $15 = ((($13)) + 11|0);
    $16 = HEAP8[$15>>0]|0;
    $17 = ($16<<24>>24)<(0);
    if ($17) {
     $20 = HEAP32[$13>>2]|0;
     __ZdlPv($20);
     $$pre$i$i$i$i$i$i$i = HEAP32[$10>>2]|0;
     $18 = $$pre$i$i$i$i$i$i$i;
    } else {
     $18 = $13;
    }
    $19 = ($18|0)==($8|0);
    if ($19) {
     break;
    } else {
     $14 = $18;
    }
   }
   $$pre$i$i$i$i$i = HEAP32[$7>>2]|0;
   $21 = $$pre$i$i$i$i$i;
  }
  __ZdlPv($21);
 }
 $22 = ((($6)) + 11|0);
 $23 = HEAP8[$22>>0]|0;
 $24 = ($23<<24>>24)<(0);
 if ($24) {
  $25 = HEAP32[$6>>2]|0;
  __ZdlPv($25);
 }
 __ZdlPv($1);
 return;
}
function __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg5State12UniformStackEEENS_19__map_value_compareIS7_SB_NS_4lessIS7_EELb1EEENS5_ISB_EEE7destroyEPNS_11__tree_nodeISB_PvEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $scevgep$i$i$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 }
 $3 = HEAP32[$1>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg5State12UniformStackEEENS_19__map_value_compareIS7_SB_NS_4lessIS7_EELb1EEENS5_ISB_EEE7destroyEPNS_11__tree_nodeISB_PvEE($0,$3);
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg5State12UniformStackEEENS_19__map_value_compareIS7_SB_NS_4lessIS7_EELb1EEENS5_ISB_EEE7destroyEPNS_11__tree_nodeISB_PvEE($0,$5);
 $6 = ((($1)) + 16|0);
 $7 = ((($1)) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if (!($9)) {
  $10 = ((($1)) + 32|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($11|0)==($8|0);
  if (!($12)) {
   $scevgep$i$i$i$i$i$i$i = ((($11)) + -8|0);
   $13 = $scevgep$i$i$i$i$i$i$i;
   $14 = $8;
   $15 = (($13) - ($14))|0;
   $16 = $15 >>> 3;
   $17 = $16 ^ -1;
   $scevgep5$i$i$i$i$i$i$i = (($11) + ($17<<3)|0);
   HEAP32[$10>>2] = $scevgep5$i$i$i$i$i$i$i;
  }
  __ZdlPv($8);
 }
 $18 = ((($6)) + 11|0);
 $19 = HEAP8[$18>>0]|0;
 $20 = ($19<<24>>24)<(0);
 if ($20) {
  $21 = HEAP32[$6>>2]|0;
  __ZdlPv($21);
 }
 __ZdlPv($1);
 return;
}
function __GLOBAL__sub_I_State_cpp() {
 var $$0$i = 0, $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0;
 var label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $0 = sp + 12|0;
 $1 = sp;
 HEAPF32[52164] = 1.0;
 HEAPF32[(208660)>>2] = 0.0;
 HEAPF32[(208664)>>2] = 0.0;
 HEAPF32[52167] = 0.0;
 HEAPF32[(208672)>>2] = 1.0;
 HEAPF32[(208676)>>2] = 0.0;
 HEAPF32[52170] = 0.0;
 HEAPF32[(208684)>>2] = 0.0;
 HEAPF32[(208688)>>2] = 1.0;
 $2 = (__Znwj(32)|0);
 HEAP32[$0>>2] = $2;
 $3 = ((($0)) + 8|0);
 HEAP32[$3>>2] = -2147483616;
 $4 = ((($0)) + 4|0);
 HEAP32[$4>>2] = 28;
 dest=$2; src=148707; stop=dest+28|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $5 = ((($2)) + 28|0);
 HEAP8[$5>>0] = 0;
 ;HEAP32[$1>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;
 __THREW__ = 0;
 $6 = (invoke_ii(3276,112)|0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $25 = ___cxa_find_matching_catch_2()|0;
  $26 = tempRet0;
  $$0$i = $26;$$01$i = $25;
 } else {
  HEAP32[$1>>2] = $6;
  $9 = ((($1)) + 8|0);
  HEAP32[$9>>2] = -2147483536;
  $10 = ((($1)) + 4|0);
  HEAP32[$10>>2] = 107;
  dest=$6; src=148736; stop=dest+107|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
  $11 = ((($6)) + 107|0);
  HEAP8[$11>>0] = 0;
  __THREW__ = 0;
  $12 = (invoke_i(3459)|0);
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if (!($14)) {
   __THREW__ = 0;
   invoke_viiii(3460,($12|0),2,($0|0),($1|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    $17 = ((($1)) + 11|0);
    $18 = HEAP8[$17>>0]|0;
    $19 = ($18<<24>>24)<(0);
    if ($19) {
     $20 = HEAP32[$1>>2]|0;
     __ZdlPv($20);
    }
    $21 = ((($0)) + 11|0);
    $22 = HEAP8[$21>>0]|0;
    $23 = ($22<<24>>24)<(0);
    if (!($23)) {
     STACKTOP = sp;return;
    }
    $24 = HEAP32[$0>>2]|0;
    __ZdlPv($24);
    STACKTOP = sp;return;
   }
  }
  $27 = ___cxa_find_matching_catch_2()|0;
  $28 = tempRet0;
  $29 = ((($1)) + 11|0);
  $30 = HEAP8[$29>>0]|0;
  $31 = ($30<<24>>24)<(0);
  if ($31) {
   $32 = HEAP32[$1>>2]|0;
   __ZdlPv($32);
   $$0$i = $28;$$01$i = $27;
  } else {
   $$0$i = $28;$$01$i = $27;
  }
 }
 $33 = ((($0)) + 11|0);
 $34 = HEAP8[$33>>0]|0;
 $35 = ($34<<24>>24)<(0);
 if (!($35)) {
  ___resumeException($$01$i|0);
  // unreachable;
 }
 $36 = HEAP32[$0>>2]|0;
 __ZdlPv($36);
 ___resumeException($$01$i|0);
 // unreachable;
}
function __ZN3osg5StateC2Ev($0) {
 $0 = $0|0;
 var $$015 = 0, $$0160 = 0, $$017 = 0, $$019 = 0, $$021 = 0, $$023159 = 0, $$1162 = 0, $$124161 = 0, $$21 = 0, $$2144 = 0, $$2164 = 0, $$225163 = 0, $$3166 = 0, $$326165 = 0, $$5 = 0, $$528 = 0, $$6 = 0, $$629 = 0, $$pr = 0, $$pr158 = 0;
 var $$pre$i = 0, $$pre$i154 = 0, $$pre$i157 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0;
 var $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0;
 var $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0;
 var $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0;
 var $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0;
 var $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0;
 var $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0;
 var $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0;
 var $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0;
 var $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0;
 var $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0;
 var $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0;
 var $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0;
 var $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0;
 var $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0;
 var $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0;
 var $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0;
 var $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0;
 var $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0;
 var $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0;
 var $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0;
 var $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0;
 var $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0;
 var $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0;
 var $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0;
 var $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0;
 var $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0;
 var $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0;
 var $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, $eh$lpad$body98$index7Z2D = 0, $eh$lpad$body98$indexZ2D = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i$1 = 0, $scevgep$i$i$i$2 = 0, $scevgep$i$i$i$3 = 0, $scevgep$i$i$i149 = 0, $scevgep$i$i$i54 = 0, $scevgep$i$i$i54$1 = 0, $scevgep$i$i$i54$2 = 0, $scevgep$i$i$i54$3 = 0, $scevgep5$i$i$i = 0, $scevgep5$i$i$i$1 = 0, $scevgep5$i$i$i$2 = 0, $scevgep5$i$i$i$3 = 0, $scevgep5$i$i$i150 = 0, $scevgep5$i$i$i55 = 0;
 var $scevgep5$i$i$i55$1 = 0, $scevgep5$i$i$i55$2 = 0, $scevgep5$i$i$i55$3 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $1 = sp + 36|0;
 $2 = sp + 24|0;
 $3 = sp + 12|0;
 $4 = sp;
 __ZN3osg10ReferencedC2Eb($0,1);
 HEAP32[$0>>2] = (66172);
 $5 = ((($0)) + 12|0);
 $6 = ((($0)) + 16|0);
 HEAP32[$6>>2] = 0;
 $7 = ((($0)) + 20|0);
 HEAP32[$7>>2] = 0;
 $8 = ((($0)) + 16|0);
 HEAP32[$5>>2] = $8;
 $9 = ((($0)) + 24|0);
 $10 = ((($0)) + 128|0);
 HEAP32[$10>>2] = 0;
 $11 = ((($0)) + 140|0);
 HEAP32[$11>>2] = 0;
 $12 = ((($0)) + 148|0);
 $13 = ((($0)) + 152|0);
 HEAP32[$13>>2] = 0;
 $14 = ((($0)) + 156|0);
 HEAP32[$14>>2] = 0;
 $15 = ((($0)) + 152|0);
 dest=$9; stop=dest+96|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAP32[$12>>2] = $15;
 $16 = ((($0)) + 160|0);
 $17 = ((($0)) + 164|0);
 $18 = ((($0)) + 168|0);
 $19 = ((($0)) + 172|0);
 $20 = ((($0)) + 176|0);
 $21 = ((($0)) + 180|0);
 $22 = ((($0)) + 188|0);
 $23 = ((($0)) + 192|0);
 $24 = ((($0)) + 196|0);
 $25 = ((($0)) + 200|0);
 $26 = ((($0)) + 208|0);
 ;HEAP32[$16>>2]=0|0;HEAP32[$16+4>>2]=0|0;HEAP32[$16+8>>2]=0|0;HEAP32[$16+12>>2]=0|0;HEAP32[$16+16>>2]=0|0;HEAP32[$16+20>>2]=0|0;
 ;HEAP32[$22>>2]=0|0;HEAP32[$22+4>>2]=0|0;HEAP32[$22+8>>2]=0|0;HEAP32[$22+12>>2]=0|0;
 __THREW__ = 0;
 invoke_vi(3299,($26|0));
 $27 = __THREW__; __THREW__ = 0;
 $28 = $27&1;
 if ($28) {
  $295 = ___cxa_find_matching_catch_2()|0;
  $296 = tempRet0;
  $$21 = $295;$$2144 = $296;
 } else {
  $29 = ((($0)) + 336|0);
  HEAP32[$29>>2] = 0;
  $30 = ((($0)) + 352|0);
  $31 = ((($0)) + 552|0);
  $32 = ((($0)) + 556|0);
  $33 = ((($0)) + 564|0);
  $34 = ((($0)) + 568|0);
  HEAP32[$34>>2] = 0;
  $35 = ((($0)) + 572|0);
  HEAP32[$35>>2] = 0;
  $36 = ((($0)) + 568|0);
  _memset(($30|0),0,212)|0;
  HEAP32[$33>>2] = $36;
  $37 = ((($0)) + 576|0);
  $38 = ((($0)) + 580|0);
  HEAP32[$38>>2] = 0;
  $39 = ((($0)) + 584|0);
  HEAP32[$39>>2] = 0;
  $40 = ((($0)) + 580|0);
  HEAP32[$37>>2] = $40;
  $41 = ((($0)) + 588|0);
  $42 = ((($0)) + 592|0);
  HEAP32[$42>>2] = 0;
  $43 = ((($0)) + 596|0);
  HEAP32[$43>>2] = 0;
  $44 = ((($0)) + 592|0);
  HEAP32[$41>>2] = $44;
  $45 = ((($0)) + 600|0);
  $46 = ((($0)) + 604|0);
  HEAP32[$46>>2] = 0;
  $47 = ((($0)) + 608|0);
  HEAP32[$47>>2] = 0;
  $48 = ((($0)) + 604|0);
  HEAP32[$45>>2] = $48;
  $49 = ((($0)) + 612|0);
  $50 = ((($0)) + 616|0);
  HEAP32[$50>>2] = 0;
  $51 = ((($0)) + 620|0);
  HEAP32[$51>>2] = 0;
  $52 = ((($0)) + 616|0);
  HEAP32[$49>>2] = $52;
  $53 = ((($0)) + 624|0);
  HEAP8[$53>>0] = 0;
  $54 = ((($0)) + 632|0);
  HEAP32[$54>>2] = 0;
  $55 = ((($0)) + 636|0);
  HEAP32[$55>>2] = 0;
  $56 = ((($0)) + 632|0);
  $57 = ((($0)) + 628|0);
  HEAP32[$57>>2] = $56;
  $58 = ((($0)) + 640|0);
  $59 = ((($0)) + 644|0);
  $60 = ((($0)) + 652|0);
  $61 = ((($0)) + 656|0);
  $62 = ((($0)) + 668|0);
  HEAP32[$62>>2] = 0;
  $63 = ((($0)) + 672|0);
  HEAP32[$63>>2] = 0;
  $64 = ((($0)) + 676|0);
  HEAP32[$64>>2] = 0;
  $65 = ((($0)) + 784|0);
  HEAP32[$65>>2] = 0;
  $66 = ((($0)) + 792|0);
  HEAP32[$66>>2] = 0;
  $67 = ((($0)) + 796|0);
  ;HEAP32[$58>>2]=0|0;HEAP32[$58+4>>2]=0|0;HEAP32[$58+8>>2]=0|0;HEAP32[$58+12>>2]=0|0;HEAP32[$58+16>>2]=0|0;HEAP32[$58+20>>2]=0|0;
  __THREW__ = 0;
  invoke_vi(3918,($67|0));
  $68 = __THREW__; __THREW__ = 0;
  $69 = $68&1;
  if ($69) {
   $297 = ___cxa_find_matching_catch_2()|0;
   $298 = tempRet0;
   $$6 = $297;$$629 = $298;
  } else {
   $70 = ((($0)) + 860|0);
   HEAP32[$70>>2] = 0;
   $71 = ((($0)) + 120|0);
   HEAP32[$71>>2] = 0;
   $72 = ((($0)) + 124|0);
   HEAP32[$72>>2] = 0;
   $73 = ((($0)) + 136|0);
   HEAP8[$73>>0] = 0;
   $74 = ((($0)) + 137|0);
   HEAP8[$74>>0] = 1;
   __THREW__ = 0;
   $75 = (invoke_ii(3276,56)|0);
   $76 = __THREW__; __THREW__ = 0;
   $77 = $76&1;
   L7: do {
    if ($77) {
     label = 91;
    } else {
     __THREW__ = 0;
     invoke_vi(3919,($75|0));
     $78 = __THREW__; __THREW__ = 0;
     $79 = $78&1;
     if ($79) {
      $301 = ___cxa_find_matching_catch_2()|0;
      $302 = tempRet0;
      __ZdlPv($75);
      $$5 = $301;$$528 = $302;
      break;
     }
     $80 = HEAP32[$11>>2]|0;
     $81 = ($80|0)==($75|0);
     if (!($81)) {
      HEAP32[$11>>2] = $75;
      $82 = ((($75)) + 8|0);
      $83 = HEAP32[$82>>2]|0;HEAP32[$82>>2] = (($83+1)|0);
      $84 = ($80|0)==(0|0);
      if (!($84)) {
       $85 = ((($80)) + 8|0);
       $86 = HEAP32[$85>>2]|0;HEAP32[$85>>2] = (($86-1)|0);
       $87 = ($86|0)==(1);
       if ($87) {
        __THREW__ = 0;
        invoke_viii(3262,($80|0),1,1);
        $88 = __THREW__; __THREW__ = 0;
        $89 = $88&1;
        if ($89) {
         label = 91;
         break;
        }
       }
      }
     }
     $90 = ((($0)) + 144|0);
     HEAP32[$90>>2] = 0;
     __THREW__ = 0;
     $91 = (invoke_ii(3276,160)|0);
     $92 = __THREW__; __THREW__ = 0;
     $93 = $92&1;
     if ($93) {
      label = 91;
     } else {
      __THREW__ = 0;
      invoke_vii(3435,($91|0),0);
      $94 = __THREW__; __THREW__ = 0;
      $95 = $94&1;
      do {
       if ($95) {
        $303 = ___cxa_find_matching_catch_2()|0;
        $304 = tempRet0;
        $eh$lpad$body$index2Z2D = $304;$eh$lpad$body$indexZ2D = $303;
       } else {
        HEAP32[$91>>2] = (63412);
        $96 = ((($91)) + 12|0);
        ;HEAP32[$96>>2]=0|0;HEAP32[$96+4>>2]=0|0;HEAP32[$96+8>>2]=0|0;
        $97 = ((($91)) + 24|0);
        HEAP32[$97>>2] = 2;
        $98 = ((($91)) + 28|0);
        HEAP32[$98>>2] = 0;
        $99 = ((($91)) + 32|0);
        __THREW__ = 0;
        invoke_vi(3299,($99|0));
        $100 = __THREW__; __THREW__ = 0;
        $101 = $100&1;
        if ($101) {
         $102 = ___cxa_find_matching_catch_2()|0;
         $103 = tempRet0;
         __THREW__ = 0;
         invoke_vi(388,($91|0));
         $104 = __THREW__; __THREW__ = 0;
         $105 = $104&1;
         if (!($105)) {
          $eh$lpad$body$index2Z2D = $103;$eh$lpad$body$indexZ2D = $102;
          break;
         }
         $106 = ___cxa_find_matching_catch_3(0|0)|0;
         $107 = tempRet0;
         ___clang_call_terminate($106);
         // unreachable;
        }
        HEAP32[$91>>2] = (47588);
        $108 = HEAP32[$17>>2]|0;
        $109 = ($108|0)==($91|0);
        if ($109) {
         $120 = $91;
        } else {
         HEAP32[$17>>2] = $91;
         $110 = ((($91)) + 8|0);
         $111 = HEAP32[$110>>2]|0;HEAP32[$110>>2] = (($111+1)|0);
         $112 = ($108|0)==(0|0);
         if (!($112)) {
          $113 = ((($108)) + 8|0);
          $114 = HEAP32[$113>>2]|0;HEAP32[$113>>2] = (($114-1)|0);
          $115 = ($114|0)==(1);
          if ($115) {
           __THREW__ = 0;
           invoke_viii(3262,($108|0),1,1);
           $116 = __THREW__; __THREW__ = 0;
           $117 = $116&1;
           if ($117) {
            label = 91;
            break L7;
           }
          }
         }
         $$pr = HEAP32[$17>>2]|0;
         $120 = $$pr;
        }
        $118 = HEAP32[$18>>2]|0;
        $119 = ($118|0)==($120|0);
        if (!($119)) {
         HEAP32[$18>>2] = $120;
         $121 = ($120|0)==(0|0);
         if (!($121)) {
          $122 = ((($120)) + 8|0);
          $123 = HEAP32[$122>>2]|0;HEAP32[$122>>2] = (($123+1)|0);
         }
         $124 = ($118|0)==(0|0);
         if (!($124)) {
          $125 = ((($118)) + 8|0);
          $126 = HEAP32[$125>>2]|0;HEAP32[$125>>2] = (($126-1)|0);
          $127 = ($126|0)==(1);
          if ($127) {
           __THREW__ = 0;
           invoke_viii(3262,($118|0),1,1);
           $128 = __THREW__; __THREW__ = 0;
           $129 = $128&1;
           if ($129) {
            label = 91;
            break L7;
           }
          }
         }
        }
        $130 = HEAP32[$19>>2]|0;
        $131 = HEAP32[$17>>2]|0;
        $132 = ($130|0)==($131|0);
        if ($132) {
         $144 = $130;
        } else {
         HEAP32[$19>>2] = $131;
         $133 = ($131|0)==(0|0);
         if (!($133)) {
          $134 = ((($131)) + 8|0);
          $135 = HEAP32[$134>>2]|0;HEAP32[$134>>2] = (($135+1)|0);
         }
         $136 = ($130|0)==(0|0);
         if (!($136)) {
          $137 = ((($130)) + 8|0);
          $138 = HEAP32[$137>>2]|0;HEAP32[$137>>2] = (($138-1)|0);
          $139 = ($138|0)==(1);
          if ($139) {
           __THREW__ = 0;
           invoke_viii(3262,($130|0),1,1);
           $140 = __THREW__; __THREW__ = 0;
           $141 = $140&1;
           if ($141) {
            label = 91;
            break L7;
           }
          }
         }
         $$pr158 = HEAP32[$17>>2]|0;
         $144 = $$pr158;
        }
        $142 = HEAP32[$20>>2]|0;
        $143 = ($142|0)==($144|0);
        if (!($143)) {
         HEAP32[$20>>2] = $144;
         $145 = ($144|0)==(0|0);
         if (!($145)) {
          $146 = ((($144)) + 8|0);
          $147 = HEAP32[$146>>2]|0;HEAP32[$146>>2] = (($147+1)|0);
         }
         $148 = ($142|0)==(0|0);
         if (!($148)) {
          $149 = ((($142)) + 8|0);
          $150 = HEAP32[$149>>2]|0;HEAP32[$149>>2] = (($150-1)|0);
          $151 = ($150|0)==(1);
          if ($151) {
           __THREW__ = 0;
           invoke_viii(3262,($142|0),1,1);
           $152 = __THREW__; __THREW__ = 0;
           $153 = $152&1;
           if ($153) {
            label = 91;
            break L7;
           }
          }
         }
        }
        __THREW__ = 0;
        $154 = (invoke_ii(3276,160)|0);
        $155 = __THREW__; __THREW__ = 0;
        $156 = $155&1;
        if ($156) {
         label = 91;
         break L7;
        }
        __THREW__ = 0;
        invoke_vii(3435,($154|0),0);
        $157 = __THREW__; __THREW__ = 0;
        $158 = $157&1;
        do {
         if ($158) {
          $305 = ___cxa_find_matching_catch_2()|0;
          $306 = tempRet0;
          $eh$lpad$body98$index7Z2D = $306;$eh$lpad$body98$indexZ2D = $305;
         } else {
          HEAP32[$154>>2] = (63412);
          $159 = ((($154)) + 12|0);
          ;HEAP32[$159>>2]=0|0;HEAP32[$159+4>>2]=0|0;HEAP32[$159+8>>2]=0|0;
          $160 = ((($154)) + 24|0);
          HEAP32[$160>>2] = 2;
          $161 = ((($154)) + 28|0);
          HEAP32[$161>>2] = 0;
          $162 = ((($154)) + 32|0);
          __THREW__ = 0;
          invoke_vi(3299,($162|0));
          $163 = __THREW__; __THREW__ = 0;
          $164 = $163&1;
          if ($164) {
           $165 = ___cxa_find_matching_catch_2()|0;
           $166 = tempRet0;
           __THREW__ = 0;
           invoke_vi(388,($154|0));
           $167 = __THREW__; __THREW__ = 0;
           $168 = $167&1;
           if (!($168)) {
            $eh$lpad$body98$index7Z2D = $166;$eh$lpad$body98$indexZ2D = $165;
            break;
           }
           $169 = ___cxa_find_matching_catch_3(0|0)|0;
           $170 = tempRet0;
           ___clang_call_terminate($169);
           // unreachable;
          }
          HEAP32[$154>>2] = (47588);
          $171 = HEAP32[$21>>2]|0;
          $172 = ($171|0)==($154|0);
          do {
           if (!($172)) {
            HEAP32[$21>>2] = $154;
            $173 = ((($154)) + 8|0);
            $174 = HEAP32[$173>>2]|0;HEAP32[$173>>2] = (($174+1)|0);
            $175 = ($171|0)==(0|0);
            if ($175) {
             break;
            }
            $176 = ((($171)) + 8|0);
            $177 = HEAP32[$176>>2]|0;HEAP32[$176>>2] = (($177-1)|0);
            $178 = ($177|0)==(1);
            if (!($178)) {
             break;
            }
            __THREW__ = 0;
            invoke_viii(3262,($171|0),1,1);
            $179 = __THREW__; __THREW__ = 0;
            $180 = $179&1;
            if ($180) {
             label = 91;
             break L7;
            }
           }
          } while(0);
          $181 = ((($0)) + 184|0);
          HEAP8[$181>>0] = 1;
          $182 = ((($0)) + 348|0);
          HEAP8[$182>>0] = 1;
          __THREW__ = 0;
          $183 = (invoke_ii(3276,92)|0);
          $184 = __THREW__; __THREW__ = 0;
          $185 = $184&1;
          if ($185) {
           label = 91;
           break L7;
          }
          ;HEAP32[$1>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;
          __THREW__ = 0;
          $186 = (invoke_ii(3276,32)|0);
          $187 = __THREW__; __THREW__ = 0;
          $188 = $187&1;
          do {
           if ($188) {
            $307 = ___cxa_find_matching_catch_2()|0;
            $308 = tempRet0;
            $$0160 = $307;$$023159 = $308;
           } else {
            HEAP32[$1>>2] = $186;
            $189 = ((($1)) + 8|0);
            HEAP32[$189>>2] = -2147483616;
            $190 = ((($1)) + 4|0);
            HEAP32[$190>>2] = 19;
            dest=$186; src=148844; stop=dest+19|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
            $191 = ((($186)) + 19|0);
            HEAP8[$191>>0] = 0;
            __THREW__ = 0;
            invoke_viiii(3920,($183|0),35676,($1|0),1);
            $192 = __THREW__; __THREW__ = 0;
            $193 = $192&1;
            L75: do {
             if ($193) {
              $$021 = 1;
             } else {
              $194 = HEAP32[$22>>2]|0;
              $195 = ($194|0)==($183|0);
              do {
               if (!($195)) {
                HEAP32[$22>>2] = $183;
                $196 = ((($183)) + 8|0);
                $197 = HEAP32[$196>>2]|0;HEAP32[$196>>2] = (($197+1)|0);
                $198 = ($194|0)==(0|0);
                if ($198) {
                 break;
                }
                $199 = ((($194)) + 8|0);
                $200 = HEAP32[$199>>2]|0;HEAP32[$199>>2] = (($200-1)|0);
                $201 = ($200|0)==(1);
                if (!($201)) {
                 break;
                }
                __THREW__ = 0;
                invoke_viii(3262,($194|0),1,1);
                $202 = __THREW__; __THREW__ = 0;
                $203 = $202&1;
                if ($203) {
                 $$021 = 0;
                 break L75;
                }
               }
              } while(0);
              $204 = ((($1)) + 11|0);
              $205 = HEAP8[$204>>0]|0;
              $206 = ($205<<24>>24)<(0);
              if ($206) {
               $207 = HEAP32[$1>>2]|0;
               __ZdlPv($207);
              }
              __THREW__ = 0;
              $208 = (invoke_ii(3276,92)|0);
              $209 = __THREW__; __THREW__ = 0;
              $210 = $209&1;
              if ($210) {
               label = 91;
               break L7;
              }
              ;HEAP32[$2>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;
              __THREW__ = 0;
              $211 = (invoke_ii(3276,32)|0);
              $212 = __THREW__; __THREW__ = 0;
              $213 = $212&1;
              do {
               if ($213) {
                $315 = ___cxa_find_matching_catch_2()|0;
                $316 = tempRet0;
                $$1162 = $315;$$124161 = $316;
               } else {
                HEAP32[$2>>2] = $211;
                $214 = ((($2)) + 8|0);
                HEAP32[$214>>2] = -2147483616;
                $215 = ((($2)) + 4|0);
                HEAP32[$215>>2] = 20;
                dest=$211; src=148864; stop=dest+20|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                $216 = ((($211)) + 20|0);
                HEAP8[$216>>0] = 0;
                __THREW__ = 0;
                invoke_viiii(3920,($208|0),35676,($2|0),1);
                $217 = __THREW__; __THREW__ = 0;
                $218 = $217&1;
                L89: do {
                 if ($218) {
                  $$019 = 1;
                 } else {
                  $219 = HEAP32[$23>>2]|0;
                  $220 = ($219|0)==($208|0);
                  do {
                   if (!($220)) {
                    HEAP32[$23>>2] = $208;
                    $221 = ((($208)) + 8|0);
                    $222 = HEAP32[$221>>2]|0;HEAP32[$221>>2] = (($222+1)|0);
                    $223 = ($219|0)==(0|0);
                    if ($223) {
                     break;
                    }
                    $224 = ((($219)) + 8|0);
                    $225 = HEAP32[$224>>2]|0;HEAP32[$224>>2] = (($225-1)|0);
                    $226 = ($225|0)==(1);
                    if (!($226)) {
                     break;
                    }
                    __THREW__ = 0;
                    invoke_viii(3262,($219|0),1,1);
                    $227 = __THREW__; __THREW__ = 0;
                    $228 = $227&1;
                    if ($228) {
                     $$019 = 0;
                     break L89;
                    }
                   }
                  } while(0);
                  $229 = ((($2)) + 11|0);
                  $230 = HEAP8[$229>>0]|0;
                  $231 = ($230<<24>>24)<(0);
                  if ($231) {
                   $232 = HEAP32[$2>>2]|0;
                   __ZdlPv($232);
                  }
                  __THREW__ = 0;
                  $233 = (invoke_ii(3276,92)|0);
                  $234 = __THREW__; __THREW__ = 0;
                  $235 = $234&1;
                  if ($235) {
                   label = 91;
                   break L7;
                  }
                  ;HEAP32[$3>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;
                  __THREW__ = 0;
                  $236 = (invoke_ii(3276,32)|0);
                  $237 = __THREW__; __THREW__ = 0;
                  $238 = $237&1;
                  do {
                   if ($238) {
                    $323 = ___cxa_find_matching_catch_2()|0;
                    $324 = tempRet0;
                    $$2164 = $323;$$225163 = $324;
                   } else {
                    HEAP32[$3>>2] = $236;
                    $239 = ((($3)) + 8|0);
                    HEAP32[$239>>2] = -2147483616;
                    $240 = ((($3)) + 4|0);
                    HEAP32[$240>>2] = 29;
                    dest=$236; src=148885; stop=dest+29|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                    $241 = ((($236)) + 29|0);
                    HEAP8[$241>>0] = 0;
                    __THREW__ = 0;
                    invoke_viiii(3920,($233|0),35676,($3|0),1);
                    $242 = __THREW__; __THREW__ = 0;
                    $243 = $242&1;
                    L103: do {
                     if ($243) {
                      $$017 = 1;
                     } else {
                      $244 = HEAP32[$24>>2]|0;
                      $245 = ($244|0)==($233|0);
                      do {
                       if (!($245)) {
                        HEAP32[$24>>2] = $233;
                        $246 = ((($233)) + 8|0);
                        $247 = HEAP32[$246>>2]|0;HEAP32[$246>>2] = (($247+1)|0);
                        $248 = ($244|0)==(0|0);
                        if ($248) {
                         break;
                        }
                        $249 = ((($244)) + 8|0);
                        $250 = HEAP32[$249>>2]|0;HEAP32[$249>>2] = (($250-1)|0);
                        $251 = ($250|0)==(1);
                        if (!($251)) {
                         break;
                        }
                        __THREW__ = 0;
                        invoke_viii(3262,($244|0),1,1);
                        $252 = __THREW__; __THREW__ = 0;
                        $253 = $252&1;
                        if ($253) {
                         $$017 = 0;
                         break L103;
                        }
                       }
                      } while(0);
                      $254 = ((($3)) + 11|0);
                      $255 = HEAP8[$254>>0]|0;
                      $256 = ($255<<24>>24)<(0);
                      if ($256) {
                       $257 = HEAP32[$3>>2]|0;
                       __ZdlPv($257);
                      }
                      __THREW__ = 0;
                      $258 = (invoke_ii(3276,92)|0);
                      $259 = __THREW__; __THREW__ = 0;
                      $260 = $259&1;
                      if ($260) {
                       label = 91;
                       break L7;
                      }
                      ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;
                      __THREW__ = 0;
                      $261 = (invoke_ii(3276,32)|0);
                      $262 = __THREW__; __THREW__ = 0;
                      $263 = $262&1;
                      do {
                       if ($263) {
                        $331 = ___cxa_find_matching_catch_2()|0;
                        $332 = tempRet0;
                        $$3166 = $331;$$326165 = $332;
                       } else {
                        HEAP32[$4>>2] = $261;
                        $264 = ((($4)) + 8|0);
                        HEAP32[$264>>2] = -2147483616;
                        $265 = ((($4)) + 4|0);
                        HEAP32[$265>>2] = 16;
                        dest=$261; src=148915; stop=dest+16|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                        $266 = ((($261)) + 16|0);
                        HEAP8[$266>>0] = 0;
                        __THREW__ = 0;
                        invoke_viiii(3920,($258|0),35675,($4|0),1);
                        $267 = __THREW__; __THREW__ = 0;
                        $268 = $267&1;
                        L117: do {
                         if ($268) {
                          $$015 = 1;
                         } else {
                          $269 = HEAP32[$25>>2]|0;
                          $270 = ($269|0)==($258|0);
                          do {
                           if (!($270)) {
                            HEAP32[$25>>2] = $258;
                            $271 = ((($258)) + 8|0);
                            $272 = HEAP32[$271>>2]|0;HEAP32[$271>>2] = (($272+1)|0);
                            $273 = ($269|0)==(0|0);
                            if ($273) {
                             break;
                            }
                            $274 = ((($269)) + 8|0);
                            $275 = HEAP32[$274>>2]|0;HEAP32[$274>>2] = (($275-1)|0);
                            $276 = ($275|0)==(1);
                            if (!($276)) {
                             break;
                            }
                            __THREW__ = 0;
                            invoke_viii(3262,($269|0),1,1);
                            $277 = __THREW__; __THREW__ = 0;
                            $278 = $277&1;
                            if ($278) {
                             $$015 = 0;
                             break L117;
                            }
                           }
                          } while(0);
                          $279 = ((($4)) + 11|0);
                          $280 = HEAP8[$279>>0]|0;
                          $281 = ($280<<24>>24)<(0);
                          if ($281) {
                           $282 = HEAP32[$4>>2]|0;
                           __ZdlPv($282);
                          }
                          __THREW__ = 0;
                          invoke_viii(3921,($0|0),1,8);
                          $283 = __THREW__; __THREW__ = 0;
                          $284 = $283&1;
                          if ($284) {
                           label = 91;
                           break L7;
                          }
                          $285 = ((($0)) + 340|0);
                          HEAP32[$285>>2] = 0;
                          $286 = ((($0)) + 344|0);
                          HEAP32[$286>>2] = 1;
                          $287 = (_getenv((148932|0))|0);
                          $288 = ($287|0)==(0|0);
                          L128: do {
                           if (!($288)) {
                            $289 = (_strcmp($287,148954)|0);
                            $290 = ($289|0)==(0);
                            do {
                             if (!($290)) {
                              $291 = (_strcmp($287,165306)|0);
                              $292 = ($291|0)==(0);
                              if ($292) {
                               break;
                              }
                              $293 = (_strcmp($287,165303)|0);
                              $294 = ($293|0)==(0);
                              if ($294) {
                               break;
                              }
                              $341 = (_strcmp($287,167116)|0);
                              $342 = ($341|0)==(0);
                              if (!($342)) {
                               $343 = (_strcmp($287,167112)|0);
                               $344 = ($343|0)==(0);
                               if (!($344)) {
                                break L128;
                               }
                              }
                              HEAP32[$286>>2] = 0;
                              break L128;
                             }
                            } while(0);
                            HEAP32[$286>>2] = 2;
                           }
                          } while(0);
                          $345 = ((($0)) + 688|0);
                          $346 = ((($0)) + 664|0);
                          HEAP32[$346>>2] = 0;
                          $347 = ((($0)) + 724|0);
                          $348 = ((($0)) + 788|0);
                          HEAP32[$348>>2] = 0;
                          $349 = ((($0)) + 716|0);
                          ;HEAP32[$345>>2]=0|0;HEAP32[$345+4>>2]=0|0;HEAP32[$345+8>>2]=0|0;HEAP32[$345+12>>2]=0|0;HEAP32[$345+16>>2]=0|0;HEAP32[$345+20>>2]=0|0;HEAP16[$345+24>>1]=0|0;HEAP8[$345+26>>0]=0|0;
                          dest=$347; stop=dest+60|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
                          HEAP32[$349>>2] = 1;
                          $350 = ((($0)) + 720|0);
                          HEAP32[$350>>2] = 1;
                          $351 = ((($0)) + 680|0);
                          HEAP32[$351>>2] = 0;
                          $352 = ((($0)) + 684|0);
                          HEAP32[$352>>2] = 0;
                          __THREW__ = 0;
                          invoke_vii(3922,($67|0),($0|0));
                          $353 = __THREW__; __THREW__ = 0;
                          $354 = $353&1;
                          do {
                           if (!($354)) {
                            __THREW__ = 0;
                            $355 = (invoke_ii(3276,24)|0);
                            $356 = __THREW__; __THREW__ = 0;
                            $357 = $356&1;
                            if ($357) {
                             break;
                            }
                            __THREW__ = 0;
                            invoke_vi(3923,($355|0));
                            $358 = __THREW__; __THREW__ = 0;
                            $359 = $358&1;
                            if ($359) {
                             $372 = ___cxa_find_matching_catch_2()|0;
                             $373 = tempRet0;
                             __ZdlPv($355);
                             $$5 = $372;$$528 = $373;
                             break L7;
                            }
                            $360 = HEAP32[$70>>2]|0;
                            $361 = ($360|0)==($355|0);
                            if ($361) {
                             $370 = ((($0)) + 864|0);
                             $371 = ((($0)) + 132|0);
                             HEAP32[$371>>2] = 0;
                             ;HEAP32[$370>>2]=0|0;HEAP32[$370+4>>2]=0|0;HEAP32[$370+8>>2]=0|0;HEAP32[$370+12>>2]=0|0;HEAP32[$370+16>>2]=0|0;HEAP32[$370+20>>2]=0|0;HEAP32[$370+24>>2]=0|0;
                             STACKTOP = sp;return;
                            }
                            HEAP32[$70>>2] = $355;
                            $362 = ((($355)) + 8|0);
                            $363 = HEAP32[$362>>2]|0;HEAP32[$362>>2] = (($363+1)|0);
                            $364 = ($360|0)==(0|0);
                            if ($364) {
                             $370 = ((($0)) + 864|0);
                             $371 = ((($0)) + 132|0);
                             HEAP32[$371>>2] = 0;
                             ;HEAP32[$370>>2]=0|0;HEAP32[$370+4>>2]=0|0;HEAP32[$370+8>>2]=0|0;HEAP32[$370+12>>2]=0|0;HEAP32[$370+16>>2]=0|0;HEAP32[$370+20>>2]=0|0;HEAP32[$370+24>>2]=0|0;
                             STACKTOP = sp;return;
                            }
                            $365 = ((($360)) + 8|0);
                            $366 = HEAP32[$365>>2]|0;HEAP32[$365>>2] = (($366-1)|0);
                            $367 = ($366|0)==(1);
                            if (!($367)) {
                             $370 = ((($0)) + 864|0);
                             $371 = ((($0)) + 132|0);
                             HEAP32[$371>>2] = 0;
                             ;HEAP32[$370>>2]=0|0;HEAP32[$370+4>>2]=0|0;HEAP32[$370+8>>2]=0|0;HEAP32[$370+12>>2]=0|0;HEAP32[$370+16>>2]=0|0;HEAP32[$370+20>>2]=0|0;HEAP32[$370+24>>2]=0|0;
                             STACKTOP = sp;return;
                            }
                            __THREW__ = 0;
                            invoke_viii(3262,($360|0),1,1);
                            $368 = __THREW__; __THREW__ = 0;
                            $369 = $368&1;
                            if ($369) {
                             break;
                            }
                            $370 = ((($0)) + 864|0);
                            $371 = ((($0)) + 132|0);
                            HEAP32[$371>>2] = 0;
                            ;HEAP32[$370>>2]=0|0;HEAP32[$370+4>>2]=0|0;HEAP32[$370+8>>2]=0|0;HEAP32[$370+12>>2]=0|0;HEAP32[$370+16>>2]=0|0;HEAP32[$370+20>>2]=0|0;HEAP32[$370+24>>2]=0|0;
                            STACKTOP = sp;return;
                           }
                          } while(0);
                          $339 = ___cxa_find_matching_catch_2()|0;
                          $340 = tempRet0;
                          $$5 = $339;$$528 = $340;
                          break L7;
                         }
                        } while(0);
                        $333 = ___cxa_find_matching_catch_2()|0;
                        $334 = tempRet0;
                        $335 = ((($4)) + 11|0);
                        $336 = HEAP8[$335>>0]|0;
                        $337 = ($336<<24>>24)<(0);
                        if ($337) {
                         $338 = HEAP32[$4>>2]|0;
                         __ZdlPv($338);
                         if ($$015) {
                          $$3166 = $333;$$326165 = $334;
                          break;
                         } else {
                          $$5 = $333;$$528 = $334;
                          break L7;
                         }
                        } else {
                         if ($$015) {
                          $$3166 = $333;$$326165 = $334;
                          break;
                         } else {
                          $$5 = $333;$$528 = $334;
                          break L7;
                         }
                        }
                       }
                      } while(0);
                      __ZdlPv($258);
                      $$5 = $$3166;$$528 = $$326165;
                      break L7;
                     }
                    } while(0);
                    $325 = ___cxa_find_matching_catch_2()|0;
                    $326 = tempRet0;
                    $327 = ((($3)) + 11|0);
                    $328 = HEAP8[$327>>0]|0;
                    $329 = ($328<<24>>24)<(0);
                    if ($329) {
                     $330 = HEAP32[$3>>2]|0;
                     __ZdlPv($330);
                     if ($$017) {
                      $$2164 = $325;$$225163 = $326;
                      break;
                     } else {
                      $$5 = $325;$$528 = $326;
                      break L7;
                     }
                    } else {
                     if ($$017) {
                      $$2164 = $325;$$225163 = $326;
                      break;
                     } else {
                      $$5 = $325;$$528 = $326;
                      break L7;
                     }
                    }
                   }
                  } while(0);
                  __ZdlPv($233);
                  $$5 = $$2164;$$528 = $$225163;
                  break L7;
                 }
                } while(0);
                $317 = ___cxa_find_matching_catch_2()|0;
                $318 = tempRet0;
                $319 = ((($2)) + 11|0);
                $320 = HEAP8[$319>>0]|0;
                $321 = ($320<<24>>24)<(0);
                if ($321) {
                 $322 = HEAP32[$2>>2]|0;
                 __ZdlPv($322);
                 if ($$019) {
                  $$1162 = $317;$$124161 = $318;
                  break;
                 } else {
                  $$5 = $317;$$528 = $318;
                  break L7;
                 }
                } else {
                 if ($$019) {
                  $$1162 = $317;$$124161 = $318;
                  break;
                 } else {
                  $$5 = $317;$$528 = $318;
                  break L7;
                 }
                }
               }
              } while(0);
              __ZdlPv($208);
              $$5 = $$1162;$$528 = $$124161;
              break L7;
             }
            } while(0);
            $309 = ___cxa_find_matching_catch_2()|0;
            $310 = tempRet0;
            $311 = ((($1)) + 11|0);
            $312 = HEAP8[$311>>0]|0;
            $313 = ($312<<24>>24)<(0);
            if ($313) {
             $314 = HEAP32[$1>>2]|0;
             __ZdlPv($314);
             if ($$021) {
              $$0160 = $309;$$023159 = $310;
              break;
             } else {
              $$5 = $309;$$528 = $310;
              break L7;
             }
            } else {
             if ($$021) {
              $$0160 = $309;$$023159 = $310;
              break;
             } else {
              $$5 = $309;$$528 = $310;
              break L7;
             }
            }
           }
          } while(0);
          __ZdlPv($183);
          $$5 = $$0160;$$528 = $$023159;
          break L7;
         }
        } while(0);
        __ZdlPv($154);
        $$5 = $eh$lpad$body98$indexZ2D;$$528 = $eh$lpad$body98$index7Z2D;
        break L7;
       }
      } while(0);
      __ZdlPv($91);
      $$5 = $eh$lpad$body$indexZ2D;$$528 = $eh$lpad$body$index2Z2D;
     }
    }
   } while(0);
   if ((label|0) == 91) {
    $299 = ___cxa_find_matching_catch_2()|0;
    $300 = tempRet0;
    $$5 = $299;$$528 = $300;
   }
   $374 = HEAP32[$70>>2]|0;
   $375 = ($374|0)==(0|0);
   if (!($375)) {
    $376 = ((($374)) + 8|0);
    $377 = HEAP32[$376>>2]|0;HEAP32[$376>>2] = (($377-1)|0);
    $378 = ($377|0)==(1);
    if ($378) {
     __THREW__ = 0;
     invoke_viii(3262,($374|0),1,1);
     $379 = __THREW__; __THREW__ = 0;
     $380 = $379&1;
     if ($380) {
      $652 = ___cxa_find_matching_catch_3(0|0)|0;
      $653 = tempRet0;
      ___clang_call_terminate($652);
      // unreachable;
     }
    }
   }
   HEAP32[$70>>2] = 0;
   __THREW__ = 0;
   invoke_vi(2450,($67|0));
   $381 = __THREW__; __THREW__ = 0;
   $382 = $381&1;
   if ($382) {
    $652 = ___cxa_find_matching_catch_3(0|0)|0;
    $653 = tempRet0;
    ___clang_call_terminate($652);
    // unreachable;
   } else {
    $$6 = $$5;$$629 = $$528;
   }
  }
  $383 = HEAP32[$66>>2]|0;
  $384 = ($383|0)==(0|0);
  if (!($384)) {
   $385 = ((($383)) + 8|0);
   $386 = HEAP32[$385>>2]|0;HEAP32[$385>>2] = (($386-1)|0);
   $387 = ($386|0)==(1);
   if ($387) {
    __THREW__ = 0;
    invoke_viii(3262,($383|0),1,1);
    $388 = __THREW__; __THREW__ = 0;
    $389 = $388&1;
    if ($389) {
     $652 = ___cxa_find_matching_catch_3(0|0)|0;
     $653 = tempRet0;
     ___clang_call_terminate($652);
     // unreachable;
    }
   }
  }
  HEAP32[$66>>2] = 0;
  $390 = HEAP32[$65>>2]|0;
  $391 = ($390|0)==(0|0);
  if (!($391)) {
   $392 = ((($390)) + 8|0);
   $393 = HEAP32[$392>>2]|0;HEAP32[$392>>2] = (($393-1)|0);
   $394 = ($393|0)==(1);
   if ($394) {
    __THREW__ = 0;
    invoke_viii(3262,($390|0),1,1);
    $395 = __THREW__; __THREW__ = 0;
    $396 = $395&1;
    if ($396) {
     $652 = ___cxa_find_matching_catch_3(0|0)|0;
     $653 = tempRet0;
     ___clang_call_terminate($652);
     // unreachable;
    }
   }
  }
  HEAP32[$65>>2] = 0;
  $397 = HEAP32[$62>>2]|0;
  $398 = ($397|0)==(0|0);
  if (!($398)) {
   $399 = HEAP32[$63>>2]|0;
   $400 = ($399|0)==($397|0);
   if (!($400)) {
    $scevgep$i$i$i149 = ((($399)) + -4|0);
    $401 = $scevgep$i$i$i149;
    $402 = $397;
    $403 = (($401) - ($402))|0;
    $404 = $403 >>> 2;
    $405 = $404 ^ -1;
    $scevgep5$i$i$i150 = (($399) + ($405<<2)|0);
    HEAP32[$63>>2] = $scevgep5$i$i$i150;
   }
   __ZdlPv($397);
  }
  $406 = HEAP32[$60>>2]|0;
  $407 = ($406|0)==(0|0);
  if (!($407)) {
   $408 = HEAP32[$61>>2]|0;
   $409 = ($408|0)==($406|0);
   if ($409) {
    $416 = $406;
   } else {
    $411 = $408;
    while(1) {
     $410 = ((($411)) + -12|0);
     HEAP32[$61>>2] = $410;
     $412 = ((($411)) + -8|0);
     $413 = HEAP32[$412>>2]|0;
     __ZNSt3__26__treeINS_12__value_typeINS_4pairIN3osg14StateAttribute4TypeEjEENS3_5State14AttributeStackEEENS_19__map_value_compareIS6_S9_NS_4lessIS6_EELb1EEENS_9allocatorIS9_EEE7destroyEPNS_11__tree_nodeIS9_PvEE($410,$413);
     $414 = HEAP32[$61>>2]|0;
     $415 = ($414|0)==($406|0);
     if ($415) {
      break;
     } else {
      $411 = $414;
     }
    }
    $$pre$i154 = HEAP32[$60>>2]|0;
    $416 = $$pre$i154;
   }
   __ZdlPv($416);
  }
  $417 = HEAP32[$58>>2]|0;
  $418 = ($417|0)==(0|0);
  if (!($418)) {
   $419 = HEAP32[$59>>2]|0;
   $420 = ($419|0)==($417|0);
   if ($420) {
    $427 = $417;
   } else {
    $422 = $419;
    while(1) {
     $421 = ((($422)) + -12|0);
     HEAP32[$59>>2] = $421;
     $423 = ((($422)) + -8|0);
     $424 = HEAP32[$423>>2]|0;
     __ZNSt3__26__treeINS_12__value_typeIjN3osg5State9ModeStackEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($421,$424);
     $425 = HEAP32[$59>>2]|0;
     $426 = ($425|0)==($417|0);
     if ($426) {
      break;
     } else {
      $422 = $425;
     }
    }
    $$pre$i157 = HEAP32[$58>>2]|0;
    $427 = $$pre$i157;
   }
   __ZdlPv($427);
  }
  $428 = ((($0)) + 628|0);
  $429 = HEAP32[$56>>2]|0;
  __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4pairIS7_jEEEENS_19__map_value_compareIS7_SA_NS_4lessIS7_EELb1EEENS5_ISA_EEE7destroyEPNS_11__tree_nodeISA_PvEE($428,$429);
  $430 = HEAP32[$52>>2]|0;
  __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg5State11DefineStackEEENS_19__map_value_compareIS7_SB_NS_4lessIS7_EELb1EEENS5_ISB_EEE7destroyEPNS_11__tree_nodeISB_PvEE($49,$430);
  $431 = HEAP32[$48>>2]|0;
  __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg5State12UniformStackEEENS_19__map_value_compareIS7_SB_NS_4lessIS7_EELb1EEENS5_ISB_EEE7destroyEPNS_11__tree_nodeISB_PvEE($45,$431);
  $432 = HEAP32[$44>>2]|0;
  __ZNSt3__26__treeINS_12__value_typeINS_4pairIN3osg14StateAttribute4TypeEjEENS3_5State14AttributeStackEEENS_19__map_value_compareIS6_S9_NS_4lessIS6_EELb1EEENS_9allocatorIS9_EEE7destroyEPNS_11__tree_nodeIS9_PvEE($41,$432);
  $433 = HEAP32[$40>>2]|0;
  __ZNSt3__26__treeINS_12__value_typeIjN3osg5State9ModeStackEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($37,$433);
  $434 = HEAP32[$36>>2]|0;
  __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEjEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($33,$434);
  $435 = HEAP32[$31>>2]|0;
  $436 = ($435|0)==(0|0);
  if (!($436)) {
   $437 = HEAP32[$32>>2]|0;
   $438 = ($437|0)==($435|0);
   if ($438) {
    $458 = $435;
   } else {
    $440 = $437;
    while(1) {
     $439 = ((($440)) + -40|0);
     HEAP32[$32>>2] = $439;
     $441 = ((($440)) + -12|0);
     $442 = ((($441)) + 11|0);
     $443 = HEAP8[$442>>0]|0;
     $444 = ($443<<24>>24)<(0);
     if ($444) {
      $445 = HEAP32[$441>>2]|0;
      __ZdlPv($445);
     }
     $446 = ((($440)) + -24|0);
     $447 = ((($446)) + 11|0);
     $448 = HEAP8[$447>>0]|0;
     $449 = ($448<<24>>24)<(0);
     if ($449) {
      $450 = HEAP32[$446>>2]|0;
      __ZdlPv($450);
     }
     $451 = ((($440)) + -36|0);
     $452 = ((($451)) + 11|0);
     $453 = HEAP8[$452>>0]|0;
     $454 = ($453<<24>>24)<(0);
     if ($454) {
      $457 = HEAP32[$451>>2]|0;
      __ZdlPv($457);
     }
     $455 = HEAP32[$32>>2]|0;
     $456 = ($455|0)==($435|0);
     if ($456) {
      break;
     } else {
      $440 = $455;
     }
    }
    $$pre$i = HEAP32[$31>>2]|0;
    $458 = $$pre$i;
   }
   __ZdlPv($458);
  }
  $459 = ((($0)) + 540|0);
  $460 = ((($459)) + 11|0);
  $461 = HEAP8[$460>>0]|0;
  $462 = ($461<<24>>24)<(0);
  if ($462) {
   $463 = HEAP32[$459>>2]|0;
   __ZdlPv($463);
  }
  $464 = ((($0)) + 528|0);
  $465 = ((($464)) + 11|0);
  $466 = HEAP8[$465>>0]|0;
  $467 = ($466<<24>>24)<(0);
  if ($467) {
   $468 = HEAP32[$464>>2]|0;
   __ZdlPv($468);
  }
  $469 = ((($0)) + 516|0);
  $470 = ((($469)) + 11|0);
  $471 = HEAP8[$470>>0]|0;
  $472 = ($471<<24>>24)<(0);
  if ($472) {
   $473 = HEAP32[$469>>2]|0;
   __ZdlPv($473);
  }
  $474 = ((($0)) + 500|0);
  $475 = ((($474)) + 11|0);
  $476 = HEAP8[$475>>0]|0;
  $477 = ($476<<24>>24)<(0);
  if ($477) {
   $478 = HEAP32[$474>>2]|0;
   __ZdlPv($478);
  }
  $479 = ((($0)) + 488|0);
  $480 = ((($479)) + 11|0);
  $481 = HEAP8[$480>>0]|0;
  $482 = ($481<<24>>24)<(0);
  if ($482) {
   $483 = HEAP32[$479>>2]|0;
   __ZdlPv($483);
  }
  $484 = ((($0)) + 476|0);
  $485 = ((($484)) + 11|0);
  $486 = HEAP8[$485>>0]|0;
  $487 = ($486<<24>>24)<(0);
  if ($487) {
   $488 = HEAP32[$484>>2]|0;
   __ZdlPv($488);
  }
  $489 = ((($0)) + 460|0);
  $490 = ((($489)) + 11|0);
  $491 = HEAP8[$490>>0]|0;
  $492 = ($491<<24>>24)<(0);
  if ($492) {
   $493 = HEAP32[$489>>2]|0;
   __ZdlPv($493);
  }
  $494 = ((($0)) + 448|0);
  $495 = ((($494)) + 11|0);
  $496 = HEAP8[$495>>0]|0;
  $497 = ($496<<24>>24)<(0);
  if ($497) {
   $498 = HEAP32[$494>>2]|0;
   __ZdlPv($498);
  }
  $499 = ((($0)) + 436|0);
  $500 = ((($499)) + 11|0);
  $501 = HEAP8[$500>>0]|0;
  $502 = ($501<<24>>24)<(0);
  if ($502) {
   $503 = HEAP32[$499>>2]|0;
   __ZdlPv($503);
  }
  $504 = ((($0)) + 420|0);
  $505 = ((($504)) + 11|0);
  $506 = HEAP8[$505>>0]|0;
  $507 = ($506<<24>>24)<(0);
  if ($507) {
   $508 = HEAP32[$504>>2]|0;
   __ZdlPv($508);
  }
  $509 = ((($0)) + 408|0);
  $510 = ((($509)) + 11|0);
  $511 = HEAP8[$510>>0]|0;
  $512 = ($511<<24>>24)<(0);
  if ($512) {
   $513 = HEAP32[$509>>2]|0;
   __ZdlPv($513);
  }
  $514 = ((($0)) + 396|0);
  $515 = ((($514)) + 11|0);
  $516 = HEAP8[$515>>0]|0;
  $517 = ($516<<24>>24)<(0);
  if ($517) {
   $518 = HEAP32[$514>>2]|0;
   __ZdlPv($518);
  }
  $519 = ((($0)) + 380|0);
  $520 = ((($519)) + 11|0);
  $521 = HEAP8[$520>>0]|0;
  $522 = ($521<<24>>24)<(0);
  if ($522) {
   $523 = HEAP32[$519>>2]|0;
   __ZdlPv($523);
  }
  $524 = ((($0)) + 368|0);
  $525 = ((($524)) + 11|0);
  $526 = HEAP8[$525>>0]|0;
  $527 = ($526<<24>>24)<(0);
  if ($527) {
   $528 = HEAP32[$524>>2]|0;
   __ZdlPv($528);
  }
  $529 = ((($0)) + 356|0);
  $530 = ((($529)) + 11|0);
  $531 = HEAP8[$530>>0]|0;
  $532 = ($531<<24>>24)<(0);
  if ($532) {
   $533 = HEAP32[$529>>2]|0;
   __ZdlPv($533);
  }
  $534 = HEAP32[$29>>2]|0;
  $535 = ($534|0)==(0|0);
  do {
   if (!($535)) {
    $536 = ((($534)) + 8|0);
    $537 = HEAP32[$536>>2]|0;HEAP32[$536>>2] = (($537-1)|0);
    $538 = ($537|0)==(1);
    if (!($538)) {
     break;
    }
    __THREW__ = 0;
    invoke_viii(3262,($534|0),1,1);
    $539 = __THREW__; __THREW__ = 0;
    $540 = $539&1;
    if (!($540)) {
     break;
    }
    $652 = ___cxa_find_matching_catch_3(0|0)|0;
    $653 = tempRet0;
    ___clang_call_terminate($652);
    // unreachable;
   }
  } while(0);
  HEAP32[$29>>2] = 0;
  $$21 = $$6;$$2144 = $$629;
 }
 $541 = HEAP32[$25>>2]|0;
 $542 = ($541|0)==(0|0);
 if (!($542)) {
  $543 = ((($541)) + 8|0);
  $544 = HEAP32[$543>>2]|0;HEAP32[$543>>2] = (($544-1)|0);
  $545 = ($544|0)==(1);
  if ($545) {
   __THREW__ = 0;
   invoke_viii(3262,($541|0),1,1);
   $546 = __THREW__; __THREW__ = 0;
   $547 = $546&1;
   if ($547) {
    $652 = ___cxa_find_matching_catch_3(0|0)|0;
    $653 = tempRet0;
    ___clang_call_terminate($652);
    // unreachable;
   }
  }
 }
 HEAP32[$25>>2] = 0;
 $548 = HEAP32[$24>>2]|0;
 $549 = ($548|0)==(0|0);
 if (!($549)) {
  $550 = ((($548)) + 8|0);
  $551 = HEAP32[$550>>2]|0;HEAP32[$550>>2] = (($551-1)|0);
  $552 = ($551|0)==(1);
  if ($552) {
   __THREW__ = 0;
   invoke_viii(3262,($548|0),1,1);
   $553 = __THREW__; __THREW__ = 0;
   $554 = $553&1;
   if ($554) {
    $652 = ___cxa_find_matching_catch_3(0|0)|0;
    $653 = tempRet0;
    ___clang_call_terminate($652);
    // unreachable;
   }
  }
 }
 HEAP32[$24>>2] = 0;
 $555 = HEAP32[$23>>2]|0;
 $556 = ($555|0)==(0|0);
 if (!($556)) {
  $557 = ((($555)) + 8|0);
  $558 = HEAP32[$557>>2]|0;HEAP32[$557>>2] = (($558-1)|0);
  $559 = ($558|0)==(1);
  if ($559) {
   __THREW__ = 0;
   invoke_viii(3262,($555|0),1,1);
   $560 = __THREW__; __THREW__ = 0;
   $561 = $560&1;
   if ($561) {
    $652 = ___cxa_find_matching_catch_3(0|0)|0;
    $653 = tempRet0;
    ___clang_call_terminate($652);
    // unreachable;
   }
  }
 }
 HEAP32[$23>>2] = 0;
 $562 = HEAP32[$22>>2]|0;
 $563 = ($562|0)==(0|0);
 if (!($563)) {
  $564 = ((($562)) + 8|0);
  $565 = HEAP32[$564>>2]|0;HEAP32[$564>>2] = (($565-1)|0);
  $566 = ($565|0)==(1);
  if ($566) {
   __THREW__ = 0;
   invoke_viii(3262,($562|0),1,1);
   $567 = __THREW__; __THREW__ = 0;
   $568 = $567&1;
   if ($568) {
    $652 = ___cxa_find_matching_catch_3(0|0)|0;
    $653 = tempRet0;
    ___clang_call_terminate($652);
    // unreachable;
   }
  }
 }
 HEAP32[$22>>2] = 0;
 $569 = HEAP32[$21>>2]|0;
 $570 = ($569|0)==(0|0);
 if (!($570)) {
  $571 = ((($569)) + 8|0);
  $572 = HEAP32[$571>>2]|0;HEAP32[$571>>2] = (($572-1)|0);
  $573 = ($572|0)==(1);
  if ($573) {
   __THREW__ = 0;
   invoke_viii(3262,($569|0),1,1);
   $574 = __THREW__; __THREW__ = 0;
   $575 = $574&1;
   if ($575) {
    $652 = ___cxa_find_matching_catch_3(0|0)|0;
    $653 = tempRet0;
    ___clang_call_terminate($652);
    // unreachable;
   }
  }
 }
 HEAP32[$21>>2] = 0;
 $576 = HEAP32[$20>>2]|0;
 $577 = ($576|0)==(0|0);
 if (!($577)) {
  $578 = ((($576)) + 8|0);
  $579 = HEAP32[$578>>2]|0;HEAP32[$578>>2] = (($579-1)|0);
  $580 = ($579|0)==(1);
  if ($580) {
   __THREW__ = 0;
   invoke_viii(3262,($576|0),1,1);
   $581 = __THREW__; __THREW__ = 0;
   $582 = $581&1;
   if ($582) {
    $652 = ___cxa_find_matching_catch_3(0|0)|0;
    $653 = tempRet0;
    ___clang_call_terminate($652);
    // unreachable;
   }
  }
 }
 HEAP32[$20>>2] = 0;
 $583 = HEAP32[$19>>2]|0;
 $584 = ($583|0)==(0|0);
 if (!($584)) {
  $585 = ((($583)) + 8|0);
  $586 = HEAP32[$585>>2]|0;HEAP32[$585>>2] = (($586-1)|0);
  $587 = ($586|0)==(1);
  if ($587) {
   __THREW__ = 0;
   invoke_viii(3262,($583|0),1,1);
   $588 = __THREW__; __THREW__ = 0;
   $589 = $588&1;
   if ($589) {
    $652 = ___cxa_find_matching_catch_3(0|0)|0;
    $653 = tempRet0;
    ___clang_call_terminate($652);
    // unreachable;
   }
  }
 }
 HEAP32[$19>>2] = 0;
 $590 = HEAP32[$18>>2]|0;
 $591 = ($590|0)==(0|0);
 if (!($591)) {
  $592 = ((($590)) + 8|0);
  $593 = HEAP32[$592>>2]|0;HEAP32[$592>>2] = (($593-1)|0);
  $594 = ($593|0)==(1);
  if ($594) {
   __THREW__ = 0;
   invoke_viii(3262,($590|0),1,1);
   $595 = __THREW__; __THREW__ = 0;
   $596 = $595&1;
   if ($596) {
    $652 = ___cxa_find_matching_catch_3(0|0)|0;
    $653 = tempRet0;
    ___clang_call_terminate($652);
    // unreachable;
   }
  }
 }
 HEAP32[$18>>2] = 0;
 $597 = HEAP32[$17>>2]|0;
 $598 = ($597|0)==(0|0);
 if (!($598)) {
  $599 = ((($597)) + 8|0);
  $600 = HEAP32[$599>>2]|0;HEAP32[$599>>2] = (($600-1)|0);
  $601 = ($600|0)==(1);
  if ($601) {
   __THREW__ = 0;
   invoke_viii(3262,($597|0),1,1);
   $602 = __THREW__; __THREW__ = 0;
   $603 = $602&1;
   if ($603) {
    $652 = ___cxa_find_matching_catch_3(0|0)|0;
    $653 = tempRet0;
    ___clang_call_terminate($652);
    // unreachable;
   }
  }
 }
 HEAP32[$17>>2] = 0;
 $604 = HEAP32[$16>>2]|0;
 $605 = ($604|0)==(0|0);
 if (!($605)) {
  $606 = ((($604)) + 8|0);
  $607 = HEAP32[$606>>2]|0;HEAP32[$606>>2] = (($607-1)|0);
  $608 = ($607|0)==(1);
  if ($608) {
   __THREW__ = 0;
   invoke_viii(3262,($604|0),1,1);
   $609 = __THREW__; __THREW__ = 0;
   $610 = $609&1;
   if ($610) {
    $652 = ___cxa_find_matching_catch_3(0|0)|0;
    $653 = tempRet0;
    ___clang_call_terminate($652);
    // unreachable;
   }
  }
 }
 HEAP32[$16>>2] = 0;
 $611 = HEAP32[$15>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4pairIN3osg7ref_ptrINS9_7UniformEEEjEEEENS_19__map_value_compareIS7_SE_NS_4lessIS7_EELb1EEENS5_ISE_EEE7destroyEPNS_11__tree_nodeISE_PvEE($12,$611);
 $612 = HEAP32[$11>>2]|0;
 $613 = ($612|0)==(0|0);
 if (!($613)) {
  $614 = ((($612)) + 8|0);
  $615 = HEAP32[$614>>2]|0;HEAP32[$614>>2] = (($615-1)|0);
  $616 = ($615|0)==(1);
  if ($616) {
   __THREW__ = 0;
   invoke_viii(3262,($612|0),1,1);
   $617 = __THREW__; __THREW__ = 0;
   $618 = $617&1;
   if ($618) {
    $652 = ___cxa_find_matching_catch_3(0|0)|0;
    $653 = tempRet0;
    ___clang_call_terminate($652);
    // unreachable;
   }
  }
 }
 HEAP32[$11>>2] = 0;
 $619 = HEAP32[$10>>2]|0;
 $620 = ($619|0)==(0|0);
 if (!($620)) {
  $621 = ((($619)) + 8|0);
  $622 = HEAP32[$621>>2]|0;HEAP32[$621>>2] = (($622-1)|0);
  $623 = ($622|0)==(1);
  if ($623) {
   __THREW__ = 0;
   invoke_viii(3262,($619|0),1,1);
   $624 = __THREW__; __THREW__ = 0;
   $625 = $624&1;
   if ($625) {
    $652 = ___cxa_find_matching_catch_3(0|0)|0;
    $653 = tempRet0;
    ___clang_call_terminate($652);
    // unreachable;
   }
  }
 }
 HEAP32[$10>>2] = 0;
 $626 = ((($0)) + 108|0);
 $627 = HEAP32[$626>>2]|0;
 $628 = ($627|0)==(0|0);
 if (!($628)) {
  $629 = ((($0)) + 112|0);
  $630 = HEAP32[$629>>2]|0;
  $631 = ($630|0)==($627|0);
  if (!($631)) {
   $scevgep$i$i$i54 = ((($630)) + -4|0);
   $632 = $scevgep$i$i$i54;
   $633 = $627;
   $634 = (($632) - ($633))|0;
   $635 = $634 >>> 2;
   $636 = $635 ^ -1;
   $scevgep5$i$i$i55 = (($630) + ($636<<2)|0);
   HEAP32[$629>>2] = $scevgep5$i$i$i55;
  }
  __ZdlPv($627);
 }
 $637 = ((($0)) + 96|0);
 $638 = HEAP32[$637>>2]|0;
 $639 = ($638|0)==(0|0);
 if (!($639)) {
  $687 = ((($0)) + 100|0);
  $688 = HEAP32[$687>>2]|0;
  $689 = ($688|0)==($638|0);
  if (!($689)) {
   $scevgep$i$i$i54$1 = ((($688)) + -4|0);
   $690 = $scevgep$i$i$i54$1;
   $691 = $638;
   $692 = (($690) - ($691))|0;
   $693 = $692 >>> 2;
   $694 = $693 ^ -1;
   $scevgep5$i$i$i55$1 = (($688) + ($694<<2)|0);
   HEAP32[$687>>2] = $scevgep5$i$i$i55$1;
  }
  __ZdlPv($638);
 }
 $695 = ((($0)) + 84|0);
 $696 = HEAP32[$695>>2]|0;
 $697 = ($696|0)==(0|0);
 if (!($697)) {
  $698 = ((($0)) + 88|0);
  $699 = HEAP32[$698>>2]|0;
  $700 = ($699|0)==($696|0);
  if (!($700)) {
   $scevgep$i$i$i54$2 = ((($699)) + -4|0);
   $701 = $scevgep$i$i$i54$2;
   $702 = $696;
   $703 = (($701) - ($702))|0;
   $704 = $703 >>> 2;
   $705 = $704 ^ -1;
   $scevgep5$i$i$i55$2 = (($699) + ($705<<2)|0);
   HEAP32[$698>>2] = $scevgep5$i$i$i55$2;
  }
  __ZdlPv($696);
 }
 $706 = ((($0)) + 72|0);
 $707 = HEAP32[$706>>2]|0;
 $708 = ($707|0)==(0|0);
 if (!($708)) {
  $709 = ((($0)) + 76|0);
  $710 = HEAP32[$709>>2]|0;
  $711 = ($710|0)==($707|0);
  if (!($711)) {
   $scevgep$i$i$i54$3 = ((($710)) + -4|0);
   $712 = $scevgep$i$i$i54$3;
   $713 = $707;
   $714 = (($712) - ($713))|0;
   $715 = $714 >>> 2;
   $716 = $715 ^ -1;
   $scevgep5$i$i$i55$3 = (($710) + ($716<<2)|0);
   HEAP32[$709>>2] = $scevgep5$i$i$i55$3;
  }
  __ZdlPv($707);
 }
 $717 = ((($0)) + 60|0);
 $643 = HEAP32[$717>>2]|0;
 $718 = ($643|0)==(0|0);
 if (!($718)) {
  $640 = ((($0)) + 64|0);
  $641 = HEAP32[$640>>2]|0;
  $642 = ($641|0)==($643|0);
  if (!($642)) {
   $scevgep$i$i$i = ((($641)) + -2|0);
   $644 = $scevgep$i$i$i;
   $645 = $643;
   $646 = (($644) - ($645))|0;
   $647 = $646 >>> 1;
   $648 = $647 ^ -1;
   $scevgep5$i$i$i = (($641) + ($648<<1)|0);
   HEAP32[$640>>2] = $scevgep5$i$i$i;
  }
  __ZdlPv($643);
 }
 $649 = ((($0)) + 48|0);
 $650 = HEAP32[$649>>2]|0;
 $651 = ($650|0)==(0|0);
 if (!($651)) {
  $654 = ((($0)) + 52|0);
  $655 = HEAP32[$654>>2]|0;
  $656 = ($655|0)==($650|0);
  if (!($656)) {
   $scevgep$i$i$i$1 = ((($655)) + -2|0);
   $657 = $scevgep$i$i$i$1;
   $658 = $650;
   $659 = (($657) - ($658))|0;
   $660 = $659 >>> 1;
   $661 = $660 ^ -1;
   $scevgep5$i$i$i$1 = (($655) + ($661<<1)|0);
   HEAP32[$654>>2] = $scevgep5$i$i$i$1;
  }
  __ZdlPv($650);
 }
 $662 = ((($0)) + 36|0);
 $663 = HEAP32[$662>>2]|0;
 $664 = ($663|0)==(0|0);
 if (!($664)) {
  $665 = ((($0)) + 40|0);
  $666 = HEAP32[$665>>2]|0;
  $667 = ($666|0)==($663|0);
  if (!($667)) {
   $scevgep$i$i$i$2 = ((($666)) + -2|0);
   $668 = $scevgep$i$i$i$2;
   $669 = $663;
   $670 = (($668) - ($669))|0;
   $671 = $670 >>> 1;
   $672 = $671 ^ -1;
   $scevgep5$i$i$i$2 = (($666) + ($672<<1)|0);
   HEAP32[$665>>2] = $scevgep5$i$i$i$2;
  }
  __ZdlPv($663);
 }
 $673 = ((($0)) + 24|0);
 $674 = HEAP32[$673>>2]|0;
 $675 = ($674|0)==(0|0);
 if (!($675)) {
  $676 = ((($0)) + 28|0);
  $677 = HEAP32[$676>>2]|0;
  $678 = ($677|0)==($674|0);
  if (!($678)) {
   $scevgep$i$i$i$3 = ((($677)) + -2|0);
   $679 = $scevgep$i$i$i$3;
   $680 = $674;
   $681 = (($679) - ($680))|0;
   $682 = $681 >>> 1;
   $683 = $682 ^ -1;
   $scevgep5$i$i$i$3 = (($677) + ($683<<1)|0);
   HEAP32[$676>>2] = $scevgep5$i$i$i$3;
  }
  __ZdlPv($674);
 }
 $684 = HEAP32[$8>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIPKSt9type_infoN3osg7ref_ptrINS5_10ReferencedEEEEENS_19__map_value_compareIS4_S9_NS_4lessIS4_EELb1EEENS_9allocatorIS9_EEE7destroyEPNS_11__tree_nodeIS9_PvEE($5,$684);
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $685 = __THREW__; __THREW__ = 0;
 $686 = $685&1;
 if ($686) {
  $652 = ___cxa_find_matching_catch_3(0|0)|0;
  $653 = tempRet0;
  ___clang_call_terminate($652);
  // unreachable;
 } else {
  ___resumeException($$21|0);
  // unreachable;
 }
}
function __ZN3osg5State25resetVertexAttributeAliasEbj($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$i = 0, $$0$i149 = 0, $$0$i324 = 0, $$0$i332 = 0, $$03$i = 0, $$03$i148 = 0, $$03$i323 = 0, $$03$i331 = 0, $$034$lcssa = 0, $$034558 = 0, $$035557 = 0, $$0559 = 0, $$10 = 0, $$1047 = 0, $$12 = 0, $$1249 = 0, $$14 = 0, $$1451 = 0, $$23 = 0, $$2360 = 0;
 var $$25 = 0, $$2562 = 0, $$27 = 0, $$2764 = 0, $$28 = 0, $$2865 = 0, $$29 = 0, $$2966 = 0, $$30 = 0, $$3067 = 0, $$31 = 0, $$3168 = 0, $$7 = 0, $$744 = 0, $$8 = 0, $$845 = 0, $$9 = 0, $$946 = 0, $$pre = 0, $$pre564 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0;
 var $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0;
 var $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0;
 var $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0;
 var $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0;
 var $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0;
 var $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0;
 var $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0;
 var $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0;
 var $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0;
 var $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0;
 var $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0;
 var $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0;
 var $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0;
 var $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0;
 var $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0;
 var $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0;
 var $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0;
 var $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0;
 var $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0;
 var $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0;
 var $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0;
 var $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0;
 var $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0;
 var $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0;
 var $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0;
 var $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0;
 var $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0;
 var $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0;
 var $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0;
 var $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0;
 var $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0;
 var $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0;
 var $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0;
 var $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0;
 var $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0;
 var $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $eh$lpad$body$i$index2Z2D = 0, $eh$lpad$body$i$indexZ2D = 0, $eh$lpad$body$i146$index7Z2D = 0, $eh$lpad$body$i146$indexZ2D = 0, $eh$lpad$body$i321$index12Z2D = 0, $eh$lpad$body$i321$indexZ2D = 0, $eh$lpad$body$i329$index17Z2D = 0, $eh$lpad$body$i329$indexZ2D = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1072|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(1072|0);
 $3 = sp + 1052|0;
 $4 = sp + 1040|0;
 $5 = sp + 1028|0;
 $6 = sp + 1016|0;
 $7 = sp + 1004|0;
 $8 = sp + 992|0;
 $9 = sp + 980|0;
 $10 = sp + 968|0;
 $11 = sp + 956|0;
 $12 = sp + 944|0;
 $13 = sp + 16|0;
 $14 = sp + 932|0;
 $15 = sp + 920|0;
 $16 = sp + 776|0;
 $17 = sp + 632|0;
 $18 = sp + 616|0;
 $19 = sp + 604|0;
 $20 = sp + 592|0;
 $21 = sp + 580|0;
 $22 = sp + 568|0;
 $23 = sp + 556|0;
 $24 = sp + 544|0;
 $25 = sp + 532|0;
 $26 = sp + 520|0;
 $27 = sp + 508|0;
 $28 = sp + 496|0;
 $29 = sp + 484|0;
 $30 = sp + 472|0;
 $31 = sp + 460|0;
 $32 = sp + 448|0;
 $33 = sp;
 $34 = sp + 436|0;
 $35 = sp + 424|0;
 $36 = sp + 412|0;
 $37 = sp + 400|0;
 $38 = sp + 388|0;
 $39 = sp + 376|0;
 $40 = sp + 364|0;
 $41 = sp + 352|0;
 $42 = sp + 208|0;
 $43 = sp + 64|0;
 $44 = sp + 52|0;
 $45 = sp + 40|0;
 $46 = sp + 28|0;
 $47 = ((($0)) + 552|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = ((($0)) + 556|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = ($50|0)==($48|0);
 if (!($51)) {
  $53 = $50;
  while(1) {
   $52 = ((($53)) + -40|0);
   HEAP32[$49>>2] = $52;
   $54 = ((($53)) + -12|0);
   $55 = ((($54)) + 11|0);
   $56 = HEAP8[$55>>0]|0;
   $57 = ($56<<24>>24)<(0);
   if ($57) {
    $58 = HEAP32[$54>>2]|0;
    __ZdlPv($58);
   }
   $59 = ((($53)) + -24|0);
   $60 = ((($59)) + 11|0);
   $61 = HEAP8[$60>>0]|0;
   $62 = ($61<<24>>24)<(0);
   if ($62) {
    $63 = HEAP32[$59>>2]|0;
    __ZdlPv($63);
   }
   $64 = ((($53)) + -36|0);
   $65 = ((($64)) + 11|0);
   $66 = HEAP8[$65>>0]|0;
   $67 = ($66<<24>>24)<(0);
   if ($67) {
    $70 = HEAP32[$64>>2]|0;
    __ZdlPv($70);
   }
   $68 = HEAP32[$49>>2]|0;
   $69 = ($68|0)==($48|0);
   if ($69) {
    break;
   } else {
    $53 = $68;
   }
  }
 }
 $71 = ((($0)) + 564|0);
 $72 = ((($0)) + 568|0);
 $73 = HEAP32[$72>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEjEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($71,$73);
 $74 = ((($0)) + 572|0);
 HEAP32[$74>>2] = 0;
 HEAP32[$71>>2] = $72;
 HEAP32[$72>>2] = 0;
 $75 = ((($0)) + 352|0);
 if ($1) {
  ;HEAP32[$7>>2]=0|0;HEAP32[$7+4>>2]=0|0;HEAP32[$7+8>>2]=0|0;
  $76 = ((($7)) + 11|0);
  HEAP8[$76>>0] = 9;
  dest=$7; src=148973; stop=dest+9|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
  $77 = ((($7)) + 9|0);
  HEAP8[$77>>0] = 0;
  $78 = ((($8)) + 11|0);
  HEAP8[$78>>0] = 10;
  dest=$8; src=148983; stop=dest+10|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
  $79 = ((($8)) + 10|0);
  HEAP8[$79>>0] = 0;
  ;HEAP32[$9>>2]=0|0;HEAP32[$9+4>>2]=0|0;HEAP32[$9+8>>2]=0|0;
  $80 = ((($9)) + 11|0);
  HEAP8[$80>>0] = 5;
  ;HEAP8[$9>>0]=HEAP8[148994>>0]|0;HEAP8[$9+1>>0]=HEAP8[148994+1>>0]|0;HEAP8[$9+2>>0]=HEAP8[148994+2>>0]|0;HEAP8[$9+3>>0]=HEAP8[148994+3>>0]|0;HEAP8[$9+4>>0]=HEAP8[148994+4>>0]|0;
  $81 = ((($9)) + 5|0);
  HEAP8[$81>>0] = 0;
  __THREW__ = 0;
  invoke_viiiiii(3924,($0|0),($75|0),0,($7|0),($8|0),($9|0));
  $82 = __THREW__; __THREW__ = 0;
  $83 = $82&1;
  if ($83) {
   $209 = ___cxa_find_matching_catch_2()|0;
   $210 = tempRet0;
   $211 = HEAP8[$80>>0]|0;
   $212 = ($211<<24>>24)<(0);
   if ($212) {
    $213 = HEAP32[$9>>2]|0;
    __ZdlPv($213);
   }
   $214 = HEAP8[$78>>0]|0;
   $215 = ($214<<24>>24)<(0);
   if ($215) {
    $216 = HEAP32[$8>>2]|0;
    __ZdlPv($216);
   }
   $217 = HEAP8[$76>>0]|0;
   $218 = ($217<<24>>24)<(0);
   if (!($218)) {
    $$31 = $210;$$3168 = $209;
    ___resumeException($$3168|0);
    // unreachable;
   }
   $219 = HEAP32[$7>>2]|0;
   __ZdlPv($219);
   $$31 = $210;$$3168 = $209;
   ___resumeException($$3168|0);
   // unreachable;
  }
  $84 = HEAP8[$80>>0]|0;
  $85 = ($84<<24>>24)<(0);
  if ($85) {
   $86 = HEAP32[$9>>2]|0;
   __ZdlPv($86);
  }
  $87 = HEAP8[$78>>0]|0;
  $88 = ($87<<24>>24)<(0);
  if ($88) {
   $89 = HEAP32[$8>>2]|0;
   __ZdlPv($89);
  }
  $90 = HEAP8[$76>>0]|0;
  $91 = ($90<<24>>24)<(0);
  if ($91) {
   $92 = HEAP32[$7>>2]|0;
   __ZdlPv($92);
  }
  $93 = ((($0)) + 392|0);
  ;HEAP32[$10>>2]=0|0;HEAP32[$10+4>>2]=0|0;HEAP32[$10+8>>2]=0|0;
  $94 = ((($10)) + 11|0);
  HEAP8[$94>>0] = 9;
  dest=$10; src=149000; stop=dest+9|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
  $95 = ((($10)) + 9|0);
  HEAP8[$95>>0] = 0;
  $96 = ((($11)) + 11|0);
  HEAP8[$96>>0] = 10;
  dest=$11; src=149010; stop=dest+10|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
  $97 = ((($11)) + 10|0);
  HEAP8[$97>>0] = 0;
  ;HEAP32[$12>>2]=0|0;HEAP32[$12+4>>2]=0|0;HEAP32[$12+8>>2]=0|0;
  $98 = ((($12)) + 11|0);
  HEAP8[$98>>0] = 5;
  ;HEAP8[$12>>0]=HEAP8[149021>>0]|0;HEAP8[$12+1>>0]=HEAP8[149021+1>>0]|0;HEAP8[$12+2>>0]=HEAP8[149021+2>>0]|0;HEAP8[$12+3>>0]=HEAP8[149021+3>>0]|0;HEAP8[$12+4>>0]=HEAP8[149021+4>>0]|0;
  $99 = ((($12)) + 5|0);
  HEAP8[$99>>0] = 0;
  __THREW__ = 0;
  invoke_viiiiii(3924,($0|0),($93|0),1,($10|0),($11|0),($12|0));
  $100 = __THREW__; __THREW__ = 0;
  $101 = $100&1;
  if ($101) {
   $220 = ___cxa_find_matching_catch_2()|0;
   $221 = tempRet0;
   $222 = HEAP8[$98>>0]|0;
   $223 = ($222<<24>>24)<(0);
   if ($223) {
    $224 = HEAP32[$12>>2]|0;
    __ZdlPv($224);
   }
   $225 = HEAP8[$96>>0]|0;
   $226 = ($225<<24>>24)<(0);
   if ($226) {
    $227 = HEAP32[$11>>2]|0;
    __ZdlPv($227);
   }
   $228 = HEAP8[$94>>0]|0;
   $229 = ($228<<24>>24)<(0);
   if (!($229)) {
    $$31 = $221;$$3168 = $220;
    ___resumeException($$3168|0);
    // unreachable;
   }
   $230 = HEAP32[$10>>2]|0;
   __ZdlPv($230);
   $$31 = $221;$$3168 = $220;
   ___resumeException($$3168|0);
   // unreachable;
  }
  $102 = HEAP8[$98>>0]|0;
  $103 = ($102<<24>>24)<(0);
  if ($103) {
   $104 = HEAP32[$12>>2]|0;
   __ZdlPv($104);
  }
  $105 = HEAP8[$96>>0]|0;
  $106 = ($105<<24>>24)<(0);
  if ($106) {
   $107 = HEAP32[$11>>2]|0;
   __ZdlPv($107);
  }
  $108 = HEAP8[$94>>0]|0;
  $109 = ($108<<24>>24)<(0);
  if ($109) {
   $110 = HEAP32[$10>>2]|0;
   __ZdlPv($110);
  }
  $111 = ((($0)) + 432|0);
  ;HEAP32[$13>>2]=0|0;HEAP32[$13+4>>2]=0|0;HEAP32[$13+8>>2]=0|0;
  $112 = ((($13)) + 11|0);
  HEAP8[$112>>0] = 8;
  $113 = $13;
  $114 = $113;
  HEAP32[$114>>2] = 1130327143;
  $115 = (($113) + 4)|0;
  $116 = $115;
  HEAP32[$116>>2] = 1919904879;
  $117 = ((($13)) + 8|0);
  HEAP8[$117>>0] = 0;
  ;HEAP32[$14>>2]=0|0;HEAP32[$14+4>>2]=0|0;HEAP32[$14+8>>2]=0|0;
  $118 = ((($14)) + 11|0);
  HEAP8[$118>>0] = 9;
  dest=$14; src=149027; stop=dest+9|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
  $119 = ((($14)) + 9|0);
  HEAP8[$119>>0] = 0;
  ;HEAP32[$15>>2]=0|0;HEAP32[$15+4>>2]=0|0;HEAP32[$15+8>>2]=0|0;
  $120 = ((($15)) + 11|0);
  HEAP8[$120>>0] = 5;
  ;HEAP8[$15>>0]=HEAP8[148994>>0]|0;HEAP8[$15+1>>0]=HEAP8[148994+1>>0]|0;HEAP8[$15+2>>0]=HEAP8[148994+2>>0]|0;HEAP8[$15+3>>0]=HEAP8[148994+3>>0]|0;HEAP8[$15+4>>0]=HEAP8[148994+4>>0]|0;
  $121 = ((($15)) + 5|0);
  HEAP8[$121>>0] = 0;
  __THREW__ = 0;
  invoke_viiiiii(3924,($0|0),($111|0),2,($13|0),($14|0),($15|0));
  $122 = __THREW__; __THREW__ = 0;
  $123 = $122&1;
  if ($123) {
   $231 = ___cxa_find_matching_catch_2()|0;
   $232 = tempRet0;
   $233 = HEAP8[$120>>0]|0;
   $234 = ($233<<24>>24)<(0);
   if ($234) {
    $235 = HEAP32[$15>>2]|0;
    __ZdlPv($235);
   }
   $236 = HEAP8[$118>>0]|0;
   $237 = ($236<<24>>24)<(0);
   if ($237) {
    $238 = HEAP32[$14>>2]|0;
    __ZdlPv($238);
   }
   $239 = HEAP8[$112>>0]|0;
   $240 = ($239<<24>>24)<(0);
   if (!($240)) {
    $$31 = $232;$$3168 = $231;
    ___resumeException($$3168|0);
    // unreachable;
   }
   $241 = HEAP32[$13>>2]|0;
   __ZdlPv($241);
   $$31 = $232;$$3168 = $231;
   ___resumeException($$3168|0);
   // unreachable;
  }
  $124 = HEAP8[$120>>0]|0;
  $125 = ($124<<24>>24)<(0);
  if ($125) {
   $126 = HEAP32[$15>>2]|0;
   __ZdlPv($126);
  }
  $127 = HEAP8[$118>>0]|0;
  $128 = ($127<<24>>24)<(0);
  if ($128) {
   $129 = HEAP32[$14>>2]|0;
   __ZdlPv($129);
  }
  $130 = HEAP8[$112>>0]|0;
  $131 = ($130<<24>>24)<(0);
  if ($131) {
   $132 = HEAP32[$13>>2]|0;
   __ZdlPv($132);
  }
  $133 = HEAP32[$49>>2]|0;
  $134 = HEAP32[$47>>2]|0;
  $135 = (($133) - ($134))|0;
  $136 = (($135|0) / 40)&-1;
  $137 = ($136>>>0)<($2>>>0);
  $138 = $134;
  $139 = $133;
  if ($137) {
   $140 = (($2) - ($136))|0;
   __ZNSt3__26vectorIN3osg17VertexAttribAliasENS_9allocatorIS2_EEE8__appendEj($47,$140);
   $$pre564 = HEAP32[$49>>2]|0;
   $164 = $$pre564;
  } else {
   $141 = ($136>>>0)>($2>>>0);
   if ($141) {
    $142 = (($138) + (($2*40)|0)|0);
    $143 = ($139|0)==($142|0);
    if ($143) {
     $164 = $133;
    } else {
     $145 = $139;
     while(1) {
      $144 = ((($145)) + -40|0);
      HEAP32[$49>>2] = $144;
      $146 = ((($145)) + -12|0);
      $147 = ((($146)) + 11|0);
      $148 = HEAP8[$147>>0]|0;
      $149 = ($148<<24>>24)<(0);
      if ($149) {
       $150 = HEAP32[$146>>2]|0;
       __ZdlPv($150);
      }
      $151 = ((($145)) + -24|0);
      $152 = ((($151)) + 11|0);
      $153 = HEAP8[$152>>0]|0;
      $154 = ($153<<24>>24)<(0);
      if ($154) {
       $155 = HEAP32[$151>>2]|0;
       __ZdlPv($155);
      }
      $156 = ((($145)) + -36|0);
      $157 = ((($156)) + 11|0);
      $158 = HEAP8[$157>>0]|0;
      $159 = ($158<<24>>24)<(0);
      if ($159) {
       $192 = HEAP32[$156>>2]|0;
       __ZdlPv($192);
      }
      $160 = HEAP32[$49>>2]|0;
      $161 = ($160|0)==($142|0);
      if ($161) {
       break;
      } else {
       $145 = $160;
      }
     }
     $162 = $160;
     $164 = $162;
    }
   } else {
    $164 = $133;
   }
  }
  $163 = HEAP32[$47>>2]|0;
  $165 = ($164|0)==($163|0);
  L99: do {
   if ($165) {
    $$034$lcssa = 3;
   } else {
    $166 = ((($16)) + 64|0);
    $167 = ((($16)) + 8|0);
    $168 = ((($16)) + 12|0);
    $169 = ((($16)) + 4|0);
    $170 = ((($16)) + 64|0);
    $171 = ((($16)) + 136|0);
    $172 = ((($16)) + 140|0);
    $173 = ((($16)) + 44|0);
    $174 = ((($16)) + 60|0);
    $175 = ((($6)) + 11|0);
    $176 = ((($17)) + 64|0);
    $177 = ((($17)) + 8|0);
    $178 = ((($17)) + 12|0);
    $179 = ((($17)) + 4|0);
    $180 = ((($17)) + 64|0);
    $181 = ((($17)) + 136|0);
    $182 = ((($17)) + 140|0);
    $183 = ((($17)) + 44|0);
    $184 = ((($17)) + 60|0);
    $185 = ((($5)) + 11|0);
    $186 = ((($16)) + 8|0);
    $187 = ((($17)) + 8|0);
    $188 = ((($20)) + 11|0);
    $189 = ((($20)) + 5|0);
    $190 = ((($19)) + 11|0);
    $191 = ((($18)) + 11|0);
    $$034558 = 3;$$035557 = 0;
    while(1) {
     HEAP32[$167>>2] = (49248);
     HEAP32[$16>>2] = ((21156));
     HEAP32[$166>>2] = ((21176));
     HEAP32[$169>>2] = 0;
     __THREW__ = 0;
     invoke_vii(3368,($170|0),($168|0));
     $242 = __THREW__; __THREW__ = 0;
     $243 = $242&1;
     if ($243) {
      label = 76;
      break;
     }
     HEAP32[$171>>2] = 0;
     HEAP32[$172>>2] = -1;
     HEAP32[$16>>2] = (49228);
     HEAP32[$166>>2] = (49268);
     HEAP32[$167>>2] = (49248);
     __THREW__ = 0;
     invoke_vi(3369,($168|0));
     $244 = __THREW__; __THREW__ = 0;
     $245 = $244&1;
     if ($245) {
      label = 77;
      break;
     }
     HEAP32[$168>>2] = (37132);
     ;HEAP32[$173>>2]=0|0;HEAP32[$173+4>>2]=0|0;HEAP32[$173+8>>2]=0|0;HEAP32[$173+12>>2]=0|0;
     HEAP32[$174>>2] = 24;
     ;HEAP32[$6>>2]=0|0;HEAP32[$6+4>>2]=0|0;HEAP32[$6+8>>2]=0|0;
     __THREW__ = 0;
     invoke_vii(3370,($168|0),($6|0));
     $246 = __THREW__; __THREW__ = 0;
     $247 = $246&1;
     if ($247) {
      label = 70;
      break;
     }
     $248 = HEAP8[$175>>0]|0;
     $249 = ($248<<24>>24)<(0);
     if ($249) {
      $250 = HEAP32[$6>>2]|0;
      __ZdlPv($250);
     }
     HEAP32[$177>>2] = (49248);
     HEAP32[$17>>2] = ((21156));
     HEAP32[$176>>2] = ((21176));
     HEAP32[$179>>2] = 0;
     __THREW__ = 0;
     invoke_vii(3368,($180|0),($178|0));
     $274 = __THREW__; __THREW__ = 0;
     $275 = $274&1;
     if ($275) {
      label = 93;
      break;
     }
     HEAP32[$181>>2] = 0;
     HEAP32[$182>>2] = -1;
     HEAP32[$17>>2] = (49228);
     HEAP32[$176>>2] = (49268);
     HEAP32[$177>>2] = (49248);
     __THREW__ = 0;
     invoke_vi(3369,($178|0));
     $276 = __THREW__; __THREW__ = 0;
     $277 = $276&1;
     if ($277) {
      label = 94;
      break;
     }
     HEAP32[$178>>2] = (37132);
     ;HEAP32[$183>>2]=0|0;HEAP32[$183+4>>2]=0|0;HEAP32[$183+8>>2]=0|0;HEAP32[$183+12>>2]=0|0;
     HEAP32[$184>>2] = 24;
     ;HEAP32[$5>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;
     __THREW__ = 0;
     invoke_vii(3370,($178|0),($5|0));
     $278 = __THREW__; __THREW__ = 0;
     $279 = $278&1;
     if ($279) {
      label = 87;
      break;
     }
     $280 = HEAP8[$185>>0]|0;
     $281 = ($280<<24>>24)<(0);
     if ($281) {
      $282 = HEAP32[$5>>2]|0;
      __ZdlPv($282);
     }
     __THREW__ = 0;
     $306 = (invoke_iiii(3267,($186|0),(149074|0),16)|0);
     $307 = __THREW__; __THREW__ = 0;
     $308 = $307&1;
     if ($308) {
      label = 113;
      break;
     }
     __THREW__ = 0;
     (invoke_iii(3417,($306|0),($$035557|0))|0);
     $309 = __THREW__; __THREW__ = 0;
     $310 = $309&1;
     if ($310) {
      label = 113;
      break;
     }
     __THREW__ = 0;
     $311 = (invoke_iiii(3267,($187|0),(149091|0),17)|0);
     $312 = __THREW__; __THREW__ = 0;
     $313 = $312&1;
     if ($313) {
      label = 113;
      break;
     }
     __THREW__ = 0;
     (invoke_iii(3417,($311|0),($$035557|0))|0);
     $314 = __THREW__; __THREW__ = 0;
     $315 = $314&1;
     if ($315) {
      label = 113;
      break;
     }
     $316 = HEAP32[$47>>2]|0;
     $317 = (($316) + (($$035557*40)|0)|0);
     $318 = (($$034558) + 1)|0;
     __THREW__ = 0;
     invoke_vii(3615,($18|0),($168|0));
     $319 = __THREW__; __THREW__ = 0;
     $320 = $319&1;
     if ($320) {
      label = 113;
      break;
     }
     __THREW__ = 0;
     invoke_vii(3615,($19|0),($178|0));
     $321 = __THREW__; __THREW__ = 0;
     $322 = $321&1;
     if ($322) {
      label = 114;
      break;
     }
     ;HEAP32[$20>>2]=0|0;HEAP32[$20+4>>2]=0|0;HEAP32[$20+8>>2]=0|0;
     HEAP8[$188>>0] = 5;
     ;HEAP8[$20>>0]=HEAP8[148994>>0]|0;HEAP8[$20+1>>0]=HEAP8[148994+1>>0]|0;HEAP8[$20+2>>0]=HEAP8[148994+2>>0]|0;HEAP8[$20+3>>0]=HEAP8[148994+3>>0]|0;HEAP8[$20+4>>0]=HEAP8[148994+4>>0]|0;
     HEAP8[$189>>0] = 0;
     __THREW__ = 0;
     invoke_viiiiii(3924,($0|0),($317|0),($$034558|0),($18|0),($19|0),($20|0));
     $323 = __THREW__; __THREW__ = 0;
     $324 = $323&1;
     if ($324) {
      label = 115;
      break;
     }
     $325 = HEAP8[$188>>0]|0;
     $326 = ($325<<24>>24)<(0);
     if ($326) {
      $327 = HEAP32[$20>>2]|0;
      __ZdlPv($327);
     }
     $328 = HEAP8[$190>>0]|0;
     $329 = ($328<<24>>24)<(0);
     if ($329) {
      $330 = HEAP32[$19>>2]|0;
      __ZdlPv($330);
     }
     $331 = HEAP8[$191>>0]|0;
     $332 = ($331<<24>>24)<(0);
     if ($332) {
      $333 = HEAP32[$18>>2]|0;
      __ZdlPv($333);
     }
     __THREW__ = 0;
     invoke_vi(1045,($17|0));
     $334 = __THREW__; __THREW__ = 0;
     $335 = $334&1;
     if ($335) {
      label = 121;
      break;
     }
     __ZNSt3__218basic_stringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($16);
     $336 = (($$035557) + 1)|0;
     $337 = HEAP32[$49>>2]|0;
     $338 = HEAP32[$47>>2]|0;
     $339 = (($337) - ($338))|0;
     $340 = (($339|0) / 40)&-1;
     $341 = ($336>>>0)<($340>>>0);
     if ($341) {
      $$034558 = $318;$$035557 = $336;
     } else {
      $$034$lcssa = $318;
      break L99;
     }
    }
    switch (label|0) {
     case 70: {
      $251 = ___cxa_find_matching_catch_2()|0;
      $252 = tempRet0;
      $253 = HEAP8[$175>>0]|0;
      $254 = ($253<<24>>24)<(0);
      if ($254) {
       $255 = HEAP32[$6>>2]|0;
       __ZdlPv($255);
      }
      $256 = ((($173)) + 11|0);
      $257 = HEAP8[$256>>0]|0;
      $258 = ($257<<24>>24)<(0);
      if ($258) {
       $259 = HEAP32[$173>>2]|0;
       __ZdlPv($259);
      }
      __THREW__ = 0;
      invoke_vi(2911,($168|0));
      $260 = __THREW__; __THREW__ = 0;
      $261 = $260&1;
      if (!($261)) {
       $eh$lpad$body$i$index2Z2D = $252;$eh$lpad$body$i$indexZ2D = $251;
       label = 78;
       break;
      }
      $262 = ___cxa_find_matching_catch_3(0|0)|0;
      $263 = tempRet0;
      ___clang_call_terminate($262);
      // unreachable;
      break;
     }
     case 76: {
      $264 = ___cxa_find_matching_catch_2()|0;
      $265 = tempRet0;
      $$0$i = $265;$$03$i = $264;
      label = 79;
      break;
     }
     case 77: {
      $266 = ___cxa_find_matching_catch_2()|0;
      $267 = tempRet0;
      $eh$lpad$body$i$index2Z2D = $267;$eh$lpad$body$i$indexZ2D = $266;
      label = 78;
      break;
     }
     case 87: {
      $283 = ___cxa_find_matching_catch_2()|0;
      $284 = tempRet0;
      $285 = HEAP8[$185>>0]|0;
      $286 = ($285<<24>>24)<(0);
      if ($286) {
       $287 = HEAP32[$5>>2]|0;
       __ZdlPv($287);
      }
      $288 = ((($183)) + 11|0);
      $289 = HEAP8[$288>>0]|0;
      $290 = ($289<<24>>24)<(0);
      if ($290) {
       $291 = HEAP32[$183>>2]|0;
       __ZdlPv($291);
      }
      __THREW__ = 0;
      invoke_vi(2911,($178|0));
      $292 = __THREW__; __THREW__ = 0;
      $293 = $292&1;
      if (!($293)) {
       $eh$lpad$body$i146$index7Z2D = $284;$eh$lpad$body$i146$indexZ2D = $283;
       label = 95;
       break;
      }
      $294 = ___cxa_find_matching_catch_3(0|0)|0;
      $295 = tempRet0;
      ___clang_call_terminate($294);
      // unreachable;
      break;
     }
     case 93: {
      $296 = ___cxa_find_matching_catch_2()|0;
      $297 = tempRet0;
      $$0$i149 = $297;$$03$i148 = $296;
      label = 96;
      break;
     }
     case 94: {
      $298 = ___cxa_find_matching_catch_2()|0;
      $299 = tempRet0;
      $eh$lpad$body$i146$index7Z2D = $299;$eh$lpad$body$i146$indexZ2D = $298;
      label = 95;
      break;
     }
     case 113: {
      $342 = ___cxa_find_matching_catch_2()|0;
      $343 = tempRet0;
      $$8 = $343;$$845 = $342;
      label = 122;
      break;
     }
     case 114: {
      $344 = ___cxa_find_matching_catch_2()|0;
      $345 = tempRet0;
      $$7 = $345;$$744 = $344;
      label = 119;
      break;
     }
     case 115: {
      $346 = ___cxa_find_matching_catch_2()|0;
      $347 = tempRet0;
      $348 = HEAP8[$188>>0]|0;
      $349 = ($348<<24>>24)<(0);
      if ($349) {
       $350 = HEAP32[$20>>2]|0;
       __ZdlPv($350);
      }
      $351 = HEAP8[$190>>0]|0;
      $352 = ($351<<24>>24)<(0);
      if (!($352)) {
       $$7 = $347;$$744 = $346;
       label = 119;
       break;
      }
      $353 = HEAP32[$19>>2]|0;
      __ZdlPv($353);
      $$7 = $347;$$744 = $346;
      label = 119;
      break;
     }
     case 121: {
      $357 = ___cxa_find_matching_catch_2()|0;
      $358 = tempRet0;
      $$9 = $358;$$946 = $357;
      label = 123;
      break;
     }
    }
    if ((label|0) == 78) {
     __THREW__ = 0;
     invoke_vii(3568,($16|0),((49280)|0));
     $268 = __THREW__; __THREW__ = 0;
     $269 = $268&1;
     if ($269) {
      $272 = ___cxa_find_matching_catch_3(0|0)|0;
      $273 = tempRet0;
      ___clang_call_terminate($272);
      // unreachable;
     } else {
      $$0$i = $eh$lpad$body$i$index2Z2D;$$03$i = $eh$lpad$body$i$indexZ2D;
      label = 79;
     }
    }
    else if ((label|0) == 95) {
     __THREW__ = 0;
     invoke_vii(3568,($17|0),((49280)|0));
     $300 = __THREW__; __THREW__ = 0;
     $301 = $300&1;
     if ($301) {
      $304 = ___cxa_find_matching_catch_3(0|0)|0;
      $305 = tempRet0;
      ___clang_call_terminate($304);
      // unreachable;
     } else {
      $$0$i149 = $eh$lpad$body$i146$index7Z2D;$$03$i148 = $eh$lpad$body$i146$indexZ2D;
      label = 96;
     }
    }
    else if ((label|0) == 119) {
     $354 = HEAP8[$191>>0]|0;
     $355 = ($354<<24>>24)<(0);
     if ($355) {
      $356 = HEAP32[$18>>2]|0;
      __ZdlPv($356);
      $$8 = $$7;$$845 = $$744;
      label = 122;
     } else {
      $$8 = $$7;$$845 = $$744;
      label = 122;
     }
    }
    if ((label|0) == 79) {
     __THREW__ = 0;
     invoke_vi(2907,($166|0));
     $270 = __THREW__; __THREW__ = 0;
     $271 = $270&1;
     if ($271) {
      $272 = ___cxa_find_matching_catch_3(0|0)|0;
      $273 = tempRet0;
      ___clang_call_terminate($272);
      // unreachable;
     } else {
      ___resumeException($$03$i|0);
      // unreachable;
     }
    }
    else if ((label|0) == 96) {
     __THREW__ = 0;
     invoke_vi(2907,($176|0));
     $302 = __THREW__; __THREW__ = 0;
     $303 = $302&1;
     if ($303) {
      $304 = ___cxa_find_matching_catch_3(0|0)|0;
      $305 = tempRet0;
      ___clang_call_terminate($304);
      // unreachable;
     } else {
      $$10 = $$0$i149;$$1047 = $$03$i148;
     }
    }
    else if ((label|0) == 122) {
     __THREW__ = 0;
     invoke_vi(1045,($17|0));
     $359 = __THREW__; __THREW__ = 0;
     $360 = $359&1;
     if ($360) {
      $783 = ___cxa_find_matching_catch_3(0|0)|0;
      $784 = tempRet0;
      ___clang_call_terminate($783);
      // unreachable;
     } else {
      $$9 = $$8;$$946 = $$845;
      label = 123;
     }
    }
    if ((label|0) == 123) {
     $$10 = $$9;$$1047 = $$946;
    }
    __THREW__ = 0;
    invoke_vi(1045,($16|0));
    $361 = __THREW__; __THREW__ = 0;
    $362 = $361&1;
    if ($362) {
     $783 = ___cxa_find_matching_catch_3(0|0)|0;
     $784 = tempRet0;
     ___clang_call_terminate($783);
     // unreachable;
    }
    $$31 = $$10;$$3168 = $$1047;
    ___resumeException($$3168|0);
    // unreachable;
   }
  } while(0);
  $193 = (($$034$lcssa) + 1)|0;
  $194 = (__Znwj(32)|0);
  HEAP32[$21>>2] = $194;
  $195 = ((($21)) + 8|0);
  HEAP32[$195>>2] = -2147483616;
  $196 = ((($21)) + 4|0);
  HEAP32[$196>>2] = 17;
  dest=$194; src=149037; stop=dest+17|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
  $197 = ((($194)) + 17|0);
  HEAP8[$197>>0] = 0;
  ;HEAP32[$22>>2]=0|0;HEAP32[$22+4>>2]=0|0;HEAP32[$22+8>>2]=0|0;
  __THREW__ = 0;
  $198 = (invoke_ii(3276,32)|0);
  $199 = __THREW__; __THREW__ = 0;
  $200 = $199&1;
  do {
   if ($200) {
    $400 = ___cxa_find_matching_catch_2()|0;
    $401 = tempRet0;
    $$12 = $401;$$1249 = $400;
   } else {
    $201 = ((($0)) + 472|0);
    HEAP32[$22>>2] = $198;
    $202 = ((($22)) + 8|0);
    HEAP32[$202>>2] = -2147483616;
    $203 = ((($22)) + 4|0);
    HEAP32[$203>>2] = 18;
    dest=$198; src=149055; stop=dest+18|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
    $204 = ((($198)) + 18|0);
    HEAP8[$204>>0] = 0;
    ;HEAP32[$23>>2]=0|0;HEAP32[$23+4>>2]=0|0;HEAP32[$23+8>>2]=0|0;
    $205 = ((($23)) + 11|0);
    HEAP8[$205>>0] = 5;
    ;HEAP8[$23>>0]=HEAP8[148994>>0]|0;HEAP8[$23+1>>0]=HEAP8[148994+1>>0]|0;HEAP8[$23+2>>0]=HEAP8[148994+2>>0]|0;HEAP8[$23+3>>0]=HEAP8[148994+3>>0]|0;HEAP8[$23+4>>0]=HEAP8[148994+4>>0]|0;
    $206 = ((($23)) + 5|0);
    HEAP8[$206>>0] = 0;
    __THREW__ = 0;
    invoke_viiiiii(3924,($0|0),($201|0),($$034$lcssa|0),($21|0),($22|0),($23|0));
    $207 = __THREW__; __THREW__ = 0;
    $208 = $207&1;
    if ($208) {
     $402 = ___cxa_find_matching_catch_2()|0;
     $403 = tempRet0;
     $404 = HEAP8[$205>>0]|0;
     $405 = ($404<<24>>24)<(0);
     if ($405) {
      $406 = HEAP32[$23>>2]|0;
      __ZdlPv($406);
     }
     $407 = ((($22)) + 11|0);
     $408 = HEAP8[$407>>0]|0;
     $409 = ($408<<24>>24)<(0);
     if (!($409)) {
      $$12 = $403;$$1249 = $402;
      break;
     }
     $410 = HEAP32[$22>>2]|0;
     __ZdlPv($410);
     $$12 = $403;$$1249 = $402;
     break;
    }
    $363 = HEAP8[$205>>0]|0;
    $364 = ($363<<24>>24)<(0);
    if ($364) {
     $365 = HEAP32[$23>>2]|0;
     __ZdlPv($365);
    }
    $366 = ((($22)) + 11|0);
    $367 = HEAP8[$366>>0]|0;
    $368 = ($367<<24>>24)<(0);
    if ($368) {
     $369 = HEAP32[$22>>2]|0;
     __ZdlPv($369);
    }
    $370 = ((($21)) + 11|0);
    $371 = HEAP8[$370>>0]|0;
    $372 = ($371<<24>>24)<(0);
    if ($372) {
     $373 = HEAP32[$21>>2]|0;
     __ZdlPv($373);
    }
    $374 = (__Znwj(16)|0);
    HEAP32[$24>>2] = $374;
    $375 = ((($24)) + 8|0);
    HEAP32[$375>>2] = -2147483632;
    $376 = ((($24)) + 4|0);
    HEAP32[$376>>2] = 11;
    dest=$374; src=149109; stop=dest+11|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
    $377 = ((($374)) + 11|0);
    HEAP8[$377>>0] = 0;
    ;HEAP32[$25>>2]=0|0;HEAP32[$25+4>>2]=0|0;HEAP32[$25+8>>2]=0|0;
    __THREW__ = 0;
    $378 = (invoke_ii(3276,16)|0);
    $379 = __THREW__; __THREW__ = 0;
    $380 = $379&1;
    do {
     if ($380) {
      $415 = ___cxa_find_matching_catch_2()|0;
      $416 = tempRet0;
      $$14 = $416;$$1451 = $415;
     } else {
      $381 = ((($0)) + 512|0);
      HEAP32[$25>>2] = $378;
      $382 = ((($25)) + 8|0);
      HEAP32[$382>>2] = -2147483632;
      $383 = ((($25)) + 4|0);
      HEAP32[$383>>2] = 12;
      dest=$378; src=149121; stop=dest+12|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
      $384 = ((($378)) + 12|0);
      HEAP8[$384>>0] = 0;
      ;HEAP32[$26>>2]=0|0;HEAP32[$26+4>>2]=0|0;HEAP32[$26+8>>2]=0|0;
      $385 = ((($26)) + 11|0);
      HEAP8[$385>>0] = 6;
      ;HEAP8[$26>>0]=HEAP8[149134>>0]|0;HEAP8[$26+1>>0]=HEAP8[149134+1>>0]|0;HEAP8[$26+2>>0]=HEAP8[149134+2>>0]|0;HEAP8[$26+3>>0]=HEAP8[149134+3>>0]|0;HEAP8[$26+4>>0]=HEAP8[149134+4>>0]|0;HEAP8[$26+5>>0]=HEAP8[149134+5>>0]|0;
      $386 = ((($26)) + 6|0);
      HEAP8[$386>>0] = 0;
      __THREW__ = 0;
      invoke_viiiiii(3924,($0|0),($381|0),($193|0),($24|0),($25|0),($26|0));
      $387 = __THREW__; __THREW__ = 0;
      $388 = $387&1;
      if ($388) {
       $417 = ___cxa_find_matching_catch_2()|0;
       $418 = tempRet0;
       $419 = HEAP8[$385>>0]|0;
       $420 = ($419<<24>>24)<(0);
       if ($420) {
        $421 = HEAP32[$26>>2]|0;
        __ZdlPv($421);
       }
       $422 = ((($25)) + 11|0);
       $423 = HEAP8[$422>>0]|0;
       $424 = ($423<<24>>24)<(0);
       if (!($424)) {
        $$14 = $418;$$1451 = $417;
        break;
       }
       $425 = HEAP32[$25>>2]|0;
       __ZdlPv($425);
       $$14 = $418;$$1451 = $417;
       break;
      }
      $389 = HEAP8[$385>>0]|0;
      $390 = ($389<<24>>24)<(0);
      if ($390) {
       $391 = HEAP32[$26>>2]|0;
       __ZdlPv($391);
      }
      $392 = ((($25)) + 11|0);
      $393 = HEAP8[$392>>0]|0;
      $394 = ($393<<24>>24)<(0);
      if ($394) {
       $395 = HEAP32[$25>>2]|0;
       __ZdlPv($395);
      }
      $396 = ((($24)) + 11|0);
      $397 = HEAP8[$396>>0]|0;
      $398 = ($397<<24>>24)<(0);
      if (!($398)) {
       STACKTOP = sp;return;
      }
      $399 = HEAP32[$24>>2]|0;
      __ZdlPv($399);
      STACKTOP = sp;return;
     }
    } while(0);
    $426 = ((($24)) + 11|0);
    $427 = HEAP8[$426>>0]|0;
    $428 = ($427<<24>>24)<(0);
    if (!($428)) {
     $$31 = $$14;$$3168 = $$1451;
     ___resumeException($$3168|0);
     // unreachable;
    }
    $429 = HEAP32[$24>>2]|0;
    __ZdlPv($429);
    $$31 = $$14;$$3168 = $$1451;
    ___resumeException($$3168|0);
    // unreachable;
   }
  } while(0);
  $411 = ((($21)) + 11|0);
  $412 = HEAP8[$411>>0]|0;
  $413 = ($412<<24>>24)<(0);
  if (!($413)) {
   $$31 = $$12;$$3168 = $$1249;
   ___resumeException($$3168|0);
   // unreachable;
  }
  $414 = HEAP32[$21>>2]|0;
  __ZdlPv($414);
  $$31 = $$12;$$3168 = $$1249;
  ___resumeException($$3168|0);
  // unreachable;
 } else {
  ;HEAP32[$27>>2]=0|0;HEAP32[$27+4>>2]=0|0;HEAP32[$27+8>>2]=0|0;
  $430 = ((($27)) + 11|0);
  HEAP8[$430>>0] = 9;
  dest=$27; src=148973; stop=dest+9|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
  $431 = ((($27)) + 9|0);
  HEAP8[$431>>0] = 0;
  $432 = ((($28)) + 11|0);
  HEAP8[$432>>0] = 10;
  dest=$28; src=148983; stop=dest+10|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
  $433 = ((($28)) + 10|0);
  HEAP8[$433>>0] = 0;
  ;HEAP32[$29>>2]=0|0;HEAP32[$29+4>>2]=0|0;HEAP32[$29+8>>2]=0|0;
  $434 = ((($29)) + 11|0);
  HEAP8[$434>>0] = 5;
  ;HEAP8[$29>>0]=HEAP8[148994>>0]|0;HEAP8[$29+1>>0]=HEAP8[148994+1>>0]|0;HEAP8[$29+2>>0]=HEAP8[148994+2>>0]|0;HEAP8[$29+3>>0]=HEAP8[148994+3>>0]|0;HEAP8[$29+4>>0]=HEAP8[148994+4>>0]|0;
  $435 = ((($29)) + 5|0);
  HEAP8[$435>>0] = 0;
  __THREW__ = 0;
  invoke_viiiiii(3924,($0|0),($75|0),0,($27|0),($28|0),($29|0));
  $436 = __THREW__; __THREW__ = 0;
  $437 = $436&1;
  if ($437) {
   $599 = ___cxa_find_matching_catch_2()|0;
   $600 = tempRet0;
   $601 = HEAP8[$434>>0]|0;
   $602 = ($601<<24>>24)<(0);
   if ($602) {
    $603 = HEAP32[$29>>2]|0;
    __ZdlPv($603);
   }
   $604 = HEAP8[$432>>0]|0;
   $605 = ($604<<24>>24)<(0);
   if ($605) {
    $606 = HEAP32[$28>>2]|0;
    __ZdlPv($606);
   }
   $607 = HEAP8[$430>>0]|0;
   $608 = ($607<<24>>24)<(0);
   if (!($608)) {
    $$31 = $600;$$3168 = $599;
    ___resumeException($$3168|0);
    // unreachable;
   }
   $609 = HEAP32[$27>>2]|0;
   __ZdlPv($609);
   $$31 = $600;$$3168 = $599;
   ___resumeException($$3168|0);
   // unreachable;
  }
  $438 = HEAP8[$434>>0]|0;
  $439 = ($438<<24>>24)<(0);
  if ($439) {
   $440 = HEAP32[$29>>2]|0;
   __ZdlPv($440);
  }
  $441 = HEAP8[$432>>0]|0;
  $442 = ($441<<24>>24)<(0);
  if ($442) {
   $443 = HEAP32[$28>>2]|0;
   __ZdlPv($443);
  }
  $444 = HEAP8[$430>>0]|0;
  $445 = ($444<<24>>24)<(0);
  if ($445) {
   $446 = HEAP32[$27>>2]|0;
   __ZdlPv($446);
  }
  $447 = ((($0)) + 392|0);
  ;HEAP32[$30>>2]=0|0;HEAP32[$30+4>>2]=0|0;HEAP32[$30+8>>2]=0|0;
  $448 = ((($30)) + 11|0);
  HEAP8[$448>>0] = 9;
  dest=$30; src=149000; stop=dest+9|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
  $449 = ((($30)) + 9|0);
  HEAP8[$449>>0] = 0;
  $450 = ((($31)) + 11|0);
  HEAP8[$450>>0] = 10;
  dest=$31; src=149010; stop=dest+10|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
  $451 = ((($31)) + 10|0);
  HEAP8[$451>>0] = 0;
  ;HEAP32[$32>>2]=0|0;HEAP32[$32+4>>2]=0|0;HEAP32[$32+8>>2]=0|0;
  $452 = ((($32)) + 11|0);
  HEAP8[$452>>0] = 5;
  ;HEAP8[$32>>0]=HEAP8[149021>>0]|0;HEAP8[$32+1>>0]=HEAP8[149021+1>>0]|0;HEAP8[$32+2>>0]=HEAP8[149021+2>>0]|0;HEAP8[$32+3>>0]=HEAP8[149021+3>>0]|0;HEAP8[$32+4>>0]=HEAP8[149021+4>>0]|0;
  $453 = ((($32)) + 5|0);
  HEAP8[$453>>0] = 0;
  __THREW__ = 0;
  invoke_viiiiii(3924,($0|0),($447|0),2,($30|0),($31|0),($32|0));
  $454 = __THREW__; __THREW__ = 0;
  $455 = $454&1;
  if ($455) {
   $610 = ___cxa_find_matching_catch_2()|0;
   $611 = tempRet0;
   $612 = HEAP8[$452>>0]|0;
   $613 = ($612<<24>>24)<(0);
   if ($613) {
    $614 = HEAP32[$32>>2]|0;
    __ZdlPv($614);
   }
   $615 = HEAP8[$450>>0]|0;
   $616 = ($615<<24>>24)<(0);
   if ($616) {
    $617 = HEAP32[$31>>2]|0;
    __ZdlPv($617);
   }
   $618 = HEAP8[$448>>0]|0;
   $619 = ($618<<24>>24)<(0);
   if (!($619)) {
    $$31 = $611;$$3168 = $610;
    ___resumeException($$3168|0);
    // unreachable;
   }
   $620 = HEAP32[$30>>2]|0;
   __ZdlPv($620);
   $$31 = $611;$$3168 = $610;
   ___resumeException($$3168|0);
   // unreachable;
  }
  $456 = HEAP8[$452>>0]|0;
  $457 = ($456<<24>>24)<(0);
  if ($457) {
   $458 = HEAP32[$32>>2]|0;
   __ZdlPv($458);
  }
  $459 = HEAP8[$450>>0]|0;
  $460 = ($459<<24>>24)<(0);
  if ($460) {
   $461 = HEAP32[$31>>2]|0;
   __ZdlPv($461);
  }
  $462 = HEAP8[$448>>0]|0;
  $463 = ($462<<24>>24)<(0);
  if ($463) {
   $464 = HEAP32[$30>>2]|0;
   __ZdlPv($464);
  }
  $465 = ((($0)) + 432|0);
  ;HEAP32[$33>>2]=0|0;HEAP32[$33+4>>2]=0|0;HEAP32[$33+8>>2]=0|0;
  $466 = ((($33)) + 11|0);
  HEAP8[$466>>0] = 8;
  $467 = $33;
  $468 = $467;
  HEAP32[$468>>2] = 1130327143;
  $469 = (($467) + 4)|0;
  $470 = $469;
  HEAP32[$470>>2] = 1919904879;
  $471 = ((($33)) + 8|0);
  HEAP8[$471>>0] = 0;
  ;HEAP32[$34>>2]=0|0;HEAP32[$34+4>>2]=0|0;HEAP32[$34+8>>2]=0|0;
  $472 = ((($34)) + 11|0);
  HEAP8[$472>>0] = 9;
  dest=$34; src=149027; stop=dest+9|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
  $473 = ((($34)) + 9|0);
  HEAP8[$473>>0] = 0;
  ;HEAP32[$35>>2]=0|0;HEAP32[$35+4>>2]=0|0;HEAP32[$35+8>>2]=0|0;
  $474 = ((($35)) + 11|0);
  HEAP8[$474>>0] = 5;
  ;HEAP8[$35>>0]=HEAP8[148994>>0]|0;HEAP8[$35+1>>0]=HEAP8[148994+1>>0]|0;HEAP8[$35+2>>0]=HEAP8[148994+2>>0]|0;HEAP8[$35+3>>0]=HEAP8[148994+3>>0]|0;HEAP8[$35+4>>0]=HEAP8[148994+4>>0]|0;
  $475 = ((($35)) + 5|0);
  HEAP8[$475>>0] = 0;
  __THREW__ = 0;
  invoke_viiiiii(3924,($0|0),($465|0),3,($33|0),($34|0),($35|0));
  $476 = __THREW__; __THREW__ = 0;
  $477 = $476&1;
  if ($477) {
   $621 = ___cxa_find_matching_catch_2()|0;
   $622 = tempRet0;
   $623 = HEAP8[$474>>0]|0;
   $624 = ($623<<24>>24)<(0);
   if ($624) {
    $625 = HEAP32[$35>>2]|0;
    __ZdlPv($625);
   }
   $626 = HEAP8[$472>>0]|0;
   $627 = ($626<<24>>24)<(0);
   if ($627) {
    $628 = HEAP32[$34>>2]|0;
    __ZdlPv($628);
   }
   $629 = HEAP8[$466>>0]|0;
   $630 = ($629<<24>>24)<(0);
   if (!($630)) {
    $$31 = $622;$$3168 = $621;
    ___resumeException($$3168|0);
    // unreachable;
   }
   $631 = HEAP32[$33>>2]|0;
   __ZdlPv($631);
   $$31 = $622;$$3168 = $621;
   ___resumeException($$3168|0);
   // unreachable;
  }
  $478 = HEAP8[$474>>0]|0;
  $479 = ($478<<24>>24)<(0);
  if ($479) {
   $480 = HEAP32[$35>>2]|0;
   __ZdlPv($480);
  }
  $481 = HEAP8[$472>>0]|0;
  $482 = ($481<<24>>24)<(0);
  if ($482) {
   $483 = HEAP32[$34>>2]|0;
   __ZdlPv($483);
  }
  $484 = HEAP8[$466>>0]|0;
  $485 = ($484<<24>>24)<(0);
  if ($485) {
   $486 = HEAP32[$33>>2]|0;
   __ZdlPv($486);
  }
  $487 = (__Znwj(32)|0);
  HEAP32[$36>>2] = $487;
  $488 = ((($36)) + 8|0);
  HEAP32[$488>>2] = -2147483616;
  $489 = ((($36)) + 4|0);
  HEAP32[$489>>2] = 17;
  dest=$487; src=149037; stop=dest+17|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
  $490 = ((($487)) + 17|0);
  HEAP8[$490>>0] = 0;
  ;HEAP32[$37>>2]=0|0;HEAP32[$37+4>>2]=0|0;HEAP32[$37+8>>2]=0|0;
  __THREW__ = 0;
  $491 = (invoke_ii(3276,32)|0);
  $492 = __THREW__; __THREW__ = 0;
  $493 = $492&1;
  do {
   if ($493) {
    $632 = ___cxa_find_matching_catch_2()|0;
    $633 = tempRet0;
    $$23 = $633;$$2360 = $632;
   } else {
    $494 = ((($0)) + 472|0);
    HEAP32[$37>>2] = $491;
    $495 = ((($37)) + 8|0);
    HEAP32[$495>>2] = -2147483616;
    $496 = ((($37)) + 4|0);
    HEAP32[$496>>2] = 18;
    dest=$491; src=149055; stop=dest+18|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
    $497 = ((($491)) + 18|0);
    HEAP8[$497>>0] = 0;
    ;HEAP32[$38>>2]=0|0;HEAP32[$38+4>>2]=0|0;HEAP32[$38+8>>2]=0|0;
    $498 = ((($38)) + 11|0);
    HEAP8[$498>>0] = 5;
    ;HEAP8[$38>>0]=HEAP8[148994>>0]|0;HEAP8[$38+1>>0]=HEAP8[148994+1>>0]|0;HEAP8[$38+2>>0]=HEAP8[148994+2>>0]|0;HEAP8[$38+3>>0]=HEAP8[148994+3>>0]|0;HEAP8[$38+4>>0]=HEAP8[148994+4>>0]|0;
    $499 = ((($38)) + 5|0);
    HEAP8[$499>>0] = 0;
    __THREW__ = 0;
    invoke_viiiiii(3924,($0|0),($494|0),4,($36|0),($37|0),($38|0));
    $500 = __THREW__; __THREW__ = 0;
    $501 = $500&1;
    if ($501) {
     $634 = ___cxa_find_matching_catch_2()|0;
     $635 = tempRet0;
     $636 = HEAP8[$498>>0]|0;
     $637 = ($636<<24>>24)<(0);
     if ($637) {
      $638 = HEAP32[$38>>2]|0;
      __ZdlPv($638);
     }
     $639 = ((($37)) + 11|0);
     $640 = HEAP8[$639>>0]|0;
     $641 = ($640<<24>>24)<(0);
     if (!($641)) {
      $$23 = $635;$$2360 = $634;
      break;
     }
     $642 = HEAP32[$37>>2]|0;
     __ZdlPv($642);
     $$23 = $635;$$2360 = $634;
     break;
    }
    $502 = HEAP8[$498>>0]|0;
    $503 = ($502<<24>>24)<(0);
    if ($503) {
     $504 = HEAP32[$38>>2]|0;
     __ZdlPv($504);
    }
    $505 = ((($37)) + 11|0);
    $506 = HEAP8[$505>>0]|0;
    $507 = ($506<<24>>24)<(0);
    if ($507) {
     $508 = HEAP32[$37>>2]|0;
     __ZdlPv($508);
    }
    $509 = ((($36)) + 11|0);
    $510 = HEAP8[$509>>0]|0;
    $511 = ($510<<24>>24)<(0);
    if ($511) {
     $512 = HEAP32[$36>>2]|0;
     __ZdlPv($512);
    }
    $513 = (__Znwj(16)|0);
    HEAP32[$39>>2] = $513;
    $514 = ((($39)) + 8|0);
    HEAP32[$514>>2] = -2147483632;
    $515 = ((($39)) + 4|0);
    HEAP32[$515>>2] = 11;
    dest=$513; src=149109; stop=dest+11|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
    $516 = ((($513)) + 11|0);
    HEAP8[$516>>0] = 0;
    ;HEAP32[$40>>2]=0|0;HEAP32[$40+4>>2]=0|0;HEAP32[$40+8>>2]=0|0;
    __THREW__ = 0;
    $517 = (invoke_ii(3276,16)|0);
    $518 = __THREW__; __THREW__ = 0;
    $519 = $518&1;
    do {
     if ($519) {
      $647 = ___cxa_find_matching_catch_2()|0;
      $648 = tempRet0;
      $$25 = $648;$$2562 = $647;
     } else {
      $520 = ((($0)) + 512|0);
      HEAP32[$40>>2] = $517;
      $521 = ((($40)) + 8|0);
      HEAP32[$521>>2] = -2147483632;
      $522 = ((($40)) + 4|0);
      HEAP32[$522>>2] = 12;
      dest=$517; src=149121; stop=dest+12|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
      $523 = ((($517)) + 12|0);
      HEAP8[$523>>0] = 0;
      ;HEAP32[$41>>2]=0|0;HEAP32[$41+4>>2]=0|0;HEAP32[$41+8>>2]=0|0;
      $524 = ((($41)) + 11|0);
      HEAP8[$524>>0] = 6;
      ;HEAP8[$41>>0]=HEAP8[149134>>0]|0;HEAP8[$41+1>>0]=HEAP8[149134+1>>0]|0;HEAP8[$41+2>>0]=HEAP8[149134+2>>0]|0;HEAP8[$41+3>>0]=HEAP8[149134+3>>0]|0;HEAP8[$41+4>>0]=HEAP8[149134+4>>0]|0;HEAP8[$41+5>>0]=HEAP8[149134+5>>0]|0;
      $525 = ((($41)) + 6|0);
      HEAP8[$525>>0] = 0;
      __THREW__ = 0;
      invoke_viiiiii(3924,($0|0),($520|0),5,($39|0),($40|0),($41|0));
      $526 = __THREW__; __THREW__ = 0;
      $527 = $526&1;
      if ($527) {
       $649 = ___cxa_find_matching_catch_2()|0;
       $650 = tempRet0;
       $651 = HEAP8[$524>>0]|0;
       $652 = ($651<<24>>24)<(0);
       if ($652) {
        $653 = HEAP32[$41>>2]|0;
        __ZdlPv($653);
       }
       $654 = ((($40)) + 11|0);
       $655 = HEAP8[$654>>0]|0;
       $656 = ($655<<24>>24)<(0);
       if (!($656)) {
        $$25 = $650;$$2562 = $649;
        break;
       }
       $657 = HEAP32[$40>>2]|0;
       __ZdlPv($657);
       $$25 = $650;$$2562 = $649;
       break;
      }
      $528 = HEAP8[$524>>0]|0;
      $529 = ($528<<24>>24)<(0);
      if ($529) {
       $530 = HEAP32[$41>>2]|0;
       __ZdlPv($530);
      }
      $531 = ((($40)) + 11|0);
      $532 = HEAP8[$531>>0]|0;
      $533 = ($532<<24>>24)<(0);
      if ($533) {
       $534 = HEAP32[$40>>2]|0;
       __ZdlPv($534);
      }
      $535 = ((($39)) + 11|0);
      $536 = HEAP8[$535>>0]|0;
      $537 = ($536<<24>>24)<(0);
      if ($537) {
       $538 = HEAP32[$39>>2]|0;
       __ZdlPv($538);
      }
      $539 = HEAP32[$49>>2]|0;
      $540 = HEAP32[$47>>2]|0;
      $541 = (($539) - ($540))|0;
      $542 = (($541|0) / 40)&-1;
      $543 = ($542>>>0)<($2>>>0);
      $544 = $540;
      $545 = $539;
      do {
       if ($543) {
        $546 = (($2) - ($542))|0;
        __ZNSt3__26vectorIN3osg17VertexAttribAliasENS_9allocatorIS2_EEE8__appendEj($47,$546);
        $$pre = HEAP32[$49>>2]|0;
        $570 = $$pre;
       } else {
        $547 = ($542>>>0)>($2>>>0);
        if (!($547)) {
         $570 = $539;
         break;
        }
        $548 = (($544) + (($2*40)|0)|0);
        $549 = ($545|0)==($548|0);
        if ($549) {
         $570 = $539;
         break;
        } else {
         $551 = $545;
        }
        while(1) {
         $550 = ((($551)) + -40|0);
         HEAP32[$49>>2] = $550;
         $552 = ((($551)) + -12|0);
         $553 = ((($552)) + 11|0);
         $554 = HEAP8[$553>>0]|0;
         $555 = ($554<<24>>24)<(0);
         if ($555) {
          $556 = HEAP32[$552>>2]|0;
          __ZdlPv($556);
         }
         $557 = ((($551)) + -24|0);
         $558 = ((($557)) + 11|0);
         $559 = HEAP8[$558>>0]|0;
         $560 = ($559<<24>>24)<(0);
         if ($560) {
          $561 = HEAP32[$557>>2]|0;
          __ZdlPv($561);
         }
         $562 = ((($551)) + -36|0);
         $563 = ((($562)) + 11|0);
         $564 = HEAP8[$563>>0]|0;
         $565 = ($564<<24>>24)<(0);
         if ($565) {
          $598 = HEAP32[$562>>2]|0;
          __ZdlPv($598);
         }
         $566 = HEAP32[$49>>2]|0;
         $567 = ($566|0)==($548|0);
         if ($567) {
          break;
         } else {
          $551 = $566;
         }
        }
        $568 = $566;
        $570 = $568;
       }
      } while(0);
      $569 = HEAP32[$47>>2]|0;
      $571 = ($570|0)==($569|0);
      if ($571) {
       STACKTOP = sp;return;
      }
      $572 = ((($42)) + 64|0);
      $573 = ((($42)) + 8|0);
      $574 = ((($42)) + 12|0);
      $575 = ((($42)) + 4|0);
      $576 = ((($42)) + 64|0);
      $577 = ((($42)) + 136|0);
      $578 = ((($42)) + 140|0);
      $579 = ((($42)) + 44|0);
      $580 = ((($42)) + 60|0);
      $581 = ((($4)) + 11|0);
      $582 = ((($43)) + 64|0);
      $583 = ((($43)) + 8|0);
      $584 = ((($43)) + 12|0);
      $585 = ((($43)) + 4|0);
      $586 = ((($43)) + 64|0);
      $587 = ((($43)) + 136|0);
      $588 = ((($43)) + 140|0);
      $589 = ((($43)) + 44|0);
      $590 = ((($43)) + 60|0);
      $591 = ((($3)) + 11|0);
      $592 = ((($42)) + 8|0);
      $593 = ((($43)) + 8|0);
      $594 = ((($46)) + 11|0);
      $595 = ((($46)) + 5|0);
      $596 = ((($45)) + 11|0);
      $597 = ((($44)) + 11|0);
      $$0559 = 0;
      while(1) {
       HEAP32[$573>>2] = (49248);
       HEAP32[$42>>2] = ((21156));
       HEAP32[$572>>2] = ((21176));
       HEAP32[$575>>2] = 0;
       __THREW__ = 0;
       invoke_vii(3368,($576|0),($574|0));
       $662 = __THREW__; __THREW__ = 0;
       $663 = $662&1;
       if ($663) {
        label = 248;
        break;
       }
       HEAP32[$577>>2] = 0;
       HEAP32[$578>>2] = -1;
       HEAP32[$42>>2] = (49228);
       HEAP32[$572>>2] = (49268);
       HEAP32[$573>>2] = (49248);
       __THREW__ = 0;
       invoke_vi(3369,($574|0));
       $664 = __THREW__; __THREW__ = 0;
       $665 = $664&1;
       if ($665) {
        label = 249;
        break;
       }
       HEAP32[$574>>2] = (37132);
       ;HEAP32[$579>>2]=0|0;HEAP32[$579+4>>2]=0|0;HEAP32[$579+8>>2]=0|0;HEAP32[$579+12>>2]=0|0;
       HEAP32[$580>>2] = 24;
       ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;
       __THREW__ = 0;
       invoke_vii(3370,($574|0),($4|0));
       $666 = __THREW__; __THREW__ = 0;
       $667 = $666&1;
       if ($667) {
        label = 242;
        break;
       }
       $668 = HEAP8[$581>>0]|0;
       $669 = ($668<<24>>24)<(0);
       if ($669) {
        $670 = HEAP32[$4>>2]|0;
        __ZdlPv($670);
       }
       HEAP32[$583>>2] = (49248);
       HEAP32[$43>>2] = ((21156));
       HEAP32[$582>>2] = ((21176));
       HEAP32[$585>>2] = 0;
       __THREW__ = 0;
       invoke_vii(3368,($586|0),($584|0));
       $694 = __THREW__; __THREW__ = 0;
       $695 = $694&1;
       if ($695) {
        label = 265;
        break;
       }
       HEAP32[$587>>2] = 0;
       HEAP32[$588>>2] = -1;
       HEAP32[$43>>2] = (49228);
       HEAP32[$582>>2] = (49268);
       HEAP32[$583>>2] = (49248);
       __THREW__ = 0;
       invoke_vi(3369,($584|0));
       $696 = __THREW__; __THREW__ = 0;
       $697 = $696&1;
       if ($697) {
        label = 266;
        break;
       }
       HEAP32[$584>>2] = (37132);
       ;HEAP32[$589>>2]=0|0;HEAP32[$589+4>>2]=0|0;HEAP32[$589+8>>2]=0|0;HEAP32[$589+12>>2]=0|0;
       HEAP32[$590>>2] = 24;
       ;HEAP32[$3>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;
       __THREW__ = 0;
       invoke_vii(3370,($584|0),($3|0));
       $698 = __THREW__; __THREW__ = 0;
       $699 = $698&1;
       if ($699) {
        label = 259;
        break;
       }
       $700 = HEAP8[$591>>0]|0;
       $701 = ($700<<24>>24)<(0);
       if ($701) {
        $702 = HEAP32[$3>>2]|0;
        __ZdlPv($702);
       }
       __THREW__ = 0;
       $726 = (invoke_iiii(3267,($592|0),(149074|0),16)|0);
       $727 = __THREW__; __THREW__ = 0;
       $728 = $727&1;
       if ($728) {
        label = 285;
        break;
       }
       __THREW__ = 0;
       (invoke_iii(3417,($726|0),($$0559|0))|0);
       $729 = __THREW__; __THREW__ = 0;
       $730 = $729&1;
       if ($730) {
        label = 285;
        break;
       }
       __THREW__ = 0;
       $731 = (invoke_iiii(3267,($593|0),(149091|0),17)|0);
       $732 = __THREW__; __THREW__ = 0;
       $733 = $732&1;
       if ($733) {
        label = 285;
        break;
       }
       __THREW__ = 0;
       (invoke_iii(3417,($731|0),($$0559|0))|0);
       $734 = __THREW__; __THREW__ = 0;
       $735 = $734&1;
       if ($735) {
        label = 285;
        break;
       }
       $736 = HEAP32[$47>>2]|0;
       $737 = (($736) + (($$0559*40)|0)|0);
       $738 = (($$0559) + 8)|0;
       __THREW__ = 0;
       invoke_vii(3615,($44|0),($574|0));
       $739 = __THREW__; __THREW__ = 0;
       $740 = $739&1;
       if ($740) {
        label = 285;
        break;
       }
       __THREW__ = 0;
       invoke_vii(3615,($45|0),($584|0));
       $741 = __THREW__; __THREW__ = 0;
       $742 = $741&1;
       if ($742) {
        label = 286;
        break;
       }
       ;HEAP32[$46>>2]=0|0;HEAP32[$46+4>>2]=0|0;HEAP32[$46+8>>2]=0|0;
       HEAP8[$594>>0] = 5;
       ;HEAP8[$46>>0]=HEAP8[148994>>0]|0;HEAP8[$46+1>>0]=HEAP8[148994+1>>0]|0;HEAP8[$46+2>>0]=HEAP8[148994+2>>0]|0;HEAP8[$46+3>>0]=HEAP8[148994+3>>0]|0;HEAP8[$46+4>>0]=HEAP8[148994+4>>0]|0;
       HEAP8[$595>>0] = 0;
       __THREW__ = 0;
       invoke_viiiiii(3924,($0|0),($737|0),($738|0),($44|0),($45|0),($46|0));
       $743 = __THREW__; __THREW__ = 0;
       $744 = $743&1;
       if ($744) {
        label = 287;
        break;
       }
       $745 = HEAP8[$594>>0]|0;
       $746 = ($745<<24>>24)<(0);
       if ($746) {
        $747 = HEAP32[$46>>2]|0;
        __ZdlPv($747);
       }
       $748 = HEAP8[$596>>0]|0;
       $749 = ($748<<24>>24)<(0);
       if ($749) {
        $750 = HEAP32[$45>>2]|0;
        __ZdlPv($750);
       }
       $751 = HEAP8[$597>>0]|0;
       $752 = ($751<<24>>24)<(0);
       if ($752) {
        $753 = HEAP32[$44>>2]|0;
        __ZdlPv($753);
       }
       __THREW__ = 0;
       invoke_vi(1045,($43|0));
       $754 = __THREW__; __THREW__ = 0;
       $755 = $754&1;
       if ($755) {
        label = 293;
        break;
       }
       __ZNSt3__218basic_stringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($42);
       $756 = (($$0559) + 1)|0;
       $757 = HEAP32[$49>>2]|0;
       $758 = HEAP32[$47>>2]|0;
       $759 = (($757) - ($758))|0;
       $760 = (($759|0) / 40)&-1;
       $761 = ($756>>>0)<($760>>>0);
       if ($761) {
        $$0559 = $756;
       } else {
        label = 298;
        break;
       }
      }
      switch (label|0) {
       case 242: {
        $671 = ___cxa_find_matching_catch_2()|0;
        $672 = tempRet0;
        $673 = HEAP8[$581>>0]|0;
        $674 = ($673<<24>>24)<(0);
        if ($674) {
         $675 = HEAP32[$4>>2]|0;
         __ZdlPv($675);
        }
        $676 = ((($579)) + 11|0);
        $677 = HEAP8[$676>>0]|0;
        $678 = ($677<<24>>24)<(0);
        if ($678) {
         $679 = HEAP32[$579>>2]|0;
         __ZdlPv($679);
        }
        __THREW__ = 0;
        invoke_vi(2911,($574|0));
        $680 = __THREW__; __THREW__ = 0;
        $681 = $680&1;
        if (!($681)) {
         $eh$lpad$body$i321$index12Z2D = $672;$eh$lpad$body$i321$indexZ2D = $671;
         label = 250;
         break;
        }
        $682 = ___cxa_find_matching_catch_3(0|0)|0;
        $683 = tempRet0;
        ___clang_call_terminate($682);
        // unreachable;
        break;
       }
       case 248: {
        $684 = ___cxa_find_matching_catch_2()|0;
        $685 = tempRet0;
        $$0$i324 = $685;$$03$i323 = $684;
        label = 251;
        break;
       }
       case 249: {
        $686 = ___cxa_find_matching_catch_2()|0;
        $687 = tempRet0;
        $eh$lpad$body$i321$index12Z2D = $687;$eh$lpad$body$i321$indexZ2D = $686;
        label = 250;
        break;
       }
       case 259: {
        $703 = ___cxa_find_matching_catch_2()|0;
        $704 = tempRet0;
        $705 = HEAP8[$591>>0]|0;
        $706 = ($705<<24>>24)<(0);
        if ($706) {
         $707 = HEAP32[$3>>2]|0;
         __ZdlPv($707);
        }
        $708 = ((($589)) + 11|0);
        $709 = HEAP8[$708>>0]|0;
        $710 = ($709<<24>>24)<(0);
        if ($710) {
         $711 = HEAP32[$589>>2]|0;
         __ZdlPv($711);
        }
        __THREW__ = 0;
        invoke_vi(2911,($584|0));
        $712 = __THREW__; __THREW__ = 0;
        $713 = $712&1;
        if (!($713)) {
         $eh$lpad$body$i329$index17Z2D = $704;$eh$lpad$body$i329$indexZ2D = $703;
         label = 267;
         break;
        }
        $714 = ___cxa_find_matching_catch_3(0|0)|0;
        $715 = tempRet0;
        ___clang_call_terminate($714);
        // unreachable;
        break;
       }
       case 265: {
        $716 = ___cxa_find_matching_catch_2()|0;
        $717 = tempRet0;
        $$0$i332 = $717;$$03$i331 = $716;
        label = 268;
        break;
       }
       case 266: {
        $718 = ___cxa_find_matching_catch_2()|0;
        $719 = tempRet0;
        $eh$lpad$body$i329$index17Z2D = $719;$eh$lpad$body$i329$indexZ2D = $718;
        label = 267;
        break;
       }
       case 285: {
        $762 = ___cxa_find_matching_catch_2()|0;
        $763 = tempRet0;
        $$28 = $763;$$2865 = $762;
        label = 294;
        break;
       }
       case 286: {
        $764 = ___cxa_find_matching_catch_2()|0;
        $765 = tempRet0;
        $$27 = $765;$$2764 = $764;
        label = 291;
        break;
       }
       case 287: {
        $766 = ___cxa_find_matching_catch_2()|0;
        $767 = tempRet0;
        $768 = HEAP8[$594>>0]|0;
        $769 = ($768<<24>>24)<(0);
        if ($769) {
         $770 = HEAP32[$46>>2]|0;
         __ZdlPv($770);
        }
        $771 = HEAP8[$596>>0]|0;
        $772 = ($771<<24>>24)<(0);
        if (!($772)) {
         $$27 = $767;$$2764 = $766;
         label = 291;
         break;
        }
        $773 = HEAP32[$45>>2]|0;
        __ZdlPv($773);
        $$27 = $767;$$2764 = $766;
        label = 291;
        break;
       }
       case 293: {
        $777 = ___cxa_find_matching_catch_2()|0;
        $778 = tempRet0;
        $$29 = $778;$$2966 = $777;
        label = 295;
        break;
       }
       case 298: {
        STACKTOP = sp;return;
        break;
       }
      }
      do {
       if ((label|0) == 250) {
        __THREW__ = 0;
        invoke_vii(3568,($42|0),((49280)|0));
        $688 = __THREW__; __THREW__ = 0;
        $689 = $688&1;
        if (!($689)) {
         $$0$i324 = $eh$lpad$body$i321$index12Z2D;$$03$i323 = $eh$lpad$body$i321$indexZ2D;
         label = 251;
         break;
        }
        $692 = ___cxa_find_matching_catch_3(0|0)|0;
        $693 = tempRet0;
        ___clang_call_terminate($692);
        // unreachable;
       }
       else if ((label|0) == 267) {
        __THREW__ = 0;
        invoke_vii(3568,($43|0),((49280)|0));
        $720 = __THREW__; __THREW__ = 0;
        $721 = $720&1;
        if (!($721)) {
         $$0$i332 = $eh$lpad$body$i329$index17Z2D;$$03$i331 = $eh$lpad$body$i329$indexZ2D;
         label = 268;
         break;
        }
        $724 = ___cxa_find_matching_catch_3(0|0)|0;
        $725 = tempRet0;
        ___clang_call_terminate($724);
        // unreachable;
       }
       else if ((label|0) == 291) {
        $774 = HEAP8[$597>>0]|0;
        $775 = ($774<<24>>24)<(0);
        if (!($775)) {
         $$28 = $$27;$$2865 = $$2764;
         label = 294;
         break;
        }
        $776 = HEAP32[$44>>2]|0;
        __ZdlPv($776);
        $$28 = $$27;$$2865 = $$2764;
        label = 294;
       }
      } while(0);
      do {
       if ((label|0) == 251) {
        __THREW__ = 0;
        invoke_vi(2907,($572|0));
        $690 = __THREW__; __THREW__ = 0;
        $691 = $690&1;
        if ($691) {
         $692 = ___cxa_find_matching_catch_3(0|0)|0;
         $693 = tempRet0;
         ___clang_call_terminate($692);
         // unreachable;
        } else {
         ___resumeException($$03$i323|0);
         // unreachable;
        }
       }
       else if ((label|0) == 268) {
        __THREW__ = 0;
        invoke_vi(2907,($582|0));
        $722 = __THREW__; __THREW__ = 0;
        $723 = $722&1;
        if (!($723)) {
         $$30 = $$0$i332;$$3067 = $$03$i331;
         break;
        }
        $724 = ___cxa_find_matching_catch_3(0|0)|0;
        $725 = tempRet0;
        ___clang_call_terminate($724);
        // unreachable;
       }
       else if ((label|0) == 294) {
        __THREW__ = 0;
        invoke_vi(1045,($43|0));
        $779 = __THREW__; __THREW__ = 0;
        $780 = $779&1;
        if (!($780)) {
         $$29 = $$28;$$2966 = $$2865;
         label = 295;
         break;
        }
        $783 = ___cxa_find_matching_catch_3(0|0)|0;
        $784 = tempRet0;
        ___clang_call_terminate($783);
        // unreachable;
       }
      } while(0);
      if ((label|0) == 295) {
       $$30 = $$29;$$3067 = $$2966;
      }
      __THREW__ = 0;
      invoke_vi(1045,($42|0));
      $781 = __THREW__; __THREW__ = 0;
      $782 = $781&1;
      if ($782) {
       $783 = ___cxa_find_matching_catch_3(0|0)|0;
       $784 = tempRet0;
       ___clang_call_terminate($783);
       // unreachable;
      }
      $$31 = $$30;$$3168 = $$3067;
      ___resumeException($$3168|0);
      // unreachable;
     }
    } while(0);
    $658 = ((($39)) + 11|0);
    $659 = HEAP8[$658>>0]|0;
    $660 = ($659<<24>>24)<(0);
    if (!($660)) {
     $$31 = $$25;$$3168 = $$2562;
     ___resumeException($$3168|0);
     // unreachable;
    }
    $661 = HEAP32[$39>>2]|0;
    __ZdlPv($661);
    $$31 = $$25;$$3168 = $$2562;
    ___resumeException($$3168|0);
    // unreachable;
   }
  } while(0);
  $643 = ((($36)) + 11|0);
  $644 = HEAP8[$643>>0]|0;
  $645 = ($644<<24>>24)<(0);
  if (!($645)) {
   $$31 = $$23;$$3168 = $$2360;
   ___resumeException($$3168|0);
   // unreachable;
  }
  $646 = HEAP32[$36>>2]|0;
  __ZdlPv($646);
  $$31 = $$23;$$3168 = $$2360;
  ___resumeException($$3168|0);
  // unreachable;
 }
}
function __ZN3osg5State22setUpVertexAttribAliasERNS_17VertexAttribAliasEjNSt3__212basic_stringIcNS3_11char_traitsIcEENS3_9allocatorIcEEEES9_RKS9_($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$0 = 0, $$0$i = 0, $$0$i$sink = 0, $$04$i = 0, $$04$i$sink = 0, $$06 = 0, $$1 = 0, $$17 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(64|0);
 $6 = sp + 24|0;
 $7 = sp + 12|0;
 $8 = sp;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_($7,$3);
 __THREW__ = 0;
 invoke_vii(3457,($8|0),($4|0));
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if ($10) {
  $64 = ___cxa_find_matching_catch_2()|0;
  $65 = tempRet0;
  $$1 = $65;$$17 = $64;
 } else {
  HEAP32[$6>>2] = $2;
  $11 = ((($6)) + 4|0);
  __THREW__ = 0;
  invoke_vii(3457,($11|0),($7|0));
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  L4: do {
   if ($13) {
    $66 = ___cxa_find_matching_catch_2()|0;
    $67 = tempRet0;
    $$0$i$sink = $67;$$04$i$sink = $66;
    label = 26;
   } else {
    $14 = ((($6)) + 16|0);
    __THREW__ = 0;
    invoke_vii(3457,($14|0),($8|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    do {
     if ($16) {
      $20 = ___cxa_find_matching_catch_2()|0;
      $21 = tempRet0;
      $$0$i = $21;$$04$i = $20;
     } else {
      $17 = ((($6)) + 28|0);
      __THREW__ = 0;
      invoke_vii(3457,($17|0),($5|0));
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if ($19) {
       $22 = ___cxa_find_matching_catch_2()|0;
       $23 = tempRet0;
       $24 = ((($14)) + 11|0);
       $25 = HEAP8[$24>>0]|0;
       $26 = ($25<<24>>24)<(0);
       if (!($26)) {
        $$0$i = $23;$$04$i = $22;
        break;
       }
       $27 = HEAP32[$14>>2]|0;
       __ZdlPv($27);
       $$0$i = $23;$$04$i = $22;
       break;
      }
      $32 = HEAP32[$6>>2]|0;
      HEAP32[$1>>2] = $32;
      $33 = ((($1)) + 4|0);
      __THREW__ = 0;
      (invoke_iii(3477,($33|0),($11|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if (!($35)) {
       $36 = ((($1)) + 16|0);
       __THREW__ = 0;
       (invoke_iii(3477,($36|0),($14|0))|0);
       $37 = __THREW__; __THREW__ = 0;
       $38 = $37&1;
       if (!($38)) {
        $39 = ((($1)) + 28|0);
        __THREW__ = 0;
        (invoke_iii(3477,($39|0),($17|0))|0);
        $40 = __THREW__; __THREW__ = 0;
        $41 = $40&1;
        if (!($41)) {
         $42 = ((($17)) + 11|0);
         $43 = HEAP8[$42>>0]|0;
         $44 = ($43<<24>>24)<(0);
         if ($44) {
          $45 = HEAP32[$17>>2]|0;
          __ZdlPv($45);
         }
         $46 = ((($14)) + 11|0);
         $47 = HEAP8[$46>>0]|0;
         $48 = ($47<<24>>24)<(0);
         if ($48) {
          $49 = HEAP32[$14>>2]|0;
          __ZdlPv($49);
         }
         $50 = ((($11)) + 11|0);
         $51 = HEAP8[$50>>0]|0;
         $52 = ($51<<24>>24)<(0);
         if ($52) {
          $53 = HEAP32[$11>>2]|0;
          __ZdlPv($53);
         }
         $54 = ((($8)) + 11|0);
         $55 = HEAP8[$54>>0]|0;
         $56 = ($55<<24>>24)<(0);
         if ($56) {
          $57 = HEAP32[$8>>2]|0;
          __ZdlPv($57);
         }
         $58 = ((($7)) + 11|0);
         $59 = HEAP8[$58>>0]|0;
         $60 = ($59<<24>>24)<(0);
         if (!($60)) {
          $62 = ((($0)) + 564|0);
          $63 = (__ZNSt3__23mapINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEjNS_4lessIS6_EENS4_INS_4pairIKS6_jEEEEEixERSA_($62,$4)|0);
          HEAP32[$63>>2] = $2;
          STACKTOP = sp;return;
         }
         $61 = HEAP32[$7>>2]|0;
         __ZdlPv($61);
         $62 = ((($0)) + 564|0);
         $63 = (__ZNSt3__23mapINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEjNS_4lessIS6_EENS4_INS_4pairIKS6_jEEEEEixERSA_($62,$4)|0);
         HEAP32[$63>>2] = $2;
         STACKTOP = sp;return;
        }
       }
      }
      $68 = ___cxa_find_matching_catch_2()|0;
      $69 = tempRet0;
      $70 = ((($17)) + 11|0);
      $71 = HEAP8[$70>>0]|0;
      $72 = ($71<<24>>24)<(0);
      if ($72) {
       $73 = HEAP32[$17>>2]|0;
       __ZdlPv($73);
      }
      $74 = ((($14)) + 11|0);
      $75 = HEAP8[$74>>0]|0;
      $76 = ($75<<24>>24)<(0);
      if ($76) {
       $77 = HEAP32[$14>>2]|0;
       __ZdlPv($77);
      }
      $78 = ((($11)) + 11|0);
      $79 = HEAP8[$78>>0]|0;
      $80 = ($79<<24>>24)<(0);
      if (!($80)) {
       $$0 = $69;$$06 = $68;
       break L4;
      }
      $81 = HEAP32[$11>>2]|0;
      __ZdlPv($81);
      $$0 = $69;$$06 = $68;
      break L4;
     }
    } while(0);
    $28 = ((($11)) + 11|0);
    $29 = HEAP8[$28>>0]|0;
    $30 = ($29<<24>>24)<(0);
    if ($30) {
     $31 = HEAP32[$11>>2]|0;
     __ZdlPv($31);
     $$0$i$sink = $$0$i;$$04$i$sink = $$04$i;
     label = 26;
    } else {
     $$0$i$sink = $$0$i;$$04$i$sink = $$04$i;
     label = 26;
    }
   }
  } while(0);
  if ((label|0) == 26) {
   $$0 = $$0$i$sink;$$06 = $$04$i$sink;
  }
  $82 = ((($8)) + 11|0);
  $83 = HEAP8[$82>>0]|0;
  $84 = ($83<<24>>24)<(0);
  if ($84) {
   $85 = HEAP32[$8>>2]|0;
   __ZdlPv($85);
   $$1 = $$0;$$17 = $$06;
  } else {
   $$1 = $$0;$$17 = $$06;
  }
 }
 $86 = ((($7)) + 11|0);
 $87 = HEAP8[$86>>0]|0;
 $88 = ($87<<24>>24)<(0);
 if (!($88)) {
  ___resumeException($$17|0);
  // unreachable;
 }
 $89 = HEAP32[$7>>2]|0;
 __ZdlPv($89);
 ___resumeException($$17|0);
 // unreachable;
}
function __ZNSt3__26vectorIN3osg17VertexAttribAliasENS_9allocatorIS2_EEE8__appendEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $scevgep19 = 0, dest = 0;
 var label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $2 = sp;
 $3 = ((($0)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) - ($6))|0;
 $8 = (($7|0) / 40)&-1;
 $9 = ($8>>>0)<($1>>>0);
 if (!($9)) {
  $10 = $6;
  $$0$i = $1;$11 = $10;
  while(1) {
   dest=$11; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
   $12 = HEAP32[$5>>2]|0;
   $13 = ((($12)) + 40|0);
   HEAP32[$5>>2] = $13;
   $14 = (($$0$i) + -1)|0;
   $15 = ($14|0)==(0);
   if ($15) {
    break;
   } else {
    $$0$i = $14;$11 = $13;
   }
  }
  STACKTOP = sp;return;
 }
 $16 = HEAP32[$0>>2]|0;
 $17 = (($6) - ($16))|0;
 $18 = (($17|0) / 40)&-1;
 $19 = (($18) + ($1))|0;
 $20 = ($19>>>0)>(107374182);
 if ($20) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $21 = ((($0)) + 8|0);
 $22 = (($4) - ($16))|0;
 $23 = (($22|0) / 40)&-1;
 $24 = ($23>>>0)<(53687091);
 $25 = $23 << 1;
 $26 = ($25>>>0)<($19>>>0);
 $$sroa$speculated$i = $26 ? $19 : $25;
 $$sroa$speculated$$i = $24 ? $$sroa$speculated$i : 107374182;
 $27 = ((($2)) + 12|0);
 HEAP32[$27>>2] = 0;
 $28 = ((($2)) + 16|0);
 HEAP32[$28>>2] = $21;
 $29 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($29) {
   $38 = 0;
  } else {
   $30 = ($$sroa$speculated$$i>>>0)>(107374182);
   if (!($30)) {
    $36 = ($$sroa$speculated$$i*40)|0;
    $37 = (__Znwj($36)|0);
    $38 = $37;
    break;
   }
   $31 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($31|0),(204840|0));
   $32 = __THREW__; __THREW__ = 0;
   $33 = $32&1;
   if ($33) {
    $34 = ___cxa_find_matching_catch_2()|0;
    $35 = tempRet0;
    ___cxa_free_exception(($31|0));
    ___resumeException($34|0);
    // unreachable;
   } else {
    HEAP32[$31>>2] = (99824);
    ___cxa_throw(($31|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 HEAP32[$2>>2] = $38;
 $39 = (($38) + (($18*40)|0)|0);
 $40 = ((($2)) + 8|0);
 $41 = ((($2)) + 4|0);
 HEAP32[$41>>2] = $39;
 $42 = (($38) + (($$sroa$speculated$$i*40)|0)|0);
 $43 = ((($2)) + 12|0);
 HEAP32[$43>>2] = $42;
 $44 = ($1*40)|0;
 $scevgep19 = (($39) + (($1*40)|0)|0);
 _memset(($39|0),0,($44|0))|0;
 HEAP32[$40>>2] = $scevgep19;
 __THREW__ = 0;
 invoke_vii(3925,($0|0),($2|0));
 $45 = __THREW__; __THREW__ = 0;
 $46 = $45&1;
 if ($46) {
  $71 = ___cxa_find_matching_catch_2()|0;
  $72 = tempRet0;
  $73 = HEAP32[$41>>2]|0;
  $74 = HEAP32[$40>>2]|0;
  $75 = ($74|0)==($73|0);
  if (!($75)) {
   $77 = $74;
   while(1) {
    $76 = ((($77)) + -40|0);
    HEAP32[$40>>2] = $76;
    $78 = ((($77)) + -12|0);
    $79 = ((($78)) + 11|0);
    $80 = HEAP8[$79>>0]|0;
    $81 = ($80<<24>>24)<(0);
    if ($81) {
     $82 = HEAP32[$78>>2]|0;
     __ZdlPv($82);
    }
    $83 = ((($77)) + -24|0);
    $84 = ((($83)) + 11|0);
    $85 = HEAP8[$84>>0]|0;
    $86 = ($85<<24>>24)<(0);
    if ($86) {
     $87 = HEAP32[$83>>2]|0;
     __ZdlPv($87);
    }
    $88 = ((($77)) + -36|0);
    $89 = ((($88)) + 11|0);
    $90 = HEAP8[$89>>0]|0;
    $91 = ($90<<24>>24)<(0);
    if ($91) {
     $94 = HEAP32[$88>>2]|0;
     __ZdlPv($94);
    }
    $92 = HEAP32[$40>>2]|0;
    $93 = ($92|0)==($73|0);
    if ($93) {
     break;
    } else {
     $77 = $92;
    }
   }
  }
  $95 = HEAP32[$2>>2]|0;
  $96 = ($95|0)==(0|0);
  if ($96) {
   ___resumeException($71|0);
   // unreachable;
  }
  __ZdlPv($95);
  ___resumeException($71|0);
  // unreachable;
 } else {
  $47 = HEAP32[$41>>2]|0;
  $48 = HEAP32[$40>>2]|0;
  $49 = ($48|0)==($47|0);
  if (!($49)) {
   $51 = $48;
   while(1) {
    $50 = ((($51)) + -40|0);
    HEAP32[$40>>2] = $50;
    $52 = ((($51)) + -12|0);
    $53 = ((($52)) + 11|0);
    $54 = HEAP8[$53>>0]|0;
    $55 = ($54<<24>>24)<(0);
    if ($55) {
     $56 = HEAP32[$52>>2]|0;
     __ZdlPv($56);
    }
    $57 = ((($51)) + -24|0);
    $58 = ((($57)) + 11|0);
    $59 = HEAP8[$58>>0]|0;
    $60 = ($59<<24>>24)<(0);
    if ($60) {
     $61 = HEAP32[$57>>2]|0;
     __ZdlPv($61);
    }
    $62 = ((($51)) + -36|0);
    $63 = ((($62)) + 11|0);
    $64 = HEAP8[$63>>0]|0;
    $65 = ($64<<24>>24)<(0);
    if ($65) {
     $68 = HEAP32[$62>>2]|0;
     __ZdlPv($68);
    }
    $66 = HEAP32[$40>>2]|0;
    $67 = ($66|0)==($47|0);
    if ($67) {
     break;
    } else {
     $51 = $66;
    }
   }
  }
  $69 = HEAP32[$2>>2]|0;
  $70 = ($69|0)==(0|0);
  if (!($70)) {
   __ZdlPv($69);
  }
  STACKTOP = sp;return;
 }
}
function __ZNSt3__26vectorIN3osg17VertexAttribAliasENS_9allocatorIS2_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS2_RS4_EE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i$i = 0, $$06$i$i$i = 0, $$09$i = 0, $$pre = 0, $$pre$i = 0, $$pre$phi21Z2D = 0, $$pre$phiZ2D = 0, $$pre18 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $3 = ((($0)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($1)) + 4|0);
 $6 = ($4|0)==($2|0);
 do {
  if ($6) {
   $7 = $2;
   $$pre18 = HEAP32[$5>>2]|0;
   $$pre$phi21Z2D = $5;$$pre$phiZ2D = $0;$38 = $$pre18;$39 = $7;
  } else {
   $$pre$i = HEAP32[$5>>2]|0;
   $$09$i = $4;$10 = $$pre$i;
   while(1) {
    $8 = ((($$09$i)) + -40|0);
    $9 = ((($10)) + -40|0);
    $11 = HEAP32[$8>>2]|0;
    HEAP32[$9>>2] = $11;
    $12 = ((($10)) + -36|0);
    $13 = ((($$09$i)) + -36|0);
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_($12,$13);
    $14 = ((($10)) + -24|0);
    $15 = ((($$09$i)) + -24|0);
    __THREW__ = 0;
    invoke_vii(3457,($14|0),($15|0));
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     label = 6;
     break;
    }
    $18 = ((($10)) + -12|0);
    $19 = ((($$09$i)) + -12|0);
    __THREW__ = 0;
    invoke_vii(3457,($18|0),($19|0));
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     label = 7;
     break;
    }
    $34 = HEAP32[$5>>2]|0;
    $35 = ((($34)) + -40|0);
    HEAP32[$5>>2] = $35;
    $36 = ($8|0)==($2|0);
    if ($36) {
     label = 13;
     break;
    } else {
     $$09$i = $8;$10 = $35;
    }
   }
   if ((label|0) == 6) {
    $22 = ___cxa_find_matching_catch_2()|0;
    $23 = tempRet0;
    $$0$i$i$i = $23;$$06$i$i$i = $22;
   }
   else if ((label|0) == 7) {
    $24 = ___cxa_find_matching_catch_2()|0;
    $25 = tempRet0;
    $26 = ((($14)) + 11|0);
    $27 = HEAP8[$26>>0]|0;
    $28 = ($27<<24>>24)<(0);
    if ($28) {
     $29 = HEAP32[$14>>2]|0;
     __ZdlPv($29);
     $$0$i$i$i = $25;$$06$i$i$i = $24;
    } else {
     $$0$i$i$i = $25;$$06$i$i$i = $24;
    }
   }
   else if ((label|0) == 13) {
    $37 = $35;
    $$pre = HEAP32[$0>>2]|0;
    $$pre$phi21Z2D = $5;$$pre$phiZ2D = $0;$38 = $37;$39 = $$pre;
    break;
   }
   $30 = ((($12)) + 11|0);
   $31 = HEAP8[$30>>0]|0;
   $32 = ($31<<24>>24)<(0);
   if (!($32)) {
    ___resumeException($$06$i$i$i|0);
    // unreachable;
   }
   $33 = HEAP32[$12>>2]|0;
   __ZdlPv($33);
   ___resumeException($$06$i$i$i|0);
   // unreachable;
  }
 } while(0);
 HEAP32[$$pre$phiZ2D>>2] = $38;
 HEAP32[$$pre$phi21Z2D>>2] = $39;
 $40 = ((($1)) + 8|0);
 $41 = HEAP32[$3>>2]|0;
 $42 = HEAP32[$40>>2]|0;
 HEAP32[$3>>2] = $42;
 HEAP32[$40>>2] = $41;
 $43 = ((($0)) + 8|0);
 $44 = ((($1)) + 12|0);
 $45 = HEAP32[$43>>2]|0;
 $46 = HEAP32[$44>>2]|0;
 HEAP32[$43>>2] = $46;
 HEAP32[$44>>2] = $45;
 $47 = HEAP32[$$pre$phi21Z2D>>2]|0;
 HEAP32[$1>>2] = $47;
 return;
}
function __ZN3osg5State24initializeExtensionProcsEv($0) {
 $0 = $0|0;
 var $$0 = 0, $$016$i$i = 0, $$016$i$i61 = 0, $$017$i$i = 0, $$017$i$i62 = 0, $$018 = 0, $$02729$i$i$i = 0, $$02729$i$i$i66 = 0, $$02729$i$i$i77 = 0, $$2 = 0, $$220 = 0, $$4 = 0, $$422 = 0, $$pre = 0, $$pre$phi112Z2D = 0, $$pre$phi118Z2D = 0, $$pre111$pre$phiZZ2D = 0, $$pre114 = 0, $$pre117$pre$phiZZ2D = 0, $$pre120 = 0;
 var $$sink = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0;
 var $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0;
 var $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0;
 var $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0;
 var $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0;
 var $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0;
 var $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0.0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0;
 var $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0;
 var $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0;
 var $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0;
 var $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0;
 var $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0;
 var $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, $or$cond = 0, $or$cond104 = 0;
 var $or$cond105 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(112|0);
 $1 = sp + 100|0;
 $2 = sp + 96|0;
 $3 = sp + 92|0;
 $4 = sp + 80|0;
 $5 = sp + 64|0;
 $6 = sp + 52|0;
 $7 = sp + 40|0;
 $8 = sp + 36|0;
 $9 = sp;
 $10 = ((($0)) + 714|0);
 $11 = HEAP8[$10>>0]|0;
 $12 = ($11<<24>>24)==(0);
 if (!($12)) {
  STACKTOP = sp;return;
 }
 $13 = (_glGetString(7936)|0);
 $14 = ($13|0)==(0|0);
 L4: do {
  if (!($14)) {
   ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;
   $15 = (_strlen($13)|0);
   $16 = ($15>>>0)>(4294967279);
   if ($16) {
    __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv($4);
    // unreachable;
   }
   $17 = ($15>>>0)<(11);
   if ($17) {
    $24 = $15&255;
    $25 = ((($4)) + 11|0);
    HEAP8[$25>>0] = $24;
    $26 = ($15|0)==(0);
    if ($26) {
     $$017$i$i = $4;$$pre$phi118Z2D = $25;
    } else {
     $$016$i$i = $4;$$pre117$pre$phiZZ2D = $25;
     label = 8;
    }
   } else {
    $18 = (($15) + 16)|0;
    $19 = $18 & -16;
    $20 = (__Znwj($19)|0);
    HEAP32[$4>>2] = $20;
    $21 = $19 | -2147483648;
    $22 = ((($4)) + 8|0);
    HEAP32[$22>>2] = $21;
    $23 = ((($4)) + 4|0);
    HEAP32[$23>>2] = $15;
    $$pre120 = ((($4)) + 11|0);
    $$016$i$i = $20;$$pre117$pre$phiZZ2D = $$pre120;
    label = 8;
   }
   if ((label|0) == 8) {
    _memcpy(($$016$i$i|0),($13|0),($15|0))|0;
    $$017$i$i = $$016$i$i;$$pre$phi118Z2D = $$pre117$pre$phiZZ2D;
   }
   $27 = (($$017$i$i) + ($15)|0);
   HEAP8[$27>>0] = 0;
   $28 = HEAP8[$$pre$phi118Z2D>>0]|0;
   $29 = ($28<<24>>24)<(0);
   $30 = HEAP32[$4>>2]|0;
   $31 = ((($4)) + 4|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = $28&255;
   $34 = $29 ? $30 : $4;
   $35 = $29 ? $32 : $33;
   $36 = (($34) + ($35)|0);
   $37 = ($35|0)==(0);
   if (!($37)) {
    $39 = $34;
    while(1) {
     $38 = HEAP8[$39>>0]|0;
     $40 = ($38<<24>>24)==(32);
     if ($40) {
      HEAP8[$39>>0] = 95;
     }
     $41 = ((($39)) + 1|0);
     $42 = ($41|0)==($36|0);
     if ($42) {
      break;
     } else {
      $39 = $41;
     }
    }
   }
   __THREW__ = 0;
   $43 = (invoke_ii(3265,4)|0);
   $44 = __THREW__; __THREW__ = 0;
   $45 = $44&1;
   L22: do {
    if ($45) {
     label = 28;
    } else {
     do {
      if ($43) {
       __THREW__ = 0;
       $46 = (invoke_ii(3266,4)|0);
       $47 = __THREW__; __THREW__ = 0;
       $48 = $47&1;
       if ($48) {
        label = 28;
        break L22;
       }
       __THREW__ = 0;
       $49 = (invoke_iiii(3267,($46|0),(149141|0),13)|0);
       $50 = __THREW__; __THREW__ = 0;
       $51 = $50&1;
       if ($51) {
        label = 28;
        break L22;
       }
       $52 = HEAP8[$$pre$phi118Z2D>>0]|0;
       $53 = ($52<<24>>24)<(0);
       $54 = HEAP32[$4>>2]|0;
       $55 = $53 ? $54 : $4;
       $56 = ((($4)) + 4|0);
       $57 = HEAP32[$56>>2]|0;
       $58 = $52&255;
       $59 = $53 ? $57 : $58;
       __THREW__ = 0;
       $60 = (invoke_iiii(3267,($49|0),($55|0),($59|0))|0);
       $61 = __THREW__; __THREW__ = 0;
       $62 = $61&1;
       if ($62) {
        label = 28;
        break L22;
       }
       __THREW__ = 0;
       $63 = (invoke_iiii(3267,($60|0),(149155|0),1)|0);
       $64 = __THREW__; __THREW__ = 0;
       $65 = $64&1;
       if ($65) {
        label = 28;
        break L22;
       }
       $66 = HEAP32[$63>>2]|0;
       $67 = ((($66)) + -12|0);
       $68 = HEAP32[$67>>2]|0;
       $69 = (($63) + ($68)|0);
       __THREW__ = 0;
       invoke_vii(3257,($3|0),($69|0));
       $70 = __THREW__; __THREW__ = 0;
       $71 = $70&1;
       if ($71) {
        label = 28;
        break L22;
       }
       __THREW__ = 0;
       $72 = (invoke_iii(3255,($3|0),(215188|0))|0);
       $73 = __THREW__; __THREW__ = 0;
       $74 = $73&1;
       if (!($74)) {
        $75 = HEAP32[$72>>2]|0;
        $76 = ((($75)) + 28|0);
        $77 = HEAP32[$76>>2]|0;
        __THREW__ = 0;
        $78 = (invoke_iii($77|0,($72|0),10)|0);
        $79 = __THREW__; __THREW__ = 0;
        $80 = $79&1;
        if (!($80)) {
         __THREW__ = 0;
         invoke_vi(3263,($3|0));
         $81 = __THREW__; __THREW__ = 0;
         $82 = $81&1;
         if ($82) {
          label = 28;
          break L22;
         }
         __THREW__ = 0;
         (invoke_iii(3268,($63|0),($78|0))|0);
         $89 = __THREW__; __THREW__ = 0;
         $90 = $89&1;
         if ($90) {
          label = 28;
          break L22;
         }
         __THREW__ = 0;
         (invoke_ii(3269,($63|0))|0);
         $91 = __THREW__; __THREW__ = 0;
         $92 = $91&1;
         if ($92) {
          label = 28;
          break L22;
         } else {
          break;
         }
        }
       }
       $83 = ___cxa_find_matching_catch_2()|0;
       $84 = tempRet0;
       __THREW__ = 0;
       invoke_vi(3263,($3|0));
       $85 = __THREW__; __THREW__ = 0;
       $86 = $85&1;
       if ($86) {
        $87 = ___cxa_find_matching_catch_3(0|0)|0;
        $88 = tempRet0;
        ___clang_call_terminate($87);
        // unreachable;
       } else {
        $eh$lpad$body$index2Z2D = $84;$eh$lpad$body$indexZ2D = $83;
        label = 29;
        break L22;
       }
      }
     } while(0);
     $95 = ((($0)) + 612|0);
     __THREW__ = 0;
     $96 = (invoke_iii(3926,($95|0),($4|0))|0);
     $97 = __THREW__; __THREW__ = 0;
     $98 = $97&1;
     if ($98) {
      label = 28;
     } else {
      $99 = ((($96)) + 4|0);
      ;HEAP32[$6>>2]=0|0;HEAP32[$6+4>>2]=0|0;HEAP32[$6+8>>2]=0|0;
      $100 = ((($6)) + 11|0);
      HEAP8[$100>>0] = 1;
      HEAP8[$6>>0] = 49;
      $101 = ((($6)) + 1|0);
      HEAP8[$101>>0] = 0;
      __THREW__ = 0;
      invoke_vii(3457,($5|0),($6|0));
      $102 = __THREW__; __THREW__ = 0;
      $103 = $102&1;
      do {
       if ($103) {
        $132 = ___cxa_find_matching_catch_2()|0;
        $133 = tempRet0;
        $$0 = $132;$$018 = $133;
       } else {
        $104 = ((($5)) + 12|0);
        HEAP32[$104>>2] = 1;
        $105 = ((($96)) + 8|0);
        $106 = HEAP32[$105>>2]|0;
        $107 = ((($96)) + 12|0);
        $108 = HEAP32[$107>>2]|0;
        $109 = ($106|0)==($108|0);
        if ($109) {
         __THREW__ = 0;
         invoke_vii(3927,($99|0),($5|0));
         $116 = __THREW__; __THREW__ = 0;
         $117 = $116&1;
         if ($117) {
          label = 45;
         }
        } else {
         __THREW__ = 0;
         invoke_vii(3457,($106|0),($5|0));
         $110 = __THREW__; __THREW__ = 0;
         $111 = $110&1;
         if ($111) {
          label = 45;
         } else {
          $112 = ((($106)) + 12|0);
          $113 = HEAP32[$104>>2]|0;
          HEAP32[$112>>2] = $113;
          $114 = HEAP32[$105>>2]|0;
          $115 = ((($114)) + 16|0);
          HEAP32[$105>>2] = $115;
         }
        }
        if ((label|0) == 45) {
         $134 = ___cxa_find_matching_catch_2()|0;
         $135 = tempRet0;
         $136 = ((($5)) + 11|0);
         $137 = HEAP8[$136>>0]|0;
         $138 = ($137<<24>>24)<(0);
         if (!($138)) {
          $$0 = $134;$$018 = $135;
          break;
         }
         $139 = HEAP32[$5>>2]|0;
         __ZdlPv($139);
         $$0 = $134;$$018 = $135;
         break;
        }
        $118 = ((($5)) + 11|0);
        $119 = HEAP8[$118>>0]|0;
        $120 = ($119<<24>>24)<(0);
        if ($120) {
         $121 = HEAP32[$5>>2]|0;
         __ZdlPv($121);
        }
        $122 = HEAP8[$100>>0]|0;
        $123 = ($122<<24>>24)<(0);
        if ($123) {
         $124 = HEAP32[$6>>2]|0;
         __ZdlPv($124);
        }
        __THREW__ = 0;
        $125 = (invoke_iii(3926,($95|0),($4|0))|0);
        $126 = __THREW__; __THREW__ = 0;
        $127 = $126&1;
        if ($127) {
         label = 28;
         break L22;
        }
        HEAP8[$125>>0] = 1;
        $128 = ((($0)) + 624|0);
        HEAP8[$128>>0] = 1;
        $129 = HEAP8[$$pre$phi118Z2D>>0]|0;
        $130 = ($129<<24>>24)<(0);
        if ($130) {
         $131 = HEAP32[$4>>2]|0;
         __ZdlPv($131);
        }
        break L4;
       }
      } while(0);
      $140 = HEAP8[$100>>0]|0;
      $141 = ($140<<24>>24)<(0);
      if ($141) {
       $142 = HEAP32[$6>>2]|0;
       __ZdlPv($142);
      }
      $$2 = $$0;$$220 = $$018;
     }
    }
   } while(0);
   if ((label|0) == 28) {
    $93 = ___cxa_find_matching_catch_2()|0;
    $94 = tempRet0;
    $eh$lpad$body$index2Z2D = $94;$eh$lpad$body$indexZ2D = $93;
    label = 29;
   }
   if ((label|0) == 29) {
    $$2 = $eh$lpad$body$indexZ2D;$$220 = $eh$lpad$body$index2Z2D;
   }
   $143 = HEAP8[$$pre$phi118Z2D>>0]|0;
   $144 = ($143<<24>>24)<(0);
   if ($144) {
    $145 = HEAP32[$4>>2]|0;
    __ZdlPv($145);
   }
   $$4 = $$2;$$422 = $$220;
   ___resumeException($$4|0);
   // unreachable;
  }
 } while(0);
 $146 = ((($0)) + 124|0);
 $147 = HEAP32[$146>>2]|0;
 $148 = (__ZN3osg12GLExtensions3GetEjb($147,1)|0);
 $149 = ((($0)) + 784|0);
 $150 = HEAP32[$149>>2]|0;
 $151 = ($150|0)==($148|0);
 if (!($151)) {
  HEAP32[$149>>2] = $148;
  $152 = ($148|0)==(0|0);
  if (!($152)) {
   $153 = ((($148)) + 8|0);
   $154 = HEAP32[$153>>2]|0;HEAP32[$153>>2] = (($154+1)|0);
  }
  $155 = ($150|0)==(0|0);
  if (!($155)) {
   $156 = ((($150)) + 8|0);
   $157 = HEAP32[$156>>2]|0;HEAP32[$156>>2] = (($157-1)|0);
   $158 = ($157|0)==(1);
   if ($158) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($150,1,1);
   }
  }
 }
 $159 = HEAP32[$146>>2]|0;
 $160 = (__ZN3osg22isGLExtensionSupportedEjPKc($159,149157)|0);
 $161 = ((($0)) + 708|0);
 $162 = $160&1;
 HEAP8[$161>>0] = $162;
 $163 = HEAP32[$146>>2]|0;
 $164 = (__ZN3osg22isGLExtensionSupportedEjPKc($163,149180)|0);
 $165 = ((($0)) + 709|0);
 $166 = $164&1;
 HEAP8[$165>>0] = $166;
 $167 = ((($0)) + 710|0);
 HEAP8[$167>>0] = 1;
 $168 = HEAP32[$149>>2]|0;
 $169 = ((($168)) + 716|0);
 $170 = HEAP8[$169>>0]|0;
 $171 = ((($0)) + 711|0);
 HEAP8[$171>>0] = $170;
 $172 = ((($0)) + 336|0);
 $173 = HEAP32[$172>>2]|0;
 $174 = ($173|0)==(0|0);
 if ($174) {
  $175 = (__ZN3osg15DisplaySettings8instanceEv()|0);
  $176 = HEAP32[$175>>2]|0;
  $178 = $176;
 } else {
  $178 = $173;
 }
 $177 = ((($178)) + 160|0);
 $179 = HEAP32[$177>>2]|0;
 switch ($179|0) {
 case 1:  {
  $$sink = 0;
  label = 63;
  break;
 }
 case 2:  {
  $$sink = 1;
  label = 63;
  break;
 }
 default: {
 }
 }
 if ((label|0) == 63) {
  $180 = ((($0)) + 712|0);
  HEAP8[$180>>0] = 1;
  $181 = ((($0)) + 713|0);
  HEAP8[$181>>0] = $$sink;
 }
 $182 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
 do {
  if ($182) {
   $183 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
   $184 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($183,149197,26)|0);
   $185 = ((($0)) + 713|0);
   $186 = HEAP8[$185>>0]|0;
   $187 = ($186<<24>>24)!=(0);
   $188 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEb($184,$187)|0);
   $189 = HEAP32[$188>>2]|0;
   $190 = ((($189)) + -12|0);
   $191 = HEAP32[$190>>2]|0;
   $192 = (($188) + ($191)|0);
   __ZNKSt3__28ios_base6getlocEv($1,$192);
   __THREW__ = 0;
   $193 = (invoke_iii(3255,($1|0),(215188|0))|0);
   $194 = __THREW__; __THREW__ = 0;
   $195 = $194&1;
   if (!($195)) {
    $196 = HEAP32[$193>>2]|0;
    $197 = ((($196)) + 28|0);
    $198 = HEAP32[$197>>2]|0;
    __THREW__ = 0;
    $199 = (invoke_iii($198|0,($193|0),10)|0);
    $200 = __THREW__; __THREW__ = 0;
    $201 = $200&1;
    if (!($201)) {
     __ZNSt3__26localeD2Ev($1);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($188,$199)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($188)|0);
     break;
    }
   }
   $202 = ___cxa_find_matching_catch_2()|0;
   $203 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($1|0));
   $204 = __THREW__; __THREW__ = 0;
   $205 = $204&1;
   if ($205) {
    $206 = ___cxa_find_matching_catch_3(0|0)|0;
    $207 = tempRet0;
    ___clang_call_terminate($206);
    // unreachable;
   } else {
    ___resumeException($202|0);
    // unreachable;
   }
  }
 } while(0);
 $208 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
 do {
  if ($208) {
   $209 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
   $210 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($209,149224,27)|0);
   $211 = ((($0)) + 712|0);
   $212 = HEAP8[$211>>0]|0;
   $213 = ($212<<24>>24)!=(0);
   $214 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEb($210,$213)|0);
   $215 = HEAP32[$214>>2]|0;
   $216 = ((($215)) + -12|0);
   $217 = HEAP32[$216>>2]|0;
   $218 = (($214) + ($217)|0);
   __ZNKSt3__28ios_base6getlocEv($2,$218);
   __THREW__ = 0;
   $219 = (invoke_iii(3255,($2|0),(215188|0))|0);
   $220 = __THREW__; __THREW__ = 0;
   $221 = $220&1;
   if (!($221)) {
    $222 = HEAP32[$219>>2]|0;
    $223 = ((($222)) + 28|0);
    $224 = HEAP32[$223>>2]|0;
    __THREW__ = 0;
    $225 = (invoke_iii($224|0,($219|0),10)|0);
    $226 = __THREW__; __THREW__ = 0;
    $227 = $226&1;
    if (!($227)) {
     __ZNSt3__26localeD2Ev($2);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($214,$225)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($214)|0);
     break;
    }
   }
   $228 = ___cxa_find_matching_catch_2()|0;
   $229 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($2|0));
   $230 = __THREW__; __THREW__ = 0;
   $231 = $230&1;
   if ($231) {
    $232 = ___cxa_find_matching_catch_3(0|0)|0;
    $233 = tempRet0;
    ___clang_call_terminate($232);
    // unreachable;
   } else {
    ___resumeException($228|0);
    // unreachable;
   }
  }
 } while(0);
 $234 = (__Znwj(108)|0);
 __THREW__ = 0;
 invoke_vii(3752,($234|0),($0|0));
 $235 = __THREW__; __THREW__ = 0;
 $236 = $235&1;
 if ($236) {
  $329 = ___cxa_find_matching_catch_2()|0;
  $330 = tempRet0;
  __ZdlPv($234);
  $$4 = $329;$$422 = $330;
  ___resumeException($$4|0);
  // unreachable;
 }
 $237 = ((($0)) + 128|0);
 $238 = HEAP32[$237>>2]|0;
 $239 = ($238|0)==($234|0);
 if (!($239)) {
  HEAP32[$237>>2] = $234;
  $240 = ((($234)) + 8|0);
  $241 = HEAP32[$240>>2]|0;HEAP32[$240>>2] = (($241+1)|0);
  $242 = ($238|0)==(0|0);
  if (!($242)) {
   $243 = ((($238)) + 8|0);
   $244 = HEAP32[$243>>2]|0;HEAP32[$243>>2] = (($244-1)|0);
   $245 = ($244|0)==(1);
   if ($245) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($238,1,1);
   }
  }
 }
 $246 = HEAP32[$237>>2]|0;
 __ZN3osg16VertexArrayState20assignAllDispatchersEv($246);
 $247 = HEAP32[$237>>2]|0;
 $248 = ((($0)) + 132|0);
 HEAP32[$248>>2] = $247;
 $249 = ((($0)) + 724|0);
 $250 = (__ZN3osg21getGLExtensionFuncPtrEPKc(197883)|0);
 $251 = ($250|0)==(0|0);
 if ($251) {
  $252 = (__ZN3osg21getGLExtensionFuncPtrEPKc(149252)|0);
  $253 = $252;
 } else {
  $253 = $250;
 }
 HEAP32[$249>>2] = $253;
 $254 = ((($0)) + 728|0);
 $255 = (__ZN3osg21getGLExtensionFuncPtrEPKc(198446)|0);
 $256 = ($255|0)==(0|0);
 if ($256) {
  $257 = (__ZN3osg21getGLExtensionFuncPtrEPKc(149277)|0);
  $258 = $257;
 } else {
  $258 = $255;
 }
 HEAP32[$254>>2] = $258;
 $259 = ((($0)) + 744|0);
 $260 = (__ZN3osg21getGLExtensionFuncPtrEPKc(149296)|0);
 $261 = ($260|0)==(0|0);
 if ($261) {
  $262 = (__ZN3osg21getGLExtensionFuncPtrEPKc(149314)|0);
  $263 = $262;
 } else {
  $263 = $260;
 }
 HEAP32[$259>>2] = $263;
 $264 = ((($0)) + 748|0);
 $265 = (__ZN3osg21getGLExtensionFuncPtrEPKc(149335)|0);
 $266 = ($265|0)==(0|0);
 if ($266) {
  $267 = (__ZN3osg21getGLExtensionFuncPtrEPKc(149359)|0);
  $268 = $267;
 } else {
  $268 = $265;
 }
 HEAP32[$264>>2] = $268;
 $269 = ((($0)) + 752|0);
 $270 = (__ZN3osg21getGLExtensionFuncPtrEPKc(198024)|0);
 $271 = ($270|0)==(0|0);
 if ($271) {
  $272 = (__ZN3osg21getGLExtensionFuncPtrEPKc(149386)|0);
  $273 = $272;
 } else {
  $273 = $270;
 }
 HEAP32[$269>>2] = $273;
 $274 = ((($0)) + 756|0);
 $275 = (__ZN3osg21getGLExtensionFuncPtrEPKc(149411)|0);
 HEAP32[$274>>2] = $275;
 $276 = ((($0)) + 760|0);
 $277 = (__ZN3osg21getGLExtensionFuncPtrEPKc(149434)|0);
 $278 = ($277|0)==(0|0);
 if ($278) {
  $279 = (__ZN3osg21getGLExtensionFuncPtrEPKc(149386)|0);
  $280 = $279;
 } else {
  $280 = $277;
 }
 HEAP32[$276>>2] = $280;
 $281 = ((($0)) + 764|0);
 $282 = (__ZN3osg21getGLExtensionFuncPtrEPKc(198046)|0);
 $283 = ($282|0)==(0|0);
 if ($283) {
  $284 = (__ZN3osg21getGLExtensionFuncPtrEPKc(149457)|0);
  $285 = $284;
 } else {
  $285 = $282;
 }
 HEAP32[$281>>2] = $285;
 $286 = ((($0)) + 732|0);
 $287 = (__ZN3osg21getGLExtensionFuncPtrEPKc(149486)|0);
 $288 = ($287|0)==(0|0);
 if ($288) {
  $289 = (__ZN3osg21getGLExtensionFuncPtrEPKc(149504)|0);
  $290 = $289;
 } else {
  $290 = $287;
 }
 HEAP32[$286>>2] = $290;
 $291 = ((($0)) + 736|0);
 $292 = (__ZN3osg21getGLExtensionFuncPtrEPKc(198867)|0);
 HEAP32[$291>>2] = $292;
 $293 = ((($0)) + 740|0);
 $294 = (__ZN3osg21getGLExtensionFuncPtrEPKc(197211)|0);
 HEAP32[$293>>2] = $294;
 $295 = ((($0)) + 768|0);
 $296 = (__ZN3osg21getGLExtensionFuncPtrEPKc(198072)|0);
 $297 = ($296|0)==(0|0);
 if ($297) {
  $298 = (__ZN3osg21getGLExtensionFuncPtrEPKc(149525)|0);
  $299 = $298;
 } else {
  $299 = $296;
 }
 HEAP32[$295>>2] = $299;
 $300 = ((($0)) + 772|0);
 $301 = (__ZN3osg21getGLExtensionFuncPtrEPKc(197144)|0);
 $302 = ($301|0)==(0|0);
 if ($302) {
  $303 = (__ZN3osg21getGLExtensionFuncPtrEPKc(149555)|0);
  $304 = $303;
 } else {
  $304 = $301;
 }
 HEAP32[$300>>2] = $304;
 $305 = ((($0)) + 776|0);
 $306 = (__ZN3osg21getGLExtensionFuncPtrEPKc(198199)|0);
 $307 = ($306|0)==(0|0);
 do {
  if ($307) {
   $308 = (__ZN3osg21getGLExtensionFuncPtrEPKc(149571)|0);
   $309 = ($308|0)==(0|0);
   if (!($309)) {
    $311 = $308;
    break;
   }
   $310 = (__ZN3osg21getGLExtensionFuncPtrEPKc(149596)|0);
   $311 = $310;
  } else {
   $311 = $306;
  }
 } while(0);
 HEAP32[$305>>2] = $311;
 $312 = ((($0)) + 780|0);
 $313 = (__ZN3osg21getGLExtensionFuncPtrEPKc(198221)|0);
 $314 = ($313|0)==(0|0);
 do {
  if ($314) {
   $315 = (__ZN3osg21getGLExtensionFuncPtrEPKc(149621)|0);
   $316 = ($315|0)==(0|0);
   if (!($316)) {
    $318 = $315;
    break;
   }
   $317 = (__ZN3osg21getGLExtensionFuncPtrEPKc(149648)|0);
   $318 = $317;
  } else {
   $318 = $313;
  }
 } while(0);
 HEAP32[$312>>2] = $318;
 $319 = (+__ZN3osg18getGLVersionNumberEv());
 $320 = !($319 >= 2.0);
 if ($320) {
  $321 = HEAP32[$146>>2]|0;
  (__ZN3osg22isGLExtensionSupportedEjPKc($321,149675)|0);
 }
 $322 = ((($0)) + 720|0);
 _glGetIntegerv(35661,($322|0));
 $323 = HEAP32[$322>>2]|0;
 $324 = ((($0)) + 716|0);
 HEAP32[$324>>2] = $323;
 $325 = HEAP32[$149>>2]|0;
 $326 = ((($325)) + 806|0);
 $327 = HEAP8[$326>>0]|0;
 $328 = ($327<<24>>24)==(0);
 if (!($328)) {
  $331 = (_glGetString(7937)|0);
  $332 = ($331|0)!=(0|0);
  $333 = $332 ? $331 : 221531;
  ;HEAP32[$7>>2]=0|0;HEAP32[$7+4>>2]=0|0;HEAP32[$7+8>>2]=0|0;
  $334 = (_strlen($333)|0);
  $335 = ($334>>>0)>(4294967279);
  if ($335) {
   __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv($7);
   // unreachable;
  }
  $336 = ($334>>>0)<(11);
  if ($336) {
   $343 = $334&255;
   $344 = ((($7)) + 11|0);
   HEAP8[$344>>0] = $343;
   $345 = ($334|0)==(0);
   if ($345) {
    $$017$i$i62 = $7;$$pre$phi112Z2D = $344;
   } else {
    $$016$i$i61 = $7;$$pre111$pre$phiZZ2D = $344;
    label = 118;
   }
  } else {
   $337 = (($334) + 16)|0;
   $338 = $337 & -16;
   $339 = (__Znwj($338)|0);
   HEAP32[$7>>2] = $339;
   $340 = $338 | -2147483648;
   $341 = ((($7)) + 8|0);
   HEAP32[$341>>2] = $340;
   $342 = ((($7)) + 4|0);
   HEAP32[$342>>2] = $334;
   $$pre114 = ((($7)) + 11|0);
   $$016$i$i61 = $339;$$pre111$pre$phiZZ2D = $$pre114;
   label = 118;
  }
  if ((label|0) == 118) {
   _memcpy(($$016$i$i61|0),($333|0),($334|0))|0;
   $$017$i$i62 = $$016$i$i61;$$pre$phi112Z2D = $$pre111$pre$phiZZ2D;
  }
  $346 = (($$017$i$i62) + ($334)|0);
  HEAP8[$346>>0] = 0;
  $347 = HEAP8[$$pre$phi112Z2D>>0]|0;
  $348 = ($347<<24>>24)<(0);
  $349 = HEAP32[$7>>2]|0;
  $350 = $348 ? $349 : $7;
  $351 = ((($7)) + 4|0);
  $352 = HEAP32[$351>>2]|0;
  $353 = $347&255;
  $354 = $348 ? $352 : $353;
  $355 = (($350) + ($354)|0);
  $356 = $355;
  $357 = $350;
  $358 = ($354|0)<(6);
  L174: do {
   if ($358) {
    label = 138;
   } else {
    $$02729$i$i$i = $350;$360 = $354;
    while(1) {
     $359 = (($360) + -5)|0;
     $361 = ($359|0)==(0);
     if ($361) {
      label = 125;
      break;
     }
     $362 = (_memchr($$02729$i$i$i,82,$359)|0);
     $363 = ($362|0)==(0|0);
     if ($363) {
      label = 125;
      break;
     }
     $364 = (_memcmp($362,149696,6)|0);
     $365 = ($364|0)==(0);
     if ($365) {
      label = 124;
      break;
     }
     $366 = ((($362)) + 1|0);
     $367 = $366;
     $368 = (($356) - ($367))|0;
     $369 = ($368|0)<(6);
     if ($369) {
      label = 125;
      break;
     } else {
      $$02729$i$i$i = $366;$360 = $368;
     }
    }
    if ((label|0) == 124) {
     $370 = ($362|0)==($355|0);
     $371 = $362;
     $372 = (($371) - ($357))|0;
     $373 = ($372|0)==(-1);
     $or$cond = $370 | $373;
     if ($or$cond) {
      label = 125;
     }
    }
    do {
     if ((label|0) == 125) {
      if ($358) {
       label = 138;
       break L174;
      } else {
       $$02729$i$i$i66 = $350;$375 = $354;
      }
      while(1) {
       $374 = (($375) + -5)|0;
       $376 = ($374|0)==(0);
       if ($376) {
        break;
       }
       $377 = (_memchr($$02729$i$i$i66,82,$374)|0);
       $378 = ($377|0)==(0|0);
       if ($378) {
        break;
       }
       $379 = (_memcmp($377,149703,6)|0);
       $380 = ($379|0)==(0);
       if ($380) {
        label = 130;
        break;
       }
       $381 = ((($377)) + 1|0);
       $382 = $381;
       $383 = (($356) - ($382))|0;
       $384 = ($383|0)<(6);
       if ($384) {
        break;
       } else {
        $$02729$i$i$i66 = $381;$375 = $383;
       }
      }
      if ((label|0) == 130) {
       $385 = ($377|0)==($355|0);
       $386 = $377;
       $387 = (($386) - ($357))|0;
       $388 = ($387|0)==(-1);
       $or$cond104 = $385 | $388;
       if (!($or$cond104)) {
        break;
       }
      }
      $389 = ($354|0)<(7);
      if ($389) {
       label = 138;
       break L174;
      } else {
       $$02729$i$i$i77 = $350;$391 = $354;
      }
      while(1) {
       $390 = (($391) + -6)|0;
       $392 = ($390|0)==(0);
       if ($392) {
        label = 138;
        break L174;
       }
       $393 = (_memchr($$02729$i$i$i77,70,$390)|0);
       $394 = ($393|0)==(0|0);
       if ($394) {
        label = 138;
        break L174;
       }
       $395 = (_memcmp($393,149710,7)|0);
       $396 = ($395|0)==(0);
       if ($396) {
        break;
       }
       $397 = ((($393)) + 1|0);
       $398 = $397;
       $399 = (($356) - ($398))|0;
       $400 = ($399|0)<(7);
       if ($400) {
        label = 138;
        break L174;
       } else {
        $$02729$i$i$i77 = $397;$391 = $399;
       }
      }
      $401 = ($393|0)==($355|0);
      $402 = $393;
      $403 = (($402) - ($357))|0;
      $404 = ($403|0)==(-1);
      $or$cond105 = $401 | $404;
      if ($or$cond105) {
       label = 138;
       break L174;
      }
     }
    } while(0);
    $405 = ((($0)) + 888|0);
    HEAP32[$405>>2] = 64;
    $418 = $347;
   }
  } while(0);
  do {
   if ((label|0) == 138) {
    HEAP32[$8>>2] = 0;
    $406 = HEAP32[$149>>2]|0;
    $407 = ((($406)) + 900|0);
    $408 = HEAP32[$407>>2]|0;
    __THREW__ = 0;
    invoke_viii($408|0,36392,34916,($8|0));
    $409 = __THREW__; __THREW__ = 0;
    $410 = $409&1;
    if (!($410)) {
     $411 = HEAP32[$8>>2]|0;
     $412 = ((($0)) + 888|0);
     HEAP32[$412>>2] = $411;
     $$pre = HEAP8[$$pre$phi112Z2D>>0]|0;
     $418 = $$pre;
     break;
    }
    $413 = ___cxa_find_matching_catch_2()|0;
    $414 = tempRet0;
    $415 = HEAP8[$$pre$phi112Z2D>>0]|0;
    $416 = ($415<<24>>24)<(0);
    if ($416) {
     $417 = HEAP32[$7>>2]|0;
     __ZdlPv($417);
    }
    $$4 = $413;$$422 = $414;
    ___resumeException($$4|0);
    // unreachable;
   }
  } while(0);
  $419 = ($418<<24>>24)<(0);
  if ($419) {
   $420 = HEAP32[$7>>2]|0;
   __ZdlPv($420);
  }
 }
 HEAP8[$10>>0] = 1;
 $421 = ((($0)) + 860|0);
 $422 = HEAP32[$421>>2]|0;
 $423 = ($422|0)==(0|0);
 if ($423) {
  STACKTOP = sp;return;
 }
 HEAP32[$9>>2] = $0;
 $424 = ((($0)) + 8|0);
 $425 = HEAP32[$424>>2]|0;HEAP32[$424>>2] = (($425+1)|0);
 $426 = ((($9)) + 4|0);
 ;HEAP32[$426>>2]=0|0;HEAP32[$426+4>>2]=0|0;HEAP32[$426+8>>2]=0|0;HEAP32[$426+12>>2]=0|0;HEAP32[$426+16>>2]=0|0;HEAP32[$426+20>>2]=0|0;HEAP32[$426+24>>2]=0|0;HEAP32[$426+28>>2]=0|0;
 $427 = HEAP32[$421>>2]|0;
 __THREW__ = 0;
 invoke_vii(3928,($427|0),($9|0));
 $428 = __THREW__; __THREW__ = 0;
 $429 = $428&1;
 if (!($429)) {
  __ZN3osg10RenderInfoD2Ev($9);
  STACKTOP = sp;return;
 }
 $430 = ___cxa_find_matching_catch_2()|0;
 $431 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3504,($9|0));
 $432 = __THREW__; __THREW__ = 0;
 $433 = $432&1;
 if ($433) {
  $434 = ___cxa_find_matching_catch_3(0|0)|0;
  $435 = tempRet0;
  ___clang_call_terminate($434);
  // unreachable;
 }
 $$4 = $430;$$422 = $431;
 ___resumeException($$4|0);
 // unreachable;
}
function __ZNSt3__23mapINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg5State11DefineStackENS_4lessIS6_EENS4_INS_4pairIKS6_S9_EEEEEixERSD_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$014 = 0, $$pre$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = (__ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg5State11DefineStackEEENS_19__map_value_compareIS7_SB_NS_4lessIS7_EELb1EEENS5_ISB_EEE12__find_equalIS7_EERPNS_16__tree_node_baseIPvEERPNS_15__tree_end_nodeISM_EERKT_($0,$2,$1)|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if (!($5)) {
  $$014 = $4;
  $29 = ((($$014)) + 28|0);
  STACKTOP = sp;return ($29|0);
 }
 $6 = (__Znwj(44)|0);
 $7 = ((($6)) + 16|0);
 __THREW__ = 0;
 invoke_vii(3457,($7|0),($1|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $10 = ___cxa_find_matching_catch_2()|0;
  $11 = tempRet0;
  __ZdlPv($6);
  ___resumeException($10|0);
  // unreachable;
 }
 $12 = ((($6)) + 28|0);
 HEAP8[$12>>0] = 0;
 $13 = ((($6)) + 32|0);
 HEAP32[$13>>2] = 0;
 $14 = ((($6)) + 36|0);
 HEAP32[$14>>2] = 0;
 $15 = ((($6)) + 40|0);
 HEAP32[$15>>2] = 0;
 $16 = HEAP32[$2>>2]|0;
 HEAP32[$6>>2] = 0;
 $17 = ((($6)) + 4|0);
 HEAP32[$17>>2] = 0;
 $18 = ((($6)) + 8|0);
 HEAP32[$18>>2] = $16;
 HEAP32[$3>>2] = $6;
 $19 = HEAP32[$0>>2]|0;
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)==(0|0);
 if ($21) {
  $25 = $6;
 } else {
  $22 = $20;
  HEAP32[$0>>2] = $22;
  $$pre$i = HEAP32[$3>>2]|0;
  $25 = $$pre$i;
 }
 $23 = ((($0)) + 4|0);
 $24 = HEAP32[$23>>2]|0;
 __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($24,$25);
 $26 = ((($0)) + 8|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (($27) + 1)|0;
 HEAP32[$26>>2] = $28;
 $$014 = $6;
 $29 = ((($$014)) + 28|0);
 STACKTOP = sp;return ($29|0);
}
function __ZNSt3__26vectorINS_4pairINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEjEENS5_IS8_EEE21__push_back_slow_pathIKS8_EEvRT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$06$i$i = 0, $$pre = 0, $$pre$i = 0, $$sroa$16$0 = 0, $$sroa$7$0 = 0, $$sroa$7$1 = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 4;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(268435455);
 if ($8) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $9 = ((($0)) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) - ($4))|0;
 $12 = $11 >> 4;
 $13 = ($12>>>0)<(134217727);
 $14 = $11 >> 3;
 $15 = ($14>>>0)<($7>>>0);
 $$sroa$speculated$i = $15 ? $7 : $14;
 $$sroa$speculated$$i = $13 ? $$sroa$speculated$i : 268435455;
 $16 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($16) {
   $26 = 0;$80 = 0;
  } else {
   $17 = ($$sroa$speculated$$i>>>0)>(268435455);
   if (!($17)) {
    $23 = $$sroa$speculated$$i << 4;
    $24 = (__Znwj($23)|0);
    $26 = $24;$80 = $24;
    break;
   }
   $18 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($18|0),(204840|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if ($20) {
    $21 = ___cxa_find_matching_catch_2()|0;
    $22 = tempRet0;
    ___cxa_free_exception(($18|0));
    ___resumeException($21|0);
    // unreachable;
   } else {
    HEAP32[$18>>2] = (99824);
    ___cxa_throw(($18|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $25 = (($26) + ($6<<4)|0);
 $27 = $25;
 $28 = (($26) + ($$sroa$speculated$$i<<4)|0);
 $29 = $28;
 __THREW__ = 0;
 invoke_vii(3457,($25|0),($1|0));
 $30 = __THREW__; __THREW__ = 0;
 $31 = $30&1;
 L13: do {
  if ($31) {
   $$sroa$16$0 = $27;$$sroa$7$1 = $27;
  } else {
   $32 = (((($26) + ($6<<4)|0)) + 12|0);
   $33 = ((($1)) + 12|0);
   $34 = HEAP32[$33>>2]|0;
   HEAP32[$32>>2] = $34;
   $35 = ((($25)) + 16|0);
   $36 = $35;
   $37 = HEAP32[$0>>2]|0;
   $38 = HEAP32[$2>>2]|0;
   $39 = ($38|0)==($37|0);
   if ($39) {
    $40 = $37;
    $53 = $27;$54 = $40;$56 = $37;
   } else {
    $$06$i$i = $38;$$sroa$7$0 = $27;$43 = $25;
    while(1) {
     $41 = ((($$06$i$i)) + -16|0);
     $42 = ((($43)) + -16|0);
     __THREW__ = 0;
     invoke_vii(3457,($42|0),($41|0));
     $44 = __THREW__; __THREW__ = 0;
     $45 = $44&1;
     if ($45) {
      $$sroa$16$0 = $36;$$sroa$7$1 = $$sroa$7$0;
      break L13;
     }
     $46 = ((($43)) + -4|0);
     $47 = ((($$06$i$i)) + -4|0);
     $48 = HEAP32[$47>>2]|0;
     HEAP32[$46>>2] = $48;
     $49 = $$sroa$7$0;
     $50 = ((($49)) + -16|0);
     $51 = $50;
     $52 = ($41|0)==($37|0);
     if ($52) {
      break;
     } else {
      $$06$i$i = $41;$$sroa$7$0 = $51;$43 = $50;
     }
    }
    $$pre$i = HEAP32[$0>>2]|0;
    $$pre = HEAP32[$2>>2]|0;
    $53 = $51;$54 = $$pre$i;$56 = $$pre;
   }
   HEAP32[$0>>2] = $53;
   HEAP32[$2>>2] = $36;
   HEAP32[$9>>2] = $29;
   $55 = $54;
   $57 = ($56|0)==($55|0);
   if (!($57)) {
    $59 = $56;
    while(1) {
     $58 = ((($59)) + -16|0);
     $60 = ((($58)) + 11|0);
     $61 = HEAP8[$60>>0]|0;
     $62 = ($61<<24>>24)<(0);
     if ($62) {
      $64 = HEAP32[$58>>2]|0;
      __ZdlPv($64);
     }
     $63 = ($58|0)==($55|0);
     if ($63) {
      break;
     } else {
      $59 = $58;
     }
    }
   }
   $65 = ($54|0)==(0);
   if ($65) {
    return;
   }
   $66 = $54;
   __ZdlPv($66);
   return;
  }
 } while(0);
 $67 = ___cxa_find_matching_catch_2()|0;
 $68 = tempRet0;
 $69 = $$sroa$7$1;
 $70 = $$sroa$16$0;
 $71 = ($70|0)==($69|0);
 if (!($71)) {
  $73 = $70;
  while(1) {
   $72 = ((($73)) + -16|0);
   $74 = ((($72)) + 11|0);
   $75 = HEAP8[$74>>0]|0;
   $76 = ($75<<24>>24)<(0);
   if ($76) {
    $78 = HEAP32[$72>>2]|0;
    __ZdlPv($78);
   }
   $77 = ($72|0)==($69|0);
   if ($77) {
    break;
   } else {
    $73 = $72;
   }
  }
 }
 $79 = ($26|0)==(0|0);
 if ($79) {
  ___resumeException($67|0);
  // unreachable;
 }
 __ZdlPv($80);
 ___resumeException($67|0);
 // unreachable;
}
function __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg5State11DefineStackEEENS_19__map_value_compareIS7_SB_NS_4lessIS7_EELb1EEENS5_ISB_EEE12__find_equalIS7_EERPNS_16__tree_node_baseIPvEERPNS_15__tree_end_nodeISM_EERKT_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$0$ph = 0, $$024 = 0, $$025 = 0, $$in = 0, $$sroa$speculated$i$i$i$i$i = 0, $$sroa$speculated$i$i$i$i$i26 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  HEAP32[$1>>2] = $3;
  $$025 = $3;
  return ($$025|0);
 }
 $6 = ((($0)) + 4|0);
 $7 = ((($2)) + 11|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = ($8<<24>>24)<(0);
 $10 = ((($2)) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $8&255;
 $13 = $9 ? $11 : $12;
 $14 = HEAP32[$2>>2]|0;
 $15 = $9 ? $14 : $2;
 $$0 = $6;$$024 = $4;
 while(1) {
  $16 = ((($$024)) + 16|0);
  $17 = ((($16)) + 11|0);
  $18 = HEAP8[$17>>0]|0;
  $19 = ($18<<24>>24)<(0);
  $20 = ((($$024)) + 20|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = $18&255;
  $23 = $19 ? $21 : $22;
  $24 = ($23>>>0)<($13>>>0);
  $$sroa$speculated$i$i$i$i$i26 = $24 ? $23 : $13;
  $25 = ($$sroa$speculated$i$i$i$i$i26|0)==(0);
  if ($25) {
   label = 6;
  } else {
   $26 = HEAP32[$16>>2]|0;
   $27 = $19 ? $26 : $16;
   $28 = (_memcmp($15,$27,$$sroa$speculated$i$i$i$i$i26)|0);
   $29 = ($28|0)==(0);
   if ($29) {
    label = 6;
   } else {
    $31 = ($28|0)<(0);
    if ($31) {
     label = 8;
    } else {
     label = 10;
    }
   }
  }
  if ((label|0) == 6) {
   label = 0;
   $30 = ($13>>>0)<($23>>>0);
   if ($30) {
    label = 8;
   } else {
    label = 10;
   }
  }
  if ((label|0) == 8) {
   label = 0;
   $32 = HEAP32[$$024>>2]|0;
   $33 = ($32|0)==(0|0);
   if ($33) {
    label = 9;
    break;
   } else {
    $$0$ph = $$024;$$in = $32;
   }
  }
  else if ((label|0) == 10) {
   label = 0;
   $34 = ($13>>>0)<($23>>>0);
   $$sroa$speculated$i$i$i$i$i = $34 ? $13 : $23;
   $35 = ($$sroa$speculated$i$i$i$i$i|0)==(0);
   if ($35) {
    label = 12;
   } else {
    $36 = HEAP32[$16>>2]|0;
    $37 = $19 ? $36 : $16;
    $38 = (_memcmp($37,$15,$$sroa$speculated$i$i$i$i$i)|0);
    $39 = ($38|0)==(0);
    if ($39) {
     label = 12;
    } else {
     $40 = ($38|0)<(0);
     if (!($40)) {
      label = 16;
      break;
     }
    }
   }
   if ((label|0) == 12) {
    label = 0;
    if (!($24)) {
     label = 16;
     break;
    }
   }
   $41 = ((($$024)) + 4|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = ($42|0)==(0|0);
   if ($43) {
    label = 15;
    break;
   } else {
    $$0$ph = $41;$$in = $42;
   }
  }
  $$0 = $$0$ph;$$024 = $$in;
 }
 if ((label|0) == 9) {
  HEAP32[$1>>2] = $$024;
  $$025 = $$024;
  return ($$025|0);
 }
 else if ((label|0) == 15) {
  HEAP32[$1>>2] = $$024;
  $$025 = $41;
  return ($$025|0);
 }
 else if ((label|0) == 16) {
  HEAP32[$1>>2] = $$024;
  $$025 = $$0;
  return ($$025|0);
 }
 return (0)|0;
}
function __ZN3osg5State16releaseGLObjectsEv($0) {
 $0 = $0|0;
 var $$0$i$i$i$i = 0, $$0$i$i$i$i14 = 0, $$pre = 0, $$sroa$022$0$be = 0, $$sroa$022$048 = 0, $$sroa$028$049 = 0, $$sroa$034$0$be = 0, $$sroa$034$052 = 0, $$sroa$040$055 = 0, $1 = 0, $10 = 0, $100 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 140|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + 136|0);
 $5 = HEAP32[$4>>2]|0;
 FUNCTION_TABLE_vii[$5 & 8191]($2,$0);
 $6 = ((($0)) + 668|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($0)) + 672|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($7|0)==($9|0);
 if (!($10)) {
  $$sroa$040$055 = $7;
  while(1) {
   $30 = HEAP32[$$sroa$040$055>>2]|0;
   $31 = HEAP32[$30>>2]|0;
   $32 = ((($31)) + 136|0);
   $33 = HEAP32[$32>>2]|0;
   FUNCTION_TABLE_vii[$33 & 8191]($30,$0);
   $34 = ((($$sroa$040$055)) + 4|0);
   $35 = HEAP32[$8>>2]|0;
   $36 = ($34|0)==($35|0);
   if ($36) {
    break;
   } else {
    $$sroa$040$055 = $34;
   }
  }
 }
 $11 = ((($0)) + 576|0);
 $12 = ((($0)) + 580|0);
 $13 = HEAP32[$12>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIjN3osg5State9ModeStackEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($11,$13);
 $14 = ((($0)) + 584|0);
 HEAP32[$14>>2] = 0;
 HEAP32[$11>>2] = $12;
 HEAP32[$12>>2] = 0;
 $15 = ((($0)) + 640|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ((($0)) + 644|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ($18|0)==($16|0);
 if (!($19)) {
  $21 = $18;
  while(1) {
   $20 = ((($21)) + -12|0);
   HEAP32[$17>>2] = $20;
   $22 = ((($21)) + -8|0);
   $23 = HEAP32[$22>>2]|0;
   __ZNSt3__26__treeINS_12__value_typeIjN3osg5State9ModeStackEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($20,$23);
   $24 = HEAP32[$17>>2]|0;
   $25 = ($24|0)==($16|0);
   if ($25) {
    break;
   } else {
    $21 = $24;
   }
  }
 }
 $26 = ((($0)) + 588|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ((($0)) + 592|0);
 $29 = ($27|0)==($28|0);
 if (!($29)) {
  $$sroa$034$052 = $27;
  while(1) {
   $44 = ((($$sroa$034$052)) + 36|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = ($45|0)==(0|0);
   if (!($46)) {
    $47 = HEAP32[$45>>2]|0;
    $48 = ((($47)) + 136|0);
    $49 = HEAP32[$48>>2]|0;
    FUNCTION_TABLE_vii[$49 & 8191]($45,$0);
   }
   $50 = ((($$sroa$034$052)) + 4|0);
   $51 = HEAP32[$50>>2]|0;
   $52 = ($51|0)==(0|0);
   if ($52) {
    $53 = ((($$sroa$034$052)) + 8|0);
    $54 = HEAP32[$53>>2]|0;
    $55 = HEAP32[$54>>2]|0;
    $56 = ($55|0)==($$sroa$034$052|0);
    if ($56) {
     $$sroa$034$0$be = $54;
    } else {
     $61 = $53;
     while(1) {
      $60 = HEAP32[$61>>2]|0;
      $62 = ((($60)) + 8|0);
      $63 = HEAP32[$62>>2]|0;
      $64 = HEAP32[$63>>2]|0;
      $65 = ($64|0)==($60|0);
      if ($65) {
       $$sroa$034$0$be = $63;
       break;
      } else {
       $61 = $62;
      }
     }
    }
   } else {
    $$0$i$i$i$i14 = $51;
    while(1) {
     $58 = HEAP32[$$0$i$i$i$i14>>2]|0;
     $59 = ($58|0)==(0|0);
     if ($59) {
      break;
     } else {
      $$0$i$i$i$i14 = $58;
     }
    }
    $$sroa$034$0$be = $$0$i$i$i$i14;
   }
   $57 = ($$sroa$034$0$be|0)==($28|0);
   if ($57) {
    break;
   } else {
    $$sroa$034$052 = $$sroa$034$0$be;
   }
  }
 }
 $37 = HEAP32[$28>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_4pairIN3osg14StateAttribute4TypeEjEENS3_5State14AttributeStackEEENS_19__map_value_compareIS6_S9_NS_4lessIS6_EELb1EEENS_9allocatorIS9_EEE7destroyEPNS_11__tree_nodeIS9_PvEE($26,$37);
 $38 = ((($0)) + 596|0);
 HEAP32[$38>>2] = 0;
 HEAP32[$26>>2] = $28;
 HEAP32[$28>>2] = 0;
 $39 = ((($0)) + 652|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ((($0)) + 656|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ($40|0)==($42|0);
 if ($43) {
  return;
 } else {
  $$sroa$028$049 = $40;
 }
 while(1) {
  $74 = HEAP32[$$sroa$028$049>>2]|0;
  $75 = ((($$sroa$028$049)) + 4|0);
  $76 = ($74|0)==($75|0);
  if (!($76)) {
   $$sroa$022$048 = $74;
   while(1) {
    $79 = ((($$sroa$022$048)) + 36|0);
    $80 = HEAP32[$79>>2]|0;
    $81 = ($80|0)==(0|0);
    if (!($81)) {
     $82 = HEAP32[$80>>2]|0;
     $83 = ((($82)) + 136|0);
     $84 = HEAP32[$83>>2]|0;
     FUNCTION_TABLE_vii[$84 & 8191]($80,$0);
    }
    $85 = ((($$sroa$022$048)) + 4|0);
    $86 = HEAP32[$85>>2]|0;
    $87 = ($86|0)==(0|0);
    if ($87) {
     $88 = ((($$sroa$022$048)) + 8|0);
     $89 = HEAP32[$88>>2]|0;
     $90 = HEAP32[$89>>2]|0;
     $91 = ($90|0)==($$sroa$022$048|0);
     if ($91) {
      $$sroa$022$0$be = $89;
     } else {
      $96 = $88;
      while(1) {
       $95 = HEAP32[$96>>2]|0;
       $97 = ((($95)) + 8|0);
       $98 = HEAP32[$97>>2]|0;
       $99 = HEAP32[$98>>2]|0;
       $100 = ($99|0)==($95|0);
       if ($100) {
        $$sroa$022$0$be = $98;
        break;
       } else {
        $96 = $97;
       }
      }
     }
    } else {
     $$0$i$i$i$i = $86;
     while(1) {
      $93 = HEAP32[$$0$i$i$i$i>>2]|0;
      $94 = ($93|0)==(0|0);
      if ($94) {
       break;
      } else {
       $$0$i$i$i$i = $93;
      }
     }
     $$sroa$022$0$be = $$0$i$i$i$i;
    }
    $92 = ($$sroa$022$0$be|0)==($75|0);
    if ($92) {
     break;
    } else {
     $$sroa$022$048 = $$sroa$022$0$be;
    }
   }
  }
  $66 = ((($$sroa$028$049)) + 12|0);
  $77 = HEAP32[$41>>2]|0;
  $78 = ($66|0)==($77|0);
  if ($78) {
   break;
  } else {
   $$sroa$028$049 = $66;
  }
 }
 $$pre = HEAP32[$39>>2]|0;
 $67 = ($66|0)==($$pre|0);
 if ($67) {
  return;
 } else {
  $69 = $66;
 }
 while(1) {
  $68 = ((($69)) + -12|0);
  HEAP32[$41>>2] = $68;
  $70 = ((($69)) + -8|0);
  $71 = HEAP32[$70>>2]|0;
  __ZNSt3__26__treeINS_12__value_typeINS_4pairIN3osg14StateAttribute4TypeEjEENS3_5State14AttributeStackEEENS_19__map_value_compareIS6_S9_NS_4lessIS6_EELb1EEENS_9allocatorIS9_EEE7destroyEPNS_11__tree_nodeIS9_PvEE($68,$71);
  $72 = HEAP32[$41>>2]|0;
  $73 = ($72|0)==($$pre|0);
  if ($73) {
   break;
  } else {
   $69 = $72;
  }
 }
 return;
}
function __ZN3osg5State20setInitialViewMatrixEPKNS_10RefMatrixdE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0.0, $27 = 0, $28 = 0;
 var $29 = 0.0, $3 = 0, $30 = 0, $31 = 0, $32 = 0.0, $33 = 0, $34 = 0, $35 = 0.0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 $3 = ((($0)) + 168|0);
 $4 = HEAP32[$3>>2]|0;
 if ($2) {
  $12 = ((($0)) + 164|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($4|0)==($13|0);
  if (!($14)) {
   HEAP32[$3>>2] = $13;
   $15 = ($13|0)==(0|0);
   if (!($15)) {
    $16 = ((($13)) + 8|0);
    $17 = HEAP32[$16>>2]|0;HEAP32[$16>>2] = (($17+1)|0);
   }
   $18 = ($4|0)==(0|0);
   if (!($18)) {
    $19 = ((($4)) + 8|0);
    $20 = HEAP32[$19>>2]|0;HEAP32[$19>>2] = (($20-1)|0);
    $21 = ($20|0)==(1);
    if ($21) {
     __ZNK3osg10Referenced24signalObserversAndDeleteEbb($4,1,1);
    }
   }
  }
 } else {
  $5 = ($4|0)==($1|0);
  if (!($5)) {
   HEAP32[$3>>2] = $1;
   $6 = ((($1)) + 8|0);
   $7 = HEAP32[$6>>2]|0;HEAP32[$6>>2] = (($7+1)|0);
   $8 = ($4|0)==(0|0);
   if (!($8)) {
    $9 = ((($4)) + 8|0);
    $10 = HEAP32[$9>>2]|0;HEAP32[$9>>2] = (($10-1)|0);
    $11 = ($10|0)==(1);
    if ($11) {
     __ZNK3osg10Referenced24signalObserversAndDeleteEbb($4,1,1);
    }
   }
  }
 }
 $22 = ((($0)) + 208|0);
 $23 = HEAP32[$3>>2]|0;
 $24 = ((($23)) + 32|0);
 $25 = ((($23)) + 56|0);
 $26 = +HEAPF64[$25>>3];
 $27 = $26 == 0.0;
 if ($27) {
  $28 = ((($23)) + 88|0);
  $29 = +HEAPF64[$28>>3];
  $30 = $29 == 0.0;
  if ($30) {
   $31 = ((($23)) + 120|0);
   $32 = +HEAPF64[$31>>3];
   $33 = $32 == 0.0;
   if ($33) {
    $34 = ((($23)) + 152|0);
    $35 = +HEAPF64[$34>>3];
    $36 = $35 == 1.0;
    if ($36) {
     (__ZN3osg7Matrixd10invert_4x3ERKS0_($22,$24)|0);
     return;
    }
   }
  }
 }
 (__ZN3osg7Matrixd10invert_4x4ERKS0_($22,$24)|0);
 return;
}
function __ZN3osg5State21setMaxTexturePoolSizeEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = ((($0)) + 680|0);
 HEAP32[$3>>2] = $1;
 $4 = ((($0)) + 124|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (__ZN3osg22getOrCreateContextDataEj($5)|0);
 $7 = (__ZN3osg11ContextData3getINS_20TextureObjectManagerEEEPT_v($6)|0);
 __ZN3osg20TextureObjectManager21setMaxTexturePoolSizeEj($7,$1);
 $8 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
 if (!($8)) {
  STACKTOP = sp;return;
 }
 $9 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
 $10 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($9,149718,32)|0);
 $11 = HEAP32[$3>>2]|0;
 $12 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($10,$11)|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($13)) + -12|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($12) + ($15)|0);
 __ZNKSt3__28ios_base6getlocEv($2,$16);
 __THREW__ = 0;
 $17 = (invoke_iii(3255,($2|0),(215188|0))|0);
 $18 = __THREW__; __THREW__ = 0;
 $19 = $18&1;
 if (!($19)) {
  $20 = HEAP32[$17>>2]|0;
  $21 = ((($20)) + 28|0);
  $22 = HEAP32[$21>>2]|0;
  __THREW__ = 0;
  $23 = (invoke_iii($22|0,($17|0),10)|0);
  $24 = __THREW__; __THREW__ = 0;
  $25 = $24&1;
  if (!($25)) {
   __ZNSt3__26localeD2Ev($2);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($12,$23)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($12)|0);
   STACKTOP = sp;return;
  }
 }
 $26 = ___cxa_find_matching_catch_2()|0;
 $27 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($2|0));
 $28 = __THREW__; __THREW__ = 0;
 $29 = $28&1;
 if ($29) {
  $30 = ___cxa_find_matching_catch_3(0|0)|0;
  $31 = tempRet0;
  ___clang_call_terminate($30);
  // unreachable;
 } else {
  ___resumeException($26|0);
  // unreachable;
 }
}
function __ZN3osg11ContextData3getINS_20TextureObjectManagerEEEPT_v($0) {
 $0 = $0|0;
 var $$0$i$i = 0, $$0$ph$i$i = 0, $$014$i = 0, $$024$i$i = 0, $$025$i$i = 0, $$025$i53$i = 0, $$037$i = 0, $$03752$i = 0, $$in$i$i = 0, $$pre$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 36|0);
 $2 = ((($0)) + 40|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 do {
  if ($4) {
   $$025$i$i = $2;$$037$i = $2;$15 = $3;
   label = 12;
  } else {
   $5 = ((($0)) + 40|0);
   $$0$i$i = $5;$$024$i$i = $3;$51 = $3;
   while(1) {
    $6 = ((($$024$i$i)) + 16|0);
    $7 = HEAP32[$6>>2]|0;
    $8 = ($7>>>0)>(26848>>>0);
    if ($8) {
     $9 = HEAP32[$$024$i$i>>2]|0;
     $10 = ($9|0)==(0|0);
     if ($10) {
      label = 6;
      break;
     } else {
      $$0$ph$i$i = $$024$i$i;$$in$i$i = $9;
     }
    } else {
     $11 = ($7>>>0)<(26848>>>0);
     if (!($11)) {
      label = 10;
      break;
     }
     $12 = ((($$024$i$i)) + 4|0);
     $13 = HEAP32[$12>>2]|0;
     $14 = ($13|0)==(0|0);
     if ($14) {
      label = 9;
      break;
     } else {
      $$0$ph$i$i = $12;$$in$i$i = $13;
     }
    }
    $$0$i$i = $$0$ph$i$i;$$024$i$i = $$in$i$i;$51 = $$in$i$i;
   }
   if ((label|0) == 6) {
    $$025$i53$i = $$024$i$i;$$03752$i = $$024$i$i;
    label = 13;
    break;
   }
   else if ((label|0) == 9) {
    $$025$i53$i = $12;$$03752$i = $$024$i$i;
    label = 13;
    break;
   }
   else if ((label|0) == 10) {
    $$025$i$i = $$0$i$i;$$037$i = $$024$i$i;$15 = $51;
    label = 12;
    break;
   }
  }
 } while(0);
 if ((label|0) == 12) {
  $16 = ($15|0)==(0|0);
  if ($16) {
   $$025$i53$i = $$025$i$i;$$03752$i = $$037$i;
   label = 13;
  } else {
   $$014$i = $15;
  }
 }
 if ((label|0) == 13) {
  $17 = (__Znwj(24)|0);
  $18 = ((($17)) + 16|0);
  HEAP32[$18>>2] = (26848);
  $19 = ((($17)) + 20|0);
  HEAP32[$19>>2] = 0;
  HEAP32[$17>>2] = 0;
  $20 = ((($17)) + 4|0);
  HEAP32[$20>>2] = 0;
  $21 = ((($17)) + 8|0);
  HEAP32[$21>>2] = $$03752$i;
  HEAP32[$$025$i53$i>>2] = $17;
  $22 = HEAP32[$1>>2]|0;
  $23 = HEAP32[$22>>2]|0;
  $24 = ($23|0)==(0|0);
  if ($24) {
   $28 = $17;
  } else {
   $25 = $23;
   HEAP32[$1>>2] = $25;
   $$pre$i$i = HEAP32[$$025$i53$i>>2]|0;
   $28 = $$pre$i$i;
  }
  $26 = ((($0)) + 40|0);
  $27 = HEAP32[$26>>2]|0;
  __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($27,$28);
  $29 = ((($0)) + 44|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (($30) + 1)|0;
  HEAP32[$29>>2] = $31;
  $$014$i = $17;
 }
 $32 = ((($$014$i)) + 20|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ($33|0)==(0|0);
 if (!($34)) {
  $50 = HEAP32[$32>>2]|0;
  return ($50|0);
 }
 $35 = (__Znwj(96)|0);
 $36 = ((($0)) + 24|0);
 $37 = HEAP32[$36>>2]|0;
 __THREW__ = 0;
 invoke_vii(3929,($35|0),($37|0));
 $38 = __THREW__; __THREW__ = 0;
 $39 = $38&1;
 if ($39) {
  $48 = ___cxa_find_matching_catch_2()|0;
  $49 = tempRet0;
  __ZdlPv($35);
  ___resumeException($48|0);
  // unreachable;
 }
 $40 = HEAP32[$32>>2]|0;
 $41 = ($40|0)==($35|0);
 if ($41) {
  $50 = HEAP32[$32>>2]|0;
  return ($50|0);
 }
 HEAP32[$32>>2] = $35;
 $42 = ((($35)) + 8|0);
 $43 = HEAP32[$42>>2]|0;HEAP32[$42>>2] = (($43+1)|0);
 $44 = ($40|0)==(0|0);
 if ($44) {
  $50 = HEAP32[$32>>2]|0;
  return ($50|0);
 }
 $45 = ((($40)) + 8|0);
 $46 = HEAP32[$45>>2]|0;HEAP32[$45>>2] = (($46-1)|0);
 $47 = ($46|0)==(1);
 if (!($47)) {
  $50 = HEAP32[$32>>2]|0;
  return ($50|0);
 }
 __ZNK3osg10Referenced24signalObserversAndDeleteEbb($40,1,1);
 $50 = HEAP32[$32>>2]|0;
 return ($50|0);
}
function __ZN3osg5State26setMaxBufferObjectPoolSizeEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = ((($0)) + 684|0);
 HEAP32[$3>>2] = $1;
 $4 = ((($0)) + 124|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (__ZN3osg22getOrCreateContextDataEj($5)|0);
 $7 = (__ZN3osg11ContextData3getINS_21GLBufferObjectManagerEEEPT_v($6)|0);
 $8 = HEAP32[$3>>2]|0;
 __ZN3osg21GLBufferObjectManager28setMaxGLBufferObjectPoolSizeEj($7,$8);
 $9 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
 $11 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($10,149751,37)|0);
 $12 = HEAP32[$3>>2]|0;
 $13 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($11,$12)|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ((($14)) + -12|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($13) + ($16)|0);
 __ZNKSt3__28ios_base6getlocEv($2,$17);
 __THREW__ = 0;
 $18 = (invoke_iii(3255,($2|0),(215188|0))|0);
 $19 = __THREW__; __THREW__ = 0;
 $20 = $19&1;
 if (!($20)) {
  $21 = HEAP32[$18>>2]|0;
  $22 = ((($21)) + 28|0);
  $23 = HEAP32[$22>>2]|0;
  __THREW__ = 0;
  $24 = (invoke_iii($23|0,($18|0),10)|0);
  $25 = __THREW__; __THREW__ = 0;
  $26 = $25&1;
  if (!($26)) {
   __ZNSt3__26localeD2Ev($2);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($13,$24)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($13)|0);
   STACKTOP = sp;return;
  }
 }
 $27 = ___cxa_find_matching_catch_2()|0;
 $28 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($2|0));
 $29 = __THREW__; __THREW__ = 0;
 $30 = $29&1;
 if ($30) {
  $31 = ___cxa_find_matching_catch_3(0|0)|0;
  $32 = tempRet0;
  ___clang_call_terminate($31);
  // unreachable;
 } else {
  ___resumeException($27|0);
  // unreachable;
 }
}
function __ZN3osg5State12pushStateSetEPKNS_8StateSetE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$019 = 0, $$118 = 0, $$pre = 0, $$pre23 = 0, $$pre24 = 0, $$pre25 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 HEAP32[$2>>2] = $1;
 $3 = ((($0)) + 672|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 676|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4|0)==($6|0);
 if ($7) {
  $11 = ((($0)) + 668|0);
  __ZNSt3__26vectorIPKN3osg8StateSetENS_9allocatorIS4_EEE21__push_back_slow_pathIKS4_EEvRT_($11,$2);
 } else {
  $8 = $1;
  HEAP32[$4>>2] = $8;
  $9 = HEAP32[$3>>2]|0;
  $10 = ((($9)) + 4|0);
  HEAP32[$3>>2] = $10;
 }
 $12 = HEAP32[$2>>2]|0;
 $13 = ($12|0)==(0|0);
 if ($13) {
  STACKTOP = sp;return;
 }
 $14 = ((($0)) + 576|0);
 $15 = ((($12)) + 44|0);
 __ZN3osg5State12pushModeListERNSt3__23mapIjNS0_9ModeStackENS1_4lessIjEENS1_9allocatorINS1_4pairIKjS3_EEEEEERKNS2_IjjS5_NS6_INS7_IS8_jEEEEEE($0,$14,$15);
 $16 = HEAP32[$2>>2]|0;
 $17 = ((($16)) + 68|0);
 $18 = ((($16)) + 72|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$17>>2]|0;
 $21 = ($19|0)==($20|0);
 if ($21) {
  $53 = $16;
 } else {
  $22 = ((($0)) + 640|0);
  $23 = ((($0)) + 644|0);
  $$019 = 0;
  while(1) {
   $24 = HEAP32[$23>>2]|0;
   $25 = HEAP32[$22>>2]|0;
   $26 = (($24) - ($25))|0;
   $27 = (($26|0) / 12)&-1;
   $28 = ($27>>>0)>($$019>>>0);
   $$pre25 = (($$019) + 1)|0;
   do {
    if (!($28)) {
     $29 = ($$pre25>>>0)>($27>>>0);
     $30 = $25;
     $31 = $24;
     if ($29) {
      $32 = (($$pre25) - ($27))|0;
      __ZNSt3__26vectorINS_3mapIjN3osg5State9ModeStackENS_4lessIjEENS_9allocatorINS_4pairIKjS4_EEEEEENS7_ISC_EEE8__appendEj($22,$32);
      break;
     }
     $33 = ($$pre25>>>0)<($27>>>0);
     if ($33) {
      $34 = (($30) + (($$pre25*12)|0)|0);
      $35 = ($31|0)==($34|0);
      if (!($35)) {
       $37 = $31;
       while(1) {
        $36 = ((($37)) + -12|0);
        HEAP32[$23>>2] = $36;
        $38 = ((($37)) + -8|0);
        $39 = HEAP32[$38>>2]|0;
        __ZNSt3__26__treeINS_12__value_typeIjN3osg5State9ModeStackEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($36,$39);
        $40 = HEAP32[$23>>2]|0;
        $41 = ($40|0)==($34|0);
        if ($41) {
         break;
        } else {
         $37 = $40;
        }
       }
      }
     }
    }
   } while(0);
   $42 = HEAP32[$22>>2]|0;
   $43 = (($42) + (($$019*12)|0)|0);
   $44 = HEAP32[$17>>2]|0;
   $45 = (($44) + (($$019*12)|0)|0);
   __ZN3osg5State12pushModeListERNSt3__23mapIjNS0_9ModeStackENS1_4lessIjEENS1_9allocatorINS1_4pairIKjS3_EEEEEERKNS2_IjjS5_NS6_INS7_IS8_jEEEEEE($0,$43,$45);
   $46 = HEAP32[$18>>2]|0;
   $47 = HEAP32[$17>>2]|0;
   $48 = (($46) - ($47))|0;
   $49 = (($48|0) / 12)&-1;
   $50 = ($$pre25>>>0)<($49>>>0);
   if ($50) {
    $$019 = $$pre25;
   } else {
    break;
   }
  }
  $$pre = HEAP32[$2>>2]|0;
  $53 = $$pre;
 }
 $51 = ((($0)) + 588|0);
 $52 = ((($53)) + 56|0);
 __ZN3osg5State17pushAttributeListERNSt3__23mapINS1_4pairINS_14StateAttribute4TypeEjEENS0_14AttributeStackENS1_4lessIS6_EENS1_9allocatorINS3_IKS6_S7_EEEEEERKNS2_IS6_NS3_INS_7ref_ptrIS4_EEjEES9_NSA_INS3_ISB_SI_EEEEEE($0,$51,$52);
 $54 = HEAP32[$2>>2]|0;
 $55 = ((($54)) + 80|0);
 $56 = ((($54)) + 84|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = HEAP32[$55>>2]|0;
 $59 = ($57|0)==($58|0);
 if ($59) {
  $91 = $54;
 } else {
  $60 = ((($0)) + 652|0);
  $61 = ((($0)) + 656|0);
  $$118 = 0;
  while(1) {
   $62 = HEAP32[$61>>2]|0;
   $63 = HEAP32[$60>>2]|0;
   $64 = (($62) - ($63))|0;
   $65 = (($64|0) / 12)&-1;
   $66 = ($65>>>0)>($$118>>>0);
   $$pre24 = (($$118) + 1)|0;
   do {
    if (!($66)) {
     $67 = ($$pre24>>>0)>($65>>>0);
     $68 = $63;
     $69 = $62;
     if ($67) {
      $70 = (($$pre24) - ($65))|0;
      __ZNSt3__26vectorINS_3mapINS_4pairIN3osg14StateAttribute4TypeEjEENS3_5State14AttributeStackENS_4lessIS6_EENS_9allocatorINS2_IKS6_S8_EEEEEENSB_ISF_EEE8__appendEj($60,$70);
      break;
     }
     $71 = ($$pre24>>>0)<($65>>>0);
     if ($71) {
      $72 = (($68) + (($$pre24*12)|0)|0);
      $73 = ($69|0)==($72|0);
      if (!($73)) {
       $75 = $69;
       while(1) {
        $74 = ((($75)) + -12|0);
        HEAP32[$61>>2] = $74;
        $76 = ((($75)) + -8|0);
        $77 = HEAP32[$76>>2]|0;
        __ZNSt3__26__treeINS_12__value_typeINS_4pairIN3osg14StateAttribute4TypeEjEENS3_5State14AttributeStackEEENS_19__map_value_compareIS6_S9_NS_4lessIS6_EELb1EEENS_9allocatorIS9_EEE7destroyEPNS_11__tree_nodeIS9_PvEE($74,$77);
        $78 = HEAP32[$61>>2]|0;
        $79 = ($78|0)==($72|0);
        if ($79) {
         break;
        } else {
         $75 = $78;
        }
       }
      }
     }
    }
   } while(0);
   $80 = HEAP32[$60>>2]|0;
   $81 = (($80) + (($$118*12)|0)|0);
   $82 = HEAP32[$55>>2]|0;
   $83 = (($82) + (($$118*12)|0)|0);
   __ZN3osg5State17pushAttributeListERNSt3__23mapINS1_4pairINS_14StateAttribute4TypeEjEENS0_14AttributeStackENS1_4lessIS6_EENS1_9allocatorINS3_IKS6_S7_EEEEEERKNS2_IS6_NS3_INS_7ref_ptrIS4_EEjEES9_NSA_INS3_ISB_SI_EEEEEE($0,$81,$83);
   $84 = HEAP32[$56>>2]|0;
   $85 = HEAP32[$55>>2]|0;
   $86 = (($84) - ($85))|0;
   $87 = (($86|0) / 12)&-1;
   $88 = ($$pre24>>>0)<($87>>>0);
   if ($88) {
    $$118 = $$pre24;
   } else {
    break;
   }
  }
  $$pre23 = HEAP32[$2>>2]|0;
  $91 = $$pre23;
 }
 $89 = ((($0)) + 600|0);
 $90 = ((($91)) + 92|0);
 __ZN3osg5State15pushUniformListERNSt3__23mapINS1_12basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEENS0_12UniformStackENS1_4lessIS8_EENS6_INS1_4pairIKS8_S9_EEEEEERKNS2_IS8_NSC_INS_7ref_ptrINS_7UniformEEEjEESB_NS6_INSC_ISD_SL_EEEEEE($0,$89,$90);
 $92 = ((($0)) + 612|0);
 $93 = HEAP32[$2>>2]|0;
 $94 = ((($93)) + 104|0);
 __ZN3osg5State14pushDefineListERNS0_9DefineMapERKNSt3__23mapINS3_12basic_stringIcNS3_11char_traitsIcEENS3_9allocatorIcEEEENS3_4pairISA_jEENS3_4lessISA_EENS8_INSB_IKSA_SC_EEEEEE($0,$92,$94);
 STACKTOP = sp;return;
}
function __ZNSt3__26vectorIPKN3osg8StateSetENS_9allocatorIS4_EEE21__push_back_slow_pathIKS4_EEvRT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(1073741823);
 if ($8) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $9 = ((($0)) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) - ($4))|0;
 $12 = $11 >> 2;
 $13 = ($12>>>0)<(536870911);
 $14 = $11 >> 1;
 $15 = ($14>>>0)<($7>>>0);
 $$sroa$speculated$i = $15 ? $7 : $14;
 $$sroa$speculated$$i = $13 ? $$sroa$speculated$i : 1073741823;
 $16 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($16) {
   $26 = 0;
  } else {
   $17 = ($$sroa$speculated$$i>>>0)>(1073741823);
   if (!($17)) {
    $23 = $$sroa$speculated$$i << 2;
    $24 = (__Znwj($23)|0);
    $26 = $24;
    break;
   }
   $18 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($18|0),(204840|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if ($20) {
    $21 = ___cxa_find_matching_catch_2()|0;
    $22 = tempRet0;
    ___cxa_free_exception(($18|0));
    ___resumeException($21|0);
    // unreachable;
   } else {
    HEAP32[$18>>2] = (99824);
    ___cxa_throw(($18|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $25 = (($26) + ($6<<2)|0);
 $27 = (($26) + ($$sroa$speculated$$i<<2)|0);
 $28 = $27;
 $29 = HEAP32[$1>>2]|0;
 HEAP32[$25>>2] = $29;
 $30 = ((($25)) + 4|0);
 $31 = $30;
 $32 = (0 - ($6))|0;
 $33 = (($25) + ($32<<2)|0);
 $34 = $33;
 $35 = ($5|0)>(0);
 if ($35) {
  $36 = $4;
  _memcpy(($33|0),($36|0),($5|0))|0;
 }
 HEAP32[$0>>2] = $34;
 HEAP32[$2>>2] = $31;
 HEAP32[$9>>2] = $28;
 $37 = ($4|0)==(0);
 if ($37) {
  return;
 }
 $38 = $4;
 __ZdlPv($38);
 return;
}
function __ZN3osg5State12pushModeListERNSt3__23mapIjNS0_9ModeStackENS1_4lessIjEENS1_9allocatorINS1_4pairIKjS3_EEEEEERKNS2_IjjS5_NS6_INS7_IS8_jEEEEEE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$i$i = 0, $$0$i$i$i$i = 0, $$0$ph$i$i = 0, $$014$i = 0, $$024$i$i = 0, $$025$i$i = 0, $$025$i65$i = 0, $$049$i = 0, $$04964$i = 0, $$in$i$i = 0, $$pre = 0, $$pre$i$i = 0, $$sroa$014$0$be = 0, $$sroa$014$030 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($2)) + 4|0);
 $5 = ($3|0)==($4|0);
 if ($5) {
  return;
 }
 $6 = ((($1)) + 4|0);
 $7 = ((($1)) + 4|0);
 $8 = ((($1)) + 8|0);
 $$sroa$014$030 = $3;
 while(1) {
  $9 = ((($$sroa$014$030)) + 16|0);
  $10 = HEAP32[$6>>2]|0;
  $11 = ($10|0)==(0|0);
  do {
   if ($11) {
    $$025$i$i = $6;$$049$i = $6;$22 = $10;
    label = 14;
   } else {
    $12 = HEAP32[$9>>2]|0;
    $$0$i$i = $7;$$024$i$i = $10;$88 = $10;
    while(1) {
     $13 = ((($$024$i$i)) + 16|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = ($12>>>0)<($14>>>0);
     if ($15) {
      $16 = HEAP32[$$024$i$i>>2]|0;
      $17 = ($16|0)==(0|0);
      if ($17) {
       label = 9;
       break;
      } else {
       $$0$ph$i$i = $$024$i$i;$$in$i$i = $16;
      }
     } else {
      $18 = ($14>>>0)<($12>>>0);
      if (!($18)) {
       label = 13;
       break;
      }
      $19 = ((($$024$i$i)) + 4|0);
      $20 = HEAP32[$19>>2]|0;
      $21 = ($20|0)==(0|0);
      if ($21) {
       label = 12;
       break;
      } else {
       $$0$ph$i$i = $19;$$in$i$i = $20;
      }
     }
     $$0$i$i = $$0$ph$i$i;$$024$i$i = $$in$i$i;$88 = $$in$i$i;
    }
    if ((label|0) == 9) {
     label = 0;
     $$025$i65$i = $$024$i$i;$$04964$i = $$024$i$i;
     label = 15;
     break;
    }
    else if ((label|0) == 12) {
     label = 0;
     $$025$i65$i = $19;$$04964$i = $$024$i$i;
     label = 15;
     break;
    }
    else if ((label|0) == 13) {
     label = 0;
     $$025$i$i = $$0$i$i;$$049$i = $$024$i$i;$22 = $88;
     label = 14;
     break;
    }
   }
  } while(0);
  if ((label|0) == 14) {
   label = 0;
   $23 = ($22|0)==(0|0);
   if ($23) {
    $$025$i65$i = $$025$i$i;$$04964$i = $$049$i;
    label = 15;
   } else {
    $$014$i = $22;
   }
  }
  if ((label|0) == 15) {
   label = 0;
   $24 = (__Znwj(36)|0);
   $25 = ((($24)) + 16|0);
   $26 = HEAP32[$9>>2]|0;
   HEAP32[$25>>2] = $26;
   $27 = ((($24)) + 20|0);
   $28 = ((($24)) + 24|0);
   HEAP32[$28>>2] = 0;
   $29 = ((($24)) + 28|0);
   HEAP32[$29>>2] = 0;
   $30 = ((($24)) + 32|0);
   HEAP32[$30>>2] = 0;
   HEAP8[$27>>0] = 1;
   $31 = ((($24)) + 21|0);
   HEAP8[$31>>0] = 0;
   $32 = ((($24)) + 22|0);
   HEAP8[$32>>0] = 0;
   $33 = ((($24)) + 23|0);
   HEAP8[$33>>0] = 0;
   HEAP32[$24>>2] = 0;
   $34 = ((($24)) + 4|0);
   HEAP32[$34>>2] = 0;
   $35 = ((($24)) + 8|0);
   HEAP32[$35>>2] = $$04964$i;
   HEAP32[$$025$i65$i>>2] = $24;
   $36 = HEAP32[$1>>2]|0;
   $37 = HEAP32[$36>>2]|0;
   $38 = ($37|0)==(0|0);
   if ($38) {
    $41 = $24;
   } else {
    $39 = $37;
    HEAP32[$1>>2] = $39;
    $$pre$i$i = HEAP32[$$025$i65$i>>2]|0;
    $41 = $$pre$i$i;
   }
   $40 = HEAP32[$7>>2]|0;
   __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($40,$41);
   $42 = HEAP32[$8>>2]|0;
   $43 = (($42) + 1)|0;
   HEAP32[$8>>2] = $43;
   $$014$i = $24;
  }
  $44 = ((($$014$i)) + 24|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = ((($$014$i)) + 28|0);
  $47 = HEAP32[$46>>2]|0;
  $48 = ($45|0)==($47|0);
  do {
   if ($48) {
    $49 = ((($$sroa$014$030)) + 20|0);
    $50 = ((($$014$i)) + 32|0);
    $51 = HEAP32[$50>>2]|0;
    $52 = ($45|0)==($51|0);
    if ($52) {
     __ZNSt3__26vectorIjNS_9allocatorIjEEE21__push_back_slow_pathIKjEEvRT_($44,$49);
     break;
    } else {
     $53 = HEAP32[$49>>2]|0;
     HEAP32[$45>>2] = $53;
     $54 = ((($45)) + 4|0);
     HEAP32[$46>>2] = $54;
     break;
    }
   } else {
    $55 = ((($47)) + -4|0);
    $56 = HEAP32[$55>>2]|0;
    $57 = $56 & 2;
    $58 = ($57|0)==(0);
    $$pre = ((($$sroa$014$030)) + 20|0);
    if (!($58)) {
     $59 = HEAP32[$$pre>>2]|0;
     $60 = $59 & 4;
     $61 = ($60|0)==(0);
     if ($61) {
      $62 = ((($$014$i)) + 32|0);
      $63 = HEAP32[$62>>2]|0;
      $64 = ($47|0)==($63|0);
      if ($64) {
       __ZNSt3__26vectorIjNS_9allocatorIjEEE21__push_back_slow_pathIKjEEvRT_($44,$55);
       break;
      } else {
       HEAP32[$47>>2] = $56;
       $65 = ((($47)) + 4|0);
       HEAP32[$46>>2] = $65;
       break;
      }
     }
    }
    $66 = ((($$014$i)) + 32|0);
    $67 = HEAP32[$66>>2]|0;
    $68 = ($47|0)==($67|0);
    if ($68) {
     __ZNSt3__26vectorIjNS_9allocatorIjEEE21__push_back_slow_pathIKjEEvRT_($44,$$pre);
     break;
    } else {
     $69 = HEAP32[$$pre>>2]|0;
     HEAP32[$47>>2] = $69;
     $70 = ((($47)) + 4|0);
     HEAP32[$46>>2] = $70;
     break;
    }
   }
  } while(0);
  $71 = ((($$014$i)) + 21|0);
  HEAP8[$71>>0] = 1;
  $72 = ((($$sroa$014$030)) + 4|0);
  $73 = HEAP32[$72>>2]|0;
  $74 = ($73|0)==(0|0);
  if ($74) {
   $75 = ((($$sroa$014$030)) + 8|0);
   $76 = HEAP32[$75>>2]|0;
   $77 = HEAP32[$76>>2]|0;
   $78 = ($77|0)==($$sroa$014$030|0);
   if ($78) {
    $$sroa$014$0$be = $76;
   } else {
    $83 = $75;
    while(1) {
     $82 = HEAP32[$83>>2]|0;
     $84 = ((($82)) + 8|0);
     $85 = HEAP32[$84>>2]|0;
     $86 = HEAP32[$85>>2]|0;
     $87 = ($86|0)==($82|0);
     if ($87) {
      $$sroa$014$0$be = $85;
      break;
     } else {
      $83 = $84;
     }
    }
   }
  } else {
   $$0$i$i$i$i = $73;
   while(1) {
    $80 = HEAP32[$$0$i$i$i$i>>2]|0;
    $81 = ($80|0)==(0|0);
    if ($81) {
     break;
    } else {
     $$0$i$i$i$i = $80;
    }
   }
   $$sroa$014$0$be = $$0$i$i$i$i;
  }
  $79 = ($$sroa$014$0$be|0)==($4|0);
  if ($79) {
   break;
  } else {
   $$sroa$014$030 = $$sroa$014$0$be;
  }
 }
 return;
}
function __ZN3osg5State17pushAttributeListERNSt3__23mapINS1_4pairINS_14StateAttribute4TypeEjEENS0_14AttributeStackENS1_4lessIS6_EENS1_9allocatorINS3_IKS6_S7_EEEEEERKNS2_IS6_NS3_INS_7ref_ptrIS4_EEjEES9_NSA_INS3_ISB_SI_EEEEEE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$i$i = 0, $$0$i$i$i$i = 0, $$0$ph$i$i = 0, $$014$i = 0, $$024$i$i = 0, $$025$i$i = 0, $$025$i68$i = 0, $$052$i = 0, $$05267$i = 0, $$in$i$i = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre$i$i = 0, $$sroa$018$0$be = 0, $$sroa$018$037 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0;
 var $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0;
 var $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp + 8|0;
 $4 = sp;
 $5 = HEAP32[$2>>2]|0;
 $6 = ((($2)) + 4|0);
 $7 = ($5|0)==($6|0);
 if ($7) {
  STACKTOP = sp;return;
 }
 $8 = ((($1)) + 4|0);
 $9 = ((($1)) + 4|0);
 $10 = ((($1)) + 8|0);
 $11 = ((($3)) + 4|0);
 $12 = ((($4)) + 4|0);
 $$sroa$018$037 = $5;
 while(1) {
  $13 = ((($$sroa$018$037)) + 16|0);
  $14 = HEAP32[$8>>2]|0;
  $15 = ($14|0)==(0|0);
  do {
   if ($15) {
    $$025$i$i = $8;$$052$i = $8;$32 = $14;
    label = 16;
   } else {
    $16 = HEAP32[$13>>2]|0;
    $17 = ((($$sroa$018$037)) + 20|0);
    $18 = HEAP32[$17>>2]|0;
    $$0$i$i = $9;$$024$i$i = $14;$138 = $14;
    L8: while(1) {
     $19 = ((($$024$i$i)) + 16|0);
     $20 = HEAP32[$19>>2]|0;
     $21 = ($16|0)<($20|0);
     do {
      if ($21) {
       label = 10;
      } else {
       $22 = ($20|0)<($16|0);
       if (!($22)) {
        $23 = ((($$024$i$i)) + 20|0);
        $24 = HEAP32[$23>>2]|0;
        $25 = ($18>>>0)<($24>>>0);
        if ($25) {
         label = 10;
         break;
        }
        $28 = ($24>>>0)<($18>>>0);
        if (!($28)) {
         label = 15;
         break L8;
        }
       }
       $29 = ((($$024$i$i)) + 4|0);
       $30 = HEAP32[$29>>2]|0;
       $31 = ($30|0)==(0|0);
       if ($31) {
        label = 14;
        break L8;
       } else {
        $$0$ph$i$i = $29;$$in$i$i = $30;
       }
      }
     } while(0);
     if ((label|0) == 10) {
      label = 0;
      $26 = HEAP32[$$024$i$i>>2]|0;
      $27 = ($26|0)==(0|0);
      if ($27) {
       label = 11;
       break;
      } else {
       $$0$ph$i$i = $$024$i$i;$$in$i$i = $26;
      }
     }
     $$0$i$i = $$0$ph$i$i;$$024$i$i = $$in$i$i;$138 = $$in$i$i;
    }
    if ((label|0) == 11) {
     label = 0;
     $$025$i68$i = $$024$i$i;$$05267$i = $$024$i$i;
     label = 17;
     break;
    }
    else if ((label|0) == 14) {
     label = 0;
     $$025$i68$i = $29;$$05267$i = $$024$i$i;
     label = 17;
     break;
    }
    else if ((label|0) == 15) {
     label = 0;
     $$025$i$i = $$0$i$i;$$052$i = $$024$i$i;$32 = $138;
     label = 16;
     break;
    }
   }
  } while(0);
  if ((label|0) == 16) {
   label = 0;
   $33 = ($32|0)==(0|0);
   if ($33) {
    $$025$i68$i = $$025$i$i;$$05267$i = $$052$i;
    label = 17;
   } else {
    $$014$i = $32;
   }
  }
  if ((label|0) == 17) {
   label = 0;
   $34 = (__Znwj(52)|0);
   $35 = ((($34)) + 16|0);
   $36 = $13;
   $37 = $36;
   $38 = HEAP32[$37>>2]|0;
   $39 = (($36) + 4)|0;
   $40 = $39;
   $41 = HEAP32[$40>>2]|0;
   $42 = $35;
   $43 = $42;
   HEAP32[$43>>2] = $38;
   $44 = (($42) + 4)|0;
   $45 = $44;
   HEAP32[$45>>2] = $41;
   $46 = ((($34)) + 24|0);
   HEAP8[$46>>0] = 0;
   $47 = ((($34)) + 28|0);
   ;HEAP32[$47>>2]=0|0;HEAP32[$47+4>>2]=0|0;HEAP32[$47+8>>2]=0|0;HEAP32[$47+12>>2]=0|0;HEAP32[$47+16>>2]=0|0;HEAP32[$47+20>>2]=0|0;
   HEAP32[$34>>2] = 0;
   $48 = ((($34)) + 4|0);
   HEAP32[$48>>2] = 0;
   $49 = ((($34)) + 8|0);
   HEAP32[$49>>2] = $$05267$i;
   HEAP32[$$025$i68$i>>2] = $34;
   $50 = HEAP32[$1>>2]|0;
   $51 = HEAP32[$50>>2]|0;
   $52 = ($51|0)==(0|0);
   if ($52) {
    $55 = $34;
   } else {
    $53 = $51;
    HEAP32[$1>>2] = $53;
    $$pre$i$i = HEAP32[$$025$i68$i>>2]|0;
    $55 = $$pre$i$i;
   }
   $54 = HEAP32[$9>>2]|0;
   __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($54,$55);
   $56 = HEAP32[$10>>2]|0;
   $57 = (($56) + 1)|0;
   HEAP32[$10>>2] = $57;
   $$014$i = $34;
  }
  $58 = ((($$014$i)) + 40|0);
  $59 = HEAP32[$58>>2]|0;
  $60 = ((($$014$i)) + 44|0);
  $61 = HEAP32[$60>>2]|0;
  $62 = ($59|0)==($61|0);
  do {
   if ($62) {
    $63 = ((($$sroa$018$037)) + 24|0);
    $64 = HEAP32[$63>>2]|0;
    $65 = ((($$sroa$018$037)) + 28|0);
    HEAP32[$3>>2] = $64;
    $66 = HEAP32[$65>>2]|0;
    HEAP32[$11>>2] = $66;
    $67 = ((($$014$i)) + 48|0);
    $68 = HEAP32[$67>>2]|0;
    $69 = ($59|0)==($68|0);
    if ($69) {
     __ZNSt3__26vectorINS_4pairIPKN3osg14StateAttributeEjEENS_9allocatorIS6_EEE21__push_back_slow_pathIKS6_EEvRT_($58,$3);
    } else {
     $70 = $3;
     $71 = $70;
     $72 = HEAP32[$71>>2]|0;
     $73 = (($70) + 4)|0;
     $74 = $73;
     $75 = HEAP32[$74>>2]|0;
     $76 = $59;
     $77 = $76;
     HEAP32[$77>>2] = $72;
     $78 = (($76) + 4)|0;
     $79 = $78;
     HEAP32[$79>>2] = $75;
     $80 = HEAP32[$60>>2]|0;
     $81 = ((($80)) + 8|0);
     HEAP32[$60>>2] = $81;
    }
   } else {
    $82 = ((($61)) + -8|0);
    $83 = ((($61)) + -4|0);
    $84 = HEAP32[$83>>2]|0;
    $85 = $84 & 2;
    $86 = ($85|0)!=(0);
    $$phi$trans$insert = ((($$sroa$018$037)) + 28|0);
    $$pre = HEAP32[$$phi$trans$insert>>2]|0;
    $87 = $$pre & 4;
    $88 = ($87|0)==(0);
    $or$cond = $86 & $88;
    if ($or$cond) {
     $89 = ((($$014$i)) + 48|0);
     $90 = HEAP32[$89>>2]|0;
     $91 = ($61|0)==($90|0);
     if ($91) {
      __ZNSt3__26vectorINS_4pairIPKN3osg14StateAttributeEjEENS_9allocatorIS6_EEE21__push_back_slow_pathIKS6_EEvRT_($58,$82);
      break;
     } else {
      $92 = $82;
      $93 = $92;
      $94 = HEAP32[$93>>2]|0;
      $95 = (($92) + 4)|0;
      $96 = $95;
      $97 = HEAP32[$96>>2]|0;
      $98 = $61;
      $99 = $98;
      HEAP32[$99>>2] = $94;
      $100 = (($98) + 4)|0;
      $101 = $100;
      HEAP32[$101>>2] = $97;
      $102 = HEAP32[$60>>2]|0;
      $103 = ((($102)) + 8|0);
      HEAP32[$60>>2] = $103;
      break;
     }
    }
    $104 = ((($$sroa$018$037)) + 24|0);
    $105 = HEAP32[$104>>2]|0;
    HEAP32[$4>>2] = $105;
    HEAP32[$12>>2] = $$pre;
    $106 = ((($$014$i)) + 48|0);
    $107 = HEAP32[$106>>2]|0;
    $108 = ($61|0)==($107|0);
    if ($108) {
     __ZNSt3__26vectorINS_4pairIPKN3osg14StateAttributeEjEENS_9allocatorIS6_EEE21__push_back_slow_pathIKS6_EEvRT_($58,$4);
    } else {
     $109 = $4;
     $110 = $109;
     $111 = HEAP32[$110>>2]|0;
     $112 = (($109) + 4)|0;
     $113 = $112;
     $114 = HEAP32[$113>>2]|0;
     $115 = $61;
     $116 = $115;
     HEAP32[$116>>2] = $111;
     $117 = (($115) + 4)|0;
     $118 = $117;
     HEAP32[$118>>2] = $114;
     $119 = HEAP32[$60>>2]|0;
     $120 = ((($119)) + 8|0);
     HEAP32[$60>>2] = $120;
    }
   }
  } while(0);
  $121 = ((($$014$i)) + 24|0);
  HEAP8[$121>>0] = 1;
  $122 = ((($$sroa$018$037)) + 4|0);
  $123 = HEAP32[$122>>2]|0;
  $124 = ($123|0)==(0|0);
  if ($124) {
   $125 = ((($$sroa$018$037)) + 8|0);
   $126 = HEAP32[$125>>2]|0;
   $127 = HEAP32[$126>>2]|0;
   $128 = ($127|0)==($$sroa$018$037|0);
   if ($128) {
    $$sroa$018$0$be = $126;
   } else {
    $133 = $125;
    while(1) {
     $132 = HEAP32[$133>>2]|0;
     $134 = ((($132)) + 8|0);
     $135 = HEAP32[$134>>2]|0;
     $136 = HEAP32[$135>>2]|0;
     $137 = ($136|0)==($132|0);
     if ($137) {
      $$sroa$018$0$be = $135;
      break;
     } else {
      $133 = $134;
     }
    }
   }
  } else {
   $$0$i$i$i$i = $123;
   while(1) {
    $130 = HEAP32[$$0$i$i$i$i>>2]|0;
    $131 = ($130|0)==(0|0);
    if ($131) {
     break;
    } else {
     $$0$i$i$i$i = $130;
    }
   }
   $$sroa$018$0$be = $$0$i$i$i$i;
  }
  $129 = ($$sroa$018$0$be|0)==($6|0);
  if ($129) {
   break;
  } else {
   $$sroa$018$037 = $$sroa$018$0$be;
  }
 }
 STACKTOP = sp;return;
}
function __ZN3osg5State15pushUniformListERNSt3__23mapINS1_12basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEENS0_12UniformStackENS1_4lessIS8_EENS6_INS1_4pairIKS8_S9_EEEEEERKNS2_IS8_NSC_INS_7ref_ptrINS_7UniformEEEjEESB_NS6_INSC_ISD_SL_EEEEEE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$i$i$i$i = 0, $$phi$trans$insert = 0, $$pre = 0, $$sroa$017$0$be = 0, $$sroa$017$027 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp + 8|0;
 $4 = sp;
 $5 = HEAP32[$2>>2]|0;
 $6 = ((($2)) + 4|0);
 $7 = ($5|0)==($6|0);
 if ($7) {
  STACKTOP = sp;return;
 }
 $8 = ((($3)) + 4|0);
 $9 = ((($4)) + 4|0);
 $$sroa$017$027 = $5;
 while(1) {
  $10 = ((($$sroa$017$027)) + 16|0);
  $11 = (__ZNSt3__23mapINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg5State12UniformStackENS_4lessIS6_EENS4_INS_4pairIKS6_S9_EEEEEixERSD_($1,$10)|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ((($11)) + 4|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = ($12|0)==($14|0);
  do {
   if ($15) {
    $16 = ((($$sroa$017$027)) + 28|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = ((($$sroa$017$027)) + 32|0);
    HEAP32[$3>>2] = $17;
    $19 = HEAP32[$18>>2]|0;
    HEAP32[$8>>2] = $19;
    $20 = ((($11)) + 8|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = ($12|0)==($21|0);
    if ($22) {
     __ZNSt3__26vectorINS_4pairIPKN3osg7UniformEjEENS_9allocatorIS6_EEE21__push_back_slow_pathIKS6_EEvRT_($11,$3);
    } else {
     $23 = $3;
     $24 = $23;
     $25 = HEAP32[$24>>2]|0;
     $26 = (($23) + 4)|0;
     $27 = $26;
     $28 = HEAP32[$27>>2]|0;
     $29 = $12;
     $30 = $29;
     HEAP32[$30>>2] = $25;
     $31 = (($29) + 4)|0;
     $32 = $31;
     HEAP32[$32>>2] = $28;
     $33 = HEAP32[$13>>2]|0;
     $34 = ((($33)) + 8|0);
     HEAP32[$13>>2] = $34;
    }
   } else {
    $35 = ((($14)) + -8|0);
    $36 = ((($14)) + -4|0);
    $37 = HEAP32[$36>>2]|0;
    $38 = $37 & 2;
    $39 = ($38|0)!=(0);
    $$phi$trans$insert = ((($$sroa$017$027)) + 32|0);
    $$pre = HEAP32[$$phi$trans$insert>>2]|0;
    $40 = $$pre & 4;
    $41 = ($40|0)==(0);
    $or$cond = $39 & $41;
    if ($or$cond) {
     $42 = ((($11)) + 8|0);
     $43 = HEAP32[$42>>2]|0;
     $44 = ($14|0)==($43|0);
     if ($44) {
      __ZNSt3__26vectorINS_4pairIPKN3osg7UniformEjEENS_9allocatorIS6_EEE21__push_back_slow_pathIKS6_EEvRT_($11,$35);
      break;
     } else {
      $45 = $35;
      $46 = $45;
      $47 = HEAP32[$46>>2]|0;
      $48 = (($45) + 4)|0;
      $49 = $48;
      $50 = HEAP32[$49>>2]|0;
      $51 = $14;
      $52 = $51;
      HEAP32[$52>>2] = $47;
      $53 = (($51) + 4)|0;
      $54 = $53;
      HEAP32[$54>>2] = $50;
      $55 = HEAP32[$13>>2]|0;
      $56 = ((($55)) + 8|0);
      HEAP32[$13>>2] = $56;
      break;
     }
    }
    $57 = ((($$sroa$017$027)) + 28|0);
    $58 = HEAP32[$57>>2]|0;
    HEAP32[$4>>2] = $58;
    HEAP32[$9>>2] = $$pre;
    $59 = ((($11)) + 8|0);
    $60 = HEAP32[$59>>2]|0;
    $61 = ($14|0)==($60|0);
    if ($61) {
     __ZNSt3__26vectorINS_4pairIPKN3osg7UniformEjEENS_9allocatorIS6_EEE21__push_back_slow_pathIKS6_EEvRT_($11,$4);
    } else {
     $62 = $4;
     $63 = $62;
     $64 = HEAP32[$63>>2]|0;
     $65 = (($62) + 4)|0;
     $66 = $65;
     $67 = HEAP32[$66>>2]|0;
     $68 = $14;
     $69 = $68;
     HEAP32[$69>>2] = $64;
     $70 = (($68) + 4)|0;
     $71 = $70;
     HEAP32[$71>>2] = $67;
     $72 = HEAP32[$13>>2]|0;
     $73 = ((($72)) + 8|0);
     HEAP32[$13>>2] = $73;
    }
   }
  } while(0);
  $74 = ((($$sroa$017$027)) + 4|0);
  $75 = HEAP32[$74>>2]|0;
  $76 = ($75|0)==(0|0);
  if ($76) {
   $77 = ((($$sroa$017$027)) + 8|0);
   $78 = HEAP32[$77>>2]|0;
   $79 = HEAP32[$78>>2]|0;
   $80 = ($79|0)==($$sroa$017$027|0);
   if ($80) {
    $$sroa$017$0$be = $78;
   } else {
    $85 = $77;
    while(1) {
     $84 = HEAP32[$85>>2]|0;
     $86 = ((($84)) + 8|0);
     $87 = HEAP32[$86>>2]|0;
     $88 = HEAP32[$87>>2]|0;
     $89 = ($88|0)==($84|0);
     if ($89) {
      $$sroa$017$0$be = $87;
      break;
     } else {
      $85 = $86;
     }
    }
   }
  } else {
   $$0$i$i$i$i = $75;
   while(1) {
    $82 = HEAP32[$$0$i$i$i$i>>2]|0;
    $83 = ($82|0)==(0|0);
    if ($83) {
     break;
    } else {
     $$0$i$i$i$i = $82;
    }
   }
   $$sroa$017$0$be = $$0$i$i$i$i;
  }
  $81 = ($$sroa$017$0$be|0)==($6|0);
  if ($81) {
   break;
  } else {
   $$sroa$017$027 = $$sroa$017$0$be;
  }
 }
 STACKTOP = sp;return;
}
function __ZN3osg5State14pushDefineListERNS0_9DefineMapERKNSt3__23mapINS3_12basic_stringIcNS3_11char_traitsIcEENS3_9allocatorIcEEEENS3_4pairISA_jEENS3_4lessISA_EENS8_INSB_IKSA_SC_EEEEEE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$0$i$i$i$i = 0, $$02026$i$i3$i = 0, $$02125$i$i4$i = 0, $$025 = 0, $$027$i$i2$i = 0, $$cast = 0, $$pre = 0, $$pre$i$i = 0, $$sroa$036$0$be = 0, $$sroa$036$048 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $phitmp$i = 0, $phitmp$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $3 = sp + 16|0;
 $4 = sp;
 $5 = HEAP32[$2>>2]|0;
 $6 = ((($2)) + 4|0);
 $7 = ($5|0)==($6|0);
 if ($7) {
  STACKTOP = sp;return;
 }
 $8 = ((($3)) + 12|0);
 $9 = ((($3)) + 11|0);
 $10 = ((($1)) + 12|0);
 $11 = ((($4)) + 12|0);
 $12 = ((($4)) + 11|0);
 $$sroa$036$048 = $5;
 L4: while(1) {
  $13 = ((($$sroa$036$048)) + 16|0);
  $14 = (__ZNSt3__23mapINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg5State11DefineStackENS_4lessIS6_EENS4_INS_4pairIKS6_S9_EEEEEixERSD_($1,$13)|0);
  $15 = ((($14)) + 4|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ((($14)) + 8|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = ($16|0)==($18|0);
  L6: do {
   if ($19) {
    $20 = ((($$sroa$036$048)) + 28|0);
    $21 = ((($$sroa$036$048)) + 40|0);
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_($3,$20);
    $22 = HEAP32[$21>>2]|0;
    HEAP32[$8>>2] = $22;
    $23 = HEAP32[$17>>2]|0;
    $24 = ((($14)) + 12|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = ($23|0)==($25|0);
    if ($26) {
     __THREW__ = 0;
     invoke_vii(3927,($15|0),($3|0));
     $33 = __THREW__; __THREW__ = 0;
     $34 = $33&1;
     if ($34) {
      label = 12;
      break L4;
     }
    } else {
     __THREW__ = 0;
     invoke_vii(3457,($23|0),($3|0));
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     if ($28) {
      label = 12;
      break L4;
     }
     $29 = ((($23)) + 12|0);
     $30 = HEAP32[$8>>2]|0;
     HEAP32[$29>>2] = $30;
     $31 = HEAP32[$17>>2]|0;
     $32 = ((($31)) + 16|0);
     HEAP32[$17>>2] = $32;
    }
    $35 = HEAP8[$9>>0]|0;
    $36 = ($35<<24>>24)<(0);
    if ($36) {
     $37 = HEAP32[$3>>2]|0;
     __ZdlPv($37);
    }
    HEAP8[$14>>0] = 1;
    HEAP8[$10>>0] = 1;
   } else {
    $43 = ((($18)) + -16|0);
    $44 = ((($18)) + -4|0);
    $45 = HEAP32[$44>>2]|0;
    $46 = $45 & 2;
    $47 = ($46|0)==(0);
    $$pre = ((($$sroa$036$048)) + 40|0);
    if (!($47)) {
     $48 = HEAP32[$$pre>>2]|0;
     $49 = $48 & 4;
     $50 = ($49|0)==(0);
     if ($50) {
      $51 = ((($14)) + 12|0);
      $52 = HEAP32[$51>>2]|0;
      $53 = ($18|0)==($52|0);
      if ($53) {
       __ZNSt3__26vectorINS_4pairINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEjEENS5_IS8_EEE21__push_back_slow_pathIKS8_EEvRT_($15,$43);
       break;
      } else {
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_($18,$43);
       $54 = ((($18)) + 12|0);
       $55 = HEAP32[$44>>2]|0;
       HEAP32[$54>>2] = $55;
       $56 = HEAP32[$17>>2]|0;
       $57 = ((($56)) + 16|0);
       HEAP32[$17>>2] = $57;
       break;
      }
     }
    }
    $58 = ((($$sroa$036$048)) + 28|0);
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_($4,$58);
    $59 = HEAP32[$$pre>>2]|0;
    HEAP32[$11>>2] = $59;
    $60 = HEAP32[$17>>2]|0;
    $61 = ((($14)) + 12|0);
    $62 = HEAP32[$61>>2]|0;
    $63 = ($60|0)==($62|0);
    if ($63) {
     __THREW__ = 0;
     invoke_vii(3927,($15|0),($4|0));
     $70 = __THREW__; __THREW__ = 0;
     $71 = $70&1;
     if ($71) {
      label = 36;
      break L4;
     }
    } else {
     __THREW__ = 0;
     invoke_vii(3457,($60|0),($4|0));
     $64 = __THREW__; __THREW__ = 0;
     $65 = $64&1;
     if ($65) {
      label = 36;
      break L4;
     }
     $66 = ((($60)) + 12|0);
     $67 = HEAP32[$11>>2]|0;
     HEAP32[$66>>2] = $67;
     $68 = HEAP32[$17>>2]|0;
     $69 = ((($68)) + 16|0);
     HEAP32[$17>>2] = $69;
    }
    $72 = HEAP8[$12>>0]|0;
    $73 = ($72<<24>>24)<(0);
    if ($73) {
     $74 = HEAP32[$4>>2]|0;
     __ZdlPv($74);
    }
    $75 = HEAP32[$17>>2]|0;
    $76 = HEAP32[$15>>2]|0;
    $77 = (($75) - ($76))|0;
    $78 = $77 >> 4;
    $79 = (($78) + -2)|0;
    $$cast = $76;
    $80 = (($$cast) + ($79<<4)|0);
    $81 = $75;
    $82 = ((($81)) + -16|0);
    $83 = ((($80)) + 11|0);
    $84 = HEAP8[$83>>0]|0;
    $85 = ($84<<24>>24)<(0);
    $86 = (((($$cast) + ($79<<4)|0)) + 4|0);
    $87 = HEAP32[$86>>2]|0;
    $88 = $84&255;
    $89 = $85 ? $87 : $88;
    $90 = ((($82)) + 11|0);
    $91 = HEAP8[$90>>0]|0;
    $92 = ($91<<24>>24)<(0);
    $93 = ((($81)) + -12|0);
    $94 = HEAP32[$93>>2]|0;
    $95 = $91&255;
    $96 = $92 ? $94 : $95;
    $97 = ($89|0)==($96|0);
    L32: do {
     if ($97) {
      $98 = HEAP32[$80>>2]|0;
      $99 = $85 ? $98 : $80;
      $100 = HEAP32[$82>>2]|0;
      $101 = $92 ? $100 : $82;
      $102 = ($89|0)==(0);
      L34: do {
       if ($85) {
        if (!($102)) {
         $113 = (_memcmp($99,$101,$89)|0);
         $phitmp$i$i$i = ($113|0)==(0);
         if (!($phitmp$i$i$i)) {
          break L32;
         }
        }
       } else {
        if (!($102)) {
         $103 = $98;
         $104 = $103&255;
         $105 = HEAP8[$101>>0]|0;
         $106 = ($104<<24>>24)==($105<<24>>24);
         if ($106) {
          $$02026$i$i3$i = $80;$$02125$i$i4$i = $88;$$027$i$i2$i = $101;
         } else {
          break L32;
         }
         while(1) {
          $107 = (($$02125$i$i4$i) + -1)|0;
          $108 = ((($$02026$i$i3$i)) + 1|0);
          $109 = ($107|0)==(0);
          if ($109) {
           break L34;
          }
          $110 = ((($$027$i$i2$i)) + 1|0);
          $$pre$i$i = HEAP8[$108>>0]|0;
          $111 = HEAP8[$110>>0]|0;
          $112 = ($$pre$i$i<<24>>24)==($111<<24>>24);
          if ($112) {
           $$02026$i$i3$i = $108;$$02125$i$i4$i = $107;$$027$i$i2$i = $110;
          } else {
           break L32;
          }
         }
        }
       }
      } while(0);
      $114 = (((($$cast) + ($79<<4)|0)) + 12|0);
      $115 = HEAP32[$114>>2]|0;
      $116 = ((($81)) + -4|0);
      $117 = HEAP32[$116>>2]|0;
      $phitmp$i = ($115|0)==($117|0);
      if ($phitmp$i) {
       break L6;
      }
     }
    } while(0);
    HEAP8[$14>>0] = 1;
    HEAP8[$10>>0] = 1;
   }
  } while(0);
  $123 = ((($$sroa$036$048)) + 4|0);
  $124 = HEAP32[$123>>2]|0;
  $125 = ($124|0)==(0|0);
  if ($125) {
   $126 = ((($$sroa$036$048)) + 8|0);
   $127 = HEAP32[$126>>2]|0;
   $128 = HEAP32[$127>>2]|0;
   $129 = ($128|0)==($$sroa$036$048|0);
   if ($129) {
    $$sroa$036$0$be = $127;
   } else {
    $134 = $126;
    while(1) {
     $133 = HEAP32[$134>>2]|0;
     $135 = ((($133)) + 8|0);
     $136 = HEAP32[$135>>2]|0;
     $137 = HEAP32[$136>>2]|0;
     $138 = ($137|0)==($133|0);
     if ($138) {
      $$sroa$036$0$be = $136;
      break;
     } else {
      $134 = $135;
     }
    }
   }
  } else {
   $$0$i$i$i$i = $124;
   while(1) {
    $131 = HEAP32[$$0$i$i$i$i>>2]|0;
    $132 = ($131|0)==(0|0);
    if ($132) {
     break;
    } else {
     $$0$i$i$i$i = $131;
    }
   }
   $$sroa$036$0$be = $$0$i$i$i$i;
  }
  $130 = ($$sroa$036$0$be|0)==($6|0);
  if ($130) {
   label = 3;
   break;
  } else {
   $$sroa$036$048 = $$sroa$036$0$be;
  }
 }
 if ((label|0) == 3) {
  STACKTOP = sp;return;
 }
 else if ((label|0) == 12) {
  $38 = ___cxa_find_matching_catch_2()|0;
  $39 = tempRet0;
  $40 = HEAP8[$9>>0]|0;
  $41 = ($40<<24>>24)<(0);
  if ($41) {
   $42 = HEAP32[$3>>2]|0;
   __ZdlPv($42);
  }
  $$0 = $38;$$025 = $39;
  ___resumeException($$0|0);
  // unreachable;
 }
 else if ((label|0) == 36) {
  $118 = ___cxa_find_matching_catch_2()|0;
  $119 = tempRet0;
  $120 = HEAP8[$12>>0]|0;
  $121 = ($120<<24>>24)<(0);
  if ($121) {
   $122 = HEAP32[$4>>2]|0;
   __ZdlPv($122);
  }
  $$0 = $118;$$025 = $119;
  ___resumeException($$0|0);
  // unreachable;
 }
}
function __ZNSt3__23mapINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg5State12UniformStackENS_4lessIS6_EENS4_INS_4pairIKS6_S9_EEEEEixERSD_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$014 = 0, $$pre$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = (__ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg5State12UniformStackEEENS_19__map_value_compareIS7_SB_NS_4lessIS7_EELb1EEENS5_ISB_EEE12__find_equalIS7_EERPNS_16__tree_node_baseIPvEERPNS_15__tree_end_nodeISM_EERKT_($0,$2,$1)|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if (!($5)) {
  $$014 = $4;
  $28 = ((($$014)) + 28|0);
  STACKTOP = sp;return ($28|0);
 }
 $6 = (__Znwj(40)|0);
 $7 = ((($6)) + 16|0);
 __THREW__ = 0;
 invoke_vii(3457,($7|0),($1|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $10 = ___cxa_find_matching_catch_2()|0;
  $11 = tempRet0;
  __ZdlPv($6);
  ___resumeException($10|0);
  // unreachable;
 }
 $12 = ((($6)) + 28|0);
 HEAP32[$12>>2] = 0;
 $13 = ((($6)) + 32|0);
 HEAP32[$13>>2] = 0;
 $14 = ((($6)) + 36|0);
 HEAP32[$14>>2] = 0;
 $15 = HEAP32[$2>>2]|0;
 HEAP32[$6>>2] = 0;
 $16 = ((($6)) + 4|0);
 HEAP32[$16>>2] = 0;
 $17 = ((($6)) + 8|0);
 HEAP32[$17>>2] = $15;
 HEAP32[$3>>2] = $6;
 $18 = HEAP32[$0>>2]|0;
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)==(0|0);
 if ($20) {
  $24 = $6;
 } else {
  $21 = $19;
  HEAP32[$0>>2] = $21;
  $$pre$i = HEAP32[$3>>2]|0;
  $24 = $$pre$i;
 }
 $22 = ((($0)) + 4|0);
 $23 = HEAP32[$22>>2]|0;
 __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($23,$24);
 $25 = ((($0)) + 8|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (($26) + 1)|0;
 HEAP32[$25>>2] = $27;
 $$014 = $6;
 $28 = ((($$014)) + 28|0);
 STACKTOP = sp;return ($28|0);
}
function __ZNSt3__26vectorINS_4pairIPKN3osg7UniformEjEENS_9allocatorIS6_EEE21__push_back_slow_pathIKS6_EEvRT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 3;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(536870911);
 if ($8) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $9 = ((($0)) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) - ($4))|0;
 $12 = $11 >> 3;
 $13 = ($12>>>0)<(268435455);
 $14 = $11 >> 2;
 $15 = ($14>>>0)<($7>>>0);
 $$sroa$speculated$i = $15 ? $7 : $14;
 $$sroa$speculated$$i = $13 ? $$sroa$speculated$i : 536870911;
 $16 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($16) {
   $26 = 0;
  } else {
   $17 = ($$sroa$speculated$$i>>>0)>(536870911);
   if (!($17)) {
    $23 = $$sroa$speculated$$i << 3;
    $24 = (__Znwj($23)|0);
    $26 = $24;
    break;
   }
   $18 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($18|0),(204840|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if ($20) {
    $21 = ___cxa_find_matching_catch_2()|0;
    $22 = tempRet0;
    ___cxa_free_exception(($18|0));
    ___resumeException($21|0);
    // unreachable;
   } else {
    HEAP32[$18>>2] = (99824);
    ___cxa_throw(($18|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $25 = (($26) + ($6<<3)|0);
 $27 = (($26) + ($$sroa$speculated$$i<<3)|0);
 $28 = $27;
 $29 = $1;
 $30 = $29;
 $31 = HEAP32[$30>>2]|0;
 $32 = (($29) + 4)|0;
 $33 = $32;
 $34 = HEAP32[$33>>2]|0;
 $35 = $25;
 $36 = $35;
 HEAP32[$36>>2] = $31;
 $37 = (($35) + 4)|0;
 $38 = $37;
 HEAP32[$38>>2] = $34;
 $39 = ((($25)) + 8|0);
 $40 = $39;
 $41 = (0 - ($6))|0;
 $42 = (($25) + ($41<<3)|0);
 $43 = $42;
 $44 = ($5|0)>(0);
 if ($44) {
  $45 = $4;
  _memcpy(($42|0),($45|0),($5|0))|0;
 }
 HEAP32[$0>>2] = $43;
 HEAP32[$2>>2] = $40;
 HEAP32[$9>>2] = $28;
 $46 = ($4|0)==(0);
 if ($46) {
  return;
 }
 $47 = $4;
 __ZdlPv($47);
 return;
}
function __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg5State12UniformStackEEENS_19__map_value_compareIS7_SB_NS_4lessIS7_EELb1EEENS5_ISB_EEE12__find_equalIS7_EERPNS_16__tree_node_baseIPvEERPNS_15__tree_end_nodeISM_EERKT_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$0$ph = 0, $$024 = 0, $$025 = 0, $$in = 0, $$sroa$speculated$i$i$i$i$i = 0, $$sroa$speculated$i$i$i$i$i26 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  HEAP32[$1>>2] = $3;
  $$025 = $3;
  return ($$025|0);
 }
 $6 = ((($0)) + 4|0);
 $7 = ((($2)) + 11|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = ($8<<24>>24)<(0);
 $10 = ((($2)) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $8&255;
 $13 = $9 ? $11 : $12;
 $14 = HEAP32[$2>>2]|0;
 $15 = $9 ? $14 : $2;
 $$0 = $6;$$024 = $4;
 while(1) {
  $16 = ((($$024)) + 16|0);
  $17 = ((($16)) + 11|0);
  $18 = HEAP8[$17>>0]|0;
  $19 = ($18<<24>>24)<(0);
  $20 = ((($$024)) + 20|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = $18&255;
  $23 = $19 ? $21 : $22;
  $24 = ($23>>>0)<($13>>>0);
  $$sroa$speculated$i$i$i$i$i26 = $24 ? $23 : $13;
  $25 = ($$sroa$speculated$i$i$i$i$i26|0)==(0);
  if ($25) {
   label = 6;
  } else {
   $26 = HEAP32[$16>>2]|0;
   $27 = $19 ? $26 : $16;
   $28 = (_memcmp($15,$27,$$sroa$speculated$i$i$i$i$i26)|0);
   $29 = ($28|0)==(0);
   if ($29) {
    label = 6;
   } else {
    $31 = ($28|0)<(0);
    if ($31) {
     label = 8;
    } else {
     label = 10;
    }
   }
  }
  if ((label|0) == 6) {
   label = 0;
   $30 = ($13>>>0)<($23>>>0);
   if ($30) {
    label = 8;
   } else {
    label = 10;
   }
  }
  if ((label|0) == 8) {
   label = 0;
   $32 = HEAP32[$$024>>2]|0;
   $33 = ($32|0)==(0|0);
   if ($33) {
    label = 9;
    break;
   } else {
    $$0$ph = $$024;$$in = $32;
   }
  }
  else if ((label|0) == 10) {
   label = 0;
   $34 = ($13>>>0)<($23>>>0);
   $$sroa$speculated$i$i$i$i$i = $34 ? $13 : $23;
   $35 = ($$sroa$speculated$i$i$i$i$i|0)==(0);
   if ($35) {
    label = 12;
   } else {
    $36 = HEAP32[$16>>2]|0;
    $37 = $19 ? $36 : $16;
    $38 = (_memcmp($37,$15,$$sroa$speculated$i$i$i$i$i)|0);
    $39 = ($38|0)==(0);
    if ($39) {
     label = 12;
    } else {
     $40 = ($38|0)<(0);
     if (!($40)) {
      label = 16;
      break;
     }
    }
   }
   if ((label|0) == 12) {
    label = 0;
    if (!($24)) {
     label = 16;
     break;
    }
   }
   $41 = ((($$024)) + 4|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = ($42|0)==(0|0);
   if ($43) {
    label = 15;
    break;
   } else {
    $$0$ph = $41;$$in = $42;
   }
  }
  $$0 = $$0$ph;$$024 = $$in;
 }
 if ((label|0) == 9) {
  HEAP32[$1>>2] = $$024;
  $$025 = $$024;
  return ($$025|0);
 }
 else if ((label|0) == 15) {
  HEAP32[$1>>2] = $$024;
  $$025 = $41;
  return ($$025|0);
 }
 else if ((label|0) == 16) {
  HEAP32[$1>>2] = $$024;
  $$025 = $$0;
  return ($$025|0);
 }
 return (0)|0;
}
function __ZNSt3__26vectorINS_4pairIPKN3osg14StateAttributeEjEENS_9allocatorIS6_EEE21__push_back_slow_pathIKS6_EEvRT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 3;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(536870911);
 if ($8) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $9 = ((($0)) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) - ($4))|0;
 $12 = $11 >> 3;
 $13 = ($12>>>0)<(268435455);
 $14 = $11 >> 2;
 $15 = ($14>>>0)<($7>>>0);
 $$sroa$speculated$i = $15 ? $7 : $14;
 $$sroa$speculated$$i = $13 ? $$sroa$speculated$i : 536870911;
 $16 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($16) {
   $26 = 0;
  } else {
   $17 = ($$sroa$speculated$$i>>>0)>(536870911);
   if (!($17)) {
    $23 = $$sroa$speculated$$i << 3;
    $24 = (__Znwj($23)|0);
    $26 = $24;
    break;
   }
   $18 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($18|0),(204840|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if ($20) {
    $21 = ___cxa_find_matching_catch_2()|0;
    $22 = tempRet0;
    ___cxa_free_exception(($18|0));
    ___resumeException($21|0);
    // unreachable;
   } else {
    HEAP32[$18>>2] = (99824);
    ___cxa_throw(($18|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $25 = (($26) + ($6<<3)|0);
 $27 = (($26) + ($$sroa$speculated$$i<<3)|0);
 $28 = $27;
 $29 = $1;
 $30 = $29;
 $31 = HEAP32[$30>>2]|0;
 $32 = (($29) + 4)|0;
 $33 = $32;
 $34 = HEAP32[$33>>2]|0;
 $35 = $25;
 $36 = $35;
 HEAP32[$36>>2] = $31;
 $37 = (($35) + 4)|0;
 $38 = $37;
 HEAP32[$38>>2] = $34;
 $39 = ((($25)) + 8|0);
 $40 = $39;
 $41 = (0 - ($6))|0;
 $42 = (($25) + ($41<<3)|0);
 $43 = $42;
 $44 = ($5|0)>(0);
 if ($44) {
  $45 = $4;
  _memcpy(($42|0),($45|0),($5|0))|0;
 }
 HEAP32[$0>>2] = $43;
 HEAP32[$2>>2] = $40;
 HEAP32[$9>>2] = $28;
 $46 = ($4|0)==(0);
 if ($46) {
  return;
 }
 $47 = $4;
 __ZdlPv($47);
 return;
}
function __ZN3osg5State15popAllStateSetsEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 668|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 672|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2|0)==($4|0);
 if (!($5)) {
  while(1) {
   __ZN3osg5State11popStateSetEv($0);
   $6 = HEAP32[$1>>2]|0;
   $7 = HEAP32[$3>>2]|0;
   $8 = ($6|0)==($7|0);
   if ($8) {
    break;
   }
  }
 }
 $9 = ((($0)) + 172|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if (!($11)) {
  $12 = ((($0)) + 164|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($10|0)==($13|0);
  if (!($14)) {
   HEAP32[$9>>2] = $13;
   $15 = ($13|0)==(0|0);
   if (!($15)) {
    $16 = ((($13)) + 8|0);
    $17 = HEAP32[$16>>2]|0;HEAP32[$16>>2] = (($17+1)|0);
   }
   $18 = ((($10)) + 8|0);
   $19 = HEAP32[$18>>2]|0;HEAP32[$18>>2] = (($19-1)|0);
   $20 = ($19|0)==(1);
   if ($20) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($10,1,1);
   }
  }
  $21 = ((($0)) + 184|0);
  $22 = HEAP8[$21>>0]|0;
  $23 = ($22<<24>>24)==(0);
  if (!($23)) {
   $24 = ((($0)) + 192|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = ($25|0)==(0|0);
   if (!($26)) {
    $27 = HEAP32[$9>>2]|0;
    $28 = ((($27)) + 32|0);
    (__ZN3osg7Uniform3setERKNS_7MatrixdE($25,$28)|0);
   }
   __ZN3osg5State42updateModelViewAndProjectionMatrixUniformsEv($0);
  }
 }
 $29 = ((($0)) + 176|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ($30|0)==(0|0);
 if ($31) {
  $49 = ((($0)) + 664|0);
  HEAP32[$49>>2] = 0;
  return;
 }
 $32 = ((($0)) + 164|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ($30|0)==($33|0);
 if (!($34)) {
  HEAP32[$29>>2] = $33;
  $35 = ($33|0)==(0|0);
  if (!($35)) {
   $36 = ((($33)) + 8|0);
   $37 = HEAP32[$36>>2]|0;HEAP32[$36>>2] = (($37+1)|0);
  }
  $38 = ((($30)) + 8|0);
  $39 = HEAP32[$38>>2]|0;HEAP32[$38>>2] = (($39-1)|0);
  $40 = ($39|0)==(1);
  if ($40) {
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($30,1,1);
  }
 }
 $41 = ((($0)) + 184|0);
 $42 = HEAP8[$41>>0]|0;
 $43 = ($42<<24>>24)==(0);
 if ($43) {
  $49 = ((($0)) + 664|0);
  HEAP32[$49>>2] = 0;
  return;
 }
 $44 = ((($0)) + 188|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = ($45|0)==(0|0);
 if (!($46)) {
  $47 = HEAP32[$29>>2]|0;
  $48 = ((($47)) + 32|0);
  (__ZN3osg7Uniform3setERKNS_7MatrixdE($45,$48)|0);
 }
 __ZN3osg5State42updateModelViewAndProjectionMatrixUniformsEv($0);
 $49 = ((($0)) + 664|0);
 HEAP32[$49>>2] = 0;
 return;
}
function __ZN3osg5State11popStateSetEv($0) {
 $0 = $0|0;
 var $$0$i$i$i$i$i = 0, $$029 = 0, $$128 = 0, $$pre = 0, $$pre33 = 0, $$pre34 = 0, $$sroa$08$0$be$i = 0, $$sroa$08$012$i = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $scevgep5$i$i$i$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 668|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 672|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2|0)==($4|0);
 if ($5) {
  return;
 }
 $6 = ((($4)) + -4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if ($8) {
  $111 = $4;
 } else {
  $9 = ((($0)) + 576|0);
  $10 = ((($7)) + 44|0);
  __ZN3osg5State11popModeListERNSt3__23mapIjNS0_9ModeStackENS1_4lessIjEENS1_9allocatorINS1_4pairIKjS3_EEEEEERKNS2_IjjS5_NS6_INS7_IS8_jEEEEEE($0,$9,$10);
  $11 = ((($7)) + 68|0);
  $12 = ((($7)) + 72|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = HEAP32[$11>>2]|0;
  $15 = ($13|0)==($14|0);
  if (!($15)) {
   $16 = ((($0)) + 640|0);
   $17 = ((($0)) + 644|0);
   $$029 = 0;
   while(1) {
    $18 = HEAP32[$17>>2]|0;
    $19 = HEAP32[$16>>2]|0;
    $20 = (($18) - ($19))|0;
    $21 = (($20|0) / 12)&-1;
    $22 = ($21>>>0)>($$029>>>0);
    $$pre34 = (($$029) + 1)|0;
    do {
     if (!($22)) {
      $23 = ($$pre34>>>0)>($21>>>0);
      $24 = $19;
      $25 = $18;
      if ($23) {
       $26 = (($$pre34) - ($21))|0;
       __ZNSt3__26vectorINS_3mapIjN3osg5State9ModeStackENS_4lessIjEENS_9allocatorINS_4pairIKjS4_EEEEEENS7_ISC_EEE8__appendEj($16,$26);
       break;
      }
      $27 = ($$pre34>>>0)<($21>>>0);
      if ($27) {
       $28 = (($24) + (($$pre34*12)|0)|0);
       $29 = ($25|0)==($28|0);
       if (!($29)) {
        $31 = $25;
        while(1) {
         $30 = ((($31)) + -12|0);
         HEAP32[$17>>2] = $30;
         $32 = ((($31)) + -8|0);
         $33 = HEAP32[$32>>2]|0;
         __ZNSt3__26__treeINS_12__value_typeIjN3osg5State9ModeStackEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($30,$33);
         $34 = HEAP32[$17>>2]|0;
         $35 = ($34|0)==($28|0);
         if ($35) {
          break;
         } else {
          $31 = $34;
         }
        }
       }
      }
     }
    } while(0);
    $36 = HEAP32[$16>>2]|0;
    $37 = (($36) + (($$029*12)|0)|0);
    $38 = HEAP32[$11>>2]|0;
    $39 = (($38) + (($$029*12)|0)|0);
    __ZN3osg5State11popModeListERNSt3__23mapIjNS0_9ModeStackENS1_4lessIjEENS1_9allocatorINS1_4pairIKjS3_EEEEEERKNS2_IjjS5_NS6_INS7_IS8_jEEEEEE($0,$37,$39);
    $40 = HEAP32[$12>>2]|0;
    $41 = HEAP32[$11>>2]|0;
    $42 = (($40) - ($41))|0;
    $43 = (($42|0) / 12)&-1;
    $44 = ($$pre34>>>0)<($43>>>0);
    if ($44) {
     $$029 = $$pre34;
    } else {
     break;
    }
   }
  }
  $45 = ((($0)) + 588|0);
  $46 = ((($7)) + 56|0);
  __ZN3osg5State16popAttributeListERNSt3__23mapINS1_4pairINS_14StateAttribute4TypeEjEENS0_14AttributeStackENS1_4lessIS6_EENS1_9allocatorINS3_IKS6_S7_EEEEEERKNS2_IS6_NS3_INS_7ref_ptrIS4_EEjEES9_NSA_INS3_ISB_SI_EEEEEE($0,$45,$46);
  $47 = ((($7)) + 80|0);
  $48 = ((($7)) + 84|0);
  $49 = HEAP32[$48>>2]|0;
  $50 = HEAP32[$47>>2]|0;
  $51 = ($49|0)==($50|0);
  if (!($51)) {
   $52 = ((($0)) + 652|0);
   $53 = ((($0)) + 656|0);
   $$128 = 0;
   while(1) {
    $54 = HEAP32[$53>>2]|0;
    $55 = HEAP32[$52>>2]|0;
    $56 = (($54) - ($55))|0;
    $57 = (($56|0) / 12)&-1;
    $58 = ($57>>>0)>($$128>>>0);
    $$pre33 = (($$128) + 1)|0;
    do {
     if (!($58)) {
      $59 = ($$pre33>>>0)>($57>>>0);
      $60 = $55;
      $61 = $54;
      if ($59) {
       $62 = (($$pre33) - ($57))|0;
       __ZNSt3__26vectorINS_3mapINS_4pairIN3osg14StateAttribute4TypeEjEENS3_5State14AttributeStackENS_4lessIS6_EENS_9allocatorINS2_IKS6_S8_EEEEEENSB_ISF_EEE8__appendEj($52,$62);
       break;
      }
      $63 = ($$pre33>>>0)<($57>>>0);
      if ($63) {
       $64 = (($60) + (($$pre33*12)|0)|0);
       $65 = ($61|0)==($64|0);
       if (!($65)) {
        $67 = $61;
        while(1) {
         $66 = ((($67)) + -12|0);
         HEAP32[$53>>2] = $66;
         $68 = ((($67)) + -8|0);
         $69 = HEAP32[$68>>2]|0;
         __ZNSt3__26__treeINS_12__value_typeINS_4pairIN3osg14StateAttribute4TypeEjEENS3_5State14AttributeStackEEENS_19__map_value_compareIS6_S9_NS_4lessIS6_EELb1EEENS_9allocatorIS9_EEE7destroyEPNS_11__tree_nodeIS9_PvEE($66,$69);
         $70 = HEAP32[$53>>2]|0;
         $71 = ($70|0)==($64|0);
         if ($71) {
          break;
         } else {
          $67 = $70;
         }
        }
       }
      }
     }
    } while(0);
    $72 = HEAP32[$52>>2]|0;
    $73 = (($72) + (($$128*12)|0)|0);
    $74 = HEAP32[$47>>2]|0;
    $75 = (($74) + (($$128*12)|0)|0);
    __ZN3osg5State16popAttributeListERNSt3__23mapINS1_4pairINS_14StateAttribute4TypeEjEENS0_14AttributeStackENS1_4lessIS6_EENS1_9allocatorINS3_IKS6_S7_EEEEEERKNS2_IS6_NS3_INS_7ref_ptrIS4_EEjEES9_NSA_INS3_ISB_SI_EEEEEE($0,$73,$75);
    $76 = HEAP32[$48>>2]|0;
    $77 = HEAP32[$47>>2]|0;
    $78 = (($76) - ($77))|0;
    $79 = (($78|0) / 12)&-1;
    $80 = ($$pre33>>>0)<($79>>>0);
    if ($80) {
     $$128 = $$pre33;
    } else {
     break;
    }
   }
  }
  $81 = ((($0)) + 600|0);
  $82 = ((($7)) + 92|0);
  $83 = HEAP32[$82>>2]|0;
  $84 = ((($7)) + 96|0);
  $85 = ($83|0)==($84|0);
  if (!($85)) {
   $$sroa$08$012$i = $83;
   while(1) {
    $86 = ((($$sroa$08$012$i)) + 16|0);
    $87 = (__ZNSt3__23mapINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg5State12UniformStackENS_4lessIS6_EENS4_INS_4pairIKS6_S9_EEEEEixERSD_($81,$86)|0);
    $88 = HEAP32[$87>>2]|0;
    $89 = ((($87)) + 4|0);
    $90 = HEAP32[$89>>2]|0;
    $91 = ($88|0)==($90|0);
    if (!($91)) {
     $scevgep5$i$i$i$i = ((($90)) + -8|0);
     HEAP32[$89>>2] = $scevgep5$i$i$i$i;
    }
    $92 = ((($$sroa$08$012$i)) + 4|0);
    $93 = HEAP32[$92>>2]|0;
    $94 = ($93|0)==(0|0);
    if ($94) {
     $95 = ((($$sroa$08$012$i)) + 8|0);
     $96 = HEAP32[$95>>2]|0;
     $97 = HEAP32[$96>>2]|0;
     $98 = ($97|0)==($$sroa$08$012$i|0);
     if ($98) {
      $$sroa$08$0$be$i = $96;
     } else {
      $103 = $95;
      while(1) {
       $102 = HEAP32[$103>>2]|0;
       $104 = ((($102)) + 8|0);
       $105 = HEAP32[$104>>2]|0;
       $106 = HEAP32[$105>>2]|0;
       $107 = ($106|0)==($102|0);
       if ($107) {
        $$sroa$08$0$be$i = $105;
        break;
       } else {
        $103 = $104;
       }
      }
     }
    } else {
     $$0$i$i$i$i$i = $93;
     while(1) {
      $100 = HEAP32[$$0$i$i$i$i$i>>2]|0;
      $101 = ($100|0)==(0|0);
      if ($101) {
       break;
      } else {
       $$0$i$i$i$i$i = $100;
      }
     }
     $$sroa$08$0$be$i = $$0$i$i$i$i$i;
    }
    $99 = ($$sroa$08$0$be$i|0)==($84|0);
    if ($99) {
     break;
    } else {
     $$sroa$08$012$i = $$sroa$08$0$be$i;
    }
   }
  }
  $108 = ((($0)) + 612|0);
  $109 = ((($7)) + 104|0);
  __ZN3osg5State13popDefineListERNS0_9DefineMapERKNSt3__23mapINS3_12basic_stringIcNS3_11char_traitsIcEENS3_9allocatorIcEEEENS3_4pairISA_jEENS3_4lessISA_EENS8_INSB_IKSA_SC_EEEEEE($0,$108,$109);
  $$pre = HEAP32[$3>>2]|0;
  $111 = $$pre;
 }
 $110 = ((($111)) + -4|0);
 HEAP32[$3>>2] = $110;
 return;
}
function __ZN3osg5State42updateModelViewAndProjectionMatrixUniformsEv($0) {
 $0 = $0|0;
 var $$1 = 0, $$13 = 0, $$2 = 0, $$24 = 0, $$3 = 0, $$35 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0.0, $102 = 0.0, $103 = 0, $104 = 0.0, $105 = 0.0, $106 = 0, $107 = 0.0, $108 = 0.0, $109 = 0, $11 = 0, $110 = 0.0;
 var $111 = 0.0, $112 = 0, $113 = 0.0, $114 = 0.0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0.0, $25 = 0, $26 = 0.0, $27 = 0, $28 = 0, $29 = 0.0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0.0, $33 = 0, $34 = 0, $35 = 0.0, $36 = 0, $37 = 0, $38 = 0.0, $39 = 0, $4 = 0, $40 = 0, $41 = 0.0, $42 = 0, $43 = 0, $44 = 0.0, $45 = 0, $46 = 0, $47 = 0.0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0.0, $51 = 0, $52 = 0, $53 = 0.0, $54 = 0, $55 = 0, $56 = 0.0, $57 = 0, $58 = 0, $59 = 0.0, $6 = 0, $60 = 0, $61 = 0, $62 = 0.0, $63 = 0, $64 = 0, $65 = 0.0;
 var $66 = 0, $67 = 0, $68 = 0.0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0.0, $75 = 0, $76 = 0, $77 = 0.0, $78 = 0, $79 = 0, $8 = 0, $80 = 0.0, $81 = 0, $82 = 0, $83 = 0.0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0.0, $9 = 0, $90 = 0.0, $91 = 0, $92 = 0.0, $93 = 0.0, $94 = 0, $95 = 0.0, $96 = 0.0, $97 = 0, $98 = 0.0, $99 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 432|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(432|0);
 $1 = sp + 256|0;
 $2 = sp + 128|0;
 $3 = sp;
 $4 = sp + 384|0;
 $5 = ((($0)) + 196|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 do {
  if (!($7)) {
   $8 = ((($0)) + 176|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = ((($9)) + 32|0);
   $11 = ((($0)) + 172|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = ((($12)) + 32|0);
   __ZN3osg7Matrixd12makeIdentityEv($1);
   __ZN3osg7Matrixd4multERKS0_S2_($1,$10,$13);
   __THREW__ = 0;
   (invoke_iii(3608,($6|0),($1|0))|0);
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if (!($15)) {
    break;
   }
   $16 = ___cxa_find_matching_catch_2()|0;
   $17 = tempRet0;
   $$3 = $17;$$35 = $16;
   ___resumeException($$35|0);
   // unreachable;
  }
 } while(0);
 $18 = ((($0)) + 200|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)==(0|0);
 if ($20) {
  STACKTOP = sp;return;
 }
 $21 = ((($0)) + 176|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ((($22)) + 32|0);
 $24 = +HEAPF64[$23>>3];
 HEAPF64[$2>>3] = $24;
 $25 = ((($22)) + 40|0);
 $26 = +HEAPF64[$25>>3];
 $27 = ((($2)) + 8|0);
 HEAPF64[$27>>3] = $26;
 $28 = ((($22)) + 48|0);
 $29 = +HEAPF64[$28>>3];
 $30 = ((($2)) + 16|0);
 HEAPF64[$30>>3] = $29;
 $31 = ((($22)) + 56|0);
 $32 = +HEAPF64[$31>>3];
 $33 = ((($2)) + 24|0);
 HEAPF64[$33>>3] = $32;
 $34 = ((($22)) + 64|0);
 $35 = +HEAPF64[$34>>3];
 $36 = ((($2)) + 32|0);
 HEAPF64[$36>>3] = $35;
 $37 = ((($22)) + 72|0);
 $38 = +HEAPF64[$37>>3];
 $39 = ((($2)) + 40|0);
 HEAPF64[$39>>3] = $38;
 $40 = ((($22)) + 80|0);
 $41 = +HEAPF64[$40>>3];
 $42 = ((($2)) + 48|0);
 HEAPF64[$42>>3] = $41;
 $43 = ((($22)) + 88|0);
 $44 = +HEAPF64[$43>>3];
 $45 = ((($2)) + 56|0);
 HEAPF64[$45>>3] = $44;
 $46 = ((($22)) + 96|0);
 $47 = +HEAPF64[$46>>3];
 $48 = ((($2)) + 64|0);
 HEAPF64[$48>>3] = $47;
 $49 = ((($22)) + 104|0);
 $50 = +HEAPF64[$49>>3];
 $51 = ((($2)) + 72|0);
 HEAPF64[$51>>3] = $50;
 $52 = ((($22)) + 112|0);
 $53 = +HEAPF64[$52>>3];
 $54 = ((($2)) + 80|0);
 HEAPF64[$54>>3] = $53;
 $55 = ((($22)) + 120|0);
 $56 = +HEAPF64[$55>>3];
 $57 = ((($2)) + 88|0);
 HEAPF64[$57>>3] = $56;
 $58 = ((($22)) + 128|0);
 $59 = +HEAPF64[$58>>3];
 $60 = ((($2)) + 96|0);
 HEAPF64[$60>>3] = $59;
 $61 = ((($22)) + 136|0);
 $62 = +HEAPF64[$61>>3];
 $63 = ((($2)) + 104|0);
 HEAPF64[$63>>3] = $62;
 $64 = ((($22)) + 144|0);
 $65 = +HEAPF64[$64>>3];
 $66 = ((($2)) + 112|0);
 HEAPF64[$66>>3] = $65;
 $67 = ((($22)) + 152|0);
 $68 = +HEAPF64[$67>>3];
 $69 = ((($2)) + 120|0);
 HEAPF64[$69>>3] = $68;
 __THREW__ = 0;
 invoke_viddd(3930,($2|0),0.0,0.0,0.0);
 $70 = __THREW__; __THREW__ = 0;
 $71 = $70&1;
 if ($71) {
  label = 16;
 } else {
  __THREW__ = 0;
  invoke_vi(3299,($3|0));
  $72 = __THREW__; __THREW__ = 0;
  $73 = $72&1;
  if ($73) {
   label = 16;
  } else {
   $74 = +HEAPF64[$33>>3];
   $75 = $74 == 0.0;
   if ($75) {
    $76 = ((($2)) + 56|0);
    $77 = +HEAPF64[$76>>3];
    $78 = $77 == 0.0;
    if ($78) {
     $79 = ((($2)) + 88|0);
     $80 = +HEAPF64[$79>>3];
     $81 = $80 == 0.0;
     if ($81) {
      $82 = ((($2)) + 120|0);
      $83 = +HEAPF64[$82>>3];
      $84 = $83 == 1.0;
      if ($84) {
       __THREW__ = 0;
       (invoke_iii(3303,($3|0),($2|0))|0);
       $85 = __THREW__; __THREW__ = 0;
       $86 = $85&1;
       if ($86) {
        label = 17;
       } else {
        label = 14;
       }
      } else {
       label = 13;
      }
     } else {
      label = 13;
     }
    } else {
     label = 13;
    }
   } else {
    label = 13;
   }
   if ((label|0) == 13) {
    __THREW__ = 0;
    (invoke_iii(3304,($3|0),($2|0))|0);
    $87 = __THREW__; __THREW__ = 0;
    $88 = $87&1;
    if ($88) {
     label = 17;
    } else {
     label = 14;
    }
   }
   do {
    if ((label|0) == 14) {
     $89 = +HEAPF64[$3>>3];
     $90 = $89;
     $91 = ((($3)) + 32|0);
     $92 = +HEAPF64[$91>>3];
     $93 = $92;
     $94 = ((($3)) + 64|0);
     $95 = +HEAPF64[$94>>3];
     $96 = $95;
     $97 = ((($3)) + 8|0);
     $98 = +HEAPF64[$97>>3];
     $99 = $98;
     $100 = ((($3)) + 40|0);
     $101 = +HEAPF64[$100>>3];
     $102 = $101;
     $103 = ((($3)) + 72|0);
     $104 = +HEAPF64[$103>>3];
     $105 = $104;
     $106 = ((($3)) + 16|0);
     $107 = +HEAPF64[$106>>3];
     $108 = $107;
     $109 = ((($3)) + 48|0);
     $110 = +HEAPF64[$109>>3];
     $111 = $110;
     $112 = ((($3)) + 80|0);
     $113 = +HEAPF64[$112>>3];
     $114 = $113;
     HEAPF32[$4>>2] = $90;
     $115 = ((($4)) + 4|0);
     HEAPF32[$115>>2] = $93;
     $116 = ((($4)) + 8|0);
     HEAPF32[$116>>2] = $96;
     $117 = ((($4)) + 12|0);
     HEAPF32[$117>>2] = $99;
     $118 = ((($4)) + 16|0);
     HEAPF32[$118>>2] = $102;
     $119 = ((($4)) + 20|0);
     HEAPF32[$119>>2] = $105;
     $120 = ((($4)) + 24|0);
     HEAPF32[$120>>2] = $108;
     $121 = ((($4)) + 28|0);
     HEAPF32[$121>>2] = $111;
     $122 = ((($4)) + 32|0);
     HEAPF32[$122>>2] = $114;
     $123 = HEAP32[$18>>2]|0;
     __THREW__ = 0;
     (invoke_iii(3931,($123|0),($4|0))|0);
     $124 = __THREW__; __THREW__ = 0;
     $125 = $124&1;
     if ($125) {
      $130 = ___cxa_find_matching_catch_2()|0;
      $131 = tempRet0;
      $$1 = $131;$$13 = $130;
      break;
     }
     STACKTOP = sp;return;
    }
    else if ((label|0) == 17) {
     $128 = ___cxa_find_matching_catch_2()|0;
     $129 = tempRet0;
     $$1 = $129;$$13 = $128;
    }
   } while(0);
   $$2 = $$1;$$24 = $$13;
  }
 }
 if ((label|0) == 16) {
  $126 = ___cxa_find_matching_catch_2()|0;
  $127 = tempRet0;
  $$2 = $127;$$24 = $126;
 }
 $$3 = $$2;$$35 = $$24;
 ___resumeException($$35|0);
 // unreachable;
}
function __ZN3osg5State11popModeListERNSt3__23mapIjNS0_9ModeStackENS1_4lessIjEENS1_9allocatorINS1_4pairIKjS3_EEEEEERKNS2_IjjS5_NS6_INS7_IS8_jEEEEEE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$i$i = 0, $$0$i$i$i$i = 0, $$0$ph$i$i = 0, $$014$i = 0, $$024$i$i = 0, $$025$i$i = 0, $$025$i65$i = 0, $$049$i = 0, $$04964$i = 0, $$in$i$i = 0, $$pre$i$i = 0, $$sroa$09$0$be = 0, $$sroa$09$022 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($2)) + 4|0);
 $5 = ($3|0)==($4|0);
 if ($5) {
  return;
 }
 $6 = ((($1)) + 4|0);
 $7 = ((($1)) + 4|0);
 $8 = ((($1)) + 8|0);
 $$sroa$09$022 = $3;
 while(1) {
  $9 = ((($$sroa$09$022)) + 16|0);
  $10 = HEAP32[$6>>2]|0;
  $11 = ($10|0)==(0|0);
  do {
   if ($11) {
    $$025$i$i = $6;$$049$i = $6;$22 = $10;
    label = 14;
   } else {
    $12 = HEAP32[$9>>2]|0;
    $$0$i$i = $7;$$024$i$i = $10;$67 = $10;
    while(1) {
     $13 = ((($$024$i$i)) + 16|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = ($12>>>0)<($14>>>0);
     if ($15) {
      $16 = HEAP32[$$024$i$i>>2]|0;
      $17 = ($16|0)==(0|0);
      if ($17) {
       label = 9;
       break;
      } else {
       $$0$ph$i$i = $$024$i$i;$$in$i$i = $16;
      }
     } else {
      $18 = ($14>>>0)<($12>>>0);
      if (!($18)) {
       label = 13;
       break;
      }
      $19 = ((($$024$i$i)) + 4|0);
      $20 = HEAP32[$19>>2]|0;
      $21 = ($20|0)==(0|0);
      if ($21) {
       label = 12;
       break;
      } else {
       $$0$ph$i$i = $19;$$in$i$i = $20;
      }
     }
     $$0$i$i = $$0$ph$i$i;$$024$i$i = $$in$i$i;$67 = $$in$i$i;
    }
    if ((label|0) == 9) {
     label = 0;
     $$025$i65$i = $$024$i$i;$$04964$i = $$024$i$i;
     label = 15;
     break;
    }
    else if ((label|0) == 12) {
     label = 0;
     $$025$i65$i = $19;$$04964$i = $$024$i$i;
     label = 15;
     break;
    }
    else if ((label|0) == 13) {
     label = 0;
     $$025$i$i = $$0$i$i;$$049$i = $$024$i$i;$22 = $67;
     label = 14;
     break;
    }
   }
  } while(0);
  if ((label|0) == 14) {
   label = 0;
   $23 = ($22|0)==(0|0);
   if ($23) {
    $$025$i65$i = $$025$i$i;$$04964$i = $$049$i;
    label = 15;
   } else {
    $$014$i = $22;
   }
  }
  if ((label|0) == 15) {
   label = 0;
   $24 = (__Znwj(36)|0);
   $25 = ((($24)) + 16|0);
   $26 = HEAP32[$9>>2]|0;
   HEAP32[$25>>2] = $26;
   $27 = ((($24)) + 20|0);
   $28 = ((($24)) + 24|0);
   HEAP32[$28>>2] = 0;
   $29 = ((($24)) + 28|0);
   HEAP32[$29>>2] = 0;
   $30 = ((($24)) + 32|0);
   HEAP32[$30>>2] = 0;
   HEAP8[$27>>0] = 1;
   $31 = ((($24)) + 21|0);
   HEAP8[$31>>0] = 0;
   $32 = ((($24)) + 22|0);
   HEAP8[$32>>0] = 0;
   $33 = ((($24)) + 23|0);
   HEAP8[$33>>0] = 0;
   HEAP32[$24>>2] = 0;
   $34 = ((($24)) + 4|0);
   HEAP32[$34>>2] = 0;
   $35 = ((($24)) + 8|0);
   HEAP32[$35>>2] = $$04964$i;
   HEAP32[$$025$i65$i>>2] = $24;
   $36 = HEAP32[$1>>2]|0;
   $37 = HEAP32[$36>>2]|0;
   $38 = ($37|0)==(0|0);
   if ($38) {
    $41 = $24;
   } else {
    $39 = $37;
    HEAP32[$1>>2] = $39;
    $$pre$i$i = HEAP32[$$025$i65$i>>2]|0;
    $41 = $$pre$i$i;
   }
   $40 = HEAP32[$7>>2]|0;
   __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($40,$41);
   $42 = HEAP32[$8>>2]|0;
   $43 = (($42) + 1)|0;
   HEAP32[$8>>2] = $43;
   $$014$i = $24;
  }
  $44 = ((($$014$i)) + 24|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = ((($$014$i)) + 28|0);
  $47 = HEAP32[$46>>2]|0;
  $48 = ($45|0)==($47|0);
  if (!($48)) {
   $49 = ((($47)) + -4|0);
   HEAP32[$46>>2] = $49;
  }
  $50 = ((($$014$i)) + 21|0);
  HEAP8[$50>>0] = 1;
  $51 = ((($$sroa$09$022)) + 4|0);
  $52 = HEAP32[$51>>2]|0;
  $53 = ($52|0)==(0|0);
  if ($53) {
   $54 = ((($$sroa$09$022)) + 8|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = HEAP32[$55>>2]|0;
   $57 = ($56|0)==($$sroa$09$022|0);
   if ($57) {
    $$sroa$09$0$be = $55;
   } else {
    $62 = $54;
    while(1) {
     $61 = HEAP32[$62>>2]|0;
     $63 = ((($61)) + 8|0);
     $64 = HEAP32[$63>>2]|0;
     $65 = HEAP32[$64>>2]|0;
     $66 = ($65|0)==($61|0);
     if ($66) {
      $$sroa$09$0$be = $64;
      break;
     } else {
      $62 = $63;
     }
    }
   }
  } else {
   $$0$i$i$i$i = $52;
   while(1) {
    $59 = HEAP32[$$0$i$i$i$i>>2]|0;
    $60 = ($59|0)==(0|0);
    if ($60) {
     break;
    } else {
     $$0$i$i$i$i = $59;
    }
   }
   $$sroa$09$0$be = $$0$i$i$i$i;
  }
  $58 = ($$sroa$09$0$be|0)==($4|0);
  if ($58) {
   break;
  } else {
   $$sroa$09$022 = $$sroa$09$0$be;
  }
 }
 return;
}
function __ZN3osg5State16popAttributeListERNSt3__23mapINS1_4pairINS_14StateAttribute4TypeEjEENS0_14AttributeStackENS1_4lessIS6_EENS1_9allocatorINS3_IKS6_S7_EEEEEERKNS2_IS6_NS3_INS_7ref_ptrIS4_EEjEES9_NSA_INS3_ISB_SI_EEEEEE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$i$i = 0, $$0$i$i$i$i = 0, $$0$ph$i$i = 0, $$014$i = 0, $$024$i$i = 0, $$025$i$i = 0, $$025$i68$i = 0, $$052$i = 0, $$05267$i = 0, $$in$i$i = 0, $$pre$i$i = 0, $$sroa$09$0$be = 0, $$sroa$09$022 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $8 = 0, $9 = 0, $scevgep5$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($2)) + 4|0);
 $5 = ($3|0)==($4|0);
 if ($5) {
  return;
 }
 $6 = ((($1)) + 4|0);
 $7 = ((($1)) + 4|0);
 $8 = ((($1)) + 8|0);
 $$sroa$09$022 = $3;
 while(1) {
  $9 = ((($$sroa$09$022)) + 16|0);
  $10 = HEAP32[$6>>2]|0;
  $11 = ($10|0)==(0|0);
  do {
   if ($11) {
    $$025$i$i = $6;$$052$i = $6;$28 = $10;
    label = 16;
   } else {
    $12 = HEAP32[$9>>2]|0;
    $13 = ((($$sroa$09$022)) + 20|0);
    $14 = HEAP32[$13>>2]|0;
    $$0$i$i = $7;$$024$i$i = $10;$76 = $10;
    L8: while(1) {
     $15 = ((($$024$i$i)) + 16|0);
     $16 = HEAP32[$15>>2]|0;
     $17 = ($12|0)<($16|0);
     do {
      if ($17) {
       label = 10;
      } else {
       $18 = ($16|0)<($12|0);
       if (!($18)) {
        $19 = ((($$024$i$i)) + 20|0);
        $20 = HEAP32[$19>>2]|0;
        $21 = ($14>>>0)<($20>>>0);
        if ($21) {
         label = 10;
         break;
        }
        $24 = ($20>>>0)<($14>>>0);
        if (!($24)) {
         label = 15;
         break L8;
        }
       }
       $25 = ((($$024$i$i)) + 4|0);
       $26 = HEAP32[$25>>2]|0;
       $27 = ($26|0)==(0|0);
       if ($27) {
        label = 14;
        break L8;
       } else {
        $$0$ph$i$i = $25;$$in$i$i = $26;
       }
      }
     } while(0);
     if ((label|0) == 10) {
      label = 0;
      $22 = HEAP32[$$024$i$i>>2]|0;
      $23 = ($22|0)==(0|0);
      if ($23) {
       label = 11;
       break;
      } else {
       $$0$ph$i$i = $$024$i$i;$$in$i$i = $22;
      }
     }
     $$0$i$i = $$0$ph$i$i;$$024$i$i = $$in$i$i;$76 = $$in$i$i;
    }
    if ((label|0) == 11) {
     label = 0;
     $$025$i68$i = $$024$i$i;$$05267$i = $$024$i$i;
     label = 17;
     break;
    }
    else if ((label|0) == 14) {
     label = 0;
     $$025$i68$i = $25;$$05267$i = $$024$i$i;
     label = 17;
     break;
    }
    else if ((label|0) == 15) {
     label = 0;
     $$025$i$i = $$0$i$i;$$052$i = $$024$i$i;$28 = $76;
     label = 16;
     break;
    }
   }
  } while(0);
  if ((label|0) == 16) {
   label = 0;
   $29 = ($28|0)==(0|0);
   if ($29) {
    $$025$i68$i = $$025$i$i;$$05267$i = $$052$i;
    label = 17;
   } else {
    $$014$i = $28;
   }
  }
  if ((label|0) == 17) {
   label = 0;
   $30 = (__Znwj(52)|0);
   $31 = ((($30)) + 16|0);
   $32 = $9;
   $33 = $32;
   $34 = HEAP32[$33>>2]|0;
   $35 = (($32) + 4)|0;
   $36 = $35;
   $37 = HEAP32[$36>>2]|0;
   $38 = $31;
   $39 = $38;
   HEAP32[$39>>2] = $34;
   $40 = (($38) + 4)|0;
   $41 = $40;
   HEAP32[$41>>2] = $37;
   $42 = ((($30)) + 24|0);
   HEAP8[$42>>0] = 0;
   $43 = ((($30)) + 28|0);
   ;HEAP32[$43>>2]=0|0;HEAP32[$43+4>>2]=0|0;HEAP32[$43+8>>2]=0|0;HEAP32[$43+12>>2]=0|0;HEAP32[$43+16>>2]=0|0;HEAP32[$43+20>>2]=0|0;
   HEAP32[$30>>2] = 0;
   $44 = ((($30)) + 4|0);
   HEAP32[$44>>2] = 0;
   $45 = ((($30)) + 8|0);
   HEAP32[$45>>2] = $$05267$i;
   HEAP32[$$025$i68$i>>2] = $30;
   $46 = HEAP32[$1>>2]|0;
   $47 = HEAP32[$46>>2]|0;
   $48 = ($47|0)==(0|0);
   if ($48) {
    $51 = $30;
   } else {
    $49 = $47;
    HEAP32[$1>>2] = $49;
    $$pre$i$i = HEAP32[$$025$i68$i>>2]|0;
    $51 = $$pre$i$i;
   }
   $50 = HEAP32[$7>>2]|0;
   __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($50,$51);
   $52 = HEAP32[$8>>2]|0;
   $53 = (($52) + 1)|0;
   HEAP32[$8>>2] = $53;
   $$014$i = $30;
  }
  $54 = ((($$014$i)) + 40|0);
  $55 = HEAP32[$54>>2]|0;
  $56 = ((($$014$i)) + 44|0);
  $57 = HEAP32[$56>>2]|0;
  $58 = ($55|0)==($57|0);
  if (!($58)) {
   $scevgep5$i$i$i = ((($57)) + -8|0);
   HEAP32[$56>>2] = $scevgep5$i$i$i;
  }
  $59 = ((($$014$i)) + 24|0);
  HEAP8[$59>>0] = 1;
  $60 = ((($$sroa$09$022)) + 4|0);
  $61 = HEAP32[$60>>2]|0;
  $62 = ($61|0)==(0|0);
  if ($62) {
   $63 = ((($$sroa$09$022)) + 8|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = HEAP32[$64>>2]|0;
   $66 = ($65|0)==($$sroa$09$022|0);
   if ($66) {
    $$sroa$09$0$be = $64;
   } else {
    $71 = $63;
    while(1) {
     $70 = HEAP32[$71>>2]|0;
     $72 = ((($70)) + 8|0);
     $73 = HEAP32[$72>>2]|0;
     $74 = HEAP32[$73>>2]|0;
     $75 = ($74|0)==($70|0);
     if ($75) {
      $$sroa$09$0$be = $73;
      break;
     } else {
      $71 = $72;
     }
    }
   }
  } else {
   $$0$i$i$i$i = $61;
   while(1) {
    $68 = HEAP32[$$0$i$i$i$i>>2]|0;
    $69 = ($68|0)==(0|0);
    if ($69) {
     break;
    } else {
     $$0$i$i$i$i = $68;
    }
   }
   $$sroa$09$0$be = $$0$i$i$i$i;
  }
  $67 = ($$sroa$09$0$be|0)==($4|0);
  if ($67) {
   break;
  } else {
   $$sroa$09$022 = $$sroa$09$0$be;
  }
 }
 return;
}
function __ZN3osg5State13popDefineListERNS0_9DefineMapERKNSt3__23mapINS3_12basic_stringIcNS3_11char_traitsIcEENS3_9allocatorIcEEEENS3_4pairISA_jEENS3_4lessISA_EENS8_INSB_IKSA_SC_EEEEEE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$i$i$i$i = 0, $$02026$i$i3$i = 0, $$02125$i$i4$i = 0, $$027$i$i2$i = 0, $$pre$i$i = 0, $$pre$i$i$i = 0, $$pre$phiZ2D = 0, $$pre$pre$phiZZ2D = 0, $$pre24 = 0, $$sroa$019$0$be = 0, $$sroa$019$023 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $9 = 0, $phitmp$i = 0, $phitmp$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($2)) + 4|0);
 $5 = ($3|0)==($4|0);
 if ($5) {
  return;
 }
 $6 = ((($1)) + 12|0);
 $$sroa$019$023 = $3;
 while(1) {
  $7 = ((($$sroa$019$023)) + 16|0);
  $8 = (__ZNSt3__23mapINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg5State11DefineStackENS_4lessIS6_EENS4_INS_4pairIKS6_S9_EEEEEixERSD_($1,$7)|0);
  $9 = ((($8)) + 4|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ((($8)) + 8|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($10|0)==($12|0);
  if (!($13)) {
   $14 = $10;
   $15 = $12;
   $16 = (($15) - ($14))|0;
   $17 = $16 >> 4;
   $18 = ($17>>>0)<(2);
   L8: do {
    if ($18) {
     $$pre24 = ((($12)) + -16|0);
     $$pre$pre$phiZZ2D = $$pre24;
     label = 16;
    } else {
     $19 = (($17) + -2)|0;
     $20 = (($10) + ($19<<4)|0);
     $21 = ((($12)) + -16|0);
     $22 = ((($20)) + 11|0);
     $23 = HEAP8[$22>>0]|0;
     $24 = ($23<<24>>24)<(0);
     $25 = (((($10) + ($19<<4)|0)) + 4|0);
     $26 = HEAP32[$25>>2]|0;
     $27 = $23&255;
     $28 = $24 ? $26 : $27;
     $29 = ((($21)) + 11|0);
     $30 = HEAP8[$29>>0]|0;
     $31 = ($30<<24>>24)<(0);
     $32 = ((($12)) + -12|0);
     $33 = HEAP32[$32>>2]|0;
     $34 = $30&255;
     $35 = $31 ? $33 : $34;
     $36 = ($28|0)==($35|0);
     if ($36) {
      $37 = HEAP32[$20>>2]|0;
      $38 = $24 ? $37 : $20;
      $39 = HEAP32[$21>>2]|0;
      $40 = $31 ? $39 : $21;
      $41 = ($28|0)==(0);
      L12: do {
       if ($24) {
        if (!($41)) {
         $52 = (_memcmp($38,$40,$28)|0);
         $phitmp$i$i$i = ($52|0)==(0);
         if (!($phitmp$i$i$i)) {
          $$pre$pre$phiZZ2D = $21;
          label = 16;
          break L8;
         }
        }
       } else {
        if (!($41)) {
         $42 = $37;
         $43 = $42&255;
         $44 = HEAP8[$40>>0]|0;
         $45 = ($43<<24>>24)==($44<<24>>24);
         if ($45) {
          $$02026$i$i3$i = $20;$$02125$i$i4$i = $27;$$027$i$i2$i = $40;
         } else {
          $$pre$pre$phiZZ2D = $21;
          label = 16;
          break L8;
         }
         while(1) {
          $46 = (($$02125$i$i4$i) + -1)|0;
          $47 = ((($$02026$i$i3$i)) + 1|0);
          $48 = ($46|0)==(0);
          if ($48) {
           break L12;
          }
          $49 = ((($$027$i$i2$i)) + 1|0);
          $$pre$i$i = HEAP8[$47>>0]|0;
          $50 = HEAP8[$49>>0]|0;
          $51 = ($$pre$i$i<<24>>24)==($50<<24>>24);
          if ($51) {
           $$02026$i$i3$i = $47;$$02125$i$i4$i = $46;$$027$i$i2$i = $49;
          } else {
           $$pre$pre$phiZZ2D = $21;
           label = 16;
           break L8;
          }
         }
        }
       }
      } while(0);
      $53 = (((($10) + ($19<<4)|0)) + 12|0);
      $54 = HEAP32[$53>>2]|0;
      $55 = ((($12)) + -4|0);
      $56 = HEAP32[$55>>2]|0;
      $phitmp$i = ($54|0)==($56|0);
      if ($phitmp$i) {
       $$pre$phiZ2D = $21;
      } else {
       $$pre$pre$phiZZ2D = $21;
       label = 16;
      }
     } else {
      $$pre$pre$phiZZ2D = $21;
      label = 16;
     }
    }
   } while(0);
   if ((label|0) == 16) {
    label = 0;
    HEAP8[$8>>0] = 1;
    HEAP8[$6>>0] = 1;
    $$pre$phiZ2D = $$pre$pre$phiZZ2D;
   }
   $58 = $12;
   while(1) {
    $57 = ((($58)) + -16|0);
    HEAP32[$11>>2] = $57;
    $59 = ((($57)) + 11|0);
    $60 = HEAP8[$59>>0]|0;
    $61 = ($60<<24>>24)<(0);
    if ($61) {
     $64 = HEAP32[$57>>2]|0;
     __ZdlPv($64);
     $$pre$i$i$i = HEAP32[$11>>2]|0;
     $62 = $$pre$i$i$i;
    } else {
     $62 = $57;
    }
    $63 = ($62|0)==($$pre$phiZ2D|0);
    if ($63) {
     break;
    } else {
     $58 = $62;
    }
   }
  }
  $65 = ((($$sroa$019$023)) + 4|0);
  $66 = HEAP32[$65>>2]|0;
  $67 = ($66|0)==(0|0);
  if ($67) {
   $68 = ((($$sroa$019$023)) + 8|0);
   $69 = HEAP32[$68>>2]|0;
   $70 = HEAP32[$69>>2]|0;
   $71 = ($70|0)==($$sroa$019$023|0);
   if ($71) {
    $$sroa$019$0$be = $69;
   } else {
    $76 = $68;
    while(1) {
     $75 = HEAP32[$76>>2]|0;
     $77 = ((($75)) + 8|0);
     $78 = HEAP32[$77>>2]|0;
     $79 = HEAP32[$78>>2]|0;
     $80 = ($79|0)==($75|0);
     if ($80) {
      $$sroa$019$0$be = $78;
      break;
     } else {
      $76 = $77;
     }
    }
   }
  } else {
   $$0$i$i$i$i = $66;
   while(1) {
    $73 = HEAP32[$$0$i$i$i$i>>2]|0;
    $74 = ($73|0)==(0|0);
    if ($74) {
     break;
    } else {
     $$0$i$i$i$i = $73;
    }
   }
   $$sroa$019$0$be = $$0$i$i$i$i;
  }
  $72 = ($$sroa$019$0$be|0)==($4|0);
  if ($72) {
   break;
  } else {
   $$sroa$019$023 = $$sroa$019$0$be;
  }
 }
 return;
}
function __ZN3osg5State21applyProjectionMatrixEPKNS_10RefMatrixdE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 172|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==($1|0);
 if ($4) {
  return;
 }
 $5 = ($1|0)==(0|0);
 if ($5) {
  $12 = ((($0)) + 164|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($3|0)==($13|0);
  if (!($14)) {
   HEAP32[$2>>2] = $13;
   $15 = ($13|0)==(0|0);
   if (!($15)) {
    $16 = ((($13)) + 8|0);
    $17 = HEAP32[$16>>2]|0;HEAP32[$16>>2] = (($17+1)|0);
   }
   $18 = ($3|0)==(0|0);
   if (!($18)) {
    $19 = ((($3)) + 8|0);
    $20 = HEAP32[$19>>2]|0;HEAP32[$19>>2] = (($20-1)|0);
    $21 = ($20|0)==(1);
    if ($21) {
     __ZNK3osg10Referenced24signalObserversAndDeleteEbb($3,1,1);
    }
   }
  }
 } else {
  HEAP32[$2>>2] = $1;
  $6 = ((($1)) + 8|0);
  $7 = HEAP32[$6>>2]|0;HEAP32[$6>>2] = (($7+1)|0);
  $8 = ($3|0)==(0|0);
  if (!($8)) {
   $9 = ((($3)) + 8|0);
   $10 = HEAP32[$9>>2]|0;HEAP32[$9>>2] = (($10-1)|0);
   $11 = ($10|0)==(1);
   if ($11) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($3,1,1);
   }
  }
 }
 $22 = ((($0)) + 184|0);
 $23 = HEAP8[$22>>0]|0;
 $24 = ($23<<24>>24)==(0);
 if ($24) {
  return;
 }
 $25 = ((($0)) + 192|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($26|0)==(0|0);
 if (!($27)) {
  $28 = HEAP32[$2>>2]|0;
  $29 = ((($28)) + 32|0);
  (__ZN3osg7Uniform3setERKNS_7MatrixdE($26,$29)|0);
 }
 __ZN3osg5State42updateModelViewAndProjectionMatrixUniformsEv($0);
 return;
}
function __ZN3osg5State20applyModelViewMatrixEPKNS_10RefMatrixdE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 176|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==($1|0);
 if ($4) {
  return;
 }
 $5 = ($1|0)==(0|0);
 if ($5) {
  $12 = ((($0)) + 164|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($3|0)==($13|0);
  if (!($14)) {
   HEAP32[$2>>2] = $13;
   $15 = ($13|0)==(0|0);
   if (!($15)) {
    $16 = ((($13)) + 8|0);
    $17 = HEAP32[$16>>2]|0;HEAP32[$16>>2] = (($17+1)|0);
   }
   $18 = ($3|0)==(0|0);
   if (!($18)) {
    $19 = ((($3)) + 8|0);
    $20 = HEAP32[$19>>2]|0;HEAP32[$19>>2] = (($20-1)|0);
    $21 = ($20|0)==(1);
    if ($21) {
     __ZNK3osg10Referenced24signalObserversAndDeleteEbb($3,1,1);
    }
   }
  }
 } else {
  HEAP32[$2>>2] = $1;
  $6 = ((($1)) + 8|0);
  $7 = HEAP32[$6>>2]|0;HEAP32[$6>>2] = (($7+1)|0);
  $8 = ($3|0)==(0|0);
  if (!($8)) {
   $9 = ((($3)) + 8|0);
   $10 = HEAP32[$9>>2]|0;HEAP32[$9>>2] = (($10-1)|0);
   $11 = ($10|0)==(1);
   if ($11) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($3,1,1);
   }
  }
 }
 $22 = ((($0)) + 184|0);
 $23 = HEAP8[$22>>0]|0;
 $24 = ($23<<24>>24)==(0);
 if ($24) {
  return;
 }
 $25 = ((($0)) + 188|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($26|0)==(0|0);
 if (!($27)) {
  $28 = HEAP32[$2>>2]|0;
  $29 = ((($28)) + 32|0);
  (__ZN3osg7Uniform3setERKNS_7MatrixdE($26,$29)|0);
 }
 __ZN3osg5State42updateModelViewAndProjectionMatrixUniformsEv($0);
 return;
}
function __ZN3osg5State14insertStateSetEjPKNS_8StateSetE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$in = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i6 = 0, $scevgep5$i$i$i = 0, $scevgep5$i$i$i7 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 HEAP32[$3>>2] = 0;
 $4 = ((($3)) + 4|0);
 HEAP32[$4>>2] = 0;
 $5 = ((($3)) + 8|0);
 HEAP32[$5>>2] = 0;
 $6 = ((($0)) + 668|0);
 $7 = ((($0)) + 672|0);
 $8 = ((($3)) + 8|0);
 while(1) {
  $9 = HEAP32[$7>>2]|0;
  $10 = HEAP32[$6>>2]|0;
  $11 = (($9) - ($10))|0;
  $12 = $11 >> 2;
  $13 = ($12>>>0)>($1>>>0);
  if (!($13)) {
   label = 7;
   break;
  }
  $14 = $9;
  $15 = ((($14)) + -4|0);
  $16 = HEAP32[$4>>2]|0;
  $17 = HEAP32[$8>>2]|0;
  $18 = ($16|0)==($17|0);
  if ($18) {
   __THREW__ = 0;
   invoke_vii(3932,($3|0),($15|0));
   $22 = __THREW__; __THREW__ = 0;
   $23 = $22&1;
   if ($23) {
    break;
   }
  } else {
   $19 = HEAP32[$15>>2]|0;
   HEAP32[$16>>2] = $19;
   $20 = HEAP32[$4>>2]|0;
   $21 = ((($20)) + 4|0);
   HEAP32[$4>>2] = $21;
  }
  __THREW__ = 0;
  invoke_vi(3670,($0|0));
  $24 = __THREW__; __THREW__ = 0;
  $25 = $24&1;
  if ($25) {
   break;
  }
 }
 L8: do {
  if ((label|0) == 7) {
   __THREW__ = 0;
   invoke_vii(3669,($0|0),($2|0));
   $26 = __THREW__; __THREW__ = 0;
   $27 = $26&1;
   if (!($27)) {
    $28 = HEAP32[$4>>2]|0;
    $29 = HEAP32[$3>>2]|0;
    $30 = ($28|0)==($29|0);
    if ($30) {
     $31 = ($28|0)==(0|0);
     if ($31) {
      STACKTOP = sp;return;
     } else {
      $$in = $28;
     }
    } else {
     $40 = $28;
     while(1) {
      $39 = ((($40)) + -4|0);
      $41 = HEAP32[$39>>2]|0;
      __THREW__ = 0;
      invoke_vii(3669,($0|0),($41|0));
      $42 = __THREW__; __THREW__ = 0;
      $43 = $42&1;
      if ($43) {
       break L8;
      }
      $44 = HEAP32[$3>>2]|0;
      $45 = ($39|0)==($44|0);
      if ($45) {
       $$in = $39;
       break;
      } else {
       $40 = $39;
      }
     }
    }
    $32 = HEAP32[$4>>2]|0;
    $33 = ($32|0)==($$in|0);
    if (!($33)) {
     $scevgep$i$i$i6 = ((($32)) + -4|0);
     $34 = $scevgep$i$i$i6;
     $35 = $$in;
     $36 = (($34) - ($35))|0;
     $37 = $36 >>> 2;
     $38 = $37 ^ -1;
     $scevgep5$i$i$i7 = (($32) + ($38<<2)|0);
     HEAP32[$4>>2] = $scevgep5$i$i$i7;
    }
    __ZdlPv($$in);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $46 = ___cxa_find_matching_catch_2()|0;
 $47 = tempRet0;
 $48 = HEAP32[$3>>2]|0;
 $49 = ($48|0)==(0|0);
 if ($49) {
  ___resumeException($46|0);
  // unreachable;
 }
 $50 = HEAP32[$4>>2]|0;
 $51 = ($50|0)==($48|0);
 if (!($51)) {
  $scevgep$i$i$i = ((($50)) + -4|0);
  $52 = $scevgep$i$i$i;
  $53 = $48;
  $54 = (($52) - ($53))|0;
  $55 = $54 >>> 2;
  $56 = $55 ^ -1;
  $scevgep5$i$i$i = (($50) + ($56<<2)|0);
  HEAP32[$4>>2] = $scevgep5$i$i$i;
 }
 __ZdlPv($48);
 ___resumeException($46|0);
 // unreachable;
}
function __ZN3osg5State14removeStateSetEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$in26 = 0, $$in28 = 0, $$pre = 0, $$pre24 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $9 = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i7 = 0, $scevgep5$i$i$i = 0, $scevgep5$i$i$i8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp + 12|0;
 $3 = sp;
 $4 = ((($0)) + 668|0);
 $5 = ((($0)) + 672|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$4>>2]|0;
 $8 = (($6) - ($7))|0;
 $9 = $8 >> 2;
 $10 = ($9>>>0)>($1>>>0);
 if (!($10)) {
  $11 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
  if (!($11)) {
   STACKTOP = sp;return;
  }
  $12 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
  $13 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($12,149789,31)|0);
  $14 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($13,$1)|0);
  $15 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($14,149821,14)|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ((($16)) + -12|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (($15) + ($18)|0);
  __ZNKSt3__28ios_base6getlocEv($2,$19);
  __THREW__ = 0;
  $20 = (invoke_iii(3255,($2|0),(215188|0))|0);
  $21 = __THREW__; __THREW__ = 0;
  $22 = $21&1;
  if (!($22)) {
   $23 = HEAP32[$20>>2]|0;
   $24 = ((($23)) + 28|0);
   $25 = HEAP32[$24>>2]|0;
   __THREW__ = 0;
   $26 = (invoke_iii($25|0,($20|0),10)|0);
   $27 = __THREW__; __THREW__ = 0;
   $28 = $27&1;
   if (!($28)) {
    __ZNSt3__26localeD2Ev($2);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($15,$26)|0);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($15)|0);
    STACKTOP = sp;return;
   }
  }
  $29 = ___cxa_find_matching_catch_2()|0;
  $30 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3263,($2|0));
  $31 = __THREW__; __THREW__ = 0;
  $32 = $31&1;
  if ($32) {
   $33 = ___cxa_find_matching_catch_3(0|0)|0;
   $34 = tempRet0;
   ___clang_call_terminate($33);
   // unreachable;
  } else {
   ___resumeException($29|0);
   // unreachable;
  }
 }
 HEAP32[$3>>2] = 0;
 $35 = ((($3)) + 4|0);
 HEAP32[$35>>2] = 0;
 $36 = ((($3)) + 8|0);
 HEAP32[$36>>2] = 0;
 $37 = ((($3)) + 8|0);
 $38 = (($6) - ($7))|0;
 $39 = $38 >> 2;
 $40 = (($39) + -1)|0;
 $41 = ($40>>>0)>($1>>>0);
 L15: do {
  if ($41) {
   $$in28 = $6;
   while(1) {
    $42 = $$in28;
    $43 = ((($42)) + -4|0);
    $44 = HEAP32[$35>>2]|0;
    $45 = HEAP32[$37>>2]|0;
    $46 = ($44|0)==($45|0);
    if ($46) {
     __THREW__ = 0;
     invoke_vii(3932,($3|0),($43|0));
     $50 = __THREW__; __THREW__ = 0;
     $51 = $50&1;
     if ($51) {
      break L15;
     }
    } else {
     $47 = HEAP32[$43>>2]|0;
     HEAP32[$44>>2] = $47;
     $48 = HEAP32[$35>>2]|0;
     $49 = ((($48)) + 4|0);
     HEAP32[$35>>2] = $49;
    }
    __THREW__ = 0;
    invoke_vi(3670,($0|0));
    $52 = __THREW__; __THREW__ = 0;
    $53 = $52&1;
    if ($53) {
     break L15;
    }
    $$pre = HEAP32[$5>>2]|0;
    $$pre24 = HEAP32[$4>>2]|0;
    $54 = (($$pre) - ($$pre24))|0;
    $55 = $54 >> 2;
    $56 = (($55) + -1)|0;
    $57 = ($56>>>0)>($1>>>0);
    if ($57) {
     $$in28 = $$pre;
    } else {
     label = 15;
     break;
    }
   }
  } else {
   label = 15;
  }
 } while(0);
 L23: do {
  if ((label|0) == 15) {
   __THREW__ = 0;
   invoke_vi(3670,($0|0));
   $58 = __THREW__; __THREW__ = 0;
   $59 = $58&1;
   if (!($59)) {
    $60 = HEAP32[$35>>2]|0;
    $61 = HEAP32[$3>>2]|0;
    $62 = ($60|0)==($61|0);
    if ($62) {
     $63 = ($60|0)==(0|0);
     if (!($63)) {
      $$in26 = $60;
      label = 18;
     }
    } else {
     $72 = $60;
     while(1) {
      $71 = ((($72)) + -4|0);
      $73 = HEAP32[$71>>2]|0;
      __THREW__ = 0;
      invoke_vii(3669,($0|0),($73|0));
      $74 = __THREW__; __THREW__ = 0;
      $75 = $74&1;
      if ($75) {
       break L23;
      }
      $76 = HEAP32[$3>>2]|0;
      $77 = ($71|0)==($76|0);
      if ($77) {
       $$in26 = $71;
       label = 18;
       break;
      } else {
       $72 = $71;
      }
     }
    }
    if ((label|0) == 18) {
     $64 = HEAP32[$35>>2]|0;
     $65 = ($64|0)==($$in26|0);
     if (!($65)) {
      $scevgep$i$i$i = ((($64)) + -4|0);
      $66 = $scevgep$i$i$i;
      $67 = $$in26;
      $68 = (($66) - ($67))|0;
      $69 = $68 >>> 2;
      $70 = $69 ^ -1;
      $scevgep5$i$i$i = (($64) + ($70<<2)|0);
      HEAP32[$35>>2] = $scevgep5$i$i$i;
     }
     __ZdlPv($$in26);
    }
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $78 = ___cxa_find_matching_catch_2()|0;
 $79 = tempRet0;
 $80 = HEAP32[$3>>2]|0;
 $81 = ($80|0)==(0|0);
 if ($81) {
  ___resumeException($78|0);
  // unreachable;
 }
 $82 = HEAP32[$35>>2]|0;
 $83 = ($82|0)==($80|0);
 if (!($83)) {
  $scevgep$i$i$i7 = ((($82)) + -4|0);
  $84 = $scevgep$i$i$i7;
  $85 = $80;
  $86 = (($84) - ($85))|0;
  $87 = $86 >>> 2;
  $88 = $87 ^ -1;
  $scevgep5$i$i$i8 = (($82) + ($88<<2)|0);
  HEAP32[$35>>2] = $scevgep5$i$i$i8;
 }
 __ZdlPv($80);
 ___resumeException($78|0);
 // unreachable;
}
function __ZN3osg5State5applyEPKNS_8StateSetE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i38 = 0, $$051 = 0, $$byval_copy = 0, $$pre = 0, $$pre$i$i$i$i$i = 0, $$pre56 = 0, $$pre57 = 0, $$sroa$044$0 = 0, $$sroa$07$0$be$i = 0, $$sroa$07$011$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0;
 var $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0;
 var $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0;
 var $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0;
 var $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0;
 var $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0;
 var $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $or$cond34 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $$byval_copy = sp + 16|0;
 $2 = sp + 12|0;
 $3 = sp + 8|0;
 $4 = sp + 4|0;
 $5 = sp;
 HEAP32[$5>>2] = $1;
 $6 = ((($0)) + 344|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(2);
 $9 = $1;
 if ($8) {
  (__ZNK3osg5State13checkGLErrorsEPKcS2_(0,149836,0)|0);
 }
 $10 = ($1|0)==(0|0);
 if ($10) {
  __ZN3osg5State5applyEv($0);
 } else {
  $11 = ((($0)) + 672|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ((($0)) + 676|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = ($12|0)==($14|0);
  if ($15) {
   $18 = ((($0)) + 668|0);
   __ZNSt3__26vectorIPKN3osg8StateSetENS_9allocatorIS4_EEE21__push_back_slow_pathIKS4_EEvRT_($18,$5);
  } else {
   HEAP32[$12>>2] = $9;
   $16 = HEAP32[$11>>2]|0;
   $17 = ((($16)) + 4|0);
   HEAP32[$11>>2] = $17;
  }
  $19 = ((($0)) + 148|0);
  $20 = ((($0)) + 152|0);
  $21 = HEAP32[$20>>2]|0;
  __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4pairIN3osg7ref_ptrINS9_7UniformEEEjEEEENS_19__map_value_compareIS7_SE_NS_4lessIS7_EELb1EEENS5_ISE_EEE7destroyEPNS_11__tree_nodeISE_PvEE($19,$21);
  $22 = ((($0)) + 156|0);
  HEAP32[$22>>2] = 0;
  HEAP32[$19>>2] = $20;
  HEAP32[$20>>2] = 0;
  $23 = HEAP32[$5>>2]|0;
  $24 = ((($23)) + 68|0);
  $25 = ((($23)) + 80|0);
  $26 = ((($23)) + 72|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = HEAP32[$24>>2]|0;
  $29 = (($27) - ($28))|0;
  $30 = (($29|0) / 12)&-1;
  $31 = ((($23)) + 84|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = HEAP32[$25>>2]|0;
  $34 = (($32) - ($33))|0;
  $35 = (($34|0) / 12)&-1;
  $36 = ($30>>>0)>($35>>>0);
  $37 = $36 ? $30 : $35;
  $38 = ((($0)) + 640|0);
  $39 = ((($0)) + 644|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = HEAP32[$38>>2]|0;
  $42 = (($40) - ($41))|0;
  $43 = (($42|0) / 12)&-1;
  $44 = ($37>>>0)>($43>>>0);
  $45 = $44 ? $37 : $43;
  $46 = ((($0)) + 652|0);
  $47 = ((($0)) + 656|0);
  $48 = HEAP32[$47>>2]|0;
  $49 = HEAP32[$46>>2]|0;
  $50 = (($48) - ($49))|0;
  $51 = (($50|0) / 12)&-1;
  $52 = ($45>>>0)>($51>>>0);
  $53 = $52 ? $45 : $51;
  $54 = ($53|0)==(0);
  if ($54) {
   $123 = $23;
  } else {
   $$051 = 0;$56 = $28;$57 = $27;
   while(1) {
    $55 = (($57) - ($56))|0;
    $58 = (($55|0) / 12)&-1;
    $59 = ($$051>>>0)<($58>>>0);
    $60 = HEAP32[$39>>2]|0;
    $61 = HEAP32[$38>>2]|0;
    $62 = (($60) - ($61))|0;
    $63 = (($62|0) / 12)&-1;
    if ($59) {
     $64 = ($63>>>0)>($$051>>>0);
     do {
      if (!($64)) {
       $65 = (($$051) + 1)|0;
       $66 = ($65>>>0)>($63>>>0);
       $67 = $61;
       $68 = $60;
       if ($66) {
        $69 = (($65) - ($63))|0;
        __ZNSt3__26vectorINS_3mapIjN3osg5State9ModeStackENS_4lessIjEENS_9allocatorINS_4pairIKjS4_EEEEEENS7_ISC_EEE8__appendEj($38,$69);
        break;
       }
       $70 = ($65>>>0)<($63>>>0);
       if ($70) {
        $71 = (($67) + (($65*12)|0)|0);
        $72 = ($68|0)==($71|0);
        if (!($72)) {
         $74 = $68;
         while(1) {
          $73 = ((($74)) + -12|0);
          HEAP32[$39>>2] = $73;
          $75 = ((($74)) + -8|0);
          $76 = HEAP32[$75>>2]|0;
          __ZNSt3__26__treeINS_12__value_typeIjN3osg5State9ModeStackEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($73,$76);
          $77 = HEAP32[$39>>2]|0;
          $78 = ($77|0)==($71|0);
          if ($78) {
           break;
          } else {
           $74 = $77;
          }
         }
        }
       }
      }
     } while(0);
     $79 = HEAP32[$38>>2]|0;
     $80 = (($79) + (($$051*12)|0)|0);
     $81 = HEAP32[$24>>2]|0;
     $82 = (($81) + (($$051*12)|0)|0);
     __ZN3osg5State22applyModeListOnTexUnitEjRNSt3__23mapIjNS0_9ModeStackENS1_4lessIjEENS1_9allocatorINS1_4pairIKjS3_EEEEEERKNS2_IjjS5_NS6_INS7_IS8_jEEEEEE($0,$$051,$80,$82);
    } else {
     $83 = ($$051>>>0)<($63>>>0);
     if ($83) {
      $84 = $61;
      $85 = (($84) + (($$051*12)|0)|0);
      __ZN3osg5State21applyModeMapOnTexUnitEjRNSt3__23mapIjNS0_9ModeStackENS1_4lessIjEENS1_9allocatorINS1_4pairIKjS3_EEEEEE($0,$$051,$85);
     }
    }
    $86 = HEAP32[$31>>2]|0;
    $87 = HEAP32[$25>>2]|0;
    $88 = (($86) - ($87))|0;
    $89 = (($88|0) / 12)&-1;
    $90 = ($$051>>>0)<($89>>>0);
    $91 = HEAP32[$47>>2]|0;
    $92 = HEAP32[$46>>2]|0;
    $93 = (($91) - ($92))|0;
    $94 = (($93|0) / 12)&-1;
    if ($90) {
     $95 = ($94>>>0)>($$051>>>0);
     do {
      if (!($95)) {
       $96 = (($$051) + 1)|0;
       $97 = ($96>>>0)>($94>>>0);
       $98 = $92;
       $99 = $91;
       if ($97) {
        $100 = (($96) - ($94))|0;
        __ZNSt3__26vectorINS_3mapINS_4pairIN3osg14StateAttribute4TypeEjEENS3_5State14AttributeStackENS_4lessIS6_EENS_9allocatorINS2_IKS6_S8_EEEEEENSB_ISF_EEE8__appendEj($46,$100);
        break;
       }
       $101 = ($96>>>0)<($94>>>0);
       if ($101) {
        $102 = (($98) + (($96*12)|0)|0);
        $103 = ($99|0)==($102|0);
        if (!($103)) {
         $105 = $99;
         while(1) {
          $104 = ((($105)) + -12|0);
          HEAP32[$47>>2] = $104;
          $106 = ((($105)) + -8|0);
          $107 = HEAP32[$106>>2]|0;
          __ZNSt3__26__treeINS_12__value_typeINS_4pairIN3osg14StateAttribute4TypeEjEENS3_5State14AttributeStackEEENS_19__map_value_compareIS6_S9_NS_4lessIS6_EELb1EEENS_9allocatorIS9_EEE7destroyEPNS_11__tree_nodeIS9_PvEE($104,$107);
          $108 = HEAP32[$47>>2]|0;
          $109 = ($108|0)==($102|0);
          if ($109) {
           break;
          } else {
           $105 = $108;
          }
         }
        }
       }
      }
     } while(0);
     $110 = HEAP32[$46>>2]|0;
     $111 = (($110) + (($$051*12)|0)|0);
     $112 = HEAP32[$25>>2]|0;
     $113 = (($112) + (($$051*12)|0)|0);
     __ZN3osg5State27applyAttributeListOnTexUnitEjRNSt3__23mapINS1_4pairINS_14StateAttribute4TypeEjEENS0_14AttributeStackENS1_4lessIS6_EENS1_9allocatorINS3_IKS6_S7_EEEEEERKNS2_IS6_NS3_INS_7ref_ptrIS4_EEjEES9_NSA_INS3_ISB_SI_EEEEEE($0,$$051,$111,$113);
    } else {
     $114 = ($$051>>>0)<($94>>>0);
     if ($114) {
      $115 = $92;
      $116 = (($115) + (($$051*12)|0)|0);
      __ZN3osg5State26applyAttributeMapOnTexUnitEjRNSt3__23mapINS1_4pairINS_14StateAttribute4TypeEjEENS0_14AttributeStackENS1_4lessIS6_EENS1_9allocatorINS3_IKS6_S7_EEEEEE($0,$$051,$116);
     }
    }
    $117 = (($$051) + 1)|0;
    $118 = ($117>>>0)<($53>>>0);
    if (!($118)) {
     break;
    }
    $$pre = HEAP32[$26>>2]|0;
    $$pre56 = HEAP32[$24>>2]|0;
    $$051 = $117;$56 = $$pre56;$57 = $$pre;
   }
   $$pre57 = HEAP32[$5>>2]|0;
   $123 = $$pre57;
  }
  $119 = ((($0)) + 664|0);
  $120 = HEAP32[$119>>2]|0;
  $121 = ((($0)) + 576|0);
  $122 = ((($123)) + 44|0);
  __ZN3osg5State13applyModeListERNSt3__23mapIjNS0_9ModeStackENS1_4lessIjEENS1_9allocatorINS1_4pairIKjS3_EEEEEERKNS2_IjjS5_NS6_INS7_IS8_jEEEEEE($0,$121,$122);
  $124 = ((($0)) + 612|0);
  $125 = HEAP32[$5>>2]|0;
  $126 = ((($125)) + 104|0);
  __ZN3osg5State14pushDefineListERNS0_9DefineMapERKNSt3__23mapINS3_12basic_stringIcNS3_11char_traitsIcEENS3_9allocatorIcEEEENS3_4pairISA_jEENS3_4lessISA_EENS8_INSB_IKSA_SC_EEEEEE($0,$124,$126);
  $127 = ((($0)) + 588|0);
  $128 = HEAP32[$5>>2]|0;
  $129 = ((($128)) + 56|0);
  __ZN3osg5State18applyAttributeListERNSt3__23mapINS1_4pairINS_14StateAttribute4TypeEjEENS0_14AttributeStackENS1_4lessIS6_EENS1_9allocatorINS3_IKS6_S7_EEEEEERKNS2_IS6_NS3_INS_7ref_ptrIS4_EEjEES9_NSA_INS3_ISB_SI_EEEEEE($0,$127,$129);
  $130 = HEAP32[$119>>2]|0;
  $131 = ($130|0)!=(0|0);
  $132 = ($120|0)==($130|0);
  $or$cond = $131 & $132;
  if ($or$cond) {
   $133 = ((($0)) + 624|0);
   $134 = HEAP8[$133>>0]|0;
   $135 = ($134<<24>>24)==(0);
   if (!($135)) {
    $136 = ((($120)) + 12|0);
    $137 = HEAP32[$136>>2]|0;
    $138 = HEAP32[$137>>2]|0;
    $139 = ((($138)) + 172|0);
    $140 = HEAP32[$139>>2]|0;
    FUNCTION_TABLE_vii[$140 & 8191]($137,$0);
   }
  }
  $141 = ((($0)) + 136|0);
  $142 = HEAP8[$141>>0]|0;
  $143 = ($142<<24>>24)==(0);
  if (!($143)) {
   $144 = HEAP32[$119>>2]|0;
   $145 = ($120|0)==($144|0);
   $146 = ($144|0)==(0|0);
   $or$cond34 = $145 | $146;
   if ($or$cond34) {
    __ZN3osg5State22applyShaderCompositionEv($0);
   }
  }
  $147 = HEAP32[$5>>2]|0;
  $148 = ((($147)) + 92|0);
  $149 = ((($147)) + 100|0);
  $150 = HEAP32[$149>>2]|0;
  $151 = ($150|0)==(0);
  $152 = HEAP32[$22>>2]|0;
  $153 = ($152|0)==(0);
  do {
   if ($151) {
    $154 = ((($0)) + 600|0);
    if (!($153)) {
     __ZN3osg5State16applyUniformListERNSt3__23mapINS1_12basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEENS0_12UniformStackENS1_4lessIS8_EENS6_INS1_4pairIKS8_S9_EEEEEERKNS2_IS8_NSC_INS_7ref_ptrINS_7UniformEEEjEESB_NS6_INSC_ISD_SL_EEEEEE($0,$154,$19);
     break;
    }
    $155 = HEAP32[$119>>2]|0;
    $156 = ($155|0)==(0|0);
    if (!($156)) {
     $157 = HEAP32[$154>>2]|0;
     $158 = ((($0)) + 604|0);
     $159 = ($157|0)==($158|0);
     if (!($159)) {
      $$sroa$07$011$i = $157;
      while(1) {
       $160 = ((($$sroa$07$011$i)) + 28|0);
       $161 = HEAP32[$160>>2]|0;
       $162 = ((($$sroa$07$011$i)) + 32|0);
       $163 = HEAP32[$162>>2]|0;
       $164 = ($161|0)==($163|0);
       if (!($164)) {
        $165 = HEAP32[$119>>2]|0;
        $166 = ((($163)) + -8|0);
        $167 = HEAP32[$166>>2]|0;
        __ZNK3osg7Program17PerContextProgram5applyERKNS_7UniformE($165,$167);
       }
       $168 = ((($$sroa$07$011$i)) + 4|0);
       $169 = HEAP32[$168>>2]|0;
       $170 = ($169|0)==(0|0);
       if ($170) {
        $171 = ((($$sroa$07$011$i)) + 8|0);
        $172 = HEAP32[$171>>2]|0;
        $173 = HEAP32[$172>>2]|0;
        $174 = ($173|0)==($$sroa$07$011$i|0);
        if ($174) {
         $$sroa$07$0$be$i = $172;
        } else {
         $179 = $171;
         while(1) {
          $178 = HEAP32[$179>>2]|0;
          $180 = ((($178)) + 8|0);
          $181 = HEAP32[$180>>2]|0;
          $182 = HEAP32[$181>>2]|0;
          $183 = ($182|0)==($178|0);
          if ($183) {
           $$sroa$07$0$be$i = $181;
           break;
          } else {
           $179 = $180;
          }
         }
        }
       } else {
        $$0$i$i$i$i$i38 = $169;
        while(1) {
         $176 = HEAP32[$$0$i$i$i$i$i38>>2]|0;
         $177 = ($176|0)==(0|0);
         if ($177) {
          break;
         } else {
          $$0$i$i$i$i$i38 = $176;
         }
        }
        $$sroa$07$0$be$i = $$0$i$i$i$i$i38;
       }
       $175 = ($$sroa$07$0$be$i|0)==($158|0);
       if ($175) {
        break;
       } else {
        $$sroa$07$011$i = $$sroa$07$0$be$i;
       }
      }
     }
    }
   } else {
    if ($153) {
     $184 = ((($0)) + 600|0);
     __ZN3osg5State16applyUniformListERNSt3__23mapINS1_12basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEENS0_12UniformStackENS1_4lessIS8_EENS6_INS1_4pairIKS8_S9_EEEEEERKNS2_IS8_NSC_INS_7ref_ptrINS_7UniformEEEjEESB_NS6_INSC_ISD_SL_EEEEEE($0,$184,$148);
     break;
    }
    $185 = HEAP32[$148>>2]|0;
    $186 = ((($147)) + 96|0);
    $187 = ($185|0)==($186|0);
    L77: do {
     if (!($187)) {
      $188 = $20;
      $189 = ((($0)) + 152|0);
      $$sroa$044$0 = $185;
      while(1) {
       $190 = ((($$sroa$044$0)) + 16|0);
       HEAP32[$4>>2] = $188;
       ;HEAP32[$$byval_copy>>2]=HEAP32[$4>>2]|0;
       $191 = (__ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4pairIN3osg7ref_ptrINS9_7UniformEEEjEEEENS_19__map_value_compareIS7_SE_NS_4lessIS7_EELb1EEENS5_ISE_EEE12__find_equalIS7_EERPNS_16__tree_node_baseIPvEENS_21__tree_const_iteratorISE_PNS_11__tree_nodeISE_SN_EEiEERPNS_15__tree_end_nodeISP_EESQ_RKT_($19,$$byval_copy,$2,$3,$190)|0);
       $192 = HEAP32[$191>>2]|0;
       $193 = ($192|0)==(0|0);
       if ($193) {
        $194 = (__Znwj(36)|0);
        $195 = ((($194)) + 16|0);
        __THREW__ = 0;
        invoke_vii(3457,($195|0),($190|0));
        $196 = __THREW__; __THREW__ = 0;
        $197 = $196&1;
        if ($197) {
         break;
        }
        $198 = ((($194)) + 28|0);
        $199 = ((($$sroa$044$0)) + 28|0);
        $200 = HEAP32[$199>>2]|0;
        HEAP32[$198>>2] = $200;
        $201 = ($200|0)==(0|0);
        if (!($201)) {
         $202 = ((($200)) + 8|0);
         $203 = HEAP32[$202>>2]|0;HEAP32[$202>>2] = (($203+1)|0);
        }
        $206 = ((($194)) + 32|0);
        $207 = ((($$sroa$044$0)) + 32|0);
        $208 = HEAP32[$207>>2]|0;
        HEAP32[$206>>2] = $208;
        $209 = HEAP32[$2>>2]|0;
        HEAP32[$194>>2] = 0;
        $210 = ((($194)) + 4|0);
        HEAP32[$210>>2] = 0;
        $211 = ((($194)) + 8|0);
        HEAP32[$211>>2] = $209;
        HEAP32[$191>>2] = $194;
        $212 = HEAP32[$19>>2]|0;
        $213 = HEAP32[$212>>2]|0;
        $214 = ($213|0)==(0|0);
        if ($214) {
         $217 = $194;
        } else {
         $215 = $213;
         HEAP32[$19>>2] = $215;
         $$pre$i$i$i$i$i = HEAP32[$191>>2]|0;
         $217 = $$pre$i$i$i$i$i;
        }
        $216 = HEAP32[$189>>2]|0;
        __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($216,$217);
        $218 = HEAP32[$22>>2]|0;
        $219 = (($218) + 1)|0;
        HEAP32[$22>>2] = $219;
       }
       $220 = ((($$sroa$044$0)) + 4|0);
       $221 = HEAP32[$220>>2]|0;
       $222 = ($221|0)==(0|0);
       if ($222) {
        $223 = ((($$sroa$044$0)) + 8|0);
        $224 = HEAP32[$223>>2]|0;
        $225 = HEAP32[$224>>2]|0;
        $226 = ($225|0)==($$sroa$044$0|0);
        if ($226) {
         $$0$i$i$i$i = $224;
        } else {
         $230 = $223;
         while(1) {
          $229 = HEAP32[$230>>2]|0;
          $231 = ((($229)) + 8|0);
          $232 = HEAP32[$231>>2]|0;
          $233 = HEAP32[$232>>2]|0;
          $234 = ($233|0)==($229|0);
          if ($234) {
           $$0$i$i$i$i = $232;
           break;
          } else {
           $230 = $231;
          }
         }
        }
       } else {
        $$0$i$i$i$i$i = $221;
        while(1) {
         $227 = HEAP32[$$0$i$i$i$i$i>>2]|0;
         $228 = ($227|0)==(0|0);
         if ($228) {
          break;
         } else {
          $$0$i$i$i$i$i = $227;
         }
        }
        $$0$i$i$i$i = $$0$i$i$i$i$i;
       }
       $235 = ($$0$i$i$i$i|0)==($186|0);
       if ($235) {
        break L77;
       } else {
        $$sroa$044$0 = $$0$i$i$i$i;
       }
      }
      $204 = ___cxa_find_matching_catch_2()|0;
      $205 = tempRet0;
      __ZdlPv($194);
      ___resumeException($204|0);
      // unreachable;
     }
    } while(0);
    $236 = ((($0)) + 600|0);
    __ZN3osg5State16applyUniformListERNSt3__23mapINS1_12basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEENS0_12UniformStackENS1_4lessIS8_EENS6_INS1_4pairIKS8_S9_EEEEEERKNS2_IS8_NSC_INS_7ref_ptrINS_7UniformEEEjEESB_NS6_INSC_ISD_SL_EEEEEE($0,$236,$19);
   }
  } while(0);
  $237 = HEAP32[$5>>2]|0;
  $238 = ((($237)) + 104|0);
  __ZN3osg5State13popDefineListERNS0_9DefineMapERKNSt3__23mapINS3_12basic_stringIcNS3_11char_traitsIcEENS3_9allocatorIcEEEENS3_4pairISA_jEENS3_4lessISA_EENS8_INSB_IKSA_SC_EEEEEE($0,$124,$238);
  $239 = HEAP32[$11>>2]|0;
  $240 = ((($239)) + -4|0);
  HEAP32[$11>>2] = $240;
 }
 $241 = HEAP32[$6>>2]|0;
 $242 = ($241|0)==(2);
 if (!($242)) {
  STACKTOP = sp;return;
 }
 (__ZNK3osg5State13checkGLErrorsEPKcS2_(0,149869,0)|0);
 STACKTOP = sp;return;
}
function __ZNK3osg5State13checkGLErrorsEPKcS2_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = (_glGetError()|0);
 $5 = ($4|0)==(0);
 if ($5) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $6 = (__ZN3osg14gluErrorStringEj($4)|0);
 $7 = ($6|0)==(0|0);
 $8 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
 if ($7) {
  if ($8) {
   $13 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
   $14 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($13,150007,40)|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = ((($15)) + -12|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (($14) + ($17)|0);
   $19 = ((($18)) + 4|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = $20 & -75;
   $22 = $21 | 8;
   HEAP32[$19>>2] = $22;
   $23 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($14,$4)|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = ((($24)) + -12|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = (($23) + ($26)|0);
   $28 = ((($27)) + 4|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = $29 & -75;
   $31 = $30 | 2;
   HEAP32[$28>>2] = $31;
  }
 } else {
  if ($8) {
   $9 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
   $10 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($9,149946,32)|0);
   $11 = (_strlen($6)|0);
   $12 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($10,$6,$11)|0);
   (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($12,150128,1)|0);
  }
 }
 $32 = ($1|0)!=(0|0);
 $33 = ($2|0)!=(0|0);
 $or$cond = $32 | $33;
 $34 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
 if ($or$cond) {
  if ($34) {
   $35 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
   (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($35,150130,3)|0);
  }
  if ($32) {
   $36 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
   if ($36) {
    $37 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
    $38 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($37,159071,1)|0);
    $39 = (_strlen($1)|0);
    (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($38,$1,$39)|0);
   }
  }
  if ($33) {
   $40 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
   if ($40) {
    $41 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
    $42 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($41,159071,1)|0);
    $43 = (_strlen($2)|0);
    (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($42,$2,$43)|0);
   }
  }
 } else {
  if ($34) {
   $44 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
   (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($44,150134,15)|0);
  }
 }
 $45 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
 if (!($45)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $46 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = ((($47)) + -12|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = (($46) + ($49)|0);
 __ZNKSt3__28ios_base6getlocEv($3,$50);
 __THREW__ = 0;
 $51 = (invoke_iii(3255,($3|0),(215188|0))|0);
 $52 = __THREW__; __THREW__ = 0;
 $53 = $52&1;
 if (!($53)) {
  $54 = HEAP32[$51>>2]|0;
  $55 = ((($54)) + 28|0);
  $56 = HEAP32[$55>>2]|0;
  __THREW__ = 0;
  $57 = (invoke_iii($56|0,($51|0),10)|0);
  $58 = __THREW__; __THREW__ = 0;
  $59 = $58&1;
  if (!($59)) {
   __ZNSt3__26localeD2Ev($3);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($46,$57)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($46)|0);
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $60 = ___cxa_find_matching_catch_2()|0;
 $61 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($3|0));
 $62 = __THREW__; __THREW__ = 0;
 $63 = $62&1;
 if ($63) {
  $64 = ___cxa_find_matching_catch_3(0|0)|0;
  $65 = tempRet0;
  ___clang_call_terminate($64);
  // unreachable;
 } else {
  ___resumeException($60|0);
  // unreachable;
 }
 return (0)|0;
}
function __ZN3osg5State22applyModeListOnTexUnitEjRNSt3__23mapIjNS0_9ModeStackENS1_4lessIjEENS1_9allocatorINS1_4pairIKjS3_EEEEEERKNS2_IjjS5_NS6_INS7_IS8_jEEEEEE($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i108 = 0, $$0$i$i$i$i115 = 0, $$0$i$i$i$i122 = 0, $$0$i$i$i$i59 = 0, $$0$i$i$i$i81 = 0, $$0$i$i$i126 = 0, $$0$i$i92 = 0, $$0$ph$i$i = 0, $$0$ph$i$i89 = 0, $$014$i = 0, $$014$i101 = 0, $$024$i$i = 0, $$024$i$i91 = 0, $$025$i$i = 0, $$025$i$i94 = 0, $$025$i65$i = 0, $$025$i65$i96 = 0, $$049$i = 0;
 var $$049$i93 = 0, $$04964$i = 0, $$04964$i97 = 0, $$in$i$i = 0, $$in$i$i88 = 0, $$not = 0, $$not176 = 0, $$not176207 = 0, $$not206 = 0, $$pre = 0, $$pre$i$i = 0, $$pre$i$i99 = 0, $$sroa$0143$0$be = 0, $$sroa$0143$0$lcssa = 0, $$sroa$0143$0209 = 0, $$sroa$0143$1$be = 0, $$sroa$0143$1204 = 0, $$sroa$0159$0$be = 0, $$sroa$0159$0$lcssa = 0, $$sroa$0159$0210 = 0;
 var $$sroa$0159$1$be = 0, $$sroa$0159$1203 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0;
 var $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0;
 var $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0;
 var $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0;
 var $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0;
 var $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0;
 var $298 = 0, $299 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0;
 var $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0;
 var $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0;
 var $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0;
 var $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0;
 var $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0;
 var $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $brmerge = 0, $brmerge208 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$2>>2]|0;
 $6 = ((($2)) + 4|0);
 $7 = ((($3)) + 4|0);
 $$not206 = ($5|0)==($6|0);
 $$not176207 = ($4|0)==($7|0);
 $brmerge208 = $$not206 | $$not176207;
 if ($brmerge208) {
  $$sroa$0143$0$lcssa = $5;$$sroa$0159$0$lcssa = $4;
 } else {
  $8 = ((($0)) + 688|0);
  $9 = ((($0)) + 344|0);
  $10 = ((($0)) + 728|0);
  $11 = ($1|0)==(0);
  $12 = ((($0)) + 716|0);
  $13 = ((($0)) + 720|0);
  $14 = (($1) + 33984)|0;
  $15 = ((($2)) + 4|0);
  $16 = ((($2)) + 8|0);
  $$sroa$0143$0209 = $5;$$sroa$0159$0210 = $4;
  while(1) {
   $25 = ((($$sroa$0143$0209)) + 16|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = ((($$sroa$0159$0210)) + 16|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = ($26>>>0)<($28>>>0);
   L5: do {
    if ($29) {
     $30 = ((($$sroa$0143$0209)) + 20|0);
     $31 = ((($25)) + 5|0);
     $32 = HEAP8[$31>>0]|0;
     $33 = ($32<<24>>24)==(0);
     L7: do {
      if (!($33)) {
       HEAP8[$31>>0] = 0;
       $34 = ((($$sroa$0143$0209)) + 24|0);
       $35 = HEAP32[$34>>2]|0;
       $36 = ((($$sroa$0143$0209)) + 28|0);
       $37 = HEAP32[$36>>2]|0;
       $38 = ($35|0)==($37|0);
       if ($38) {
        $61 = ((($25)) + 7|0);
        $62 = HEAP8[$61>>0]|0;
        $63 = ($62<<24>>24)==(0);
        $64 = HEAP8[$30>>0]|0;
        $65 = ($64<<24>>24)==(0);
        if ($65) {
         break;
        }
        $66 = ((($30)) + 2|0);
        $67 = HEAP8[$66>>0]|0;
        $68 = ($67<<24>>24)==($62<<24>>24);
        if ($68) {
         break;
        }
        $69 = HEAP32[$8>>2]|0;
        $70 = ($69|0)==($1|0);
        do {
         if (!($70)) {
          $71 = HEAP32[$10>>2]|0;
          $72 = ($71|0)==(0|0);
          if (!($72)) {
           $73 = HEAP32[$12>>2]|0;
           $74 = HEAP32[$13>>2]|0;
           $75 = ($73|0)>($74|0);
           $76 = $75 ? $73 : $74;
           $77 = ($76>>>0)>($1>>>0);
           if ($77) {
            FUNCTION_TABLE_vi[$71 & 8191]($14);
            HEAP32[$8>>2] = $1;
            break;
           }
          }
          if (!($11)) {
           break L7;
          }
         }
        } while(0);
        HEAP8[$66>>0] = $62;
        if ($63) {
         _glDisable(($26|0));
        } else {
         _glEnable(($26|0));
        }
        $78 = HEAP32[$9>>2]|0;
        $79 = ($78|0)==(2);
        if (!($79)) {
         break;
        }
        (__ZNK3osg5State13checkGLErrorsEj(0,$26)|0);
        break;
       } else {
        $39 = ((($37)) + -4|0);
        $40 = HEAP32[$39>>2]|0;
        $41 = $40 & 1;
        $42 = ($41|0)==(0);
        $43 = $41&255;
        $44 = HEAP8[$30>>0]|0;
        $45 = ($44<<24>>24)==(0);
        if ($45) {
         break;
        }
        $46 = ((($30)) + 2|0);
        $47 = HEAP8[$46>>0]|0;
        $48 = $47&255;
        $49 = ($48|0)==($41|0);
        if ($49) {
         break;
        }
        $50 = HEAP32[$8>>2]|0;
        $51 = ($50|0)==($1|0);
        do {
         if (!($51)) {
          $52 = HEAP32[$10>>2]|0;
          $53 = ($52|0)==(0|0);
          if (!($53)) {
           $54 = HEAP32[$12>>2]|0;
           $55 = HEAP32[$13>>2]|0;
           $56 = ($54|0)>($55|0);
           $57 = $56 ? $54 : $55;
           $58 = ($57>>>0)>($1>>>0);
           if ($58) {
            FUNCTION_TABLE_vi[$52 & 8191]($14);
            HEAP32[$8>>2] = $1;
            break;
           }
          }
          if (!($11)) {
           break L7;
          }
         }
        } while(0);
        HEAP8[$46>>0] = $43;
        if ($42) {
         _glDisable(($26|0));
        } else {
         _glEnable(($26|0));
        }
        $59 = HEAP32[$9>>2]|0;
        $60 = ($59|0)==(2);
        if (!($60)) {
         break;
        }
        (__ZNK3osg5State13checkGLErrorsEj(0,$26)|0);
        break;
       }
      }
     } while(0);
     $80 = ((($$sroa$0143$0209)) + 4|0);
     $81 = HEAP32[$80>>2]|0;
     $82 = ($81|0)==(0|0);
     if ($82) {
      $83 = ((($$sroa$0143$0209)) + 8|0);
      $84 = HEAP32[$83>>2]|0;
      $85 = HEAP32[$84>>2]|0;
      $86 = ($85|0)==($$sroa$0143$0209|0);
      if ($86) {
       $$sroa$0143$0$be = $84;$$sroa$0159$0$be = $$sroa$0159$0210;
       break;
      } else {
       $90 = $83;
      }
      while(1) {
       $89 = HEAP32[$90>>2]|0;
       $91 = ((($89)) + 8|0);
       $92 = HEAP32[$91>>2]|0;
       $93 = HEAP32[$92>>2]|0;
       $94 = ($93|0)==($89|0);
       if ($94) {
        $$sroa$0143$0$be = $92;$$sroa$0159$0$be = $$sroa$0159$0210;
        break;
       } else {
        $90 = $91;
       }
      }
     } else {
      $$0$i$i$i$i81 = $81;
      while(1) {
       $87 = HEAP32[$$0$i$i$i$i81>>2]|0;
       $88 = ($87|0)==(0|0);
       if ($88) {
        break;
       } else {
        $$0$i$i$i$i81 = $87;
       }
      }
      $$sroa$0143$0$be = $$0$i$i$i$i81;$$sroa$0159$0$be = $$sroa$0159$0210;
      break;
     }
    } else {
     $95 = ($28>>>0)<($26>>>0);
     if ($95) {
      $96 = HEAP32[$6>>2]|0;
      $97 = ($96|0)==(0|0);
      do {
       if ($97) {
        $$025$i$i94 = $6;$$049$i93 = $6;$107 = $96;
        label = 48;
       } else {
        $$0$i$i92 = $15;$$024$i$i91 = $96;$414 = $96;
        while(1) {
         $98 = ((($$024$i$i91)) + 16|0);
         $99 = HEAP32[$98>>2]|0;
         $100 = ($28>>>0)<($99>>>0);
         if ($100) {
          $101 = HEAP32[$$024$i$i91>>2]|0;
          $102 = ($101|0)==(0|0);
          if ($102) {
           label = 43;
           break;
          } else {
           $$0$ph$i$i89 = $$024$i$i91;$$in$i$i88 = $101;
          }
         } else {
          $103 = ($99>>>0)<($28>>>0);
          if (!($103)) {
           label = 47;
           break;
          }
          $104 = ((($$024$i$i91)) + 4|0);
          $105 = HEAP32[$104>>2]|0;
          $106 = ($105|0)==(0|0);
          if ($106) {
           label = 46;
           break;
          } else {
           $$0$ph$i$i89 = $104;$$in$i$i88 = $105;
          }
         }
         $$0$i$i92 = $$0$ph$i$i89;$$024$i$i91 = $$in$i$i88;$414 = $$in$i$i88;
        }
        if ((label|0) == 43) {
         label = 0;
         $$025$i65$i96 = $$024$i$i91;$$04964$i97 = $$024$i$i91;
         label = 49;
         break;
        }
        else if ((label|0) == 46) {
         label = 0;
         $$025$i65$i96 = $104;$$04964$i97 = $$024$i$i91;
         label = 49;
         break;
        }
        else if ((label|0) == 47) {
         label = 0;
         $$025$i$i94 = $$0$i$i92;$$049$i93 = $$024$i$i91;$107 = $414;
         label = 48;
         break;
        }
       }
      } while(0);
      if ((label|0) == 48) {
       label = 0;
       $108 = ($107|0)==(0|0);
       if ($108) {
        $$025$i65$i96 = $$025$i$i94;$$04964$i97 = $$049$i93;
        label = 49;
       } else {
        $$014$i101 = $107;$150 = $28;
       }
      }
      if ((label|0) == 49) {
       label = 0;
       $109 = (__Znwj(36)|0);
       $110 = ((($109)) + 16|0);
       $111 = HEAP32[$27>>2]|0;
       HEAP32[$110>>2] = $111;
       $112 = ((($109)) + 20|0);
       $113 = ((($109)) + 24|0);
       HEAP32[$113>>2] = 0;
       $114 = ((($109)) + 28|0);
       HEAP32[$114>>2] = 0;
       $115 = ((($109)) + 32|0);
       HEAP32[$115>>2] = 0;
       HEAP8[$112>>0] = 1;
       $116 = ((($109)) + 21|0);
       HEAP8[$116>>0] = 0;
       $117 = ((($109)) + 22|0);
       HEAP8[$117>>0] = 0;
       $118 = ((($109)) + 23|0);
       HEAP8[$118>>0] = 0;
       HEAP32[$109>>2] = 0;
       $119 = ((($109)) + 4|0);
       HEAP32[$119>>2] = 0;
       $120 = ((($109)) + 8|0);
       HEAP32[$120>>2] = $$04964$i97;
       HEAP32[$$025$i65$i96>>2] = $109;
       $121 = HEAP32[$2>>2]|0;
       $122 = HEAP32[$121>>2]|0;
       $123 = ($122|0)==(0|0);
       if ($123) {
        $126 = $109;
       } else {
        $124 = $122;
        HEAP32[$2>>2] = $124;
        $$pre$i$i99 = HEAP32[$$025$i65$i96>>2]|0;
        $126 = $$pre$i$i99;
       }
       $125 = HEAP32[$15>>2]|0;
       __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($125,$126);
       $127 = HEAP32[$16>>2]|0;
       $128 = (($127) + 1)|0;
       HEAP32[$16>>2] = $128;
       $$pre = HEAP32[$27>>2]|0;
       $$014$i101 = $109;$150 = $$pre;
      }
      $129 = ((($$sroa$0159$0210)) + 20|0);
      $130 = HEAP32[$129>>2]|0;
      $131 = $130 & 1;
      $132 = ($131|0)==(0);
      $133 = $131&255;
      $134 = ((($$014$i101)) + 20|0);
      $135 = HEAP8[$134>>0]|0;
      $136 = ($135<<24>>24)==(0);
      L71: do {
       if (!($136)) {
        $137 = ((($$014$i101)) + 22|0);
        $138 = HEAP8[$137>>0]|0;
        $139 = $138&255;
        $140 = ($139|0)==($131|0);
        if (!($140)) {
         $141 = HEAP32[$8>>2]|0;
         $142 = ($141|0)==($1|0);
         do {
          if (!($142)) {
           $143 = HEAP32[$10>>2]|0;
           $144 = ($143|0)==(0|0);
           if (!($144)) {
            $145 = HEAP32[$12>>2]|0;
            $146 = HEAP32[$13>>2]|0;
            $147 = ($145|0)>($146|0);
            $148 = $147 ? $145 : $146;
            $149 = ($148>>>0)>($1>>>0);
            if ($149) {
             FUNCTION_TABLE_vi[$143 & 8191]($14);
             HEAP32[$8>>2] = $1;
             break;
            }
           }
           if (!($11)) {
            break L71;
           }
          }
         } while(0);
         HEAP8[$137>>0] = $133;
         if ($132) {
          _glDisable(($150|0));
         } else {
          _glEnable(($150|0));
         }
         $151 = HEAP32[$9>>2]|0;
         $152 = ($151|0)==(2);
         if ($152) {
          (__ZNK3osg5State13checkGLErrorsEj(0,$150)|0);
         }
        }
       }
      } while(0);
      $153 = ((($$014$i101)) + 21|0);
      HEAP8[$153>>0] = 1;
      $154 = ((($$sroa$0159$0210)) + 4|0);
      $155 = HEAP32[$154>>2]|0;
      $156 = ($155|0)==(0|0);
      if ($156) {
       $157 = ((($$sroa$0159$0210)) + 8|0);
       $158 = HEAP32[$157>>2]|0;
       $159 = HEAP32[$158>>2]|0;
       $160 = ($159|0)==($$sroa$0159$0210|0);
       if ($160) {
        $$sroa$0143$0$be = $$sroa$0143$0209;$$sroa$0159$0$be = $158;
        break;
       } else {
        $164 = $157;
       }
       while(1) {
        $163 = HEAP32[$164>>2]|0;
        $165 = ((($163)) + 8|0);
        $166 = HEAP32[$165>>2]|0;
        $167 = HEAP32[$166>>2]|0;
        $168 = ($167|0)==($163|0);
        if ($168) {
         $$sroa$0143$0$be = $$sroa$0143$0209;$$sroa$0159$0$be = $166;
         break L5;
        } else {
         $164 = $165;
        }
       }
      } else {
       $$0$i$i$i$i108 = $155;
       while(1) {
        $161 = HEAP32[$$0$i$i$i$i108>>2]|0;
        $162 = ($161|0)==(0|0);
        if ($162) {
         break;
        } else {
         $$0$i$i$i$i108 = $161;
        }
       }
       $$sroa$0143$0$be = $$sroa$0143$0209;$$sroa$0159$0$be = $$0$i$i$i$i108;
       break;
      }
     }
     $169 = ((($$sroa$0143$0209)) + 20|0);
     $170 = ((($$sroa$0143$0209)) + 24|0);
     $171 = HEAP32[$170>>2]|0;
     $172 = ((($$sroa$0143$0209)) + 28|0);
     $173 = HEAP32[$172>>2]|0;
     $174 = ($171|0)==($173|0);
     L95: do {
      if ($174) {
       label = 85;
      } else {
       $175 = ((($173)) + -4|0);
       $176 = HEAP32[$175>>2]|0;
       $177 = $176 & 2;
       $178 = ($177|0)==(0);
       if ($178) {
        label = 85;
       } else {
        $179 = ((($$sroa$0159$0210)) + 20|0);
        $180 = HEAP32[$179>>2]|0;
        $181 = $180 & 4;
        $182 = ($181|0)==(0);
        if ($182) {
         $183 = ((($25)) + 5|0);
         $184 = HEAP8[$183>>0]|0;
         $185 = ($184<<24>>24)==(0);
         if (!($185)) {
          HEAP8[$183>>0] = 0;
          $186 = $176 & 1;
          $187 = ($186|0)==(0);
          $188 = $186&255;
          $189 = HEAP8[$169>>0]|0;
          $190 = ($189<<24>>24)==(0);
          if (!($190)) {
           $191 = ((($169)) + 2|0);
           $192 = HEAP8[$191>>0]|0;
           $193 = $192&255;
           $194 = ($193|0)==($186|0);
           if (!($194)) {
            $195 = HEAP32[$8>>2]|0;
            $196 = ($195|0)==($1|0);
            do {
             if (!($196)) {
              $197 = HEAP32[$10>>2]|0;
              $198 = ($197|0)==(0|0);
              if (!($198)) {
               $199 = HEAP32[$12>>2]|0;
               $200 = HEAP32[$13>>2]|0;
               $201 = ($199|0)>($200|0);
               $202 = $201 ? $199 : $200;
               $203 = ($202>>>0)>($1>>>0);
               if ($203) {
                FUNCTION_TABLE_vi[$197 & 8191]($14);
                HEAP32[$8>>2] = $1;
                break;
               }
              }
              if (!($11)) {
               break L95;
              }
             }
            } while(0);
            HEAP8[$191>>0] = $188;
            if ($187) {
             _glDisable(($26|0));
            } else {
             _glEnable(($26|0));
            }
            $204 = HEAP32[$9>>2]|0;
            $205 = ($204|0)==(2);
            if ($205) {
             (__ZNK3osg5State13checkGLErrorsEj(0,$26)|0);
            }
           }
          }
         }
        } else {
         label = 85;
        }
       }
      }
     } while(0);
     L114: do {
      if ((label|0) == 85) {
       label = 0;
       $206 = ((($$sroa$0159$0210)) + 20|0);
       $207 = HEAP32[$206>>2]|0;
       $208 = $207 & 1;
       $209 = ($208|0)==(0);
       $210 = $208&255;
       $211 = HEAP8[$169>>0]|0;
       $212 = ($211<<24>>24)==(0);
       if (!($212)) {
        $213 = ((($169)) + 2|0);
        $214 = HEAP8[$213>>0]|0;
        $215 = $214&255;
        $216 = ($215|0)==($208|0);
        if (!($216)) {
         $217 = HEAP32[$8>>2]|0;
         $218 = ($217|0)==($1|0);
         do {
          if (!($218)) {
           $219 = HEAP32[$10>>2]|0;
           $220 = ($219|0)==(0|0);
           if (!($220)) {
            $221 = HEAP32[$12>>2]|0;
            $222 = HEAP32[$13>>2]|0;
            $223 = ($221|0)>($222|0);
            $224 = $223 ? $221 : $222;
            $225 = ($224>>>0)>($1>>>0);
            if ($225) {
             FUNCTION_TABLE_vi[$219 & 8191]($14);
             HEAP32[$8>>2] = $1;
             break;
            }
           }
           if (!($11)) {
            break L114;
           }
          }
         } while(0);
         HEAP8[$213>>0] = $210;
         if ($209) {
          _glDisable(($28|0));
         } else {
          _glEnable(($28|0));
         }
         $226 = HEAP32[$9>>2]|0;
         $227 = ($226|0)==(2);
         if ($227) {
          (__ZNK3osg5State13checkGLErrorsEj(0,$28)|0);
         }
         $228 = ((($25)) + 5|0);
         HEAP8[$228>>0] = 1;
        }
       }
      }
     } while(0);
     $229 = ((($$sroa$0143$0209)) + 4|0);
     $230 = HEAP32[$229>>2]|0;
     $231 = ($230|0)==(0|0);
     if ($231) {
      $232 = ((($$sroa$0143$0209)) + 8|0);
      $233 = HEAP32[$232>>2]|0;
      $234 = HEAP32[$233>>2]|0;
      $235 = ($234|0)==($$sroa$0143$0209|0);
      if ($235) {
       $$0$i$i$i126 = $233;
      } else {
       $239 = $232;
       while(1) {
        $238 = HEAP32[$239>>2]|0;
        $240 = ((($238)) + 8|0);
        $241 = HEAP32[$240>>2]|0;
        $242 = HEAP32[$241>>2]|0;
        $243 = ($242|0)==($238|0);
        if ($243) {
         $$0$i$i$i126 = $241;
         break;
        } else {
         $239 = $240;
        }
       }
      }
     } else {
      $$0$i$i$i$i122 = $230;
      while(1) {
       $236 = HEAP32[$$0$i$i$i$i122>>2]|0;
       $237 = ($236|0)==(0|0);
       if ($237) {
        break;
       } else {
        $$0$i$i$i$i122 = $236;
       }
      }
      $$0$i$i$i126 = $$0$i$i$i$i122;
     }
     $244 = ((($$sroa$0159$0210)) + 4|0);
     $245 = HEAP32[$244>>2]|0;
     $246 = ($245|0)==(0|0);
     if ($246) {
      $247 = ((($$sroa$0159$0210)) + 8|0);
      $248 = HEAP32[$247>>2]|0;
      $249 = HEAP32[$248>>2]|0;
      $250 = ($249|0)==($$sroa$0159$0210|0);
      if ($250) {
       $$sroa$0143$0$be = $$0$i$i$i126;$$sroa$0159$0$be = $248;
       break;
      } else {
       $254 = $247;
      }
      while(1) {
       $253 = HEAP32[$254>>2]|0;
       $255 = ((($253)) + 8|0);
       $256 = HEAP32[$255>>2]|0;
       $257 = HEAP32[$256>>2]|0;
       $258 = ($257|0)==($253|0);
       if ($258) {
        $$sroa$0143$0$be = $$0$i$i$i126;$$sroa$0159$0$be = $256;
        break;
       } else {
        $254 = $255;
       }
      }
     } else {
      $$0$i$i$i$i115 = $245;
      while(1) {
       $251 = HEAP32[$$0$i$i$i$i115>>2]|0;
       $252 = ($251|0)==(0|0);
       if ($252) {
        break;
       } else {
        $$0$i$i$i$i115 = $251;
       }
      }
      $$sroa$0143$0$be = $$0$i$i$i126;$$sroa$0159$0$be = $$0$i$i$i$i115;
      break;
     }
    }
   } while(0);
   $$not = ($$sroa$0143$0$be|0)==($6|0);
   $$not176 = ($$sroa$0159$0$be|0)==($7|0);
   $brmerge = $$not | $$not176;
   if ($brmerge) {
    $$sroa$0143$0$lcssa = $$sroa$0143$0$be;$$sroa$0159$0$lcssa = $$sroa$0159$0$be;
    break;
   } else {
    $$sroa$0143$0209 = $$sroa$0143$0$be;$$sroa$0159$0210 = $$sroa$0159$0$be;
   }
  }
 }
 $17 = ($$sroa$0143$0$lcssa|0)==($6|0);
 if (!($17)) {
  $18 = ((($0)) + 688|0);
  $19 = ((($0)) + 344|0);
  $20 = ((($0)) + 728|0);
  $21 = ($1|0)==(0);
  $22 = ((($0)) + 716|0);
  $23 = ((($0)) + 720|0);
  $24 = (($1) + 33984)|0;
  $$sroa$0143$1204 = $$sroa$0143$0$lcssa;
  while(1) {
   $269 = ((($$sroa$0143$1204)) + 16|0);
   $270 = ((($$sroa$0143$1204)) + 20|0);
   $271 = ((($269)) + 5|0);
   $272 = HEAP8[$271>>0]|0;
   $273 = ($272<<24>>24)==(0);
   L154: do {
    if (!($273)) {
     HEAP8[$271>>0] = 0;
     $274 = ((($$sroa$0143$1204)) + 24|0);
     $275 = HEAP32[$274>>2]|0;
     $276 = ((($$sroa$0143$1204)) + 28|0);
     $277 = HEAP32[$276>>2]|0;
     $278 = ($275|0)==($277|0);
     if ($278) {
      $302 = HEAP32[$269>>2]|0;
      $303 = ((($269)) + 7|0);
      $304 = HEAP8[$303>>0]|0;
      $305 = ($304<<24>>24)==(0);
      $306 = HEAP8[$270>>0]|0;
      $307 = ($306<<24>>24)==(0);
      if ($307) {
       break;
      }
      $308 = ((($270)) + 2|0);
      $309 = HEAP8[$308>>0]|0;
      $310 = ($309<<24>>24)==($304<<24>>24);
      if ($310) {
       break;
      }
      $311 = HEAP32[$18>>2]|0;
      $312 = ($311|0)==($1|0);
      do {
       if (!($312)) {
        $313 = HEAP32[$20>>2]|0;
        $314 = ($313|0)==(0|0);
        if (!($314)) {
         $315 = HEAP32[$22>>2]|0;
         $316 = HEAP32[$23>>2]|0;
         $317 = ($315|0)>($316|0);
         $318 = $317 ? $315 : $316;
         $319 = ($318>>>0)>($1>>>0);
         if ($319) {
          FUNCTION_TABLE_vi[$313 & 8191]($24);
          HEAP32[$18>>2] = $1;
          break;
         }
        }
        if (!($21)) {
         break L154;
        }
       }
      } while(0);
      HEAP8[$308>>0] = $304;
      if ($305) {
       _glDisable(($302|0));
      } else {
       _glEnable(($302|0));
      }
      $320 = HEAP32[$19>>2]|0;
      $321 = ($320|0)==(2);
      if (!($321)) {
       break;
      }
      (__ZNK3osg5State13checkGLErrorsEj(0,$302)|0);
      break;
     } else {
      $279 = ((($277)) + -4|0);
      $280 = HEAP32[$279>>2]|0;
      $281 = $280 & 1;
      $282 = ($281|0)==(0);
      $283 = HEAP32[$269>>2]|0;
      $284 = $281&255;
      $285 = HEAP8[$270>>0]|0;
      $286 = ($285<<24>>24)==(0);
      if ($286) {
       break;
      }
      $287 = ((($270)) + 2|0);
      $288 = HEAP8[$287>>0]|0;
      $289 = $288&255;
      $290 = ($289|0)==($281|0);
      if ($290) {
       break;
      }
      $291 = HEAP32[$18>>2]|0;
      $292 = ($291|0)==($1|0);
      do {
       if (!($292)) {
        $293 = HEAP32[$20>>2]|0;
        $294 = ($293|0)==(0|0);
        if (!($294)) {
         $295 = HEAP32[$22>>2]|0;
         $296 = HEAP32[$23>>2]|0;
         $297 = ($295|0)>($296|0);
         $298 = $297 ? $295 : $296;
         $299 = ($298>>>0)>($1>>>0);
         if ($299) {
          FUNCTION_TABLE_vi[$293 & 8191]($24);
          HEAP32[$18>>2] = $1;
          break;
         }
        }
        if (!($21)) {
         break L154;
        }
       }
      } while(0);
      HEAP8[$287>>0] = $284;
      if ($282) {
       _glDisable(($283|0));
      } else {
       _glEnable(($283|0));
      }
      $300 = HEAP32[$19>>2]|0;
      $301 = ($300|0)==(2);
      if (!($301)) {
       break;
      }
      (__ZNK3osg5State13checkGLErrorsEj(0,$283)|0);
      break;
     }
    }
   } while(0);
   $322 = ((($$sroa$0143$1204)) + 4|0);
   $323 = HEAP32[$322>>2]|0;
   $324 = ($323|0)==(0|0);
   if ($324) {
    $325 = ((($$sroa$0143$1204)) + 8|0);
    $326 = HEAP32[$325>>2]|0;
    $327 = HEAP32[$326>>2]|0;
    $328 = ($327|0)==($$sroa$0143$1204|0);
    if ($328) {
     $$sroa$0143$1$be = $326;
    } else {
     $333 = $325;
     while(1) {
      $332 = HEAP32[$333>>2]|0;
      $334 = ((($332)) + 8|0);
      $335 = HEAP32[$334>>2]|0;
      $336 = HEAP32[$335>>2]|0;
      $337 = ($336|0)==($332|0);
      if ($337) {
       $$sroa$0143$1$be = $335;
       break;
      } else {
       $333 = $334;
      }
     }
    }
   } else {
    $$0$i$i$i$i59 = $323;
    while(1) {
     $330 = HEAP32[$$0$i$i$i$i59>>2]|0;
     $331 = ($330|0)==(0|0);
     if ($331) {
      break;
     } else {
      $$0$i$i$i$i59 = $330;
     }
    }
    $$sroa$0143$1$be = $$0$i$i$i$i59;
   }
   $329 = ($$sroa$0143$1$be|0)==($6|0);
   if ($329) {
    break;
   } else {
    $$sroa$0143$1204 = $$sroa$0143$1$be;
   }
  }
 }
 $259 = ($$sroa$0159$0$lcssa|0)==($7|0);
 if ($259) {
  return;
 }
 $260 = ((($2)) + 4|0);
 $261 = ((($2)) + 8|0);
 $262 = ((($0)) + 688|0);
 $263 = ((($0)) + 344|0);
 $264 = ((($0)) + 728|0);
 $265 = ($1|0)==(0);
 $266 = ((($0)) + 716|0);
 $267 = ((($0)) + 720|0);
 $268 = (($1) + 33984)|0;
 $$sroa$0159$1203 = $$sroa$0159$0$lcssa;
 while(1) {
  $338 = ((($$sroa$0159$1203)) + 16|0);
  $339 = HEAP32[$6>>2]|0;
  $340 = ($339|0)==(0|0);
  do {
   if ($340) {
    $$025$i$i = $6;$$049$i = $6;$351 = $339;
    label = 152;
   } else {
    $341 = HEAP32[$338>>2]|0;
    $$0$i$i = $260;$$024$i$i = $339;$415 = $339;
    while(1) {
     $342 = ((($$024$i$i)) + 16|0);
     $343 = HEAP32[$342>>2]|0;
     $344 = ($341>>>0)<($343>>>0);
     if ($344) {
      $345 = HEAP32[$$024$i$i>>2]|0;
      $346 = ($345|0)==(0|0);
      if ($346) {
       label = 147;
       break;
      } else {
       $$0$ph$i$i = $$024$i$i;$$in$i$i = $345;
      }
     } else {
      $347 = ($343>>>0)<($341>>>0);
      if (!($347)) {
       label = 151;
       break;
      }
      $348 = ((($$024$i$i)) + 4|0);
      $349 = HEAP32[$348>>2]|0;
      $350 = ($349|0)==(0|0);
      if ($350) {
       label = 150;
       break;
      } else {
       $$0$ph$i$i = $348;$$in$i$i = $349;
      }
     }
     $$0$i$i = $$0$ph$i$i;$$024$i$i = $$in$i$i;$415 = $$in$i$i;
    }
    if ((label|0) == 147) {
     label = 0;
     $$025$i65$i = $$024$i$i;$$04964$i = $$024$i$i;
     label = 153;
     break;
    }
    else if ((label|0) == 150) {
     label = 0;
     $$025$i65$i = $348;$$04964$i = $$024$i$i;
     label = 153;
     break;
    }
    else if ((label|0) == 151) {
     label = 0;
     $$025$i$i = $$0$i$i;$$049$i = $$024$i$i;$351 = $415;
     label = 152;
     break;
    }
   }
  } while(0);
  if ((label|0) == 152) {
   label = 0;
   $352 = ($351|0)==(0|0);
   if ($352) {
    $$025$i65$i = $$025$i$i;$$04964$i = $$049$i;
    label = 153;
   } else {
    $$014$i = $351;
   }
  }
  if ((label|0) == 153) {
   label = 0;
   $353 = (__Znwj(36)|0);
   $354 = ((($353)) + 16|0);
   $355 = HEAP32[$338>>2]|0;
   HEAP32[$354>>2] = $355;
   $356 = ((($353)) + 20|0);
   $357 = ((($353)) + 24|0);
   HEAP32[$357>>2] = 0;
   $358 = ((($353)) + 28|0);
   HEAP32[$358>>2] = 0;
   $359 = ((($353)) + 32|0);
   HEAP32[$359>>2] = 0;
   HEAP8[$356>>0] = 1;
   $360 = ((($353)) + 21|0);
   HEAP8[$360>>0] = 0;
   $361 = ((($353)) + 22|0);
   HEAP8[$361>>0] = 0;
   $362 = ((($353)) + 23|0);
   HEAP8[$362>>0] = 0;
   HEAP32[$353>>2] = 0;
   $363 = ((($353)) + 4|0);
   HEAP32[$363>>2] = 0;
   $364 = ((($353)) + 8|0);
   HEAP32[$364>>2] = $$04964$i;
   HEAP32[$$025$i65$i>>2] = $353;
   $365 = HEAP32[$2>>2]|0;
   $366 = HEAP32[$365>>2]|0;
   $367 = ($366|0)==(0|0);
   if ($367) {
    $370 = $353;
   } else {
    $368 = $366;
    HEAP32[$2>>2] = $368;
    $$pre$i$i = HEAP32[$$025$i65$i>>2]|0;
    $370 = $$pre$i$i;
   }
   $369 = HEAP32[$260>>2]|0;
   __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($369,$370);
   $371 = HEAP32[$261>>2]|0;
   $372 = (($371) + 1)|0;
   HEAP32[$261>>2] = $372;
   $$014$i = $353;
  }
  $373 = ((($$sroa$0159$1203)) + 20|0);
  $374 = HEAP32[$373>>2]|0;
  $375 = $374 & 1;
  $376 = ($375|0)==(0);
  $377 = HEAP32[$338>>2]|0;
  $378 = $375&255;
  $379 = ((($$014$i)) + 20|0);
  $380 = HEAP8[$379>>0]|0;
  $381 = ($380<<24>>24)==(0);
  L223: do {
   if (!($381)) {
    $382 = ((($$014$i)) + 22|0);
    $383 = HEAP8[$382>>0]|0;
    $384 = $383&255;
    $385 = ($384|0)==($375|0);
    if (!($385)) {
     $386 = HEAP32[$262>>2]|0;
     $387 = ($386|0)==($1|0);
     do {
      if (!($387)) {
       $388 = HEAP32[$264>>2]|0;
       $389 = ($388|0)==(0|0);
       if (!($389)) {
        $390 = HEAP32[$266>>2]|0;
        $391 = HEAP32[$267>>2]|0;
        $392 = ($390|0)>($391|0);
        $393 = $392 ? $390 : $391;
        $394 = ($393>>>0)>($1>>>0);
        if ($394) {
         FUNCTION_TABLE_vi[$388 & 8191]($268);
         HEAP32[$262>>2] = $1;
         break;
        }
       }
       if (!($265)) {
        break L223;
       }
      }
     } while(0);
     HEAP8[$382>>0] = $378;
     if ($376) {
      _glDisable(($377|0));
     } else {
      _glEnable(($377|0));
     }
     $395 = HEAP32[$263>>2]|0;
     $396 = ($395|0)==(2);
     if ($396) {
      (__ZNK3osg5State13checkGLErrorsEj(0,$377)|0);
     }
    }
   }
  } while(0);
  $397 = ((($$014$i)) + 21|0);
  HEAP8[$397>>0] = 1;
  $398 = ((($$sroa$0159$1203)) + 4|0);
  $399 = HEAP32[$398>>2]|0;
  $400 = ($399|0)==(0|0);
  if ($400) {
   $401 = ((($$sroa$0159$1203)) + 8|0);
   $402 = HEAP32[$401>>2]|0;
   $403 = HEAP32[$402>>2]|0;
   $404 = ($403|0)==($$sroa$0159$1203|0);
   if ($404) {
    $$sroa$0159$1$be = $402;
   } else {
    $409 = $401;
    while(1) {
     $408 = HEAP32[$409>>2]|0;
     $410 = ((($408)) + 8|0);
     $411 = HEAP32[$410>>2]|0;
     $412 = HEAP32[$411>>2]|0;
     $413 = ($412|0)==($408|0);
     if ($413) {
      $$sroa$0159$1$be = $411;
      break;
     } else {
      $409 = $410;
     }
    }
   }
  } else {
   $$0$i$i$i$i = $399;
   while(1) {
    $406 = HEAP32[$$0$i$i$i$i>>2]|0;
    $407 = ($406|0)==(0|0);
    if ($407) {
     break;
    } else {
     $$0$i$i$i$i = $406;
    }
   }
   $$sroa$0159$1$be = $$0$i$i$i$i;
  }
  $405 = ($$sroa$0159$1$be|0)==($7|0);
  if ($405) {
   break;
  } else {
   $$sroa$0159$1203 = $$sroa$0159$1$be;
  }
 }
 return;
}
function __ZN3osg5State21applyModeMapOnTexUnitEjRNSt3__23mapIjNS0_9ModeStackENS1_4lessIjEENS1_9allocatorINS1_4pairIKjS3_EEEEEE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$i$i$i$i = 0, $$sroa$018$0$be = 0, $$sroa$018$024 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($2)) + 4|0);
 $5 = ($3|0)==($4|0);
 if ($5) {
  return;
 }
 $6 = ((($0)) + 688|0);
 $7 = ((($0)) + 344|0);
 $8 = ((($0)) + 728|0);
 $9 = ($1|0)==(0);
 $10 = ((($0)) + 716|0);
 $11 = ((($0)) + 720|0);
 $12 = (($1) + 33984)|0;
 $$sroa$018$024 = $3;
 while(1) {
  $13 = ((($$sroa$018$024)) + 16|0);
  $14 = ((($$sroa$018$024)) + 20|0);
  $15 = ((($13)) + 5|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = ($16<<24>>24)==(0);
  L6: do {
   if (!($17)) {
    HEAP8[$15>>0] = 0;
    $18 = ((($$sroa$018$024)) + 24|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = ((($$sroa$018$024)) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = ($19|0)==($21|0);
    if ($22) {
     $46 = HEAP32[$13>>2]|0;
     $47 = ((($13)) + 7|0);
     $48 = HEAP8[$47>>0]|0;
     $49 = ($48<<24>>24)==(0);
     $50 = HEAP8[$14>>0]|0;
     $51 = ($50<<24>>24)==(0);
     if ($51) {
      break;
     }
     $52 = ((($14)) + 2|0);
     $53 = HEAP8[$52>>0]|0;
     $54 = ($53<<24>>24)==($48<<24>>24);
     if ($54) {
      break;
     }
     $55 = HEAP32[$6>>2]|0;
     $56 = ($55|0)==($1|0);
     do {
      if (!($56)) {
       $57 = HEAP32[$8>>2]|0;
       $58 = ($57|0)==(0|0);
       if (!($58)) {
        $59 = HEAP32[$10>>2]|0;
        $60 = HEAP32[$11>>2]|0;
        $61 = ($59|0)>($60|0);
        $62 = $61 ? $59 : $60;
        $63 = ($62>>>0)>($1>>>0);
        if ($63) {
         FUNCTION_TABLE_vi[$57 & 8191]($12);
         HEAP32[$6>>2] = $1;
         break;
        }
       }
       if (!($9)) {
        break L6;
       }
      }
     } while(0);
     HEAP8[$52>>0] = $48;
     if ($49) {
      _glDisable(($46|0));
     } else {
      _glEnable(($46|0));
     }
     $64 = HEAP32[$7>>2]|0;
     $65 = ($64|0)==(2);
     if (!($65)) {
      break;
     }
     (__ZNK3osg5State13checkGLErrorsEj(0,$46)|0);
     break;
    } else {
     $23 = ((($21)) + -4|0);
     $24 = HEAP32[$23>>2]|0;
     $25 = $24 & 1;
     $26 = ($25|0)==(0);
     $27 = HEAP32[$13>>2]|0;
     $28 = $25&255;
     $29 = HEAP8[$14>>0]|0;
     $30 = ($29<<24>>24)==(0);
     if ($30) {
      break;
     }
     $31 = ((($14)) + 2|0);
     $32 = HEAP8[$31>>0]|0;
     $33 = $32&255;
     $34 = ($33|0)==($25|0);
     if ($34) {
      break;
     }
     $35 = HEAP32[$6>>2]|0;
     $36 = ($35|0)==($1|0);
     do {
      if (!($36)) {
       $37 = HEAP32[$8>>2]|0;
       $38 = ($37|0)==(0|0);
       if (!($38)) {
        $39 = HEAP32[$10>>2]|0;
        $40 = HEAP32[$11>>2]|0;
        $41 = ($39|0)>($40|0);
        $42 = $41 ? $39 : $40;
        $43 = ($42>>>0)>($1>>>0);
        if ($43) {
         FUNCTION_TABLE_vi[$37 & 8191]($12);
         HEAP32[$6>>2] = $1;
         break;
        }
       }
       if (!($9)) {
        break L6;
       }
      }
     } while(0);
     HEAP8[$31>>0] = $28;
     if ($26) {
      _glDisable(($27|0));
     } else {
      _glEnable(($27|0));
     }
     $44 = HEAP32[$7>>2]|0;
     $45 = ($44|0)==(2);
     if (!($45)) {
      break;
     }
     (__ZNK3osg5State13checkGLErrorsEj(0,$27)|0);
     break;
    }
   }
  } while(0);
  $66 = ((($$sroa$018$024)) + 4|0);
  $67 = HEAP32[$66>>2]|0;
  $68 = ($67|0)==(0|0);
  if ($68) {
   $69 = ((($$sroa$018$024)) + 8|0);
   $70 = HEAP32[$69>>2]|0;
   $71 = HEAP32[$70>>2]|0;
   $72 = ($71|0)==($$sroa$018$024|0);
   if ($72) {
    $$sroa$018$0$be = $70;
   } else {
    $77 = $69;
    while(1) {
     $76 = HEAP32[$77>>2]|0;
     $78 = ((($76)) + 8|0);
     $79 = HEAP32[$78>>2]|0;
     $80 = HEAP32[$79>>2]|0;
     $81 = ($80|0)==($76|0);
     if ($81) {
      $$sroa$018$0$be = $79;
      break;
     } else {
      $77 = $78;
     }
    }
   }
  } else {
   $$0$i$i$i$i = $67;
   while(1) {
    $74 = HEAP32[$$0$i$i$i$i>>2]|0;
    $75 = ($74|0)==(0|0);
    if ($75) {
     break;
    } else {
     $$0$i$i$i$i = $74;
    }
   }
   $$sroa$018$0$be = $$0$i$i$i$i;
  }
  $73 = ($$sroa$018$0$be|0)==($4|0);
  if ($73) {
   break;
  } else {
   $$sroa$018$024 = $$sroa$018$0$be;
  }
 }
 return;
}
function __ZN3osg5State27applyAttributeListOnTexUnitEjRNSt3__23mapINS1_4pairINS_14StateAttribute4TypeEjEENS0_14AttributeStackENS1_4lessIS6_EENS1_9allocatorINS3_IKS6_S7_EEEEEERKNS2_IS6_NS3_INS_7ref_ptrIS4_EEjEES9_NSA_INS3_ISB_SI_EEEEEE($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i124 = 0, $$0$i$i$i$i69 = 0, $$0$i$i$i$i69$us = 0, $$0$i$i$i$i75 = 0, $$0$i$i$i$i82 = 0, $$0$i$i$i$i89 = 0, $$0$i$i$i86 = 0, $$0$i$i100 = 0, $$0$ph$i$i = 0, $$0$ph$i$i97 = 0, $$014$i = 0, $$014$i114 = 0, $$024$i$i = 0, $$024$i$i99 = 0, $$025$i$i = 0, $$025$i$i107 = 0, $$025$i68$i = 0, $$025$i68$i109 = 0;
 var $$052$i = 0, $$052$i106 = 0, $$05267$i = 0, $$05267$i110 = 0, $$cast$i = 0, $$cast$i$us = 0, $$cast$i120 = 0, $$in$i$i = 0, $$in$i$i96 = 0, $$not = 0, $$not165 = 0, $$not165197 = 0, $$not196 = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i$i112 = 0, $$pre$i$us = 0, $$pre$i117 = 0, $$sroa$0138$0$be = 0, $$sroa$0138$0$lcssa = 0;
 var $$sroa$0138$0199 = 0, $$sroa$0138$1$be = 0, $$sroa$0138$1$be$us = 0, $$sroa$0138$1193 = 0, $$sroa$0138$1193$us = 0, $$sroa$0149$0$be = 0, $$sroa$0149$0$lcssa = 0, $$sroa$0149$0201 = 0, $$sroa$0149$1$be = 0, $$sroa$0149$1192 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0;
 var $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0;
 var $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0;
 var $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0;
 var $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0;
 var $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0;
 var $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0;
 var $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0;
 var $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0;
 var $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0;
 var $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0;
 var $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0;
 var $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0;
 var $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $brmerge = 0, $brmerge198 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$2>>2]|0;
 $6 = ((($2)) + 4|0);
 $7 = ((($3)) + 4|0);
 $$not196 = ($5|0)==($6|0);
 $$not165197 = ($4|0)==($7|0);
 $brmerge198 = $$not196 | $$not165197;
 if ($brmerge198) {
  $$sroa$0138$0$lcssa = $5;$$sroa$0149$0$lcssa = $4;
 } else {
  $8 = ((($0)) + 688|0);
  $9 = ((($0)) + 344|0);
  $10 = ((($0)) + 137|0);
  $11 = ((($0)) + 728|0);
  $12 = ($1|0)==(0);
  $13 = ((($0)) + 716|0);
  $14 = ((($0)) + 720|0);
  $15 = (($1) + 33984)|0;
  $16 = ((($2)) + 4|0);
  $17 = ((($2)) + 8|0);
  $$sroa$0138$0199 = $5;$$sroa$0149$0201 = $4;
  while(1) {
   $82 = ((($$sroa$0138$0199)) + 16|0);
   $83 = ((($$sroa$0149$0201)) + 16|0);
   $84 = HEAP32[$82>>2]|0;
   $85 = HEAP32[$83>>2]|0;
   $86 = ($84|0)<($85|0);
   L5: do {
    if ($86) {
     label = 27;
    } else {
     $87 = ($85|0)<($84|0);
     if (!($87)) {
      $88 = ((($$sroa$0138$0199)) + 20|0);
      $89 = HEAP32[$88>>2]|0;
      $90 = ((($$sroa$0149$0201)) + 20|0);
      $91 = HEAP32[$90>>2]|0;
      $92 = ($89>>>0)<($91>>>0);
      if ($92) {
       label = 27;
       break;
      }
      $147 = ((($$sroa$0149$0201)) + 20|0);
      $148 = HEAP32[$147>>2]|0;
      $149 = ((($$sroa$0138$0199)) + 20|0);
      $150 = HEAP32[$149>>2]|0;
      $151 = ($148>>>0)<($150>>>0);
      if (!($151)) {
       $213 = ((($$sroa$0138$0199)) + 24|0);
       $214 = ((($$sroa$0138$0199)) + 40|0);
       $215 = HEAP32[$214>>2]|0;
       $216 = ((($$sroa$0138$0199)) + 44|0);
       $217 = HEAP32[$216>>2]|0;
       $218 = ($215|0)==($217|0);
       if ($218) {
        label = 74;
       } else {
        $219 = ((($217)) + -4|0);
        $220 = HEAP32[$219>>2]|0;
        $221 = $220 & 2;
        $222 = ($221|0)==(0);
        if ($222) {
         label = 74;
        } else {
         $223 = ((($$sroa$0149$0201)) + 28|0);
         $224 = HEAP32[$223>>2]|0;
         $225 = $224 & 4;
         $226 = ($225|0)==(0);
         if ($226) {
          $227 = HEAP8[$213>>0]|0;
          $228 = ($227<<24>>24)==(0);
          if (!($228)) {
           HEAP8[$213>>0] = 0;
           $229 = ((($217)) + -8|0);
           $230 = HEAP32[$229>>2]|0;
           (__ZN3osg5State23applyAttributeOnTexUnitEjPKNS_14StateAttributeERNS0_14AttributeStackE($0,$1,$230,$213)|0);
          }
         } else {
          label = 74;
         }
        }
       }
       if ((label|0) == 74) {
        label = 0;
        $231 = ((($$sroa$0149$0201)) + 24|0);
        $232 = HEAP32[$231>>2]|0;
        $233 = (__ZN3osg5State23applyAttributeOnTexUnitEjPKNS_14StateAttributeERNS0_14AttributeStackE($0,$1,$232,$213)|0);
        if ($233) {
         HEAP8[$213>>0] = 1;
        }
       }
       $234 = ((($$sroa$0138$0199)) + 4|0);
       $235 = HEAP32[$234>>2]|0;
       $236 = ($235|0)==(0|0);
       if ($236) {
        $237 = ((($$sroa$0138$0199)) + 8|0);
        $238 = HEAP32[$237>>2]|0;
        $239 = HEAP32[$238>>2]|0;
        $240 = ($239|0)==($$sroa$0138$0199|0);
        if ($240) {
         $$0$i$i$i86 = $238;
        } else {
         $244 = $237;
         while(1) {
          $243 = HEAP32[$244>>2]|0;
          $245 = ((($243)) + 8|0);
          $246 = HEAP32[$245>>2]|0;
          $247 = HEAP32[$246>>2]|0;
          $248 = ($247|0)==($243|0);
          if ($248) {
           $$0$i$i$i86 = $246;
           break;
          } else {
           $244 = $245;
          }
         }
        }
       } else {
        $$0$i$i$i$i82 = $235;
        while(1) {
         $241 = HEAP32[$$0$i$i$i$i82>>2]|0;
         $242 = ($241|0)==(0|0);
         if ($242) {
          break;
         } else {
          $$0$i$i$i$i82 = $241;
         }
        }
        $$0$i$i$i86 = $$0$i$i$i$i82;
       }
       $249 = ((($$sroa$0149$0201)) + 4|0);
       $250 = HEAP32[$249>>2]|0;
       $251 = ($250|0)==(0|0);
       if ($251) {
        $252 = ((($$sroa$0149$0201)) + 8|0);
        $253 = HEAP32[$252>>2]|0;
        $254 = HEAP32[$253>>2]|0;
        $255 = ($254|0)==($$sroa$0149$0201|0);
        if ($255) {
         $$sroa$0138$0$be = $$0$i$i$i86;$$sroa$0149$0$be = $253;
         break;
        } else {
         $259 = $252;
        }
        while(1) {
         $258 = HEAP32[$259>>2]|0;
         $260 = ((($258)) + 8|0);
         $261 = HEAP32[$260>>2]|0;
         $262 = HEAP32[$261>>2]|0;
         $263 = ($262|0)==($258|0);
         if ($263) {
          $$sroa$0138$0$be = $$0$i$i$i86;$$sroa$0149$0$be = $261;
          break L5;
         } else {
          $259 = $260;
         }
        }
       } else {
        $$0$i$i$i$i75 = $250;
        while(1) {
         $256 = HEAP32[$$0$i$i$i$i75>>2]|0;
         $257 = ($256|0)==(0|0);
         if ($257) {
          break;
         } else {
          $$0$i$i$i$i75 = $256;
         }
        }
        $$sroa$0138$0$be = $$0$i$i$i86;$$sroa$0149$0$be = $$0$i$i$i$i75;
        break;
       }
      }
     }
     $152 = HEAP32[$6>>2]|0;
     $153 = ($152|0)==(0|0);
     do {
      if ($153) {
       $$025$i$i107 = $6;$$052$i106 = $6;$169 = $152;
       label = 60;
      } else {
       $154 = ((($$sroa$0149$0201)) + 20|0);
       $155 = HEAP32[$154>>2]|0;
       $$0$i$i100 = $16;$$024$i$i99 = $152;$386 = $152;
       L38: while(1) {
        $156 = ((($$024$i$i99)) + 16|0);
        $157 = HEAP32[$156>>2]|0;
        $158 = ($85|0)<($157|0);
        do {
         if ($158) {
          label = 54;
         } else {
          $159 = ($157|0)<($85|0);
          if (!($159)) {
           $160 = ((($$024$i$i99)) + 20|0);
           $161 = HEAP32[$160>>2]|0;
           $162 = ($155>>>0)<($161>>>0);
           if ($162) {
            label = 54;
            break;
           }
           $165 = ($161>>>0)<($155>>>0);
           if (!($165)) {
            label = 59;
            break L38;
           }
          }
          $166 = ((($$024$i$i99)) + 4|0);
          $167 = HEAP32[$166>>2]|0;
          $168 = ($167|0)==(0|0);
          if ($168) {
           label = 58;
           break L38;
          } else {
           $$0$ph$i$i97 = $166;$$in$i$i96 = $167;
          }
         }
        } while(0);
        if ((label|0) == 54) {
         label = 0;
         $163 = HEAP32[$$024$i$i99>>2]|0;
         $164 = ($163|0)==(0|0);
         if ($164) {
          label = 55;
          break;
         } else {
          $$0$ph$i$i97 = $$024$i$i99;$$in$i$i96 = $163;
         }
        }
        $$0$i$i100 = $$0$ph$i$i97;$$024$i$i99 = $$in$i$i96;$386 = $$in$i$i96;
       }
       if ((label|0) == 55) {
        label = 0;
        $$025$i68$i109 = $$024$i$i99;$$05267$i110 = $$024$i$i99;
        label = 61;
        break;
       }
       else if ((label|0) == 58) {
        label = 0;
        $$025$i68$i109 = $166;$$05267$i110 = $$024$i$i99;
        label = 61;
        break;
       }
       else if ((label|0) == 59) {
        label = 0;
        $$025$i$i107 = $$0$i$i100;$$052$i106 = $$024$i$i99;$169 = $386;
        label = 60;
        break;
       }
      }
     } while(0);
     if ((label|0) == 60) {
      label = 0;
      $170 = ($169|0)==(0|0);
      if ($170) {
       $$025$i68$i109 = $$025$i$i107;$$05267$i110 = $$052$i106;
       label = 61;
      } else {
       $$014$i114 = $169;
      }
     }
     if ((label|0) == 61) {
      label = 0;
      $171 = (__Znwj(52)|0);
      $172 = ((($171)) + 16|0);
      $173 = $83;
      $174 = $173;
      $175 = HEAP32[$174>>2]|0;
      $176 = (($173) + 4)|0;
      $177 = $176;
      $178 = HEAP32[$177>>2]|0;
      $179 = $172;
      $180 = $179;
      HEAP32[$180>>2] = $175;
      $181 = (($179) + 4)|0;
      $182 = $181;
      HEAP32[$182>>2] = $178;
      $183 = ((($171)) + 24|0);
      HEAP8[$183>>0] = 0;
      $184 = ((($171)) + 28|0);
      ;HEAP32[$184>>2]=0|0;HEAP32[$184+4>>2]=0|0;HEAP32[$184+8>>2]=0|0;HEAP32[$184+12>>2]=0|0;HEAP32[$184+16>>2]=0|0;HEAP32[$184+20>>2]=0|0;
      HEAP32[$171>>2] = 0;
      $185 = ((($171)) + 4|0);
      HEAP32[$185>>2] = 0;
      $186 = ((($171)) + 8|0);
      HEAP32[$186>>2] = $$05267$i110;
      HEAP32[$$025$i68$i109>>2] = $171;
      $187 = HEAP32[$2>>2]|0;
      $188 = HEAP32[$187>>2]|0;
      $189 = ($188|0)==(0|0);
      if ($189) {
       $192 = $171;
      } else {
       $190 = $188;
       HEAP32[$2>>2] = $190;
       $$pre$i$i112 = HEAP32[$$025$i68$i109>>2]|0;
       $192 = $$pre$i$i112;
      }
      $191 = HEAP32[$16>>2]|0;
      __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($191,$192);
      $193 = HEAP32[$17>>2]|0;
      $194 = (($193) + 1)|0;
      HEAP32[$17>>2] = $194;
      $$014$i114 = $171;
     }
     $195 = ((($$014$i114)) + 24|0);
     $196 = ((($$sroa$0149$0201)) + 24|0);
     $197 = HEAP32[$196>>2]|0;
     (__ZN3osg5State23applyAttributeOnTexUnitEjPKNS_14StateAttributeERNS0_14AttributeStackE($0,$1,$197,$195)|0);
     HEAP8[$195>>0] = 1;
     $198 = ((($$sroa$0149$0201)) + 4|0);
     $199 = HEAP32[$198>>2]|0;
     $200 = ($199|0)==(0|0);
     if ($200) {
      $201 = ((($$sroa$0149$0201)) + 8|0);
      $202 = HEAP32[$201>>2]|0;
      $203 = HEAP32[$202>>2]|0;
      $204 = ($203|0)==($$sroa$0149$0201|0);
      if ($204) {
       $$sroa$0138$0$be = $$sroa$0138$0199;$$sroa$0149$0$be = $202;
       break;
      } else {
       $208 = $201;
      }
      while(1) {
       $207 = HEAP32[$208>>2]|0;
       $209 = ((($207)) + 8|0);
       $210 = HEAP32[$209>>2]|0;
       $211 = HEAP32[$210>>2]|0;
       $212 = ($211|0)==($207|0);
       if ($212) {
        $$sroa$0138$0$be = $$sroa$0138$0199;$$sroa$0149$0$be = $210;
        break;
       } else {
        $208 = $209;
       }
      }
     } else {
      $$0$i$i$i$i89 = $199;
      while(1) {
       $205 = HEAP32[$$0$i$i$i$i89>>2]|0;
       $206 = ($205|0)==(0|0);
       if ($206) {
        break;
       } else {
        $$0$i$i$i$i89 = $205;
       }
      }
      $$sroa$0138$0$be = $$sroa$0138$0199;$$sroa$0149$0$be = $$0$i$i$i$i89;
      break;
     }
    }
   } while(0);
   do {
    if ((label|0) == 27) {
     label = 0;
     $93 = ((($$sroa$0138$0199)) + 24|0);
     $94 = HEAP8[$93>>0]|0;
     $95 = ($94<<24>>24)==(0);
     L70: do {
      if (!($95)) {
       HEAP8[$93>>0] = 0;
       $96 = ((($$sroa$0138$0199)) + 40|0);
       $97 = HEAP32[$96>>2]|0;
       $98 = ((($$sroa$0138$0199)) + 44|0);
       $99 = HEAP32[$98>>2]|0;
       $100 = ($97|0)==($99|0);
       if (!($100)) {
        $101 = ((($99)) + -8|0);
        $102 = HEAP32[$101>>2]|0;
        (__ZN3osg5State23applyAttributeOnTexUnitEjPKNS_14StateAttributeERNS0_14AttributeStackE($0,$1,$102,$93)|0);
        break;
       }
       $103 = ((($$sroa$0138$0199)) + 28|0);
       $104 = HEAP32[$103>>2]|0;
       $105 = ((($$sroa$0138$0199)) + 36|0);
       $106 = HEAP32[$105>>2]|0;
       $107 = ($104|0)==($106|0);
       $108 = $106;
       if (!($107)) {
        $109 = HEAP32[$8>>2]|0;
        $110 = ($109|0)==($1|0);
        do {
         if ($110) {
          $118 = $108;
         } else {
          $111 = HEAP32[$11>>2]|0;
          $112 = ($111|0)==(0|0);
          if (!($112)) {
           $113 = HEAP32[$13>>2]|0;
           $114 = HEAP32[$14>>2]|0;
           $115 = ($113|0)>($114|0);
           $116 = $115 ? $113 : $114;
           $117 = ($116>>>0)>($1>>>0);
           if ($117) {
            FUNCTION_TABLE_vi[$111 & 8191]($15);
            HEAP32[$8>>2] = $1;
            $$pre$i117 = HEAP32[$105>>2]|0;
            $118 = $$pre$i117;
            break;
           }
          }
          if ($12) {
           $118 = $108;
          } else {
           break L70;
          }
         }
        } while(0);
        HEAP32[$103>>2] = $118;
        $119 = ($118|0)==(0);
        if (!($119)) {
         $$cast$i120 = $118;
         $120 = $118;
         $121 = HEAP32[$120>>2]|0;
         $122 = ((($121)) + 172|0);
         $123 = HEAP32[$122>>2]|0;
         FUNCTION_TABLE_vii[$123 & 8191]($$cast$i120,$0);
         $124 = HEAP32[$105>>2]|0;
         $125 = ((($124)) + 44|0);
         $126 = HEAP32[$125>>2]|0;
         $127 = ((($$sroa$0138$0199)) + 32|0);
         $128 = HEAP32[$127>>2]|0;
         $129 = ($128|0)==($126|0);
         if (!($129)) {
          HEAP32[$127>>2] = $126;
          HEAP8[$10>>0] = 1;
         }
         $130 = HEAP32[$9>>2]|0;
         $131 = ($130|0)==(2);
         if ($131) {
          (__ZNK3osg5State13checkGLErrorsEPKNS_14StateAttributeE(0,$124)|0);
         }
        }
       }
      }
     } while(0);
     $132 = ((($$sroa$0138$0199)) + 4|0);
     $133 = HEAP32[$132>>2]|0;
     $134 = ($133|0)==(0|0);
     if ($134) {
      $135 = ((($$sroa$0138$0199)) + 8|0);
      $136 = HEAP32[$135>>2]|0;
      $137 = HEAP32[$136>>2]|0;
      $138 = ($137|0)==($$sroa$0138$0199|0);
      if ($138) {
       $$sroa$0138$0$be = $136;$$sroa$0149$0$be = $$sroa$0149$0201;
       break;
      } else {
       $142 = $135;
      }
      while(1) {
       $141 = HEAP32[$142>>2]|0;
       $143 = ((($141)) + 8|0);
       $144 = HEAP32[$143>>2]|0;
       $145 = HEAP32[$144>>2]|0;
       $146 = ($145|0)==($141|0);
       if ($146) {
        $$sroa$0138$0$be = $144;$$sroa$0149$0$be = $$sroa$0149$0201;
        break;
       } else {
        $142 = $143;
       }
      }
     } else {
      $$0$i$i$i$i124 = $133;
      while(1) {
       $139 = HEAP32[$$0$i$i$i$i124>>2]|0;
       $140 = ($139|0)==(0|0);
       if ($140) {
        break;
       } else {
        $$0$i$i$i$i124 = $139;
       }
      }
      $$sroa$0138$0$be = $$0$i$i$i$i124;$$sroa$0149$0$be = $$sroa$0149$0201;
      break;
     }
    }
   } while(0);
   $$not = ($$sroa$0138$0$be|0)==($6|0);
   $$not165 = ($$sroa$0149$0$be|0)==($7|0);
   $brmerge = $$not | $$not165;
   if ($brmerge) {
    $$sroa$0138$0$lcssa = $$sroa$0138$0$be;$$sroa$0149$0$lcssa = $$sroa$0149$0$be;
    break;
   } else {
    $$sroa$0138$0199 = $$sroa$0138$0$be;$$sroa$0149$0201 = $$sroa$0149$0$be;
   }
  }
 }
 $18 = ($$sroa$0138$0$lcssa|0)==($6|0);
 if (!($18)) {
  $19 = ((($0)) + 688|0);
  $20 = ((($0)) + 344|0);
  $21 = ((($0)) + 137|0);
  $22 = ((($0)) + 728|0);
  $23 = ($1|0)==(0);
  $24 = ((($0)) + 716|0);
  $25 = ((($0)) + 720|0);
  $26 = (($1) + 33984)|0;
  if ($23) {
   $$sroa$0138$1193$us = $$sroa$0138$0$lcssa;
   while(1) {
    $27 = ((($$sroa$0138$1193$us)) + 24|0);
    $28 = HEAP8[$27>>0]|0;
    $29 = ($28<<24>>24)==(0);
    do {
     if (!($29)) {
      HEAP8[$27>>0] = 0;
      $30 = ((($$sroa$0138$1193$us)) + 40|0);
      $31 = HEAP32[$30>>2]|0;
      $32 = ((($$sroa$0138$1193$us)) + 44|0);
      $33 = HEAP32[$32>>2]|0;
      $34 = ($31|0)==($33|0);
      if (!($34)) {
       $35 = ((($33)) + -8|0);
       $36 = HEAP32[$35>>2]|0;
       (__ZN3osg5State23applyAttributeOnTexUnitEjPKNS_14StateAttributeERNS0_14AttributeStackE($0,0,$36,$27)|0);
       break;
      }
      $37 = ((($$sroa$0138$1193$us)) + 28|0);
      $38 = HEAP32[$37>>2]|0;
      $39 = ((($$sroa$0138$1193$us)) + 36|0);
      $40 = HEAP32[$39>>2]|0;
      $41 = ($38|0)==($40|0);
      $42 = $40;
      if (!($41)) {
       $43 = HEAP32[$19>>2]|0;
       $44 = ($43|0)==(0);
       if ($44) {
        $52 = $42;
       } else {
        $45 = HEAP32[$22>>2]|0;
        $46 = ($45|0)==(0|0);
        if ($46) {
         $52 = $42;
        } else {
         $47 = HEAP32[$24>>2]|0;
         $48 = HEAP32[$25>>2]|0;
         $49 = ($47|0)>($48|0);
         $50 = $49 ? $47 : $48;
         $51 = ($50|0)==(0);
         if ($51) {
          $52 = $42;
         } else {
          FUNCTION_TABLE_vi[$45 & 8191]($26);
          HEAP32[$19>>2] = 0;
          $$pre$i$us = HEAP32[$39>>2]|0;
          $52 = $$pre$i$us;
         }
        }
       }
       HEAP32[$37>>2] = $52;
       $53 = ($52|0)==(0);
       if (!($53)) {
        $$cast$i$us = $52;
        $54 = $52;
        $55 = HEAP32[$54>>2]|0;
        $56 = ((($55)) + 172|0);
        $57 = HEAP32[$56>>2]|0;
        FUNCTION_TABLE_vii[$57 & 8191]($$cast$i$us,$0);
        $58 = HEAP32[$39>>2]|0;
        $59 = ((($58)) + 44|0);
        $60 = HEAP32[$59>>2]|0;
        $61 = ((($$sroa$0138$1193$us)) + 32|0);
        $62 = HEAP32[$61>>2]|0;
        $63 = ($62|0)==($60|0);
        if (!($63)) {
         HEAP32[$61>>2] = $60;
         HEAP8[$21>>0] = 1;
        }
        $64 = HEAP32[$20>>2]|0;
        $65 = ($64|0)==(2);
        if ($65) {
         (__ZNK3osg5State13checkGLErrorsEPKNS_14StateAttributeE(0,$58)|0);
        }
       }
      }
     }
    } while(0);
    $66 = ((($$sroa$0138$1193$us)) + 4|0);
    $67 = HEAP32[$66>>2]|0;
    $68 = ($67|0)==(0|0);
    if ($68) {
     $71 = ((($$sroa$0138$1193$us)) + 8|0);
     $72 = HEAP32[$71>>2]|0;
     $73 = HEAP32[$72>>2]|0;
     $74 = ($73|0)==($$sroa$0138$1193$us|0);
     if ($74) {
      $$sroa$0138$1$be$us = $72;
     } else {
      $76 = $71;
      while(1) {
       $75 = HEAP32[$76>>2]|0;
       $77 = ((($75)) + 8|0);
       $78 = HEAP32[$77>>2]|0;
       $79 = HEAP32[$78>>2]|0;
       $80 = ($79|0)==($75|0);
       if ($80) {
        $$sroa$0138$1$be$us = $78;
        break;
       } else {
        $76 = $77;
       }
      }
     }
    } else {
     $$0$i$i$i$i69$us = $67;
     while(1) {
      $69 = HEAP32[$$0$i$i$i$i69$us>>2]|0;
      $70 = ($69|0)==(0|0);
      if ($70) {
       break;
      } else {
       $$0$i$i$i$i69$us = $69;
      }
     }
     $$sroa$0138$1$be$us = $$0$i$i$i$i69$us;
    }
    $81 = ($$sroa$0138$1$be$us|0)==($6|0);
    if ($81) {
     break;
    } else {
     $$sroa$0138$1193$us = $$sroa$0138$1$be$us;
    }
   }
  } else {
   $$sroa$0138$1193 = $$sroa$0138$0$lcssa;
   while(1) {
    $267 = ((($$sroa$0138$1193)) + 24|0);
    $268 = HEAP8[$267>>0]|0;
    $269 = ($268<<24>>24)==(0);
    do {
     if (!($269)) {
      HEAP8[$267>>0] = 0;
      $270 = ((($$sroa$0138$1193)) + 40|0);
      $271 = HEAP32[$270>>2]|0;
      $272 = ((($$sroa$0138$1193)) + 44|0);
      $273 = HEAP32[$272>>2]|0;
      $274 = ($271|0)==($273|0);
      if (!($274)) {
       $275 = ((($273)) + -8|0);
       $276 = HEAP32[$275>>2]|0;
       (__ZN3osg5State23applyAttributeOnTexUnitEjPKNS_14StateAttributeERNS0_14AttributeStackE($0,$1,$276,$267)|0);
       break;
      }
      $277 = ((($$sroa$0138$1193)) + 28|0);
      $278 = HEAP32[$277>>2]|0;
      $279 = ((($$sroa$0138$1193)) + 36|0);
      $280 = HEAP32[$279>>2]|0;
      $281 = ($278|0)==($280|0);
      if (!($281)) {
       $282 = $280;
       $283 = HEAP32[$19>>2]|0;
       $284 = ($283|0)==($1|0);
       if ($284) {
        $292 = $282;
       } else {
        $285 = HEAP32[$22>>2]|0;
        $286 = ($285|0)==(0|0);
        if ($286) {
         break;
        }
        $287 = HEAP32[$24>>2]|0;
        $288 = HEAP32[$25>>2]|0;
        $289 = ($287|0)>($288|0);
        $290 = $289 ? $287 : $288;
        $291 = ($290>>>0)>($1>>>0);
        if (!($291)) {
         break;
        }
        FUNCTION_TABLE_vi[$285 & 8191]($26);
        HEAP32[$19>>2] = $1;
        $$pre$i = HEAP32[$279>>2]|0;
        $292 = $$pre$i;
       }
       HEAP32[$277>>2] = $292;
       $293 = ($292|0)==(0);
       if (!($293)) {
        $$cast$i = $292;
        $294 = $292;
        $295 = HEAP32[$294>>2]|0;
        $296 = ((($295)) + 172|0);
        $297 = HEAP32[$296>>2]|0;
        FUNCTION_TABLE_vii[$297 & 8191]($$cast$i,$0);
        $298 = HEAP32[$279>>2]|0;
        $299 = ((($298)) + 44|0);
        $300 = HEAP32[$299>>2]|0;
        $301 = ((($$sroa$0138$1193)) + 32|0);
        $302 = HEAP32[$301>>2]|0;
        $303 = ($302|0)==($300|0);
        if (!($303)) {
         HEAP32[$301>>2] = $300;
         HEAP8[$21>>0] = 1;
        }
        $304 = HEAP32[$20>>2]|0;
        $305 = ($304|0)==(2);
        if ($305) {
         (__ZNK3osg5State13checkGLErrorsEPKNS_14StateAttributeE(0,$298)|0);
        }
       }
      }
     }
    } while(0);
    $306 = ((($$sroa$0138$1193)) + 4|0);
    $307 = HEAP32[$306>>2]|0;
    $308 = ($307|0)==(0|0);
    if ($308) {
     $309 = ((($$sroa$0138$1193)) + 8|0);
     $310 = HEAP32[$309>>2]|0;
     $311 = HEAP32[$310>>2]|0;
     $312 = ($311|0)==($$sroa$0138$1193|0);
     if ($312) {
      $$sroa$0138$1$be = $310;
     } else {
      $317 = $309;
      while(1) {
       $316 = HEAP32[$317>>2]|0;
       $318 = ((($316)) + 8|0);
       $319 = HEAP32[$318>>2]|0;
       $320 = HEAP32[$319>>2]|0;
       $321 = ($320|0)==($316|0);
       if ($321) {
        $$sroa$0138$1$be = $319;
        break;
       } else {
        $317 = $318;
       }
      }
     }
    } else {
     $$0$i$i$i$i69 = $307;
     while(1) {
      $314 = HEAP32[$$0$i$i$i$i69>>2]|0;
      $315 = ($314|0)==(0|0);
      if ($315) {
       break;
      } else {
       $$0$i$i$i$i69 = $314;
      }
     }
     $$sroa$0138$1$be = $$0$i$i$i$i69;
    }
    $313 = ($$sroa$0138$1$be|0)==($6|0);
    if ($313) {
     break;
    } else {
     $$sroa$0138$1193 = $$sroa$0138$1$be;
    }
   }
  }
 }
 $264 = ($$sroa$0149$0$lcssa|0)==($7|0);
 if ($264) {
  return;
 }
 $265 = ((($2)) + 4|0);
 $266 = ((($2)) + 8|0);
 $$sroa$0149$1192 = $$sroa$0149$0$lcssa;
 while(1) {
  $322 = ((($$sroa$0149$1192)) + 16|0);
  $323 = HEAP32[$6>>2]|0;
  $324 = ($323|0)==(0|0);
  do {
   if ($324) {
    $$025$i$i = $6;$$052$i = $6;$341 = $323;
    label = 119;
   } else {
    $325 = HEAP32[$322>>2]|0;
    $326 = ((($$sroa$0149$1192)) + 20|0);
    $327 = HEAP32[$326>>2]|0;
    $$0$i$i = $265;$$024$i$i = $323;$387 = $323;
    L163: while(1) {
     $328 = ((($$024$i$i)) + 16|0);
     $329 = HEAP32[$328>>2]|0;
     $330 = ($325|0)<($329|0);
     do {
      if ($330) {
       label = 113;
      } else {
       $331 = ($329|0)<($325|0);
       if (!($331)) {
        $332 = ((($$024$i$i)) + 20|0);
        $333 = HEAP32[$332>>2]|0;
        $334 = ($327>>>0)<($333>>>0);
        if ($334) {
         label = 113;
         break;
        }
        $337 = ($333>>>0)<($327>>>0);
        if (!($337)) {
         label = 118;
         break L163;
        }
       }
       $338 = ((($$024$i$i)) + 4|0);
       $339 = HEAP32[$338>>2]|0;
       $340 = ($339|0)==(0|0);
       if ($340) {
        label = 117;
        break L163;
       } else {
        $$0$ph$i$i = $338;$$in$i$i = $339;
       }
      }
     } while(0);
     if ((label|0) == 113) {
      label = 0;
      $335 = HEAP32[$$024$i$i>>2]|0;
      $336 = ($335|0)==(0|0);
      if ($336) {
       label = 114;
       break;
      } else {
       $$0$ph$i$i = $$024$i$i;$$in$i$i = $335;
      }
     }
     $$0$i$i = $$0$ph$i$i;$$024$i$i = $$in$i$i;$387 = $$in$i$i;
    }
    if ((label|0) == 114) {
     label = 0;
     $$025$i68$i = $$024$i$i;$$05267$i = $$024$i$i;
     label = 120;
     break;
    }
    else if ((label|0) == 117) {
     label = 0;
     $$025$i68$i = $338;$$05267$i = $$024$i$i;
     label = 120;
     break;
    }
    else if ((label|0) == 118) {
     label = 0;
     $$025$i$i = $$0$i$i;$$052$i = $$024$i$i;$341 = $387;
     label = 119;
     break;
    }
   }
  } while(0);
  if ((label|0) == 119) {
   label = 0;
   $342 = ($341|0)==(0|0);
   if ($342) {
    $$025$i68$i = $$025$i$i;$$05267$i = $$052$i;
    label = 120;
   } else {
    $$014$i = $341;
   }
  }
  if ((label|0) == 120) {
   label = 0;
   $343 = (__Znwj(52)|0);
   $344 = ((($343)) + 16|0);
   $345 = $322;
   $346 = $345;
   $347 = HEAP32[$346>>2]|0;
   $348 = (($345) + 4)|0;
   $349 = $348;
   $350 = HEAP32[$349>>2]|0;
   $351 = $344;
   $352 = $351;
   HEAP32[$352>>2] = $347;
   $353 = (($351) + 4)|0;
   $354 = $353;
   HEAP32[$354>>2] = $350;
   $355 = ((($343)) + 24|0);
   HEAP8[$355>>0] = 0;
   $356 = ((($343)) + 28|0);
   ;HEAP32[$356>>2]=0|0;HEAP32[$356+4>>2]=0|0;HEAP32[$356+8>>2]=0|0;HEAP32[$356+12>>2]=0|0;HEAP32[$356+16>>2]=0|0;HEAP32[$356+20>>2]=0|0;
   HEAP32[$343>>2] = 0;
   $357 = ((($343)) + 4|0);
   HEAP32[$357>>2] = 0;
   $358 = ((($343)) + 8|0);
   HEAP32[$358>>2] = $$05267$i;
   HEAP32[$$025$i68$i>>2] = $343;
   $359 = HEAP32[$2>>2]|0;
   $360 = HEAP32[$359>>2]|0;
   $361 = ($360|0)==(0|0);
   if ($361) {
    $364 = $343;
   } else {
    $362 = $360;
    HEAP32[$2>>2] = $362;
    $$pre$i$i = HEAP32[$$025$i68$i>>2]|0;
    $364 = $$pre$i$i;
   }
   $363 = HEAP32[$265>>2]|0;
   __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($363,$364);
   $365 = HEAP32[$266>>2]|0;
   $366 = (($365) + 1)|0;
   HEAP32[$266>>2] = $366;
   $$014$i = $343;
  }
  $367 = ((($$014$i)) + 24|0);
  $368 = ((($$sroa$0149$1192)) + 24|0);
  $369 = HEAP32[$368>>2]|0;
  (__ZN3osg5State23applyAttributeOnTexUnitEjPKNS_14StateAttributeERNS0_14AttributeStackE($0,$1,$369,$367)|0);
  HEAP8[$367>>0] = 1;
  $370 = ((($$sroa$0149$1192)) + 4|0);
  $371 = HEAP32[$370>>2]|0;
  $372 = ($371|0)==(0|0);
  if ($372) {
   $373 = ((($$sroa$0149$1192)) + 8|0);
   $374 = HEAP32[$373>>2]|0;
   $375 = HEAP32[$374>>2]|0;
   $376 = ($375|0)==($$sroa$0149$1192|0);
   if ($376) {
    $$sroa$0149$1$be = $374;
   } else {
    $381 = $373;
    while(1) {
     $380 = HEAP32[$381>>2]|0;
     $382 = ((($380)) + 8|0);
     $383 = HEAP32[$382>>2]|0;
     $384 = HEAP32[$383>>2]|0;
     $385 = ($384|0)==($380|0);
     if ($385) {
      $$sroa$0149$1$be = $383;
      break;
     } else {
      $381 = $382;
     }
    }
   }
  } else {
   $$0$i$i$i$i = $371;
   while(1) {
    $378 = HEAP32[$$0$i$i$i$i>>2]|0;
    $379 = ($378|0)==(0|0);
    if ($379) {
     break;
    } else {
     $$0$i$i$i$i = $378;
    }
   }
   $$sroa$0149$1$be = $$0$i$i$i$i;
  }
  $377 = ($$sroa$0149$1$be|0)==($7|0);
  if ($377) {
   break;
  } else {
   $$sroa$0149$1192 = $$sroa$0149$1$be;
  }
 }
 return;
}
function __ZN3osg5State26applyAttributeMapOnTexUnitEjRNSt3__23mapINS1_4pairINS_14StateAttribute4TypeEjEENS0_14AttributeStackENS1_4lessIS6_EENS1_9allocatorINS3_IKS6_S7_EEEEEE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$i$i$i$i = 0, $$0$i$i$i$i$us = 0, $$cast$i = 0, $$cast$i$us = 0, $$pre$i = 0, $$pre$i$us = 0, $$sroa$015$0$be = 0, $$sroa$015$0$be$us = 0, $$sroa$015$019 = 0, $$sroa$015$019$us = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($2)) + 4|0);
 $5 = ($3|0)==($4|0);
 if ($5) {
  return;
 }
 $6 = ((($0)) + 688|0);
 $7 = ((($0)) + 344|0);
 $8 = ((($0)) + 137|0);
 $9 = ((($0)) + 728|0);
 $10 = ($1|0)==(0);
 $11 = ((($0)) + 716|0);
 $12 = ((($0)) + 720|0);
 $13 = (($1) + 33984)|0;
 if ($10) {
  $$sroa$015$019$us = $3;
  while(1) {
   $14 = ((($$sroa$015$019$us)) + 24|0);
   $15 = HEAP8[$14>>0]|0;
   $16 = ($15<<24>>24)==(0);
   do {
    if (!($16)) {
     HEAP8[$14>>0] = 0;
     $17 = ((($$sroa$015$019$us)) + 40|0);
     $18 = HEAP32[$17>>2]|0;
     $19 = ((($$sroa$015$019$us)) + 44|0);
     $20 = HEAP32[$19>>2]|0;
     $21 = ($18|0)==($20|0);
     if (!($21)) {
      $22 = ((($20)) + -8|0);
      $23 = HEAP32[$22>>2]|0;
      (__ZN3osg5State23applyAttributeOnTexUnitEjPKNS_14StateAttributeERNS0_14AttributeStackE($0,0,$23,$14)|0);
      break;
     }
     $24 = ((($$sroa$015$019$us)) + 28|0);
     $25 = HEAP32[$24>>2]|0;
     $26 = ((($$sroa$015$019$us)) + 36|0);
     $27 = HEAP32[$26>>2]|0;
     $28 = ($25|0)==($27|0);
     $29 = $27;
     if (!($28)) {
      $30 = HEAP32[$6>>2]|0;
      $31 = ($30|0)==(0);
      if ($31) {
       $39 = $29;
      } else {
       $32 = HEAP32[$9>>2]|0;
       $33 = ($32|0)==(0|0);
       if ($33) {
        $39 = $29;
       } else {
        $34 = HEAP32[$11>>2]|0;
        $35 = HEAP32[$12>>2]|0;
        $36 = ($34|0)>($35|0);
        $37 = $36 ? $34 : $35;
        $38 = ($37|0)==(0);
        if ($38) {
         $39 = $29;
        } else {
         FUNCTION_TABLE_vi[$32 & 8191]($13);
         HEAP32[$6>>2] = 0;
         $$pre$i$us = HEAP32[$26>>2]|0;
         $39 = $$pre$i$us;
        }
       }
      }
      HEAP32[$24>>2] = $39;
      $40 = ($39|0)==(0);
      if (!($40)) {
       $$cast$i$us = $39;
       $41 = $39;
       $42 = HEAP32[$41>>2]|0;
       $43 = ((($42)) + 172|0);
       $44 = HEAP32[$43>>2]|0;
       FUNCTION_TABLE_vii[$44 & 8191]($$cast$i$us,$0);
       $45 = HEAP32[$26>>2]|0;
       $46 = ((($45)) + 44|0);
       $47 = HEAP32[$46>>2]|0;
       $48 = ((($$sroa$015$019$us)) + 32|0);
       $49 = HEAP32[$48>>2]|0;
       $50 = ($49|0)==($47|0);
       if (!($50)) {
        HEAP32[$48>>2] = $47;
        HEAP8[$8>>0] = 1;
       }
       $51 = HEAP32[$7>>2]|0;
       $52 = ($51|0)==(2);
       if ($52) {
        (__ZNK3osg5State13checkGLErrorsEPKNS_14StateAttributeE(0,$45)|0);
       }
      }
     }
    }
   } while(0);
   $53 = ((($$sroa$015$019$us)) + 4|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = ($54|0)==(0|0);
   if ($55) {
    $58 = ((($$sroa$015$019$us)) + 8|0);
    $59 = HEAP32[$58>>2]|0;
    $60 = HEAP32[$59>>2]|0;
    $61 = ($60|0)==($$sroa$015$019$us|0);
    if ($61) {
     $$sroa$015$0$be$us = $59;
    } else {
     $63 = $58;
     while(1) {
      $62 = HEAP32[$63>>2]|0;
      $64 = ((($62)) + 8|0);
      $65 = HEAP32[$64>>2]|0;
      $66 = HEAP32[$65>>2]|0;
      $67 = ($66|0)==($62|0);
      if ($67) {
       $$sroa$015$0$be$us = $65;
       break;
      } else {
       $63 = $64;
      }
     }
    }
   } else {
    $$0$i$i$i$i$us = $54;
    while(1) {
     $56 = HEAP32[$$0$i$i$i$i$us>>2]|0;
     $57 = ($56|0)==(0|0);
     if ($57) {
      break;
     } else {
      $$0$i$i$i$i$us = $56;
     }
    }
    $$sroa$015$0$be$us = $$0$i$i$i$i$us;
   }
   $68 = ($$sroa$015$0$be$us|0)==($4|0);
   if ($68) {
    break;
   } else {
    $$sroa$015$019$us = $$sroa$015$0$be$us;
   }
  }
  return;
 } else {
  $$sroa$015$019 = $3;
  while(1) {
   $69 = ((($$sroa$015$019)) + 24|0);
   $70 = HEAP8[$69>>0]|0;
   $71 = ($70<<24>>24)==(0);
   do {
    if (!($71)) {
     HEAP8[$69>>0] = 0;
     $72 = ((($$sroa$015$019)) + 40|0);
     $73 = HEAP32[$72>>2]|0;
     $74 = ((($$sroa$015$019)) + 44|0);
     $75 = HEAP32[$74>>2]|0;
     $76 = ($73|0)==($75|0);
     if (!($76)) {
      $77 = ((($75)) + -8|0);
      $78 = HEAP32[$77>>2]|0;
      (__ZN3osg5State23applyAttributeOnTexUnitEjPKNS_14StateAttributeERNS0_14AttributeStackE($0,$1,$78,$69)|0);
      break;
     }
     $79 = ((($$sroa$015$019)) + 28|0);
     $80 = HEAP32[$79>>2]|0;
     $81 = ((($$sroa$015$019)) + 36|0);
     $82 = HEAP32[$81>>2]|0;
     $83 = ($80|0)==($82|0);
     if (!($83)) {
      $84 = $82;
      $85 = HEAP32[$6>>2]|0;
      $86 = ($85|0)==($1|0);
      if ($86) {
       $94 = $84;
      } else {
       $87 = HEAP32[$9>>2]|0;
       $88 = ($87|0)==(0|0);
       if ($88) {
        break;
       }
       $89 = HEAP32[$11>>2]|0;
       $90 = HEAP32[$12>>2]|0;
       $91 = ($89|0)>($90|0);
       $92 = $91 ? $89 : $90;
       $93 = ($92>>>0)>($1>>>0);
       if (!($93)) {
        break;
       }
       FUNCTION_TABLE_vi[$87 & 8191]($13);
       HEAP32[$6>>2] = $1;
       $$pre$i = HEAP32[$81>>2]|0;
       $94 = $$pre$i;
      }
      HEAP32[$79>>2] = $94;
      $95 = ($94|0)==(0);
      if (!($95)) {
       $$cast$i = $94;
       $96 = $94;
       $97 = HEAP32[$96>>2]|0;
       $98 = ((($97)) + 172|0);
       $99 = HEAP32[$98>>2]|0;
       FUNCTION_TABLE_vii[$99 & 8191]($$cast$i,$0);
       $100 = HEAP32[$81>>2]|0;
       $101 = ((($100)) + 44|0);
       $102 = HEAP32[$101>>2]|0;
       $103 = ((($$sroa$015$019)) + 32|0);
       $104 = HEAP32[$103>>2]|0;
       $105 = ($104|0)==($102|0);
       if (!($105)) {
        HEAP32[$103>>2] = $102;
        HEAP8[$8>>0] = 1;
       }
       $106 = HEAP32[$7>>2]|0;
       $107 = ($106|0)==(2);
       if ($107) {
        (__ZNK3osg5State13checkGLErrorsEPKNS_14StateAttributeE(0,$100)|0);
       }
      }
     }
    }
   } while(0);
   $108 = ((($$sroa$015$019)) + 4|0);
   $109 = HEAP32[$108>>2]|0;
   $110 = ($109|0)==(0|0);
   if ($110) {
    $111 = ((($$sroa$015$019)) + 8|0);
    $112 = HEAP32[$111>>2]|0;
    $113 = HEAP32[$112>>2]|0;
    $114 = ($113|0)==($$sroa$015$019|0);
    if ($114) {
     $$sroa$015$0$be = $112;
    } else {
     $119 = $111;
     while(1) {
      $118 = HEAP32[$119>>2]|0;
      $120 = ((($118)) + 8|0);
      $121 = HEAP32[$120>>2]|0;
      $122 = HEAP32[$121>>2]|0;
      $123 = ($122|0)==($118|0);
      if ($123) {
       $$sroa$015$0$be = $121;
       break;
      } else {
       $119 = $120;
      }
     }
    }
   } else {
    $$0$i$i$i$i = $109;
    while(1) {
     $116 = HEAP32[$$0$i$i$i$i>>2]|0;
     $117 = ($116|0)==(0|0);
     if ($117) {
      break;
     } else {
      $$0$i$i$i$i = $116;
     }
    }
    $$sroa$015$0$be = $$0$i$i$i$i;
   }
   $115 = ($$sroa$015$0$be|0)==($4|0);
   if ($115) {
    break;
   } else {
    $$sroa$015$019 = $$sroa$015$0$be;
   }
  }
  return;
 }
}
function __ZN3osg5State13applyModeListERNSt3__23mapIjNS0_9ModeStackENS1_4lessIjEENS1_9allocatorINS1_4pairIKjS3_EEEEEERKNS2_IjjS5_NS6_INS7_IS8_jEEEEEE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i106 = 0, $$0$i$i$i$i51 = 0, $$0$i$i$i$i61 = 0, $$0$i$i$i$i68 = 0, $$0$i$i$i$i81 = 0, $$0$i$i$i72 = 0, $$0$i$i92 = 0, $$0$ph$i$i = 0, $$0$ph$i$i89 = 0, $$014$i = 0, $$014$i101 = 0, $$024$i$i = 0, $$024$i$i91 = 0, $$025$i$i = 0, $$025$i$i94 = 0, $$025$i65$i = 0, $$025$i65$i96 = 0, $$049$i = 0;
 var $$049$i93 = 0, $$04964$i = 0, $$04964$i97 = 0, $$in$i$i = 0, $$in$i$i88 = 0, $$not = 0, $$not154 = 0, $$not154185 = 0, $$not184 = 0, $$pre = 0, $$pre$i$i = 0, $$pre$i$i99 = 0, $$sroa$0121$0$be = 0, $$sroa$0121$0$lcssa = 0, $$sroa$0121$0187 = 0, $$sroa$0121$1$be = 0, $$sroa$0121$1182 = 0, $$sroa$0137$0$be = 0, $$sroa$0137$0$lcssa = 0, $$sroa$0137$0188 = 0;
 var $$sroa$0137$1$be = 0, $$sroa$0137$1181 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0;
 var $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0;
 var $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0;
 var $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0;
 var $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0;
 var $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0;
 var $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0;
 var $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $brmerge = 0, $brmerge186 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$1>>2]|0;
 $5 = ((($1)) + 4|0);
 $6 = ((($2)) + 4|0);
 $$not184 = ($4|0)==($5|0);
 $$not154185 = ($3|0)==($6|0);
 $brmerge186 = $$not184 | $$not154185;
 if ($brmerge186) {
  $$sroa$0121$0$lcssa = $4;$$sroa$0137$0$lcssa = $3;
 } else {
  $7 = ((($0)) + 344|0);
  $8 = ((($1)) + 4|0);
  $9 = ((($1)) + 8|0);
  $$sroa$0121$0187 = $4;$$sroa$0137$0188 = $3;
  while(1) {
   $12 = ((($$sroa$0121$0187)) + 16|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = ((($$sroa$0137$0188)) + 16|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = ($13>>>0)<($15>>>0);
   L5: do {
    if ($16) {
     $17 = ((($$sroa$0121$0187)) + 20|0);
     $18 = ((($12)) + 5|0);
     $19 = HEAP8[$18>>0]|0;
     $20 = ($19<<24>>24)==(0);
     do {
      if (!($20)) {
       HEAP8[$18>>0] = 0;
       $21 = ((($$sroa$0121$0187)) + 24|0);
       $22 = HEAP32[$21>>2]|0;
       $23 = ((($$sroa$0121$0187)) + 28|0);
       $24 = HEAP32[$23>>2]|0;
       $25 = ($22|0)==($24|0);
       if ($25) {
        $39 = ((($12)) + 7|0);
        $40 = HEAP8[$39>>0]|0;
        $41 = ($40<<24>>24)==(0);
        $42 = HEAP8[$17>>0]|0;
        $43 = ($42<<24>>24)==(0);
        if ($43) {
         break;
        }
        $44 = ((($17)) + 2|0);
        $45 = HEAP8[$44>>0]|0;
        $46 = ($45<<24>>24)==($40<<24>>24);
        if ($46) {
         break;
        }
        HEAP8[$44>>0] = $40;
        if ($41) {
         _glDisable(($13|0));
        } else {
         _glEnable(($13|0));
        }
        $47 = HEAP32[$7>>2]|0;
        $48 = ($47|0)==(2);
        if (!($48)) {
         break;
        }
        (__ZNK3osg5State13checkGLErrorsEj(0,$13)|0);
        break;
       } else {
        $26 = ((($24)) + -4|0);
        $27 = HEAP32[$26>>2]|0;
        $28 = $27 & 1;
        $29 = ($28|0)==(0);
        $30 = $28&255;
        $31 = HEAP8[$17>>0]|0;
        $32 = ($31<<24>>24)==(0);
        if ($32) {
         break;
        }
        $33 = ((($17)) + 2|0);
        $34 = HEAP8[$33>>0]|0;
        $35 = $34&255;
        $36 = ($35|0)==($28|0);
        if ($36) {
         break;
        }
        HEAP8[$33>>0] = $30;
        if ($29) {
         _glDisable(($13|0));
        } else {
         _glEnable(($13|0));
        }
        $37 = HEAP32[$7>>2]|0;
        $38 = ($37|0)==(2);
        if (!($38)) {
         break;
        }
        (__ZNK3osg5State13checkGLErrorsEj(0,$13)|0);
        break;
       }
      }
     } while(0);
     $49 = ((($$sroa$0121$0187)) + 4|0);
     $50 = HEAP32[$49>>2]|0;
     $51 = ($50|0)==(0|0);
     if ($51) {
      $52 = ((($$sroa$0121$0187)) + 8|0);
      $53 = HEAP32[$52>>2]|0;
      $54 = HEAP32[$53>>2]|0;
      $55 = ($54|0)==($$sroa$0121$0187|0);
      if ($55) {
       $$sroa$0121$0$be = $53;$$sroa$0137$0$be = $$sroa$0137$0188;
       break;
      } else {
       $59 = $52;
      }
      while(1) {
       $58 = HEAP32[$59>>2]|0;
       $60 = ((($58)) + 8|0);
       $61 = HEAP32[$60>>2]|0;
       $62 = HEAP32[$61>>2]|0;
       $63 = ($62|0)==($58|0);
       if ($63) {
        $$sroa$0121$0$be = $61;$$sroa$0137$0$be = $$sroa$0137$0188;
        break;
       } else {
        $59 = $60;
       }
      }
     } else {
      $$0$i$i$i$i81 = $50;
      while(1) {
       $56 = HEAP32[$$0$i$i$i$i81>>2]|0;
       $57 = ($56|0)==(0|0);
       if ($57) {
        break;
       } else {
        $$0$i$i$i$i81 = $56;
       }
      }
      $$sroa$0121$0$be = $$0$i$i$i$i81;$$sroa$0137$0$be = $$sroa$0137$0188;
      break;
     }
    } else {
     $64 = ($15>>>0)<($13>>>0);
     if ($64) {
      $65 = HEAP32[$5>>2]|0;
      $66 = ($65|0)==(0|0);
      do {
       if ($66) {
        $$025$i$i94 = $5;$$049$i93 = $5;$76 = $65;
        label = 38;
       } else {
        $$0$i$i92 = $8;$$024$i$i91 = $65;$323 = $65;
        while(1) {
         $67 = ((($$024$i$i91)) + 16|0);
         $68 = HEAP32[$67>>2]|0;
         $69 = ($15>>>0)<($68>>>0);
         if ($69) {
          $70 = HEAP32[$$024$i$i91>>2]|0;
          $71 = ($70|0)==(0|0);
          if ($71) {
           label = 33;
           break;
          } else {
           $$0$ph$i$i89 = $$024$i$i91;$$in$i$i88 = $70;
          }
         } else {
          $72 = ($68>>>0)<($15>>>0);
          if (!($72)) {
           label = 37;
           break;
          }
          $73 = ((($$024$i$i91)) + 4|0);
          $74 = HEAP32[$73>>2]|0;
          $75 = ($74|0)==(0|0);
          if ($75) {
           label = 36;
           break;
          } else {
           $$0$ph$i$i89 = $73;$$in$i$i88 = $74;
          }
         }
         $$0$i$i92 = $$0$ph$i$i89;$$024$i$i91 = $$in$i$i88;$323 = $$in$i$i88;
        }
        if ((label|0) == 33) {
         label = 0;
         $$025$i65$i96 = $$024$i$i91;$$04964$i97 = $$024$i$i91;
         label = 39;
         break;
        }
        else if ((label|0) == 36) {
         label = 0;
         $$025$i65$i96 = $73;$$04964$i97 = $$024$i$i91;
         label = 39;
         break;
        }
        else if ((label|0) == 37) {
         label = 0;
         $$025$i$i94 = $$0$i$i92;$$049$i93 = $$024$i$i91;$76 = $323;
         label = 38;
         break;
        }
       }
      } while(0);
      if ((label|0) == 38) {
       label = 0;
       $77 = ($76|0)==(0|0);
       if ($77) {
        $$025$i65$i96 = $$025$i$i94;$$04964$i97 = $$049$i93;
        label = 39;
       } else {
        $$014$i101 = $76;$110 = $15;
       }
      }
      if ((label|0) == 39) {
       label = 0;
       $78 = (__Znwj(36)|0);
       $79 = ((($78)) + 16|0);
       $80 = HEAP32[$14>>2]|0;
       HEAP32[$79>>2] = $80;
       $81 = ((($78)) + 20|0);
       $82 = ((($78)) + 24|0);
       HEAP32[$82>>2] = 0;
       $83 = ((($78)) + 28|0);
       HEAP32[$83>>2] = 0;
       $84 = ((($78)) + 32|0);
       HEAP32[$84>>2] = 0;
       HEAP8[$81>>0] = 1;
       $85 = ((($78)) + 21|0);
       HEAP8[$85>>0] = 0;
       $86 = ((($78)) + 22|0);
       HEAP8[$86>>0] = 0;
       $87 = ((($78)) + 23|0);
       HEAP8[$87>>0] = 0;
       HEAP32[$78>>2] = 0;
       $88 = ((($78)) + 4|0);
       HEAP32[$88>>2] = 0;
       $89 = ((($78)) + 8|0);
       HEAP32[$89>>2] = $$04964$i97;
       HEAP32[$$025$i65$i96>>2] = $78;
       $90 = HEAP32[$1>>2]|0;
       $91 = HEAP32[$90>>2]|0;
       $92 = ($91|0)==(0|0);
       if ($92) {
        $95 = $78;
       } else {
        $93 = $91;
        HEAP32[$1>>2] = $93;
        $$pre$i$i99 = HEAP32[$$025$i65$i96>>2]|0;
        $95 = $$pre$i$i99;
       }
       $94 = HEAP32[$8>>2]|0;
       __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($94,$95);
       $96 = HEAP32[$9>>2]|0;
       $97 = (($96) + 1)|0;
       HEAP32[$9>>2] = $97;
       $$pre = HEAP32[$14>>2]|0;
       $$014$i101 = $78;$110 = $$pre;
      }
      $98 = ((($$sroa$0137$0188)) + 20|0);
      $99 = HEAP32[$98>>2]|0;
      $100 = $99 & 1;
      $101 = ($100|0)==(0);
      $102 = $100&255;
      $103 = ((($$014$i101)) + 20|0);
      $104 = HEAP8[$103>>0]|0;
      $105 = ($104<<24>>24)==(0);
      if (!($105)) {
       $106 = ((($$014$i101)) + 22|0);
       $107 = HEAP8[$106>>0]|0;
       $108 = $107&255;
       $109 = ($108|0)==($100|0);
       if (!($109)) {
        HEAP8[$106>>0] = $102;
        if ($101) {
         _glDisable(($110|0));
        } else {
         _glEnable(($110|0));
        }
        $111 = HEAP32[$7>>2]|0;
        $112 = ($111|0)==(2);
        if ($112) {
         (__ZNK3osg5State13checkGLErrorsEj(0,$110)|0);
        }
       }
      }
      $113 = ((($$014$i101)) + 21|0);
      HEAP8[$113>>0] = 1;
      $114 = ((($$sroa$0137$0188)) + 4|0);
      $115 = HEAP32[$114>>2]|0;
      $116 = ($115|0)==(0|0);
      if ($116) {
       $117 = ((($$sroa$0137$0188)) + 8|0);
       $118 = HEAP32[$117>>2]|0;
       $119 = HEAP32[$118>>2]|0;
       $120 = ($119|0)==($$sroa$0137$0188|0);
       if ($120) {
        $$sroa$0121$0$be = $$sroa$0121$0187;$$sroa$0137$0$be = $118;
        break;
       } else {
        $124 = $117;
       }
       while(1) {
        $123 = HEAP32[$124>>2]|0;
        $125 = ((($123)) + 8|0);
        $126 = HEAP32[$125>>2]|0;
        $127 = HEAP32[$126>>2]|0;
        $128 = ($127|0)==($123|0);
        if ($128) {
         $$sroa$0121$0$be = $$sroa$0121$0187;$$sroa$0137$0$be = $126;
         break L5;
        } else {
         $124 = $125;
        }
       }
      } else {
       $$0$i$i$i$i106 = $115;
       while(1) {
        $121 = HEAP32[$$0$i$i$i$i106>>2]|0;
        $122 = ($121|0)==(0|0);
        if ($122) {
         break;
        } else {
         $$0$i$i$i$i106 = $121;
        }
       }
       $$sroa$0121$0$be = $$sroa$0121$0187;$$sroa$0137$0$be = $$0$i$i$i$i106;
       break;
      }
     }
     $129 = ((($$sroa$0121$0187)) + 20|0);
     $130 = ((($$sroa$0121$0187)) + 24|0);
     $131 = HEAP32[$130>>2]|0;
     $132 = ((($$sroa$0121$0187)) + 28|0);
     $133 = HEAP32[$132>>2]|0;
     $134 = ($131|0)==($133|0);
     if ($134) {
      label = 65;
     } else {
      $135 = ((($133)) + -4|0);
      $136 = HEAP32[$135>>2]|0;
      $137 = $136 & 2;
      $138 = ($137|0)==(0);
      if ($138) {
       label = 65;
      } else {
       $139 = ((($$sroa$0137$0188)) + 20|0);
       $140 = HEAP32[$139>>2]|0;
       $141 = $140 & 4;
       $142 = ($141|0)==(0);
       if ($142) {
        $143 = ((($12)) + 5|0);
        $144 = HEAP8[$143>>0]|0;
        $145 = ($144<<24>>24)==(0);
        if (!($145)) {
         HEAP8[$143>>0] = 0;
         $146 = $136 & 1;
         $147 = ($146|0)==(0);
         $148 = $146&255;
         $149 = HEAP8[$129>>0]|0;
         $150 = ($149<<24>>24)==(0);
         if (!($150)) {
          $151 = ((($129)) + 2|0);
          $152 = HEAP8[$151>>0]|0;
          $153 = $152&255;
          $154 = ($153|0)==($146|0);
          if (!($154)) {
           HEAP8[$151>>0] = $148;
           if ($147) {
            _glDisable(($13|0));
           } else {
            _glEnable(($13|0));
           }
           $155 = HEAP32[$7>>2]|0;
           $156 = ($155|0)==(2);
           if ($156) {
            (__ZNK3osg5State13checkGLErrorsEj(0,$13)|0);
           }
          }
         }
        }
       } else {
        label = 65;
       }
      }
     }
     if ((label|0) == 65) {
      label = 0;
      $157 = ((($$sroa$0137$0188)) + 20|0);
      $158 = HEAP32[$157>>2]|0;
      $159 = $158 & 1;
      $160 = ($159|0)==(0);
      $161 = $159&255;
      $162 = HEAP8[$129>>0]|0;
      $163 = ($162<<24>>24)==(0);
      if (!($163)) {
       $164 = ((($129)) + 2|0);
       $165 = HEAP8[$164>>0]|0;
       $166 = $165&255;
       $167 = ($166|0)==($159|0);
       if (!($167)) {
        HEAP8[$164>>0] = $161;
        if ($160) {
         _glDisable(($15|0));
        } else {
         _glEnable(($15|0));
        }
        $168 = HEAP32[$7>>2]|0;
        $169 = ($168|0)==(2);
        if ($169) {
         (__ZNK3osg5State13checkGLErrorsEj(0,$15)|0);
        }
        $170 = ((($12)) + 5|0);
        HEAP8[$170>>0] = 1;
       }
      }
     }
     $171 = ((($$sroa$0121$0187)) + 4|0);
     $172 = HEAP32[$171>>2]|0;
     $173 = ($172|0)==(0|0);
     if ($173) {
      $174 = ((($$sroa$0121$0187)) + 8|0);
      $175 = HEAP32[$174>>2]|0;
      $176 = HEAP32[$175>>2]|0;
      $177 = ($176|0)==($$sroa$0121$0187|0);
      if ($177) {
       $$0$i$i$i72 = $175;
      } else {
       $181 = $174;
       while(1) {
        $180 = HEAP32[$181>>2]|0;
        $182 = ((($180)) + 8|0);
        $183 = HEAP32[$182>>2]|0;
        $184 = HEAP32[$183>>2]|0;
        $185 = ($184|0)==($180|0);
        if ($185) {
         $$0$i$i$i72 = $183;
         break;
        } else {
         $181 = $182;
        }
       }
      }
     } else {
      $$0$i$i$i$i68 = $172;
      while(1) {
       $178 = HEAP32[$$0$i$i$i$i68>>2]|0;
       $179 = ($178|0)==(0|0);
       if ($179) {
        break;
       } else {
        $$0$i$i$i$i68 = $178;
       }
      }
      $$0$i$i$i72 = $$0$i$i$i$i68;
     }
     $186 = ((($$sroa$0137$0188)) + 4|0);
     $187 = HEAP32[$186>>2]|0;
     $188 = ($187|0)==(0|0);
     if ($188) {
      $189 = ((($$sroa$0137$0188)) + 8|0);
      $190 = HEAP32[$189>>2]|0;
      $191 = HEAP32[$190>>2]|0;
      $192 = ($191|0)==($$sroa$0137$0188|0);
      if ($192) {
       $$sroa$0121$0$be = $$0$i$i$i72;$$sroa$0137$0$be = $190;
       break;
      } else {
       $196 = $189;
      }
      while(1) {
       $195 = HEAP32[$196>>2]|0;
       $197 = ((($195)) + 8|0);
       $198 = HEAP32[$197>>2]|0;
       $199 = HEAP32[$198>>2]|0;
       $200 = ($199|0)==($195|0);
       if ($200) {
        $$sroa$0121$0$be = $$0$i$i$i72;$$sroa$0137$0$be = $198;
        break;
       } else {
        $196 = $197;
       }
      }
     } else {
      $$0$i$i$i$i61 = $187;
      while(1) {
       $193 = HEAP32[$$0$i$i$i$i61>>2]|0;
       $194 = ($193|0)==(0|0);
       if ($194) {
        break;
       } else {
        $$0$i$i$i$i61 = $193;
       }
      }
      $$sroa$0121$0$be = $$0$i$i$i72;$$sroa$0137$0$be = $$0$i$i$i$i61;
      break;
     }
    }
   } while(0);
   $$not = ($$sroa$0121$0$be|0)==($5|0);
   $$not154 = ($$sroa$0137$0$be|0)==($6|0);
   $brmerge = $$not | $$not154;
   if ($brmerge) {
    $$sroa$0121$0$lcssa = $$sroa$0121$0$be;$$sroa$0137$0$lcssa = $$sroa$0137$0$be;
    break;
   } else {
    $$sroa$0121$0187 = $$sroa$0121$0$be;$$sroa$0137$0188 = $$sroa$0137$0$be;
   }
  }
 }
 $10 = ($$sroa$0121$0$lcssa|0)==($5|0);
 if (!($10)) {
  $11 = ((($0)) + 344|0);
  $$sroa$0121$1182 = $$sroa$0121$0$lcssa;
  while(1) {
   $205 = ((($$sroa$0121$1182)) + 16|0);
   $206 = ((($$sroa$0121$1182)) + 20|0);
   $207 = ((($205)) + 5|0);
   $208 = HEAP8[$207>>0]|0;
   $209 = ($208<<24>>24)==(0);
   do {
    if (!($209)) {
     HEAP8[$207>>0] = 0;
     $210 = ((($$sroa$0121$1182)) + 24|0);
     $211 = HEAP32[$210>>2]|0;
     $212 = ((($$sroa$0121$1182)) + 28|0);
     $213 = HEAP32[$212>>2]|0;
     $214 = ($211|0)==($213|0);
     if ($214) {
      $229 = HEAP32[$205>>2]|0;
      $230 = ((($205)) + 7|0);
      $231 = HEAP8[$230>>0]|0;
      $232 = ($231<<24>>24)==(0);
      $233 = HEAP8[$206>>0]|0;
      $234 = ($233<<24>>24)==(0);
      if ($234) {
       break;
      }
      $235 = ((($206)) + 2|0);
      $236 = HEAP8[$235>>0]|0;
      $237 = ($236<<24>>24)==($231<<24>>24);
      if ($237) {
       break;
      }
      HEAP8[$235>>0] = $231;
      if ($232) {
       _glDisable(($229|0));
      } else {
       _glEnable(($229|0));
      }
      $238 = HEAP32[$11>>2]|0;
      $239 = ($238|0)==(2);
      if (!($239)) {
       break;
      }
      (__ZNK3osg5State13checkGLErrorsEj(0,$229)|0);
      break;
     } else {
      $215 = ((($213)) + -4|0);
      $216 = HEAP32[$215>>2]|0;
      $217 = $216 & 1;
      $218 = ($217|0)==(0);
      $219 = HEAP32[$205>>2]|0;
      $220 = $217&255;
      $221 = HEAP8[$206>>0]|0;
      $222 = ($221<<24>>24)==(0);
      if ($222) {
       break;
      }
      $223 = ((($206)) + 2|0);
      $224 = HEAP8[$223>>0]|0;
      $225 = $224&255;
      $226 = ($225|0)==($217|0);
      if ($226) {
       break;
      }
      HEAP8[$223>>0] = $220;
      if ($218) {
       _glDisable(($219|0));
      } else {
       _glEnable(($219|0));
      }
      $227 = HEAP32[$11>>2]|0;
      $228 = ($227|0)==(2);
      if (!($228)) {
       break;
      }
      (__ZNK3osg5State13checkGLErrorsEj(0,$219)|0);
      break;
     }
    }
   } while(0);
   $240 = ((($$sroa$0121$1182)) + 4|0);
   $241 = HEAP32[$240>>2]|0;
   $242 = ($241|0)==(0|0);
   if ($242) {
    $243 = ((($$sroa$0121$1182)) + 8|0);
    $244 = HEAP32[$243>>2]|0;
    $245 = HEAP32[$244>>2]|0;
    $246 = ($245|0)==($$sroa$0121$1182|0);
    if ($246) {
     $$sroa$0121$1$be = $244;
    } else {
     $251 = $243;
     while(1) {
      $250 = HEAP32[$251>>2]|0;
      $252 = ((($250)) + 8|0);
      $253 = HEAP32[$252>>2]|0;
      $254 = HEAP32[$253>>2]|0;
      $255 = ($254|0)==($250|0);
      if ($255) {
       $$sroa$0121$1$be = $253;
       break;
      } else {
       $251 = $252;
      }
     }
    }
   } else {
    $$0$i$i$i$i51 = $241;
    while(1) {
     $248 = HEAP32[$$0$i$i$i$i51>>2]|0;
     $249 = ($248|0)==(0|0);
     if ($249) {
      break;
     } else {
      $$0$i$i$i$i51 = $248;
     }
    }
    $$sroa$0121$1$be = $$0$i$i$i$i51;
   }
   $247 = ($$sroa$0121$1$be|0)==($5|0);
   if ($247) {
    break;
   } else {
    $$sroa$0121$1182 = $$sroa$0121$1$be;
   }
  }
 }
 $201 = ($$sroa$0137$0$lcssa|0)==($6|0);
 if ($201) {
  return;
 }
 $202 = ((($1)) + 4|0);
 $203 = ((($1)) + 8|0);
 $204 = ((($0)) + 344|0);
 $$sroa$0137$1181 = $$sroa$0137$0$lcssa;
 while(1) {
  $256 = ((($$sroa$0137$1181)) + 16|0);
  $257 = HEAP32[$5>>2]|0;
  $258 = ($257|0)==(0|0);
  do {
   if ($258) {
    $$025$i$i = $5;$$049$i = $5;$269 = $257;
    label = 117;
   } else {
    $259 = HEAP32[$256>>2]|0;
    $$0$i$i = $202;$$024$i$i = $257;$324 = $257;
    while(1) {
     $260 = ((($$024$i$i)) + 16|0);
     $261 = HEAP32[$260>>2]|0;
     $262 = ($259>>>0)<($261>>>0);
     if ($262) {
      $263 = HEAP32[$$024$i$i>>2]|0;
      $264 = ($263|0)==(0|0);
      if ($264) {
       label = 112;
       break;
      } else {
       $$0$ph$i$i = $$024$i$i;$$in$i$i = $263;
      }
     } else {
      $265 = ($261>>>0)<($259>>>0);
      if (!($265)) {
       label = 116;
       break;
      }
      $266 = ((($$024$i$i)) + 4|0);
      $267 = HEAP32[$266>>2]|0;
      $268 = ($267|0)==(0|0);
      if ($268) {
       label = 115;
       break;
      } else {
       $$0$ph$i$i = $266;$$in$i$i = $267;
      }
     }
     $$0$i$i = $$0$ph$i$i;$$024$i$i = $$in$i$i;$324 = $$in$i$i;
    }
    if ((label|0) == 112) {
     label = 0;
     $$025$i65$i = $$024$i$i;$$04964$i = $$024$i$i;
     label = 118;
     break;
    }
    else if ((label|0) == 115) {
     label = 0;
     $$025$i65$i = $266;$$04964$i = $$024$i$i;
     label = 118;
     break;
    }
    else if ((label|0) == 116) {
     label = 0;
     $$025$i$i = $$0$i$i;$$049$i = $$024$i$i;$269 = $324;
     label = 117;
     break;
    }
   }
  } while(0);
  if ((label|0) == 117) {
   label = 0;
   $270 = ($269|0)==(0|0);
   if ($270) {
    $$025$i65$i = $$025$i$i;$$04964$i = $$049$i;
    label = 118;
   } else {
    $$014$i = $269;
   }
  }
  if ((label|0) == 118) {
   label = 0;
   $271 = (__Znwj(36)|0);
   $272 = ((($271)) + 16|0);
   $273 = HEAP32[$256>>2]|0;
   HEAP32[$272>>2] = $273;
   $274 = ((($271)) + 20|0);
   $275 = ((($271)) + 24|0);
   HEAP32[$275>>2] = 0;
   $276 = ((($271)) + 28|0);
   HEAP32[$276>>2] = 0;
   $277 = ((($271)) + 32|0);
   HEAP32[$277>>2] = 0;
   HEAP8[$274>>0] = 1;
   $278 = ((($271)) + 21|0);
   HEAP8[$278>>0] = 0;
   $279 = ((($271)) + 22|0);
   HEAP8[$279>>0] = 0;
   $280 = ((($271)) + 23|0);
   HEAP8[$280>>0] = 0;
   HEAP32[$271>>2] = 0;
   $281 = ((($271)) + 4|0);
   HEAP32[$281>>2] = 0;
   $282 = ((($271)) + 8|0);
   HEAP32[$282>>2] = $$04964$i;
   HEAP32[$$025$i65$i>>2] = $271;
   $283 = HEAP32[$1>>2]|0;
   $284 = HEAP32[$283>>2]|0;
   $285 = ($284|0)==(0|0);
   if ($285) {
    $288 = $271;
   } else {
    $286 = $284;
    HEAP32[$1>>2] = $286;
    $$pre$i$i = HEAP32[$$025$i65$i>>2]|0;
    $288 = $$pre$i$i;
   }
   $287 = HEAP32[$202>>2]|0;
   __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($287,$288);
   $289 = HEAP32[$203>>2]|0;
   $290 = (($289) + 1)|0;
   HEAP32[$203>>2] = $290;
   $$014$i = $271;
  }
  $291 = ((($$sroa$0137$1181)) + 20|0);
  $292 = HEAP32[$291>>2]|0;
  $293 = $292 & 1;
  $294 = ($293|0)==(0);
  $295 = HEAP32[$256>>2]|0;
  $296 = $293&255;
  $297 = ((($$014$i)) + 20|0);
  $298 = HEAP8[$297>>0]|0;
  $299 = ($298<<24>>24)==(0);
  if (!($299)) {
   $300 = ((($$014$i)) + 22|0);
   $301 = HEAP8[$300>>0]|0;
   $302 = $301&255;
   $303 = ($302|0)==($293|0);
   if (!($303)) {
    HEAP8[$300>>0] = $296;
    if ($294) {
     _glDisable(($295|0));
    } else {
     _glEnable(($295|0));
    }
    $304 = HEAP32[$204>>2]|0;
    $305 = ($304|0)==(2);
    if ($305) {
     (__ZNK3osg5State13checkGLErrorsEj(0,$295)|0);
    }
   }
  }
  $306 = ((($$014$i)) + 21|0);
  HEAP8[$306>>0] = 1;
  $307 = ((($$sroa$0137$1181)) + 4|0);
  $308 = HEAP32[$307>>2]|0;
  $309 = ($308|0)==(0|0);
  if ($309) {
   $310 = ((($$sroa$0137$1181)) + 8|0);
   $311 = HEAP32[$310>>2]|0;
   $312 = HEAP32[$311>>2]|0;
   $313 = ($312|0)==($$sroa$0137$1181|0);
   if ($313) {
    $$sroa$0137$1$be = $311;
   } else {
    $318 = $310;
    while(1) {
     $317 = HEAP32[$318>>2]|0;
     $319 = ((($317)) + 8|0);
     $320 = HEAP32[$319>>2]|0;
     $321 = HEAP32[$320>>2]|0;
     $322 = ($321|0)==($317|0);
     if ($322) {
      $$sroa$0137$1$be = $320;
      break;
     } else {
      $318 = $319;
     }
    }
   }
  } else {
   $$0$i$i$i$i = $308;
   while(1) {
    $315 = HEAP32[$$0$i$i$i$i>>2]|0;
    $316 = ($315|0)==(0|0);
    if ($316) {
     break;
    } else {
     $$0$i$i$i$i = $315;
    }
   }
   $$sroa$0137$1$be = $$0$i$i$i$i;
  }
  $314 = ($$sroa$0137$1$be|0)==($6|0);
  if ($314) {
   break;
  } else {
   $$sroa$0137$1181 = $$sroa$0137$1$be;
  }
 }
 return;
}
function __ZN3osg5State18applyAttributeListERNSt3__23mapINS1_4pairINS_14StateAttribute4TypeEjEENS0_14AttributeStackENS1_4lessIS6_EENS1_9allocatorINS3_IKS6_S7_EEEEEERKNS2_IS6_NS3_INS_7ref_ptrIS4_EEjEES9_NSA_INS3_ISB_SI_EEEEEE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i109 = 0, $$0$i$i$i$i116 = 0, $$0$i$i$i$i123 = 0, $$0$i$i$i$i62 = 0, $$0$i$i$i$i77 = 0, $$0$i$i$i127 = 0, $$0$i$i89 = 0, $$0$ph$i$i = 0, $$0$ph$i$i86 = 0, $$014$i = 0, $$014$i103 = 0, $$024$i$i = 0, $$024$i$i88 = 0, $$025$i$i = 0, $$025$i$i96 = 0, $$025$i68$i = 0, $$025$i68$i98 = 0, $$052$i = 0;
 var $$052$i95 = 0, $$05267$i = 0, $$05267$i99 = 0, $$in$i$i = 0, $$in$i$i85 = 0, $$not = 0, $$not169 = 0, $$not169200 = 0, $$not199 = 0, $$pre$i$i = 0, $$pre$i$i101 = 0, $$sroa$0142$0$be = 0, $$sroa$0142$0$lcssa = 0, $$sroa$0142$0202 = 0, $$sroa$0142$1$be = 0, $$sroa$0142$1197 = 0, $$sroa$0153$0$be = 0, $$sroa$0153$0$lcssa = 0, $$sroa$0153$0204 = 0, $$sroa$0153$1$be = 0;
 var $$sroa$0153$1196 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0;
 var $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0;
 var $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0;
 var $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0;
 var $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0;
 var $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0;
 var $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0;
 var $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0;
 var $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0;
 var $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0;
 var $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0;
 var $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0;
 var $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0;
 var $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0;
 var $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0;
 var $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0;
 var $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0;
 var $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0;
 var $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0;
 var $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0;
 var $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0;
 var $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $brmerge = 0, $brmerge201 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$1>>2]|0;
 $5 = ((($1)) + 4|0);
 $6 = ((($2)) + 4|0);
 $$not199 = ($4|0)==($5|0);
 $$not169200 = ($3|0)==($6|0);
 $brmerge201 = $$not199 | $$not169200;
 if ($brmerge201) {
  $$sroa$0142$0$lcssa = $4;$$sroa$0153$0$lcssa = $3;
 } else {
  $7 = ((($0)) + 344|0);
  $8 = ((($0)) + 137|0);
  $9 = ((($1)) + 4|0);
  $10 = ((($1)) + 8|0);
  $$sroa$0142$0202 = $4;$$sroa$0153$0204 = $3;
  while(1) {
   $14 = ((($$sroa$0142$0202)) + 16|0);
   $15 = ((($$sroa$0153$0204)) + 16|0);
   $16 = HEAP32[$14>>2]|0;
   $17 = HEAP32[$15>>2]|0;
   $18 = ($16|0)<($17|0);
   L5: do {
    if ($18) {
     label = 8;
    } else {
     $19 = ($17|0)<($16|0);
     if (!($19)) {
      $20 = ((($$sroa$0142$0202)) + 20|0);
      $21 = HEAP32[$20>>2]|0;
      $22 = ((($$sroa$0153$0204)) + 20|0);
      $23 = HEAP32[$22>>2]|0;
      $24 = ($21>>>0)<($23>>>0);
      if ($24) {
       label = 8;
       break;
      }
      $100 = ((($$sroa$0153$0204)) + 20|0);
      $101 = HEAP32[$100>>2]|0;
      $102 = ((($$sroa$0142$0202)) + 20|0);
      $103 = HEAP32[$102>>2]|0;
      $104 = ($101>>>0)<($103>>>0);
      if (!($104)) {
       $199 = ((($$sroa$0142$0202)) + 24|0);
       $200 = ((($$sroa$0142$0202)) + 40|0);
       $201 = HEAP32[$200>>2]|0;
       $202 = ((($$sroa$0142$0202)) + 44|0);
       $203 = HEAP32[$202>>2]|0;
       $204 = ($201|0)==($203|0);
       if ($204) {
        label = 84;
       } else {
        $205 = ((($203)) + -4|0);
        $206 = HEAP32[$205>>2]|0;
        $207 = $206 & 2;
        $208 = ($207|0)==(0);
        if ($208) {
         label = 84;
        } else {
         $209 = ((($$sroa$0153$0204)) + 28|0);
         $210 = HEAP32[$209>>2]|0;
         $211 = $210 & 4;
         $212 = ($211|0)==(0);
         if ($212) {
          $213 = HEAP8[$199>>0]|0;
          $214 = ($213<<24>>24)==(0);
          if (!($214)) {
           HEAP8[$199>>0] = 0;
           $215 = ((($203)) + -8|0);
           $216 = HEAP32[$215>>2]|0;
           $217 = ((($$sroa$0142$0202)) + 28|0);
           $218 = HEAP32[$217>>2]|0;
           $219 = ($218|0)==($216|0);
           if (!($219)) {
            $220 = ((($$sroa$0142$0202)) + 36|0);
            $221 = HEAP32[$220>>2]|0;
            $222 = ($221|0)==(0|0);
            do {
             if ($222) {
              $223 = HEAP32[$216>>2]|0;
              $224 = ((($223)) + 12|0);
              $225 = HEAP32[$224>>2]|0;
              $226 = (FUNCTION_TABLE_ii[$225 & 8191]($216)|0);
              $227 = HEAP32[$226>>2]|0;
              $228 = ((($227)) + 56|0);
              $229 = HEAP32[$228>>2]|0;
              $230 = (FUNCTION_TABLE_ii[$229 & 8191]($226)|0);
              $231 = HEAP32[$220>>2]|0;
              $232 = ($231|0)==($230|0);
              if (!($232)) {
               HEAP32[$220>>2] = $230;
               $233 = ($230|0)==(0|0);
               if (!($233)) {
                $234 = ((($230)) + 8|0);
                $235 = HEAP32[$234>>2]|0;HEAP32[$234>>2] = (($235+1)|0);
               }
               $236 = ($231|0)==(0|0);
               if (!($236)) {
                $237 = ((($231)) + 8|0);
                $238 = HEAP32[$237>>2]|0;HEAP32[$237>>2] = (($238-1)|0);
                $239 = ($238|0)==(1);
                if (!($239)) {
                 break;
                }
                __ZNK3osg10Referenced24signalObserversAndDeleteEbb($231,1,1);
               }
              }
             }
            } while(0);
            HEAP32[$217>>2] = $216;
            $240 = HEAP32[$216>>2]|0;
            $241 = ((($240)) + 172|0);
            $242 = HEAP32[$241>>2]|0;
            FUNCTION_TABLE_vii[$242 & 8191]($216,$0);
            $243 = ((($216)) + 44|0);
            $244 = HEAP32[$243>>2]|0;
            $245 = ((($$sroa$0142$0202)) + 32|0);
            $246 = HEAP32[$245>>2]|0;
            $247 = ($246|0)==($244|0);
            if (!($247)) {
             HEAP32[$245>>2] = $244;
             HEAP8[$8>>0] = 1;
            }
            $248 = HEAP32[$7>>2]|0;
            $249 = ($248|0)==(2);
            if ($249) {
             (__ZNK3osg5State13checkGLErrorsEPKNS_14StateAttributeE(0,$216)|0);
            }
           }
          }
         } else {
          label = 84;
         }
        }
       }
       if ((label|0) == 84) {
        label = 0;
        $250 = ((($$sroa$0153$0204)) + 24|0);
        $251 = HEAP32[$250>>2]|0;
        $252 = ((($$sroa$0142$0202)) + 28|0);
        $253 = HEAP32[$252>>2]|0;
        $254 = ($253|0)==($251|0);
        if (!($254)) {
         $255 = ((($$sroa$0142$0202)) + 36|0);
         $256 = HEAP32[$255>>2]|0;
         $257 = ($256|0)==(0|0);
         if ($257) {
          $258 = HEAP32[$251>>2]|0;
          $259 = ((($258)) + 12|0);
          $260 = HEAP32[$259>>2]|0;
          $261 = (FUNCTION_TABLE_ii[$260 & 8191]($251)|0);
          $262 = HEAP32[$261>>2]|0;
          $263 = ((($262)) + 56|0);
          $264 = HEAP32[$263>>2]|0;
          $265 = (FUNCTION_TABLE_ii[$264 & 8191]($261)|0);
          $266 = HEAP32[$255>>2]|0;
          $267 = ($266|0)==($265|0);
          if (!($267)) {
           HEAP32[$255>>2] = $265;
           $268 = ($265|0)==(0|0);
           if (!($268)) {
            $269 = ((($265)) + 8|0);
            $270 = HEAP32[$269>>2]|0;HEAP32[$269>>2] = (($270+1)|0);
           }
           $271 = ($266|0)==(0|0);
           if (!($271)) {
            $272 = ((($266)) + 8|0);
            $273 = HEAP32[$272>>2]|0;HEAP32[$272>>2] = (($273-1)|0);
            $274 = ($273|0)==(1);
            if ($274) {
             __ZNK3osg10Referenced24signalObserversAndDeleteEbb($266,1,1);
            }
           }
          }
         }
         HEAP32[$252>>2] = $251;
         $275 = HEAP32[$251>>2]|0;
         $276 = ((($275)) + 172|0);
         $277 = HEAP32[$276>>2]|0;
         FUNCTION_TABLE_vii[$277 & 8191]($251,$0);
         $278 = ((($251)) + 44|0);
         $279 = HEAP32[$278>>2]|0;
         $280 = ((($$sroa$0142$0202)) + 32|0);
         $281 = HEAP32[$280>>2]|0;
         $282 = ($281|0)==($279|0);
         if (!($282)) {
          HEAP32[$280>>2] = $279;
          HEAP8[$8>>0] = 1;
         }
         $283 = HEAP32[$7>>2]|0;
         $284 = ($283|0)==(2);
         if ($284) {
          (__ZNK3osg5State13checkGLErrorsEPKNS_14StateAttributeE(0,$251)|0);
         }
         HEAP8[$199>>0] = 1;
        }
       }
       $285 = ((($$sroa$0142$0202)) + 4|0);
       $286 = HEAP32[$285>>2]|0;
       $287 = ($286|0)==(0|0);
       if ($287) {
        $288 = ((($$sroa$0142$0202)) + 8|0);
        $289 = HEAP32[$288>>2]|0;
        $290 = HEAP32[$289>>2]|0;
        $291 = ($290|0)==($$sroa$0142$0202|0);
        if ($291) {
         $$0$i$i$i127 = $289;
        } else {
         $295 = $288;
         while(1) {
          $294 = HEAP32[$295>>2]|0;
          $296 = ((($294)) + 8|0);
          $297 = HEAP32[$296>>2]|0;
          $298 = HEAP32[$297>>2]|0;
          $299 = ($298|0)==($294|0);
          if ($299) {
           $$0$i$i$i127 = $297;
           break;
          } else {
           $295 = $296;
          }
         }
        }
       } else {
        $$0$i$i$i$i123 = $286;
        while(1) {
         $292 = HEAP32[$$0$i$i$i$i123>>2]|0;
         $293 = ($292|0)==(0|0);
         if ($293) {
          break;
         } else {
          $$0$i$i$i$i123 = $292;
         }
        }
        $$0$i$i$i127 = $$0$i$i$i$i123;
       }
       $300 = ((($$sroa$0153$0204)) + 4|0);
       $301 = HEAP32[$300>>2]|0;
       $302 = ($301|0)==(0|0);
       if ($302) {
        $303 = ((($$sroa$0153$0204)) + 8|0);
        $304 = HEAP32[$303>>2]|0;
        $305 = HEAP32[$304>>2]|0;
        $306 = ($305|0)==($$sroa$0153$0204|0);
        if ($306) {
         $$sroa$0142$0$be = $$0$i$i$i127;$$sroa$0153$0$be = $304;
         break;
        } else {
         $310 = $303;
        }
        while(1) {
         $309 = HEAP32[$310>>2]|0;
         $311 = ((($309)) + 8|0);
         $312 = HEAP32[$311>>2]|0;
         $313 = HEAP32[$312>>2]|0;
         $314 = ($313|0)==($309|0);
         if ($314) {
          $$sroa$0142$0$be = $$0$i$i$i127;$$sroa$0153$0$be = $312;
          break L5;
         } else {
          $310 = $311;
         }
        }
       } else {
        $$0$i$i$i$i116 = $301;
        while(1) {
         $307 = HEAP32[$$0$i$i$i$i116>>2]|0;
         $308 = ($307|0)==(0|0);
         if ($308) {
          break;
         } else {
          $$0$i$i$i$i116 = $307;
         }
        }
        $$sroa$0142$0$be = $$0$i$i$i127;$$sroa$0153$0$be = $$0$i$i$i$i116;
        break;
       }
      }
     }
     $105 = HEAP32[$5>>2]|0;
     $106 = ($105|0)==(0|0);
     do {
      if ($106) {
       $$025$i$i96 = $5;$$052$i95 = $5;$122 = $105;
       label = 47;
      } else {
       $107 = ((($$sroa$0153$0204)) + 20|0);
       $108 = HEAP32[$107>>2]|0;
       $$0$i$i89 = $9;$$024$i$i88 = $105;$493 = $105;
       L67: while(1) {
        $109 = ((($$024$i$i88)) + 16|0);
        $110 = HEAP32[$109>>2]|0;
        $111 = ($17|0)<($110|0);
        do {
         if ($111) {
          label = 41;
         } else {
          $112 = ($110|0)<($17|0);
          if (!($112)) {
           $113 = ((($$024$i$i88)) + 20|0);
           $114 = HEAP32[$113>>2]|0;
           $115 = ($108>>>0)<($114>>>0);
           if ($115) {
            label = 41;
            break;
           }
           $118 = ($114>>>0)<($108>>>0);
           if (!($118)) {
            label = 46;
            break L67;
           }
          }
          $119 = ((($$024$i$i88)) + 4|0);
          $120 = HEAP32[$119>>2]|0;
          $121 = ($120|0)==(0|0);
          if ($121) {
           label = 45;
           break L67;
          } else {
           $$0$ph$i$i86 = $119;$$in$i$i85 = $120;
          }
         }
        } while(0);
        if ((label|0) == 41) {
         label = 0;
         $116 = HEAP32[$$024$i$i88>>2]|0;
         $117 = ($116|0)==(0|0);
         if ($117) {
          label = 42;
          break;
         } else {
          $$0$ph$i$i86 = $$024$i$i88;$$in$i$i85 = $116;
         }
        }
        $$0$i$i89 = $$0$ph$i$i86;$$024$i$i88 = $$in$i$i85;$493 = $$in$i$i85;
       }
       if ((label|0) == 42) {
        label = 0;
        $$025$i68$i98 = $$024$i$i88;$$05267$i99 = $$024$i$i88;
        label = 48;
        break;
       }
       else if ((label|0) == 45) {
        label = 0;
        $$025$i68$i98 = $119;$$05267$i99 = $$024$i$i88;
        label = 48;
        break;
       }
       else if ((label|0) == 46) {
        label = 0;
        $$025$i$i96 = $$0$i$i89;$$052$i95 = $$024$i$i88;$122 = $493;
        label = 47;
        break;
       }
      }
     } while(0);
     if ((label|0) == 47) {
      label = 0;
      $123 = ($122|0)==(0|0);
      if ($123) {
       $$025$i68$i98 = $$025$i$i96;$$05267$i99 = $$052$i95;
       label = 48;
      } else {
       $$014$i103 = $122;
      }
     }
     if ((label|0) == 48) {
      label = 0;
      $124 = (__Znwj(52)|0);
      $125 = ((($124)) + 16|0);
      $126 = $15;
      $127 = $126;
      $128 = HEAP32[$127>>2]|0;
      $129 = (($126) + 4)|0;
      $130 = $129;
      $131 = HEAP32[$130>>2]|0;
      $132 = $125;
      $133 = $132;
      HEAP32[$133>>2] = $128;
      $134 = (($132) + 4)|0;
      $135 = $134;
      HEAP32[$135>>2] = $131;
      $136 = ((($124)) + 24|0);
      HEAP8[$136>>0] = 0;
      $137 = ((($124)) + 28|0);
      ;HEAP32[$137>>2]=0|0;HEAP32[$137+4>>2]=0|0;HEAP32[$137+8>>2]=0|0;HEAP32[$137+12>>2]=0|0;HEAP32[$137+16>>2]=0|0;HEAP32[$137+20>>2]=0|0;
      HEAP32[$124>>2] = 0;
      $138 = ((($124)) + 4|0);
      HEAP32[$138>>2] = 0;
      $139 = ((($124)) + 8|0);
      HEAP32[$139>>2] = $$05267$i99;
      HEAP32[$$025$i68$i98>>2] = $124;
      $140 = HEAP32[$1>>2]|0;
      $141 = HEAP32[$140>>2]|0;
      $142 = ($141|0)==(0|0);
      if ($142) {
       $145 = $124;
      } else {
       $143 = $141;
       HEAP32[$1>>2] = $143;
       $$pre$i$i101 = HEAP32[$$025$i68$i98>>2]|0;
       $145 = $$pre$i$i101;
      }
      $144 = HEAP32[$9>>2]|0;
      __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($144,$145);
      $146 = HEAP32[$10>>2]|0;
      $147 = (($146) + 1)|0;
      HEAP32[$10>>2] = $147;
      $$014$i103 = $124;
     }
     $148 = ((($$sroa$0153$0204)) + 24|0);
     $149 = HEAP32[$148>>2]|0;
     $150 = ((($$014$i103)) + 28|0);
     $151 = HEAP32[$150>>2]|0;
     $152 = ($151|0)==($149|0);
     if (!($152)) {
      $153 = ((($$014$i103)) + 36|0);
      $154 = HEAP32[$153>>2]|0;
      $155 = ($154|0)==(0|0);
      if ($155) {
       $156 = HEAP32[$149>>2]|0;
       $157 = ((($156)) + 12|0);
       $158 = HEAP32[$157>>2]|0;
       $159 = (FUNCTION_TABLE_ii[$158 & 8191]($149)|0);
       $160 = HEAP32[$159>>2]|0;
       $161 = ((($160)) + 56|0);
       $162 = HEAP32[$161>>2]|0;
       $163 = (FUNCTION_TABLE_ii[$162 & 8191]($159)|0);
       $164 = HEAP32[$153>>2]|0;
       $165 = ($164|0)==($163|0);
       if (!($165)) {
        HEAP32[$153>>2] = $163;
        $166 = ($163|0)==(0|0);
        if (!($166)) {
         $167 = ((($163)) + 8|0);
         $168 = HEAP32[$167>>2]|0;HEAP32[$167>>2] = (($168+1)|0);
        }
        $169 = ($164|0)==(0|0);
        if (!($169)) {
         $170 = ((($164)) + 8|0);
         $171 = HEAP32[$170>>2]|0;HEAP32[$170>>2] = (($171-1)|0);
         $172 = ($171|0)==(1);
         if ($172) {
          __ZNK3osg10Referenced24signalObserversAndDeleteEbb($164,1,1);
         }
        }
       }
      }
      HEAP32[$150>>2] = $149;
      $173 = HEAP32[$149>>2]|0;
      $174 = ((($173)) + 172|0);
      $175 = HEAP32[$174>>2]|0;
      FUNCTION_TABLE_vii[$175 & 8191]($149,$0);
      $176 = ((($149)) + 44|0);
      $177 = HEAP32[$176>>2]|0;
      $178 = ((($$014$i103)) + 32|0);
      $179 = HEAP32[$178>>2]|0;
      $180 = ($179|0)==($177|0);
      if (!($180)) {
       HEAP32[$178>>2] = $177;
       HEAP8[$8>>0] = 1;
      }
      $181 = HEAP32[$7>>2]|0;
      $182 = ($181|0)==(2);
      if ($182) {
       (__ZNK3osg5State13checkGLErrorsEPKNS_14StateAttributeE(0,$149)|0);
      }
     }
     $183 = ((($$014$i103)) + 24|0);
     HEAP8[$183>>0] = 1;
     $184 = ((($$sroa$0153$0204)) + 4|0);
     $185 = HEAP32[$184>>2]|0;
     $186 = ($185|0)==(0|0);
     if ($186) {
      $187 = ((($$sroa$0153$0204)) + 8|0);
      $188 = HEAP32[$187>>2]|0;
      $189 = HEAP32[$188>>2]|0;
      $190 = ($189|0)==($$sroa$0153$0204|0);
      if ($190) {
       $$sroa$0142$0$be = $$sroa$0142$0202;$$sroa$0153$0$be = $188;
       break;
      } else {
       $194 = $187;
      }
      while(1) {
       $193 = HEAP32[$194>>2]|0;
       $195 = ((($193)) + 8|0);
       $196 = HEAP32[$195>>2]|0;
       $197 = HEAP32[$196>>2]|0;
       $198 = ($197|0)==($193|0);
       if ($198) {
        $$sroa$0142$0$be = $$sroa$0142$0202;$$sroa$0153$0$be = $196;
        break;
       } else {
        $194 = $195;
       }
      }
     } else {
      $$0$i$i$i$i109 = $185;
      while(1) {
       $191 = HEAP32[$$0$i$i$i$i109>>2]|0;
       $192 = ($191|0)==(0|0);
       if ($192) {
        break;
       } else {
        $$0$i$i$i$i109 = $191;
       }
      }
      $$sroa$0142$0$be = $$sroa$0142$0202;$$sroa$0153$0$be = $$0$i$i$i$i109;
      break;
     }
    }
   } while(0);
   do {
    if ((label|0) == 8) {
     label = 0;
     $25 = ((($$sroa$0142$0202)) + 24|0);
     $26 = HEAP8[$25>>0]|0;
     $27 = ($26<<24>>24)==(0);
     do {
      if (!($27)) {
       HEAP8[$25>>0] = 0;
       $28 = ((($$sroa$0142$0202)) + 40|0);
       $29 = HEAP32[$28>>2]|0;
       $30 = ((($$sroa$0142$0202)) + 44|0);
       $31 = HEAP32[$30>>2]|0;
       $32 = ($29|0)==($31|0);
       if ($32) {
        $68 = ((($$sroa$0142$0202)) + 28|0);
        $69 = HEAP32[$68>>2]|0;
        $70 = ((($$sroa$0142$0202)) + 36|0);
        $71 = HEAP32[$70>>2]|0;
        $72 = ($69|0)==($71|0);
        if ($72) {
         break;
        }
        HEAP32[$68>>2] = $71;
        $73 = ($71|0)==(0|0);
        if ($73) {
         break;
        }
        $74 = HEAP32[$71>>2]|0;
        $75 = ((($74)) + 172|0);
        $76 = HEAP32[$75>>2]|0;
        FUNCTION_TABLE_vii[$76 & 8191]($71,$0);
        $77 = HEAP32[$70>>2]|0;
        $78 = ((($77)) + 44|0);
        $79 = HEAP32[$78>>2]|0;
        $80 = ((($$sroa$0142$0202)) + 32|0);
        $81 = HEAP32[$80>>2]|0;
        $82 = ($81|0)==($79|0);
        if (!($82)) {
         HEAP32[$80>>2] = $79;
         HEAP8[$8>>0] = 1;
        }
        $83 = HEAP32[$7>>2]|0;
        $84 = ($83|0)==(2);
        if (!($84)) {
         break;
        }
        (__ZNK3osg5State13checkGLErrorsEPKNS_14StateAttributeE(0,$77)|0);
        break;
       }
       $33 = ((($31)) + -8|0);
       $34 = HEAP32[$33>>2]|0;
       $35 = ((($$sroa$0142$0202)) + 28|0);
       $36 = HEAP32[$35>>2]|0;
       $37 = ($36|0)==($34|0);
       if (!($37)) {
        $38 = ((($$sroa$0142$0202)) + 36|0);
        $39 = HEAP32[$38>>2]|0;
        $40 = ($39|0)==(0|0);
        if ($40) {
         $41 = HEAP32[$34>>2]|0;
         $42 = ((($41)) + 12|0);
         $43 = HEAP32[$42>>2]|0;
         $44 = (FUNCTION_TABLE_ii[$43 & 8191]($34)|0);
         $45 = HEAP32[$44>>2]|0;
         $46 = ((($45)) + 56|0);
         $47 = HEAP32[$46>>2]|0;
         $48 = (FUNCTION_TABLE_ii[$47 & 8191]($44)|0);
         $49 = HEAP32[$38>>2]|0;
         $50 = ($49|0)==($48|0);
         if (!($50)) {
          HEAP32[$38>>2] = $48;
          $51 = ($48|0)==(0|0);
          if (!($51)) {
           $52 = ((($48)) + 8|0);
           $53 = HEAP32[$52>>2]|0;HEAP32[$52>>2] = (($53+1)|0);
          }
          $54 = ($49|0)==(0|0);
          if (!($54)) {
           $55 = ((($49)) + 8|0);
           $56 = HEAP32[$55>>2]|0;HEAP32[$55>>2] = (($56-1)|0);
           $57 = ($56|0)==(1);
           if ($57) {
            __ZNK3osg10Referenced24signalObserversAndDeleteEbb($49,1,1);
           }
          }
         }
        }
        HEAP32[$35>>2] = $34;
        $58 = HEAP32[$34>>2]|0;
        $59 = ((($58)) + 172|0);
        $60 = HEAP32[$59>>2]|0;
        FUNCTION_TABLE_vii[$60 & 8191]($34,$0);
        $61 = ((($34)) + 44|0);
        $62 = HEAP32[$61>>2]|0;
        $63 = ((($$sroa$0142$0202)) + 32|0);
        $64 = HEAP32[$63>>2]|0;
        $65 = ($64|0)==($62|0);
        if (!($65)) {
         HEAP32[$63>>2] = $62;
         HEAP8[$8>>0] = 1;
        }
        $66 = HEAP32[$7>>2]|0;
        $67 = ($66|0)==(2);
        if ($67) {
         (__ZNK3osg5State13checkGLErrorsEPKNS_14StateAttributeE(0,$34)|0);
        }
       }
      }
     } while(0);
     $85 = ((($$sroa$0142$0202)) + 4|0);
     $86 = HEAP32[$85>>2]|0;
     $87 = ($86|0)==(0|0);
     if ($87) {
      $88 = ((($$sroa$0142$0202)) + 8|0);
      $89 = HEAP32[$88>>2]|0;
      $90 = HEAP32[$89>>2]|0;
      $91 = ($90|0)==($$sroa$0142$0202|0);
      if ($91) {
       $$sroa$0142$0$be = $89;$$sroa$0153$0$be = $$sroa$0153$0204;
       break;
      } else {
       $95 = $88;
      }
      while(1) {
       $94 = HEAP32[$95>>2]|0;
       $96 = ((($94)) + 8|0);
       $97 = HEAP32[$96>>2]|0;
       $98 = HEAP32[$97>>2]|0;
       $99 = ($98|0)==($94|0);
       if ($99) {
        $$sroa$0142$0$be = $97;$$sroa$0153$0$be = $$sroa$0153$0204;
        break;
       } else {
        $95 = $96;
       }
      }
     } else {
      $$0$i$i$i$i77 = $86;
      while(1) {
       $92 = HEAP32[$$0$i$i$i$i77>>2]|0;
       $93 = ($92|0)==(0|0);
       if ($93) {
        break;
       } else {
        $$0$i$i$i$i77 = $92;
       }
      }
      $$sroa$0142$0$be = $$0$i$i$i$i77;$$sroa$0153$0$be = $$sroa$0153$0204;
      break;
     }
    }
   } while(0);
   $$not = ($$sroa$0142$0$be|0)==($5|0);
   $$not169 = ($$sroa$0153$0$be|0)==($6|0);
   $brmerge = $$not | $$not169;
   if ($brmerge) {
    $$sroa$0142$0$lcssa = $$sroa$0142$0$be;$$sroa$0153$0$lcssa = $$sroa$0153$0$be;
    break;
   } else {
    $$sroa$0142$0202 = $$sroa$0142$0$be;$$sroa$0153$0204 = $$sroa$0153$0$be;
   }
  }
 }
 $11 = ($$sroa$0142$0$lcssa|0)==($5|0);
 if (!($11)) {
  $12 = ((($0)) + 344|0);
  $13 = ((($0)) + 137|0);
  $$sroa$0142$1197 = $$sroa$0142$0$lcssa;
  while(1) {
   $320 = ((($$sroa$0142$1197)) + 24|0);
   $321 = HEAP8[$320>>0]|0;
   $322 = ($321<<24>>24)==(0);
   do {
    if (!($322)) {
     HEAP8[$320>>0] = 0;
     $323 = ((($$sroa$0142$1197)) + 40|0);
     $324 = HEAP32[$323>>2]|0;
     $325 = ((($$sroa$0142$1197)) + 44|0);
     $326 = HEAP32[$325>>2]|0;
     $327 = ($324|0)==($326|0);
     if ($327) {
      $363 = ((($$sroa$0142$1197)) + 28|0);
      $364 = HEAP32[$363>>2]|0;
      $365 = ((($$sroa$0142$1197)) + 36|0);
      $366 = HEAP32[$365>>2]|0;
      $367 = ($364|0)==($366|0);
      if ($367) {
       break;
      }
      HEAP32[$363>>2] = $366;
      $368 = ($366|0)==(0|0);
      if ($368) {
       break;
      }
      $369 = HEAP32[$366>>2]|0;
      $370 = ((($369)) + 172|0);
      $371 = HEAP32[$370>>2]|0;
      FUNCTION_TABLE_vii[$371 & 8191]($366,$0);
      $372 = HEAP32[$365>>2]|0;
      $373 = ((($372)) + 44|0);
      $374 = HEAP32[$373>>2]|0;
      $375 = ((($$sroa$0142$1197)) + 32|0);
      $376 = HEAP32[$375>>2]|0;
      $377 = ($376|0)==($374|0);
      if (!($377)) {
       HEAP32[$375>>2] = $374;
       HEAP8[$13>>0] = 1;
      }
      $378 = HEAP32[$12>>2]|0;
      $379 = ($378|0)==(2);
      if (!($379)) {
       break;
      }
      (__ZNK3osg5State13checkGLErrorsEPKNS_14StateAttributeE(0,$372)|0);
      break;
     }
     $328 = ((($326)) + -8|0);
     $329 = HEAP32[$328>>2]|0;
     $330 = ((($$sroa$0142$1197)) + 28|0);
     $331 = HEAP32[$330>>2]|0;
     $332 = ($331|0)==($329|0);
     if (!($332)) {
      $333 = ((($$sroa$0142$1197)) + 36|0);
      $334 = HEAP32[$333>>2]|0;
      $335 = ($334|0)==(0|0);
      if ($335) {
       $336 = HEAP32[$329>>2]|0;
       $337 = ((($336)) + 12|0);
       $338 = HEAP32[$337>>2]|0;
       $339 = (FUNCTION_TABLE_ii[$338 & 8191]($329)|0);
       $340 = HEAP32[$339>>2]|0;
       $341 = ((($340)) + 56|0);
       $342 = HEAP32[$341>>2]|0;
       $343 = (FUNCTION_TABLE_ii[$342 & 8191]($339)|0);
       $344 = HEAP32[$333>>2]|0;
       $345 = ($344|0)==($343|0);
       if (!($345)) {
        HEAP32[$333>>2] = $343;
        $346 = ($343|0)==(0|0);
        if (!($346)) {
         $347 = ((($343)) + 8|0);
         $348 = HEAP32[$347>>2]|0;HEAP32[$347>>2] = (($348+1)|0);
        }
        $349 = ($344|0)==(0|0);
        if (!($349)) {
         $350 = ((($344)) + 8|0);
         $351 = HEAP32[$350>>2]|0;HEAP32[$350>>2] = (($351-1)|0);
         $352 = ($351|0)==(1);
         if ($352) {
          __ZNK3osg10Referenced24signalObserversAndDeleteEbb($344,1,1);
         }
        }
       }
      }
      HEAP32[$330>>2] = $329;
      $353 = HEAP32[$329>>2]|0;
      $354 = ((($353)) + 172|0);
      $355 = HEAP32[$354>>2]|0;
      FUNCTION_TABLE_vii[$355 & 8191]($329,$0);
      $356 = ((($329)) + 44|0);
      $357 = HEAP32[$356>>2]|0;
      $358 = ((($$sroa$0142$1197)) + 32|0);
      $359 = HEAP32[$358>>2]|0;
      $360 = ($359|0)==($357|0);
      if (!($360)) {
       HEAP32[$358>>2] = $357;
       HEAP8[$13>>0] = 1;
      }
      $361 = HEAP32[$12>>2]|0;
      $362 = ($361|0)==(2);
      if ($362) {
       (__ZNK3osg5State13checkGLErrorsEPKNS_14StateAttributeE(0,$329)|0);
      }
     }
    }
   } while(0);
   $380 = ((($$sroa$0142$1197)) + 4|0);
   $381 = HEAP32[$380>>2]|0;
   $382 = ($381|0)==(0|0);
   if ($382) {
    $383 = ((($$sroa$0142$1197)) + 8|0);
    $384 = HEAP32[$383>>2]|0;
    $385 = HEAP32[$384>>2]|0;
    $386 = ($385|0)==($$sroa$0142$1197|0);
    if ($386) {
     $$sroa$0142$1$be = $384;
    } else {
     $391 = $383;
     while(1) {
      $390 = HEAP32[$391>>2]|0;
      $392 = ((($390)) + 8|0);
      $393 = HEAP32[$392>>2]|0;
      $394 = HEAP32[$393>>2]|0;
      $395 = ($394|0)==($390|0);
      if ($395) {
       $$sroa$0142$1$be = $393;
       break;
      } else {
       $391 = $392;
      }
     }
    }
   } else {
    $$0$i$i$i$i62 = $381;
    while(1) {
     $388 = HEAP32[$$0$i$i$i$i62>>2]|0;
     $389 = ($388|0)==(0|0);
     if ($389) {
      break;
     } else {
      $$0$i$i$i$i62 = $388;
     }
    }
    $$sroa$0142$1$be = $$0$i$i$i$i62;
   }
   $387 = ($$sroa$0142$1$be|0)==($5|0);
   if ($387) {
    break;
   } else {
    $$sroa$0142$1197 = $$sroa$0142$1$be;
   }
  }
 }
 $315 = ($$sroa$0153$0$lcssa|0)==($6|0);
 if ($315) {
  return;
 }
 $316 = ((($1)) + 4|0);
 $317 = ((($1)) + 8|0);
 $318 = ((($0)) + 344|0);
 $319 = ((($0)) + 137|0);
 $$sroa$0153$1196 = $$sroa$0153$0$lcssa;
 while(1) {
  $396 = ((($$sroa$0153$1196)) + 16|0);
  $397 = HEAP32[$5>>2]|0;
  $398 = ($397|0)==(0|0);
  do {
   if ($398) {
    $$025$i$i = $5;$$052$i = $5;$415 = $397;
    label = 147;
   } else {
    $399 = HEAP32[$396>>2]|0;
    $400 = ((($$sroa$0153$1196)) + 20|0);
    $401 = HEAP32[$400>>2]|0;
    $$0$i$i = $316;$$024$i$i = $397;$494 = $397;
    L196: while(1) {
     $402 = ((($$024$i$i)) + 16|0);
     $403 = HEAP32[$402>>2]|0;
     $404 = ($399|0)<($403|0);
     do {
      if ($404) {
       label = 141;
      } else {
       $405 = ($403|0)<($399|0);
       if (!($405)) {
        $406 = ((($$024$i$i)) + 20|0);
        $407 = HEAP32[$406>>2]|0;
        $408 = ($401>>>0)<($407>>>0);
        if ($408) {
         label = 141;
         break;
        }
        $411 = ($407>>>0)<($401>>>0);
        if (!($411)) {
         label = 146;
         break L196;
        }
       }
       $412 = ((($$024$i$i)) + 4|0);
       $413 = HEAP32[$412>>2]|0;
       $414 = ($413|0)==(0|0);
       if ($414) {
        label = 145;
        break L196;
       } else {
        $$0$ph$i$i = $412;$$in$i$i = $413;
       }
      }
     } while(0);
     if ((label|0) == 141) {
      label = 0;
      $409 = HEAP32[$$024$i$i>>2]|0;
      $410 = ($409|0)==(0|0);
      if ($410) {
       label = 142;
       break;
      } else {
       $$0$ph$i$i = $$024$i$i;$$in$i$i = $409;
      }
     }
     $$0$i$i = $$0$ph$i$i;$$024$i$i = $$in$i$i;$494 = $$in$i$i;
    }
    if ((label|0) == 142) {
     label = 0;
     $$025$i68$i = $$024$i$i;$$05267$i = $$024$i$i;
     label = 148;
     break;
    }
    else if ((label|0) == 145) {
     label = 0;
     $$025$i68$i = $412;$$05267$i = $$024$i$i;
     label = 148;
     break;
    }
    else if ((label|0) == 146) {
     label = 0;
     $$025$i$i = $$0$i$i;$$052$i = $$024$i$i;$415 = $494;
     label = 147;
     break;
    }
   }
  } while(0);
  if ((label|0) == 147) {
   label = 0;
   $416 = ($415|0)==(0|0);
   if ($416) {
    $$025$i68$i = $$025$i$i;$$05267$i = $$052$i;
    label = 148;
   } else {
    $$014$i = $415;
   }
  }
  if ((label|0) == 148) {
   label = 0;
   $417 = (__Znwj(52)|0);
   $418 = ((($417)) + 16|0);
   $419 = $396;
   $420 = $419;
   $421 = HEAP32[$420>>2]|0;
   $422 = (($419) + 4)|0;
   $423 = $422;
   $424 = HEAP32[$423>>2]|0;
   $425 = $418;
   $426 = $425;
   HEAP32[$426>>2] = $421;
   $427 = (($425) + 4)|0;
   $428 = $427;
   HEAP32[$428>>2] = $424;
   $429 = ((($417)) + 24|0);
   HEAP8[$429>>0] = 0;
   $430 = ((($417)) + 28|0);
   ;HEAP32[$430>>2]=0|0;HEAP32[$430+4>>2]=0|0;HEAP32[$430+8>>2]=0|0;HEAP32[$430+12>>2]=0|0;HEAP32[$430+16>>2]=0|0;HEAP32[$430+20>>2]=0|0;
   HEAP32[$417>>2] = 0;
   $431 = ((($417)) + 4|0);
   HEAP32[$431>>2] = 0;
   $432 = ((($417)) + 8|0);
   HEAP32[$432>>2] = $$05267$i;
   HEAP32[$$025$i68$i>>2] = $417;
   $433 = HEAP32[$1>>2]|0;
   $434 = HEAP32[$433>>2]|0;
   $435 = ($434|0)==(0|0);
   if ($435) {
    $438 = $417;
   } else {
    $436 = $434;
    HEAP32[$1>>2] = $436;
    $$pre$i$i = HEAP32[$$025$i68$i>>2]|0;
    $438 = $$pre$i$i;
   }
   $437 = HEAP32[$316>>2]|0;
   __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($437,$438);
   $439 = HEAP32[$317>>2]|0;
   $440 = (($439) + 1)|0;
   HEAP32[$317>>2] = $440;
   $$014$i = $417;
  }
  $441 = ((($$sroa$0153$1196)) + 24|0);
  $442 = HEAP32[$441>>2]|0;
  $443 = ((($$014$i)) + 28|0);
  $444 = HEAP32[$443>>2]|0;
  $445 = ($444|0)==($442|0);
  if (!($445)) {
   $446 = ((($$014$i)) + 36|0);
   $447 = HEAP32[$446>>2]|0;
   $448 = ($447|0)==(0|0);
   if ($448) {
    $449 = HEAP32[$442>>2]|0;
    $450 = ((($449)) + 12|0);
    $451 = HEAP32[$450>>2]|0;
    $452 = (FUNCTION_TABLE_ii[$451 & 8191]($442)|0);
    $453 = HEAP32[$452>>2]|0;
    $454 = ((($453)) + 56|0);
    $455 = HEAP32[$454>>2]|0;
    $456 = (FUNCTION_TABLE_ii[$455 & 8191]($452)|0);
    $457 = HEAP32[$446>>2]|0;
    $458 = ($457|0)==($456|0);
    if (!($458)) {
     HEAP32[$446>>2] = $456;
     $459 = ($456|0)==(0|0);
     if (!($459)) {
      $460 = ((($456)) + 8|0);
      $461 = HEAP32[$460>>2]|0;HEAP32[$460>>2] = (($461+1)|0);
     }
     $462 = ($457|0)==(0|0);
     if (!($462)) {
      $463 = ((($457)) + 8|0);
      $464 = HEAP32[$463>>2]|0;HEAP32[$463>>2] = (($464-1)|0);
      $465 = ($464|0)==(1);
      if ($465) {
       __ZNK3osg10Referenced24signalObserversAndDeleteEbb($457,1,1);
      }
     }
    }
   }
   HEAP32[$443>>2] = $442;
   $466 = HEAP32[$442>>2]|0;
   $467 = ((($466)) + 172|0);
   $468 = HEAP32[$467>>2]|0;
   FUNCTION_TABLE_vii[$468 & 8191]($442,$0);
   $469 = ((($442)) + 44|0);
   $470 = HEAP32[$469>>2]|0;
   $471 = ((($$014$i)) + 32|0);
   $472 = HEAP32[$471>>2]|0;
   $473 = ($472|0)==($470|0);
   if (!($473)) {
    HEAP32[$471>>2] = $470;
    HEAP8[$319>>0] = 1;
   }
   $474 = HEAP32[$318>>2]|0;
   $475 = ($474|0)==(2);
   if ($475) {
    (__ZNK3osg5State13checkGLErrorsEPKNS_14StateAttributeE(0,$442)|0);
   }
  }
  $476 = ((($$014$i)) + 24|0);
  HEAP8[$476>>0] = 1;
  $477 = ((($$sroa$0153$1196)) + 4|0);
  $478 = HEAP32[$477>>2]|0;
  $479 = ($478|0)==(0|0);
  if ($479) {
   $480 = ((($$sroa$0153$1196)) + 8|0);
   $481 = HEAP32[$480>>2]|0;
   $482 = HEAP32[$481>>2]|0;
   $483 = ($482|0)==($$sroa$0153$1196|0);
   if ($483) {
    $$sroa$0153$1$be = $481;
   } else {
    $488 = $480;
    while(1) {
     $487 = HEAP32[$488>>2]|0;
     $489 = ((($487)) + 8|0);
     $490 = HEAP32[$489>>2]|0;
     $491 = HEAP32[$490>>2]|0;
     $492 = ($491|0)==($487|0);
     if ($492) {
      $$sroa$0153$1$be = $490;
      break;
     } else {
      $488 = $489;
     }
    }
   }
  } else {
   $$0$i$i$i$i = $478;
   while(1) {
    $485 = HEAP32[$$0$i$i$i$i>>2]|0;
    $486 = ($485|0)==(0|0);
    if ($486) {
     break;
    } else {
     $$0$i$i$i$i = $485;
    }
   }
   $$sroa$0153$1$be = $$0$i$i$i$i;
  }
  $484 = ($$sroa$0153$1$be|0)==($6|0);
  if ($484) {
   break;
  } else {
   $$sroa$0153$1196 = $$sroa$0153$1$be;
  }
 }
 return;
}
function __ZN3osg5State22applyShaderCompositionEv($0) {
 $0 = $0|0;
 var $$0$i$i$i$i = 0, $$1 = 0, $$110 = 0, $$pre = 0, $$pre$phiZ2D = 0, $$sroa$018$0$be = 0, $$sroa$018$024 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $9 = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i11 = 0, $scevgep5$i$i$i = 0, $scevgep5$i$i$i12 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp + 4|0;
 $2 = sp;
 $3 = ((($0)) + 136|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)==(0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $6 = ((($0)) + 137|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = ($7<<24>>24)==(0);
 L4: do {
  if ($8) {
   $$pre = ((($0)) + 144|0);
   $$pre$phiZ2D = $$pre;
  } else {
   HEAP32[$1>>2] = 0;
   $9 = ((($1)) + 4|0);
   HEAP32[$9>>2] = 0;
   $10 = ((($1)) + 8|0);
   HEAP32[$10>>2] = 0;
   $11 = ((($0)) + 588|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = ((($0)) + 592|0);
   $14 = ($12|0)==($13|0);
   L7: do {
    if ($14) {
     label = 6;
    } else {
     $15 = ((($1)) + 8|0);
     $$sroa$018$024 = $12;
     while(1) {
      $24 = ((($$sroa$018$024)) + 32|0);
      $25 = HEAP32[$24>>2]|0;
      $26 = ($25|0)==(0|0);
      $27 = $25;
      if (!($26)) {
       HEAP32[$2>>2] = $27;
       $28 = HEAP32[$9>>2]|0;
       $29 = HEAP32[$15>>2]|0;
       $30 = ($28|0)==($29|0);
       if ($30) {
        __THREW__ = 0;
        invoke_vii(3933,($1|0),($2|0));
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break;
        }
       } else {
        HEAP32[$28>>2] = $27;
        $31 = HEAP32[$9>>2]|0;
        $32 = ((($31)) + 4|0);
        HEAP32[$9>>2] = $32;
       }
      }
      $35 = ((($$sroa$018$024)) + 4|0);
      $36 = HEAP32[$35>>2]|0;
      $37 = ($36|0)==(0|0);
      if ($37) {
       $38 = ((($$sroa$018$024)) + 8|0);
       $39 = HEAP32[$38>>2]|0;
       $40 = HEAP32[$39>>2]|0;
       $41 = ($40|0)==($$sroa$018$024|0);
       if ($41) {
        $$sroa$018$0$be = $39;
       } else {
        $46 = $38;
        while(1) {
         $45 = HEAP32[$46>>2]|0;
         $47 = ((($45)) + 8|0);
         $48 = HEAP32[$47>>2]|0;
         $49 = HEAP32[$48>>2]|0;
         $50 = ($49|0)==($45|0);
         if ($50) {
          $$sroa$018$0$be = $48;
          break;
         } else {
          $46 = $47;
         }
        }
       }
      } else {
       $$0$i$i$i$i = $36;
       while(1) {
        $43 = HEAP32[$$0$i$i$i$i>>2]|0;
        $44 = ($43|0)==(0|0);
        if ($44) {
         break;
        } else {
         $$0$i$i$i$i = $43;
        }
       }
       $$sroa$018$0$be = $$0$i$i$i$i;
      }
      $42 = ($$sroa$018$0$be|0)==($13|0);
      if ($42) {
       label = 6;
       break L7;
      } else {
       $$sroa$018$024 = $$sroa$018$0$be;
      }
     }
     $51 = ___cxa_find_matching_catch_2()|0;
     $52 = tempRet0;
     $$1 = $51;$$110 = $52;
    }
   } while(0);
   do {
    if ((label|0) == 6) {
     $16 = ((($0)) + 140|0);
     $17 = HEAP32[$16>>2]|0;
     $18 = HEAP32[$17>>2]|0;
     $19 = ((($18)) + 140|0);
     $20 = HEAP32[$19>>2]|0;
     __THREW__ = 0;
     $21 = (invoke_iii($20|0,($17|0),($1|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      $63 = ___cxa_find_matching_catch_2()|0;
      $64 = tempRet0;
      $$1 = $63;$$110 = $64;
      break;
     }
     $53 = ((($0)) + 144|0);
     HEAP32[$53>>2] = $21;
     $54 = HEAP32[$1>>2]|0;
     $55 = ($54|0)==(0|0);
     if (!($55)) {
      $56 = HEAP32[$9>>2]|0;
      $57 = ($56|0)==($54|0);
      if (!($57)) {
       $scevgep$i$i$i11 = ((($56)) + -4|0);
       $58 = $scevgep$i$i$i11;
       $59 = $54;
       $60 = (($58) - ($59))|0;
       $61 = $60 >>> 2;
       $62 = $61 ^ -1;
       $scevgep5$i$i$i12 = (($56) + ($62<<2)|0);
       HEAP32[$9>>2] = $scevgep5$i$i$i12;
      }
      __ZdlPv($54);
     }
     $$pre$phiZ2D = $53;
     break L4;
    }
   } while(0);
   $65 = HEAP32[$1>>2]|0;
   $66 = ($65|0)==(0|0);
   if ($66) {
    ___resumeException($$1|0);
    // unreachable;
   }
   $67 = HEAP32[$9>>2]|0;
   $68 = ($67|0)==($65|0);
   if (!($68)) {
    $scevgep$i$i$i = ((($67)) + -4|0);
    $69 = $scevgep$i$i$i;
    $70 = $65;
    $71 = (($69) - ($70))|0;
    $72 = $71 >>> 2;
    $73 = $72 ^ -1;
    $scevgep5$i$i$i = (($67) + ($73<<2)|0);
    HEAP32[$9>>2] = $scevgep5$i$i$i;
   }
   __ZdlPv($65);
   ___resumeException($$1|0);
   // unreachable;
  }
 } while(0);
 $74 = HEAP32[$$pre$phiZ2D>>2]|0;
 $75 = ($74|0)==(0|0);
 if ($75) {
  STACKTOP = sp;return;
 }
 $76 = (__ZNK3osg7Program6getPCPERNS_5StateE($74,$0)|0);
 $77 = ((($0)) + 664|0);
 $78 = HEAP32[$77>>2]|0;
 $79 = ($78|0)==($76|0);
 if ($79) {
  STACKTOP = sp;return;
 }
 $80 = HEAP32[$$pre$phiZ2D>>2]|0;
 (__ZN3osg5State14applyAttributeEPKNS_14StateAttributeE($0,$80)|0);
 STACKTOP = sp;return;
}
function __ZN3osg5State16applyUniformListERNSt3__23mapINS1_12basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEENS0_12UniformStackENS1_4lessIS8_EENS6_INS1_4pairIKS8_S9_EEEEEERKNS2_IS8_NSC_INS_7ref_ptrINS_7UniformEEEjEESB_NS6_INSC_ISD_SL_EEEEEE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$i$i$i$i = 0, $$0$i$i$i$i21 = 0, $$0$i$i$i$i27 = 0, $$0$i$i$i$i34 = 0, $$0$i$i$i$i41 = 0, $$0$i$i$i$i48 = 0, $$0$i$i$i38 = 0, $$not = 0, $$not105 = 0, $$not93 = 0, $$not93106 = 0, $$sroa$067$0$be = 0, $$sroa$067$0$lcssa = 0, $$sroa$067$0108 = 0, $$sroa$067$1$be = 0, $$sroa$067$1103 = 0, $$sroa$078$0$be = 0, $$sroa$078$0$lcssa = 0, $$sroa$078$0111 = 0, $$sroa$078$1$be = 0;
 var $$sroa$078$1102 = 0, $$sroa$speculated$i$i$i = 0, $$sroa$speculated$i$i$i54 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $brmerge = 0, $brmerge107 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 664|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  return;
 }
 $6 = HEAP32[$2>>2]|0;
 $7 = HEAP32[$1>>2]|0;
 $8 = ((($1)) + 4|0);
 $9 = ((($2)) + 4|0);
 $$not105 = ($7|0)==($8|0);
 $$not93106 = ($6|0)==($9|0);
 $brmerge107 = $$not105 | $$not93106;
 if ($brmerge107) {
  $$sroa$067$0$lcssa = $7;$$sroa$078$0$lcssa = $6;
 } else {
  $$sroa$067$0108 = $7;$$sroa$078$0111 = $6;
  while(1) {
   $11 = ((($$sroa$067$0108)) + 16|0);
   $12 = ((($$sroa$078$0111)) + 16|0);
   $13 = ((($12)) + 11|0);
   $14 = HEAP8[$13>>0]|0;
   $15 = ($14<<24>>24)<(0);
   $16 = ((($$sroa$078$0111)) + 20|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = $14&255;
   $19 = $15 ? $17 : $18;
   $20 = ((($11)) + 11|0);
   $21 = HEAP8[$20>>0]|0;
   $22 = ($21<<24>>24)<(0);
   $23 = ((($$sroa$067$0108)) + 20|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = $21&255;
   $26 = $22 ? $24 : $25;
   $27 = ($19>>>0)<($26>>>0);
   $$sroa$speculated$i$i$i54 = $27 ? $19 : $26;
   $28 = ($$sroa$speculated$i$i$i54|0)==(0);
   if ($28) {
    label = 6;
   } else {
    $29 = HEAP32[$11>>2]|0;
    $30 = $22 ? $29 : $11;
    $31 = HEAP32[$12>>2]|0;
    $32 = $15 ? $31 : $12;
    $33 = (_memcmp($30,$32,$$sroa$speculated$i$i$i54)|0);
    $34 = ($33|0)==(0);
    if ($34) {
     label = 6;
    } else {
     $36 = ($33|0)<(0);
     if ($36) {
      label = 8;
     } else {
      label = 16;
     }
    }
   }
   if ((label|0) == 6) {
    label = 0;
    $35 = ($26>>>0)<($19>>>0);
    if ($35) {
     label = 8;
    } else {
     label = 16;
    }
   }
   L12: do {
    if ((label|0) == 8) {
     label = 0;
     $37 = ((($$sroa$067$0108)) + 28|0);
     $38 = HEAP32[$37>>2]|0;
     $39 = ((($$sroa$067$0108)) + 32|0);
     $40 = HEAP32[$39>>2]|0;
     $41 = ($38|0)==($40|0);
     if (!($41)) {
      $42 = HEAP32[$3>>2]|0;
      $43 = ((($40)) + -8|0);
      $44 = HEAP32[$43>>2]|0;
      __ZNK3osg7Program17PerContextProgram5applyERKNS_7UniformE($42,$44);
     }
     $45 = ((($$sroa$067$0108)) + 4|0);
     $46 = HEAP32[$45>>2]|0;
     $47 = ($46|0)==(0|0);
     if ($47) {
      $48 = ((($$sroa$067$0108)) + 8|0);
      $49 = HEAP32[$48>>2]|0;
      $50 = HEAP32[$49>>2]|0;
      $51 = ($50|0)==($$sroa$067$0108|0);
      if ($51) {
       $$sroa$067$0$be = $49;$$sroa$078$0$be = $$sroa$078$0111;
       break;
      } else {
       $55 = $48;
      }
      while(1) {
       $54 = HEAP32[$55>>2]|0;
       $56 = ((($54)) + 8|0);
       $57 = HEAP32[$56>>2]|0;
       $58 = HEAP32[$57>>2]|0;
       $59 = ($58|0)==($54|0);
       if ($59) {
        $$sroa$067$0$be = $57;$$sroa$078$0$be = $$sroa$078$0111;
        break;
       } else {
        $55 = $56;
       }
      }
     } else {
      $$0$i$i$i$i48 = $46;
      while(1) {
       $52 = HEAP32[$$0$i$i$i$i48>>2]|0;
       $53 = ($52|0)==(0|0);
       if ($53) {
        break;
       } else {
        $$0$i$i$i$i48 = $52;
       }
      }
      $$sroa$067$0$be = $$0$i$i$i$i48;$$sroa$078$0$be = $$sroa$078$0111;
      break;
     }
    }
    else if ((label|0) == 16) {
     label = 0;
     $60 = ($26>>>0)<($19>>>0);
     $$sroa$speculated$i$i$i = $60 ? $26 : $19;
     $61 = ($$sroa$speculated$i$i$i|0)==(0);
     if ($61) {
      label = 18;
     } else {
      $62 = HEAP32[$12>>2]|0;
      $63 = $15 ? $62 : $12;
      $64 = HEAP32[$11>>2]|0;
      $65 = $22 ? $64 : $11;
      $66 = (_memcmp($63,$65,$$sroa$speculated$i$i$i)|0);
      $67 = ($66|0)==(0);
      if ($67) {
       label = 18;
      } else {
       $68 = ($66|0)<(0);
       if ($68) {
        label = 20;
       }
      }
     }
     if ((label|0) == 18) {
      label = 0;
      if ($27) {
       label = 20;
      }
     }
     if ((label|0) == 20) {
      label = 0;
      $69 = HEAP32[$3>>2]|0;
      $70 = ((($$sroa$078$0111)) + 28|0);
      $71 = HEAP32[$70>>2]|0;
      __ZNK3osg7Program17PerContextProgram5applyERKNS_7UniformE($69,$71);
      $72 = ((($$sroa$078$0111)) + 4|0);
      $73 = HEAP32[$72>>2]|0;
      $74 = ($73|0)==(0|0);
      if ($74) {
       $75 = ((($$sroa$078$0111)) + 8|0);
       $76 = HEAP32[$75>>2]|0;
       $77 = HEAP32[$76>>2]|0;
       $78 = ($77|0)==($$sroa$078$0111|0);
       if ($78) {
        $$sroa$067$0$be = $$sroa$067$0108;$$sroa$078$0$be = $76;
        break;
       } else {
        $82 = $75;
       }
       while(1) {
        $81 = HEAP32[$82>>2]|0;
        $83 = ((($81)) + 8|0);
        $84 = HEAP32[$83>>2]|0;
        $85 = HEAP32[$84>>2]|0;
        $86 = ($85|0)==($81|0);
        if ($86) {
         $$sroa$067$0$be = $$sroa$067$0108;$$sroa$078$0$be = $84;
         break L12;
        } else {
         $82 = $83;
        }
       }
      } else {
       $$0$i$i$i$i41 = $73;
       while(1) {
        $79 = HEAP32[$$0$i$i$i$i41>>2]|0;
        $80 = ($79|0)==(0|0);
        if ($80) {
         break;
        } else {
         $$0$i$i$i$i41 = $79;
        }
       }
       $$sroa$067$0$be = $$sroa$067$0108;$$sroa$078$0$be = $$0$i$i$i$i41;
       break;
      }
     }
     $87 = ((($$sroa$067$0108)) + 28|0);
     $88 = HEAP32[$87>>2]|0;
     $89 = ((($$sroa$067$0108)) + 32|0);
     $90 = HEAP32[$89>>2]|0;
     $91 = ($88|0)==($90|0);
     if ($91) {
      label = 29;
     } else {
      $92 = ((($90)) + -4|0);
      $93 = HEAP32[$92>>2]|0;
      $94 = $93 & 2;
      $95 = ($94|0)==(0);
      if ($95) {
       label = 29;
      } else {
       $96 = ((($$sroa$078$0111)) + 32|0);
       $97 = HEAP32[$96>>2]|0;
       $98 = $97 & 4;
       $99 = ($98|0)==(0);
       if ($99) {
        $100 = HEAP32[$3>>2]|0;
        $101 = ((($90)) + -8|0);
        $102 = HEAP32[$101>>2]|0;
        __ZNK3osg7Program17PerContextProgram5applyERKNS_7UniformE($100,$102);
       } else {
        label = 29;
       }
      }
     }
     if ((label|0) == 29) {
      label = 0;
      $103 = HEAP32[$3>>2]|0;
      $104 = ((($$sroa$078$0111)) + 28|0);
      $105 = HEAP32[$104>>2]|0;
      __ZNK3osg7Program17PerContextProgram5applyERKNS_7UniformE($103,$105);
     }
     $106 = ((($$sroa$067$0108)) + 4|0);
     $107 = HEAP32[$106>>2]|0;
     $108 = ($107|0)==(0|0);
     if ($108) {
      $109 = ((($$sroa$067$0108)) + 8|0);
      $110 = HEAP32[$109>>2]|0;
      $111 = HEAP32[$110>>2]|0;
      $112 = ($111|0)==($$sroa$067$0108|0);
      if ($112) {
       $$0$i$i$i38 = $110;
      } else {
       $116 = $109;
       while(1) {
        $115 = HEAP32[$116>>2]|0;
        $117 = ((($115)) + 8|0);
        $118 = HEAP32[$117>>2]|0;
        $119 = HEAP32[$118>>2]|0;
        $120 = ($119|0)==($115|0);
        if ($120) {
         $$0$i$i$i38 = $118;
         break;
        } else {
         $116 = $117;
        }
       }
      }
     } else {
      $$0$i$i$i$i34 = $107;
      while(1) {
       $113 = HEAP32[$$0$i$i$i$i34>>2]|0;
       $114 = ($113|0)==(0|0);
       if ($114) {
        break;
       } else {
        $$0$i$i$i$i34 = $113;
       }
      }
      $$0$i$i$i38 = $$0$i$i$i$i34;
     }
     $121 = ((($$sroa$078$0111)) + 4|0);
     $122 = HEAP32[$121>>2]|0;
     $123 = ($122|0)==(0|0);
     if ($123) {
      $124 = ((($$sroa$078$0111)) + 8|0);
      $125 = HEAP32[$124>>2]|0;
      $126 = HEAP32[$125>>2]|0;
      $127 = ($126|0)==($$sroa$078$0111|0);
      if ($127) {
       $$sroa$067$0$be = $$0$i$i$i38;$$sroa$078$0$be = $125;
       break;
      } else {
       $131 = $124;
      }
      while(1) {
       $130 = HEAP32[$131>>2]|0;
       $132 = ((($130)) + 8|0);
       $133 = HEAP32[$132>>2]|0;
       $134 = HEAP32[$133>>2]|0;
       $135 = ($134|0)==($130|0);
       if ($135) {
        $$sroa$067$0$be = $$0$i$i$i38;$$sroa$078$0$be = $133;
        break;
       } else {
        $131 = $132;
       }
      }
     } else {
      $$0$i$i$i$i27 = $122;
      while(1) {
       $128 = HEAP32[$$0$i$i$i$i27>>2]|0;
       $129 = ($128|0)==(0|0);
       if ($129) {
        break;
       } else {
        $$0$i$i$i$i27 = $128;
       }
      }
      $$sroa$067$0$be = $$0$i$i$i38;$$sroa$078$0$be = $$0$i$i$i$i27;
      break;
     }
    }
   } while(0);
   $$not = ($$sroa$067$0$be|0)==($8|0);
   $$not93 = ($$sroa$078$0$be|0)==($9|0);
   $brmerge = $$not | $$not93;
   if ($brmerge) {
    $$sroa$067$0$lcssa = $$sroa$067$0$be;$$sroa$078$0$lcssa = $$sroa$078$0$be;
    break;
   } else {
    $$sroa$067$0108 = $$sroa$067$0$be;$$sroa$078$0111 = $$sroa$078$0$be;
   }
  }
 }
 $10 = ($$sroa$067$0$lcssa|0)==($8|0);
 if (!($10)) {
  $$sroa$067$1103 = $$sroa$067$0$lcssa;
  while(1) {
   $137 = ((($$sroa$067$1103)) + 28|0);
   $138 = HEAP32[$137>>2]|0;
   $139 = ((($$sroa$067$1103)) + 32|0);
   $140 = HEAP32[$139>>2]|0;
   $141 = ($138|0)==($140|0);
   if (!($141)) {
    $142 = HEAP32[$3>>2]|0;
    $143 = ((($140)) + -8|0);
    $144 = HEAP32[$143>>2]|0;
    __ZNK3osg7Program17PerContextProgram5applyERKNS_7UniformE($142,$144);
   }
   $145 = ((($$sroa$067$1103)) + 4|0);
   $146 = HEAP32[$145>>2]|0;
   $147 = ($146|0)==(0|0);
   if ($147) {
    $148 = ((($$sroa$067$1103)) + 8|0);
    $149 = HEAP32[$148>>2]|0;
    $150 = HEAP32[$149>>2]|0;
    $151 = ($150|0)==($$sroa$067$1103|0);
    if ($151) {
     $$sroa$067$1$be = $149;
    } else {
     $156 = $148;
     while(1) {
      $155 = HEAP32[$156>>2]|0;
      $157 = ((($155)) + 8|0);
      $158 = HEAP32[$157>>2]|0;
      $159 = HEAP32[$158>>2]|0;
      $160 = ($159|0)==($155|0);
      if ($160) {
       $$sroa$067$1$be = $158;
       break;
      } else {
       $156 = $157;
      }
     }
    }
   } else {
    $$0$i$i$i$i21 = $146;
    while(1) {
     $153 = HEAP32[$$0$i$i$i$i21>>2]|0;
     $154 = ($153|0)==(0|0);
     if ($154) {
      break;
     } else {
      $$0$i$i$i$i21 = $153;
     }
    }
    $$sroa$067$1$be = $$0$i$i$i$i21;
   }
   $152 = ($$sroa$067$1$be|0)==($8|0);
   if ($152) {
    break;
   } else {
    $$sroa$067$1103 = $$sroa$067$1$be;
   }
  }
 }
 $136 = ($$sroa$078$0$lcssa|0)==($9|0);
 if ($136) {
  return;
 } else {
  $$sroa$078$1102 = $$sroa$078$0$lcssa;
 }
 while(1) {
  $161 = HEAP32[$3>>2]|0;
  $162 = ((($$sroa$078$1102)) + 28|0);
  $163 = HEAP32[$162>>2]|0;
  __ZNK3osg7Program17PerContextProgram5applyERKNS_7UniformE($161,$163);
  $164 = ((($$sroa$078$1102)) + 4|0);
  $165 = HEAP32[$164>>2]|0;
  $166 = ($165|0)==(0|0);
  if ($166) {
   $167 = ((($$sroa$078$1102)) + 8|0);
   $168 = HEAP32[$167>>2]|0;
   $169 = HEAP32[$168>>2]|0;
   $170 = ($169|0)==($$sroa$078$1102|0);
   if ($170) {
    $$sroa$078$1$be = $168;
   } else {
    $175 = $167;
    while(1) {
     $174 = HEAP32[$175>>2]|0;
     $176 = ((($174)) + 8|0);
     $177 = HEAP32[$176>>2]|0;
     $178 = HEAP32[$177>>2]|0;
     $179 = ($178|0)==($174|0);
     if ($179) {
      $$sroa$078$1$be = $177;
      break;
     } else {
      $175 = $176;
     }
    }
   }
  } else {
   $$0$i$i$i$i = $165;
   while(1) {
    $172 = HEAP32[$$0$i$i$i$i>>2]|0;
    $173 = ($172|0)==(0|0);
    if ($173) {
     break;
    } else {
     $$0$i$i$i$i = $172;
    }
   }
   $$sroa$078$1$be = $$0$i$i$i$i;
  }
  $171 = ($$sroa$078$1$be|0)==($9|0);
  if ($171) {
   break;
  } else {
   $$sroa$078$1102 = $$sroa$078$1$be;
  }
 }
 return;
}
function __ZN3osg5State5applyEv($0) {
 $0 = $0|0;
 var $$0$i$i$i$i$i = 0, $$015 = 0, $$in = 0, $$pre = 0, $$pre17 = 0, $$sroa$07$0$be$i = 0, $$sroa$07$011$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 344|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(2);
 if ($3) {
  (__ZNK3osg5State13checkGLErrorsEPKcS2_(0,149900,0)|0);
 }
 $4 = ((($0)) + 148|0);
 $5 = ((($0)) + 152|0);
 $6 = HEAP32[$5>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4pairIN3osg7ref_ptrINS9_7UniformEEEjEEEENS_19__map_value_compareIS7_SE_NS_4lessIS7_EELb1EEENS5_ISE_EEE7destroyEPNS_11__tree_nodeISE_PvEE($4,$6);
 $7 = ((($0)) + 156|0);
 HEAP32[$7>>2] = 0;
 HEAP32[$4>>2] = $5;
 HEAP32[$5>>2] = 0;
 $8 = ((($0)) + 640|0);
 $9 = ((($0)) + 644|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$8>>2]|0;
 $12 = (($10) - ($11))|0;
 $13 = (($12|0) / 12)&-1;
 $14 = ((($0)) + 652|0);
 $15 = ((($0)) + 656|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = HEAP32[$14>>2]|0;
 $18 = (($16) - ($17))|0;
 $19 = (($18|0) / 12)&-1;
 $20 = ($13>>>0)>($19>>>0);
 $21 = $20 ? $13 : $19;
 $22 = ($21|0)==(0);
 L4: do {
  if (!($22)) {
   $$015 = 0;$$in = $11;$24 = $10;
   while(1) {
    $23 = (($24) - ($$in))|0;
    $25 = (($23|0) / 12)&-1;
    $26 = ($$015>>>0)<($25>>>0);
    if ($26) {
     $27 = $$in;
     $28 = (($27) + (($$015*12)|0)|0);
     __ZN3osg5State21applyModeMapOnTexUnitEjRNSt3__23mapIjNS0_9ModeStackENS1_4lessIjEENS1_9allocatorINS1_4pairIKjS3_EEEEEE($0,$$015,$28);
    }
    $29 = HEAP32[$15>>2]|0;
    $30 = HEAP32[$14>>2]|0;
    $31 = (($29) - ($30))|0;
    $32 = (($31|0) / 12)&-1;
    $33 = ($$015>>>0)<($32>>>0);
    if ($33) {
     $34 = $30;
     $35 = (($34) + (($$015*12)|0)|0);
     __ZN3osg5State26applyAttributeMapOnTexUnitEjRNSt3__23mapINS1_4pairINS_14StateAttribute4TypeEjEENS0_14AttributeStackENS1_4lessIS6_EENS1_9allocatorINS3_IKS6_S7_EEEEEE($0,$$015,$35);
    }
    $36 = (($$015) + 1)|0;
    $37 = ($36>>>0)<($21>>>0);
    if (!($37)) {
     break L4;
    }
    $$pre = HEAP32[$9>>2]|0;
    $$pre17 = HEAP32[$8>>2]|0;
    $$015 = $36;$$in = $$pre17;$24 = $$pre;
   }
  }
 } while(0);
 $38 = ((($0)) + 576|0);
 __ZN3osg5State12applyModeMapERNSt3__23mapIjNS0_9ModeStackENS1_4lessIjEENS1_9allocatorINS1_4pairIKjS3_EEEEEE($0,$38);
 $39 = ((($0)) + 664|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ((($0)) + 588|0);
 __ZN3osg5State17applyAttributeMapERNSt3__23mapINS1_4pairINS_14StateAttribute4TypeEjEENS0_14AttributeStackENS1_4lessIS6_EENS1_9allocatorINS3_IKS6_S7_EEEEEE($0,$41);
 $42 = HEAP32[$39>>2]|0;
 $43 = ($42|0)!=(0|0);
 $44 = ($40|0)==($42|0);
 $or$cond = $43 & $44;
 if ($or$cond) {
  $45 = ((($0)) + 624|0);
  $46 = HEAP8[$45>>0]|0;
  $47 = ($46<<24>>24)==(0);
  if (!($47)) {
   $48 = ((($40)) + 12|0);
   $49 = HEAP32[$48>>2]|0;
   $50 = HEAP32[$49>>2]|0;
   $51 = ((($50)) + 172|0);
   $52 = HEAP32[$51>>2]|0;
   FUNCTION_TABLE_vii[$52 & 8191]($49,$0);
  }
 }
 $53 = ((($0)) + 136|0);
 $54 = HEAP8[$53>>0]|0;
 $55 = ($54<<24>>24)==(0);
 if (!($55)) {
  __ZN3osg5State22applyShaderCompositionEv($0);
 }
 $56 = HEAP32[$7>>2]|0;
 $57 = ($56|0)==(0);
 $58 = ((($0)) + 600|0);
 if ($57) {
  $59 = HEAP32[$39>>2]|0;
  $60 = ($59|0)==(0|0);
  if (!($60)) {
   $61 = HEAP32[$58>>2]|0;
   $62 = ((($0)) + 604|0);
   $63 = ($61|0)==($62|0);
   if (!($63)) {
    $$sroa$07$011$i = $61;
    while(1) {
     $64 = ((($$sroa$07$011$i)) + 28|0);
     $65 = HEAP32[$64>>2]|0;
     $66 = ((($$sroa$07$011$i)) + 32|0);
     $67 = HEAP32[$66>>2]|0;
     $68 = ($65|0)==($67|0);
     if (!($68)) {
      $69 = HEAP32[$39>>2]|0;
      $70 = ((($67)) + -8|0);
      $71 = HEAP32[$70>>2]|0;
      __ZNK3osg7Program17PerContextProgram5applyERKNS_7UniformE($69,$71);
     }
     $72 = ((($$sroa$07$011$i)) + 4|0);
     $73 = HEAP32[$72>>2]|0;
     $74 = ($73|0)==(0|0);
     if ($74) {
      $75 = ((($$sroa$07$011$i)) + 8|0);
      $76 = HEAP32[$75>>2]|0;
      $77 = HEAP32[$76>>2]|0;
      $78 = ($77|0)==($$sroa$07$011$i|0);
      if ($78) {
       $$sroa$07$0$be$i = $76;
      } else {
       $83 = $75;
       while(1) {
        $82 = HEAP32[$83>>2]|0;
        $84 = ((($82)) + 8|0);
        $85 = HEAP32[$84>>2]|0;
        $86 = HEAP32[$85>>2]|0;
        $87 = ($86|0)==($82|0);
        if ($87) {
         $$sroa$07$0$be$i = $85;
         break;
        } else {
         $83 = $84;
        }
       }
      }
     } else {
      $$0$i$i$i$i$i = $73;
      while(1) {
       $80 = HEAP32[$$0$i$i$i$i$i>>2]|0;
       $81 = ($80|0)==(0|0);
       if ($81) {
        break;
       } else {
        $$0$i$i$i$i$i = $80;
       }
      }
      $$sroa$07$0$be$i = $$0$i$i$i$i$i;
     }
     $79 = ($$sroa$07$0$be$i|0)==($62|0);
     if ($79) {
      break;
     } else {
      $$sroa$07$011$i = $$sroa$07$0$be$i;
     }
    }
   }
  }
 } else {
  __ZN3osg5State16applyUniformListERNSt3__23mapINS1_12basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEENS0_12UniformStackENS1_4lessIS8_EENS6_INS1_4pairIKS8_S9_EEEEEERKNS2_IS8_NSC_INS_7ref_ptrINS_7UniformEEEjEESB_NS6_INSC_ISD_SL_EEEEEE($0,$58,$4);
 }
 $88 = HEAP32[$1>>2]|0;
 $89 = ($88|0)==(2);
 if (!($89)) {
  return;
 }
 (__ZNK3osg5State13checkGLErrorsEPKcS2_(0,149924,0)|0);
 return;
}
function __ZN3osg5State12applyModeMapERNSt3__23mapIjNS0_9ModeStackENS1_4lessIjEENS1_9allocatorINS1_4pairIKjS3_EEEEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i$i$i = 0, $$sroa$014$0$be = 0, $$sroa$014$020 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($1)) + 4|0);
 $4 = ($2|0)==($3|0);
 if ($4) {
  return;
 }
 $5 = ((($0)) + 344|0);
 $$sroa$014$020 = $2;
 while(1) {
  $6 = ((($$sroa$014$020)) + 16|0);
  $7 = ((($$sroa$014$020)) + 20|0);
  $8 = ((($6)) + 5|0);
  $9 = HEAP8[$8>>0]|0;
  $10 = ($9<<24>>24)==(0);
  do {
   if (!($10)) {
    HEAP8[$8>>0] = 0;
    $11 = ((($$sroa$014$020)) + 24|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ((($$sroa$014$020)) + 28|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ($12|0)==($14|0);
    if ($15) {
     $30 = HEAP32[$6>>2]|0;
     $31 = ((($6)) + 7|0);
     $32 = HEAP8[$31>>0]|0;
     $33 = ($32<<24>>24)==(0);
     $34 = HEAP8[$7>>0]|0;
     $35 = ($34<<24>>24)==(0);
     if ($35) {
      break;
     }
     $36 = ((($7)) + 2|0);
     $37 = HEAP8[$36>>0]|0;
     $38 = ($37<<24>>24)==($32<<24>>24);
     if ($38) {
      break;
     }
     HEAP8[$36>>0] = $32;
     if ($33) {
      _glDisable(($30|0));
     } else {
      _glEnable(($30|0));
     }
     $39 = HEAP32[$5>>2]|0;
     $40 = ($39|0)==(2);
     if (!($40)) {
      break;
     }
     (__ZNK3osg5State13checkGLErrorsEj(0,$30)|0);
     break;
    } else {
     $16 = ((($14)) + -4|0);
     $17 = HEAP32[$16>>2]|0;
     $18 = $17 & 1;
     $19 = ($18|0)==(0);
     $20 = HEAP32[$6>>2]|0;
     $21 = $18&255;
     $22 = HEAP8[$7>>0]|0;
     $23 = ($22<<24>>24)==(0);
     if ($23) {
      break;
     }
     $24 = ((($7)) + 2|0);
     $25 = HEAP8[$24>>0]|0;
     $26 = $25&255;
     $27 = ($26|0)==($18|0);
     if ($27) {
      break;
     }
     HEAP8[$24>>0] = $21;
     if ($19) {
      _glDisable(($20|0));
     } else {
      _glEnable(($20|0));
     }
     $28 = HEAP32[$5>>2]|0;
     $29 = ($28|0)==(2);
     if (!($29)) {
      break;
     }
     (__ZNK3osg5State13checkGLErrorsEj(0,$20)|0);
     break;
    }
   }
  } while(0);
  $41 = ((($$sroa$014$020)) + 4|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = ($42|0)==(0|0);
  if ($43) {
   $44 = ((($$sroa$014$020)) + 8|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = HEAP32[$45>>2]|0;
   $47 = ($46|0)==($$sroa$014$020|0);
   if ($47) {
    $$sroa$014$0$be = $45;
   } else {
    $52 = $44;
    while(1) {
     $51 = HEAP32[$52>>2]|0;
     $53 = ((($51)) + 8|0);
     $54 = HEAP32[$53>>2]|0;
     $55 = HEAP32[$54>>2]|0;
     $56 = ($55|0)==($51|0);
     if ($56) {
      $$sroa$014$0$be = $54;
      break;
     } else {
      $52 = $53;
     }
    }
   }
  } else {
   $$0$i$i$i$i = $42;
   while(1) {
    $49 = HEAP32[$$0$i$i$i$i>>2]|0;
    $50 = ($49|0)==(0|0);
    if ($50) {
     break;
    } else {
     $$0$i$i$i$i = $49;
    }
   }
   $$sroa$014$0$be = $$0$i$i$i$i;
  }
  $48 = ($$sroa$014$0$be|0)==($3|0);
  if ($48) {
   break;
  } else {
   $$sroa$014$020 = $$sroa$014$0$be;
  }
 }
 return;
}
function __ZN3osg5State17applyAttributeMapERNSt3__23mapINS1_4pairINS_14StateAttribute4TypeEjEENS0_14AttributeStackENS1_4lessIS6_EENS1_9allocatorINS3_IKS6_S7_EEEEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i$i$i = 0, $$sroa$015$0$be = 0, $$sroa$015$019 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($1)) + 4|0);
 $4 = ($2|0)==($3|0);
 if ($4) {
  return;
 }
 $5 = ((($0)) + 344|0);
 $6 = ((($0)) + 137|0);
 $$sroa$015$019 = $2;
 while(1) {
  $7 = ((($$sroa$015$019)) + 24|0);
  $8 = HEAP8[$7>>0]|0;
  $9 = ($8<<24>>24)==(0);
  do {
   if (!($9)) {
    HEAP8[$7>>0] = 0;
    $10 = ((($$sroa$015$019)) + 40|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ((($$sroa$015$019)) + 44|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = ($11|0)==($13|0);
    if ($14) {
     $50 = ((($$sroa$015$019)) + 28|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = ((($$sroa$015$019)) + 36|0);
     $53 = HEAP32[$52>>2]|0;
     $54 = ($51|0)==($53|0);
     if ($54) {
      break;
     }
     HEAP32[$50>>2] = $53;
     $55 = ($53|0)==(0|0);
     if ($55) {
      break;
     }
     $56 = HEAP32[$53>>2]|0;
     $57 = ((($56)) + 172|0);
     $58 = HEAP32[$57>>2]|0;
     FUNCTION_TABLE_vii[$58 & 8191]($53,$0);
     $59 = HEAP32[$52>>2]|0;
     $60 = ((($59)) + 44|0);
     $61 = HEAP32[$60>>2]|0;
     $62 = ((($$sroa$015$019)) + 32|0);
     $63 = HEAP32[$62>>2]|0;
     $64 = ($63|0)==($61|0);
     if (!($64)) {
      HEAP32[$62>>2] = $61;
      HEAP8[$6>>0] = 1;
     }
     $65 = HEAP32[$5>>2]|0;
     $66 = ($65|0)==(2);
     if (!($66)) {
      break;
     }
     (__ZNK3osg5State13checkGLErrorsEPKNS_14StateAttributeE(0,$59)|0);
     break;
    }
    $15 = ((($13)) + -8|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = ((($$sroa$015$019)) + 28|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = ($18|0)==($16|0);
    if (!($19)) {
     $20 = ((($$sroa$015$019)) + 36|0);
     $21 = HEAP32[$20>>2]|0;
     $22 = ($21|0)==(0|0);
     if ($22) {
      $23 = HEAP32[$16>>2]|0;
      $24 = ((($23)) + 12|0);
      $25 = HEAP32[$24>>2]|0;
      $26 = (FUNCTION_TABLE_ii[$25 & 8191]($16)|0);
      $27 = HEAP32[$26>>2]|0;
      $28 = ((($27)) + 56|0);
      $29 = HEAP32[$28>>2]|0;
      $30 = (FUNCTION_TABLE_ii[$29 & 8191]($26)|0);
      $31 = HEAP32[$20>>2]|0;
      $32 = ($31|0)==($30|0);
      if (!($32)) {
       HEAP32[$20>>2] = $30;
       $33 = ($30|0)==(0|0);
       if (!($33)) {
        $34 = ((($30)) + 8|0);
        $35 = HEAP32[$34>>2]|0;HEAP32[$34>>2] = (($35+1)|0);
       }
       $36 = ($31|0)==(0|0);
       if (!($36)) {
        $37 = ((($31)) + 8|0);
        $38 = HEAP32[$37>>2]|0;HEAP32[$37>>2] = (($38-1)|0);
        $39 = ($38|0)==(1);
        if ($39) {
         __ZNK3osg10Referenced24signalObserversAndDeleteEbb($31,1,1);
        }
       }
      }
     }
     HEAP32[$17>>2] = $16;
     $40 = HEAP32[$16>>2]|0;
     $41 = ((($40)) + 172|0);
     $42 = HEAP32[$41>>2]|0;
     FUNCTION_TABLE_vii[$42 & 8191]($16,$0);
     $43 = ((($16)) + 44|0);
     $44 = HEAP32[$43>>2]|0;
     $45 = ((($$sroa$015$019)) + 32|0);
     $46 = HEAP32[$45>>2]|0;
     $47 = ($46|0)==($44|0);
     if (!($47)) {
      HEAP32[$45>>2] = $44;
      HEAP8[$6>>0] = 1;
     }
     $48 = HEAP32[$5>>2]|0;
     $49 = ($48|0)==(2);
     if ($49) {
      (__ZNK3osg5State13checkGLErrorsEPKNS_14StateAttributeE(0,$16)|0);
     }
    }
   }
  } while(0);
  $67 = ((($$sroa$015$019)) + 4|0);
  $68 = HEAP32[$67>>2]|0;
  $69 = ($68|0)==(0|0);
  if ($69) {
   $70 = ((($$sroa$015$019)) + 8|0);
   $71 = HEAP32[$70>>2]|0;
   $72 = HEAP32[$71>>2]|0;
   $73 = ($72|0)==($$sroa$015$019|0);
   if ($73) {
    $$sroa$015$0$be = $71;
   } else {
    $78 = $70;
    while(1) {
     $77 = HEAP32[$78>>2]|0;
     $79 = ((($77)) + 8|0);
     $80 = HEAP32[$79>>2]|0;
     $81 = HEAP32[$80>>2]|0;
     $82 = ($81|0)==($77|0);
     if ($82) {
      $$sroa$015$0$be = $80;
      break;
     } else {
      $78 = $79;
     }
    }
   }
  } else {
   $$0$i$i$i$i = $68;
   while(1) {
    $75 = HEAP32[$$0$i$i$i$i>>2]|0;
    $76 = ($75|0)==(0|0);
    if ($76) {
     break;
    } else {
     $$0$i$i$i$i = $75;
    }
   }
   $$sroa$015$0$be = $$0$i$i$i$i;
  }
  $74 = ($$sroa$015$0$be|0)==($3|0);
  if ($74) {
   break;
  } else {
   $$sroa$015$019 = $$sroa$015$0$be;
  }
 }
 return;
}
function __ZNK3osg5State13checkGLErrorsEPKNS_14StateAttributeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp + 4|0;
 $3 = sp;
 $4 = (_glGetError()|0);
 $5 = ($4|0)==(0);
 if ($5) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $6 = (__ZN3osg14gluErrorStringEj($4)|0);
 $7 = ($6|0)==(0|0);
 $8 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
 if ($7) {
  if (!($8)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $41 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
  $42 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($41,150007,40)|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = ((($43)) + -12|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = (($42) + ($45)|0);
  $47 = ((($46)) + 4|0);
  $48 = HEAP32[$47>>2]|0;
  $49 = $48 & -75;
  $50 = $49 | 8;
  HEAP32[$47>>2] = $50;
  $51 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($42,$4)|0);
  $52 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($51,150048,26)|0);
  $53 = HEAP32[$1>>2]|0;
  $54 = ((($53)) + 28|0);
  $55 = HEAP32[$54>>2]|0;
  $56 = (FUNCTION_TABLE_ii[$55 & 8191]($1)|0);
  $57 = (_strlen($56)|0);
  $58 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($52,$56,$57)|0);
  $59 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($58,159071,1)|0);
  $60 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEPKv($59,$1)|0);
  $61 = HEAP32[$60>>2]|0;
  $62 = ((($61)) + -12|0);
  $63 = HEAP32[$62>>2]|0;
  $64 = (($60) + ($63)|0);
  $65 = ((($64)) + 4|0);
  $66 = HEAP32[$65>>2]|0;
  $67 = $66 & -75;
  $68 = $67 | 2;
  HEAP32[$65>>2] = $68;
  $69 = HEAP32[$60>>2]|0;
  $70 = ((($69)) + -12|0);
  $71 = HEAP32[$70>>2]|0;
  $72 = (($60) + ($71)|0);
  __ZNKSt3__28ios_base6getlocEv($2,$72);
  __THREW__ = 0;
  $73 = (invoke_iii(3255,($2|0),(215188|0))|0);
  $74 = __THREW__; __THREW__ = 0;
  $75 = $74&1;
  if (!($75)) {
   $76 = HEAP32[$73>>2]|0;
   $77 = ((($76)) + 28|0);
   $78 = HEAP32[$77>>2]|0;
   __THREW__ = 0;
   $79 = (invoke_iii($78|0,($73|0),10)|0);
   $80 = __THREW__; __THREW__ = 0;
   $81 = $80&1;
   if (!($81)) {
    __ZNSt3__26localeD2Ev($2);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($60,$79)|0);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($60)|0);
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
  }
  $82 = ___cxa_find_matching_catch_2()|0;
  $83 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3263,($2|0));
  $84 = __THREW__; __THREW__ = 0;
  $85 = $84&1;
  if ($85) {
   $86 = ___cxa_find_matching_catch_3(0|0)|0;
   $87 = tempRet0;
   ___clang_call_terminate($86);
   // unreachable;
  } else {
   ___resumeException($82|0);
   // unreachable;
  }
 } else {
  if (!($8)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $9 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
  $10 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($9,149946,32)|0);
  $11 = (_strlen($6)|0);
  $12 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($10,$6,$11)|0);
  $13 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($12,149979,27)|0);
  $14 = HEAP32[$1>>2]|0;
  $15 = ((($14)) + 28|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (FUNCTION_TABLE_ii[$16 & 8191]($1)|0);
  $18 = (_strlen($17)|0);
  $19 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($13,$17,$18)|0);
  $20 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($19,159071,1)|0);
  $21 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEPKv($20,$1)|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = ((($22)) + -12|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = (($21) + ($24)|0);
  __ZNKSt3__28ios_base6getlocEv($3,$25);
  __THREW__ = 0;
  $26 = (invoke_iii(3255,($3|0),(215188|0))|0);
  $27 = __THREW__; __THREW__ = 0;
  $28 = $27&1;
  if (!($28)) {
   $29 = HEAP32[$26>>2]|0;
   $30 = ((($29)) + 28|0);
   $31 = HEAP32[$30>>2]|0;
   __THREW__ = 0;
   $32 = (invoke_iii($31|0,($26|0),10)|0);
   $33 = __THREW__; __THREW__ = 0;
   $34 = $33&1;
   if (!($34)) {
    __ZNSt3__26localeD2Ev($3);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($21,$32)|0);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($21)|0);
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
  }
  $35 = ___cxa_find_matching_catch_2()|0;
  $36 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3263,($3|0));
  $37 = __THREW__; __THREW__ = 0;
  $38 = $37&1;
  if ($38) {
   $39 = ___cxa_find_matching_catch_3(0|0)|0;
   $40 = tempRet0;
   ___clang_call_terminate($39);
   // unreachable;
  } else {
   ___resumeException($35|0);
   // unreachable;
  }
 }
 return (0)|0;
}
function __ZNK3osg5State13checkGLErrorsEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp + 4|0;
 $3 = sp;
 $4 = (_glGetError()|0);
 $5 = ($4|0)==(0);
 if ($5) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $6 = (__ZN3osg14gluErrorStringEj($4)|0);
 $7 = ($6|0)==(0|0);
 $8 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
 if ($7) {
  if (!($8)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $50 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
  $51 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($50,150007,40)|0);
  $52 = HEAP32[$51>>2]|0;
  $53 = ((($52)) + -12|0);
  $54 = HEAP32[$53>>2]|0;
  $55 = (($51) + ($54)|0);
  $56 = ((($55)) + 4|0);
  $57 = HEAP32[$56>>2]|0;
  $58 = $57 & -75;
  $59 = $58 | 8;
  HEAP32[$56>>2] = $59;
  $60 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($51,$4)|0);
  $61 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($60,150102,25)|0);
  $62 = HEAP32[$61>>2]|0;
  $63 = ((($62)) + -12|0);
  $64 = HEAP32[$63>>2]|0;
  $65 = (($61) + ($64)|0);
  $66 = ((($65)) + 4|0);
  $67 = HEAP32[$66>>2]|0;
  $68 = $67 & -75;
  $69 = $68 | 8;
  HEAP32[$66>>2] = $69;
  $70 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($61,$1)|0);
  $71 = HEAP32[$70>>2]|0;
  $72 = ((($71)) + -12|0);
  $73 = HEAP32[$72>>2]|0;
  $74 = (($70) + ($73)|0);
  $75 = ((($74)) + 4|0);
  $76 = HEAP32[$75>>2]|0;
  $77 = $76 & -75;
  $78 = $77 | 2;
  HEAP32[$75>>2] = $78;
  $79 = HEAP32[$70>>2]|0;
  $80 = ((($79)) + -12|0);
  $81 = HEAP32[$80>>2]|0;
  $82 = (($70) + ($81)|0);
  __ZNKSt3__28ios_base6getlocEv($2,$82);
  __THREW__ = 0;
  $83 = (invoke_iii(3255,($2|0),(215188|0))|0);
  $84 = __THREW__; __THREW__ = 0;
  $85 = $84&1;
  if (!($85)) {
   $86 = HEAP32[$83>>2]|0;
   $87 = ((($86)) + 28|0);
   $88 = HEAP32[$87>>2]|0;
   __THREW__ = 0;
   $89 = (invoke_iii($88|0,($83|0),10)|0);
   $90 = __THREW__; __THREW__ = 0;
   $91 = $90&1;
   if (!($91)) {
    __ZNSt3__26localeD2Ev($2);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($70,$89)|0);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($70)|0);
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
  }
  $92 = ___cxa_find_matching_catch_2()|0;
  $93 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3263,($2|0));
  $94 = __THREW__; __THREW__ = 0;
  $95 = $94&1;
  if ($95) {
   $96 = ___cxa_find_matching_catch_3(0|0)|0;
   $97 = tempRet0;
   ___clang_call_terminate($96);
   // unreachable;
  } else {
   ___resumeException($92|0);
   // unreachable;
  }
 } else {
  if (!($8)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $9 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
  $10 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($9,149946,32)|0);
  $11 = (_strlen($6)|0);
  $12 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($10,$6,$11)|0);
  $13 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($12,150075,26)|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = ((($14)) + -12|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (($13) + ($16)|0);
  $18 = ((($17)) + 4|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = $19 & -75;
  $21 = $20 | 8;
  HEAP32[$18>>2] = $21;
  $22 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($13,$1)|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = ((($23)) + -12|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (($22) + ($25)|0);
  $27 = ((($26)) + 4|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = $28 & -75;
  $30 = $29 | 2;
  HEAP32[$27>>2] = $30;
  $31 = HEAP32[$22>>2]|0;
  $32 = ((($31)) + -12|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = (($22) + ($33)|0);
  __ZNKSt3__28ios_base6getlocEv($3,$34);
  __THREW__ = 0;
  $35 = (invoke_iii(3255,($3|0),(215188|0))|0);
  $36 = __THREW__; __THREW__ = 0;
  $37 = $36&1;
  if (!($37)) {
   $38 = HEAP32[$35>>2]|0;
   $39 = ((($38)) + 28|0);
   $40 = HEAP32[$39>>2]|0;
   __THREW__ = 0;
   $41 = (invoke_iii($40|0,($35|0),10)|0);
   $42 = __THREW__; __THREW__ = 0;
   $43 = $42&1;
   if (!($43)) {
    __ZNSt3__26localeD2Ev($3);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($22,$41)|0);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($22)|0);
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
  }
  $44 = ___cxa_find_matching_catch_2()|0;
  $45 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3263,($3|0));
  $46 = __THREW__; __THREW__ = 0;
  $47 = $46&1;
  if ($47) {
   $48 = ___cxa_find_matching_catch_3(0|0)|0;
   $49 = tempRet0;
   ___clang_call_terminate($48);
   // unreachable;
  } else {
   ___resumeException($44|0);
   // unreachable;
  }
 }
 return (0)|0;
}
function __ZNSt3__26vectorIPN3osg15ShaderComponentENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(1073741823);
 if ($8) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $9 = ((($0)) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) - ($4))|0;
 $12 = $11 >> 2;
 $13 = ($12>>>0)<(536870911);
 $14 = $11 >> 1;
 $15 = ($14>>>0)<($7>>>0);
 $$sroa$speculated$i = $15 ? $7 : $14;
 $$sroa$speculated$$i = $13 ? $$sroa$speculated$i : 1073741823;
 $16 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($16) {
   $26 = 0;
  } else {
   $17 = ($$sroa$speculated$$i>>>0)>(1073741823);
   if (!($17)) {
    $23 = $$sroa$speculated$$i << 2;
    $24 = (__Znwj($23)|0);
    $26 = $24;
    break;
   }
   $18 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($18|0),(204840|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if ($20) {
    $21 = ___cxa_find_matching_catch_2()|0;
    $22 = tempRet0;
    ___cxa_free_exception(($18|0));
    ___resumeException($21|0);
    // unreachable;
   } else {
    HEAP32[$18>>2] = (99824);
    ___cxa_throw(($18|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $25 = (($26) + ($6<<2)|0);
 $27 = (($26) + ($$sroa$speculated$$i<<2)|0);
 $28 = $27;
 $29 = HEAP32[$1>>2]|0;
 HEAP32[$25>>2] = $29;
 $30 = ((($25)) + 4|0);
 $31 = $30;
 $32 = (0 - ($6))|0;
 $33 = (($25) + ($32<<2)|0);
 $34 = $33;
 $35 = ($5|0)>(0);
 if ($35) {
  $36 = $4;
  _memcpy(($33|0),($36|0),($5|0))|0;
 }
 HEAP32[$0>>2] = $34;
 HEAP32[$2>>2] = $31;
 HEAP32[$9>>2] = $28;
 $37 = ($4|0)==(0);
 if ($37) {
  return;
 }
 $38 = $4;
 __ZdlPv($38);
 return;
}
function __ZN3osg5State20haveAppliedAttributeEPKNS_14StateAttributeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 588|0);
 __ZN3osg5State20haveAppliedAttributeERNSt3__23mapINS1_4pairINS_14StateAttribute4TypeEjEENS0_14AttributeStackENS1_4lessIS6_EENS1_9allocatorINS3_IKS6_S7_EEEEEEPKS4_(0,$2,$1);
 return;
}
function __ZN3osg5State20haveAppliedAttributeERNSt3__23mapINS1_4pairINS_14StateAttribute4TypeEjEENS0_14AttributeStackENS1_4lessIS6_EENS1_9allocatorINS3_IKS6_S7_EEEEEEPKS4_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$i$i = 0, $$0$ph$i$i = 0, $$014$i = 0, $$024$i$i = 0, $$025$i$i = 0, $$025$i68$i = 0, $$052$i = 0, $$05267$i = 0, $$in$i$i = 0, $$pre$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($2|0)==(0|0);
 if ($3) {
  return;
 }
 $4 = HEAP32[$2>>2]|0;
 $5 = ((($4)) + 148|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_ii[$6 & 8191]($2)|0);
 $8 = HEAP32[$2>>2]|0;
 $9 = ((($8)) + 152|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (FUNCTION_TABLE_ii[$10 & 8191]($2)|0);
 $12 = ((($1)) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0|0);
 do {
  if ($14) {
   $$025$i$i = $12;$$052$i = $12;$29 = $13;
   label = 15;
  } else {
   $15 = ((($1)) + 4|0);
   $$0$i$i = $15;$$024$i$i = $13;$53 = $13;
   L7: while(1) {
    $16 = ((($$024$i$i)) + 16|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = ($7|0)<($17|0);
    do {
     if ($18) {
      label = 8;
     } else {
      $19 = ($17|0)<($7|0);
      if (!($19)) {
       $20 = ((($$024$i$i)) + 20|0);
       $21 = HEAP32[$20>>2]|0;
       $22 = ($11>>>0)<($21>>>0);
       if ($22) {
        label = 8;
        break;
       }
       $25 = ($21>>>0)<($11>>>0);
       if (!($25)) {
        label = 13;
        break L7;
       }
      }
      $26 = ((($$024$i$i)) + 4|0);
      $27 = HEAP32[$26>>2]|0;
      $28 = ($27|0)==(0|0);
      if ($28) {
       label = 12;
       break L7;
      } else {
       $$0$ph$i$i = $26;$$in$i$i = $27;
      }
     }
    } while(0);
    if ((label|0) == 8) {
     label = 0;
     $23 = HEAP32[$$024$i$i>>2]|0;
     $24 = ($23|0)==(0|0);
     if ($24) {
      label = 9;
      break;
     } else {
      $$0$ph$i$i = $$024$i$i;$$in$i$i = $23;
     }
    }
    $$0$i$i = $$0$ph$i$i;$$024$i$i = $$in$i$i;$53 = $$in$i$i;
   }
   if ((label|0) == 9) {
    $$025$i68$i = $$024$i$i;$$05267$i = $$024$i$i;
    label = 16;
    break;
   }
   else if ((label|0) == 12) {
    $$025$i68$i = $26;$$05267$i = $$024$i$i;
    label = 16;
    break;
   }
   else if ((label|0) == 13) {
    $$025$i$i = $$0$i$i;$$052$i = $$024$i$i;$29 = $53;
    label = 15;
    break;
   }
  }
 } while(0);
 if ((label|0) == 15) {
  $30 = ($29|0)==(0|0);
  if ($30) {
   $$025$i68$i = $$025$i$i;$$05267$i = $$052$i;
   label = 16;
  } else {
   $$014$i = $29;
  }
 }
 if ((label|0) == 16) {
  $31 = (__Znwj(52)|0);
  $32 = ((($31)) + 16|0);
  $33 = $32;
  $34 = $33;
  HEAP32[$34>>2] = $7;
  $35 = (($33) + 4)|0;
  $36 = $35;
  HEAP32[$36>>2] = $11;
  $37 = ((($31)) + 24|0);
  HEAP8[$37>>0] = 0;
  $38 = ((($31)) + 28|0);
  ;HEAP32[$38>>2]=0|0;HEAP32[$38+4>>2]=0|0;HEAP32[$38+8>>2]=0|0;HEAP32[$38+12>>2]=0|0;HEAP32[$38+16>>2]=0|0;HEAP32[$38+20>>2]=0|0;
  HEAP32[$31>>2] = 0;
  $39 = ((($31)) + 4|0);
  HEAP32[$39>>2] = 0;
  $40 = ((($31)) + 8|0);
  HEAP32[$40>>2] = $$05267$i;
  HEAP32[$$025$i68$i>>2] = $31;
  $41 = HEAP32[$1>>2]|0;
  $42 = HEAP32[$41>>2]|0;
  $43 = ($42|0)==(0|0);
  if ($43) {
   $47 = $31;
  } else {
   $44 = $42;
   HEAP32[$1>>2] = $44;
   $$pre$i$i = HEAP32[$$025$i68$i>>2]|0;
   $47 = $$pre$i$i;
  }
  $45 = ((($1)) + 4|0);
  $46 = HEAP32[$45>>2]|0;
  __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($46,$47);
  $48 = ((($1)) + 8|0);
  $49 = HEAP32[$48>>2]|0;
  $50 = (($49) + 1)|0;
  HEAP32[$48>>2] = $50;
  $$014$i = $31;
 }
 $51 = ((($$014$i)) + 28|0);
 HEAP32[$51>>2] = $2;
 $52 = ((($$014$i)) + 24|0);
 HEAP8[$52>>0] = 1;
 return;
}
function __ZN3osg5State20haveAppliedAttributeENS_14StateAttribute4TypeEj($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$ph$lcssa$i$i$i$i = 0, $$0$ph14$i$i$i$i = 0, $$07$ph13$i$i$i$i = 0, $$0711$i$i$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 592|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  return;
 } else {
  $$0$ph14$i$i$i$i = $3;$$07$ph13$i$i$i$i = $4;
 }
 L3: while(1) {
  $$0711$i$i$i$i = $$07$ph13$i$i$i$i;
  while(1) {
   $6 = ((($$0711$i$i$i$i)) + 16|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($7|0)<($1|0);
   if (!($8)) {
    $9 = ($7|0)>($1|0);
    if ($9) {
     break;
    }
    $10 = ((($$0711$i$i$i$i)) + 20|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11>>>0)<($2>>>0);
    if (!($12)) {
     break;
    }
   }
   $15 = ((($$0711$i$i$i$i)) + 4|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ($16|0)==(0|0);
   if ($17) {
    $$0$ph$lcssa$i$i$i$i = $$0$ph14$i$i$i$i;
    break L3;
   } else {
    $$0711$i$i$i$i = $16;
   }
  }
  $13 = HEAP32[$$0711$i$i$i$i>>2]|0;
  $14 = ($13|0)==(0|0);
  if ($14) {
   $$0$ph$lcssa$i$i$i$i = $$0711$i$i$i$i;
   break;
  } else {
   $$0$ph14$i$i$i$i = $$0711$i$i$i$i;$$07$ph13$i$i$i$i = $13;
  }
 }
 $18 = ($$0$ph$lcssa$i$i$i$i|0)==($3|0);
 if ($18) {
  return;
 }
 $19 = ((($$0$ph$lcssa$i$i$i$i)) + 16|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)>($1|0);
 if ($21) {
  return;
 }
 $22 = ($20|0)<($1|0);
 if (!($22)) {
  $23 = ((($$0$ph$lcssa$i$i$i$i)) + 20|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = ($24>>>0)>($2>>>0);
  if ($25) {
   return;
  }
 }
 $26 = ((($$0$ph$lcssa$i$i$i$i)) + 28|0);
 HEAP32[$26>>2] = 0;
 $27 = ((($$0$ph$lcssa$i$i$i$i)) + 24|0);
 HEAP8[$27>>0] = 1;
 return;
}
function __ZN3osg5State27haveAppliedTextureAttributeEjPKNS_14StateAttributeE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 652|0);
 $4 = ((($0)) + 656|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$3>>2]|0;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 12)&-1;
 $9 = ($8>>>0)>($1>>>0);
 do {
  if (!($9)) {
   $10 = (($1) + 1)|0;
   $11 = ($10>>>0)>($8>>>0);
   $12 = $6;
   $13 = $5;
   if ($11) {
    $14 = (($10) - ($8))|0;
    __ZNSt3__26vectorINS_3mapINS_4pairIN3osg14StateAttribute4TypeEjEENS3_5State14AttributeStackENS_4lessIS6_EENS_9allocatorINS2_IKS6_S8_EEEEEENSB_ISF_EEE8__appendEj($3,$14);
    break;
   }
   $15 = ($10>>>0)<($8>>>0);
   if ($15) {
    $16 = (($12) + (($10*12)|0)|0);
    $17 = ($13|0)==($16|0);
    if (!($17)) {
     $19 = $13;
     while(1) {
      $18 = ((($19)) + -12|0);
      HEAP32[$4>>2] = $18;
      $20 = ((($19)) + -8|0);
      $21 = HEAP32[$20>>2]|0;
      __ZNSt3__26__treeINS_12__value_typeINS_4pairIN3osg14StateAttribute4TypeEjEENS3_5State14AttributeStackEEENS_19__map_value_compareIS6_S9_NS_4lessIS6_EELb1EEENS_9allocatorIS9_EEE7destroyEPNS_11__tree_nodeIS9_PvEE($18,$21);
      $22 = HEAP32[$4>>2]|0;
      $23 = ($22|0)==($16|0);
      if ($23) {
       break;
      } else {
       $19 = $22;
      }
     }
    }
   }
  }
 } while(0);
 $24 = HEAP32[$3>>2]|0;
 $25 = (($24) + (($1*12)|0)|0);
 __ZN3osg5State20haveAppliedAttributeERNSt3__23mapINS1_4pairINS_14StateAttribute4TypeEjEENS0_14AttributeStackENS1_4lessIS6_EENS1_9allocatorINS3_IKS6_S7_EEEEEEPKS4_(0,$25,$2);
 return;
}
function __ZN3osg5State45applyModelViewAndProjectionUniformsIfRequiredEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 664|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  return;
 }
 $4 = ((($0)) + 188|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  __ZNK3osg7Program17PerContextProgram5applyERKNS_7UniformE($2,$5);
 }
 $7 = ((($0)) + 192|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if (!($9)) {
  $10 = HEAP32[$1>>2]|0;
  __ZNK3osg7Program17PerContextProgram5applyERKNS_7UniformE($10,$8);
 }
 $11 = ((($0)) + 196|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0|0);
 if (!($13)) {
  $14 = HEAP32[$1>>2]|0;
  __ZNK3osg7Program17PerContextProgram5applyERKNS_7UniformE($14,$12);
 }
 $15 = ((($0)) + 200|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==(0|0);
 if ($17) {
  return;
 }
 $18 = HEAP32[$1>>2]|0;
 __ZNK3osg7Program17PerContextProgram5applyERKNS_7UniformE($18,$16);
 return;
}
function __ZN11State_Utils7replaceERNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEERKS6_S9_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$ = 0, $$026 = 0, $$027$off0$ph49 = 0, $$02729$i$i$i = 0, $$028$be = 0, $$028$ph48 = 0, $$02843 = 0, $$1$i$i55 = 0, $$2 = 0, $$mux = 0, $$off = 0, $$off36 = 0, $$off37 = 0, $10 = 0, $100 = 0, $101 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $brmerge = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($1)) + 11|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)<(0);
 $6 = ((($1)) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $4&255;
 $9 = $5 ? $7 : $8;
 $10 = ($9|0)==(0);
 if ($10) {
  $$026 = 0;
  return ($$026|0);
 }
 $11 = ((($0)) + 11|0);
 $12 = HEAP8[$11>>0]|0;
 $13 = ($12<<24>>24)<(0);
 $14 = HEAP32[$0>>2]|0;
 $15 = ((($0)) + 4|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $12&255;
 $18 = $13 ? $14 : $0;
 $19 = $13 ? $16 : $17;
 $20 = HEAP32[$1>>2]|0;
 $21 = $5 ? $20 : $1;
 $22 = ((($2)) + 11|0);
 $23 = ((($2)) + 4|0);
 $$027$off0$ph49 = 0;$$028$ph48 = 0;$100 = $19;$101 = $18;$24 = $4;$27 = $7;$29 = $12;$32 = $16;$34 = $14;$36 = $20;$98 = $9;$99 = $21;
 L4: while(1) {
  $25 = ($24<<24>>24)<(0);
  $26 = $24&255;
  $28 = $25 ? $27 : $26;
  $30 = ($29<<24>>24)<(0);
  $31 = $29&255;
  $33 = $30 ? $32 : $31;
  $35 = $30 ? $34 : $0;
  $37 = $25 ? $36 : $1;
  $$02843 = $$028$ph48;$38 = $98;$41 = $101;$43 = $100;$49 = $99;
  while(1) {
   $39 = ($38|0)==(0);
   if ($39) {
    $$1$i$i55 = $$02843;
   } else {
    $40 = (($41) + ($$02843)|0);
    $42 = (($41) + ($43)|0);
    $44 = $42;
    $45 = $40;
    $46 = (($44) - ($45))|0;
    $47 = ($46|0)<($38|0);
    if ($47) {
     $$026 = $$027$off0$ph49;
     label = 17;
     break L4;
    }
    $48 = HEAP8[$49>>0]|0;
    $50 = $48&255;
    $$02729$i$i$i = $40;$52 = $46;
    while(1) {
     $51 = (($52) - ($38))|0;
     $53 = (($51) + 1)|0;
     $54 = ($53|0)==(0);
     if ($54) {
      $$026 = $$027$off0$ph49;
      label = 17;
      break L4;
     }
     $55 = (_memchr($$02729$i$i$i,$50,$53)|0);
     $56 = ($55|0)==(0|0);
     if ($56) {
      $$026 = $$027$off0$ph49;
      label = 17;
      break L4;
     }
     $57 = (_memcmp($55,$49,$38)|0);
     $58 = ($57|0)==(0);
     if ($58) {
      break;
     }
     $59 = ((($55)) + 1|0);
     $60 = $59;
     $61 = (($44) - ($60))|0;
     $62 = ($61|0)<($38|0);
     if ($62) {
      $$026 = $$027$off0$ph49;
      label = 17;
      break L4;
     } else {
      $$02729$i$i$i = $59;$52 = $61;
     }
    }
    $63 = ($55|0)==($42|0);
    $64 = $55;
    $65 = $41;
    $66 = (($64) - ($65))|0;
    $67 = ($66|0)==(-1);
    $or$cond = $63 | $67;
    if ($or$cond) {
     $$026 = $$027$off0$ph49;
     label = 17;
     break L4;
    } else {
     $$1$i$i55 = $66;
    }
   }
   $68 = (($28) + ($$1$i$i55))|0;
   $69 = ($68>>>0)<($33>>>0);
   if (!($69)) {
    $$2 = $$1$i$i55;
    break;
   }
   $70 = (($35) + ($68)|0);
   $71 = HEAP8[$70>>0]|0;
   $$off = (($71) + -48)<<24>>24;
   $72 = ($$off&255)<(10);
   if ($72) {
    $$028$be = $68;
   } else {
    $$off36 = (($71) + -97)<<24>>24;
    $74 = ($$off36&255)<(26);
    $$off37 = (($71) + -65)<<24>>24;
    $75 = ($$off37&255)<(26);
    $$ = $75 ? $68 : $$1$i$i55;
    $brmerge = $74 | $75;
    $$mux = $74 ? $68 : $$;
    if ($brmerge) {
     $$028$be = $$mux;
    } else {
     $$2 = $$;
     break;
    }
   }
   $73 = ($33>>>0)<($$028$be>>>0);
   if ($73) {
    $$026 = $$027$off0$ph49;
    label = 17;
    break L4;
   } else {
    $$02843 = $$028$be;$38 = $28;$41 = $35;$43 = $33;$49 = $37;
   }
  }
  $76 = HEAP8[$22>>0]|0;
  $77 = ($76<<24>>24)<(0);
  $78 = HEAP32[$2>>2]|0;
  $79 = $77 ? $78 : $2;
  $80 = HEAP32[$23>>2]|0;
  $81 = $76&255;
  $82 = $77 ? $80 : $81;
  (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7replaceEjjPKcj($0,$$2,$28,$79,$82)|0);
  $83 = HEAP8[$11>>0]|0;
  $84 = ($83<<24>>24)<(0);
  $85 = HEAP32[$0>>2]|0;
  $86 = HEAP32[$15>>2]|0;
  $87 = $83&255;
  $88 = $84 ? $85 : $0;
  $89 = $84 ? $86 : $87;
  $90 = HEAP8[$3>>0]|0;
  $91 = ($90<<24>>24)<(0);
  $92 = HEAP32[$1>>2]|0;
  $93 = $91 ? $92 : $1;
  $94 = HEAP32[$6>>2]|0;
  $95 = $90&255;
  $96 = $91 ? $94 : $95;
  $97 = ($89>>>0)<($$2>>>0);
  if ($97) {
   $$026 = 1;
   label = 17;
   break;
  } else {
   $$027$off0$ph49 = 1;$$028$ph48 = $$2;$100 = $89;$101 = $88;$24 = $90;$27 = $94;$29 = $83;$32 = $86;$34 = $85;$36 = $92;$98 = $96;$99 = $93;
  }
 }
 if ((label|0) == 17) {
  return ($$026|0);
 }
 return (0)|0;
}
function __ZN11State_Utils27replaceAndInsertDeclarationERNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEjRKS6_S9_S9_S9_($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$0 = 0, $$09 = 0, $$2 = 0, $$211 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $6 = sp + 36|0;
 $7 = sp + 24|0;
 $8 = sp + 12|0;
 $9 = sp;
 $10 = (__ZN11State_Utils7replaceERNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEERKS6_S9_($0,$2,$3)|0);
 if (!($10)) {
  STACKTOP = sp;return;
 }
 __ZNSt3__2plIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_12basic_stringIT_T0_T1_EERKS9_SB_($8,$4,$5);
 __THREW__ = 0;
 invoke_viii(3550,($7|0),($8|0),($3|0));
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if ($12) {
  $42 = ___cxa_find_matching_catch_2()|0;
  $43 = tempRet0;
  $$2 = $43;$$211 = $42;
 } else {
  ;HEAP32[$9>>2]=0|0;HEAP32[$9+4>>2]=0|0;HEAP32[$9+8>>2]=0|0;
  $13 = ((($9)) + 11|0);
  HEAP8[$13>>0] = 2;
  HEAP16[$9>>1] = 2619;
  $14 = ((($9)) + 2|0);
  HEAP8[$14>>0] = 0;
  __THREW__ = 0;
  invoke_viii(3550,($6|0),($7|0),($9|0));
  $15 = __THREW__; __THREW__ = 0;
  $16 = $15&1;
  do {
   if ($16) {
    $44 = ___cxa_find_matching_catch_2()|0;
    $45 = tempRet0;
    $$0 = $45;$$09 = $44;
   } else {
    $17 = ((($6)) + 11|0);
    $18 = HEAP8[$17>>0]|0;
    $19 = ($18<<24>>24)<(0);
    $20 = HEAP32[$6>>2]|0;
    $21 = $19 ? $20 : $6;
    $22 = ((($6)) + 4|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = $18&255;
    $25 = $19 ? $23 : $24;
    __THREW__ = 0;
    (invoke_iiiii(3934,($0|0),($1|0),($21|0),($25|0))|0);
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if ($27) {
     $46 = ___cxa_find_matching_catch_2()|0;
     $47 = tempRet0;
     $48 = HEAP8[$17>>0]|0;
     $49 = ($48<<24>>24)<(0);
     if (!($49)) {
      $$0 = $47;$$09 = $46;
      break;
     }
     $50 = HEAP32[$6>>2]|0;
     __ZdlPv($50);
     $$0 = $47;$$09 = $46;
     break;
    }
    $28 = HEAP8[$17>>0]|0;
    $29 = ($28<<24>>24)<(0);
    if ($29) {
     $30 = HEAP32[$6>>2]|0;
     __ZdlPv($30);
    }
    $31 = HEAP8[$13>>0]|0;
    $32 = ($31<<24>>24)<(0);
    if ($32) {
     $33 = HEAP32[$9>>2]|0;
     __ZdlPv($33);
    }
    $34 = ((($7)) + 11|0);
    $35 = HEAP8[$34>>0]|0;
    $36 = ($35<<24>>24)<(0);
    if ($36) {
     $37 = HEAP32[$7>>2]|0;
     __ZdlPv($37);
    }
    $38 = ((($8)) + 11|0);
    $39 = HEAP8[$38>>0]|0;
    $40 = ($39<<24>>24)<(0);
    if ($40) {
     $41 = HEAP32[$8>>2]|0;
     __ZdlPv($41);
    }
    STACKTOP = sp;return;
   }
  } while(0);
  $51 = HEAP8[$13>>0]|0;
  $52 = ($51<<24>>24)<(0);
  if ($52) {
   $53 = HEAP32[$9>>2]|0;
   __ZdlPv($53);
  }
  $54 = ((($7)) + 11|0);
  $55 = HEAP8[$54>>0]|0;
  $56 = ($55<<24>>24)<(0);
  if ($56) {
   $57 = HEAP32[$7>>2]|0;
   __ZdlPv($57);
   $$2 = $$0;$$211 = $$09;
  } else {
   $$2 = $$0;$$211 = $$09;
  }
 }
 $58 = ((($8)) + 11|0);
 $59 = HEAP8[$58>>0]|0;
 $60 = ($59<<24>>24)<(0);
 if (!($60)) {
  ___resumeException($$211|0);
  // unreachable;
 }
 $61 = HEAP32[$8>>2]|0;
 __ZdlPv($61);
 ___resumeException($$211|0);
 // unreachable;
}
function __ZNK3osg5State38convertVertexShaderSourceToOsgBuiltInsERNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$0$i$i$i = 0, $$0$i$i$i122 = 0, $$0$i$i95 = 0, $$01824$i$i = 0, $$02729$i$i$i = 0, $$042$i$i$i = 0, $$042$i$i$i121 = 0, $$043$i$i$i$idx = 0, $$043$i$i$i117$idx = 0, $$067319 = 0, $$1 = 0, $$1$i$i = 0, $$1$i$i$i$add = 0, $$1$i$i$i$idx = 0, $$1$i$i$i119$add = 0, $$1$i$i$i119$idx = 0, $$10 = 0, $$1080 = 0, $$120$i$i = 0;
 var $$13 = 0, $$1383 = 0, $$14 = 0, $$1484 = 0, $$169 = 0, $$17 = 0, $$171 = 0, $$1787 = 0, $$18 = 0, $$1888 = 0, $$2 = 0, $$2$i$i$i = 0, $$20 = 0, $$2090 = 0, $$272 = 0, $$5 = 0, $$575 = 0, $$6 = 0, $$676 = 0, $$9 = 0;
 var $$979 = 0, $$in = 0, $$pre = 0, $$pre$phi329Z2D = 0, $$pre$phi331Z2D = 0, $$pre$phi333Z2D = 0, $$pre$phi335Z2D = 0, $$pre325 = 0, $$pre326 = 0, $$pre328 = 0, $$pre332 = 0, $$ptr = 0, $$ptr311 = 0, $$ptr312 = 0, $$ptr313 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0;
 var $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0;
 var $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0;
 var $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0;
 var $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0;
 var $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0;
 var $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0;
 var $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0;
 var $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0;
 var $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0;
 var $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0;
 var $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0;
 var $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0;
 var $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0;
 var $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0;
 var $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0;
 var $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0;
 var $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0;
 var $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0;
 var $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0;
 var $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0;
 var $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0;
 var $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0;
 var $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0;
 var $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0;
 var $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0;
 var $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0;
 var $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0;
 var $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0;
 var $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0;
 var $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0;
 var $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, $eh$lpad$body281$index9Z2D = 0, $eh$lpad$body281$indexZ2D = 0, $lhsc = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 304|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(304|0);
 $2 = sp + 292|0;
 $3 = sp + 288|0;
 $4 = sp + 284|0;
 $5 = sp + 280|0;
 $6 = sp + 276|0;
 $7 = sp + 272|0;
 $8 = sp + 268|0;
 $9 = sp + 264|0;
 $10 = sp + 252|0;
 $11 = sp + 240|0;
 $12 = sp + 228|0;
 $13 = sp + 296|0;
 $14 = sp + 216|0;
 $15 = sp + 204|0;
 $16 = sp + 192|0;
 $17 = sp + 180|0;
 $18 = sp + 48|0;
 $19 = sp + 168|0;
 $20 = sp + 156|0;
 $21 = sp + 144|0;
 $22 = sp + 32|0;
 $23 = sp + 132|0;
 $24 = sp + 120|0;
 $25 = sp + 108|0;
 $26 = sp + 16|0;
 $27 = sp + 96|0;
 $28 = sp + 84|0;
 $29 = sp + 72|0;
 $30 = sp;
 $31 = sp + 60|0;
 $32 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
 do {
  if ($32) {
   $33 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
   $34 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($33,150150,41)|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ((($35)) + -12|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = (($34) + ($37)|0);
   __ZNKSt3__28ios_base6getlocEv($9,$38);
   __THREW__ = 0;
   $39 = (invoke_iii(3255,($9|0),(215188|0))|0);
   $40 = __THREW__; __THREW__ = 0;
   $41 = $40&1;
   if (!($41)) {
    $42 = HEAP32[$39>>2]|0;
    $43 = ((($42)) + 28|0);
    $44 = HEAP32[$43>>2]|0;
    __THREW__ = 0;
    $45 = (invoke_iii($44|0,($39|0),10)|0);
    $46 = __THREW__; __THREW__ = 0;
    $47 = $46&1;
    if (!($47)) {
     __ZNSt3__26localeD2Ev($9);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($34,$45)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($34)|0);
     break;
    }
   }
   $48 = ___cxa_find_matching_catch_2()|0;
   $49 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($9|0));
   $50 = __THREW__; __THREW__ = 0;
   $51 = $50&1;
   if ($51) {
    $52 = ___cxa_find_matching_catch_3(0|0)|0;
    $53 = tempRet0;
    ___clang_call_terminate($52);
    // unreachable;
   } else {
    ___resumeException($48|0);
    // unreachable;
   }
  }
 } while(0);
 $54 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
 do {
  if ($54) {
   $55 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
   $56 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($55,150192,26)|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = ((($57)) + -12|0);
   $59 = HEAP32[$58>>2]|0;
   $60 = (($56) + ($59)|0);
   __ZNKSt3__28ios_base6getlocEv($8,$60);
   __THREW__ = 0;
   $61 = (invoke_iii(3255,($8|0),(215188|0))|0);
   $62 = __THREW__; __THREW__ = 0;
   $63 = $62&1;
   if (!($63)) {
    $64 = HEAP32[$61>>2]|0;
    $65 = ((($64)) + 28|0);
    $66 = HEAP32[$65>>2]|0;
    __THREW__ = 0;
    $67 = (invoke_iii($66|0,($61|0),10)|0);
    $68 = __THREW__; __THREW__ = 0;
    $69 = $68&1;
    if (!($69)) {
     __ZNSt3__26localeD2Ev($8);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($56,$67)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($56)|0);
     $76 = ((($1)) + 11|0);
     $77 = HEAP8[$76>>0]|0;
     $78 = ($77<<24>>24)<(0);
     $79 = HEAP32[$1>>2]|0;
     $80 = $78 ? $79 : $1;
     $81 = ((($1)) + 4|0);
     $82 = HEAP32[$81>>2]|0;
     $83 = $77&255;
     $84 = $78 ? $82 : $83;
     $85 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($56,$80,$84)|0);
     $86 = HEAP32[$85>>2]|0;
     $87 = ((($86)) + -12|0);
     $88 = HEAP32[$87>>2]|0;
     $89 = (($85) + ($88)|0);
     __ZNKSt3__28ios_base6getlocEv($7,$89);
     __THREW__ = 0;
     $90 = (invoke_iii(3255,($7|0),(215188|0))|0);
     $91 = __THREW__; __THREW__ = 0;
     $92 = $91&1;
     if (!($92)) {
      $93 = HEAP32[$90>>2]|0;
      $94 = ((($93)) + 28|0);
      $95 = HEAP32[$94>>2]|0;
      __THREW__ = 0;
      $96 = (invoke_iii($95|0,($90|0),10)|0);
      $97 = __THREW__; __THREW__ = 0;
      $98 = $97&1;
      if (!($98)) {
       __ZNSt3__26localeD2Ev($7);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($85,$96)|0);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($85)|0);
       $105 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($85,150219,8)|0);
       $106 = HEAP32[$105>>2]|0;
       $107 = ((($106)) + -12|0);
       $108 = HEAP32[$107>>2]|0;
       $109 = (($105) + ($108)|0);
       __ZNKSt3__28ios_base6getlocEv($6,$109);
       __THREW__ = 0;
       $110 = (invoke_iii(3255,($6|0),(215188|0))|0);
       $111 = __THREW__; __THREW__ = 0;
       $112 = $111&1;
       if (!($112)) {
        $113 = HEAP32[$110>>2]|0;
        $114 = ((($113)) + 28|0);
        $115 = HEAP32[$114>>2]|0;
        __THREW__ = 0;
        $116 = (invoke_iii($115|0,($110|0),10)|0);
        $117 = __THREW__; __THREW__ = 0;
        $118 = $117&1;
        if (!($118)) {
         __ZNSt3__26localeD2Ev($6);
         (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($105,$116)|0);
         (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($105)|0);
         $$pre$phi329Z2D = $76;$$pre$phi331Z2D = $1;$$pre$phi333Z2D = $81;$$pre$phi335Z2D = $1;
         break;
        }
       }
       $119 = ___cxa_find_matching_catch_2()|0;
       $120 = tempRet0;
       __THREW__ = 0;
       invoke_vi(3263,($6|0));
       $121 = __THREW__; __THREW__ = 0;
       $122 = $121&1;
       if ($122) {
        $123 = ___cxa_find_matching_catch_3(0|0)|0;
        $124 = tempRet0;
        ___clang_call_terminate($123);
        // unreachable;
       } else {
        ___resumeException($119|0);
        // unreachable;
       }
      }
     }
     $99 = ___cxa_find_matching_catch_2()|0;
     $100 = tempRet0;
     __THREW__ = 0;
     invoke_vi(3263,($7|0));
     $101 = __THREW__; __THREW__ = 0;
     $102 = $101&1;
     if ($102) {
      $103 = ___cxa_find_matching_catch_3(0|0)|0;
      $104 = tempRet0;
      ___clang_call_terminate($103);
      // unreachable;
     } else {
      ___resumeException($99|0);
      // unreachable;
     }
    }
   }
   $70 = ___cxa_find_matching_catch_2()|0;
   $71 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($8|0));
   $72 = __THREW__; __THREW__ = 0;
   $73 = $72&1;
   if ($73) {
    $74 = ___cxa_find_matching_catch_3(0|0)|0;
    $75 = tempRet0;
    ___clang_call_terminate($74);
    // unreachable;
   } else {
    ___resumeException($70|0);
    // unreachable;
   }
  } else {
   $$pre328 = ((($1)) + 11|0);
   $$pre332 = ((($1)) + 4|0);
   $$pre$phi329Z2D = $$pre328;$$pre$phi331Z2D = $1;$$pre$phi333Z2D = $$pre332;$$pre$phi335Z2D = $1;
  }
 } while(0);
 $125 = ((($10)) + 11|0);
 HEAP8[$125>>0] = 10;
 dest=$10; src=150228; stop=dest+10|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $126 = ((($10)) + 10|0);
 HEAP8[$126>>0] = 0;
 $127 = HEAP8[$$pre$phi329Z2D>>0]|0;
 $128 = ($127<<24>>24)<(0);
 $129 = HEAP32[$$pre$phi331Z2D>>2]|0;
 $130 = HEAP32[$$pre$phi333Z2D>>2]|0;
 $131 = $127&255;
 $132 = $128 ? $129 : $$pre$phi335Z2D;
 $133 = $128 ? $130 : $131;
 $$ptr311 = (($132) + ($133)|0);
 $134 = ($133|0)<(9);
 L36: do {
  if ($134) {
   $$0 = 0;$244 = $127;$247 = $129;$249 = $130;
   label = 74;
  } else {
   $$043$i$i$i$idx = $133;
   L37: while(1) {
    $$1$i$i$i$idx = $$043$i$i$i$idx;
    while(1) {
     $135 = ($$1$i$i$i$idx|0)==(8);
     if ($135) {
      $$0 = 0;$244 = $127;$247 = $129;$249 = $130;
      label = 74;
      break L36;
     }
     $$1$i$i$i$add = (($$1$i$i$i$idx) + -1)|0;
     $$ptr = (($132) + ($$1$i$i$i$add)|0);
     $136 = HEAP8[$$ptr>>0]|0;
     $137 = ($136<<24>>24)==(32);
     if ($137) {
      $$0$i$i$i = (150247);$$042$i$i$i = $$ptr;
      break;
     } else {
      $$1$i$i$i$idx = $$1$i$i$i$add;
     }
    }
    while(1) {
     $138 = ($$0$i$i$i|0)==(150239|0);
     if ($138) {
      break L37;
     }
     $139 = ((($$042$i$i$i)) + -1|0);
     $140 = HEAP8[$139>>0]|0;
     $141 = ((($$0$i$i$i)) + -1|0);
     $142 = HEAP8[$141>>0]|0;
     $143 = ($140<<24>>24)==($142<<24>>24);
     if ($143) {
      $$0$i$i$i = $141;$$042$i$i$i = $139;
     } else {
      $$043$i$i$i$idx = $$1$i$i$i$add;
      continue L37;
     }
    }
   }
   $144 = ($$042$i$i$i|0)==($$ptr311|0);
   $145 = $$042$i$i$i;
   $146 = $132;
   $147 = (($145) - ($146))|0;
   $148 = ($147|0)==(-1);
   $149 = $144 | $148;
   if ($149) {
    $$0 = 0;$244 = $127;$247 = $129;$249 = $130;
    label = 74;
   } else {
    $150 = ($133>>>0)<($147>>>0);
    if ($150) {
     $$1$i$i = -1;
    } else {
     $151 = $$ptr311;
     $152 = (($151) - ($145))|0;
     $153 = ($152|0)<(1);
     L49: do {
      if ($153) {
       $$2$i$i$i = $$ptr311;
      } else {
       $$02729$i$i$i = $$042$i$i$i;$154 = $152;
       while(1) {
        $155 = (_memchr($$02729$i$i$i,32,$154)|0);
        $156 = ($155|0)==(0|0);
        if ($156) {
         $$2$i$i$i = $$ptr311;
         break L49;
        }
        $lhsc = HEAP8[$155>>0]|0;
        $157 = ($lhsc<<24>>24)==(32);
        if ($157) {
         $$2$i$i$i = $155;
         break L49;
        }
        $158 = ((($155)) + 1|0);
        $159 = $158;
        $160 = (($151) - ($159))|0;
        $161 = ($160|0)<(1);
        if ($161) {
         $$2$i$i$i = $$ptr311;
         break;
        } else {
         $$02729$i$i$i = $158;$154 = $160;
        }
       }
      }
     } while(0);
     $162 = ($$2$i$i$i|0)==($$ptr311|0);
     $163 = $$2$i$i$i;
     $164 = (($163) - ($146))|0;
     $$0$i$i95 = $162 ? -1 : $164;
     $$1$i$i = $$0$i$i95;
    }
    ;HEAP32[$11>>2]=0|0;HEAP32[$11+4>>2]=0|0;HEAP32[$11+8>>2]=0|0;
    $165 = ((($11)) + 11|0);
    HEAP8[$165>>0] = 1;
    HEAP8[$11>>0] = 32;
    $166 = ((($11)) + 1|0);
    HEAP8[$166>>0] = 0;
    $167 = ($133>>>0)>($$1$i$i>>>0);
    L56: do {
     if ($167) {
      $168 = (($132) + ($$1$i$i)|0);
      $$01824$i$i = $168;
      while(1) {
       $169 = HEAP8[$$01824$i$i>>0]|0;
       $170 = $169&255;
       $171 = (_memchr($11,$170,1)|0);
       $172 = ($171|0)==(0|0);
       if ($172) {
        break;
       }
       $173 = ((($$01824$i$i)) + 1|0);
       $174 = ($173|0)==($$ptr311|0);
       if ($174) {
        $$120$i$i = -1;
        break L56;
       } else {
        $$01824$i$i = $173;
       }
      }
      $175 = $$01824$i$i;
      $176 = (($175) - ($146))|0;
      $$120$i$i = $176;
     } else {
      $$120$i$i = -1;
     }
    } while(0);
    __THREW__ = 0;
    invoke_viiiii(3746,($12|0),($1|0),($$120$i$i|0),3,($13|0));
    $177 = __THREW__; __THREW__ = 0;
    $178 = $177&1;
    if ($178) {
     $224 = ___cxa_find_matching_catch_2()|0;
     $225 = tempRet0;
     $$20 = $224;$$2090 = $225;
     break;
    }
    $179 = ((($12)) + 11|0);
    $180 = HEAP8[$179>>0]|0;
    $181 = ($180<<24>>24)<(0);
    $182 = HEAP32[$12>>2]|0;
    $183 = $181 ? $182 : $12;
    $184 = (_atoi($183)|0);
    __THREW__ = 0;
    $185 = (invoke_ii(3265,4)|0);
    $186 = __THREW__; __THREW__ = 0;
    $187 = $186&1;
    L66: do {
     if ($187) {
      label = 60;
     } else {
      do {
       if ($185) {
        __THREW__ = 0;
        $188 = (invoke_ii(3266,4)|0);
        $189 = __THREW__; __THREW__ = 0;
        $190 = $189&1;
        if ($190) {
         label = 60;
         break L66;
        }
        __THREW__ = 0;
        $191 = (invoke_iiii(3267,($188|0),(150249|0),22)|0);
        $192 = __THREW__; __THREW__ = 0;
        $193 = $192&1;
        if ($193) {
         label = 60;
         break L66;
        }
        __THREW__ = 0;
        $194 = (invoke_iii(3863,($191|0),($184|0))|0);
        $195 = __THREW__; __THREW__ = 0;
        $196 = $195&1;
        if ($196) {
         label = 60;
         break L66;
        }
        $197 = HEAP32[$194>>2]|0;
        $198 = ((($197)) + -12|0);
        $199 = HEAP32[$198>>2]|0;
        $200 = (($194) + ($199)|0);
        __THREW__ = 0;
        invoke_vii(3257,($5|0),($200|0));
        $201 = __THREW__; __THREW__ = 0;
        $202 = $201&1;
        if ($202) {
         label = 60;
         break L66;
        }
        __THREW__ = 0;
        $203 = (invoke_iii(3255,($5|0),(215188|0))|0);
        $204 = __THREW__; __THREW__ = 0;
        $205 = $204&1;
        if (!($205)) {
         $206 = HEAP32[$203>>2]|0;
         $207 = ((($206)) + 28|0);
         $208 = HEAP32[$207>>2]|0;
         __THREW__ = 0;
         $209 = (invoke_iii($208|0,($203|0),10)|0);
         $210 = __THREW__; __THREW__ = 0;
         $211 = $210&1;
         if (!($211)) {
          __THREW__ = 0;
          invoke_vi(3263,($5|0));
          $218 = __THREW__; __THREW__ = 0;
          $219 = $218&1;
          if ($219) {
           label = 60;
           break L66;
          }
          __THREW__ = 0;
          (invoke_iii(3268,($194|0),($209|0))|0);
          $220 = __THREW__; __THREW__ = 0;
          $221 = $220&1;
          if ($221) {
           label = 60;
           break L66;
          }
          __THREW__ = 0;
          (invoke_ii(3269,($194|0))|0);
          $222 = __THREW__; __THREW__ = 0;
          $223 = $222&1;
          if ($223) {
           label = 60;
           break L66;
          } else {
           break;
          }
         }
        }
        $212 = ___cxa_find_matching_catch_2()|0;
        $213 = tempRet0;
        __THREW__ = 0;
        invoke_vi(3263,($5|0));
        $214 = __THREW__; __THREW__ = 0;
        $215 = $214&1;
        if ($215) {
         $216 = ___cxa_find_matching_catch_3(0|0)|0;
         $217 = tempRet0;
         ___clang_call_terminate($216);
         // unreachable;
        } else {
         $eh$lpad$body$index2Z2D = $213;$eh$lpad$body$indexZ2D = $212;
         break L66;
        }
       }
      } while(0);
      $231 = ($184|0)>(129);
      if ($231) {
       __THREW__ = 0;
       (invoke_iii(3786,($10|0),(150272|0))|0);
       $232 = __THREW__; __THREW__ = 0;
       $233 = $232&1;
       if ($233) {
        label = 60;
        break;
       }
      }
      $234 = (__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE4findEcj($1,10,$$120$i$i)|0);
      $235 = ($234|0)==(-1);
      do {
       if ($235) {
        $237 = HEAP8[$$pre$phi329Z2D>>0]|0;
        $238 = ($237<<24>>24)<(0);
        if ($238) {
         $239 = HEAP32[$$pre$phi333Z2D>>2]|0;
         $655 = $239;
         break;
        } else {
         $240 = $237&255;
         $655 = $240;
         break;
        }
       } else {
        $236 = (($234) + 1)|0;
        $655 = $236;
       }
      } while(0);
      $241 = HEAP8[$179>>0]|0;
      $242 = ($241<<24>>24)<(0);
      if ($242) {
       $243 = HEAP32[$12>>2]|0;
       __ZdlPv($243);
      }
      $$pre = HEAP8[$$pre$phi329Z2D>>0]|0;
      $$pre325 = HEAP32[$$pre$phi331Z2D>>2]|0;
      $$pre326 = HEAP32[$$pre$phi333Z2D>>2]|0;
      $$0 = $655;$244 = $$pre;$247 = $$pre325;$249 = $$pre326;
      label = 74;
      break L36;
     }
    } while(0);
    if ((label|0) == 60) {
     $226 = ___cxa_find_matching_catch_2()|0;
     $227 = tempRet0;
     $eh$lpad$body$index2Z2D = $227;$eh$lpad$body$indexZ2D = $226;
    }
    $228 = HEAP8[$179>>0]|0;
    $229 = ($228<<24>>24)<(0);
    if ($229) {
     $230 = HEAP32[$12>>2]|0;
     __ZdlPv($230);
    }
    $$20 = $eh$lpad$body$indexZ2D;$$2090 = $eh$lpad$body$index2Z2D;
   }
  }
 } while(0);
 L103: do {
  if ((label|0) == 74) {
   $245 = ($244<<24>>24)<(0);
   $246 = $244&255;
   $248 = $245 ? $247 : $$pre$phi335Z2D;
   $250 = $245 ? $249 : $246;
   $$ptr313 = (($248) + ($250)|0);
   $251 = ($250|0)<(11);
   L105: do {
    if ($251) {
     $$1 = $$0;
    } else {
     $$043$i$i$i117$idx = $250;
     L106: while(1) {
      $$1$i$i$i119$idx = $$043$i$i$i117$idx;
      while(1) {
       $252 = ($$1$i$i$i119$idx|0)==(10);
       if ($252) {
        $$1 = $$0;
        break L105;
       }
       $$1$i$i$i119$add = (($$1$i$i$i119$idx) + -1)|0;
       $$ptr312 = (($248) + ($$1$i$i$i119$add)|0);
       $253 = HEAP8[$$ptr312>>0]|0;
       $254 = ($253<<24>>24)==(32);
       if ($254) {
        $$0$i$i$i122 = (150286);$$042$i$i$i121 = $$ptr312;
        break;
       } else {
        $$1$i$i$i119$idx = $$1$i$i$i119$add;
       }
      }
      while(1) {
       $255 = ($$0$i$i$i122|0)==(150276|0);
       if ($255) {
        break L106;
       }
       $256 = ((($$042$i$i$i121)) + -1|0);
       $257 = HEAP8[$256>>0]|0;
       $258 = ((($$0$i$i$i122)) + -1|0);
       $259 = HEAP8[$258>>0]|0;
       $260 = ($257<<24>>24)==($259<<24>>24);
       if ($260) {
        $$0$i$i$i122 = $258;$$042$i$i$i121 = $256;
       } else {
        $$043$i$i$i117$idx = $$1$i$i$i119$add;
        continue L106;
       }
      }
     }
     $261 = ($$042$i$i$i121|0)==($$ptr313|0);
     $262 = $$042$i$i$i121;
     $263 = $248;
     $264 = (($262) - ($263))|0;
     $265 = ($264|0)==(-1);
     $266 = $261 | $265;
     if ($266) {
      $$1 = $$0;
     } else {
      $267 = (__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE4findEcj($1,10,$264)|0);
      $268 = ($267|0)==(-1);
      if (!($268)) {
       $269 = (($267) + 1)|0;
       $$1 = $269;
       break;
      }
      $270 = HEAP8[$$pre$phi329Z2D>>0]|0;
      $271 = ($270<<24>>24)<(0);
      if ($271) {
       $272 = HEAP32[$$pre$phi333Z2D>>2]|0;
       $$1 = $272;
       break;
      } else {
       $273 = $270&255;
       $$1 = $273;
       break;
      }
     }
    }
   } while(0);
   $274 = ((($0)) + 184|0);
   $275 = HEAP8[$274>>0]|0;
   $276 = ($275<<24>>24)==(0);
   L123: do {
    if (!($276)) {
     ;HEAP32[$14>>2]=0|0;HEAP32[$14+4>>2]=0|0;HEAP32[$14+8>>2]=0|0;
     __THREW__ = 0;
     $277 = (invoke_ii(3276,16)|0);
     $278 = __THREW__; __THREW__ = 0;
     $279 = $278&1;
     if ($279) {
      $423 = ___cxa_find_matching_catch_2()|0;
      $424 = tempRet0;
      $$2 = $423;$$272 = $424;
     } else {
      HEAP32[$14>>2] = $277;
      $280 = ((($14)) + 8|0);
      HEAP32[$280>>2] = -2147483632;
      $281 = ((($14)) + 4|0);
      HEAP32[$281>>2] = 12;
      dest=$277; src=150288; stop=dest+12|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
      $282 = ((($277)) + 12|0);
      HEAP8[$282>>0] = 0;
      ;HEAP32[$15>>2]=0|0;HEAP32[$15+4>>2]=0|0;HEAP32[$15+8>>2]=0|0;
      __THREW__ = 0;
      $283 = (invoke_ii(3276,48)|0);
      $284 = __THREW__; __THREW__ = 0;
      $285 = $284&1;
      do {
       if ($285) {
        $425 = ___cxa_find_matching_catch_2()|0;
        $426 = tempRet0;
        $$169 = $425;$$171 = $426;
       } else {
        HEAP32[$15>>2] = $283;
        $286 = ((($15)) + 8|0);
        HEAP32[$286>>2] = -2147483600;
        $287 = ((($15)) + 4|0);
        HEAP32[$287>>2] = 40;
        dest=$283; src=150301; stop=dest+40|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
        $288 = ((($283)) + 40|0);
        HEAP8[$288>>0] = 0;
        __THREW__ = 0;
        (invoke_iiii(3935,($1|0),($14|0),($15|0))|0);
        $289 = __THREW__; __THREW__ = 0;
        $290 = $289&1;
        if ($290) {
         $427 = ___cxa_find_matching_catch_2()|0;
         $428 = tempRet0;
         $429 = ((($15)) + 11|0);
         $430 = HEAP8[$429>>0]|0;
         $431 = ($430<<24>>24)<(0);
         if (!($431)) {
          $$169 = $427;$$171 = $428;
          break;
         }
         $432 = HEAP32[$15>>2]|0;
         __ZdlPv($432);
         $$169 = $427;$$171 = $428;
         break;
        }
        $291 = ((($15)) + 11|0);
        $292 = HEAP8[$291>>0]|0;
        $293 = ($292<<24>>24)<(0);
        if ($293) {
         $294 = HEAP32[$15>>2]|0;
         __ZdlPv($294);
        }
        __ZdlPv($277);
        ;HEAP32[$16>>2]=0|0;HEAP32[$16+4>>2]=0|0;HEAP32[$16+8>>2]=0|0;
        __THREW__ = 0;
        $295 = (invoke_ii(3276,32)|0);
        $296 = __THREW__; __THREW__ = 0;
        $297 = $296&1;
        if ($297) {
         $433 = ___cxa_find_matching_catch_2()|0;
         $434 = tempRet0;
         $$6 = $433;$$676 = $434;
        } else {
         HEAP32[$16>>2] = $295;
         $298 = ((($16)) + 8|0);
         HEAP32[$298>>2] = -2147483616;
         $299 = ((($16)) + 4|0);
         HEAP32[$299>>2] = 18;
         dest=$295; src=150342; stop=dest+18|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
         $300 = ((($295)) + 18|0);
         HEAP8[$300>>0] = 0;
         ;HEAP32[$17>>2]=0|0;HEAP32[$17+4>>2]=0|0;HEAP32[$17+8>>2]=0|0;
         __THREW__ = 0;
         $301 = (invoke_ii(3276,32)|0);
         $302 = __THREW__; __THREW__ = 0;
         $303 = $302&1;
         do {
          if ($303) {
           $435 = ___cxa_find_matching_catch_2()|0;
           $436 = tempRet0;
           $$5 = $435;$$575 = $436;
          } else {
           HEAP32[$17>>2] = $301;
           $304 = ((($17)) + 8|0);
           HEAP32[$304>>2] = -2147483616;
           $305 = ((($17)) + 4|0);
           HEAP32[$305>>2] = 19;
           dest=$301; src=148844; stop=dest+19|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
           $306 = ((($301)) + 19|0);
           HEAP8[$306>>0] = 0;
           ;HEAP32[$18>>2]=0|0;HEAP32[$18+4>>2]=0|0;HEAP32[$18+8>>2]=0|0;
           $307 = ((($18)) + 11|0);
           HEAP8[$307>>0] = 8;
           $308 = $18;
           $309 = $308;
           HEAP32[$309>>2] = 1718185589;
           $310 = (($308) + 4)|0;
           $311 = $310;
           HEAP32[$311>>2] = 544043631;
           $312 = ((($18)) + 8|0);
           HEAP8[$312>>0] = 0;
           ;HEAP32[$19>>2]=0|0;HEAP32[$19+4>>2]=0|0;HEAP32[$19+8>>2]=0|0;
           $313 = ((($19)) + 11|0);
           HEAP8[$313>>0] = 5;
           ;HEAP8[$19>>0]=HEAP8[150361>>0]|0;HEAP8[$19+1>>0]=HEAP8[150361+1>>0]|0;HEAP8[$19+2>>0]=HEAP8[150361+2>>0]|0;HEAP8[$19+3>>0]=HEAP8[150361+3>>0]|0;HEAP8[$19+4>>0]=HEAP8[150361+4>>0]|0;
           $314 = ((($19)) + 5|0);
           HEAP8[$314>>0] = 0;
           __THREW__ = 0;
           invoke_viiiiii(3936,($1|0),($$1|0),($16|0),($17|0),($18|0),($19|0));
           $315 = __THREW__; __THREW__ = 0;
           $316 = $315&1;
           if ($316) {
            $437 = ___cxa_find_matching_catch_2()|0;
            $438 = tempRet0;
            $439 = HEAP8[$313>>0]|0;
            $440 = ($439<<24>>24)<(0);
            if ($440) {
             $441 = HEAP32[$19>>2]|0;
             __ZdlPv($441);
            }
            $442 = HEAP8[$307>>0]|0;
            $443 = ($442<<24>>24)<(0);
            if ($443) {
             $444 = HEAP32[$18>>2]|0;
             __ZdlPv($444);
            }
            $445 = ((($17)) + 11|0);
            $446 = HEAP8[$445>>0]|0;
            $447 = ($446<<24>>24)<(0);
            if (!($447)) {
             $$5 = $437;$$575 = $438;
             break;
            }
            $448 = HEAP32[$17>>2]|0;
            __ZdlPv($448);
            $$5 = $437;$$575 = $438;
            break;
           }
           $317 = HEAP8[$313>>0]|0;
           $318 = ($317<<24>>24)<(0);
           if ($318) {
            $319 = HEAP32[$19>>2]|0;
            __ZdlPv($319);
           }
           $320 = HEAP8[$307>>0]|0;
           $321 = ($320<<24>>24)<(0);
           if ($321) {
            $322 = HEAP32[$18>>2]|0;
            __ZdlPv($322);
           }
           $323 = ((($17)) + 11|0);
           $324 = HEAP8[$323>>0]|0;
           $325 = ($324<<24>>24)<(0);
           if ($325) {
            $326 = HEAP32[$17>>2]|0;
            __ZdlPv($326);
           }
           __ZdlPv($295);
           ;HEAP32[$20>>2]=0|0;HEAP32[$20+4>>2]=0|0;HEAP32[$20+8>>2]=0|0;
           __THREW__ = 0;
           $327 = (invoke_ii(3276,32)|0);
           $328 = __THREW__; __THREW__ = 0;
           $329 = $328&1;
           if ($329) {
            $449 = ___cxa_find_matching_catch_2()|0;
            $450 = tempRet0;
            $$10 = $449;$$1080 = $450;
           } else {
            HEAP32[$20>>2] = $327;
            $330 = ((($20)) + 8|0);
            HEAP32[$330>>2] = -2147483616;
            $331 = ((($20)) + 4|0);
            HEAP32[$331>>2] = 28;
            dest=$327; src=150367; stop=dest+28|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
            $332 = ((($327)) + 28|0);
            HEAP8[$332>>0] = 0;
            ;HEAP32[$21>>2]=0|0;HEAP32[$21+4>>2]=0|0;HEAP32[$21+8>>2]=0|0;
            __THREW__ = 0;
            $333 = (invoke_ii(3276,32)|0);
            $334 = __THREW__; __THREW__ = 0;
            $335 = $334&1;
            do {
             if ($335) {
              $451 = ___cxa_find_matching_catch_2()|0;
              $452 = tempRet0;
              $$9 = $451;$$979 = $452;
             } else {
              HEAP32[$21>>2] = $333;
              $336 = ((($21)) + 8|0);
              HEAP32[$336>>2] = -2147483616;
              $337 = ((($21)) + 4|0);
              HEAP32[$337>>2] = 29;
              dest=$333; src=148885; stop=dest+29|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
              $338 = ((($333)) + 29|0);
              HEAP8[$338>>0] = 0;
              ;HEAP32[$22>>2]=0|0;HEAP32[$22+4>>2]=0|0;HEAP32[$22+8>>2]=0|0;
              $339 = ((($22)) + 11|0);
              HEAP8[$339>>0] = 8;
              $340 = $22;
              $341 = $340;
              HEAP32[$341>>2] = 1718185589;
              $342 = (($340) + 4)|0;
              $343 = $342;
              HEAP32[$343>>2] = 544043631;
              $344 = ((($22)) + 8|0);
              HEAP8[$344>>0] = 0;
              ;HEAP32[$23>>2]=0|0;HEAP32[$23+4>>2]=0|0;HEAP32[$23+8>>2]=0|0;
              $345 = ((($23)) + 11|0);
              HEAP8[$345>>0] = 5;
              ;HEAP8[$23>>0]=HEAP8[150361>>0]|0;HEAP8[$23+1>>0]=HEAP8[150361+1>>0]|0;HEAP8[$23+2>>0]=HEAP8[150361+2>>0]|0;HEAP8[$23+3>>0]=HEAP8[150361+3>>0]|0;HEAP8[$23+4>>0]=HEAP8[150361+4>>0]|0;
              $346 = ((($23)) + 5|0);
              HEAP8[$346>>0] = 0;
              __THREW__ = 0;
              invoke_viiiiii(3936,($1|0),($$1|0),($20|0),($21|0),($22|0),($23|0));
              $347 = __THREW__; __THREW__ = 0;
              $348 = $347&1;
              if ($348) {
               $453 = ___cxa_find_matching_catch_2()|0;
               $454 = tempRet0;
               $455 = HEAP8[$345>>0]|0;
               $456 = ($455<<24>>24)<(0);
               if ($456) {
                $457 = HEAP32[$23>>2]|0;
                __ZdlPv($457);
               }
               $458 = HEAP8[$339>>0]|0;
               $459 = ($458<<24>>24)<(0);
               if ($459) {
                $460 = HEAP32[$22>>2]|0;
                __ZdlPv($460);
               }
               $461 = ((($21)) + 11|0);
               $462 = HEAP8[$461>>0]|0;
               $463 = ($462<<24>>24)<(0);
               if (!($463)) {
                $$9 = $453;$$979 = $454;
                break;
               }
               $464 = HEAP32[$21>>2]|0;
               __ZdlPv($464);
               $$9 = $453;$$979 = $454;
               break;
              }
              $349 = HEAP8[$345>>0]|0;
              $350 = ($349<<24>>24)<(0);
              if ($350) {
               $351 = HEAP32[$23>>2]|0;
               __ZdlPv($351);
              }
              $352 = HEAP8[$339>>0]|0;
              $353 = ($352<<24>>24)<(0);
              if ($353) {
               $354 = HEAP32[$22>>2]|0;
               __ZdlPv($354);
              }
              $355 = ((($21)) + 11|0);
              $356 = HEAP8[$355>>0]|0;
              $357 = ($356<<24>>24)<(0);
              if ($357) {
               $358 = HEAP32[$21>>2]|0;
               __ZdlPv($358);
              }
              __ZdlPv($327);
              ;HEAP32[$24>>2]=0|0;HEAP32[$24+4>>2]=0|0;HEAP32[$24+8>>2]=0|0;
              __THREW__ = 0;
              $359 = (invoke_ii(3276,32)|0);
              $360 = __THREW__; __THREW__ = 0;
              $361 = $360&1;
              if ($361) {
               $465 = ___cxa_find_matching_catch_2()|0;
               $466 = tempRet0;
               $$14 = $465;$$1484 = $466;
              } else {
               HEAP32[$24>>2] = $359;
               $362 = ((($24)) + 8|0);
               HEAP32[$362>>2] = -2147483616;
               $363 = ((($24)) + 4|0);
               HEAP32[$363>>2] = 19;
               dest=$359; src=150396; stop=dest+19|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
               $364 = ((($359)) + 19|0);
               HEAP8[$364>>0] = 0;
               ;HEAP32[$25>>2]=0|0;HEAP32[$25+4>>2]=0|0;HEAP32[$25+8>>2]=0|0;
               __THREW__ = 0;
               $365 = (invoke_ii(3276,32)|0);
               $366 = __THREW__; __THREW__ = 0;
               $367 = $366&1;
               do {
                if ($367) {
                 $467 = ___cxa_find_matching_catch_2()|0;
                 $468 = tempRet0;
                 $$13 = $467;$$1383 = $468;
                } else {
                 HEAP32[$25>>2] = $365;
                 $368 = ((($25)) + 8|0);
                 HEAP32[$368>>2] = -2147483616;
                 $369 = ((($25)) + 4|0);
                 HEAP32[$369>>2] = 20;
                 dest=$365; src=148864; stop=dest+20|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                 $370 = ((($365)) + 20|0);
                 HEAP8[$370>>0] = 0;
                 ;HEAP32[$26>>2]=0|0;HEAP32[$26+4>>2]=0|0;HEAP32[$26+8>>2]=0|0;
                 $371 = ((($26)) + 11|0);
                 HEAP8[$371>>0] = 8;
                 $372 = $26;
                 $373 = $372;
                 HEAP32[$373>>2] = 1718185589;
                 $374 = (($372) + 4)|0;
                 $375 = $374;
                 HEAP32[$375>>2] = 544043631;
                 $376 = ((($26)) + 8|0);
                 HEAP8[$376>>0] = 0;
                 ;HEAP32[$27>>2]=0|0;HEAP32[$27+4>>2]=0|0;HEAP32[$27+8>>2]=0|0;
                 $377 = ((($27)) + 11|0);
                 HEAP8[$377>>0] = 5;
                 ;HEAP8[$27>>0]=HEAP8[150361>>0]|0;HEAP8[$27+1>>0]=HEAP8[150361+1>>0]|0;HEAP8[$27+2>>0]=HEAP8[150361+2>>0]|0;HEAP8[$27+3>>0]=HEAP8[150361+3>>0]|0;HEAP8[$27+4>>0]=HEAP8[150361+4>>0]|0;
                 $378 = ((($27)) + 5|0);
                 HEAP8[$378>>0] = 0;
                 __THREW__ = 0;
                 invoke_viiiiii(3936,($1|0),($$1|0),($24|0),($25|0),($26|0),($27|0));
                 $379 = __THREW__; __THREW__ = 0;
                 $380 = $379&1;
                 if ($380) {
                  $469 = ___cxa_find_matching_catch_2()|0;
                  $470 = tempRet0;
                  $471 = HEAP8[$377>>0]|0;
                  $472 = ($471<<24>>24)<(0);
                  if ($472) {
                   $473 = HEAP32[$27>>2]|0;
                   __ZdlPv($473);
                  }
                  $474 = HEAP8[$371>>0]|0;
                  $475 = ($474<<24>>24)<(0);
                  if ($475) {
                   $476 = HEAP32[$26>>2]|0;
                   __ZdlPv($476);
                  }
                  $477 = ((($25)) + 11|0);
                  $478 = HEAP8[$477>>0]|0;
                  $479 = ($478<<24>>24)<(0);
                  if (!($479)) {
                   $$13 = $469;$$1383 = $470;
                   break;
                  }
                  $480 = HEAP32[$25>>2]|0;
                  __ZdlPv($480);
                  $$13 = $469;$$1383 = $470;
                  break;
                 }
                 $381 = HEAP8[$377>>0]|0;
                 $382 = ($381<<24>>24)<(0);
                 if ($382) {
                  $383 = HEAP32[$27>>2]|0;
                  __ZdlPv($383);
                 }
                 $384 = HEAP8[$371>>0]|0;
                 $385 = ($384<<24>>24)<(0);
                 if ($385) {
                  $386 = HEAP32[$26>>2]|0;
                  __ZdlPv($386);
                 }
                 $387 = ((($25)) + 11|0);
                 $388 = HEAP8[$387>>0]|0;
                 $389 = ($388<<24>>24)<(0);
                 if ($389) {
                  $390 = HEAP32[$25>>2]|0;
                  __ZdlPv($390);
                 }
                 __ZdlPv($359);
                 ;HEAP32[$28>>2]=0|0;HEAP32[$28+4>>2]=0|0;HEAP32[$28+8>>2]=0|0;
                 __THREW__ = 0;
                 $391 = (invoke_ii(3276,16)|0);
                 $392 = __THREW__; __THREW__ = 0;
                 $393 = $392&1;
                 if ($393) {
                  $481 = ___cxa_find_matching_catch_2()|0;
                  $482 = tempRet0;
                  $$18 = $481;$$1888 = $482;
                 } else {
                  HEAP32[$28>>2] = $391;
                  $394 = ((($28)) + 8|0);
                  HEAP32[$394>>2] = -2147483632;
                  $395 = ((($28)) + 4|0);
                  HEAP32[$395>>2] = 15;
                  dest=$391; src=150416; stop=dest+15|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                  $396 = ((($391)) + 15|0);
                  HEAP8[$396>>0] = 0;
                  ;HEAP32[$29>>2]=0|0;HEAP32[$29+4>>2]=0|0;HEAP32[$29+8>>2]=0|0;
                  __THREW__ = 0;
                  $397 = (invoke_ii(3276,32)|0);
                  $398 = __THREW__; __THREW__ = 0;
                  $399 = $398&1;
                  do {
                   if ($399) {
                    $483 = ___cxa_find_matching_catch_2()|0;
                    $484 = tempRet0;
                    $$17 = $483;$$1787 = $484;
                   } else {
                    HEAP32[$29>>2] = $397;
                    $400 = ((($29)) + 8|0);
                    HEAP32[$400>>2] = -2147483616;
                    $401 = ((($29)) + 4|0);
                    HEAP32[$401>>2] = 16;
                    dest=$397; src=148915; stop=dest+16|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                    $402 = ((($397)) + 16|0);
                    HEAP8[$402>>0] = 0;
                    ;HEAP32[$30>>2]=0|0;HEAP32[$30+4>>2]=0|0;HEAP32[$30+8>>2]=0|0;
                    $403 = ((($30)) + 11|0);
                    HEAP8[$403>>0] = 8;
                    $404 = $30;
                    $405 = $404;
                    HEAP32[$405>>2] = 1718185589;
                    $406 = (($404) + 4)|0;
                    $407 = $406;
                    HEAP32[$407>>2] = 544043631;
                    $408 = ((($30)) + 8|0);
                    HEAP8[$408>>0] = 0;
                    ;HEAP32[$31>>2]=0|0;HEAP32[$31+4>>2]=0|0;HEAP32[$31+8>>2]=0|0;
                    $409 = ((($31)) + 11|0);
                    HEAP8[$409>>0] = 5;
                    ;HEAP8[$31>>0]=HEAP8[150432>>0]|0;HEAP8[$31+1>>0]=HEAP8[150432+1>>0]|0;HEAP8[$31+2>>0]=HEAP8[150432+2>>0]|0;HEAP8[$31+3>>0]=HEAP8[150432+3>>0]|0;HEAP8[$31+4>>0]=HEAP8[150432+4>>0]|0;
                    $410 = ((($31)) + 5|0);
                    HEAP8[$410>>0] = 0;
                    __THREW__ = 0;
                    invoke_viiiiii(3936,($1|0),($$1|0),($28|0),($29|0),($30|0),($31|0));
                    $411 = __THREW__; __THREW__ = 0;
                    $412 = $411&1;
                    if ($412) {
                     $485 = ___cxa_find_matching_catch_2()|0;
                     $486 = tempRet0;
                     $487 = HEAP8[$409>>0]|0;
                     $488 = ($487<<24>>24)<(0);
                     if ($488) {
                      $489 = HEAP32[$31>>2]|0;
                      __ZdlPv($489);
                     }
                     $490 = HEAP8[$403>>0]|0;
                     $491 = ($490<<24>>24)<(0);
                     if ($491) {
                      $492 = HEAP32[$30>>2]|0;
                      __ZdlPv($492);
                     }
                     $493 = ((($29)) + 11|0);
                     $494 = HEAP8[$493>>0]|0;
                     $495 = ($494<<24>>24)<(0);
                     if (!($495)) {
                      $$17 = $485;$$1787 = $486;
                      break;
                     }
                     $496 = HEAP32[$29>>2]|0;
                     __ZdlPv($496);
                     $$17 = $485;$$1787 = $486;
                     break;
                    }
                    $413 = HEAP8[$409>>0]|0;
                    $414 = ($413<<24>>24)<(0);
                    if ($414) {
                     $415 = HEAP32[$31>>2]|0;
                     __ZdlPv($415);
                    }
                    $416 = HEAP8[$403>>0]|0;
                    $417 = ($416<<24>>24)<(0);
                    if ($417) {
                     $418 = HEAP32[$30>>2]|0;
                     __ZdlPv($418);
                    }
                    $419 = ((($29)) + 11|0);
                    $420 = HEAP8[$419>>0]|0;
                    $421 = ($420<<24>>24)<(0);
                    if ($421) {
                     $422 = HEAP32[$29>>2]|0;
                     __ZdlPv($422);
                    }
                    __ZdlPv($391);
                    break L123;
                   }
                  } while(0);
                  __ZdlPv($391);
                  $$18 = $$17;$$1888 = $$1787;
                 }
                 $$20 = $$18;$$2090 = $$1888;
                 break L103;
                }
               } while(0);
               __ZdlPv($359);
               $$14 = $$13;$$1484 = $$1383;
              }
              $$20 = $$14;$$2090 = $$1484;
              break L103;
             }
            } while(0);
            __ZdlPv($327);
            $$10 = $$9;$$1080 = $$979;
           }
           $$20 = $$10;$$2090 = $$1080;
           break L103;
          }
         } while(0);
         __ZdlPv($295);
         $$6 = $$5;$$676 = $$575;
        }
        $$20 = $$6;$$2090 = $$676;
        break L103;
       }
      } while(0);
      __ZdlPv($277);
      $$2 = $$169;$$272 = $$171;
     }
     $$20 = $$2;$$2090 = $$272;
     break L103;
    }
   } while(0);
   $497 = ((($0)) + 348|0);
   $498 = HEAP8[$497>>0]|0;
   $499 = ($498<<24>>24)==(0);
   L249: do {
    if ($499) {
     label = 187;
    } else {
     $500 = ((($0)) + 356|0);
     $501 = ((($0)) + 368|0);
     $502 = ((($0)) + 380|0);
     __THREW__ = 0;
     invoke_viiiiii(3936,($1|0),($$1|0),($500|0),($501|0),($10|0),($502|0));
     $503 = __THREW__; __THREW__ = 0;
     $504 = $503&1;
     if ($504) {
      label = 182;
     } else {
      $505 = ((($0)) + 396|0);
      $506 = ((($0)) + 408|0);
      $507 = ((($0)) + 420|0);
      __THREW__ = 0;
      invoke_viiiiii(3936,($1|0),($$1|0),($505|0),($506|0),($10|0),($507|0));
      $508 = __THREW__; __THREW__ = 0;
      $509 = $508&1;
      if ($509) {
       label = 182;
      } else {
       $510 = ((($0)) + 436|0);
       $511 = ((($0)) + 448|0);
       $512 = ((($0)) + 460|0);
       __THREW__ = 0;
       invoke_viiiiii(3936,($1|0),($$1|0),($510|0),($511|0),($10|0),($512|0));
       $513 = __THREW__; __THREW__ = 0;
       $514 = $513&1;
       if ($514) {
        label = 182;
       } else {
        $515 = ((($0)) + 476|0);
        $516 = ((($0)) + 488|0);
        $517 = ((($0)) + 500|0);
        __THREW__ = 0;
        invoke_viiiiii(3936,($1|0),($$1|0),($515|0),($516|0),($10|0),($517|0));
        $518 = __THREW__; __THREW__ = 0;
        $519 = $518&1;
        if ($519) {
         label = 182;
        } else {
         $520 = ((($0)) + 516|0);
         $521 = ((($0)) + 528|0);
         $522 = ((($0)) + 540|0);
         __THREW__ = 0;
         invoke_viiiiii(3936,($1|0),($$1|0),($520|0),($521|0),($10|0),($522|0));
         $523 = __THREW__; __THREW__ = 0;
         $524 = $523&1;
         if ($524) {
          label = 182;
         } else {
          $525 = ((($0)) + 552|0);
          $526 = ((($0)) + 556|0);
          $527 = HEAP32[$526>>2]|0;
          $528 = HEAP32[$525>>2]|0;
          $529 = ($527|0)==($528|0);
          if ($529) {
           label = 187;
          } else {
           $$067319 = 0;$$in = $528;
           while(1) {
            $532 = $$in;
            $533 = (((($532) + (($$067319*40)|0)|0)) + 4|0);
            $534 = (((($532) + (($$067319*40)|0)|0)) + 16|0);
            $535 = (((($532) + (($$067319*40)|0)|0)) + 28|0);
            __THREW__ = 0;
            invoke_viiiiii(3936,($1|0),($$1|0),($533|0),($534|0),($10|0),($535|0));
            $536 = __THREW__; __THREW__ = 0;
            $537 = $536&1;
            if ($537) {
             break;
            }
            $538 = (($$067319) + 1)|0;
            $539 = HEAP32[$526>>2]|0;
            $540 = HEAP32[$525>>2]|0;
            $541 = (($539) - ($540))|0;
            $542 = (($541|0) / 40)&-1;
            $543 = ($538>>>0)<($542>>>0);
            if ($543) {
             $$067319 = $538;$$in = $540;
            } else {
             label = 187;
             break L249;
            }
           }
           $544 = ___cxa_find_matching_catch_2()|0;
           $545 = tempRet0;
           $$20 = $544;$$2090 = $545;
           break L103;
          }
         }
        }
       }
      }
     }
    }
   } while(0);
   L260: do {
    if ((label|0) == 187) {
     __THREW__ = 0;
     $546 = (invoke_ii(3265,4)|0);
     $547 = __THREW__; __THREW__ = 0;
     $548 = $547&1;
     if ($548) {
      label = 182;
     } else {
      L263: do {
       if ($546) {
        __THREW__ = 0;
        $549 = (invoke_ii(3266,4)|0);
        $550 = __THREW__; __THREW__ = 0;
        $551 = $550&1;
        if ($551) {
         label = 182;
         break L260;
        }
        __THREW__ = 0;
        $552 = (invoke_iiii(3267,($549|0),(150438|0),26)|0);
        $553 = __THREW__; __THREW__ = 0;
        $554 = $553&1;
        if ($554) {
         label = 182;
         break L260;
        }
        $555 = HEAP32[$552>>2]|0;
        $556 = ((($555)) + -12|0);
        $557 = HEAP32[$556>>2]|0;
        $558 = (($552) + ($557)|0);
        __THREW__ = 0;
        invoke_vii(3257,($4|0),($558|0));
        $559 = __THREW__; __THREW__ = 0;
        $560 = $559&1;
        if ($560) {
         label = 182;
         break L260;
        }
        __THREW__ = 0;
        $561 = (invoke_iii(3255,($4|0),(215188|0))|0);
        $562 = __THREW__; __THREW__ = 0;
        $563 = $562&1;
        if (!($563)) {
         $564 = HEAP32[$561>>2]|0;
         $565 = ((($564)) + 28|0);
         $566 = HEAP32[$565>>2]|0;
         __THREW__ = 0;
         $567 = (invoke_iii($566|0,($561|0),10)|0);
         $568 = __THREW__; __THREW__ = 0;
         $569 = $568&1;
         if (!($569)) {
          __THREW__ = 0;
          invoke_vi(3263,($4|0));
          $576 = __THREW__; __THREW__ = 0;
          $577 = $576&1;
          if ($577) {
           label = 182;
           break L260;
          }
          __THREW__ = 0;
          (invoke_iii(3268,($552|0),($567|0))|0);
          $578 = __THREW__; __THREW__ = 0;
          $579 = $578&1;
          if ($579) {
           label = 182;
           break L260;
          }
          __THREW__ = 0;
          (invoke_ii(3269,($552|0))|0);
          $580 = __THREW__; __THREW__ = 0;
          $581 = $580&1;
          if ($581) {
           label = 182;
           break L260;
          }
          $582 = HEAP8[$$pre$phi329Z2D>>0]|0;
          $583 = ($582<<24>>24)<(0);
          $584 = HEAP32[$$pre$phi331Z2D>>2]|0;
          $585 = $583 ? $584 : $$pre$phi335Z2D;
          $586 = HEAP32[$$pre$phi333Z2D>>2]|0;
          $587 = $582&255;
          $588 = $583 ? $586 : $587;
          __THREW__ = 0;
          $589 = (invoke_iiii(3267,($552|0),($585|0),($588|0))|0);
          $590 = __THREW__; __THREW__ = 0;
          $591 = $590&1;
          if ($591) {
           label = 182;
           break L260;
          }
          $592 = HEAP32[$589>>2]|0;
          $593 = ((($592)) + -12|0);
          $594 = HEAP32[$593>>2]|0;
          $595 = (($589) + ($594)|0);
          __THREW__ = 0;
          invoke_vii(3257,($3|0),($595|0));
          $596 = __THREW__; __THREW__ = 0;
          $597 = $596&1;
          if ($597) {
           label = 182;
           break L260;
          }
          __THREW__ = 0;
          $598 = (invoke_iii(3255,($3|0),(215188|0))|0);
          $599 = __THREW__; __THREW__ = 0;
          $600 = $599&1;
          do {
           if (!($600)) {
            $601 = HEAP32[$598>>2]|0;
            $602 = ((($601)) + 28|0);
            $603 = HEAP32[$602>>2]|0;
            __THREW__ = 0;
            $604 = (invoke_iii($603|0,($598|0),10)|0);
            $605 = __THREW__; __THREW__ = 0;
            $606 = $605&1;
            if ($606) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3263,($3|0));
            $613 = __THREW__; __THREW__ = 0;
            $614 = $613&1;
            if ($614) {
             label = 182;
             break L260;
            }
            __THREW__ = 0;
            (invoke_iii(3268,($589|0),($604|0))|0);
            $615 = __THREW__; __THREW__ = 0;
            $616 = $615&1;
            if ($616) {
             label = 182;
             break L260;
            }
            __THREW__ = 0;
            (invoke_ii(3269,($589|0))|0);
            $617 = __THREW__; __THREW__ = 0;
            $618 = $617&1;
            if ($618) {
             label = 182;
             break L260;
            }
            __THREW__ = 0;
            $619 = (invoke_iiii(3267,($589|0),(150465|0),16)|0);
            $620 = __THREW__; __THREW__ = 0;
            $621 = $620&1;
            if ($621) {
             label = 182;
             break L260;
            }
            $622 = HEAP32[$619>>2]|0;
            $623 = ((($622)) + -12|0);
            $624 = HEAP32[$623>>2]|0;
            $625 = (($619) + ($624)|0);
            __THREW__ = 0;
            invoke_vii(3257,($2|0),($625|0));
            $626 = __THREW__; __THREW__ = 0;
            $627 = $626&1;
            if ($627) {
             label = 182;
             break L260;
            }
            __THREW__ = 0;
            $628 = (invoke_iii(3255,($2|0),(215188|0))|0);
            $629 = __THREW__; __THREW__ = 0;
            $630 = $629&1;
            do {
             if (!($630)) {
              $631 = HEAP32[$628>>2]|0;
              $632 = ((($631)) + 28|0);
              $633 = HEAP32[$632>>2]|0;
              __THREW__ = 0;
              $634 = (invoke_iii($633|0,($628|0),10)|0);
              $635 = __THREW__; __THREW__ = 0;
              $636 = $635&1;
              if ($636) {
               break;
              }
              __THREW__ = 0;
              invoke_vi(3263,($2|0));
              $643 = __THREW__; __THREW__ = 0;
              $644 = $643&1;
              if ($644) {
               label = 182;
               break L260;
              }
              __THREW__ = 0;
              (invoke_iii(3268,($619|0),($634|0))|0);
              $645 = __THREW__; __THREW__ = 0;
              $646 = $645&1;
              if ($646) {
               label = 182;
               break L260;
              }
              __THREW__ = 0;
              (invoke_ii(3269,($619|0))|0);
              $647 = __THREW__; __THREW__ = 0;
              $648 = $647&1;
              if ($648) {
               label = 182;
               break L260;
              } else {
               break L263;
              }
             }
            } while(0);
            $637 = ___cxa_find_matching_catch_2()|0;
            $638 = tempRet0;
            __THREW__ = 0;
            invoke_vi(3263,($2|0));
            $639 = __THREW__; __THREW__ = 0;
            $640 = $639&1;
            if ($640) {
             $641 = ___cxa_find_matching_catch_3(0|0)|0;
             $642 = tempRet0;
             ___clang_call_terminate($641);
             // unreachable;
            } else {
             $eh$lpad$body281$index9Z2D = $638;$eh$lpad$body281$indexZ2D = $637;
             break L260;
            }
           }
          } while(0);
          $607 = ___cxa_find_matching_catch_2()|0;
          $608 = tempRet0;
          __THREW__ = 0;
          invoke_vi(3263,($3|0));
          $609 = __THREW__; __THREW__ = 0;
          $610 = $609&1;
          if ($610) {
           $611 = ___cxa_find_matching_catch_3(0|0)|0;
           $612 = tempRet0;
           ___clang_call_terminate($611);
           // unreachable;
          } else {
           $eh$lpad$body281$index9Z2D = $608;$eh$lpad$body281$indexZ2D = $607;
           break L260;
          }
         }
        }
        $570 = ___cxa_find_matching_catch_2()|0;
        $571 = tempRet0;
        __THREW__ = 0;
        invoke_vi(3263,($4|0));
        $572 = __THREW__; __THREW__ = 0;
        $573 = $572&1;
        if ($573) {
         $574 = ___cxa_find_matching_catch_3(0|0)|0;
         $575 = tempRet0;
         ___clang_call_terminate($574);
         // unreachable;
        } else {
         $eh$lpad$body281$index9Z2D = $571;$eh$lpad$body281$indexZ2D = $570;
         break L260;
        }
       }
      } while(0);
      $649 = HEAP8[$125>>0]|0;
      $650 = ($649<<24>>24)<(0);
      if (!($650)) {
       STACKTOP = sp;return 1;
      }
      $651 = HEAP32[$10>>2]|0;
      __ZdlPv($651);
      STACKTOP = sp;return 1;
     }
    }
   } while(0);
   if ((label|0) == 182) {
    $530 = ___cxa_find_matching_catch_2()|0;
    $531 = tempRet0;
    $eh$lpad$body281$index9Z2D = $531;$eh$lpad$body281$indexZ2D = $530;
   }
   $$20 = $eh$lpad$body281$indexZ2D;$$2090 = $eh$lpad$body281$index9Z2D;
  }
 } while(0);
 $652 = HEAP8[$125>>0]|0;
 $653 = ($652<<24>>24)<(0);
 if (!($653)) {
  ___resumeException($$20|0);
  // unreachable;
 }
 $654 = HEAP32[$10>>2]|0;
 __ZdlPv($654);
 ___resumeException($$20|0);
 // unreachable;
 return (0)|0;
}
function __ZN3osg5State9drawQuadsEiii($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0101 = 0, $$087100 = 0, $$pre = 0, $$pre103 = 0, $$pre104 = 0, $$pre105 = 0, $$pre106 = 0, $$pre107 = 0, $$pre108 = 0, $$pre109 = 0, $$pre110 = 0, $$pre111 = 0, $$pre112 = 0, $$pre113 = 0, $$pre114 = 0, $$pre115 = 0, $$pre116 = 0, $$pre117 = 0, $$pre118 = 0, $$pre119 = 0;
 var $$pre120 = 0, $$pre121 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $4 = sp + 34|0;
 $5 = sp + 32|0;
 $6 = sp + 30|0;
 $7 = sp + 28|0;
 $8 = sp + 26|0;
 $9 = sp + 24|0;
 $10 = sp + 20|0;
 $11 = sp + 16|0;
 $12 = sp + 12|0;
 $13 = sp + 8|0;
 $14 = sp + 4|0;
 $15 = sp;
 $16 = (($1|0) % 4)&-1;
 $17 = (($1) - ($16))|0;
 $18 = $17 >>> 2;
 $19 = ($18*6)|0;
 $20 = (($2|0) / 4)&-1;
 $21 = ($20*6)|0;
 $22 = (($19) + ($21))|0;
 $23 = ($22>>>0)<(65536);
 if ($23) {
  $24 = (((($0)) + 24|0) + (($16*12)|0)|0);
  $25 = (((((($0)) + 24|0) + (($16*12)|0)|0)) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = HEAP32[$24>>2]|0;
  $28 = (($26) - ($27))|0;
  $29 = $28 >> 1;
  $30 = ($22>>>0)<($29>>>0);
  if (!($30)) {
   $31 = (($29>>>0) / 6)&-1;
   $32 = (($22>>>0) / 6)&-1;
   __ZNSt3__26vectorItNS_9allocatorItEEE7reserveEj($24,$22);
   $33 = ($31>>>0)<($32>>>0);
   if ($33) {
    $34 = (((((($0)) + 24|0) + (($16*12)|0)|0)) + 8|0);
    $$087100 = $31;
    while(1) {
     $35 = $$087100 << 2;
     $36 = (($35) + ($16))|0;
     $37 = $36&65535;
     HEAP16[$4>>1] = $37;
     $38 = HEAP32[$25>>2]|0;
     $39 = HEAP32[$34>>2]|0;
     $40 = ($38|0)==($39|0);
     if ($40) {
      __ZNSt3__26vectorItNS_9allocatorItEEE21__push_back_slow_pathIKtEEvRT_($24,$4);
      $$pre112 = HEAP32[$25>>2]|0;
      $$pre113 = HEAP32[$34>>2]|0;
      $44 = $$pre112;$46 = $$pre113;
     } else {
      HEAP16[$38>>1] = $37;
      $41 = ((($38)) + 2|0);
      HEAP32[$25>>2] = $41;
      $44 = $41;$46 = $39;
     }
     $42 = (($36) + 1)|0;
     $43 = $42&65535;
     HEAP16[$5>>1] = $43;
     $45 = ($44|0)==($46|0);
     if ($45) {
      __ZNSt3__26vectorItNS_9allocatorItEEE21__push_back_slow_pathIKtEEvRT_($24,$5);
      $$pre114 = HEAP32[$25>>2]|0;
      $$pre115 = HEAP32[$34>>2]|0;
      $50 = $$pre114;$52 = $$pre115;
     } else {
      HEAP16[$44>>1] = $43;
      $47 = ((($44)) + 2|0);
      HEAP32[$25>>2] = $47;
      $50 = $47;$52 = $46;
     }
     $48 = (($36) + 3)|0;
     $49 = $48&65535;
     HEAP16[$6>>1] = $49;
     $51 = ($50|0)==($52|0);
     if ($51) {
      __ZNSt3__26vectorItNS_9allocatorItEEE21__push_back_slow_pathIKtEEvRT_($24,$6);
      $$pre116 = HEAP32[$25>>2]|0;
      $$pre117 = HEAP32[$34>>2]|0;
      $54 = $$pre116;$56 = $$pre117;
     } else {
      HEAP16[$50>>1] = $49;
      $53 = ((($50)) + 2|0);
      HEAP32[$25>>2] = $53;
      $54 = $53;$56 = $52;
     }
     HEAP16[$7>>1] = $43;
     $55 = ($54|0)==($56|0);
     if ($55) {
      __ZNSt3__26vectorItNS_9allocatorItEEE21__push_back_slow_pathIKtEEvRT_($24,$7);
      $$pre118 = HEAP32[$25>>2]|0;
      $$pre119 = HEAP32[$34>>2]|0;
      $60 = $$pre118;$62 = $$pre119;
     } else {
      HEAP16[$54>>1] = $43;
      $57 = ((($54)) + 2|0);
      HEAP32[$25>>2] = $57;
      $60 = $57;$62 = $56;
     }
     $58 = (($36) + 2)|0;
     $59 = $58&65535;
     HEAP16[$8>>1] = $59;
     $61 = ($60|0)==($62|0);
     if ($61) {
      __ZNSt3__26vectorItNS_9allocatorItEEE21__push_back_slow_pathIKtEEvRT_($24,$8);
      $$pre120 = HEAP32[$25>>2]|0;
      $$pre121 = HEAP32[$34>>2]|0;
      $64 = $$pre120;$66 = $$pre121;
     } else {
      HEAP16[$60>>1] = $59;
      $63 = ((($60)) + 2|0);
      HEAP32[$25>>2] = $63;
      $64 = $63;$66 = $62;
     }
     HEAP16[$9>>1] = $49;
     $65 = ($64|0)==($66|0);
     if ($65) {
      __ZNSt3__26vectorItNS_9allocatorItEEE21__push_back_slow_pathIKtEEvRT_($24,$9);
     } else {
      HEAP16[$64>>1] = $49;
      $67 = ((($64)) + 2|0);
      HEAP32[$25>>2] = $67;
     }
     $68 = (($$087100) + 1)|0;
     $69 = ($68>>>0)<($32>>>0);
     if ($69) {
      $$087100 = $68;
     } else {
      break;
     }
    }
   }
  }
  $70 = HEAP32[$24>>2]|0;
  $71 = (($70) + ($19<<1)|0);
  $72 = ($3|0)>(0);
  if ($72) {
   $73 = ((($0)) + 780|0);
   $74 = HEAP32[$73>>2]|0;
   $75 = ($74|0)==(0|0);
   if (!($75)) {
    FUNCTION_TABLE_viiiii[$74 & 8191](4,$21,5123,$71,$3);
    STACKTOP = sp;return;
   }
  }
  _glDrawElements(4,($21|0),5123,($71|0));
  STACKTOP = sp;return;
 } else {
  $76 = (((($0)) + 72|0) + (($16*12)|0)|0);
  $77 = (((((($0)) + 72|0) + (($16*12)|0)|0)) + 4|0);
  $78 = HEAP32[$77>>2]|0;
  $79 = HEAP32[$76>>2]|0;
  $80 = (($78) - ($79))|0;
  $81 = $80 >> 2;
  $82 = ($22>>>0)<($81>>>0);
  if (!($82)) {
   $83 = (($81>>>0) / 6)&-1;
   $84 = (($22>>>0) / 6)&-1;
   __ZNSt3__26vectorIjNS_9allocatorIjEEE7reserveEj($76,$22);
   $85 = ($83>>>0)<($84>>>0);
   if ($85) {
    $86 = (((((($0)) + 72|0) + (($16*12)|0)|0)) + 8|0);
    $$0101 = $83;
    while(1) {
     $87 = $$0101 << 2;
     $88 = (($87) + ($16))|0;
     HEAP32[$10>>2] = $88;
     $89 = HEAP32[$77>>2]|0;
     $90 = HEAP32[$86>>2]|0;
     $91 = ($89|0)==($90|0);
     if ($91) {
      __ZNSt3__26vectorIjNS_9allocatorIjEEE21__push_back_slow_pathIKjEEvRT_($76,$10);
      $$pre = HEAP32[$77>>2]|0;
      $$pre103 = HEAP32[$86>>2]|0;
      $95 = $$pre;$97 = $$pre103;
     } else {
      HEAP32[$89>>2] = $88;
      $92 = ((($89)) + 4|0);
      HEAP32[$77>>2] = $92;
      $95 = $92;$97 = $90;
     }
     $93 = HEAP32[$10>>2]|0;
     $94 = (($93) + 1)|0;
     HEAP32[$11>>2] = $94;
     $96 = ($95|0)==($97|0);
     if ($96) {
      __ZNSt3__26vectorIjNS_9allocatorIjEEE21__push_back_slow_pathIKjEEvRT_($76,$11);
      $$pre104 = HEAP32[$77>>2]|0;
      $$pre105 = HEAP32[$86>>2]|0;
      $101 = $$pre104;$103 = $$pre105;
     } else {
      HEAP32[$95>>2] = $94;
      $98 = ((($95)) + 4|0);
      HEAP32[$77>>2] = $98;
      $101 = $98;$103 = $97;
     }
     $99 = HEAP32[$10>>2]|0;
     $100 = (($99) + 3)|0;
     HEAP32[$12>>2] = $100;
     $102 = ($101|0)==($103|0);
     if ($102) {
      __ZNSt3__26vectorIjNS_9allocatorIjEEE21__push_back_slow_pathIKjEEvRT_($76,$12);
      $$pre106 = HEAP32[$77>>2]|0;
      $$pre107 = HEAP32[$86>>2]|0;
      $107 = $$pre106;$109 = $$pre107;
     } else {
      HEAP32[$101>>2] = $100;
      $104 = ((($101)) + 4|0);
      HEAP32[$77>>2] = $104;
      $107 = $104;$109 = $103;
     }
     $105 = HEAP32[$10>>2]|0;
     $106 = (($105) + 1)|0;
     HEAP32[$13>>2] = $106;
     $108 = ($107|0)==($109|0);
     if ($108) {
      __ZNSt3__26vectorIjNS_9allocatorIjEEE21__push_back_slow_pathIKjEEvRT_($76,$13);
      $$pre108 = HEAP32[$77>>2]|0;
      $$pre109 = HEAP32[$86>>2]|0;
      $113 = $$pre108;$115 = $$pre109;
     } else {
      HEAP32[$107>>2] = $106;
      $110 = ((($107)) + 4|0);
      HEAP32[$77>>2] = $110;
      $113 = $110;$115 = $109;
     }
     $111 = HEAP32[$10>>2]|0;
     $112 = (($111) + 2)|0;
     HEAP32[$14>>2] = $112;
     $114 = ($113|0)==($115|0);
     if ($114) {
      __ZNSt3__26vectorIjNS_9allocatorIjEEE21__push_back_slow_pathIKjEEvRT_($76,$14);
      $$pre110 = HEAP32[$77>>2]|0;
      $$pre111 = HEAP32[$86>>2]|0;
      $119 = $$pre110;$121 = $$pre111;
     } else {
      HEAP32[$113>>2] = $112;
      $116 = ((($113)) + 4|0);
      HEAP32[$77>>2] = $116;
      $119 = $116;$121 = $115;
     }
     $117 = HEAP32[$10>>2]|0;
     $118 = (($117) + 3)|0;
     HEAP32[$15>>2] = $118;
     $120 = ($119|0)==($121|0);
     if ($120) {
      __ZNSt3__26vectorIjNS_9allocatorIjEEE21__push_back_slow_pathIKjEEvRT_($76,$15);
     } else {
      HEAP32[$119>>2] = $118;
      $122 = ((($119)) + 4|0);
      HEAP32[$77>>2] = $122;
     }
     $123 = (($$0101) + 1)|0;
     $124 = ($123>>>0)<($84>>>0);
     if ($124) {
      $$0101 = $123;
     } else {
      break;
     }
    }
   }
  }
  $125 = HEAP32[$76>>2]|0;
  $126 = (($125) + ($19<<2)|0);
  $127 = ($3|0)>(0);
  if ($127) {
   $128 = ((($0)) + 780|0);
   $129 = HEAP32[$128>>2]|0;
   $130 = ($129|0)==(0|0);
   if (!($130)) {
    FUNCTION_TABLE_viiiii[$129 & 8191](4,$21,5125,$126,$3);
    STACKTOP = sp;return;
   }
  }
  _glDrawElements(4,($21|0),5125,($126|0));
  STACKTOP = sp;return;
 }
}
function __ZN3osg5State9DefineMap20updateCurrentDefinesEv($0) {
 $0 = $0|0;
 var $$0$i$i$i$i = 0, $$0$i$i$i$sink$be = 0, $$0$i$i$i$sink20 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 16|0);
 $2 = ((($0)) + 20|0);
 $3 = HEAP32[$2>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4pairIS7_jEEEENS_19__map_value_compareIS7_SA_NS_4lessIS7_EELb1EEENS5_ISA_EEE7destroyEPNS_11__tree_nodeISA_PvEE($1,$3);
 $4 = ((($0)) + 24|0);
 HEAP32[$4>>2] = 0;
 HEAP32[$1>>2] = $2;
 HEAP32[$2>>2] = 0;
 $5 = HEAP32[$0>>2]|0;
 $6 = ((($0)) + 4|0);
 $7 = ($5|0)==($6|0);
 if ($7) {
  $8 = ((($0)) + 12|0);
  HEAP8[$8>>0] = 0;
  return 1;
 } else {
  $$0$i$i$i$sink20 = $5;
 }
 while(1) {
  $9 = ((($$0$i$i$i$sink20)) + 16|0);
  $10 = ((($$0$i$i$i$sink20)) + 32|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ((($$0$i$i$i$sink20)) + 36|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($11|0)==($13|0);
  if (!($14)) {
   $15 = ((($13)) + -4|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = $16 & 1;
   $18 = ($17|0)==(0);
   if (!($18)) {
    $19 = (__ZNSt3__23mapINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4pairIS6_jEENS_4lessIS6_EENS4_INS7_IKS6_S8_EEEEEixERSB_($1,$9)|0);
    $20 = ((($13)) + -16|0);
    (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEaSERKS5_($19,$20)|0);
    $21 = HEAP32[$15>>2]|0;
    $22 = ((($19)) + 12|0);
    HEAP32[$22>>2] = $21;
   }
  }
  $23 = ((($$0$i$i$i$sink20)) + 4|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = ($24|0)==(0|0);
  if ($25) {
   $26 = ((($$0$i$i$i$sink20)) + 8|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = HEAP32[$27>>2]|0;
   $29 = ($28|0)==($$0$i$i$i$sink20|0);
   if ($29) {
    $$0$i$i$i$sink$be = $27;
   } else {
    $34 = $26;
    while(1) {
     $33 = HEAP32[$34>>2]|0;
     $35 = ((($33)) + 8|0);
     $36 = HEAP32[$35>>2]|0;
     $37 = HEAP32[$36>>2]|0;
     $38 = ($37|0)==($33|0);
     if ($38) {
      $$0$i$i$i$sink$be = $36;
      break;
     } else {
      $34 = $35;
     }
    }
   }
  } else {
   $$0$i$i$i$i = $24;
   while(1) {
    $31 = HEAP32[$$0$i$i$i$i>>2]|0;
    $32 = ($31|0)==(0|0);
    if ($32) {
     break;
    } else {
     $$0$i$i$i$i = $31;
    }
   }
   $$0$i$i$i$sink$be = $$0$i$i$i$i;
  }
  $30 = ($$0$i$i$i$sink$be|0)==($6|0);
  if ($30) {
   break;
  } else {
   $$0$i$i$i$sink20 = $$0$i$i$i$sink$be;
  }
 }
 $8 = ((($0)) + 12|0);
 HEAP8[$8>>0] = 0;
 return 1;
}
function __ZNSt3__23mapINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4pairIS6_jEENS_4lessIS6_EENS4_INS7_IKS6_S8_EEEEEixERSB_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$014 = 0, $$pre$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = (__ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4pairIS7_jEEEENS_19__map_value_compareIS7_SA_NS_4lessIS7_EELb1EEENS5_ISA_EEE12__find_equalIS7_EERPNS_16__tree_node_baseIPvEERPNS_15__tree_end_nodeISL_EERKT_($0,$2,$1)|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if (!($5)) {
  $$014 = $4;
  $26 = ((($$014)) + 28|0);
  STACKTOP = sp;return ($26|0);
 }
 $6 = (__Znwj(44)|0);
 $7 = ((($6)) + 16|0);
 __THREW__ = 0;
 invoke_vii(3457,($7|0),($1|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $10 = ___cxa_find_matching_catch_2()|0;
  $11 = tempRet0;
  __ZdlPv($6);
  ___resumeException($10|0);
  // unreachable;
 }
 $12 = ((($6)) + 28|0);
 ;HEAP32[$12>>2]=0|0;HEAP32[$12+4>>2]=0|0;HEAP32[$12+8>>2]=0|0;HEAP32[$12+12>>2]=0|0;
 $13 = HEAP32[$2>>2]|0;
 HEAP32[$6>>2] = 0;
 $14 = ((($6)) + 4|0);
 HEAP32[$14>>2] = 0;
 $15 = ((($6)) + 8|0);
 HEAP32[$15>>2] = $13;
 HEAP32[$3>>2] = $6;
 $16 = HEAP32[$0>>2]|0;
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==(0|0);
 if ($18) {
  $22 = $6;
 } else {
  $19 = $17;
  HEAP32[$0>>2] = $19;
  $$pre$i = HEAP32[$3>>2]|0;
  $22 = $$pre$i;
 }
 $20 = ((($0)) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($21,$22);
 $23 = ((($0)) + 8|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (($24) + 1)|0;
 HEAP32[$23>>2] = $25;
 $$014 = $6;
 $26 = ((($$014)) + 28|0);
 STACKTOP = sp;return ($26|0);
}
function __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4pairIS7_jEEEENS_19__map_value_compareIS7_SA_NS_4lessIS7_EELb1EEENS5_ISA_EEE12__find_equalIS7_EERPNS_16__tree_node_baseIPvEERPNS_15__tree_end_nodeISL_EERKT_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$0$ph = 0, $$024 = 0, $$025 = 0, $$in = 0, $$sroa$speculated$i$i$i$i$i = 0, $$sroa$speculated$i$i$i$i$i26 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  HEAP32[$1>>2] = $3;
  $$025 = $3;
  return ($$025|0);
 }
 $6 = ((($0)) + 4|0);
 $7 = ((($2)) + 11|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = ($8<<24>>24)<(0);
 $10 = ((($2)) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $8&255;
 $13 = $9 ? $11 : $12;
 $14 = HEAP32[$2>>2]|0;
 $15 = $9 ? $14 : $2;
 $$0 = $6;$$024 = $4;
 while(1) {
  $16 = ((($$024)) + 16|0);
  $17 = ((($16)) + 11|0);
  $18 = HEAP8[$17>>0]|0;
  $19 = ($18<<24>>24)<(0);
  $20 = ((($$024)) + 20|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = $18&255;
  $23 = $19 ? $21 : $22;
  $24 = ($23>>>0)<($13>>>0);
  $$sroa$speculated$i$i$i$i$i26 = $24 ? $23 : $13;
  $25 = ($$sroa$speculated$i$i$i$i$i26|0)==(0);
  if ($25) {
   label = 6;
  } else {
   $26 = HEAP32[$16>>2]|0;
   $27 = $19 ? $26 : $16;
   $28 = (_memcmp($15,$27,$$sroa$speculated$i$i$i$i$i26)|0);
   $29 = ($28|0)==(0);
   if ($29) {
    label = 6;
   } else {
    $31 = ($28|0)<(0);
    if ($31) {
     label = 8;
    } else {
     label = 10;
    }
   }
  }
  if ((label|0) == 6) {
   label = 0;
   $30 = ($13>>>0)<($23>>>0);
   if ($30) {
    label = 8;
   } else {
    label = 10;
   }
  }
  if ((label|0) == 8) {
   label = 0;
   $32 = HEAP32[$$024>>2]|0;
   $33 = ($32|0)==(0|0);
   if ($33) {
    label = 9;
    break;
   } else {
    $$0$ph = $$024;$$in = $32;
   }
  }
  else if ((label|0) == 10) {
   label = 0;
   $34 = ($13>>>0)<($23>>>0);
   $$sroa$speculated$i$i$i$i$i = $34 ? $13 : $23;
   $35 = ($$sroa$speculated$i$i$i$i$i|0)==(0);
   if ($35) {
    label = 12;
   } else {
    $36 = HEAP32[$16>>2]|0;
    $37 = $19 ? $36 : $16;
    $38 = (_memcmp($37,$15,$$sroa$speculated$i$i$i$i$i)|0);
    $39 = ($38|0)==(0);
    if ($39) {
     label = 12;
    } else {
     $40 = ($38|0)<(0);
     if (!($40)) {
      label = 16;
      break;
     }
    }
   }
   if ((label|0) == 12) {
    label = 0;
    if (!($24)) {
     label = 16;
     break;
    }
   }
   $41 = ((($$024)) + 4|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = ($42|0)==(0|0);
   if ($43) {
    label = 15;
    break;
   } else {
    $$0$ph = $41;$$in = $42;
   }
  }
  $$0 = $$0$ph;$$024 = $$in;
 }
 if ((label|0) == 9) {
  HEAP32[$1>>2] = $$024;
  $$025 = $$024;
  return ($$025|0);
 }
 else if ((label|0) == 15) {
  HEAP32[$1>>2] = $$024;
  $$025 = $41;
  return ($$025|0);
 }
 else if ((label|0) == 16) {
  HEAP32[$1>>2] = $$024;
  $$025 = $$0;
  return ($$025|0);
 }
 return (0)|0;
}
function __ZN3osg5State15getDefineStringERKNSt3__23setINS1_12basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEENS1_4lessIS8_EENS6_IS8_EEEE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i25 = 0, $$0$i$i$i20 = 0, $$0$i$i$i32 = 0, $$not = 0, $$not68 = 0, $$not6875 = 0, $$not74 = 0, $$pre = 0, $$sroa$049$0$be = 0, $$sroa$049$077 = 0, $$sroa$058$0$be = 0, $$sroa$058$080 = 0, $$sroa$speculated$i$i$i = 0, $$sroa$speculated$i$i$i38 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0;
 var $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $brmerge = 0, $brmerge76 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($1)) + 624|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)==(0);
 if (!($5)) {
  $6 = ((($1)) + 612|0);
  (__ZN3osg5State9DefineMap20updateCurrentDefinesEv($6)|0);
 }
 $7 = HEAP32[$2>>2]|0;
 $8 = ((($1)) + 628|0);
 $9 = HEAP32[$8>>2]|0;
 ;HEAP32[$0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;
 $10 = ((($2)) + 4|0);
 $11 = ((($1)) + 632|0);
 $$not74 = ($7|0)==($10|0);
 $$not6875 = ($9|0)==($11|0);
 $brmerge76 = $$not6875 | $$not74;
 if ($brmerge76) {
  return;
 } else {
  $$sroa$049$077 = $9;$$sroa$058$080 = $7;
 }
 L6: while(1) {
  $12 = ((($$sroa$058$080)) + 16|0);
  $13 = ((($$sroa$049$077)) + 16|0);
  $14 = ((($13)) + 11|0);
  $15 = HEAP8[$14>>0]|0;
  $16 = ($15<<24>>24)<(0);
  $17 = ((($$sroa$049$077)) + 20|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = $15&255;
  $20 = $16 ? $18 : $19;
  $21 = ((($12)) + 11|0);
  $22 = HEAP8[$21>>0]|0;
  $23 = ($22<<24>>24)<(0);
  $24 = ((($$sroa$058$080)) + 20|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = $22&255;
  $27 = $23 ? $25 : $26;
  $28 = ($20>>>0)<($27>>>0);
  $$sroa$speculated$i$i$i38 = $28 ? $20 : $27;
  $29 = ($$sroa$speculated$i$i$i38|0)==(0);
  if ($29) {
   label = 6;
  } else {
   $30 = HEAP32[$12>>2]|0;
   $31 = $23 ? $30 : $12;
   $32 = HEAP32[$13>>2]|0;
   $33 = $16 ? $32 : $13;
   $34 = (_memcmp($31,$33,$$sroa$speculated$i$i$i38)|0);
   $35 = ($34|0)==(0);
   if ($35) {
    label = 6;
   } else {
    $37 = ($34|0)<(0);
    if ($37) {
     label = 8;
    } else {
     label = 14;
    }
   }
  }
  if ((label|0) == 6) {
   label = 0;
   $36 = ($27>>>0)<($20>>>0);
   if ($36) {
    label = 8;
   } else {
    label = 14;
   }
  }
  L13: do {
   if ((label|0) == 8) {
    label = 0;
    $38 = ((($$sroa$058$080)) + 4|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = ($39|0)==(0|0);
    if ($40) {
     $41 = ((($$sroa$058$080)) + 8|0);
     $42 = HEAP32[$41>>2]|0;
     $43 = HEAP32[$42>>2]|0;
     $44 = ($43|0)==($$sroa$058$080|0);
     if ($44) {
      $$sroa$049$0$be = $$sroa$049$077;$$sroa$058$0$be = $42;
      break;
     } else {
      $48 = $41;
     }
     while(1) {
      $47 = HEAP32[$48>>2]|0;
      $49 = ((($47)) + 8|0);
      $50 = HEAP32[$49>>2]|0;
      $51 = HEAP32[$50>>2]|0;
      $52 = ($51|0)==($47|0);
      if ($52) {
       $$sroa$049$0$be = $$sroa$049$077;$$sroa$058$0$be = $50;
       break;
      } else {
       $48 = $49;
      }
     }
    } else {
     $$0$i$i$i32 = $39;
     while(1) {
      $45 = HEAP32[$$0$i$i$i32>>2]|0;
      $46 = ($45|0)==(0|0);
      if ($46) {
       break;
      } else {
       $$0$i$i$i32 = $45;
      }
     }
     $$sroa$049$0$be = $$sroa$049$077;$$sroa$058$0$be = $$0$i$i$i32;
     break;
    }
   }
   else if ((label|0) == 14) {
    label = 0;
    $53 = ($27>>>0)<($20>>>0);
    $$sroa$speculated$i$i$i = $53 ? $27 : $20;
    $54 = ($$sroa$speculated$i$i$i|0)==(0);
    if ($54) {
     label = 16;
    } else {
     $55 = HEAP32[$13>>2]|0;
     $56 = $16 ? $55 : $13;
     $57 = HEAP32[$12>>2]|0;
     $58 = $23 ? $57 : $12;
     $59 = (_memcmp($56,$58,$$sroa$speculated$i$i$i)|0);
     $60 = ($59|0)==(0);
     if ($60) {
      label = 16;
     } else {
      $61 = ($59|0)<(0);
      if ($61) {
       label = 18;
      }
     }
    }
    if ((label|0) == 16) {
     label = 0;
     if ($28) {
      label = 18;
     }
    }
    if ((label|0) == 18) {
     label = 0;
     $62 = ((($$sroa$049$077)) + 4|0);
     $63 = HEAP32[$62>>2]|0;
     $64 = ($63|0)==(0|0);
     if ($64) {
      $65 = ((($$sroa$049$077)) + 8|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = HEAP32[$66>>2]|0;
      $68 = ($67|0)==($$sroa$049$077|0);
      if ($68) {
       $$sroa$049$0$be = $66;$$sroa$058$0$be = $$sroa$058$080;
       break;
      } else {
       $72 = $65;
      }
      while(1) {
       $71 = HEAP32[$72>>2]|0;
       $73 = ((($71)) + 8|0);
       $74 = HEAP32[$73>>2]|0;
       $75 = HEAP32[$74>>2]|0;
       $76 = ($75|0)==($71|0);
       if ($76) {
        $$sroa$049$0$be = $74;$$sroa$058$0$be = $$sroa$058$080;
        break L13;
       } else {
        $72 = $73;
       }
      }
     } else {
      $$0$i$i$i$i25 = $63;
      while(1) {
       $69 = HEAP32[$$0$i$i$i$i25>>2]|0;
       $70 = ($69|0)==(0|0);
       if ($70) {
        break;
       } else {
        $$0$i$i$i$i25 = $69;
       }
      }
      $$sroa$049$0$be = $$0$i$i$i$i25;$$sroa$058$0$be = $$sroa$058$080;
      break;
     }
    }
    __THREW__ = 0;
    (invoke_iii(3937,($0|0),(150482|0))|0);
    $77 = __THREW__; __THREW__ = 0;
    $78 = $77&1;
    if ($78) {
     break L6;
    }
    $79 = HEAP8[$14>>0]|0;
    $80 = ($79<<24>>24)<(0);
    $81 = HEAP32[$13>>2]|0;
    $82 = $80 ? $81 : $13;
    $83 = HEAP32[$17>>2]|0;
    $84 = $79&255;
    $85 = $80 ? $83 : $84;
    __THREW__ = 0;
    (invoke_iiii(3544,($0|0),($82|0),($85|0))|0);
    $86 = __THREW__; __THREW__ = 0;
    $87 = $86&1;
    if ($87) {
     break L6;
    }
    $88 = ((($$sroa$049$077)) + 28|0);
    $89 = ((($88)) + 11|0);
    $90 = HEAP8[$89>>0]|0;
    $91 = ($90<<24>>24)<(0);
    if ($91) {
     $92 = ((($$sroa$049$077)) + 32|0);
     $93 = HEAP32[$92>>2]|0;
     $95 = $93;
    } else {
     $94 = $90&255;
     $95 = $94;
    }
    $96 = ($95|0)==(0);
    if (!($96)) {
     if ($91) {
      $97 = HEAP32[$88>>2]|0;
      $99 = $97;
     } else {
      $99 = $88;
     }
     $98 = HEAP8[$99>>0]|0;
     $100 = ($98<<24>>24)==(40);
     if ($100) {
      $103 = $90;
     } else {
      __THREW__ = 0;
      (invoke_iii(3937,($0|0),(159071|0))|0);
      $101 = __THREW__; __THREW__ = 0;
      $102 = $101&1;
      if ($102) {
       break L6;
      }
      $$pre = HEAP8[$89>>0]|0;
      $103 = $$pre;
     }
     $104 = ($103<<24>>24)<(0);
     $105 = HEAP32[$88>>2]|0;
     $106 = $104 ? $105 : $88;
     $107 = ((($$sroa$049$077)) + 32|0);
     $108 = HEAP32[$107>>2]|0;
     $109 = $103&255;
     $110 = $104 ? $108 : $109;
     __THREW__ = 0;
     (invoke_iiii(3544,($0|0),($106|0),($110|0))|0);
     $111 = __THREW__; __THREW__ = 0;
     $112 = $111&1;
     if ($112) {
      break L6;
     }
    }
    __THREW__ = 0;
    (invoke_iii(3937,($0|0),(195712|0))|0);
    $113 = __THREW__; __THREW__ = 0;
    $114 = $113&1;
    if ($114) {
     break L6;
    }
    $115 = ((($$sroa$058$080)) + 4|0);
    $116 = HEAP32[$115>>2]|0;
    $117 = ($116|0)==(0|0);
    if ($117) {
     $118 = ((($$sroa$058$080)) + 8|0);
     $119 = HEAP32[$118>>2]|0;
     $120 = HEAP32[$119>>2]|0;
     $121 = ($120|0)==($$sroa$058$080|0);
     if ($121) {
      $$0$i$i = $119;
     } else {
      $125 = $118;
      while(1) {
       $124 = HEAP32[$125>>2]|0;
       $126 = ((($124)) + 8|0);
       $127 = HEAP32[$126>>2]|0;
       $128 = HEAP32[$127>>2]|0;
       $129 = ($128|0)==($124|0);
       if ($129) {
        $$0$i$i = $127;
        break;
       } else {
        $125 = $126;
       }
      }
     }
    } else {
     $$0$i$i$i20 = $116;
     while(1) {
      $122 = HEAP32[$$0$i$i$i20>>2]|0;
      $123 = ($122|0)==(0|0);
      if ($123) {
       break;
      } else {
       $$0$i$i$i20 = $122;
      }
     }
     $$0$i$i = $$0$i$i$i20;
    }
    $130 = ((($$sroa$049$077)) + 4|0);
    $131 = HEAP32[$130>>2]|0;
    $132 = ($131|0)==(0|0);
    if ($132) {
     $133 = ((($$sroa$049$077)) + 8|0);
     $134 = HEAP32[$133>>2]|0;
     $135 = HEAP32[$134>>2]|0;
     $136 = ($135|0)==($$sroa$049$077|0);
     if ($136) {
      $$sroa$049$0$be = $134;$$sroa$058$0$be = $$0$i$i;
      break;
     } else {
      $140 = $133;
     }
     while(1) {
      $139 = HEAP32[$140>>2]|0;
      $141 = ((($139)) + 8|0);
      $142 = HEAP32[$141>>2]|0;
      $143 = HEAP32[$142>>2]|0;
      $144 = ($143|0)==($139|0);
      if ($144) {
       $$sroa$049$0$be = $142;$$sroa$058$0$be = $$0$i$i;
       break;
      } else {
       $140 = $141;
      }
     }
    } else {
     $$0$i$i$i$i = $131;
     while(1) {
      $137 = HEAP32[$$0$i$i$i$i>>2]|0;
      $138 = ($137|0)==(0|0);
      if ($138) {
       break;
      } else {
       $$0$i$i$i$i = $137;
      }
     }
     $$sroa$049$0$be = $$0$i$i$i$i;$$sroa$058$0$be = $$0$i$i;
     break;
    }
   }
  } while(0);
  $$not = ($$sroa$058$0$be|0)==($10|0);
  $$not68 = ($$sroa$049$0$be|0)==($11|0);
  $brmerge = $$not68 | $$not;
  if ($brmerge) {
   label = 47;
   break;
  } else {
   $$sroa$049$077 = $$sroa$049$0$be;$$sroa$058$080 = $$sroa$058$0$be;
  }
 }
 if ((label|0) == 47) {
  return;
 }
 $145 = ___cxa_find_matching_catch_2()|0;
 $146 = tempRet0;
 $147 = ((($0)) + 11|0);
 $148 = HEAP8[$147>>0]|0;
 $149 = ($148<<24>>24)<(0);
 if (!($149)) {
  ___resumeException($145|0);
  // unreachable;
 }
 $150 = HEAP32[$0>>2]|0;
 __ZdlPv($150);
 ___resumeException($145|0);
 // unreachable;
}
function __ZN3osg5State26supportsShaderRequirementsERKNSt3__23setINS1_12basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEENS1_4lessIS8_EENS6_IS8_EEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i$i = 0, $$2 = 0, $$sroa$014$0$be = 0, $$sroa$014$018 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  $$2 = 1;
  return ($$2|0);
 }
 $5 = ((($0)) + 624|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = ($6<<24>>24)==(0);
 if (!($7)) {
  $8 = ((($0)) + 612|0);
  (__ZN3osg5State9DefineMap20updateCurrentDefinesEv($8)|0);
 }
 $9 = HEAP32[$1>>2]|0;
 $10 = ((($1)) + 4|0);
 $11 = ($9|0)==($10|0);
 if ($11) {
  $$2 = 1;
  return ($$2|0);
 }
 $12 = ((($0)) + 628|0);
 $13 = ((($0)) + 632|0);
 $$sroa$014$018 = $9;
 while(1) {
  $14 = ((($$sroa$014$018)) + 16|0);
  $15 = (__ZNKSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4pairIS7_jEEEENS_19__map_value_compareIS7_SA_NS_4lessIS7_EELb1EEENS5_ISA_EEE4findIS7_EENS_21__tree_const_iteratorISA_PNS_11__tree_nodeISA_PvEEiEERKT_($12,$14)|0);
  $16 = ($15|0)==($13|0);
  if ($16) {
   $$2 = 0;
   label = 13;
   break;
  }
  $17 = ((($$sroa$014$018)) + 4|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = ($18|0)==(0|0);
  if ($19) {
   $20 = ((($$sroa$014$018)) + 8|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = HEAP32[$21>>2]|0;
   $23 = ($22|0)==($$sroa$014$018|0);
   if ($23) {
    $$sroa$014$0$be = $21;
   } else {
    $28 = $20;
    while(1) {
     $27 = HEAP32[$28>>2]|0;
     $29 = ((($27)) + 8|0);
     $30 = HEAP32[$29>>2]|0;
     $31 = HEAP32[$30>>2]|0;
     $32 = ($31|0)==($27|0);
     if ($32) {
      $$sroa$014$0$be = $30;
      break;
     } else {
      $28 = $29;
     }
    }
   }
  } else {
   $$0$i$i$i = $18;
   while(1) {
    $25 = HEAP32[$$0$i$i$i>>2]|0;
    $26 = ($25|0)==(0|0);
    if ($26) {
     break;
    } else {
     $$0$i$i$i = $25;
    }
   }
   $$sroa$014$0$be = $$0$i$i$i;
  }
  $24 = ($$sroa$014$0$be|0)==($10|0);
  if ($24) {
   $$2 = 1;
   label = 13;
   break;
  } else {
   $$sroa$014$018 = $$sroa$014$0$be;
  }
 }
 if ((label|0) == 13) {
  return ($$2|0);
 }
 return (0)|0;
}
function __ZNKSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4pairIS7_jEEEENS_19__map_value_compareIS7_SA_NS_4lessIS7_EELb1EEENS5_ISA_EEE4findIS7_EENS_21__tree_const_iteratorISA_PNS_11__tree_nodeISA_PvEEiEERKT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$ph$lcssa$i = 0, $$0$ph15$i = 0, $$07$ph14$i = 0, $$0711$i = 0, $$sroa$0$0 = 0, $$sroa$speculated$i$i$i$i$i = 0, $$sroa$speculated$i$i$i$i$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 do {
  if (!($4)) {
   $5 = ((($1)) + 11|0);
   $6 = HEAP8[$5>>0]|0;
   $7 = ($6<<24>>24)<(0);
   $8 = ((($1)) + 4|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = $6&255;
   $11 = $7 ? $9 : $10;
   $12 = HEAP32[$1>>2]|0;
   $13 = $7 ? $12 : $1;
   $$0$ph15$i = $2;$$07$ph14$i = $3;
   L3: while(1) {
    $$0711$i = $$07$ph14$i;
    while(1) {
     $14 = ((($$0711$i)) + 16|0);
     $15 = ((($14)) + 11|0);
     $16 = HEAP8[$15>>0]|0;
     $17 = ($16<<24>>24)<(0);
     $18 = ((($$0711$i)) + 20|0);
     $19 = HEAP32[$18>>2]|0;
     $20 = $16&255;
     $21 = $17 ? $19 : $20;
     $22 = ($11>>>0)<($21>>>0);
     $$sroa$speculated$i$i$i$i$i$i = $22 ? $11 : $21;
     $23 = ($$sroa$speculated$i$i$i$i$i$i|0)==(0);
     if ($23) {
      label = 6;
     } else {
      $24 = HEAP32[$14>>2]|0;
      $25 = $17 ? $24 : $14;
      $26 = (_memcmp($25,$13,$$sroa$speculated$i$i$i$i$i$i)|0);
      $27 = ($26|0)==(0);
      if ($27) {
       label = 6;
      } else {
       $29 = ($26|0)<(0);
       if (!($29)) {
        break;
       }
      }
     }
     if ((label|0) == 6) {
      label = 0;
      $28 = ($21>>>0)<($11>>>0);
      if (!($28)) {
       break;
      }
     }
     $32 = ((($$0711$i)) + 4|0);
     $33 = HEAP32[$32>>2]|0;
     $34 = ($33|0)==(0|0);
     if ($34) {
      $$0$ph$lcssa$i = $$0$ph15$i;
      break L3;
     } else {
      $$0711$i = $33;
     }
    }
    $30 = HEAP32[$$0711$i>>2]|0;
    $31 = ($30|0)==(0|0);
    if ($31) {
     $$0$ph$lcssa$i = $$0711$i;
     break;
    } else {
     $$0$ph15$i = $$0711$i;$$07$ph14$i = $30;
    }
   }
   $35 = ($$0$ph$lcssa$i|0)==($2|0);
   if (!($35)) {
    $36 = ((($$0$ph$lcssa$i)) + 16|0);
    $37 = ((($36)) + 11|0);
    $38 = HEAP8[$37>>0]|0;
    $39 = ($38<<24>>24)<(0);
    $40 = ((($$0$ph$lcssa$i)) + 20|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = $38&255;
    $43 = $39 ? $41 : $42;
    $44 = ($43>>>0)<($11>>>0);
    $$sroa$speculated$i$i$i$i$i = $44 ? $43 : $11;
    $45 = ($$sroa$speculated$i$i$i$i$i|0)==(0);
    if (!($45)) {
     $46 = HEAP32[$36>>2]|0;
     $47 = $39 ? $46 : $36;
     $48 = (_memcmp($13,$47,$$sroa$speculated$i$i$i$i$i)|0);
     $49 = ($48|0)==(0);
     if (!($49)) {
      $51 = ($48|0)<(0);
      if ($51) {
       break;
      } else {
       $$sroa$0$0 = $$0$ph$lcssa$i;
      }
      return ($$sroa$0$0|0);
     }
    }
    $50 = ($11>>>0)<($43>>>0);
    if (!($50)) {
     $$sroa$0$0 = $$0$ph$lcssa$i;
     return ($$sroa$0$0|0);
    }
   }
  }
 } while(0);
 $$sroa$0$0 = $2;
 return ($$sroa$0$0|0);
}
function __ZN3osg8StateSet21setThreadSafeRefUnrefEb($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i$i$i = 0, $$0$i$i$i$i4 = 0, $$0$i$i$i8$sink$be = 0, $$0$i$i$i8$sink40 = 0, $$pre = 0, $$sink38 = 0, $$sroa$011$0$be = 0, $$sroa$011$037 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg6Object21setThreadSafeRefUnrefEb($0,$1);
 $2 = ((($0)) + 56|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 60|0);
 $5 = ($3|0)==($4|0);
 if (!($5)) {
  $$0$i$i$i8$sink40 = $3;
  while(1) {
   $11 = ((($$0$i$i$i8$sink40)) + 24|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = HEAP32[$12>>2]|0;
   $14 = HEAP32[$13>>2]|0;
   FUNCTION_TABLE_vii[$14 & 8191]($12,$1);
   $15 = ((($$0$i$i$i8$sink40)) + 4|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ($16|0)==(0|0);
   if ($17) {
    $18 = ((($$0$i$i$i8$sink40)) + 8|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = HEAP32[$19>>2]|0;
    $21 = ($20|0)==($$0$i$i$i8$sink40|0);
    if ($21) {
     $$0$i$i$i8$sink$be = $19;
    } else {
     $26 = $18;
     while(1) {
      $25 = HEAP32[$26>>2]|0;
      $27 = ((($25)) + 8|0);
      $28 = HEAP32[$27>>2]|0;
      $29 = HEAP32[$28>>2]|0;
      $30 = ($29|0)==($25|0);
      if ($30) {
       $$0$i$i$i8$sink$be = $28;
       break;
      } else {
       $26 = $27;
      }
     }
    }
   } else {
    $$0$i$i$i$i4 = $16;
    while(1) {
     $23 = HEAP32[$$0$i$i$i$i4>>2]|0;
     $24 = ($23|0)==(0|0);
     if ($24) {
      break;
     } else {
      $$0$i$i$i$i4 = $23;
     }
    }
    $$0$i$i$i8$sink$be = $$0$i$i$i$i4;
   }
   $22 = ($$0$i$i$i8$sink$be|0)==($4|0);
   if ($22) {
    break;
   } else {
    $$0$i$i$i8$sink40 = $$0$i$i$i8$sink$be;
   }
  }
 }
 $6 = ((($0)) + 80|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($0)) + 84|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($7|0)==($9|0);
 if ($10) {
  return;
 } else {
  $$sink38 = $7;$57 = $9;
 }
 while(1) {
  $31 = HEAP32[$$sink38>>2]|0;
  $32 = ((($$sink38)) + 4|0);
  $33 = ($31|0)==($32|0);
  if ($33) {
   $36 = $57;
  } else {
   $$sroa$011$037 = $31;
   while(1) {
    $37 = ((($$sroa$011$037)) + 24|0);
    $38 = HEAP32[$37>>2]|0;
    $39 = HEAP32[$38>>2]|0;
    $40 = HEAP32[$39>>2]|0;
    FUNCTION_TABLE_vii[$40 & 8191]($38,$1);
    $41 = ((($$sroa$011$037)) + 4|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = ($42|0)==(0|0);
    if ($43) {
     $44 = ((($$sroa$011$037)) + 8|0);
     $45 = HEAP32[$44>>2]|0;
     $46 = HEAP32[$45>>2]|0;
     $47 = ($46|0)==($$sroa$011$037|0);
     if ($47) {
      $$sroa$011$0$be = $45;
     } else {
      $52 = $44;
      while(1) {
       $51 = HEAP32[$52>>2]|0;
       $53 = ((($51)) + 8|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = HEAP32[$54>>2]|0;
       $56 = ($55|0)==($51|0);
       if ($56) {
        $$sroa$011$0$be = $54;
        break;
       } else {
        $52 = $53;
       }
      }
     }
    } else {
     $$0$i$i$i$i = $42;
     while(1) {
      $49 = HEAP32[$$0$i$i$i$i>>2]|0;
      $50 = ($49|0)==(0|0);
      if ($50) {
       break;
      } else {
       $$0$i$i$i$i = $49;
      }
     }
     $$sroa$011$0$be = $$0$i$i$i$i;
    }
    $48 = ($$sroa$011$0$be|0)==($32|0);
    if ($48) {
     break;
    } else {
     $$sroa$011$037 = $$sroa$011$0$be;
    }
   }
   $$pre = HEAP32[$8>>2]|0;
   $36 = $$pre;
  }
  $34 = ((($$sink38)) + 12|0);
  $35 = ($34|0)==($36|0);
  if ($35) {
   break;
  } else {
   $$sink38 = $34;$57 = $36;
  }
 }
 return;
}
function __ZN3osg8StateSetD2Ev($0) {
 $0 = $0|0;
 var $$0 = 0, $$02 = 0, $$1 = 0, $$13 = 0, $$pre$i = 0, $$pre$i15 = 0, $$pre$i23 = 0, $$pre$i29 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0;
 var $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i33 = 0, $scevgep5$i$i$i = 0, $scevgep5$i$i$i34 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (66196);
 __THREW__ = 0;
 invoke_vi(3938,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if ($2) {
   $81 = ___cxa_find_matching_catch_2()|0;
   $82 = tempRet0;
   $83 = ((($0)) + 152|0);
   $84 = HEAP32[$83>>2]|0;
   $85 = ($84|0)==(0|0);
   if (!($85)) {
    $86 = HEAP32[$84>>2]|0;
    $87 = ((($86)) + -16|0);
    $88 = HEAP32[$87>>2]|0;
    $89 = (($84) + ($88)|0);
    $90 = ((($89)) + 8|0);
    $91 = HEAP32[$90>>2]|0;HEAP32[$90>>2] = (($91-1)|0);
    $92 = ($91|0)==(1);
    if ($92) {
     __THREW__ = 0;
     invoke_viii(3262,($89|0),1,1);
     $93 = __THREW__; __THREW__ = 0;
     $94 = $93&1;
     if ($94) {
      $167 = ___cxa_find_matching_catch_3(0|0)|0;
      $168 = tempRet0;
      ___clang_call_terminate($167);
      // unreachable;
     }
    }
   }
   HEAP32[$83>>2] = 0;
   $$0 = $82;$$02 = $81;
   label = 31;
  } else {
   $3 = ((($0)) + 152|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = ($4|0)==(0|0);
   if (!($5)) {
    $6 = HEAP32[$4>>2]|0;
    $7 = ((($6)) + -16|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = (($4) + ($8)|0);
    $10 = ((($9)) + 8|0);
    $11 = HEAP32[$10>>2]|0;HEAP32[$10>>2] = (($11-1)|0);
    $12 = ($11|0)==(1);
    if ($12) {
     __THREW__ = 0;
     invoke_viii(3262,($9|0),1,1);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      $95 = ___cxa_find_matching_catch_2()|0;
      $96 = tempRet0;
      $$0 = $96;$$02 = $95;
      label = 31;
      break;
     }
    }
   }
   HEAP32[$3>>2] = 0;
   $15 = ((($0)) + 144|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ($16|0)==(0|0);
   if (!($17)) {
    $18 = HEAP32[$16>>2]|0;
    $19 = ((($18)) + -16|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = (($16) + ($20)|0);
    $22 = ((($21)) + 8|0);
    $23 = HEAP32[$22>>2]|0;HEAP32[$22>>2] = (($23-1)|0);
    $24 = ($23|0)==(1);
    if ($24) {
     __THREW__ = 0;
     invoke_viii(3262,($21|0),1,1);
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if ($26) {
      $97 = ___cxa_find_matching_catch_2()|0;
      $98 = tempRet0;
      $$1 = $98;$$13 = $97;
      break;
     }
    }
   }
   HEAP32[$15>>2] = 0;
   $27 = ((($0)) + 128|0);
   $28 = ((($27)) + 11|0);
   $29 = HEAP8[$28>>0]|0;
   $30 = ($29<<24>>24)<(0);
   if ($30) {
    $31 = HEAP32[$27>>2]|0;
    __ZdlPv($31);
   }
   $32 = ((($0)) + 104|0);
   $33 = ((($0)) + 108|0);
   $34 = HEAP32[$33>>2]|0;
   __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4pairIS7_jEEEENS_19__map_value_compareIS7_SA_NS_4lessIS7_EELb1EEENS5_ISA_EEE7destroyEPNS_11__tree_nodeISA_PvEE($32,$34);
   $35 = ((($0)) + 92|0);
   $36 = ((($0)) + 96|0);
   $37 = HEAP32[$36>>2]|0;
   __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4pairIN3osg7ref_ptrINS9_7UniformEEEjEEEENS_19__map_value_compareIS7_SE_NS_4lessIS7_EELb1EEENS5_ISE_EEE7destroyEPNS_11__tree_nodeISE_PvEE($35,$37);
   $38 = ((($0)) + 80|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = ($39|0)==(0|0);
   if (!($40)) {
    $41 = ((($0)) + 84|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = ($42|0)==($39|0);
    if ($43) {
     $50 = $39;
    } else {
     $45 = $42;
     while(1) {
      $44 = ((($45)) + -12|0);
      HEAP32[$41>>2] = $44;
      $46 = ((($45)) + -8|0);
      $47 = HEAP32[$46>>2]|0;
      __ZNSt3__26__treeINS_12__value_typeINS_4pairIN3osg14StateAttribute4TypeEjEENS2_INS3_7ref_ptrIS4_EEjEEEENS_19__map_value_compareIS6_SA_NS_4lessIS6_EELb1EEENS_9allocatorISA_EEE7destroyEPNS_11__tree_nodeISA_PvEE($44,$47);
      $48 = HEAP32[$41>>2]|0;
      $49 = ($48|0)==($39|0);
      if ($49) {
       break;
      } else {
       $45 = $48;
      }
     }
     $$pre$i = HEAP32[$38>>2]|0;
     $50 = $$pre$i;
    }
    __ZdlPv($50);
   }
   $51 = ((($0)) + 68|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = ($52|0)==(0|0);
   if (!($53)) {
    $54 = ((($0)) + 72|0);
    $55 = HEAP32[$54>>2]|0;
    $56 = ($55|0)==($52|0);
    if ($56) {
     $63 = $52;
    } else {
     $58 = $55;
     while(1) {
      $57 = ((($58)) + -12|0);
      HEAP32[$54>>2] = $57;
      $59 = ((($58)) + -8|0);
      $60 = HEAP32[$59>>2]|0;
      __ZNSt3__26__treeINS_12__value_typeIjjEENS_19__map_value_compareIjS2_NS_4lessIjEELb1EEENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($57,$60);
      $61 = HEAP32[$54>>2]|0;
      $62 = ($61|0)==($52|0);
      if ($62) {
       break;
      } else {
       $58 = $61;
      }
     }
     $$pre$i15 = HEAP32[$51>>2]|0;
     $63 = $$pre$i15;
    }
    __ZdlPv($63);
   }
   $64 = ((($0)) + 56|0);
   $65 = ((($0)) + 60|0);
   $66 = HEAP32[$65>>2]|0;
   __ZNSt3__26__treeINS_12__value_typeINS_4pairIN3osg14StateAttribute4TypeEjEENS2_INS3_7ref_ptrIS4_EEjEEEENS_19__map_value_compareIS6_SA_NS_4lessIS6_EELb1EEENS_9allocatorISA_EEE7destroyEPNS_11__tree_nodeISA_PvEE($64,$66);
   $67 = ((($0)) + 44|0);
   $68 = ((($0)) + 48|0);
   $69 = HEAP32[$68>>2]|0;
   __ZNSt3__26__treeINS_12__value_typeIjjEENS_19__map_value_compareIjS2_NS_4lessIjEELb1EEENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($67,$69);
   $70 = ((($0)) + 32|0);
   $71 = HEAP32[$70>>2]|0;
   $72 = ($71|0)==(0|0);
   if ($72) {
    __ZN3osg6ObjectD2Ev($0);
    return;
   }
   $73 = ((($0)) + 36|0);
   $74 = HEAP32[$73>>2]|0;
   $75 = ($74|0)==($71|0);
   if (!($75)) {
    $scevgep$i$i$i = ((($74)) + -4|0);
    $76 = $scevgep$i$i$i;
    $77 = $71;
    $78 = (($76) - ($77))|0;
    $79 = $78 >>> 2;
    $80 = $79 ^ -1;
    $scevgep5$i$i$i = (($74) + ($80<<2)|0);
    HEAP32[$73>>2] = $scevgep5$i$i$i;
   }
   __ZdlPv($71);
   __ZN3osg6ObjectD2Ev($0);
   return;
  }
 } while(0);
 if ((label|0) == 31) {
  $99 = ((($0)) + 144|0);
  $100 = HEAP32[$99>>2]|0;
  $101 = ($100|0)==(0|0);
  if (!($101)) {
   $102 = HEAP32[$100>>2]|0;
   $103 = ((($102)) + -16|0);
   $104 = HEAP32[$103>>2]|0;
   $105 = (($100) + ($104)|0);
   $106 = ((($105)) + 8|0);
   $107 = HEAP32[$106>>2]|0;HEAP32[$106>>2] = (($107-1)|0);
   $108 = ($107|0)==(1);
   if ($108) {
    __THREW__ = 0;
    invoke_viii(3262,($105|0),1,1);
    $109 = __THREW__; __THREW__ = 0;
    $110 = $109&1;
    if ($110) {
     $167 = ___cxa_find_matching_catch_3(0|0)|0;
     $168 = tempRet0;
     ___clang_call_terminate($167);
     // unreachable;
    }
   }
  }
  HEAP32[$99>>2] = 0;
  $$1 = $$0;$$13 = $$02;
 }
 $111 = ((($0)) + 128|0);
 $112 = ((($111)) + 11|0);
 $113 = HEAP8[$112>>0]|0;
 $114 = ($113<<24>>24)<(0);
 if ($114) {
  $115 = HEAP32[$111>>2]|0;
  __ZdlPv($115);
 }
 $116 = ((($0)) + 104|0);
 $117 = ((($0)) + 108|0);
 $118 = HEAP32[$117>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4pairIS7_jEEEENS_19__map_value_compareIS7_SA_NS_4lessIS7_EELb1EEENS5_ISA_EEE7destroyEPNS_11__tree_nodeISA_PvEE($116,$118);
 $119 = ((($0)) + 92|0);
 $120 = ((($0)) + 96|0);
 $121 = HEAP32[$120>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4pairIN3osg7ref_ptrINS9_7UniformEEEjEEEENS_19__map_value_compareIS7_SE_NS_4lessIS7_EELb1EEENS5_ISE_EEE7destroyEPNS_11__tree_nodeISE_PvEE($119,$121);
 $122 = ((($0)) + 80|0);
 $123 = HEAP32[$122>>2]|0;
 $124 = ($123|0)==(0|0);
 if (!($124)) {
  $125 = ((($0)) + 84|0);
  $126 = HEAP32[$125>>2]|0;
  $127 = ($126|0)==($123|0);
  if ($127) {
   $134 = $123;
  } else {
   $129 = $126;
   while(1) {
    $128 = ((($129)) + -12|0);
    HEAP32[$125>>2] = $128;
    $130 = ((($129)) + -8|0);
    $131 = HEAP32[$130>>2]|0;
    __ZNSt3__26__treeINS_12__value_typeINS_4pairIN3osg14StateAttribute4TypeEjEENS2_INS3_7ref_ptrIS4_EEjEEEENS_19__map_value_compareIS6_SA_NS_4lessIS6_EELb1EEENS_9allocatorISA_EEE7destroyEPNS_11__tree_nodeISA_PvEE($128,$131);
    $132 = HEAP32[$125>>2]|0;
    $133 = ($132|0)==($123|0);
    if ($133) {
     break;
    } else {
     $129 = $132;
    }
   }
   $$pre$i23 = HEAP32[$122>>2]|0;
   $134 = $$pre$i23;
  }
  __ZdlPv($134);
 }
 $135 = ((($0)) + 68|0);
 $136 = HEAP32[$135>>2]|0;
 $137 = ($136|0)==(0|0);
 if (!($137)) {
  $138 = ((($0)) + 72|0);
  $139 = HEAP32[$138>>2]|0;
  $140 = ($139|0)==($136|0);
  if ($140) {
   $147 = $136;
  } else {
   $142 = $139;
   while(1) {
    $141 = ((($142)) + -12|0);
    HEAP32[$138>>2] = $141;
    $143 = ((($142)) + -8|0);
    $144 = HEAP32[$143>>2]|0;
    __ZNSt3__26__treeINS_12__value_typeIjjEENS_19__map_value_compareIjS2_NS_4lessIjEELb1EEENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($141,$144);
    $145 = HEAP32[$138>>2]|0;
    $146 = ($145|0)==($136|0);
    if ($146) {
     break;
    } else {
     $142 = $145;
    }
   }
   $$pre$i29 = HEAP32[$135>>2]|0;
   $147 = $$pre$i29;
  }
  __ZdlPv($147);
 }
 $148 = ((($0)) + 56|0);
 $149 = ((($0)) + 60|0);
 $150 = HEAP32[$149>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_4pairIN3osg14StateAttribute4TypeEjEENS2_INS3_7ref_ptrIS4_EEjEEEENS_19__map_value_compareIS6_SA_NS_4lessIS6_EELb1EEENS_9allocatorISA_EEE7destroyEPNS_11__tree_nodeISA_PvEE($148,$150);
 $151 = ((($0)) + 44|0);
 $152 = ((($0)) + 48|0);
 $153 = HEAP32[$152>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIjjEENS_19__map_value_compareIjS2_NS_4lessIjEELb1EEENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($151,$153);
 $154 = ((($0)) + 32|0);
 $155 = HEAP32[$154>>2]|0;
 $156 = ($155|0)==(0|0);
 if (!($156)) {
  $157 = ((($0)) + 36|0);
  $158 = HEAP32[$157>>2]|0;
  $159 = ($158|0)==($155|0);
  if (!($159)) {
   $scevgep$i$i$i33 = ((($158)) + -4|0);
   $160 = $scevgep$i$i$i33;
   $161 = $155;
   $162 = (($160) - ($161))|0;
   $163 = $162 >>> 2;
   $164 = $163 ^ -1;
   $scevgep5$i$i$i34 = (($158) + ($164<<2)|0);
   HEAP32[$157>>2] = $scevgep5$i$i$i34;
  }
  __ZdlPv($155);
 }
 __THREW__ = 0;
 invoke_vi(388,($0|0));
 $165 = __THREW__; __THREW__ = 0;
 $166 = $165&1;
 if ($166) {
  $167 = ___cxa_find_matching_catch_3(0|0)|0;
  $168 = tempRet0;
  ___clang_call_terminate($167);
  // unreachable;
 } else {
  ___resumeException($$13|0);
  // unreachable;
 }
}
function __ZN3osg8StateSetD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(2254,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK3osg8StateSet9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(160)|0);
 __THREW__ = 0;
 invoke_vi(3572,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch_2()|0;
  $5 = tempRet0;
  __ZdlPv($1);
  ___resumeException($4|0);
  // unreachable;
 } else {
  return ($1|0);
 }
 return (0)|0;
}
function __ZNK3osg8StateSet5cloneERKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(160)|0);
 __THREW__ = 0;
 invoke_viii(3939,($2|0),($0|0),($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch_2()|0;
  $6 = tempRet0;
  __ZdlPv($2);
  ___resumeException($5|0);
  // unreachable;
 } else {
  return ($2|0);
 }
 return (0)|0;
}
function __ZNK3osg8StateSet12isSameKindAsEPKNS_6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,26648,0)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK3osg8StateSet11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175113|0);
}
function __ZNK3osg8StateSet9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (150491|0);
}
function __ZN3osg8StateSet10asStateSetEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ($0|0);
}
function __ZNK3osg8StateSet10asStateSetEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ($0|0);
}
function __ZN3osg8StateSet19computeDataVarianceEv($0) {
 $0 = $0|0;
 var $$$1$off0 = 0, $$$4$off0 = 0, $$$6$off0 = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i21 = 0, $$0$i$i$i$i27 = 0, $$0$off0 = 0, $$0970 = 0, $$1$off0$lcssa = 0, $$1$off075 = 0, $$3$off0$lcssa = 0, $$3$off071 = 0, $$4$off0$lcssa = 0, $$4$off067 = 0, $$6$off0$lcssa = 0, $$6$off065 = 0, $$sroa$034$0$be = 0, $$sroa$034$064 = 0, $$sroa$044$0$be = 0, $$sroa$044$066 = 0;
 var $$sroa$054$0$be = 0, $$sroa$054$074 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $not$$6$off0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 144|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  $4 = ((($0)) + 152|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0|0);
  if ($6) {
   $$0$off0 = 0;
  } else {
   label = 3;
  }
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $$0$off0 = 1;
 }
 $7 = ((($0)) + 56|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($0)) + 60|0);
 $10 = ($8|0)==($9|0);
 if ($10) {
  $$1$off0$lcssa = $$0$off0;
 } else {
  $$1$off075 = $$0$off0;$$sroa$054$074 = $8;
  while(1) {
   $19 = ((($$sroa$054$074)) + 24|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = ((($20)) + 24|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = ($22|0)==(2);
   do {
    if ($23) {
     $24 = ((($20)) + 48|0);
     $25 = HEAP32[$24>>2]|0;
     $26 = ($25|0)==(0|0);
     if ($26) {
      $27 = ((($20)) + 52|0);
      $28 = HEAP32[$27>>2]|0;
      $29 = ($28|0)==(0|0);
      if ($29) {
       $30 = 2;
       break;
      }
     }
     HEAP32[$21>>2] = 0;
     $30 = 0;
    } else {
     $30 = $22;
    }
   } while(0);
   $31 = ($30|0)==(0);
   $$$1$off0 = $$1$off075 | $31;
   $32 = ((($$sroa$054$074)) + 4|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = ($33|0)==(0|0);
   if ($34) {
    $35 = ((($$sroa$054$074)) + 8|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = HEAP32[$36>>2]|0;
    $38 = ($37|0)==($$sroa$054$074|0);
    if ($38) {
     $$sroa$054$0$be = $36;
    } else {
     $43 = $35;
     while(1) {
      $42 = HEAP32[$43>>2]|0;
      $44 = ((($42)) + 8|0);
      $45 = HEAP32[$44>>2]|0;
      $46 = HEAP32[$45>>2]|0;
      $47 = ($46|0)==($42|0);
      if ($47) {
       $$sroa$054$0$be = $45;
       break;
      } else {
       $43 = $44;
      }
     }
    }
   } else {
    $$0$i$i$i$i27 = $33;
    while(1) {
     $40 = HEAP32[$$0$i$i$i$i27>>2]|0;
     $41 = ($40|0)==(0|0);
     if ($41) {
      break;
     } else {
      $$0$i$i$i$i27 = $40;
     }
    }
    $$sroa$054$0$be = $$0$i$i$i$i27;
   }
   $39 = ($$sroa$054$0$be|0)==($9|0);
   if ($39) {
    $$1$off0$lcssa = $$$1$off0;
    break;
   } else {
    $$1$off075 = $$$1$off0;$$sroa$054$074 = $$sroa$054$0$be;
   }
  }
 }
 $11 = ((($0)) + 80|0);
 $12 = ((($0)) + 84|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = HEAP32[$11>>2]|0;
 $15 = ($13|0)==($14|0);
 $16 = $14;
 if ($15) {
  $$3$off0$lcssa = $$1$off0$lcssa;
 } else {
  $17 = (($13) - ($14))|0;
  $18 = (($17|0) / 12)&-1;
  $$0970 = 0;$$3$off071 = $$1$off0$lcssa;
  while(1) {
   $52 = (($16) + (($$0970*12)|0)|0);
   $53 = HEAP32[$52>>2]|0;
   $54 = (((($16) + (($$0970*12)|0)|0)) + 4|0);
   $55 = ($53|0)==($54|0);
   if ($55) {
    $$4$off0$lcssa = $$3$off071;
   } else {
    $$4$off067 = $$3$off071;$$sroa$044$066 = $53;
    while(1) {
     $58 = ((($$sroa$044$066)) + 24|0);
     $59 = HEAP32[$58>>2]|0;
     $60 = ((($59)) + 24|0);
     $61 = HEAP32[$60>>2]|0;
     $62 = ($61|0)==(2);
     do {
      if ($62) {
       $63 = ((($59)) + 48|0);
       $64 = HEAP32[$63>>2]|0;
       $65 = ($64|0)==(0|0);
       if ($65) {
        $66 = ((($59)) + 52|0);
        $67 = HEAP32[$66>>2]|0;
        $68 = ($67|0)==(0|0);
        if ($68) {
         $69 = 2;
         break;
        }
       }
       HEAP32[$60>>2] = 0;
       $69 = 0;
      } else {
       $69 = $61;
      }
     } while(0);
     $70 = ($69|0)==(0);
     $$$4$off0 = $$4$off067 | $70;
     $71 = ((($$sroa$044$066)) + 4|0);
     $72 = HEAP32[$71>>2]|0;
     $73 = ($72|0)==(0|0);
     if ($73) {
      $74 = ((($$sroa$044$066)) + 8|0);
      $75 = HEAP32[$74>>2]|0;
      $76 = HEAP32[$75>>2]|0;
      $77 = ($76|0)==($$sroa$044$066|0);
      if ($77) {
       $$sroa$044$0$be = $75;
      } else {
       $82 = $74;
       while(1) {
        $81 = HEAP32[$82>>2]|0;
        $83 = ((($81)) + 8|0);
        $84 = HEAP32[$83>>2]|0;
        $85 = HEAP32[$84>>2]|0;
        $86 = ($85|0)==($81|0);
        if ($86) {
         $$sroa$044$0$be = $84;
         break;
        } else {
         $82 = $83;
        }
       }
      }
     } else {
      $$0$i$i$i$i21 = $72;
      while(1) {
       $79 = HEAP32[$$0$i$i$i$i21>>2]|0;
       $80 = ($79|0)==(0|0);
       if ($80) {
        break;
       } else {
        $$0$i$i$i$i21 = $79;
       }
      }
      $$sroa$044$0$be = $$0$i$i$i$i21;
     }
     $78 = ($$sroa$044$0$be|0)==($54|0);
     if ($78) {
      $$4$off0$lcssa = $$$4$off0;
      break;
     } else {
      $$4$off067 = $$$4$off0;$$sroa$044$066 = $$sroa$044$0$be;
     }
    }
   }
   $56 = (($$0970) + 1)|0;
   $57 = ($56>>>0)<($18>>>0);
   if ($57) {
    $$0970 = $56;$$3$off071 = $$4$off0$lcssa;
   } else {
    $$3$off0$lcssa = $$4$off0$lcssa;
    break;
   }
  }
 }
 $48 = ((($0)) + 92|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = ((($0)) + 96|0);
 $51 = ($49|0)==($50|0);
 if ($51) {
  $$6$off0$lcssa = $$3$off0$lcssa;
 } else {
  $$6$off065 = $$3$off0$lcssa;$$sroa$034$064 = $49;
  while(1) {
   $90 = ((($$sroa$034$064)) + 28|0);
   $91 = HEAP32[$90>>2]|0;
   $92 = ((($91)) + 24|0);
   $93 = HEAP32[$92>>2]|0;
   $94 = ($93|0)==(2);
   do {
    if ($94) {
     $95 = ((($91)) + 80|0);
     $96 = HEAP32[$95>>2]|0;
     $97 = ($96|0)==(0|0);
     if ($97) {
      $98 = ((($91)) + 84|0);
      $99 = HEAP32[$98>>2]|0;
      $100 = ($99|0)==(0|0);
      if ($100) {
       $101 = 2;
       break;
      }
     }
     HEAP32[$92>>2] = 0;
     $101 = 0;
    } else {
     $101 = $93;
    }
   } while(0);
   $102 = ($101|0)==(0);
   $$$6$off0 = $$6$off065 | $102;
   $103 = ((($$sroa$034$064)) + 4|0);
   $104 = HEAP32[$103>>2]|0;
   $105 = ($104|0)==(0|0);
   if ($105) {
    $106 = ((($$sroa$034$064)) + 8|0);
    $107 = HEAP32[$106>>2]|0;
    $108 = HEAP32[$107>>2]|0;
    $109 = ($108|0)==($$sroa$034$064|0);
    if ($109) {
     $$sroa$034$0$be = $107;
    } else {
     $114 = $106;
     while(1) {
      $113 = HEAP32[$114>>2]|0;
      $115 = ((($113)) + 8|0);
      $116 = HEAP32[$115>>2]|0;
      $117 = HEAP32[$116>>2]|0;
      $118 = ($117|0)==($113|0);
      if ($118) {
       $$sroa$034$0$be = $116;
       break;
      } else {
       $114 = $115;
      }
     }
    }
   } else {
    $$0$i$i$i$i = $104;
    while(1) {
     $111 = HEAP32[$$0$i$i$i$i>>2]|0;
     $112 = ($111|0)==(0|0);
     if ($112) {
      break;
     } else {
      $$0$i$i$i$i = $111;
     }
    }
    $$sroa$034$0$be = $$0$i$i$i$i;
   }
   $110 = ($$sroa$034$0$be|0)==($50|0);
   if ($110) {
    $$6$off0$lcssa = $$$6$off0;
    break;
   } else {
    $$6$off065 = $$$6$off0;$$sroa$034$064 = $$sroa$034$0$be;
   }
  }
 }
 $87 = ((($0)) + 24|0);
 $88 = HEAP32[$87>>2]|0;
 $89 = ($88|0)==(2);
 if (!($89)) {
  return;
 }
 $not$$6$off0 = $$6$off0$lcssa ^ 1;
 $119 = $not$$6$off0&1;
 HEAP32[$87>>2] = $119;
 return;
}
function __ZN3osg8StateSet21resizeGLObjectBuffersEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i$i$i = 0, $$0$i$i$i$i3 = 0, $$0$i$i$i7$sink$be = 0, $$0$i$i$i7$sink39 = 0, $$pre = 0, $$sink37 = 0, $$sroa$010$0$be = 0, $$sroa$010$036 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 56|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 60|0);
 $5 = ($3|0)==($4|0);
 if (!($5)) {
  $$0$i$i$i7$sink39 = $3;
  while(1) {
   $11 = ((($$0$i$i$i7$sink39)) + 24|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = HEAP32[$12>>2]|0;
   $14 = ((($13)) + 132|0);
   $15 = HEAP32[$14>>2]|0;
   FUNCTION_TABLE_vii[$15 & 8191]($12,$1);
   $16 = ((($$0$i$i$i7$sink39)) + 4|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = ($17|0)==(0|0);
   if ($18) {
    $19 = ((($$0$i$i$i7$sink39)) + 8|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = HEAP32[$20>>2]|0;
    $22 = ($21|0)==($$0$i$i$i7$sink39|0);
    if ($22) {
     $$0$i$i$i7$sink$be = $20;
    } else {
     $27 = $19;
     while(1) {
      $26 = HEAP32[$27>>2]|0;
      $28 = ((($26)) + 8|0);
      $29 = HEAP32[$28>>2]|0;
      $30 = HEAP32[$29>>2]|0;
      $31 = ($30|0)==($26|0);
      if ($31) {
       $$0$i$i$i7$sink$be = $29;
       break;
      } else {
       $27 = $28;
      }
     }
    }
   } else {
    $$0$i$i$i$i3 = $17;
    while(1) {
     $24 = HEAP32[$$0$i$i$i$i3>>2]|0;
     $25 = ($24|0)==(0|0);
     if ($25) {
      break;
     } else {
      $$0$i$i$i$i3 = $24;
     }
    }
    $$0$i$i$i7$sink$be = $$0$i$i$i$i3;
   }
   $23 = ($$0$i$i$i7$sink$be|0)==($4|0);
   if ($23) {
    break;
   } else {
    $$0$i$i$i7$sink39 = $$0$i$i$i7$sink$be;
   }
  }
 }
 $6 = ((($0)) + 80|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($0)) + 84|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($7|0)==($9|0);
 if ($10) {
  return;
 } else {
  $$sink37 = $7;$59 = $9;
 }
 while(1) {
  $32 = HEAP32[$$sink37>>2]|0;
  $33 = ((($$sink37)) + 4|0);
  $34 = ($32|0)==($33|0);
  if ($34) {
   $37 = $59;
  } else {
   $$sroa$010$036 = $32;
   while(1) {
    $38 = ((($$sroa$010$036)) + 24|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = HEAP32[$39>>2]|0;
    $41 = ((($40)) + 132|0);
    $42 = HEAP32[$41>>2]|0;
    FUNCTION_TABLE_vii[$42 & 8191]($39,$1);
    $43 = ((($$sroa$010$036)) + 4|0);
    $44 = HEAP32[$43>>2]|0;
    $45 = ($44|0)==(0|0);
    if ($45) {
     $46 = ((($$sroa$010$036)) + 8|0);
     $47 = HEAP32[$46>>2]|0;
     $48 = HEAP32[$47>>2]|0;
     $49 = ($48|0)==($$sroa$010$036|0);
     if ($49) {
      $$sroa$010$0$be = $47;
     } else {
      $54 = $46;
      while(1) {
       $53 = HEAP32[$54>>2]|0;
       $55 = ((($53)) + 8|0);
       $56 = HEAP32[$55>>2]|0;
       $57 = HEAP32[$56>>2]|0;
       $58 = ($57|0)==($53|0);
       if ($58) {
        $$sroa$010$0$be = $56;
        break;
       } else {
        $54 = $55;
       }
      }
     }
    } else {
     $$0$i$i$i$i = $44;
     while(1) {
      $51 = HEAP32[$$0$i$i$i$i>>2]|0;
      $52 = ($51|0)==(0|0);
      if ($52) {
       break;
      } else {
       $$0$i$i$i$i = $51;
      }
     }
     $$sroa$010$0$be = $$0$i$i$i$i;
    }
    $50 = ($$sroa$010$0$be|0)==($33|0);
    if ($50) {
     break;
    } else {
     $$sroa$010$036 = $$sroa$010$0$be;
    }
   }
   $$pre = HEAP32[$8>>2]|0;
   $37 = $$pre;
  }
  $35 = ((($$sink37)) + 12|0);
  $36 = ($35|0)==($37|0);
  if ($36) {
   break;
  } else {
   $$sink37 = $35;$59 = $37;
  }
 }
 return;
}
function __ZNK3osg8StateSet16releaseGLObjectsEPNS_5StateE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i$i$i = 0, $$0$i$i$i$i4 = 0, $$pre = 0, $$sroa$011$0$be = 0, $$sroa$011$029 = 0, $$sroa$017$030 = 0, $$sroa$024$0$be = 0, $$sroa$024$032 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 56|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 60|0);
 $5 = ($3|0)==($4|0);
 if (!($5)) {
  $$sroa$024$032 = $3;
  while(1) {
   $11 = ((($$sroa$024$032)) + 24|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = HEAP32[$12>>2]|0;
   $14 = ((($13)) + 136|0);
   $15 = HEAP32[$14>>2]|0;
   FUNCTION_TABLE_vii[$15 & 8191]($12,$1);
   $16 = ((($$sroa$024$032)) + 4|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = ($17|0)==(0|0);
   if ($18) {
    $19 = ((($$sroa$024$032)) + 8|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = HEAP32[$20>>2]|0;
    $22 = ($21|0)==($$sroa$024$032|0);
    if ($22) {
     $$sroa$024$0$be = $20;
    } else {
     $27 = $19;
     while(1) {
      $26 = HEAP32[$27>>2]|0;
      $28 = ((($26)) + 8|0);
      $29 = HEAP32[$28>>2]|0;
      $30 = HEAP32[$29>>2]|0;
      $31 = ($30|0)==($26|0);
      if ($31) {
       $$sroa$024$0$be = $29;
       break;
      } else {
       $27 = $28;
      }
     }
    }
   } else {
    $$0$i$i$i$i4 = $17;
    while(1) {
     $24 = HEAP32[$$0$i$i$i$i4>>2]|0;
     $25 = ($24|0)==(0|0);
     if ($25) {
      break;
     } else {
      $$0$i$i$i$i4 = $24;
     }
    }
    $$sroa$024$0$be = $$0$i$i$i$i4;
   }
   $23 = ($$sroa$024$0$be|0)==($4|0);
   if ($23) {
    break;
   } else {
    $$sroa$024$032 = $$sroa$024$0$be;
   }
  }
 }
 $6 = ((($0)) + 80|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($0)) + 84|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($7|0)==($9|0);
 if ($10) {
  return;
 } else {
  $$sroa$017$030 = $7;$59 = $9;
 }
 while(1) {
  $32 = HEAP32[$$sroa$017$030>>2]|0;
  $33 = ((($$sroa$017$030)) + 4|0);
  $34 = ($32|0)==($33|0);
  if ($34) {
   $37 = $59;
  } else {
   $$sroa$011$029 = $32;
   while(1) {
    $38 = ((($$sroa$011$029)) + 24|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = HEAP32[$39>>2]|0;
    $41 = ((($40)) + 136|0);
    $42 = HEAP32[$41>>2]|0;
    FUNCTION_TABLE_vii[$42 & 8191]($39,$1);
    $43 = ((($$sroa$011$029)) + 4|0);
    $44 = HEAP32[$43>>2]|0;
    $45 = ($44|0)==(0|0);
    if ($45) {
     $46 = ((($$sroa$011$029)) + 8|0);
     $47 = HEAP32[$46>>2]|0;
     $48 = HEAP32[$47>>2]|0;
     $49 = ($48|0)==($$sroa$011$029|0);
     if ($49) {
      $$sroa$011$0$be = $47;
     } else {
      $54 = $46;
      while(1) {
       $53 = HEAP32[$54>>2]|0;
       $55 = ((($53)) + 8|0);
       $56 = HEAP32[$55>>2]|0;
       $57 = HEAP32[$56>>2]|0;
       $58 = ($57|0)==($53|0);
       if ($58) {
        $$sroa$011$0$be = $56;
        break;
       } else {
        $54 = $55;
       }
      }
     }
    } else {
     $$0$i$i$i$i = $44;
     while(1) {
      $51 = HEAP32[$$0$i$i$i$i>>2]|0;
      $52 = ($51|0)==(0|0);
      if ($52) {
       break;
      } else {
       $$0$i$i$i$i = $51;
      }
     }
     $$sroa$011$0$be = $$0$i$i$i$i;
    }
    $50 = ($$sroa$011$0$be|0)==($33|0);
    if ($50) {
     break;
    } else {
     $$sroa$011$029 = $$sroa$011$0$be;
    }
   }
   $$pre = HEAP32[$8>>2]|0;
   $37 = $$pre;
  }
  $35 = ((($$sroa$017$030)) + 12|0);
  $36 = ($35|0)==($37|0);
  if ($36) {
   break;
  } else {
   $$sroa$017$030 = $35;$59 = $37;
  }
 }
 return;
}
function __ZN3osg8StateSetC2ERKS0_RKNS_6CopyOpE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$0$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i$i = 0, $$0$i$i$i$i$i$i152 = 0, $$0$i$i$i$i$i156 = 0, $$0$i$i$i$i135 = 0, $$0$i$i$i$i194 = 0, $$0$i$i166 = 0, $$0$ph$i$i = 0, $$0$ph$i$i163 = 0, $$0113308 = 0, $$014$i = 0, $$014$i180 = 0, $$024$i$i = 0, $$024$i$i165 = 0, $$025$i$i = 0, $$025$i$i173 = 0, $$025$i53$i = 0;
 var $$025$i53$i175 = 0, $$037$i = 0, $$037$i172 = 0, $$03752$i = 0, $$03752$i176 = 0, $$086 = 0, $$12 = 0, $$1298 = 0, $$18 = 0, $$18104 = 0, $$6 = 0, $$692 = 0, $$byval_copy = 0, $$byval_copy17 = 0, $$in$i$i = 0, $$in$i$i162 = 0, $$in16$i$i = 0, $$in8$i$i = 0, $$pre = 0, $$pre$i = 0;
 var $$pre$i$i = 0, $$pre$i$i$i$i$i$i = 0, $$pre$i$i$i$i$i$i150 = 0, $$pre$i$i178 = 0, $$pre$i116 = 0, $$pre353 = 0, $$sroa$0214$0$be = 0, $$sroa$0214$0305 = 0, $$sroa$0236$0$be = 0, $$sroa$0236$0306 = 0, $$sroa$0258$0$be = 0, $$sroa$0258$0310 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0;
 var $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0;
 var $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0;
 var $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0;
 var $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0;
 var $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0;
 var $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0;
 var $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0;
 var $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0;
 var $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0;
 var $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0;
 var $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0;
 var $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0;
 var $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0;
 var $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0;
 var $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0;
 var $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0;
 var $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0;
 var $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0;
 var $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0;
 var $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0;
 var $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0;
 var $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0;
 var $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0;
 var $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0;
 var $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0;
 var $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0;
 var $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0;
 var $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$i$i$i$i$i$i$index12Z2D = 0, $eh$lpad$body$i$i$i$i$i$i$indexZ2D = 0, $eh$lpad$body$index4Z2D = 0;
 var $eh$lpad$body$indexZ2D = 0, $scevgep$i$i$i = 0, $scevgep5$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $$byval_copy17 = sp + 28|0;
 $$byval_copy = sp + 24|0;
 $3 = sp + 20|0;
 $4 = sp + 16|0;
 $5 = sp + 12|0;
 $6 = sp + 8|0;
 $7 = sp + 4|0;
 $8 = sp;
 __ZN3osg6ObjectC2ERKS0_RKNS_6CopyOpE($0,$1,$2);
 HEAP32[$0>>2] = (66196);
 $9 = ((($0)) + 32|0);
 HEAP32[$9>>2] = 0;
 $10 = ((($0)) + 36|0);
 HEAP32[$10>>2] = 0;
 $11 = ((($0)) + 40|0);
 HEAP32[$11>>2] = 0;
 $12 = ((($0)) + 44|0);
 $13 = ((($0)) + 48|0);
 HEAP32[$13>>2] = 0;
 $14 = ((($0)) + 52|0);
 HEAP32[$14>>2] = 0;
 $15 = ((($0)) + 48|0);
 HEAP32[$12>>2] = $15;
 $16 = ((($0)) + 56|0);
 $17 = ((($0)) + 60|0);
 HEAP32[$17>>2] = 0;
 $18 = ((($0)) + 64|0);
 HEAP32[$18>>2] = 0;
 $19 = ((($0)) + 60|0);
 HEAP32[$16>>2] = $19;
 $20 = ((($0)) + 68|0);
 $21 = ((($0)) + 72|0);
 $22 = ((($0)) + 80|0);
 $23 = ((($0)) + 84|0);
 $24 = ((($0)) + 92|0);
 $25 = ((($0)) + 96|0);
 HEAP32[$25>>2] = 0;
 $26 = ((($0)) + 100|0);
 HEAP32[$26>>2] = 0;
 $27 = ((($0)) + 96|0);
 ;HEAP32[$20>>2]=0|0;HEAP32[$20+4>>2]=0|0;HEAP32[$20+8>>2]=0|0;HEAP32[$20+12>>2]=0|0;HEAP32[$20+16>>2]=0|0;HEAP32[$20+20>>2]=0|0;
 HEAP32[$24>>2] = $27;
 $28 = ((($0)) + 104|0);
 $29 = ((($0)) + 108|0);
 HEAP32[$29>>2] = 0;
 $30 = ((($0)) + 112|0);
 HEAP32[$30>>2] = 0;
 $31 = ((($0)) + 108|0);
 HEAP32[$28>>2] = $31;
 $32 = ((($0)) + 128|0);
 ;HEAP32[$32>>2]=0|0;HEAP32[$32+4>>2]=0|0;HEAP32[$32+8>>2]=0|0;
 $33 = ((($0)) + 140|0);
 $34 = ((($1)) + 140|0);
 $35 = HEAP8[$34>>0]|0;
 HEAP8[$33>>0] = $35;
 $36 = ((($0)) + 144|0);
 HEAP32[$36>>2] = 0;
 $37 = ((($0)) + 152|0);
 HEAP32[$37>>2] = 0;
 $38 = ($0|0)==($1|0);
 L1: do {
  if ($38) {
   label = 16;
  } else {
   __ZNSt3__26__treeINS_12__value_typeIjjEENS_19__map_value_compareIjS2_NS_4lessIjEELb1EEENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($12,0);
   HEAP32[$14>>2] = 0;
   HEAP32[$12>>2] = $15;
   HEAP32[$15>>2] = 0;
   $39 = ((($1)) + 44|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = ((($1)) + 48|0);
   $42 = ($40|0)==($41|0);
   if ($42) {
    label = 16;
   } else {
    $43 = $15;
    $$in8$i$i = $40;
    while(1) {
     $44 = ((($$in8$i$i)) + 16|0);
     HEAP32[$8>>2] = $43;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy>>2]=HEAP32[$8>>2]|0;
     $45 = (invoke_iiiiii(3940,($12|0),($$byval_copy|0),($6|0),($7|0),($44|0))|0);
     $46 = __THREW__; __THREW__ = 0;
     $47 = $46&1;
     if ($47) {
      break;
     }
     $48 = HEAP32[$45>>2]|0;
     $49 = ($48|0)==(0|0);
     if ($49) {
      __THREW__ = 0;
      $50 = (invoke_ii(3276,24)|0);
      $51 = __THREW__; __THREW__ = 0;
      $52 = $51&1;
      if ($52) {
       break;
      }
      $53 = ((($50)) + 16|0);
      $54 = $44;
      $55 = $54;
      $56 = HEAP32[$55>>2]|0;
      $57 = (($54) + 4)|0;
      $58 = $57;
      $59 = HEAP32[$58>>2]|0;
      $60 = $53;
      $61 = $60;
      HEAP32[$61>>2] = $56;
      $62 = (($60) + 4)|0;
      $63 = $62;
      HEAP32[$63>>2] = $59;
      $64 = HEAP32[$6>>2]|0;
      HEAP32[$50>>2] = 0;
      $65 = ((($50)) + 4|0);
      HEAP32[$65>>2] = 0;
      $66 = ((($50)) + 8|0);
      HEAP32[$66>>2] = $64;
      HEAP32[$45>>2] = $50;
      $67 = HEAP32[$12>>2]|0;
      $68 = HEAP32[$67>>2]|0;
      $69 = ($68|0)==(0|0);
      if ($69) {
       $72 = $50;
      } else {
       $70 = $68;
       HEAP32[$12>>2] = $70;
       $$pre$i$i$i$i$i$i = HEAP32[$45>>2]|0;
       $72 = $$pre$i$i$i$i$i$i;
      }
      $71 = HEAP32[$13>>2]|0;
      __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($71,$72);
      $73 = HEAP32[$14>>2]|0;
      $74 = (($73) + 1)|0;
      HEAP32[$14>>2] = $74;
     }
     $75 = ((($$in8$i$i)) + 4|0);
     $76 = HEAP32[$75>>2]|0;
     $77 = ($76|0)==(0|0);
     if ($77) {
      $78 = ((($$in8$i$i)) + 8|0);
      $79 = HEAP32[$78>>2]|0;
      $80 = HEAP32[$79>>2]|0;
      $81 = ($80|0)==($$in8$i$i|0);
      if ($81) {
       $$0$i$i$i$i$i = $79;
      } else {
       $85 = $78;
       while(1) {
        $84 = HEAP32[$85>>2]|0;
        $86 = ((($84)) + 8|0);
        $87 = HEAP32[$86>>2]|0;
        $88 = HEAP32[$87>>2]|0;
        $89 = ($88|0)==($84|0);
        if ($89) {
         $$0$i$i$i$i$i = $87;
         break;
        } else {
         $85 = $86;
        }
       }
      }
     } else {
      $$0$i$i$i$i$i$i = $76;
      while(1) {
       $82 = HEAP32[$$0$i$i$i$i$i$i>>2]|0;
       $83 = ($82|0)==(0|0);
       if ($83) {
        break;
       } else {
        $$0$i$i$i$i$i$i = $82;
       }
      }
      $$0$i$i$i$i$i = $$0$i$i$i$i$i$i;
     }
     $90 = ($$0$i$i$i$i$i|0)==($41|0);
     if ($90) {
      label = 16;
      break L1;
     } else {
      $$in8$i$i = $$0$i$i$i$i$i;
     }
    }
    $103 = ___cxa_find_matching_catch_2()|0;
    $104 = tempRet0;
    $eh$lpad$body$index4Z2D = $104;$eh$lpad$body$indexZ2D = $103;
    label = 23;
   }
  }
 } while(0);
 L23: do {
  if ((label|0) == 16) {
   $91 = ((($1)) + 56|0);
   $92 = HEAP32[$91>>2]|0;
   $93 = ((($1)) + 60|0);
   $94 = ($92|0)==($93|0);
   L25: do {
    if (!($94)) {
     $$sroa$0258$0310 = $92;
     while(1) {
      $107 = ((($$sroa$0258$0310)) + 16|0);
      $108 = HEAP32[$2>>2]|0;
      $109 = ((($108)) + 28|0);
      $110 = HEAP32[$109>>2]|0;
      $111 = ((($$sroa$0258$0310)) + 24|0);
      $112 = HEAP32[$111>>2]|0;
      __THREW__ = 0;
      $113 = (invoke_iii($110|0,($2|0),($112|0))|0);
      $114 = __THREW__; __THREW__ = 0;
      $115 = $114&1;
      if ($115) {
       label = 52;
       break;
      }
      $116 = ($113|0)==(0|0);
      if (!($116)) {
       $117 = ((($113)) + 8|0);
       $118 = HEAP32[$117>>2]|0;HEAP32[$117>>2] = (($118+1)|0);
       $119 = ((($$sroa$0258$0310)) + 28|0);
       $120 = HEAP32[$117>>2]|0;HEAP32[$117>>2] = (($120+1)|0);
       $121 = HEAP32[$119>>2]|0;
       $122 = HEAP32[$19>>2]|0;
       $123 = ($122|0)==(0|0);
       do {
        if ($123) {
         $$025$i$i = $19;$$037$i = $19;$140 = $122;
         label = 38;
        } else {
         $124 = HEAP32[$107>>2]|0;
         $125 = ((($$sroa$0258$0310)) + 20|0);
         $126 = HEAP32[$125>>2]|0;
         $$0$i$i = $17;$$024$i$i = $122;$645 = $122;
         L34: while(1) {
          $127 = ((($$024$i$i)) + 16|0);
          $128 = HEAP32[$127>>2]|0;
          $129 = ($124|0)<($128|0);
          do {
           if ($129) {
            label = 32;
           } else {
            $130 = ($128|0)<($124|0);
            if (!($130)) {
             $131 = ((($$024$i$i)) + 20|0);
             $132 = HEAP32[$131>>2]|0;
             $133 = ($126>>>0)<($132>>>0);
             if ($133) {
              label = 32;
              break;
             }
             $136 = ($132>>>0)<($126>>>0);
             if (!($136)) {
              label = 37;
              break L34;
             }
            }
            $137 = ((($$024$i$i)) + 4|0);
            $138 = HEAP32[$137>>2]|0;
            $139 = ($138|0)==(0|0);
            if ($139) {
             label = 36;
             break L34;
            } else {
             $$0$ph$i$i = $137;$$in$i$i = $138;
            }
           }
          } while(0);
          if ((label|0) == 32) {
           label = 0;
           $134 = HEAP32[$$024$i$i>>2]|0;
           $135 = ($134|0)==(0|0);
           if ($135) {
            label = 33;
            break;
           } else {
            $$0$ph$i$i = $$024$i$i;$$in$i$i = $134;
           }
          }
          $$0$i$i = $$0$ph$i$i;$$024$i$i = $$in$i$i;$645 = $$in$i$i;
         }
         if ((label|0) == 33) {
          label = 0;
          $$025$i53$i = $$024$i$i;$$03752$i = $$024$i$i;
          label = 39;
          break;
         }
         else if ((label|0) == 36) {
          label = 0;
          $$025$i53$i = $137;$$03752$i = $$024$i$i;
          label = 39;
          break;
         }
         else if ((label|0) == 37) {
          label = 0;
          $$025$i$i = $$0$i$i;$$037$i = $$024$i$i;$140 = $645;
          label = 38;
          break;
         }
        }
       } while(0);
       if ((label|0) == 38) {
        label = 0;
        $141 = ($140|0)==(0|0);
        if ($141) {
         $$025$i53$i = $$025$i$i;$$03752$i = $$037$i;
         label = 39;
        } else {
         $$014$i = $140;
        }
       }
       if ((label|0) == 39) {
        label = 0;
        __THREW__ = 0;
        $142 = (invoke_ii(3276,32)|0);
        $143 = __THREW__; __THREW__ = 0;
        $144 = $143&1;
        if ($144) {
         label = 55;
         break;
        }
        $145 = ((($142)) + 16|0);
        $146 = $107;
        $147 = $146;
        $148 = HEAP32[$147>>2]|0;
        $149 = (($146) + 4)|0;
        $150 = $149;
        $151 = HEAP32[$150>>2]|0;
        $152 = $145;
        $153 = $152;
        HEAP32[$153>>2] = $148;
        $154 = (($152) + 4)|0;
        $155 = $154;
        HEAP32[$155>>2] = $151;
        $156 = ((($142)) + 24|0);
        HEAP32[$156>>2] = 0;
        $157 = ((($142)) + 28|0);
        HEAP32[$157>>2] = 0;
        HEAP32[$142>>2] = 0;
        $158 = ((($142)) + 4|0);
        HEAP32[$158>>2] = 0;
        $159 = ((($142)) + 8|0);
        HEAP32[$159>>2] = $$03752$i;
        HEAP32[$$025$i53$i>>2] = $142;
        $160 = HEAP32[$16>>2]|0;
        $161 = HEAP32[$160>>2]|0;
        $162 = ($161|0)==(0|0);
        if ($162) {
         $165 = $142;
        } else {
         $163 = $161;
         HEAP32[$16>>2] = $163;
         $$pre$i$i = HEAP32[$$025$i53$i>>2]|0;
         $165 = $$pre$i$i;
        }
        $164 = HEAP32[$17>>2]|0;
        __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($164,$165);
        $166 = HEAP32[$18>>2]|0;
        $167 = (($166) + 1)|0;
        HEAP32[$18>>2] = $167;
        $$014$i = $142;
       }
       $168 = ((($$014$i)) + 24|0);
       $169 = HEAP32[$168>>2]|0;
       $170 = ($169|0)==($113|0);
       if (!($170)) {
        HEAP32[$168>>2] = $113;
        $171 = HEAP32[$117>>2]|0;HEAP32[$117>>2] = (($171+1)|0);
        $172 = ($169|0)==(0|0);
        if (!($172)) {
         $173 = ((($169)) + 8|0);
         $174 = HEAP32[$173>>2]|0;HEAP32[$173>>2] = (($174-1)|0);
         $175 = ($174|0)==(1);
         if ($175) {
          __THREW__ = 0;
          invoke_viii(3262,($169|0),1,1);
          $176 = __THREW__; __THREW__ = 0;
          $177 = $176&1;
          if ($177) {
           label = 55;
           break;
          }
         }
        }
       }
       $178 = ((($$014$i)) + 28|0);
       HEAP32[$178>>2] = $121;
       $179 = HEAP32[$117>>2]|0;HEAP32[$117>>2] = (($179-1)|0);
       $180 = ($179|0)==(1);
       if ($180) {
        __THREW__ = 0;
        invoke_viii(3262,($113|0),1,1);
        $181 = __THREW__; __THREW__ = 0;
        $182 = $181&1;
        if ($182) {
         label = 54;
         break;
        }
       }
       $183 = HEAP32[$117>>2]|0;HEAP32[$117>>2] = (($183-1)|0);
       $184 = ($183|0)==(1);
       if ($184) {
        __THREW__ = 0;
        invoke_viii(3262,($113|0),1,1);
        $185 = __THREW__; __THREW__ = 0;
        $186 = $185&1;
        if ($186) {
         label = 53;
         break;
        }
       }
       __THREW__ = 0;
       invoke_vii(3942,($113|0),($0|0));
       $187 = __THREW__; __THREW__ = 0;
       $188 = $187&1;
       if ($188) {
        label = 59;
        break;
       }
      }
      $207 = ((($$sroa$0258$0310)) + 4|0);
      $208 = HEAP32[$207>>2]|0;
      $209 = ($208|0)==(0|0);
      if ($209) {
       $210 = ((($$sroa$0258$0310)) + 8|0);
       $211 = HEAP32[$210>>2]|0;
       $212 = HEAP32[$211>>2]|0;
       $213 = ($212|0)==($$sroa$0258$0310|0);
       if ($213) {
        $$sroa$0258$0$be = $211;
       } else {
        $218 = $210;
        while(1) {
         $217 = HEAP32[$218>>2]|0;
         $219 = ((($217)) + 8|0);
         $220 = HEAP32[$219>>2]|0;
         $221 = HEAP32[$220>>2]|0;
         $222 = ($221|0)==($217|0);
         if ($222) {
          $$sroa$0258$0$be = $220;
          break;
         } else {
          $218 = $219;
         }
        }
       }
      } else {
       $$0$i$i$i$i = $208;
       while(1) {
        $215 = HEAP32[$$0$i$i$i$i>>2]|0;
        $216 = ($215|0)==(0|0);
        if ($216) {
         break;
        } else {
         $$0$i$i$i$i = $215;
        }
       }
       $$sroa$0258$0$be = $$0$i$i$i$i;
      }
      $214 = ($$sroa$0258$0$be|0)==($93|0);
      if ($214) {
       break L25;
      } else {
       $$sroa$0258$0310 = $$sroa$0258$0$be;
      }
     }
     if ((label|0) == 52) {
      $189 = ___cxa_find_matching_catch_2()|0;
      $190 = tempRet0;
      $$18 = $189;$$18104 = $190;
      break L23;
     }
     else if ((label|0) == 53) {
      $191 = ___cxa_find_matching_catch_2()|0;
      $192 = tempRet0;
      $$18 = $191;$$18104 = $192;
      break L23;
     }
     else if ((label|0) == 54) {
      $193 = ___cxa_find_matching_catch_2()|0;
      $194 = tempRet0;
      $$0 = $193;$$086 = $194;
     }
     else if ((label|0) == 55) {
      $195 = ___cxa_find_matching_catch_2()|0;
      $196 = tempRet0;
      $197 = HEAP32[$117>>2]|0;HEAP32[$117>>2] = (($197-1)|0);
      $198 = ($197|0)==(1);
      if ($198) {
       __THREW__ = 0;
       invoke_viii(3262,($113|0),1,1);
       $199 = __THREW__; __THREW__ = 0;
       $200 = $199&1;
       if ($200) {
        $643 = ___cxa_find_matching_catch_3(0|0)|0;
        $644 = tempRet0;
        ___clang_call_terminate($643);
        // unreachable;
       } else {
        $$0 = $195;$$086 = $196;
       }
      } else {
       $$0 = $195;$$086 = $196;
      }
     }
     else if ((label|0) == 59) {
      $205 = ___cxa_find_matching_catch_2()|0;
      $206 = tempRet0;
      $$18 = $205;$$18104 = $206;
      break L23;
     }
     $201 = HEAP32[$117>>2]|0;HEAP32[$117>>2] = (($201-1)|0);
     $202 = ($201|0)==(1);
     if (!($202)) {
      $$18 = $$0;$$18104 = $$086;
      break L23;
     }
     __THREW__ = 0;
     invoke_viii(3262,($113|0),1,1);
     $203 = __THREW__; __THREW__ = 0;
     $204 = $203&1;
     if (!($204)) {
      $$18 = $$0;$$18104 = $$086;
      break L23;
     }
     $643 = ___cxa_find_matching_catch_3(0|0)|0;
     $644 = tempRet0;
     ___clang_call_terminate($643);
     // unreachable;
    }
   } while(0);
   if ($38) {
    label = 66;
   } else {
    $95 = ((($1)) + 68|0);
    $96 = HEAP32[$95>>2]|0;
    $97 = ((($1)) + 72|0);
    $98 = HEAP32[$97>>2]|0;
    __THREW__ = 0;
    invoke_viii(3941,($20|0),($96|0),($98|0));
    $99 = __THREW__; __THREW__ = 0;
    $100 = $99&1;
    if (!($100)) {
     label = 66;
    }
   }
   do {
    if ((label|0) == 66) {
     $223 = ((($1)) + 80|0);
     $224 = ((($1)) + 84|0);
     $225 = HEAP32[$224>>2]|0;
     $226 = HEAP32[$223>>2]|0;
     $227 = (($225) - ($226))|0;
     $228 = (($227|0) / 12)&-1;
     $229 = HEAP32[$23>>2]|0;
     $230 = HEAP32[$22>>2]|0;
     $231 = (($229) - ($230))|0;
     $232 = (($231|0) / 12)&-1;
     $233 = ($228>>>0)>($232>>>0);
     $234 = $230;
     $235 = $229;
     if ($233) {
      $236 = (($228) - ($232))|0;
      __THREW__ = 0;
      invoke_vii(3943,($22|0),($236|0));
      $237 = __THREW__; __THREW__ = 0;
      $238 = $237&1;
      if ($238) {
       break;
      }
     } else {
      $239 = ($228>>>0)<($232>>>0);
      if ($239) {
       $240 = (($234) + (($228*12)|0)|0);
       $241 = ($235|0)==($240|0);
       if (!($241)) {
        $243 = $235;
        while(1) {
         $242 = ((($243)) + -12|0);
         HEAP32[$23>>2] = $242;
         $244 = ((($243)) + -8|0);
         $245 = HEAP32[$244>>2]|0;
         __ZNSt3__26__treeINS_12__value_typeINS_4pairIN3osg14StateAttribute4TypeEjEENS2_INS3_7ref_ptrIS4_EEjEEEENS_19__map_value_compareIS6_SA_NS_4lessIS6_EELb1EEENS_9allocatorISA_EEE7destroyEPNS_11__tree_nodeISA_PvEE($242,$245);
         $246 = HEAP32[$23>>2]|0;
         $247 = ($246|0)==($240|0);
         if ($247) {
          break;
         } else {
          $243 = $246;
         }
        }
       }
      }
     }
     $248 = HEAP32[$224>>2]|0;
     $249 = HEAP32[$223>>2]|0;
     $250 = ($248|0)==($249|0);
     L101: do {
      if (!($250)) {
       $$0113308 = 0;$255 = $249;$646 = $248;
       L103: while(1) {
        $256 = $255;
        $257 = HEAP32[$22>>2]|0;
        $258 = (($257) + (($$0113308*12)|0)|0);
        $259 = (($256) + (($$0113308*12)|0)|0);
        $260 = HEAP32[$259>>2]|0;
        $261 = (((($256) + (($$0113308*12)|0)|0)) + 4|0);
        $262 = ($260|0)==($261|0);
        if ($262) {
         $268 = $255;$269 = $646;
        } else {
         $263 = (((($257) + (($$0113308*12)|0)|0)) + 4|0);
         $264 = (((($257) + (($$0113308*12)|0)|0)) + 4|0);
         $265 = (((($257) + (($$0113308*12)|0)|0)) + 8|0);
         $$sroa$0236$0306 = $260;
         while(1) {
          $272 = ((($$sroa$0236$0306)) + 16|0);
          $273 = HEAP32[$2>>2]|0;
          $274 = ((($273)) + 28|0);
          $275 = HEAP32[$274>>2]|0;
          $276 = ((($$sroa$0236$0306)) + 24|0);
          $277 = HEAP32[$276>>2]|0;
          __THREW__ = 0;
          $278 = (invoke_iii($275|0,($2|0),($277|0))|0);
          $279 = __THREW__; __THREW__ = 0;
          $280 = $279&1;
          if ($280) {
           label = 107;
           break L103;
          }
          $281 = ($278|0)==(0|0);
          if (!($281)) {
           $282 = ((($278)) + 8|0);
           $283 = HEAP32[$282>>2]|0;HEAP32[$282>>2] = (($283+1)|0);
           $284 = ((($$sroa$0236$0306)) + 28|0);
           $285 = HEAP32[$282>>2]|0;HEAP32[$282>>2] = (($285+1)|0);
           $286 = HEAP32[$284>>2]|0;
           $287 = HEAP32[$263>>2]|0;
           $288 = ($287|0)==(0|0);
           do {
            if ($288) {
             $$025$i$i173 = $263;$$037$i172 = $263;$305 = $287;
             label = 93;
            } else {
             $289 = HEAP32[$272>>2]|0;
             $290 = ((($$sroa$0236$0306)) + 20|0);
             $291 = HEAP32[$290>>2]|0;
             $$0$i$i166 = $264;$$024$i$i165 = $287;$647 = $287;
             L114: while(1) {
              $292 = ((($$024$i$i165)) + 16|0);
              $293 = HEAP32[$292>>2]|0;
              $294 = ($289|0)<($293|0);
              do {
               if ($294) {
                label = 87;
               } else {
                $295 = ($293|0)<($289|0);
                if (!($295)) {
                 $296 = ((($$024$i$i165)) + 20|0);
                 $297 = HEAP32[$296>>2]|0;
                 $298 = ($291>>>0)<($297>>>0);
                 if ($298) {
                  label = 87;
                  break;
                 }
                 $301 = ($297>>>0)<($291>>>0);
                 if (!($301)) {
                  label = 92;
                  break L114;
                 }
                }
                $302 = ((($$024$i$i165)) + 4|0);
                $303 = HEAP32[$302>>2]|0;
                $304 = ($303|0)==(0|0);
                if ($304) {
                 label = 91;
                 break L114;
                } else {
                 $$0$ph$i$i163 = $302;$$in$i$i162 = $303;
                }
               }
              } while(0);
              if ((label|0) == 87) {
               label = 0;
               $299 = HEAP32[$$024$i$i165>>2]|0;
               $300 = ($299|0)==(0|0);
               if ($300) {
                label = 88;
                break;
               } else {
                $$0$ph$i$i163 = $$024$i$i165;$$in$i$i162 = $299;
               }
              }
              $$0$i$i166 = $$0$ph$i$i163;$$024$i$i165 = $$in$i$i162;$647 = $$in$i$i162;
             }
             if ((label|0) == 88) {
              label = 0;
              $$025$i53$i175 = $$024$i$i165;$$03752$i176 = $$024$i$i165;
              label = 94;
              break;
             }
             else if ((label|0) == 91) {
              label = 0;
              $$025$i53$i175 = $302;$$03752$i176 = $$024$i$i165;
              label = 94;
              break;
             }
             else if ((label|0) == 92) {
              label = 0;
              $$025$i$i173 = $$0$i$i166;$$037$i172 = $$024$i$i165;$305 = $647;
              label = 93;
              break;
             }
            }
           } while(0);
           if ((label|0) == 93) {
            label = 0;
            $306 = ($305|0)==(0|0);
            if ($306) {
             $$025$i53$i175 = $$025$i$i173;$$03752$i176 = $$037$i172;
             label = 94;
            } else {
             $$014$i180 = $305;
            }
           }
           if ((label|0) == 94) {
            label = 0;
            __THREW__ = 0;
            $307 = (invoke_ii(3276,32)|0);
            $308 = __THREW__; __THREW__ = 0;
            $309 = $308&1;
            if ($309) {
             label = 110;
             break L103;
            }
            $310 = ((($307)) + 16|0);
            $311 = $272;
            $312 = $311;
            $313 = HEAP32[$312>>2]|0;
            $314 = (($311) + 4)|0;
            $315 = $314;
            $316 = HEAP32[$315>>2]|0;
            $317 = $310;
            $318 = $317;
            HEAP32[$318>>2] = $313;
            $319 = (($317) + 4)|0;
            $320 = $319;
            HEAP32[$320>>2] = $316;
            $321 = ((($307)) + 24|0);
            HEAP32[$321>>2] = 0;
            $322 = ((($307)) + 28|0);
            HEAP32[$322>>2] = 0;
            HEAP32[$307>>2] = 0;
            $323 = ((($307)) + 4|0);
            HEAP32[$323>>2] = 0;
            $324 = ((($307)) + 8|0);
            HEAP32[$324>>2] = $$03752$i176;
            HEAP32[$$025$i53$i175>>2] = $307;
            $325 = HEAP32[$258>>2]|0;
            $326 = HEAP32[$325>>2]|0;
            $327 = ($326|0)==(0|0);
            if ($327) {
             $330 = $307;
            } else {
             $328 = $326;
             HEAP32[$258>>2] = $328;
             $$pre$i$i178 = HEAP32[$$025$i53$i175>>2]|0;
             $330 = $$pre$i$i178;
            }
            $329 = HEAP32[$264>>2]|0;
            __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($329,$330);
            $331 = HEAP32[$265>>2]|0;
            $332 = (($331) + 1)|0;
            HEAP32[$265>>2] = $332;
            $$014$i180 = $307;
           }
           $333 = ((($$014$i180)) + 24|0);
           $334 = HEAP32[$333>>2]|0;
           $335 = ($334|0)==($278|0);
           if (!($335)) {
            HEAP32[$333>>2] = $278;
            $336 = HEAP32[$282>>2]|0;HEAP32[$282>>2] = (($336+1)|0);
            $337 = ($334|0)==(0|0);
            if (!($337)) {
             $338 = ((($334)) + 8|0);
             $339 = HEAP32[$338>>2]|0;HEAP32[$338>>2] = (($339-1)|0);
             $340 = ($339|0)==(1);
             if ($340) {
              __THREW__ = 0;
              invoke_viii(3262,($334|0),1,1);
              $341 = __THREW__; __THREW__ = 0;
              $342 = $341&1;
              if ($342) {
               label = 110;
               break L103;
              }
             }
            }
           }
           $343 = ((($$014$i180)) + 28|0);
           HEAP32[$343>>2] = $286;
           $344 = HEAP32[$282>>2]|0;HEAP32[$282>>2] = (($344-1)|0);
           $345 = ($344|0)==(1);
           if ($345) {
            __THREW__ = 0;
            invoke_viii(3262,($278|0),1,1);
            $346 = __THREW__; __THREW__ = 0;
            $347 = $346&1;
            if ($347) {
             label = 109;
             break L103;
            }
           }
           $348 = HEAP32[$282>>2]|0;HEAP32[$282>>2] = (($348-1)|0);
           $349 = ($348|0)==(1);
           if ($349) {
            __THREW__ = 0;
            invoke_viii(3262,($278|0),1,1);
            $350 = __THREW__; __THREW__ = 0;
            $351 = $350&1;
            if ($351) {
             label = 108;
             break L103;
            }
           }
           __THREW__ = 0;
           invoke_vii(3942,($278|0),($0|0));
           $352 = __THREW__; __THREW__ = 0;
           $353 = $352&1;
           if ($353) {
            label = 114;
            break L103;
           }
          }
          $372 = ((($$sroa$0236$0306)) + 4|0);
          $373 = HEAP32[$372>>2]|0;
          $374 = ($373|0)==(0|0);
          if ($374) {
           $375 = ((($$sroa$0236$0306)) + 8|0);
           $376 = HEAP32[$375>>2]|0;
           $377 = HEAP32[$376>>2]|0;
           $378 = ($377|0)==($$sroa$0236$0306|0);
           if ($378) {
            $$sroa$0236$0$be = $376;
           } else {
            $383 = $375;
            while(1) {
             $382 = HEAP32[$383>>2]|0;
             $384 = ((($382)) + 8|0);
             $385 = HEAP32[$384>>2]|0;
             $386 = HEAP32[$385>>2]|0;
             $387 = ($386|0)==($382|0);
             if ($387) {
              $$sroa$0236$0$be = $385;
              break;
             } else {
              $383 = $384;
             }
            }
           }
          } else {
           $$0$i$i$i$i194 = $373;
           while(1) {
            $380 = HEAP32[$$0$i$i$i$i194>>2]|0;
            $381 = ($380|0)==(0|0);
            if ($381) {
             break;
            } else {
             $$0$i$i$i$i194 = $380;
            }
           }
           $$sroa$0236$0$be = $$0$i$i$i$i194;
          }
          $379 = ($$sroa$0236$0$be|0)==($261|0);
          if ($379) {
           break;
          } else {
           $$sroa$0236$0306 = $$sroa$0236$0$be;
          }
         }
         $$pre = HEAP32[$224>>2]|0;
         $$pre353 = HEAP32[$223>>2]|0;
         $268 = $$pre353;$269 = $$pre;
        }
        $266 = (($$0113308) + 1)|0;
        $267 = (($269) - ($268))|0;
        $270 = (($267|0) / 12)&-1;
        $271 = ($266>>>0)<($270>>>0);
        if ($271) {
         $$0113308 = $266;$255 = $268;$646 = $269;
        } else {
         break L101;
        }
       }
       if ((label|0) == 107) {
        $354 = ___cxa_find_matching_catch_2()|0;
        $355 = tempRet0;
        $$18 = $354;$$18104 = $355;
        break L23;
       }
       else if ((label|0) == 108) {
        $356 = ___cxa_find_matching_catch_2()|0;
        $357 = tempRet0;
        $$18 = $356;$$18104 = $357;
        break L23;
       }
       else if ((label|0) == 109) {
        $358 = ___cxa_find_matching_catch_2()|0;
        $359 = tempRet0;
        $$6 = $358;$$692 = $359;
       }
       else if ((label|0) == 110) {
        $360 = ___cxa_find_matching_catch_2()|0;
        $361 = tempRet0;
        $362 = HEAP32[$282>>2]|0;HEAP32[$282>>2] = (($362-1)|0);
        $363 = ($362|0)==(1);
        if ($363) {
         __THREW__ = 0;
         invoke_viii(3262,($278|0),1,1);
         $364 = __THREW__; __THREW__ = 0;
         $365 = $364&1;
         if ($365) {
          $643 = ___cxa_find_matching_catch_3(0|0)|0;
          $644 = tempRet0;
          ___clang_call_terminate($643);
          // unreachable;
         } else {
          $$6 = $360;$$692 = $361;
         }
        } else {
         $$6 = $360;$$692 = $361;
        }
       }
       else if ((label|0) == 114) {
        $370 = ___cxa_find_matching_catch_2()|0;
        $371 = tempRet0;
        $$18 = $370;$$18104 = $371;
        break L23;
       }
       $366 = HEAP32[$282>>2]|0;HEAP32[$282>>2] = (($366-1)|0);
       $367 = ($366|0)==(1);
       if (!($367)) {
        $$18 = $$6;$$18104 = $$692;
        break L23;
       }
       __THREW__ = 0;
       invoke_viii(3262,($278|0),1,1);
       $368 = __THREW__; __THREW__ = 0;
       $369 = $368&1;
       if (!($369)) {
        $$18 = $$6;$$18104 = $$692;
        break L23;
       }
       $643 = ___cxa_find_matching_catch_3(0|0)|0;
       $644 = tempRet0;
       ___clang_call_terminate($643);
       // unreachable;
      }
     } while(0);
     $251 = ((($1)) + 92|0);
     $252 = HEAP32[$251>>2]|0;
     $253 = ((($1)) + 96|0);
     $254 = ($252|0)==($253|0);
     L172: do {
      if (!($254)) {
       $$sroa$0214$0305 = $252;
       while(1) {
        $448 = ((($$sroa$0214$0305)) + 16|0);
        $449 = HEAP32[$2>>2]|0;
        $450 = ((($449)) + 52|0);
        $451 = HEAP32[$450>>2]|0;
        $452 = ((($$sroa$0214$0305)) + 28|0);
        $453 = HEAP32[$452>>2]|0;
        __THREW__ = 0;
        $454 = (invoke_iii($451|0,($2|0),($453|0))|0);
        $455 = __THREW__; __THREW__ = 0;
        $456 = $455&1;
        if ($456) {
         label = 154;
         break;
        }
        $457 = ($454|0)==(0|0);
        if (!($457)) {
         $458 = ((($454)) + 8|0);
         $459 = HEAP32[$458>>2]|0;HEAP32[$458>>2] = (($459+1)|0);
         $460 = ((($$sroa$0214$0305)) + 32|0);
         $461 = HEAP32[$458>>2]|0;HEAP32[$458>>2] = (($461+1)|0);
         $462 = HEAP32[$460>>2]|0;
         __THREW__ = 0;
         $463 = (invoke_iii(3945,($24|0),($448|0))|0);
         $464 = __THREW__; __THREW__ = 0;
         $465 = $464&1;
         if ($465) {
          label = 157;
          break;
         }
         $466 = HEAP32[$463>>2]|0;
         $467 = ($466|0)==($454|0);
         if (!($467)) {
          HEAP32[$463>>2] = $454;
          $468 = HEAP32[$458>>2]|0;HEAP32[$458>>2] = (($468+1)|0);
          $469 = ($466|0)==(0|0);
          if (!($469)) {
           $470 = ((($466)) + 8|0);
           $471 = HEAP32[$470>>2]|0;HEAP32[$470>>2] = (($471-1)|0);
           $472 = ($471|0)==(1);
           if ($472) {
            __THREW__ = 0;
            invoke_viii(3262,($466|0),1,1);
            $473 = __THREW__; __THREW__ = 0;
            $474 = $473&1;
            if ($474) {
             label = 157;
             break;
            }
           }
          }
         }
         $475 = ((($463)) + 4|0);
         HEAP32[$475>>2] = $462;
         $476 = HEAP32[$458>>2]|0;HEAP32[$458>>2] = (($476-1)|0);
         $477 = ($476|0)==(1);
         if ($477) {
          __THREW__ = 0;
          invoke_viii(3262,($454|0),1,1);
          $478 = __THREW__; __THREW__ = 0;
          $479 = $478&1;
          if ($479) {
           label = 156;
           break;
          }
         }
         $480 = HEAP32[$458>>2]|0;HEAP32[$458>>2] = (($480-1)|0);
         $481 = ($480|0)==(1);
         if ($481) {
          __THREW__ = 0;
          invoke_viii(3262,($454|0),1,1);
          $482 = __THREW__; __THREW__ = 0;
          $483 = $482&1;
          if ($483) {
           label = 155;
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3946,($454|0),($0|0));
         $484 = __THREW__; __THREW__ = 0;
         $485 = $484&1;
         if ($485) {
          label = 161;
          break;
         }
        }
        $504 = ((($$sroa$0214$0305)) + 4|0);
        $505 = HEAP32[$504>>2]|0;
        $506 = ($505|0)==(0|0);
        if ($506) {
         $507 = ((($$sroa$0214$0305)) + 8|0);
         $508 = HEAP32[$507>>2]|0;
         $509 = HEAP32[$508>>2]|0;
         $510 = ($509|0)==($$sroa$0214$0305|0);
         if ($510) {
          $$sroa$0214$0$be = $508;
         } else {
          $515 = $507;
          while(1) {
           $514 = HEAP32[$515>>2]|0;
           $516 = ((($514)) + 8|0);
           $517 = HEAP32[$516>>2]|0;
           $518 = HEAP32[$517>>2]|0;
           $519 = ($518|0)==($514|0);
           if ($519) {
            $$sroa$0214$0$be = $517;
            break;
           } else {
            $515 = $516;
           }
          }
         }
        } else {
         $$0$i$i$i$i135 = $505;
         while(1) {
          $512 = HEAP32[$$0$i$i$i$i135>>2]|0;
          $513 = ($512|0)==(0|0);
          if ($513) {
           break;
          } else {
           $$0$i$i$i$i135 = $512;
          }
         }
         $$sroa$0214$0$be = $$0$i$i$i$i135;
        }
        $511 = ($$sroa$0214$0$be|0)==($253|0);
        if ($511) {
         break L172;
        } else {
         $$sroa$0214$0305 = $$sroa$0214$0$be;
        }
       }
       if ((label|0) == 154) {
        $486 = ___cxa_find_matching_catch_2()|0;
        $487 = tempRet0;
        $$18 = $486;$$18104 = $487;
        break L23;
       }
       else if ((label|0) == 155) {
        $488 = ___cxa_find_matching_catch_2()|0;
        $489 = tempRet0;
        $$18 = $488;$$18104 = $489;
        break L23;
       }
       else if ((label|0) == 156) {
        $490 = ___cxa_find_matching_catch_2()|0;
        $491 = tempRet0;
        $$12 = $490;$$1298 = $491;
       }
       else if ((label|0) == 157) {
        $492 = ___cxa_find_matching_catch_2()|0;
        $493 = tempRet0;
        $494 = HEAP32[$458>>2]|0;HEAP32[$458>>2] = (($494-1)|0);
        $495 = ($494|0)==(1);
        if ($495) {
         __THREW__ = 0;
         invoke_viii(3262,($454|0),1,1);
         $496 = __THREW__; __THREW__ = 0;
         $497 = $496&1;
         if ($497) {
          $643 = ___cxa_find_matching_catch_3(0|0)|0;
          $644 = tempRet0;
          ___clang_call_terminate($643);
          // unreachable;
         } else {
          $$12 = $492;$$1298 = $493;
         }
        } else {
         $$12 = $492;$$1298 = $493;
        }
       }
       else if ((label|0) == 161) {
        $502 = ___cxa_find_matching_catch_2()|0;
        $503 = tempRet0;
        $$18 = $502;$$18104 = $503;
        break L23;
       }
       $498 = HEAP32[$458>>2]|0;HEAP32[$458>>2] = (($498-1)|0);
       $499 = ($498|0)==(1);
       if (!($499)) {
        $$18 = $$12;$$18104 = $$1298;
        break L23;
       }
       __THREW__ = 0;
       invoke_viii(3262,($454|0),1,1);
       $500 = __THREW__; __THREW__ = 0;
       $501 = $500&1;
       if (!($501)) {
        $$18 = $$12;$$18104 = $$1298;
        break L23;
       }
       $643 = ___cxa_find_matching_catch_3(0|0)|0;
       $644 = tempRet0;
       ___clang_call_terminate($643);
       // unreachable;
      }
     } while(0);
     L212: do {
      if (!($38)) {
       $388 = HEAP32[$31>>2]|0;
       __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4pairIS7_jEEEENS_19__map_value_compareIS7_SA_NS_4lessIS7_EELb1EEENS5_ISA_EEE7destroyEPNS_11__tree_nodeISA_PvEE($28,$388);
       HEAP32[$30>>2] = 0;
       HEAP32[$28>>2] = $31;
       HEAP32[$31>>2] = 0;
       $389 = ((($1)) + 104|0);
       $390 = HEAP32[$389>>2]|0;
       $391 = ((($1)) + 108|0);
       $392 = ($390|0)==($391|0);
       if (!($392)) {
        $393 = $31;
        $$in16$i$i = $390;
        while(1) {
         $394 = ((($$in16$i$i)) + 16|0);
         HEAP32[$5>>2] = $393;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy17>>2]=HEAP32[$5>>2]|0;
         $395 = (invoke_iiiiii(3944,($28|0),($$byval_copy17|0),($3|0),($4|0),($394|0))|0);
         $396 = __THREW__; __THREW__ = 0;
         $397 = $396&1;
         if ($397) {
          label = 20;
          break;
         }
         $398 = HEAP32[$395>>2]|0;
         $399 = ($398|0)==(0|0);
         if ($399) {
          __THREW__ = 0;
          $400 = (invoke_ii(3276,44)|0);
          $401 = __THREW__; __THREW__ = 0;
          $402 = $401&1;
          if ($402) {
           label = 20;
           break;
          }
          $403 = ((($400)) + 16|0);
          __THREW__ = 0;
          invoke_vii(3457,($403|0),($394|0));
          $404 = __THREW__; __THREW__ = 0;
          $405 = $404&1;
          if ($405) {
           label = 131;
           break;
          }
          $406 = ((($400)) + 28|0);
          $407 = ((($$in16$i$i)) + 28|0);
          __THREW__ = 0;
          invoke_vii(3457,($406|0),($407|0));
          $408 = __THREW__; __THREW__ = 0;
          $409 = $408&1;
          if ($409) {
           label = 129;
           break;
          }
          $418 = ((($400)) + 40|0);
          $419 = ((($$in16$i$i)) + 40|0);
          $420 = HEAP32[$419>>2]|0;
          HEAP32[$418>>2] = $420;
          $421 = HEAP32[$3>>2]|0;
          HEAP32[$400>>2] = 0;
          $422 = ((($400)) + 4|0);
          HEAP32[$422>>2] = 0;
          $423 = ((($400)) + 8|0);
          HEAP32[$423>>2] = $421;
          HEAP32[$395>>2] = $400;
          $424 = HEAP32[$28>>2]|0;
          $425 = HEAP32[$424>>2]|0;
          $426 = ($425|0)==(0|0);
          if ($426) {
           $429 = $400;
          } else {
           $427 = $425;
           HEAP32[$28>>2] = $427;
           $$pre$i$i$i$i$i$i150 = HEAP32[$395>>2]|0;
           $429 = $$pre$i$i$i$i$i$i150;
          }
          $428 = HEAP32[$29>>2]|0;
          __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($428,$429);
          $430 = HEAP32[$30>>2]|0;
          $431 = (($430) + 1)|0;
          HEAP32[$30>>2] = $431;
         }
         $432 = ((($$in16$i$i)) + 4|0);
         $433 = HEAP32[$432>>2]|0;
         $434 = ($433|0)==(0|0);
         if ($434) {
          $435 = ((($$in16$i$i)) + 8|0);
          $436 = HEAP32[$435>>2]|0;
          $437 = HEAP32[$436>>2]|0;
          $438 = ($437|0)==($$in16$i$i|0);
          if ($438) {
           $$0$i$i$i$i$i156 = $436;
          } else {
           $442 = $435;
           while(1) {
            $441 = HEAP32[$442>>2]|0;
            $443 = ((($441)) + 8|0);
            $444 = HEAP32[$443>>2]|0;
            $445 = HEAP32[$444>>2]|0;
            $446 = ($445|0)==($441|0);
            if ($446) {
             $$0$i$i$i$i$i156 = $444;
             break;
            } else {
             $442 = $443;
            }
           }
          }
         } else {
          $$0$i$i$i$i$i$i152 = $433;
          while(1) {
           $439 = HEAP32[$$0$i$i$i$i$i$i152>>2]|0;
           $440 = ($439|0)==(0|0);
           if ($440) {
            break;
           } else {
            $$0$i$i$i$i$i$i152 = $439;
           }
          }
          $$0$i$i$i$i$i156 = $$0$i$i$i$i$i$i152;
         }
         $447 = ($$0$i$i$i$i$i156|0)==($391|0);
         if ($447) {
          break L212;
         } else {
          $$in16$i$i = $$0$i$i$i$i$i156;
         }
        }
        if ((label|0) == 20) {
         $101 = ___cxa_find_matching_catch_2()|0;
         $102 = tempRet0;
         $eh$lpad$body$index4Z2D = $102;$eh$lpad$body$indexZ2D = $101;
         label = 23;
         break L23;
        }
        else if ((label|0) == 129) {
         $410 = ___cxa_find_matching_catch_2()|0;
         $411 = tempRet0;
         $412 = ((($400)) + 27|0);
         $413 = HEAP8[$412>>0]|0;
         $414 = ($413<<24>>24)<(0);
         if ($414) {
          $415 = HEAP32[$403>>2]|0;
          __ZdlPv($415);
          $eh$lpad$body$i$i$i$i$i$i$index12Z2D = $411;$eh$lpad$body$i$i$i$i$i$i$indexZ2D = $410;
         } else {
          $eh$lpad$body$i$i$i$i$i$i$index12Z2D = $411;$eh$lpad$body$i$i$i$i$i$i$indexZ2D = $410;
         }
        }
        else if ((label|0) == 131) {
         $416 = ___cxa_find_matching_catch_2()|0;
         $417 = tempRet0;
         $eh$lpad$body$i$i$i$i$i$i$index12Z2D = $417;$eh$lpad$body$i$i$i$i$i$i$indexZ2D = $416;
        }
        __ZdlPv($400);
        $eh$lpad$body$index4Z2D = $eh$lpad$body$i$i$i$i$i$i$index12Z2D;$eh$lpad$body$indexZ2D = $eh$lpad$body$i$i$i$i$i$i$indexZ2D;
        label = 23;
        break L23;
       }
      }
     } while(0);
     $520 = ((($1)) + 116|0);
     $521 = HEAP32[$520>>2]|0;
     $522 = ((($0)) + 116|0);
     HEAP32[$522>>2] = $521;
     $523 = ((($1)) + 120|0);
     $524 = HEAP32[$523>>2]|0;
     $525 = ((($0)) + 120|0);
     HEAP32[$525>>2] = $524;
     $526 = ((($1)) + 124|0);
     $527 = HEAP32[$526>>2]|0;
     $528 = ((($0)) + 124|0);
     HEAP32[$528>>2] = $527;
     $529 = ((($1)) + 128|0);
     __THREW__ = 0;
     (invoke_iii(3477,($32|0),($529|0))|0);
     $530 = __THREW__; __THREW__ = 0;
     $531 = $530&1;
     if (!($531)) {
      $532 = HEAP32[$36>>2]|0;
      $533 = ((($1)) + 144|0);
      $534 = HEAP32[$533>>2]|0;
      $535 = ($532|0)==($534|0);
      if (!($535)) {
       HEAP32[$36>>2] = $534;
       $536 = ($534|0)==(0|0);
       if (!($536)) {
        $537 = HEAP32[$534>>2]|0;
        $538 = ((($537)) + -16|0);
        $539 = HEAP32[$538>>2]|0;
        $540 = (($534) + ($539)|0);
        $541 = ((($540)) + 8|0);
        $542 = HEAP32[$541>>2]|0;HEAP32[$541>>2] = (($542+1)|0);
       }
       $543 = ($532|0)==(0|0);
       if (!($543)) {
        $544 = HEAP32[$532>>2]|0;
        $545 = ((($544)) + -16|0);
        $546 = HEAP32[$545>>2]|0;
        $547 = (($532) + ($546)|0);
        $548 = ((($547)) + 8|0);
        $549 = HEAP32[$548>>2]|0;HEAP32[$548>>2] = (($549-1)|0);
        $550 = ($549|0)==(1);
        if ($550) {
         __THREW__ = 0;
         invoke_viii(3262,($547|0),1,1);
         $551 = __THREW__; __THREW__ = 0;
         $552 = $551&1;
         if ($552) {
          break;
         }
        }
       }
      }
      $553 = ((($1)) + 148|0);
      $554 = HEAP32[$553>>2]|0;
      $555 = ((($0)) + 148|0);
      HEAP32[$555>>2] = $554;
      $556 = HEAP32[$37>>2]|0;
      $557 = ((($1)) + 152|0);
      $558 = HEAP32[$557>>2]|0;
      $559 = ($556|0)==($558|0);
      if ($559) {
       $577 = ((($1)) + 156|0);
       $578 = HEAP32[$577>>2]|0;
       $579 = ((($0)) + 156|0);
       HEAP32[$579>>2] = $578;
       STACKTOP = sp;return;
      }
      HEAP32[$37>>2] = $558;
      $560 = ($558|0)==(0|0);
      if (!($560)) {
       $561 = HEAP32[$558>>2]|0;
       $562 = ((($561)) + -16|0);
       $563 = HEAP32[$562>>2]|0;
       $564 = (($558) + ($563)|0);
       $565 = ((($564)) + 8|0);
       $566 = HEAP32[$565>>2]|0;HEAP32[$565>>2] = (($566+1)|0);
      }
      $567 = ($556|0)==(0|0);
      if ($567) {
       $577 = ((($1)) + 156|0);
       $578 = HEAP32[$577>>2]|0;
       $579 = ((($0)) + 156|0);
       HEAP32[$579>>2] = $578;
       STACKTOP = sp;return;
      }
      $568 = HEAP32[$556>>2]|0;
      $569 = ((($568)) + -16|0);
      $570 = HEAP32[$569>>2]|0;
      $571 = (($556) + ($570)|0);
      $572 = ((($571)) + 8|0);
      $573 = HEAP32[$572>>2]|0;HEAP32[$572>>2] = (($573-1)|0);
      $574 = ($573|0)==(1);
      if (!($574)) {
       $577 = ((($1)) + 156|0);
       $578 = HEAP32[$577>>2]|0;
       $579 = ((($0)) + 156|0);
       HEAP32[$579>>2] = $578;
       STACKTOP = sp;return;
      }
      __THREW__ = 0;
      invoke_viii(3262,($571|0),1,1);
      $575 = __THREW__; __THREW__ = 0;
      $576 = $575&1;
      if (!($576)) {
       $577 = ((($1)) + 156|0);
       $578 = HEAP32[$577>>2]|0;
       $579 = ((($0)) + 156|0);
       HEAP32[$579>>2] = $578;
       STACKTOP = sp;return;
      }
     }
    }
   } while(0);
   $105 = ___cxa_find_matching_catch_2()|0;
   $106 = tempRet0;
   $eh$lpad$body$index4Z2D = $106;$eh$lpad$body$indexZ2D = $105;
   label = 23;
  }
 } while(0);
 if ((label|0) == 23) {
  $$18 = $eh$lpad$body$indexZ2D;$$18104 = $eh$lpad$body$index4Z2D;
 }
 $580 = HEAP32[$37>>2]|0;
 $581 = ($580|0)==(0|0);
 if (!($581)) {
  $582 = HEAP32[$580>>2]|0;
  $583 = ((($582)) + -16|0);
  $584 = HEAP32[$583>>2]|0;
  $585 = (($580) + ($584)|0);
  $586 = ((($585)) + 8|0);
  $587 = HEAP32[$586>>2]|0;HEAP32[$586>>2] = (($587-1)|0);
  $588 = ($587|0)==(1);
  if ($588) {
   __THREW__ = 0;
   invoke_viii(3262,($585|0),1,1);
   $589 = __THREW__; __THREW__ = 0;
   $590 = $589&1;
   if ($590) {
    $643 = ___cxa_find_matching_catch_3(0|0)|0;
    $644 = tempRet0;
    ___clang_call_terminate($643);
    // unreachable;
   }
  }
 }
 HEAP32[$37>>2] = 0;
 $591 = HEAP32[$36>>2]|0;
 $592 = ($591|0)==(0|0);
 if (!($592)) {
  $593 = HEAP32[$591>>2]|0;
  $594 = ((($593)) + -16|0);
  $595 = HEAP32[$594>>2]|0;
  $596 = (($591) + ($595)|0);
  $597 = ((($596)) + 8|0);
  $598 = HEAP32[$597>>2]|0;HEAP32[$597>>2] = (($598-1)|0);
  $599 = ($598|0)==(1);
  if ($599) {
   __THREW__ = 0;
   invoke_viii(3262,($596|0),1,1);
   $600 = __THREW__; __THREW__ = 0;
   $601 = $600&1;
   if ($601) {
    $643 = ___cxa_find_matching_catch_3(0|0)|0;
    $644 = tempRet0;
    ___clang_call_terminate($643);
    // unreachable;
   }
  }
 }
 HEAP32[$36>>2] = 0;
 $602 = ((($32)) + 11|0);
 $603 = HEAP8[$602>>0]|0;
 $604 = ($603<<24>>24)<(0);
 if ($604) {
  $605 = HEAP32[$32>>2]|0;
  __ZdlPv($605);
 }
 $606 = HEAP32[$31>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4pairIS7_jEEEENS_19__map_value_compareIS7_SA_NS_4lessIS7_EELb1EEENS5_ISA_EEE7destroyEPNS_11__tree_nodeISA_PvEE($28,$606);
 $607 = HEAP32[$27>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4pairIN3osg7ref_ptrINS9_7UniformEEEjEEEENS_19__map_value_compareIS7_SE_NS_4lessIS7_EELb1EEENS5_ISE_EEE7destroyEPNS_11__tree_nodeISE_PvEE($24,$607);
 $608 = HEAP32[$22>>2]|0;
 $609 = ($608|0)==(0|0);
 if (!($609)) {
  $610 = HEAP32[$23>>2]|0;
  $611 = ($610|0)==($608|0);
  if ($611) {
   $618 = $608;
  } else {
   $613 = $610;
   while(1) {
    $612 = ((($613)) + -12|0);
    HEAP32[$23>>2] = $612;
    $614 = ((($613)) + -8|0);
    $615 = HEAP32[$614>>2]|0;
    __ZNSt3__26__treeINS_12__value_typeINS_4pairIN3osg14StateAttribute4TypeEjEENS2_INS3_7ref_ptrIS4_EEjEEEENS_19__map_value_compareIS6_SA_NS_4lessIS6_EELb1EEENS_9allocatorISA_EEE7destroyEPNS_11__tree_nodeISA_PvEE($612,$615);
    $616 = HEAP32[$23>>2]|0;
    $617 = ($616|0)==($608|0);
    if ($617) {
     break;
    } else {
     $613 = $616;
    }
   }
   $$pre$i116 = HEAP32[$22>>2]|0;
   $618 = $$pre$i116;
  }
  __ZdlPv($618);
 }
 $619 = HEAP32[$20>>2]|0;
 $620 = ($619|0)==(0|0);
 if (!($620)) {
  $621 = HEAP32[$21>>2]|0;
  $622 = ($621|0)==($619|0);
  if ($622) {
   $629 = $619;
  } else {
   $624 = $621;
   while(1) {
    $623 = ((($624)) + -12|0);
    HEAP32[$21>>2] = $623;
    $625 = ((($624)) + -8|0);
    $626 = HEAP32[$625>>2]|0;
    __ZNSt3__26__treeINS_12__value_typeIjjEENS_19__map_value_compareIjS2_NS_4lessIjEELb1EEENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($623,$626);
    $627 = HEAP32[$21>>2]|0;
    $628 = ($627|0)==($619|0);
    if ($628) {
     break;
    } else {
     $624 = $627;
    }
   }
   $$pre$i = HEAP32[$20>>2]|0;
   $629 = $$pre$i;
  }
  __ZdlPv($629);
 }
 $630 = HEAP32[$19>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_4pairIN3osg14StateAttribute4TypeEjEENS2_INS3_7ref_ptrIS4_EEjEEEENS_19__map_value_compareIS6_SA_NS_4lessIS6_EELb1EEENS_9allocatorISA_EEE7destroyEPNS_11__tree_nodeISA_PvEE($16,$630);
 $631 = HEAP32[$15>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIjjEENS_19__map_value_compareIjS2_NS_4lessIjEELb1EEENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($12,$631);
 $632 = HEAP32[$9>>2]|0;
 $633 = ($632|0)==(0|0);
 if (!($633)) {
  $634 = HEAP32[$10>>2]|0;
  $635 = ($634|0)==($632|0);
  if (!($635)) {
   $scevgep$i$i$i = ((($634)) + -4|0);
   $636 = $scevgep$i$i$i;
   $637 = $632;
   $638 = (($636) - ($637))|0;
   $639 = $638 >>> 2;
   $640 = $639 ^ -1;
   $scevgep5$i$i$i = (($634) + ($640<<2)|0);
   HEAP32[$10>>2] = $scevgep5$i$i$i;
  }
  __ZdlPv($632);
 }
 __THREW__ = 0;
 invoke_vi(388,($0|0));
 $641 = __THREW__; __THREW__ = 0;
 $642 = $641&1;
 if ($642) {
  $643 = ___cxa_find_matching_catch_3(0|0)|0;
  $644 = tempRet0;
  ___clang_call_terminate($643);
  // unreachable;
 } else {
  ___resumeException($$18|0);
  // unreachable;
 }
}
function __ZNSt3__26__treeINS_12__value_typeIjjEENS_19__map_value_compareIjS2_NS_4lessIjEELb1EEENS_9allocatorIS2_EEE12__find_equalIjEERPNS_16__tree_node_baseIPvEENS_21__tree_const_iteratorIS2_PNS_11__tree_nodeIS2_SC_EEiEERPNS_15__tree_end_nodeISE_EESF_RKT_($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0$i = 0, $$0$i$i = 0, $$0$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i$i = 0, $$0$i26 = 0, $$0$ph$i = 0, $$0$ph$i23 = 0, $$024$i = 0, $$024$i25 = 0, $$08$i$i = 0, $$2 = 0, $$in$i = 0, $$in$i22 = 0, $$pre = 0, $$sroa$043$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = ((($0)) + 4|0);
 $6 = HEAP32[$1>>2]|0;
 $7 = ($6|0)==($5|0);
 $8 = $6;
 if (!($7)) {
  $9 = ((($6)) + 16|0);
  $10 = HEAP32[$4>>2]|0;
  $11 = HEAP32[$9>>2]|0;
  $12 = ($10>>>0)<($11>>>0);
  if (!($12)) {
   $43 = ($11>>>0)<($10>>>0);
   if (!($43)) {
    HEAP32[$2>>2] = $8;
    HEAP32[$3>>2] = $8;
    $$2 = $3;
    return ($$2|0);
   }
   $44 = ((($6)) + 4|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = ($45|0)==(0|0);
   if ($46) {
    $47 = ((($6)) + 8|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = HEAP32[$48>>2]|0;
    $50 = ($49|0)==($6|0);
    if ($50) {
     $$0$i$i$i$i$i = $48;
    } else {
     $54 = $47;
     while(1) {
      $53 = HEAP32[$54>>2]|0;
      $55 = ((($53)) + 8|0);
      $56 = HEAP32[$55>>2]|0;
      $57 = HEAP32[$56>>2]|0;
      $58 = ($57|0)==($53|0);
      if ($58) {
       $$0$i$i$i$i$i = $56;
       break;
      } else {
       $54 = $55;
      }
     }
    }
   } else {
    $$0$i$i$i$i$i$i = $45;
    while(1) {
     $51 = HEAP32[$$0$i$i$i$i$i$i>>2]|0;
     $52 = ($51|0)==(0|0);
     if ($52) {
      break;
     } else {
      $$0$i$i$i$i$i$i = $51;
     }
    }
    $$0$i$i$i$i$i = $$0$i$i$i$i$i$i;
   }
   $59 = ($$0$i$i$i$i$i|0)==($5|0);
   if (!($59)) {
    $60 = ((($$0$i$i$i$i$i)) + 16|0);
    $61 = HEAP32[$60>>2]|0;
    $62 = ($10>>>0)<($61>>>0);
    if (!($62)) {
     $66 = HEAP32[$5>>2]|0;
     $67 = ($66|0)==(0|0);
     if ($67) {
      HEAP32[$2>>2] = $5;
      $$2 = $5;
      return ($$2|0);
     }
     $68 = ((($0)) + 4|0);
     $$0$i = $68;$$024$i = $66;
     while(1) {
      $69 = ((($$024$i)) + 16|0);
      $70 = HEAP32[$69>>2]|0;
      $71 = ($10>>>0)<($70>>>0);
      if ($71) {
       $72 = HEAP32[$$024$i>>2]|0;
       $73 = ($72|0)==(0|0);
       if ($73) {
        label = 39;
        break;
       } else {
        $$0$ph$i = $$024$i;$$in$i = $72;
       }
      } else {
       $74 = ($70>>>0)<($10>>>0);
       if (!($74)) {
        label = 43;
        break;
       }
       $75 = ((($$024$i)) + 4|0);
       $76 = HEAP32[$75>>2]|0;
       $77 = ($76|0)==(0|0);
       if ($77) {
        label = 42;
        break;
       } else {
        $$0$ph$i = $75;$$in$i = $76;
       }
      }
      $$0$i = $$0$ph$i;$$024$i = $$in$i;
     }
     if ((label|0) == 39) {
      HEAP32[$2>>2] = $$024$i;
      $$2 = $$024$i;
      return ($$2|0);
     }
     else if ((label|0) == 42) {
      HEAP32[$2>>2] = $$024$i;
      $$2 = $75;
      return ($$2|0);
     }
     else if ((label|0) == 43) {
      HEAP32[$2>>2] = $$024$i;
      $$2 = $$0$i;
      return ($$2|0);
     }
    }
   }
   $63 = ((($6)) + 4|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = ($64|0)==(0|0);
   if ($65) {
    HEAP32[$2>>2] = $8;
    $$2 = $44;
    return ($$2|0);
   } else {
    HEAP32[$2>>2] = $$0$i$i$i$i$i;
    $$2 = $$0$i$i$i$i$i;
    return ($$2|0);
   }
  }
 }
 $13 = HEAP32[$0>>2]|0;
 $14 = ($6|0)==($13|0);
 $$pre = HEAP32[$6>>2]|0;
 if ($14) {
  $$sroa$043$0 = $8;
 } else {
  $15 = ($$pre|0)==(0|0);
  if ($15) {
   $$0$i$i = $6;
   while(1) {
    $19 = ((($$0$i$i)) + 8|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = HEAP32[$20>>2]|0;
    $22 = ($21|0)==($$0$i$i|0);
    if ($22) {
     $$0$i$i = $20;
    } else {
     $$08$i$i = $20;
     break;
    }
   }
  } else {
   $$0$i$i$i = $$pre;
   while(1) {
    $16 = ((($$0$i$i$i)) + 4|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = ($17|0)==(0|0);
    if ($18) {
     $$08$i$i = $$0$i$i$i;
     break;
    } else {
     $$0$i$i$i = $17;
    }
   }
  }
  $23 = $$08$i$i;
  $24 = ((($$08$i$i)) + 16|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = HEAP32[$4>>2]|0;
  $27 = ($25>>>0)<($26>>>0);
  if ($27) {
   $$sroa$043$0 = $23;
  } else {
   $31 = HEAP32[$5>>2]|0;
   $32 = ($31|0)==(0|0);
   if ($32) {
    HEAP32[$2>>2] = $5;
    $$2 = $5;
    return ($$2|0);
   }
   $33 = ((($0)) + 4|0);
   $$0$i26 = $33;$$024$i25 = $31;
   while(1) {
    $34 = ((($$024$i25)) + 16|0);
    $35 = HEAP32[$34>>2]|0;
    $36 = ($26>>>0)<($35>>>0);
    if ($36) {
     $37 = HEAP32[$$024$i25>>2]|0;
     $38 = ($37|0)==(0|0);
     if ($38) {
      label = 17;
      break;
     } else {
      $$0$ph$i23 = $$024$i25;$$in$i22 = $37;
     }
    } else {
     $39 = ($35>>>0)<($26>>>0);
     if (!($39)) {
      label = 21;
      break;
     }
     $40 = ((($$024$i25)) + 4|0);
     $41 = HEAP32[$40>>2]|0;
     $42 = ($41|0)==(0|0);
     if ($42) {
      label = 20;
      break;
     } else {
      $$0$ph$i23 = $40;$$in$i22 = $41;
     }
    }
    $$0$i26 = $$0$ph$i23;$$024$i25 = $$in$i22;
   }
   if ((label|0) == 17) {
    HEAP32[$2>>2] = $$024$i25;
    $$2 = $$024$i25;
    return ($$2|0);
   }
   else if ((label|0) == 20) {
    HEAP32[$2>>2] = $$024$i25;
    $$2 = $40;
    return ($$2|0);
   }
   else if ((label|0) == 21) {
    HEAP32[$2>>2] = $$024$i25;
    $$2 = $$0$i26;
    return ($$2|0);
   }
  }
 }
 $28 = ($$pre|0)==(0|0);
 if ($28) {
  HEAP32[$2>>2] = $6;
  $$2 = $6;
  return ($$2|0);
 } else {
  $29 = $$sroa$043$0;
  HEAP32[$2>>2] = $29;
  $30 = ((($29)) + 4|0);
  $$2 = $30;
  return ($$2|0);
 }
 return (0)|0;
}
function __ZNSt3__26vectorINS_3mapIjjNS_4lessIjEENS_9allocatorINS_4pairIKjjEEEEEENS4_IS9_EEE6assignIPS9_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS9_NS_15iterator_traitsISF_E9referenceEEE5valueEvE4typeESF_SF_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$ = 0, $$0$i$i$i$i$i$i$i = 0, $$0$i$i$i$i$i$i$i$i = 0, $$0$lcssa$i$i = 0, $$078$i$i = 0, $$09$i$i = 0, $$byval_copy = 0, $$in8$i$i$i$i = 0, $$pre$i = 0, $$pre$i$i$i$i$i$i$i$i = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy = sp + 12|0;
 $3 = sp + 8|0;
 $4 = sp + 4|0;
 $5 = sp;
 $6 = $2;
 $7 = $1;
 $8 = (($6) - ($7))|0;
 $9 = (($8|0) / 12)&-1;
 $10 = ((($0)) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = HEAP32[$0>>2]|0;
 $13 = (($11) - ($12))|0;
 $14 = (($13|0) / 12)&-1;
 $15 = ($9>>>0)>($14>>>0);
 $16 = $12;
 if ($15) {
  $92 = ($12|0)==(0);
  if ($92) {
   $106 = $11;
  } else {
   $93 = $12;
   $94 = ((($0)) + 4|0);
   $95 = HEAP32[$94>>2]|0;
   $96 = ($95|0)==($16|0);
   if ($96) {
    $103 = $93;
   } else {
    $98 = $95;
    while(1) {
     $97 = ((($98)) + -12|0);
     HEAP32[$94>>2] = $97;
     $99 = ((($98)) + -8|0);
     $100 = HEAP32[$99>>2]|0;
     __ZNSt3__26__treeINS_12__value_typeIjjEENS_19__map_value_compareIjS2_NS_4lessIjEELb1EEENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($97,$100);
     $101 = HEAP32[$94>>2]|0;
     $102 = ($101|0)==($16|0);
     if ($102) {
      break;
     } else {
      $98 = $101;
     }
    }
    $$pre$i = HEAP32[$0>>2]|0;
    $103 = $$pre$i;
   }
   __ZdlPv($103);
   HEAP32[$10>>2] = 0;
   HEAP32[$94>>2] = 0;
   HEAP32[$0>>2] = 0;
   $106 = 0;
  }
  $104 = ($9>>>0)>(357913941);
  if ($104) {
   __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
   // unreachable;
  }
  $105 = (($106|0) / 12)&-1;
  $107 = ($105>>>0)<(178956970);
  $108 = $105 << 1;
  $109 = ($108>>>0)<($9>>>0);
  $$sroa$speculated$i = $109 ? $9 : $108;
  $$sroa$speculated$$i = $107 ? $$sroa$speculated$i : 357913941;
  $110 = ($$sroa$speculated$$i>>>0)>(357913941);
  if ($110) {
   __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
   // unreachable;
  }
  $111 = ($$sroa$speculated$$i*12)|0;
  $112 = (__Znwj($111)|0);
  $113 = ((($0)) + 4|0);
  HEAP32[$113>>2] = $112;
  HEAP32[$0>>2] = $112;
  $114 = (($112) + (($$sroa$speculated$$i*12)|0)|0);
  HEAP32[$10>>2] = $114;
  __ZNSt3__26vectorINS_3mapIjjNS_4lessIjEENS_9allocatorINS_4pairIKjjEEEEEENS4_IS9_EEE18__construct_at_endIPS9_EENS_9enable_ifIXsr21__is_forward_iteratorIT_EE5valueEvE4typeESF_SF_j($0,$1,$2,$9);
  STACKTOP = sp;return;
 }
 $17 = ((($0)) + 4|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($18) - ($12))|0;
 $20 = (($19|0) / 12)&-1;
 $21 = ($9>>>0)>($20>>>0);
 $22 = (($1) + (($20*12)|0)|0);
 $$ = $21 ? $22 : $2;
 $23 = ($$|0)==($1|0);
 if ($23) {
  $$0$lcssa$i$i = $16;
 } else {
  $$078$i$i = $1;$$09$i$i = $16;
  while(1) {
   $24 = ($$09$i$i|0)==($$078$i$i|0);
   if (!($24)) {
    $25 = ((($$09$i$i)) + 4|0);
    $26 = HEAP32[$25>>2]|0;
    __ZNSt3__26__treeINS_12__value_typeIjjEENS_19__map_value_compareIjS2_NS_4lessIjEELb1EEENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($$09$i$i,$26);
    $27 = ((($$09$i$i)) + 8|0);
    HEAP32[$27>>2] = 0;
    HEAP32[$$09$i$i>>2] = $25;
    HEAP32[$25>>2] = 0;
    $28 = HEAP32[$$078$i$i>>2]|0;
    $29 = ((($$078$i$i)) + 4|0);
    $30 = ($28|0)==($29|0);
    if (!($30)) {
     $31 = $25;
     $32 = ((($$09$i$i)) + 4|0);
     $$in8$i$i$i$i = $28;
     while(1) {
      $33 = ((($$in8$i$i$i$i)) + 16|0);
      HEAP32[$5>>2] = $31;
      ;HEAP32[$$byval_copy>>2]=HEAP32[$5>>2]|0;
      $34 = (__ZNSt3__26__treeINS_12__value_typeIjjEENS_19__map_value_compareIjS2_NS_4lessIjEELb1EEENS_9allocatorIS2_EEE12__find_equalIjEERPNS_16__tree_node_baseIPvEENS_21__tree_const_iteratorIS2_PNS_11__tree_nodeIS2_SC_EEiEERPNS_15__tree_end_nodeISE_EESF_RKT_($$09$i$i,$$byval_copy,$3,$4,$33)|0);
      $35 = HEAP32[$34>>2]|0;
      $36 = ($35|0)==(0|0);
      if ($36) {
       $37 = (__Znwj(24)|0);
       $38 = ((($37)) + 16|0);
       $39 = $33;
       $40 = $39;
       $41 = HEAP32[$40>>2]|0;
       $42 = (($39) + 4)|0;
       $43 = $42;
       $44 = HEAP32[$43>>2]|0;
       $45 = $38;
       $46 = $45;
       HEAP32[$46>>2] = $41;
       $47 = (($45) + 4)|0;
       $48 = $47;
       HEAP32[$48>>2] = $44;
       $49 = HEAP32[$3>>2]|0;
       HEAP32[$37>>2] = 0;
       $50 = ((($37)) + 4|0);
       HEAP32[$50>>2] = 0;
       $51 = ((($37)) + 8|0);
       HEAP32[$51>>2] = $49;
       HEAP32[$34>>2] = $37;
       $52 = HEAP32[$$09$i$i>>2]|0;
       $53 = HEAP32[$52>>2]|0;
       $54 = ($53|0)==(0|0);
       if ($54) {
        $57 = $37;
       } else {
        $55 = $53;
        HEAP32[$$09$i$i>>2] = $55;
        $$pre$i$i$i$i$i$i$i$i = HEAP32[$34>>2]|0;
        $57 = $$pre$i$i$i$i$i$i$i$i;
       }
       $56 = HEAP32[$32>>2]|0;
       __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($56,$57);
       $58 = HEAP32[$27>>2]|0;
       $59 = (($58) + 1)|0;
       HEAP32[$27>>2] = $59;
      }
      $60 = ((($$in8$i$i$i$i)) + 4|0);
      $61 = HEAP32[$60>>2]|0;
      $62 = ($61|0)==(0|0);
      if ($62) {
       $63 = ((($$in8$i$i$i$i)) + 8|0);
       $64 = HEAP32[$63>>2]|0;
       $65 = HEAP32[$64>>2]|0;
       $66 = ($65|0)==($$in8$i$i$i$i|0);
       if ($66) {
        $$0$i$i$i$i$i$i$i = $64;
       } else {
        $70 = $63;
        while(1) {
         $69 = HEAP32[$70>>2]|0;
         $71 = ((($69)) + 8|0);
         $72 = HEAP32[$71>>2]|0;
         $73 = HEAP32[$72>>2]|0;
         $74 = ($73|0)==($69|0);
         if ($74) {
          $$0$i$i$i$i$i$i$i = $72;
          break;
         } else {
          $70 = $71;
         }
        }
       }
      } else {
       $$0$i$i$i$i$i$i$i$i = $61;
       while(1) {
        $67 = HEAP32[$$0$i$i$i$i$i$i$i$i>>2]|0;
        $68 = ($67|0)==(0|0);
        if ($68) {
         break;
        } else {
         $$0$i$i$i$i$i$i$i$i = $67;
        }
       }
       $$0$i$i$i$i$i$i$i = $$0$i$i$i$i$i$i$i$i;
      }
      $75 = ($$0$i$i$i$i$i$i$i|0)==($29|0);
      if ($75) {
       break;
      } else {
       $$in8$i$i$i$i = $$0$i$i$i$i$i$i$i;
      }
     }
    }
   }
   $76 = ((($$078$i$i)) + 12|0);
   $77 = ((($$09$i$i)) + 12|0);
   $78 = ($76|0)==($$|0);
   if ($78) {
    $$0$lcssa$i$i = $77;
    break;
   } else {
    $$078$i$i = $76;$$09$i$i = $77;
   }
  }
 }
 if ($21) {
  $79 = HEAP32[$17>>2]|0;
  $80 = HEAP32[$0>>2]|0;
  $81 = (($79) - ($80))|0;
  $82 = (($81|0) / 12)&-1;
  $83 = (($9) - ($82))|0;
  __ZNSt3__26vectorINS_3mapIjjNS_4lessIjEENS_9allocatorINS_4pairIKjjEEEEEENS4_IS9_EEE18__construct_at_endIPS9_EENS_9enable_ifIXsr21__is_forward_iteratorIT_EE5valueEvE4typeESF_SF_j($0,$$,$2,$83);
  STACKTOP = sp;return;
 }
 $84 = HEAP32[$17>>2]|0;
 $85 = ($84|0)==($$0$lcssa$i$i|0);
 if ($85) {
  STACKTOP = sp;return;
 } else {
  $87 = $84;
 }
 while(1) {
  $86 = ((($87)) + -12|0);
  HEAP32[$17>>2] = $86;
  $88 = ((($87)) + -8|0);
  $89 = HEAP32[$88>>2]|0;
  __ZNSt3__26__treeINS_12__value_typeIjjEENS_19__map_value_compareIjS2_NS_4lessIjEELb1EEENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($86,$89);
  $90 = HEAP32[$17>>2]|0;
  $91 = ($90|0)==($$0$lcssa$i$i|0);
  if ($91) {
   break;
  } else {
   $87 = $90;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__26vectorINS_3mapINS_4pairIN3osg14StateAttribute4TypeEjEENS2_INS3_7ref_ptrIS4_EEjEENS_4lessIS6_EENS_9allocatorINS2_IKS6_S9_EEEEEENSC_ISG_EEE8__appendEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i = 0, $$0$i13 = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $9 = 0, $scevgep = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $2 = sp;
 $3 = ((($0)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) - ($6))|0;
 $8 = (($7|0) / 12)&-1;
 $9 = ($8>>>0)<($1>>>0);
 if (!($9)) {
  $10 = $6;
  $$0$i = $1;$12 = $10;
  while(1) {
   $11 = ((($12)) + 4|0);
   HEAP32[$11>>2] = 0;
   $13 = ((($12)) + 8|0);
   HEAP32[$13>>2] = 0;
   $14 = ((($12)) + 4|0);
   HEAP32[$12>>2] = $14;
   $15 = HEAP32[$5>>2]|0;
   $16 = ((($15)) + 12|0);
   HEAP32[$5>>2] = $16;
   $17 = (($$0$i) + -1)|0;
   $18 = ($17|0)==(0);
   if ($18) {
    break;
   } else {
    $$0$i = $17;$12 = $16;
   }
  }
  STACKTOP = sp;return;
 }
 $19 = HEAP32[$0>>2]|0;
 $20 = (($6) - ($19))|0;
 $21 = (($20|0) / 12)&-1;
 $22 = (($21) + ($1))|0;
 $23 = ($22>>>0)>(357913941);
 if ($23) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $24 = ((($0)) + 8|0);
 $25 = (($4) - ($19))|0;
 $26 = (($25|0) / 12)&-1;
 $27 = ($26>>>0)<(178956970);
 $28 = $26 << 1;
 $29 = ($28>>>0)<($22>>>0);
 $$sroa$speculated$i = $29 ? $22 : $28;
 $$sroa$speculated$$i = $27 ? $$sroa$speculated$i : 357913941;
 $30 = ((($2)) + 12|0);
 HEAP32[$30>>2] = 0;
 $31 = ((($2)) + 16|0);
 HEAP32[$31>>2] = $24;
 $32 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($32) {
   $41 = 0;
  } else {
   $33 = ($$sroa$speculated$$i>>>0)>(357913941);
   if (!($33)) {
    $39 = ($$sroa$speculated$$i*12)|0;
    $40 = (__Znwj($39)|0);
    $41 = $40;
    break;
   }
   $34 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($34|0),(204840|0));
   $35 = __THREW__; __THREW__ = 0;
   $36 = $35&1;
   if ($36) {
    $37 = ___cxa_find_matching_catch_2()|0;
    $38 = tempRet0;
    ___cxa_free_exception(($34|0));
    ___resumeException($37|0);
    // unreachable;
   } else {
    HEAP32[$34>>2] = (99824);
    ___cxa_throw(($34|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 HEAP32[$2>>2] = $41;
 $42 = (($41) + (($21*12)|0)|0);
 $43 = ((($2)) + 8|0);
 HEAP32[$43>>2] = $42;
 $44 = ((($2)) + 4|0);
 HEAP32[$44>>2] = $42;
 $45 = (($41) + (($$sroa$speculated$$i*12)|0)|0);
 $46 = ((($2)) + 12|0);
 HEAP32[$46>>2] = $45;
 $$0$i13 = $1;$48 = $42;
 while(1) {
  $47 = ((($48)) + 4|0);
  HEAP32[$47>>2] = 0;
  $49 = ((($48)) + 8|0);
  HEAP32[$49>>2] = 0;
  $50 = ((($48)) + 4|0);
  HEAP32[$48>>2] = $50;
  $51 = ((($48)) + 12|0);
  $52 = (($$0$i13) + -1)|0;
  $53 = ($52|0)==(0);
  if ($53) {
   break;
  } else {
   $$0$i13 = $52;$48 = $51;
  }
 }
 $scevgep = (($41) + (($22*12)|0)|0);
 HEAP32[$43>>2] = $scevgep;
 __THREW__ = 0;
 invoke_vii(3947,($0|0),($2|0));
 $54 = __THREW__; __THREW__ = 0;
 $55 = $54&1;
 if ($55) {
  $67 = ___cxa_find_matching_catch_2()|0;
  $68 = tempRet0;
  $69 = HEAP32[$44>>2]|0;
  $70 = HEAP32[$43>>2]|0;
  $71 = ($70|0)==($69|0);
  if (!($71)) {
   $73 = $70;
   while(1) {
    $72 = ((($73)) + -12|0);
    HEAP32[$43>>2] = $72;
    $74 = ((($73)) + -8|0);
    $75 = HEAP32[$74>>2]|0;
    __ZNSt3__26__treeINS_12__value_typeINS_4pairIN3osg14StateAttribute4TypeEjEENS2_INS3_7ref_ptrIS4_EEjEEEENS_19__map_value_compareIS6_SA_NS_4lessIS6_EELb1EEENS_9allocatorISA_EEE7destroyEPNS_11__tree_nodeISA_PvEE($72,$75);
    $76 = HEAP32[$43>>2]|0;
    $77 = ($76|0)==($69|0);
    if ($77) {
     break;
    } else {
     $73 = $76;
    }
   }
  }
  $78 = HEAP32[$2>>2]|0;
  $79 = ($78|0)==(0|0);
  if ($79) {
   ___resumeException($67|0);
   // unreachable;
  }
  __ZdlPv($78);
  ___resumeException($67|0);
  // unreachable;
 } else {
  $56 = HEAP32[$44>>2]|0;
  $57 = HEAP32[$43>>2]|0;
  $58 = ($57|0)==($56|0);
  if (!($58)) {
   $60 = $57;
   while(1) {
    $59 = ((($60)) + -12|0);
    HEAP32[$43>>2] = $59;
    $61 = ((($60)) + -8|0);
    $62 = HEAP32[$61>>2]|0;
    __ZNSt3__26__treeINS_12__value_typeINS_4pairIN3osg14StateAttribute4TypeEjEENS2_INS3_7ref_ptrIS4_EEjEEEENS_19__map_value_compareIS6_SA_NS_4lessIS6_EELb1EEENS_9allocatorISA_EEE7destroyEPNS_11__tree_nodeISA_PvEE($59,$62);
    $63 = HEAP32[$43>>2]|0;
    $64 = ($63|0)==($56|0);
    if ($64) {
     break;
    } else {
     $60 = $63;
    }
   }
  }
  $65 = HEAP32[$2>>2]|0;
  $66 = ($65|0)==(0|0);
  if (!($66)) {
   __ZdlPv($65);
  }
  STACKTOP = sp;return;
 }
}
function __ZNSt3__26__treeINS_12__value_typeINS_4pairIN3osg14StateAttribute4TypeEjEENS2_INS3_7ref_ptrIS4_EEjEEEENS_19__map_value_compareIS6_SA_NS_4lessIS6_EELb1EEENS_9allocatorISA_EEE7destroyEPNS_11__tree_nodeISA_PvEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 }
 $3 = HEAP32[$1>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_4pairIN3osg14StateAttribute4TypeEjEENS2_INS3_7ref_ptrIS4_EEjEEEENS_19__map_value_compareIS6_SA_NS_4lessIS6_EELb1EEENS_9allocatorISA_EEE7destroyEPNS_11__tree_nodeISA_PvEE($0,$3);
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_4pairIN3osg14StateAttribute4TypeEjEENS2_INS3_7ref_ptrIS4_EEjEEEENS_19__map_value_compareIS6_SA_NS_4lessIS6_EELb1EEENS_9allocatorISA_EEE7destroyEPNS_11__tree_nodeISA_PvEE($0,$5);
 $6 = ((($1)) + 24|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = ((($7)) + 8|0);
  $10 = HEAP32[$9>>2]|0;HEAP32[$9>>2] = (($10-1)|0);
  $11 = ($10|0)==(1);
  if ($11) {
   __THREW__ = 0;
   invoke_viii(3262,($7|0),1,1);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if ($13) {
    $14 = ___cxa_find_matching_catch_2()|0;
    $15 = tempRet0;
    ___cxa_call_unexpected(($14|0));
    // unreachable;
   }
  }
 }
 __ZdlPv($1);
 return;
}
function __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4pairIS7_jEEEENS_19__map_value_compareIS7_SA_NS_4lessIS7_EELb1EEENS5_ISA_EEE12__find_equalIS7_EERPNS_16__tree_node_baseIPvEENS_21__tree_const_iteratorISA_PNS_11__tree_nodeISA_SJ_EEiEERPNS_15__tree_end_nodeISL_EESM_RKT_($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0$i$i = 0, $$0$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i$i = 0, $$08$i$i = 0, $$2 = 0, $$pre = 0, $$sroa$052$0 = 0, $$sroa$speculated$i$i$i$i$i = 0, $$sroa$speculated$i$i$i$i$i21 = 0, $$sroa$speculated$i$i$i$i$i26 = 0, $$sroa$speculated$i$i$i$i$i32 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = ((($0)) + 4|0);
 $6 = HEAP32[$1>>2]|0;
 $7 = ($6|0)==($5|0);
 $8 = $6;
 do {
  if (!($7)) {
   $9 = ((($6)) + 16|0);
   $10 = ((($9)) + 11|0);
   $11 = HEAP8[$10>>0]|0;
   $12 = ($11<<24>>24)<(0);
   $13 = ((($6)) + 20|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = $11&255;
   $16 = $12 ? $14 : $15;
   $17 = ((($4)) + 11|0);
   $18 = HEAP8[$17>>0]|0;
   $19 = ($18<<24>>24)<(0);
   $20 = ((($4)) + 4|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = $18&255;
   $23 = $19 ? $21 : $22;
   $24 = ($16>>>0)<($23>>>0);
   $$sroa$speculated$i$i$i$i$i32 = $24 ? $16 : $23;
   $25 = ($$sroa$speculated$i$i$i$i$i32|0)==(0);
   if ($25) {
    label = 4;
   } else {
    $26 = HEAP32[$4>>2]|0;
    $27 = $19 ? $26 : $4;
    $28 = HEAP32[$9>>2]|0;
    $29 = $12 ? $28 : $9;
    $30 = (_memcmp($27,$29,$$sroa$speculated$i$i$i$i$i32)|0);
    $31 = ($30|0)==(0);
    if ($31) {
     label = 4;
    } else {
     $33 = ($30|0)<(0);
     if ($33) {
      break;
     }
    }
   }
   if ((label|0) == 4) {
    $32 = ($23>>>0)<($16>>>0);
    if ($32) {
     break;
    }
   }
   $74 = ($23>>>0)<($16>>>0);
   $$sroa$speculated$i$i$i$i$i21 = $74 ? $23 : $16;
   $75 = ($$sroa$speculated$i$i$i$i$i21|0)==(0);
   if ($75) {
    label = 20;
   } else {
    $76 = HEAP32[$9>>2]|0;
    $77 = $12 ? $76 : $9;
    $78 = HEAP32[$4>>2]|0;
    $79 = $19 ? $78 : $4;
    $80 = (_memcmp($77,$79,$$sroa$speculated$i$i$i$i$i21)|0);
    $81 = ($80|0)==(0);
    if ($81) {
     label = 20;
    } else {
     $82 = ($80|0)<(0);
     if (!($82)) {
      label = 36;
     }
    }
   }
   if ((label|0) == 20) {
    if (!($24)) {
     label = 36;
    }
   }
   if ((label|0) == 36) {
    HEAP32[$2>>2] = $8;
    HEAP32[$3>>2] = $8;
    $$2 = $3;
    return ($$2|0);
   }
   $83 = ((($6)) + 4|0);
   $84 = HEAP32[$83>>2]|0;
   $85 = ($84|0)==(0|0);
   if ($85) {
    $86 = ((($6)) + 8|0);
    $87 = HEAP32[$86>>2]|0;
    $88 = HEAP32[$87>>2]|0;
    $89 = ($88|0)==($6|0);
    if ($89) {
     $$0$i$i$i$i$i = $87;
    } else {
     $93 = $86;
     while(1) {
      $92 = HEAP32[$93>>2]|0;
      $94 = ((($92)) + 8|0);
      $95 = HEAP32[$94>>2]|0;
      $96 = HEAP32[$95>>2]|0;
      $97 = ($96|0)==($92|0);
      if ($97) {
       $$0$i$i$i$i$i = $95;
       break;
      } else {
       $93 = $94;
      }
     }
    }
   } else {
    $$0$i$i$i$i$i$i = $84;
    while(1) {
     $90 = HEAP32[$$0$i$i$i$i$i$i>>2]|0;
     $91 = ($90|0)==(0|0);
     if ($91) {
      break;
     } else {
      $$0$i$i$i$i$i$i = $90;
     }
    }
    $$0$i$i$i$i$i = $$0$i$i$i$i$i$i;
   }
   $98 = ($$0$i$i$i$i$i|0)==($5|0);
   do {
    if (!($98)) {
     $99 = ((($$0$i$i$i$i$i)) + 16|0);
     $100 = ((($99)) + 11|0);
     $101 = HEAP8[$100>>0]|0;
     $102 = ($101<<24>>24)<(0);
     $103 = ((($$0$i$i$i$i$i)) + 20|0);
     $104 = HEAP32[$103>>2]|0;
     $105 = $101&255;
     $106 = $102 ? $104 : $105;
     $107 = ($106>>>0)<($23>>>0);
     $$sroa$speculated$i$i$i$i$i = $107 ? $106 : $23;
     $108 = ($$sroa$speculated$i$i$i$i$i|0)==(0);
     if ($108) {
      label = 30;
     } else {
      $109 = HEAP32[$4>>2]|0;
      $110 = $19 ? $109 : $4;
      $111 = HEAP32[$99>>2]|0;
      $112 = $102 ? $111 : $99;
      $113 = (_memcmp($110,$112,$$sroa$speculated$i$i$i$i$i)|0);
      $114 = ($113|0)==(0);
      if ($114) {
       label = 30;
      } else {
       $116 = ($113|0)<(0);
       if ($116) {
        break;
       }
      }
     }
     if ((label|0) == 30) {
      $115 = ($23>>>0)<($106>>>0);
      if ($115) {
       break;
      }
     }
     $120 = (__ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4pairIS7_jEEEENS_19__map_value_compareIS7_SA_NS_4lessIS7_EELb1EEENS5_ISA_EEE12__find_equalIS7_EERPNS_16__tree_node_baseIPvEERPNS_15__tree_end_nodeISL_EERKT_($0,$2,$4)|0);
     $$2 = $120;
     return ($$2|0);
    }
   } while(0);
   $117 = ((($6)) + 4|0);
   $118 = HEAP32[$117>>2]|0;
   $119 = ($118|0)==(0|0);
   if ($119) {
    HEAP32[$2>>2] = $8;
    $$2 = $83;
    return ($$2|0);
   } else {
    HEAP32[$2>>2] = $$0$i$i$i$i$i;
    $$2 = $$0$i$i$i$i$i;
    return ($$2|0);
   }
  }
 } while(0);
 $34 = HEAP32[$0>>2]|0;
 $35 = ($6|0)==($34|0);
 $$pre = HEAP32[$6>>2]|0;
 do {
  if ($35) {
   $$sroa$052$0 = $8;
  } else {
   $36 = ($$pre|0)==(0|0);
   if ($36) {
    $$0$i$i = $6;
    while(1) {
     $40 = ((($$0$i$i)) + 8|0);
     $41 = HEAP32[$40>>2]|0;
     $42 = HEAP32[$41>>2]|0;
     $43 = ($42|0)==($$0$i$i|0);
     if ($43) {
      $$0$i$i = $41;
     } else {
      $$08$i$i = $41;
      break;
     }
    }
   } else {
    $$0$i$i$i = $$pre;
    while(1) {
     $37 = ((($$0$i$i$i)) + 4|0);
     $38 = HEAP32[$37>>2]|0;
     $39 = ($38|0)==(0|0);
     if ($39) {
      $$08$i$i = $$0$i$i$i;
      break;
     } else {
      $$0$i$i$i = $38;
     }
    }
   }
   $44 = $$08$i$i;
   $45 = ((($$08$i$i)) + 16|0);
   $46 = ((($4)) + 11|0);
   $47 = HEAP8[$46>>0]|0;
   $48 = ($47<<24>>24)<(0);
   $49 = ((($4)) + 4|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = $47&255;
   $52 = $48 ? $50 : $51;
   $53 = ((($45)) + 11|0);
   $54 = HEAP8[$53>>0]|0;
   $55 = ($54<<24>>24)<(0);
   $56 = ((($$08$i$i)) + 20|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = $54&255;
   $59 = $55 ? $57 : $58;
   $60 = ($52>>>0)<($59>>>0);
   $$sroa$speculated$i$i$i$i$i26 = $60 ? $52 : $59;
   $61 = ($$sroa$speculated$i$i$i$i$i26|0)==(0);
   if ($61) {
    label = 12;
   } else {
    $62 = HEAP32[$45>>2]|0;
    $63 = $55 ? $62 : $45;
    $64 = HEAP32[$4>>2]|0;
    $65 = $48 ? $64 : $4;
    $66 = (_memcmp($63,$65,$$sroa$speculated$i$i$i$i$i26)|0);
    $67 = ($66|0)==(0);
    if ($67) {
     label = 12;
    } else {
     $69 = ($66|0)<(0);
     if ($69) {
      $$sroa$052$0 = $44;
      break;
     }
    }
   }
   if ((label|0) == 12) {
    $68 = ($59>>>0)<($52>>>0);
    if ($68) {
     $$sroa$052$0 = $44;
     break;
    }
   }
   $73 = (__ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4pairIS7_jEEEENS_19__map_value_compareIS7_SA_NS_4lessIS7_EELb1EEENS5_ISA_EEE12__find_equalIS7_EERPNS_16__tree_node_baseIPvEERPNS_15__tree_end_nodeISL_EERKT_($0,$2,$4)|0);
   $$2 = $73;
   return ($$2|0);
  }
 } while(0);
 $70 = ($$pre|0)==(0|0);
 if ($70) {
  HEAP32[$2>>2] = $6;
  $$2 = $6;
  return ($$2|0);
 } else {
  $71 = $$sroa$052$0;
  HEAP32[$2>>2] = $71;
  $72 = ((($71)) + 4|0);
  $$2 = $72;
  return ($$2|0);
 }
 return (0)|0;
}
function __ZNSt3__23mapINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4pairIN3osg7ref_ptrINS8_7UniformEEEjEENS_4lessIS6_EENS4_INS7_IKS6_SC_EEEEEixERSF_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$014 = 0, $$pre$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = (__ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4pairIN3osg7ref_ptrINS9_7UniformEEEjEEEENS_19__map_value_compareIS7_SE_NS_4lessIS7_EELb1EEENS5_ISE_EEE12__find_equalIS7_EERPNS_16__tree_node_baseIPvEERPNS_15__tree_end_nodeISP_EERKT_($0,$2,$1)|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if (!($5)) {
  $$014 = $4;
  $27 = ((($$014)) + 28|0);
  STACKTOP = sp;return ($27|0);
 }
 $6 = (__Znwj(36)|0);
 $7 = ((($6)) + 16|0);
 __THREW__ = 0;
 invoke_vii(3457,($7|0),($1|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $10 = ___cxa_find_matching_catch_2()|0;
  $11 = tempRet0;
  __ZdlPv($6);
  ___resumeException($10|0);
  // unreachable;
 }
 $12 = ((($6)) + 28|0);
 HEAP32[$12>>2] = 0;
 $13 = ((($6)) + 32|0);
 HEAP32[$13>>2] = 0;
 $14 = HEAP32[$2>>2]|0;
 HEAP32[$6>>2] = 0;
 $15 = ((($6)) + 4|0);
 HEAP32[$15>>2] = 0;
 $16 = ((($6)) + 8|0);
 HEAP32[$16>>2] = $14;
 HEAP32[$3>>2] = $6;
 $17 = HEAP32[$0>>2]|0;
 $18 = HEAP32[$17>>2]|0;
 $19 = ($18|0)==(0|0);
 if ($19) {
  $23 = $6;
 } else {
  $20 = $18;
  HEAP32[$0>>2] = $20;
  $$pre$i = HEAP32[$3>>2]|0;
  $23 = $$pre$i;
 }
 $21 = ((($0)) + 4|0);
 $22 = HEAP32[$21>>2]|0;
 __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($22,$23);
 $24 = ((($0)) + 8|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($25) + 1)|0;
 HEAP32[$24>>2] = $26;
 $$014 = $6;
 $27 = ((($$014)) + 28|0);
 STACKTOP = sp;return ($27|0);
}
function __ZNSt3__26vectorINS_3mapINS_4pairIN3osg14StateAttribute4TypeEjEENS2_INS3_7ref_ptrIS4_EEjEENS_4lessIS6_EENS_9allocatorINS2_IKS6_S9_EEEEEENSC_ISG_EEE26__swap_out_circular_bufferERNS_14__split_bufferISG_RSH_EE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i$i$i$i$i$i = 0, $$0$i$i$i$i$i$i$i$i = 0, $$08$i = 0, $$byval_copy = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i$i$i$i$i$i$i = 0, $$pre$phi19Z2D = 0, $$pre$phiZ2D = 0, $$pre16 = 0, $$sroa$07$0$i$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy = sp + 12|0;
 $2 = sp + 8|0;
 $3 = sp + 4|0;
 $4 = sp;
 $5 = HEAP32[$0>>2]|0;
 $6 = ((($0)) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($1)) + 4|0);
 $9 = ($7|0)==($5|0);
 if ($9) {
  $10 = $5;
  $$pre16 = HEAP32[$8>>2]|0;
  $$pre$phi19Z2D = $8;$$pre$phiZ2D = $0;$84 = $$pre16;$85 = $10;
  HEAP32[$$pre$phiZ2D>>2] = $84;
  HEAP32[$$pre$phi19Z2D>>2] = $85;
  $86 = ((($1)) + 8|0);
  $87 = HEAP32[$6>>2]|0;
  $88 = HEAP32[$86>>2]|0;
  HEAP32[$6>>2] = $88;
  HEAP32[$86>>2] = $87;
  $89 = ((($0)) + 8|0);
  $90 = ((($1)) + 12|0);
  $91 = HEAP32[$89>>2]|0;
  $92 = HEAP32[$90>>2]|0;
  HEAP32[$89>>2] = $92;
  HEAP32[$90>>2] = $91;
  $93 = HEAP32[$$pre$phi19Z2D>>2]|0;
  HEAP32[$1>>2] = $93;
  STACKTOP = sp;return;
 }
 $$pre$i = HEAP32[$8>>2]|0;
 $$08$i = $7;$12 = $$pre$i;
 L5: while(1) {
  $11 = ((($12)) + -12|0);
  $13 = ((($$08$i)) + -12|0);
  $14 = ((($12)) + -8|0);
  HEAP32[$14>>2] = 0;
  $15 = ((($12)) + -4|0);
  HEAP32[$15>>2] = 0;
  $16 = ((($12)) + -8|0);
  HEAP32[$11>>2] = $16;
  $17 = HEAP32[$13>>2]|0;
  $18 = ((($$08$i)) + -8|0);
  $19 = ($17|0)==($18|0);
  if (!($19)) {
   $20 = $16;
   $$sroa$07$0$i$i$i = $17;
   while(1) {
    $21 = ((($$sroa$07$0$i$i$i)) + 16|0);
    HEAP32[$4>>2] = $20;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy>>2]=HEAP32[$4>>2]|0;
    $22 = (invoke_iiiiii(3948,($11|0),($$byval_copy|0),($2|0),($3|0),($21|0))|0);
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if ($24) {
     label = 20;
     break L5;
    }
    $25 = HEAP32[$22>>2]|0;
    $26 = ($25|0)==(0|0);
    if ($26) {
     __THREW__ = 0;
     $27 = (invoke_ii(3276,32)|0);
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      label = 20;
      break L5;
     }
     $30 = ((($27)) + 16|0);
     $31 = $21;
     $32 = $31;
     $33 = HEAP32[$32>>2]|0;
     $34 = (($31) + 4)|0;
     $35 = $34;
     $36 = HEAP32[$35>>2]|0;
     $37 = $30;
     $38 = $37;
     HEAP32[$38>>2] = $33;
     $39 = (($37) + 4)|0;
     $40 = $39;
     HEAP32[$40>>2] = $36;
     $41 = ((($27)) + 24|0);
     $42 = ((($$sroa$07$0$i$i$i)) + 24|0);
     $43 = HEAP32[$42>>2]|0;
     HEAP32[$41>>2] = $43;
     $44 = ($43|0)==(0|0);
     if (!($44)) {
      $45 = ((($43)) + 8|0);
      $46 = HEAP32[$45>>2]|0;HEAP32[$45>>2] = (($46+1)|0);
     }
     $47 = ((($27)) + 28|0);
     $48 = ((($$sroa$07$0$i$i$i)) + 28|0);
     $49 = HEAP32[$48>>2]|0;
     HEAP32[$47>>2] = $49;
     $50 = HEAP32[$2>>2]|0;
     HEAP32[$27>>2] = 0;
     $51 = ((($27)) + 4|0);
     HEAP32[$51>>2] = 0;
     $52 = ((($27)) + 8|0);
     HEAP32[$52>>2] = $50;
     HEAP32[$22>>2] = $27;
     $53 = HEAP32[$11>>2]|0;
     $54 = HEAP32[$53>>2]|0;
     $55 = ($54|0)==(0|0);
     if ($55) {
      $58 = $27;
     } else {
      $56 = $54;
      HEAP32[$11>>2] = $56;
      $$pre$i$i$i$i$i$i$i$i = HEAP32[$22>>2]|0;
      $58 = $$pre$i$i$i$i$i$i$i$i;
     }
     $57 = HEAP32[$14>>2]|0;
     __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($57,$58);
     $59 = HEAP32[$15>>2]|0;
     $60 = (($59) + 1)|0;
     HEAP32[$15>>2] = $60;
    }
    $61 = ((($$sroa$07$0$i$i$i)) + 4|0);
    $62 = HEAP32[$61>>2]|0;
    $63 = ($62|0)==(0|0);
    if ($63) {
     $64 = ((($$sroa$07$0$i$i$i)) + 8|0);
     $65 = HEAP32[$64>>2]|0;
     $66 = HEAP32[$65>>2]|0;
     $67 = ($66|0)==($$sroa$07$0$i$i$i|0);
     if ($67) {
      $$0$i$i$i$i$i$i$i = $65;
     } else {
      $71 = $64;
      while(1) {
       $70 = HEAP32[$71>>2]|0;
       $72 = ((($70)) + 8|0);
       $73 = HEAP32[$72>>2]|0;
       $74 = HEAP32[$73>>2]|0;
       $75 = ($74|0)==($70|0);
       if ($75) {
        $$0$i$i$i$i$i$i$i = $73;
        break;
       } else {
        $71 = $72;
       }
      }
     }
    } else {
     $$0$i$i$i$i$i$i$i$i = $62;
     while(1) {
      $68 = HEAP32[$$0$i$i$i$i$i$i$i$i>>2]|0;
      $69 = ($68|0)==(0|0);
      if ($69) {
       break;
      } else {
       $$0$i$i$i$i$i$i$i$i = $68;
      }
     }
     $$0$i$i$i$i$i$i$i = $$0$i$i$i$i$i$i$i$i;
    }
    $76 = ($$0$i$i$i$i$i$i$i|0)==($18|0);
    if ($76) {
     break;
    } else {
     $$sroa$07$0$i$i$i = $$0$i$i$i$i$i$i$i;
    }
   }
  }
  $80 = HEAP32[$8>>2]|0;
  $81 = ((($80)) + -12|0);
  HEAP32[$8>>2] = $81;
  $82 = ($13|0)==($5|0);
  if ($82) {
   label = 22;
   break;
  } else {
   $$08$i = $13;$12 = $81;
  }
 }
 if ((label|0) == 20) {
  $77 = ___cxa_find_matching_catch_2()|0;
  $78 = tempRet0;
  $79 = HEAP32[$16>>2]|0;
  __ZNSt3__26__treeINS_12__value_typeINS_4pairIN3osg14StateAttribute4TypeEjEENS2_INS3_7ref_ptrIS4_EEjEEEENS_19__map_value_compareIS6_SA_NS_4lessIS6_EELb1EEENS_9allocatorISA_EEE7destroyEPNS_11__tree_nodeISA_PvEE($11,$79);
  ___resumeException($77|0);
  // unreachable;
 }
 else if ((label|0) == 22) {
  $83 = $81;
  $$pre = HEAP32[$0>>2]|0;
  $$pre$phi19Z2D = $8;$$pre$phiZ2D = $0;$84 = $83;$85 = $$pre;
  HEAP32[$$pre$phiZ2D>>2] = $84;
  HEAP32[$$pre$phi19Z2D>>2] = $85;
  $86 = ((($1)) + 8|0);
  $87 = HEAP32[$6>>2]|0;
  $88 = HEAP32[$86>>2]|0;
  HEAP32[$6>>2] = $88;
  HEAP32[$86>>2] = $87;
  $89 = ((($0)) + 8|0);
  $90 = ((($1)) + 12|0);
  $91 = HEAP32[$89>>2]|0;
  $92 = HEAP32[$90>>2]|0;
  HEAP32[$89>>2] = $92;
  HEAP32[$90>>2] = $91;
  $93 = HEAP32[$$pre$phi19Z2D>>2]|0;
  HEAP32[$1>>2] = $93;
  STACKTOP = sp;return;
 }
}
function __ZNSt3__26__treeINS_12__value_typeINS_4pairIN3osg14StateAttribute4TypeEjEENS2_INS3_7ref_ptrIS4_EEjEEEENS_19__map_value_compareIS6_SA_NS_4lessIS6_EELb1EEENS_9allocatorISA_EEE12__find_equalIS6_EERPNS_16__tree_node_baseIPvEENS_21__tree_const_iteratorISA_PNS_11__tree_nodeISA_SK_EEiEERPNS_15__tree_end_nodeISM_EESN_RKT_($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0$i = 0, $$0$i$i = 0, $$0$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i$i = 0, $$0$i26 = 0, $$0$ph$i = 0, $$0$ph$i23 = 0, $$024$i = 0, $$024$i25 = 0, $$08$i$i = 0, $$2 = 0, $$in$i = 0, $$in$i22 = 0, $$pre = 0, $$sroa$050$0 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = ((($0)) + 4|0);
 $6 = HEAP32[$1>>2]|0;
 $7 = ($6|0)==($5|0);
 $8 = $6;
 do {
  if (!($7)) {
   $9 = HEAP32[$4>>2]|0;
   $10 = ((($6)) + 16|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = ($9|0)<($11|0);
   if (!($12)) {
    $13 = ($11|0)<($9|0);
    if (!($13)) {
     $14 = ((($4)) + 4|0);
     $15 = HEAP32[$14>>2]|0;
     $16 = ((($6)) + 20|0);
     $17 = HEAP32[$16>>2]|0;
     $18 = ($15>>>0)<($17>>>0);
     if ($18) {
      break;
     }
     $61 = ((($6)) + 20|0);
     $62 = HEAP32[$61>>2]|0;
     $63 = ((($4)) + 4|0);
     $64 = HEAP32[$63>>2]|0;
     $65 = ($62>>>0)<($64>>>0);
     if (!($65)) {
      HEAP32[$2>>2] = $8;
      HEAP32[$3>>2] = $8;
      $$2 = $3;
      return ($$2|0);
     }
    }
    $66 = ((($6)) + 4|0);
    $67 = HEAP32[$66>>2]|0;
    $68 = ($67|0)==(0|0);
    if ($68) {
     $69 = ((($6)) + 8|0);
     $70 = HEAP32[$69>>2]|0;
     $71 = HEAP32[$70>>2]|0;
     $72 = ($71|0)==($6|0);
     if ($72) {
      $$0$i$i$i$i$i = $70;
     } else {
      $76 = $69;
      while(1) {
       $75 = HEAP32[$76>>2]|0;
       $77 = ((($75)) + 8|0);
       $78 = HEAP32[$77>>2]|0;
       $79 = HEAP32[$78>>2]|0;
       $80 = ($79|0)==($75|0);
       if ($80) {
        $$0$i$i$i$i$i = $78;
        break;
       } else {
        $76 = $77;
       }
      }
     }
    } else {
     $$0$i$i$i$i$i$i = $67;
     while(1) {
      $73 = HEAP32[$$0$i$i$i$i$i$i>>2]|0;
      $74 = ($73|0)==(0|0);
      if ($74) {
       break;
      } else {
       $$0$i$i$i$i$i$i = $73;
      }
     }
     $$0$i$i$i$i$i = $$0$i$i$i$i$i$i;
    }
    $81 = ($$0$i$i$i$i$i|0)==($5|0);
    do {
     if (!($81)) {
      $82 = ((($$0$i$i$i$i$i)) + 16|0);
      $83 = HEAP32[$82>>2]|0;
      $84 = ($9|0)<($83|0);
      if (!($84)) {
       $85 = ($83|0)<($9|0);
       if (!($85)) {
        $86 = ((($4)) + 4|0);
        $87 = HEAP32[$86>>2]|0;
        $88 = ((($$0$i$i$i$i$i)) + 20|0);
        $89 = HEAP32[$88>>2]|0;
        $90 = ($87>>>0)<($89>>>0);
        if ($90) {
         break;
        }
       }
       $94 = HEAP32[$5>>2]|0;
       $95 = ($94|0)==(0|0);
       if ($95) {
        HEAP32[$2>>2] = $5;
        $$2 = $5;
        return ($$2|0);
       }
       $96 = ((($0)) + 4|0);
       $97 = ((($4)) + 4|0);
       $98 = HEAP32[$97>>2]|0;
       $$0$i = $96;$$024$i = $94;
       L28: while(1) {
        $99 = ((($$024$i)) + 16|0);
        $100 = HEAP32[$99>>2]|0;
        $101 = ($9|0)<($100|0);
        do {
         if ($101) {
          label = 47;
         } else {
          $102 = ($100|0)<($9|0);
          if (!($102)) {
           $103 = ((($$024$i)) + 20|0);
           $104 = HEAP32[$103>>2]|0;
           $105 = ($98>>>0)<($104>>>0);
           if ($105) {
            label = 47;
            break;
           }
           $108 = ($104>>>0)<($98>>>0);
           if (!($108)) {
            label = 52;
            break L28;
           }
          }
          $109 = ((($$024$i)) + 4|0);
          $110 = HEAP32[$109>>2]|0;
          $111 = ($110|0)==(0|0);
          if ($111) {
           label = 51;
           break L28;
          } else {
           $$0$ph$i = $109;$$in$i = $110;
          }
         }
        } while(0);
        if ((label|0) == 47) {
         label = 0;
         $106 = HEAP32[$$024$i>>2]|0;
         $107 = ($106|0)==(0|0);
         if ($107) {
          label = 48;
          break;
         } else {
          $$0$ph$i = $$024$i;$$in$i = $106;
         }
        }
        $$0$i = $$0$ph$i;$$024$i = $$in$i;
       }
       if ((label|0) == 48) {
        HEAP32[$2>>2] = $$024$i;
        $$2 = $$024$i;
        return ($$2|0);
       }
       else if ((label|0) == 51) {
        HEAP32[$2>>2] = $$024$i;
        $$2 = $109;
        return ($$2|0);
       }
       else if ((label|0) == 52) {
        HEAP32[$2>>2] = $$024$i;
        $$2 = $$0$i;
        return ($$2|0);
       }
      }
     }
    } while(0);
    $91 = ((($6)) + 4|0);
    $92 = HEAP32[$91>>2]|0;
    $93 = ($92|0)==(0|0);
    if ($93) {
     HEAP32[$2>>2] = $8;
     $$2 = $66;
     return ($$2|0);
    } else {
     HEAP32[$2>>2] = $$0$i$i$i$i$i;
     $$2 = $$0$i$i$i$i$i;
     return ($$2|0);
    }
   }
  }
 } while(0);
 $19 = HEAP32[$0>>2]|0;
 $20 = ($6|0)==($19|0);
 $$pre = HEAP32[$6>>2]|0;
 do {
  if ($20) {
   $$sroa$050$0 = $8;
  } else {
   $21 = ($$pre|0)==(0|0);
   if ($21) {
    $$0$i$i = $6;
    while(1) {
     $25 = ((($$0$i$i)) + 8|0);
     $26 = HEAP32[$25>>2]|0;
     $27 = HEAP32[$26>>2]|0;
     $28 = ($27|0)==($$0$i$i|0);
     if ($28) {
      $$0$i$i = $26;
     } else {
      $$08$i$i = $26;
      break;
     }
    }
   } else {
    $$0$i$i$i = $$pre;
    while(1) {
     $22 = ((($$0$i$i$i)) + 4|0);
     $23 = HEAP32[$22>>2]|0;
     $24 = ($23|0)==(0|0);
     if ($24) {
      $$08$i$i = $$0$i$i$i;
      break;
     } else {
      $$0$i$i$i = $23;
     }
    }
   }
   $29 = $$08$i$i;
   $30 = ((($$08$i$i)) + 16|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = HEAP32[$4>>2]|0;
   $33 = ($31|0)<($32|0);
   if ($33) {
    $$sroa$050$0 = $29;
   } else {
    $34 = ($32|0)<($31|0);
    if (!($34)) {
     $35 = ((($$08$i$i)) + 20|0);
     $36 = HEAP32[$35>>2]|0;
     $37 = ((($4)) + 4|0);
     $38 = HEAP32[$37>>2]|0;
     $39 = ($36>>>0)<($38>>>0);
     if ($39) {
      $$sroa$050$0 = $29;
      break;
     }
    }
    $43 = HEAP32[$5>>2]|0;
    $44 = ($43|0)==(0|0);
    if ($44) {
     HEAP32[$2>>2] = $5;
     $$2 = $5;
     return ($$2|0);
    }
    $45 = ((($0)) + 4|0);
    $46 = ((($4)) + 4|0);
    $47 = HEAP32[$46>>2]|0;
    $$0$i26 = $45;$$024$i25 = $43;
    L69: while(1) {
     $48 = ((($$024$i25)) + 16|0);
     $49 = HEAP32[$48>>2]|0;
     $50 = ($32|0)<($49|0);
     do {
      if ($50) {
       label = 21;
      } else {
       $51 = ($49|0)<($32|0);
       if (!($51)) {
        $52 = ((($$024$i25)) + 20|0);
        $53 = HEAP32[$52>>2]|0;
        $54 = ($47>>>0)<($53>>>0);
        if ($54) {
         label = 21;
         break;
        }
        $57 = ($53>>>0)<($47>>>0);
        if (!($57)) {
         label = 26;
         break L69;
        }
       }
       $58 = ((($$024$i25)) + 4|0);
       $59 = HEAP32[$58>>2]|0;
       $60 = ($59|0)==(0|0);
       if ($60) {
        label = 25;
        break L69;
       } else {
        $$0$ph$i23 = $58;$$in$i22 = $59;
       }
      }
     } while(0);
     if ((label|0) == 21) {
      label = 0;
      $55 = HEAP32[$$024$i25>>2]|0;
      $56 = ($55|0)==(0|0);
      if ($56) {
       label = 22;
       break;
      } else {
       $$0$ph$i23 = $$024$i25;$$in$i22 = $55;
      }
     }
     $$0$i26 = $$0$ph$i23;$$024$i25 = $$in$i22;
    }
    if ((label|0) == 22) {
     HEAP32[$2>>2] = $$024$i25;
     $$2 = $$024$i25;
     return ($$2|0);
    }
    else if ((label|0) == 25) {
     HEAP32[$2>>2] = $$024$i25;
     $$2 = $58;
     return ($$2|0);
    }
    else if ((label|0) == 26) {
     HEAP32[$2>>2] = $$024$i25;
     $$2 = $$0$i26;
     return ($$2|0);
    }
   }
  }
 } while(0);
 $40 = ($$pre|0)==(0|0);
 if ($40) {
  HEAP32[$2>>2] = $6;
  $$2 = $6;
  return ($$2|0);
 } else {
  $41 = $$sroa$050$0;
  HEAP32[$2>>2] = $41;
  $42 = ((($41)) + 4|0);
  $$2 = $42;
  return ($$2|0);
 }
 return (0)|0;
}
function __ZNSt3__26vectorINS_3mapIjjNS_4lessIjEENS_9allocatorINS_4pairIKjjEEEEEENS4_IS9_EEE18__construct_at_endIPS9_EENS_9enable_ifIXsr21__is_forward_iteratorIT_EE5valueEvE4typeESF_SF_j($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0$i$i$i$i$i$i$i = 0, $$0$i$i$i$i$i$i$i$i = 0, $$09$i = 0, $$byval_copy = 0, $$in8$i$i$i$i = 0, $$pre$i = 0, $$pre$i$i$i$i$i$i$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy = sp + 12|0;
 $4 = sp + 8|0;
 $5 = sp + 4|0;
 $6 = sp;
 $7 = ((($0)) + 4|0);
 $8 = ($1|0)==($2|0);
 if ($8) {
  STACKTOP = sp;return;
 }
 $$pre$i = HEAP32[$7>>2]|0;
 $$09$i = $1;$10 = $$pre$i;
 L4: while(1) {
  $9 = ((($10)) + 4|0);
  HEAP32[$9>>2] = 0;
  $11 = ((($10)) + 8|0);
  HEAP32[$11>>2] = 0;
  $12 = ((($10)) + 4|0);
  HEAP32[$10>>2] = $12;
  $13 = HEAP32[$$09$i>>2]|0;
  $14 = ((($$09$i)) + 4|0);
  $15 = ($13|0)==($14|0);
  if (!($15)) {
   $16 = $12;
   $$in8$i$i$i$i = $13;
   while(1) {
    $17 = ((($$in8$i$i$i$i)) + 16|0);
    HEAP32[$6>>2] = $16;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy>>2]=HEAP32[$6>>2]|0;
    $18 = (invoke_iiiiii(3940,($10|0),($$byval_copy|0),($4|0),($5|0),($17|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     label = 17;
     break L4;
    }
    $21 = HEAP32[$18>>2]|0;
    $22 = ($21|0)==(0|0);
    if ($22) {
     __THREW__ = 0;
     $23 = (invoke_ii(3276,24)|0);
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if ($25) {
      label = 17;
      break L4;
     }
     $26 = ((($23)) + 16|0);
     $27 = $17;
     $28 = $27;
     $29 = HEAP32[$28>>2]|0;
     $30 = (($27) + 4)|0;
     $31 = $30;
     $32 = HEAP32[$31>>2]|0;
     $33 = $26;
     $34 = $33;
     HEAP32[$34>>2] = $29;
     $35 = (($33) + 4)|0;
     $36 = $35;
     HEAP32[$36>>2] = $32;
     $37 = HEAP32[$4>>2]|0;
     HEAP32[$23>>2] = 0;
     $38 = ((($23)) + 4|0);
     HEAP32[$38>>2] = 0;
     $39 = ((($23)) + 8|0);
     HEAP32[$39>>2] = $37;
     HEAP32[$18>>2] = $23;
     $40 = HEAP32[$10>>2]|0;
     $41 = HEAP32[$40>>2]|0;
     $42 = ($41|0)==(0|0);
     if ($42) {
      $45 = $23;
     } else {
      $43 = $41;
      HEAP32[$10>>2] = $43;
      $$pre$i$i$i$i$i$i$i$i = HEAP32[$18>>2]|0;
      $45 = $$pre$i$i$i$i$i$i$i$i;
     }
     $44 = HEAP32[$9>>2]|0;
     __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($44,$45);
     $46 = HEAP32[$11>>2]|0;
     $47 = (($46) + 1)|0;
     HEAP32[$11>>2] = $47;
    }
    $48 = ((($$in8$i$i$i$i)) + 4|0);
    $49 = HEAP32[$48>>2]|0;
    $50 = ($49|0)==(0|0);
    if ($50) {
     $51 = ((($$in8$i$i$i$i)) + 8|0);
     $52 = HEAP32[$51>>2]|0;
     $53 = HEAP32[$52>>2]|0;
     $54 = ($53|0)==($$in8$i$i$i$i|0);
     if ($54) {
      $$0$i$i$i$i$i$i$i = $52;
     } else {
      $58 = $51;
      while(1) {
       $57 = HEAP32[$58>>2]|0;
       $59 = ((($57)) + 8|0);
       $60 = HEAP32[$59>>2]|0;
       $61 = HEAP32[$60>>2]|0;
       $62 = ($61|0)==($57|0);
       if ($62) {
        $$0$i$i$i$i$i$i$i = $60;
        break;
       } else {
        $58 = $59;
       }
      }
     }
    } else {
     $$0$i$i$i$i$i$i$i$i = $49;
     while(1) {
      $55 = HEAP32[$$0$i$i$i$i$i$i$i$i>>2]|0;
      $56 = ($55|0)==(0|0);
      if ($56) {
       break;
      } else {
       $$0$i$i$i$i$i$i$i$i = $55;
      }
     }
     $$0$i$i$i$i$i$i$i = $$0$i$i$i$i$i$i$i$i;
    }
    $63 = ($$0$i$i$i$i$i$i$i|0)==($14|0);
    if ($63) {
     break;
    } else {
     $$in8$i$i$i$i = $$0$i$i$i$i$i$i$i;
    }
   }
  }
  $67 = ((($$09$i)) + 12|0);
  $68 = HEAP32[$7>>2]|0;
  $69 = ((($68)) + 12|0);
  HEAP32[$7>>2] = $69;
  $70 = ($67|0)==($2|0);
  if ($70) {
   label = 19;
   break;
  } else {
   $$09$i = $67;$10 = $69;
  }
 }
 if ((label|0) == 17) {
  $64 = ___cxa_find_matching_catch_2()|0;
  $65 = tempRet0;
  $66 = HEAP32[$12>>2]|0;
  __ZNSt3__26__treeINS_12__value_typeIjjEENS_19__map_value_compareIjS2_NS_4lessIjEELb1EEENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($10,$66);
  ___resumeException($64|0);
  // unreachable;
 }
 else if ((label|0) == 19) {
  STACKTOP = sp;return;
 }
}
function __ZN3osg8StateSetC2Ev($0) {
 $0 = $0|0;
 var $$pre$i = 0, $$pre$i12 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $scevgep$i$i$i = 0, $scevgep5$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg10ReferencedC2Eb($0,1);
 $1 = ((($0)) + 12|0);
 ;HEAP32[$1>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;
 $2 = ((($0)) + 24|0);
 HEAP32[$2>>2] = 2;
 $3 = ((($0)) + 28|0);
 HEAP32[$3>>2] = 0;
 HEAP32[$0>>2] = (66196);
 $4 = ((($0)) + 32|0);
 HEAP32[$4>>2] = 0;
 $5 = ((($0)) + 36|0);
 HEAP32[$5>>2] = 0;
 $6 = ((($0)) + 40|0);
 HEAP32[$6>>2] = 0;
 $7 = ((($0)) + 44|0);
 $8 = ((($0)) + 48|0);
 HEAP32[$8>>2] = 0;
 $9 = ((($0)) + 52|0);
 HEAP32[$9>>2] = 0;
 $10 = ((($0)) + 48|0);
 HEAP32[$7>>2] = $10;
 $11 = ((($0)) + 56|0);
 $12 = ((($0)) + 60|0);
 HEAP32[$12>>2] = 0;
 $13 = ((($0)) + 64|0);
 HEAP32[$13>>2] = 0;
 $14 = ((($0)) + 60|0);
 HEAP32[$11>>2] = $14;
 $15 = ((($0)) + 68|0);
 $16 = ((($0)) + 72|0);
 $17 = ((($0)) + 80|0);
 $18 = ((($0)) + 84|0);
 $19 = ((($0)) + 92|0);
 $20 = ((($0)) + 96|0);
 HEAP32[$20>>2] = 0;
 $21 = ((($0)) + 100|0);
 HEAP32[$21>>2] = 0;
 $22 = ((($0)) + 96|0);
 ;HEAP32[$15>>2]=0|0;HEAP32[$15+4>>2]=0|0;HEAP32[$15+8>>2]=0|0;HEAP32[$15+12>>2]=0|0;HEAP32[$15+16>>2]=0|0;HEAP32[$15+20>>2]=0|0;
 HEAP32[$19>>2] = $22;
 $23 = ((($0)) + 104|0);
 $24 = ((($0)) + 108|0);
 HEAP32[$24>>2] = 0;
 $25 = ((($0)) + 112|0);
 HEAP32[$25>>2] = 0;
 $26 = ((($0)) + 108|0);
 HEAP32[$23>>2] = $26;
 $27 = ((($0)) + 128|0);
 ;HEAP32[$27>>2]=0|0;HEAP32[$27+4>>2]=0|0;HEAP32[$27+8>>2]=0|0;
 $28 = ((($0)) + 140|0);
 HEAP8[$28>>0] = 1;
 $29 = ((($0)) + 144|0);
 $30 = ((($0)) + 152|0);
 $31 = ((($0)) + 116|0);
 HEAP32[$31>>2] = 0;
 $32 = ((($0)) + 120|0);
 HEAP32[$32>>2] = 0;
 $33 = ((($0)) + 124|0);
 HEAP32[$33>>2] = 0;
 ;HEAP32[$29>>2]=0|0;HEAP32[$29+4>>2]=0|0;HEAP32[$29+8>>2]=0|0;HEAP32[$29+12>>2]=0|0;
 __THREW__ = 0;
 (invoke_iii(3786,($27|0),(221531|0))|0);
 $34 = __THREW__; __THREW__ = 0;
 $35 = $34&1;
 if (!($35)) {
  return;
 }
 $36 = ___cxa_find_matching_catch_2()|0;
 $37 = tempRet0;
 $38 = HEAP32[$30>>2]|0;
 $39 = ($38|0)==(0|0);
 if (!($39)) {
  $40 = HEAP32[$38>>2]|0;
  $41 = ((($40)) + -16|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = (($38) + ($42)|0);
  $44 = ((($43)) + 8|0);
  $45 = HEAP32[$44>>2]|0;HEAP32[$44>>2] = (($45-1)|0);
  $46 = ($45|0)==(1);
  if ($46) {
   __THREW__ = 0;
   invoke_viii(3262,($43|0),1,1);
   $47 = __THREW__; __THREW__ = 0;
   $48 = $47&1;
   if ($48) {
    $101 = ___cxa_find_matching_catch_3(0|0)|0;
    $102 = tempRet0;
    ___clang_call_terminate($101);
    // unreachable;
   }
  }
 }
 HEAP32[$30>>2] = 0;
 $49 = HEAP32[$29>>2]|0;
 $50 = ($49|0)==(0|0);
 if (!($50)) {
  $51 = HEAP32[$49>>2]|0;
  $52 = ((($51)) + -16|0);
  $53 = HEAP32[$52>>2]|0;
  $54 = (($49) + ($53)|0);
  $55 = ((($54)) + 8|0);
  $56 = HEAP32[$55>>2]|0;HEAP32[$55>>2] = (($56-1)|0);
  $57 = ($56|0)==(1);
  if ($57) {
   __THREW__ = 0;
   invoke_viii(3262,($54|0),1,1);
   $58 = __THREW__; __THREW__ = 0;
   $59 = $58&1;
   if ($59) {
    $101 = ___cxa_find_matching_catch_3(0|0)|0;
    $102 = tempRet0;
    ___clang_call_terminate($101);
    // unreachable;
   }
  }
 }
 HEAP32[$29>>2] = 0;
 $60 = ((($27)) + 11|0);
 $61 = HEAP8[$60>>0]|0;
 $62 = ($61<<24>>24)<(0);
 if ($62) {
  $63 = HEAP32[$27>>2]|0;
  __ZdlPv($63);
 }
 $64 = HEAP32[$26>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4pairIS7_jEEEENS_19__map_value_compareIS7_SA_NS_4lessIS7_EELb1EEENS5_ISA_EEE7destroyEPNS_11__tree_nodeISA_PvEE($23,$64);
 $65 = HEAP32[$22>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4pairIN3osg7ref_ptrINS9_7UniformEEEjEEEENS_19__map_value_compareIS7_SE_NS_4lessIS7_EELb1EEENS5_ISE_EEE7destroyEPNS_11__tree_nodeISE_PvEE($19,$65);
 $66 = HEAP32[$17>>2]|0;
 $67 = ($66|0)==(0|0);
 if (!($67)) {
  $68 = HEAP32[$18>>2]|0;
  $69 = ($68|0)==($66|0);
  if ($69) {
   $76 = $66;
  } else {
   $71 = $68;
   while(1) {
    $70 = ((($71)) + -12|0);
    HEAP32[$18>>2] = $70;
    $72 = ((($71)) + -8|0);
    $73 = HEAP32[$72>>2]|0;
    __ZNSt3__26__treeINS_12__value_typeINS_4pairIN3osg14StateAttribute4TypeEjEENS2_INS3_7ref_ptrIS4_EEjEEEENS_19__map_value_compareIS6_SA_NS_4lessIS6_EELb1EEENS_9allocatorISA_EEE7destroyEPNS_11__tree_nodeISA_PvEE($70,$73);
    $74 = HEAP32[$18>>2]|0;
    $75 = ($74|0)==($66|0);
    if ($75) {
     break;
    } else {
     $71 = $74;
    }
   }
   $$pre$i12 = HEAP32[$17>>2]|0;
   $76 = $$pre$i12;
  }
  __ZdlPv($76);
 }
 $77 = HEAP32[$15>>2]|0;
 $78 = ($77|0)==(0|0);
 if (!($78)) {
  $79 = HEAP32[$16>>2]|0;
  $80 = ($79|0)==($77|0);
  if ($80) {
   $87 = $77;
  } else {
   $82 = $79;
   while(1) {
    $81 = ((($82)) + -12|0);
    HEAP32[$16>>2] = $81;
    $83 = ((($82)) + -8|0);
    $84 = HEAP32[$83>>2]|0;
    __ZNSt3__26__treeINS_12__value_typeIjjEENS_19__map_value_compareIjS2_NS_4lessIjEELb1EEENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($81,$84);
    $85 = HEAP32[$16>>2]|0;
    $86 = ($85|0)==($77|0);
    if ($86) {
     break;
    } else {
     $82 = $85;
    }
   }
   $$pre$i = HEAP32[$15>>2]|0;
   $87 = $$pre$i;
  }
  __ZdlPv($87);
 }
 $88 = HEAP32[$14>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_4pairIN3osg14StateAttribute4TypeEjEENS2_INS3_7ref_ptrIS4_EEjEEEENS_19__map_value_compareIS6_SA_NS_4lessIS6_EELb1EEENS_9allocatorISA_EEE7destroyEPNS_11__tree_nodeISA_PvEE($11,$88);
 $89 = HEAP32[$10>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIjjEENS_19__map_value_compareIjS2_NS_4lessIjEELb1EEENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($7,$89);
 $90 = HEAP32[$4>>2]|0;
 $91 = ($90|0)==(0|0);
 if (!($91)) {
  $92 = HEAP32[$5>>2]|0;
  $93 = ($92|0)==($90|0);
  if (!($93)) {
   $scevgep$i$i$i = ((($92)) + -4|0);
   $94 = $scevgep$i$i$i;
   $95 = $90;
   $96 = (($94) - ($95))|0;
   $97 = $96 >>> 2;
   $98 = $97 ^ -1;
   $scevgep5$i$i$i = (($92) + ($98<<2)|0);
   HEAP32[$5>>2] = $scevgep5$i$i$i;
  }
  __ZdlPv($90);
 }
 __THREW__ = 0;
 invoke_vi(388,($0|0));
 $99 = __THREW__; __THREW__ = 0;
 $100 = $99&1;
 if ($100) {
  $101 = ___cxa_find_matching_catch_3(0|0)|0;
  $102 = tempRet0;
  ___clang_call_terminate($101);
  // unreachable;
 } else {
  ___resumeException($36|0);
  // unreachable;
 }
}
function __ZN3osg8StateSet5clearEv($0) {
 $0 = $0|0;
 var $$0$i$i$i$i = 0, $$0$i$i$i$i17 = 0, $$0$i$i$i$i9 = 0, $$049 = 0, $$pre = 0, $$pre59 = 0, $$pre60 = 0, $$pre61 = 0, $$sroa$024$0$be = 0, $$sroa$024$046 = 0, $$sroa$030$0$be = 0, $$sroa$030$047 = 0, $$sroa$036$0$be = 0, $$sroa$036$053 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0;
 var $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0;
 var $122 = 0, $123 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 116|0);
 HEAP32[$1>>2] = 0;
 $2 = ((($0)) + 120|0);
 HEAP32[$2>>2] = 0;
 $3 = ((($0)) + 124|0);
 HEAP32[$3>>2] = 0;
 $4 = ((($0)) + 128|0);
 (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($4,221531)|0);
 $5 = ((($0)) + 56|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($0)) + 60|0);
 $8 = ($6|0)==($7|0);
 if (!($8)) {
  $$sroa$036$053 = $6;
  while(1) {
   $22 = ((($$sroa$036$053)) + 24|0);
   $23 = HEAP32[$22>>2]|0;
   __ZN3osg14StateAttribute12removeParentEPNS_8StateSetE($23,$0);
   $24 = ((($$sroa$036$053)) + 4|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = ($25|0)==(0|0);
   if ($26) {
    $27 = ((($$sroa$036$053)) + 8|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = HEAP32[$28>>2]|0;
    $30 = ($29|0)==($$sroa$036$053|0);
    if ($30) {
     $$sroa$036$0$be = $28;
    } else {
     $35 = $27;
     while(1) {
      $34 = HEAP32[$35>>2]|0;
      $36 = ((($34)) + 8|0);
      $37 = HEAP32[$36>>2]|0;
      $38 = HEAP32[$37>>2]|0;
      $39 = ($38|0)==($34|0);
      if ($39) {
       $$sroa$036$0$be = $37;
       break;
      } else {
       $35 = $36;
      }
     }
    }
   } else {
    $$0$i$i$i$i17 = $25;
    while(1) {
     $32 = HEAP32[$$0$i$i$i$i17>>2]|0;
     $33 = ($32|0)==(0|0);
     if ($33) {
      break;
     } else {
      $$0$i$i$i$i17 = $32;
     }
    }
    $$sroa$036$0$be = $$0$i$i$i$i17;
   }
   $31 = ($$sroa$036$0$be|0)==($7|0);
   if ($31) {
    break;
   } else {
    $$sroa$036$053 = $$sroa$036$0$be;
   }
  }
 }
 $9 = ((($0)) + 44|0);
 $10 = ((($0)) + 48|0);
 $11 = HEAP32[$10>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIjjEENS_19__map_value_compareIjS2_NS_4lessIjEELb1EEENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($9,$11);
 $12 = ((($0)) + 52|0);
 HEAP32[$12>>2] = 0;
 HEAP32[$9>>2] = $10;
 HEAP32[$10>>2] = 0;
 $13 = HEAP32[$7>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_4pairIN3osg14StateAttribute4TypeEjEENS2_INS3_7ref_ptrIS4_EEjEEEENS_19__map_value_compareIS6_SA_NS_4lessIS6_EELb1EEENS_9allocatorISA_EEE7destroyEPNS_11__tree_nodeISA_PvEE($5,$13);
 $14 = ((($0)) + 64|0);
 HEAP32[$14>>2] = 0;
 HEAP32[$5>>2] = $7;
 HEAP32[$7>>2] = 0;
 $15 = ((($0)) + 80|0);
 $16 = ((($0)) + 84|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = HEAP32[$15>>2]|0;
 $19 = ($17|0)==($18|0);
 $20 = $18;
 $21 = $17;
 if ($19) {
  $116 = $21;$117 = $20;
 } else {
  $$049 = 0;$118 = $21;$119 = $20;$120 = $18;$121 = $17;$65 = $20;
  while(1) {
   $64 = (($65) + (($$049*12)|0)|0);
   $66 = HEAP32[$64>>2]|0;
   $67 = (((($65) + (($$049*12)|0)|0)) + 4|0);
   $68 = ($66|0)==($67|0);
   if ($68) {
    $122 = $118;$123 = $119;$73 = $120;$74 = $121;
   } else {
    $$sroa$030$047 = $66;
    while(1) {
     $78 = ((($$sroa$030$047)) + 24|0);
     $79 = HEAP32[$78>>2]|0;
     __ZN3osg14StateAttribute12removeParentEPNS_8StateSetE($79,$0);
     $80 = ((($$sroa$030$047)) + 4|0);
     $81 = HEAP32[$80>>2]|0;
     $82 = ($81|0)==(0|0);
     if ($82) {
      $83 = ((($$sroa$030$047)) + 8|0);
      $84 = HEAP32[$83>>2]|0;
      $85 = HEAP32[$84>>2]|0;
      $86 = ($85|0)==($$sroa$030$047|0);
      if ($86) {
       $$sroa$030$0$be = $84;
      } else {
       $91 = $83;
       while(1) {
        $90 = HEAP32[$91>>2]|0;
        $92 = ((($90)) + 8|0);
        $93 = HEAP32[$92>>2]|0;
        $94 = HEAP32[$93>>2]|0;
        $95 = ($94|0)==($90|0);
        if ($95) {
         $$sroa$030$0$be = $93;
         break;
        } else {
         $91 = $92;
        }
       }
      }
     } else {
      $$0$i$i$i$i9 = $81;
      while(1) {
       $88 = HEAP32[$$0$i$i$i$i9>>2]|0;
       $89 = ($88|0)==(0|0);
       if ($89) {
        break;
       } else {
        $$0$i$i$i$i9 = $88;
       }
      }
      $$sroa$030$0$be = $$0$i$i$i$i9;
     }
     $87 = ($$sroa$030$0$be|0)==($67|0);
     if ($87) {
      break;
     } else {
      $$sroa$030$047 = $$sroa$030$0$be;
     }
    }
    $$pre = HEAP32[$16>>2]|0;
    $$pre59 = HEAP32[$15>>2]|0;
    $69 = $$pre59;
    $70 = $$pre;
    $122 = $70;$123 = $69;$73 = $$pre59;$74 = $$pre;
   }
   $71 = (($$049) + 1)|0;
   $72 = (($74) - ($73))|0;
   $75 = (($72|0) / 12)&-1;
   $76 = ($71>>>0)<($75>>>0);
   $77 = $73;
   if ($76) {
    $$049 = $71;$118 = $122;$119 = $123;$120 = $73;$121 = $74;$65 = $77;
   } else {
    $116 = $122;$117 = $123;
    break;
   }
  }
 }
 $40 = ((($0)) + 68|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = ((($0)) + 72|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = ($43|0)==($41|0);
 if ($44) {
  $51 = $116;$53 = $117;
 } else {
  $46 = $43;
  while(1) {
   $45 = ((($46)) + -12|0);
   HEAP32[$42>>2] = $45;
   $47 = ((($46)) + -8|0);
   $48 = HEAP32[$47>>2]|0;
   __ZNSt3__26__treeINS_12__value_typeIjjEENS_19__map_value_compareIjS2_NS_4lessIjEELb1EEENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($45,$48);
   $49 = HEAP32[$42>>2]|0;
   $50 = ($49|0)==($41|0);
   if ($50) {
    break;
   } else {
    $46 = $49;
   }
  }
  $$pre60 = HEAP32[$15>>2]|0;
  $$pre61 = HEAP32[$16>>2]|0;
  $51 = $$pre61;$53 = $$pre60;
 }
 $52 = ($51|0)==($53|0);
 if (!($52)) {
  $55 = $51;
  while(1) {
   $54 = ((($55)) + -12|0);
   HEAP32[$16>>2] = $54;
   $56 = ((($55)) + -8|0);
   $57 = HEAP32[$56>>2]|0;
   __ZNSt3__26__treeINS_12__value_typeINS_4pairIN3osg14StateAttribute4TypeEjEENS2_INS3_7ref_ptrIS4_EEjEEEENS_19__map_value_compareIS6_SA_NS_4lessIS6_EELb1EEENS_9allocatorISA_EEE7destroyEPNS_11__tree_nodeISA_PvEE($54,$57);
   $58 = HEAP32[$16>>2]|0;
   $59 = ($58|0)==($53|0);
   if ($59) {
    break;
   } else {
    $55 = $58;
   }
  }
 }
 $60 = ((($0)) + 92|0);
 $61 = HEAP32[$60>>2]|0;
 $62 = ((($0)) + 96|0);
 $63 = ($61|0)==($62|0);
 if ($63) {
  $96 = HEAP32[$62>>2]|0;
  __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4pairIN3osg7ref_ptrINS9_7UniformEEEjEEEENS_19__map_value_compareIS7_SE_NS_4lessIS7_EELb1EEENS5_ISE_EEE7destroyEPNS_11__tree_nodeISE_PvEE($60,$96);
  $97 = ((($0)) + 100|0);
  HEAP32[$97>>2] = 0;
  HEAP32[$60>>2] = $62;
  HEAP32[$62>>2] = 0;
  return;
 } else {
  $$sroa$024$046 = $61;
 }
 while(1) {
  $98 = ((($$sroa$024$046)) + 28|0);
  $99 = HEAP32[$98>>2]|0;
  __ZN3osg7Uniform12removeParentEPNS_8StateSetE($99,$0);
  $100 = ((($$sroa$024$046)) + 4|0);
  $101 = HEAP32[$100>>2]|0;
  $102 = ($101|0)==(0|0);
  if ($102) {
   $103 = ((($$sroa$024$046)) + 8|0);
   $104 = HEAP32[$103>>2]|0;
   $105 = HEAP32[$104>>2]|0;
   $106 = ($105|0)==($$sroa$024$046|0);
   if ($106) {
    $$sroa$024$0$be = $104;
   } else {
    $111 = $103;
    while(1) {
     $110 = HEAP32[$111>>2]|0;
     $112 = ((($110)) + 8|0);
     $113 = HEAP32[$112>>2]|0;
     $114 = HEAP32[$113>>2]|0;
     $115 = ($114|0)==($110|0);
     if ($115) {
      $$sroa$024$0$be = $113;
      break;
     } else {
      $111 = $112;
     }
    }
   }
  } else {
   $$0$i$i$i$i = $101;
   while(1) {
    $108 = HEAP32[$$0$i$i$i$i>>2]|0;
    $109 = ($108|0)==(0|0);
    if ($109) {
     break;
    } else {
     $$0$i$i$i$i = $108;
    }
   }
   $$sroa$024$0$be = $$0$i$i$i$i;
  }
  $107 = ($$sroa$024$0$be|0)==($62|0);
  if ($107) {
   break;
  } else {
   $$sroa$024$046 = $$sroa$024$0$be;
  }
 }
 $96 = HEAP32[$62>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4pairIN3osg7ref_ptrINS9_7UniformEEEjEEEENS_19__map_value_compareIS7_SE_NS_4lessIS7_EELb1EEENS5_ISE_EEE7destroyEPNS_11__tree_nodeISE_PvEE($60,$96);
 $97 = ((($0)) + 100|0);
 HEAP32[$97>>2] = 0;
 HEAP32[$60>>2] = $62;
 HEAP32[$62>>2] = 0;
 return;
}
function __Z20createDefaultTexturev() {
 var $$1 = 0, $$12 = 0, $$2 = 0, $$23 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $0 = sp;
 $1 = (__Znwj(140)|0);
 __THREW__ = 0;
 invoke_vi(3949,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $25 = ___cxa_find_matching_catch_2()|0;
  $26 = tempRet0;
  __ZdlPv($1);
  $$2 = $26;$$23 = $25;
  ___resumeException($$23|0);
  // unreachable;
 }
 $4 = ((($1)) + 8|0);
 $5 = HEAP32[$4>>2]|0;HEAP32[$4>>2] = (($5+1)|0);
 $6 = HEAP32[$1>>2]|0;
 $7 = ((($6)) + 176|0);
 $8 = HEAP32[$7>>2]|0;
 __THREW__ = 0;
 invoke_viiiiiii($8|0,($1|0),1,1,1,6408,5121,1);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 do {
  if ($10) {
   label = 8;
  } else {
   HEAPF32[$0>>2] = 1.0;
   $11 = ((($0)) + 4|0);
   HEAPF32[$11>>2] = 1.0;
   $12 = ((($0)) + 8|0);
   HEAPF32[$12>>2] = 1.0;
   $13 = ((($0)) + 12|0);
   HEAPF32[$13>>2] = 1.0;
   __THREW__ = 0;
   invoke_viiiii(3950,($1|0),($0|0),0,0,0);
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if ($15) {
    $29 = ___cxa_find_matching_catch_2()|0;
    $30 = tempRet0;
    $$1 = $30;$$12 = $29;
    break;
   }
   __THREW__ = 0;
   $16 = (invoke_ii(3276,272)|0);
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if ($18) {
    label = 8;
   } else {
    __THREW__ = 0;
    invoke_vii(3951,($16|0),($1|0));
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     $31 = ___cxa_find_matching_catch_2()|0;
     $32 = tempRet0;
     __ZdlPv($16);
     $$1 = $32;$$12 = $31;
     break;
    }
    $21 = ((($16)) + 8|0);
    $22 = HEAP32[$21>>2]|0;HEAP32[$21>>2] = (($22+1)|0);
    __THREW__ = 0;
    (invoke_ii(3335,($16|0))|0);
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if ($24) {
     $33 = ___cxa_find_matching_catch_2()|0;
     $34 = tempRet0;
     $35 = HEAP32[$21>>2]|0;HEAP32[$21>>2] = (($35-1)|0);
     $36 = ($35|0)==(1);
     if (!($36)) {
      $$1 = $34;$$12 = $33;
      break;
     }
     __THREW__ = 0;
     invoke_viii(3262,($16|0),1,1);
     $37 = __THREW__; __THREW__ = 0;
     $38 = $37&1;
     if (!($38)) {
      $$1 = $34;$$12 = $33;
      break;
     }
     $45 = ___cxa_find_matching_catch_3(0|0)|0;
     $46 = tempRet0;
     ___clang_call_terminate($45);
     // unreachable;
    }
    $39 = HEAP32[$4>>2]|0;HEAP32[$4>>2] = (($39-1)|0);
    $40 = ($39|0)==(1);
    if (!($40)) {
     STACKTOP = sp;return ($16|0);
    }
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($1,1,1);
    STACKTOP = sp;return ($16|0);
   }
  }
 } while(0);
 if ((label|0) == 8) {
  $27 = ___cxa_find_matching_catch_2()|0;
  $28 = tempRet0;
  $$1 = $28;$$12 = $27;
 }
 $41 = HEAP32[$4>>2]|0;HEAP32[$4>>2] = (($41-1)|0);
 $42 = ($41|0)==(1);
 if (!($42)) {
  $$2 = $$1;$$23 = $$12;
  ___resumeException($$23|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(3262,($1|0),1,1);
 $43 = __THREW__; __THREW__ = 0;
 $44 = $43&1;
 if ($44) {
  $45 = ___cxa_find_matching_catch_3(0|0)|0;
  $46 = tempRet0;
  ___clang_call_terminate($45);
  // unreachable;
 } else {
  $$2 = $$1;$$23 = $$12;
  ___resumeException($$23|0);
  // unreachable;
 }
 return (0)|0;
}
function __ZN16TextureGLModeSetC2Ev($0) {
 $0 = $0|0;
 var $$0$i$i$i$i104 = 0, $$0$i$i$i$i120 = 0, $$0$i$i$i$i136 = 0, $$0$i$i$i$i152 = 0, $$0$i$i$i$i168 = 0, $$0$i$i$i$i24 = 0, $$0$i$i$i$i40 = 0, $$0$i$i$i$i56 = 0, $$0$i$i$i$i72 = 0, $$0$i$i$i$i8 = 0, $$0$i$i$i$i88 = 0, $$0$ph$i$i$i$i101 = 0, $$0$ph$i$i$i$i117 = 0, $$0$ph$i$i$i$i133 = 0, $$0$ph$i$i$i$i149 = 0, $$0$ph$i$i$i$i165 = 0, $$0$ph$i$i$i$i21 = 0, $$0$ph$i$i$i$i37 = 0, $$0$ph$i$i$i$i5 = 0, $$0$ph$i$i$i$i53 = 0;
 var $$0$ph$i$i$i$i69 = 0, $$0$ph$i$i$i$i85 = 0, $$024$i$i$i$i103 = 0, $$024$i$i$i$i119 = 0, $$024$i$i$i$i135 = 0, $$024$i$i$i$i151 = 0, $$024$i$i$i$i167 = 0, $$024$i$i$i$i23 = 0, $$024$i$i$i$i39 = 0, $$024$i$i$i$i55 = 0, $$024$i$i$i$i7 = 0, $$024$i$i$i$i71 = 0, $$024$i$i$i$i87 = 0, $$025$i$i$i$i10 = 0, $$025$i$i$i$i106 = 0, $$025$i$i$i$i122 = 0, $$025$i$i$i$i138 = 0, $$025$i$i$i$i154 = 0, $$025$i$i$i$i170 = 0, $$025$i$i$i$i26 = 0;
 var $$025$i$i$i$i42 = 0, $$025$i$i$i$i58 = 0, $$025$i$i$i$i74 = 0, $$025$i$i$i$i90 = 0, $$036$i$i$i105 = 0, $$036$i$i$i121 = 0, $$036$i$i$i137 = 0, $$036$i$i$i153 = 0, $$036$i$i$i169 = 0, $$036$i$i$i25 = 0, $$036$i$i$i41 = 0, $$036$i$i$i57 = 0, $$036$i$i$i73 = 0, $$036$i$i$i89 = 0, $$036$i$i$i9 = 0, $$in$i$i$i$i100 = 0, $$in$i$i$i$i116 = 0, $$in$i$i$i$i132 = 0, $$in$i$i$i$i148 = 0, $$in$i$i$i$i164 = 0;
 var $$in$i$i$i$i20 = 0, $$in$i$i$i$i36 = 0, $$in$i$i$i$i4 = 0, $$in$i$i$i$i52 = 0, $$in$i$i$i$i68 = 0, $$in$i$i$i$i84 = 0, $$pre = 0, $$pre$i$i$i$i109 = 0, $$pre$i$i$i$i125 = 0, $$pre$i$i$i$i13 = 0, $$pre$i$i$i$i141 = 0, $$pre$i$i$i$i157 = 0, $$pre$i$i$i$i173 = 0, $$pre$i$i$i$i29 = 0, $$pre$i$i$i$i45 = 0, $$pre$i$i$i$i61 = 0, $$pre$i$i$i$i77 = 0, $$pre$i$i$i$i93 = 0, $$pre437 = 0, $$pre438 = 0;
 var $$pre439 = 0, $$pre440 = 0, $$pre441 = 0, $$pre442 = 0, $$pre443 = 0, $$pre444 = 0, $$pre445 = 0, $$pre446 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0;
 var $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0;
 var $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0;
 var $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0;
 var $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0;
 var $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0;
 var $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0;
 var $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0;
 var $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0;
 var $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = ((($0)) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = ((($0)) + 4|0);
 HEAP32[$0>>2] = $3;
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 do {
  if ($5) {
   __THREW__ = 0;
   $6 = (invoke_ii(3276,20)|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $313 = 0;
    $311 = ___cxa_find_matching_catch_2()|0;
    $312 = tempRet0;
    __ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEE7destroyEPNS_11__tree_nodeIjPvEE($0,$313);
    ___resumeException($311|0);
    // unreachable;
   }
   $9 = ((($6)) + 16|0);
   HEAP32[$9>>2] = 3552;
   HEAP32[$6>>2] = 0;
   $10 = ((($6)) + 4|0);
   HEAP32[$10>>2] = 0;
   $11 = ((($6)) + 8|0);
   HEAP32[$11>>2] = $3;
   HEAP32[$3>>2] = $6;
   $12 = $6;
   HEAP32[$0>>2] = $12;
   __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($6,$6);
   $13 = HEAP32[$2>>2]|0;
   $14 = (($13) + 1)|0;
   HEAP32[$2>>2] = $14;
   $$pre = HEAP32[$3>>2]|0;
   $15 = ($$pre|0)==(0|0);
   if ($15) {
    label = 12;
   } else {
    $$0$i$i$i$i8 = $1;$$024$i$i$i$i7 = $$pre;
    while(1) {
     $16 = ((($$024$i$i$i$i7)) + 16|0);
     $17 = HEAP32[$16>>2]|0;
     $18 = ($17>>>0)>(3553);
     if ($18) {
      $19 = HEAP32[$$024$i$i$i$i7>>2]|0;
      $20 = ($19|0)==(0|0);
      if ($20) {
       label = 7;
       break;
      } else {
       $$0$ph$i$i$i$i5 = $$024$i$i$i$i7;$$in$i$i$i$i4 = $19;
      }
     } else {
      $21 = ($17|0)==(3553);
      if ($21) {
       label = 11;
       break;
      }
      $22 = ((($$024$i$i$i$i7)) + 4|0);
      $23 = HEAP32[$22>>2]|0;
      $24 = ($23|0)==(0|0);
      if ($24) {
       label = 10;
       break;
      } else {
       $$0$ph$i$i$i$i5 = $22;$$in$i$i$i$i4 = $23;
      }
     }
     $$0$i$i$i$i8 = $$0$ph$i$i$i$i5;$$024$i$i$i$i7 = $$in$i$i$i$i4;
    }
    if ((label|0) == 7) {
     $$025$i$i$i$i10 = $$024$i$i$i$i7;$$036$i$i$i9 = $$024$i$i$i$i7;$314 = $$pre;
     break;
    }
    else if ((label|0) == 10) {
     $$025$i$i$i$i10 = $22;$$036$i$i$i9 = $$024$i$i$i$i7;$314 = $$pre;
     break;
    }
    else if ((label|0) == 11) {
     $$025$i$i$i$i10 = $$0$i$i$i$i8;$$036$i$i$i9 = $$024$i$i$i$i7;$314 = $$pre;
     break;
    }
   }
  } else {
   label = 12;
  }
 } while(0);
 if ((label|0) == 12) {
  $$025$i$i$i$i10 = $3;$$036$i$i$i9 = $3;$314 = 0;
 }
 $25 = HEAP32[$$025$i$i$i$i10>>2]|0;
 $26 = ($25|0)==(0|0);
 if ($26) {
  __THREW__ = 0;
  $27 = (invoke_ii(3276,20)|0);
  $28 = __THREW__; __THREW__ = 0;
  $29 = $28&1;
  if ($29) {
   $313 = $314;
   $311 = ___cxa_find_matching_catch_2()|0;
   $312 = tempRet0;
   __ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEE7destroyEPNS_11__tree_nodeIjPvEE($0,$313);
   ___resumeException($311|0);
   // unreachable;
  }
  $30 = ((($27)) + 16|0);
  HEAP32[$30>>2] = 3553;
  HEAP32[$27>>2] = 0;
  $31 = ((($27)) + 4|0);
  HEAP32[$31>>2] = 0;
  $32 = ((($27)) + 8|0);
  HEAP32[$32>>2] = $$036$i$i$i9;
  HEAP32[$$025$i$i$i$i10>>2] = $27;
  $33 = HEAP32[$0>>2]|0;
  $34 = HEAP32[$33>>2]|0;
  $35 = ($34|0)==(0|0);
  if ($35) {
   $38 = $27;
  } else {
   $36 = $34;
   HEAP32[$0>>2] = $36;
   $$pre$i$i$i$i13 = HEAP32[$$025$i$i$i$i10>>2]|0;
   $38 = $$pre$i$i$i$i13;
  }
  $37 = HEAP32[$1>>2]|0;
  __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($37,$38);
  $39 = HEAP32[$2>>2]|0;
  $40 = (($39) + 1)|0;
  HEAP32[$2>>2] = $40;
  $$pre437 = HEAP32[$3>>2]|0;
  $41 = $$pre437;
 } else {
  $41 = $314;
 }
 $42 = ($41|0)==(0|0);
 do {
  if ($42) {
   $$025$i$i$i$i26 = $3;$$036$i$i$i25 = $3;
  } else {
   $$0$i$i$i$i24 = $1;$$024$i$i$i$i23 = $41;
   while(1) {
    $43 = ((($$024$i$i$i$i23)) + 16|0);
    $44 = HEAP32[$43>>2]|0;
    $45 = ($44>>>0)>(32879);
    if ($45) {
     $46 = HEAP32[$$024$i$i$i$i23>>2]|0;
     $47 = ($46|0)==(0|0);
     if ($47) {
      label = 22;
      break;
     } else {
      $$0$ph$i$i$i$i21 = $$024$i$i$i$i23;$$in$i$i$i$i20 = $46;
     }
    } else {
     $48 = ($44|0)==(32879);
     if ($48) {
      label = 26;
      break;
     }
     $49 = ((($$024$i$i$i$i23)) + 4|0);
     $50 = HEAP32[$49>>2]|0;
     $51 = ($50|0)==(0|0);
     if ($51) {
      label = 25;
      break;
     } else {
      $$0$ph$i$i$i$i21 = $49;$$in$i$i$i$i20 = $50;
     }
    }
    $$0$i$i$i$i24 = $$0$ph$i$i$i$i21;$$024$i$i$i$i23 = $$in$i$i$i$i20;
   }
   if ((label|0) == 22) {
    $$025$i$i$i$i26 = $$024$i$i$i$i23;$$036$i$i$i25 = $$024$i$i$i$i23;
    break;
   }
   else if ((label|0) == 25) {
    $$025$i$i$i$i26 = $49;$$036$i$i$i25 = $$024$i$i$i$i23;
    break;
   }
   else if ((label|0) == 26) {
    $$025$i$i$i$i26 = $$0$i$i$i$i24;$$036$i$i$i25 = $$024$i$i$i$i23;
    break;
   }
  }
 } while(0);
 $52 = HEAP32[$$025$i$i$i$i26>>2]|0;
 $53 = ($52|0)==(0|0);
 if ($53) {
  __THREW__ = 0;
  $54 = (invoke_ii(3276,20)|0);
  $55 = __THREW__; __THREW__ = 0;
  $56 = $55&1;
  if ($56) {
   $313 = $41;
   $311 = ___cxa_find_matching_catch_2()|0;
   $312 = tempRet0;
   __ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEE7destroyEPNS_11__tree_nodeIjPvEE($0,$313);
   ___resumeException($311|0);
   // unreachable;
  }
  $57 = ((($54)) + 16|0);
  HEAP32[$57>>2] = 32879;
  HEAP32[$54>>2] = 0;
  $58 = ((($54)) + 4|0);
  HEAP32[$58>>2] = 0;
  $59 = ((($54)) + 8|0);
  HEAP32[$59>>2] = $$036$i$i$i25;
  HEAP32[$$025$i$i$i$i26>>2] = $54;
  $60 = HEAP32[$0>>2]|0;
  $61 = HEAP32[$60>>2]|0;
  $62 = ($61|0)==(0|0);
  if ($62) {
   $65 = $54;
  } else {
   $63 = $61;
   HEAP32[$0>>2] = $63;
   $$pre$i$i$i$i29 = HEAP32[$$025$i$i$i$i26>>2]|0;
   $65 = $$pre$i$i$i$i29;
  }
  $64 = HEAP32[$1>>2]|0;
  __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($64,$65);
  $66 = HEAP32[$2>>2]|0;
  $67 = (($66) + 1)|0;
  HEAP32[$2>>2] = $67;
  $$pre438 = HEAP32[$3>>2]|0;
  $68 = $$pre438;
 } else {
  $68 = $41;
 }
 $69 = ($68|0)==(0|0);
 do {
  if ($69) {
   $$025$i$i$i$i42 = $3;$$036$i$i$i41 = $3;
  } else {
   $$0$i$i$i$i40 = $1;$$024$i$i$i$i39 = $68;
   while(1) {
    $70 = ((($$024$i$i$i$i39)) + 16|0);
    $71 = HEAP32[$70>>2]|0;
    $72 = ($71>>>0)>(35882);
    if ($72) {
     $73 = HEAP32[$$024$i$i$i$i39>>2]|0;
     $74 = ($73|0)==(0|0);
     if ($74) {
      label = 37;
      break;
     } else {
      $$0$ph$i$i$i$i37 = $$024$i$i$i$i39;$$in$i$i$i$i36 = $73;
     }
    } else {
     $75 = ($71|0)==(35882);
     if ($75) {
      label = 41;
      break;
     }
     $76 = ((($$024$i$i$i$i39)) + 4|0);
     $77 = HEAP32[$76>>2]|0;
     $78 = ($77|0)==(0|0);
     if ($78) {
      label = 40;
      break;
     } else {
      $$0$ph$i$i$i$i37 = $76;$$in$i$i$i$i36 = $77;
     }
    }
    $$0$i$i$i$i40 = $$0$ph$i$i$i$i37;$$024$i$i$i$i39 = $$in$i$i$i$i36;
   }
   if ((label|0) == 37) {
    $$025$i$i$i$i42 = $$024$i$i$i$i39;$$036$i$i$i41 = $$024$i$i$i$i39;
    break;
   }
   else if ((label|0) == 40) {
    $$025$i$i$i$i42 = $76;$$036$i$i$i41 = $$024$i$i$i$i39;
    break;
   }
   else if ((label|0) == 41) {
    $$025$i$i$i$i42 = $$0$i$i$i$i40;$$036$i$i$i41 = $$024$i$i$i$i39;
    break;
   }
  }
 } while(0);
 $79 = HEAP32[$$025$i$i$i$i42>>2]|0;
 $80 = ($79|0)==(0|0);
 if ($80) {
  __THREW__ = 0;
  $81 = (invoke_ii(3276,20)|0);
  $82 = __THREW__; __THREW__ = 0;
  $83 = $82&1;
  if ($83) {
   $313 = $68;
   $311 = ___cxa_find_matching_catch_2()|0;
   $312 = tempRet0;
   __ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEE7destroyEPNS_11__tree_nodeIjPvEE($0,$313);
   ___resumeException($311|0);
   // unreachable;
  }
  $84 = ((($81)) + 16|0);
  HEAP32[$84>>2] = 35882;
  HEAP32[$81>>2] = 0;
  $85 = ((($81)) + 4|0);
  HEAP32[$85>>2] = 0;
  $86 = ((($81)) + 8|0);
  HEAP32[$86>>2] = $$036$i$i$i41;
  HEAP32[$$025$i$i$i$i42>>2] = $81;
  $87 = HEAP32[$0>>2]|0;
  $88 = HEAP32[$87>>2]|0;
  $89 = ($88|0)==(0|0);
  if ($89) {
   $92 = $81;
  } else {
   $90 = $88;
   HEAP32[$0>>2] = $90;
   $$pre$i$i$i$i45 = HEAP32[$$025$i$i$i$i42>>2]|0;
   $92 = $$pre$i$i$i$i45;
  }
  $91 = HEAP32[$1>>2]|0;
  __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($91,$92);
  $93 = HEAP32[$2>>2]|0;
  $94 = (($93) + 1)|0;
  HEAP32[$2>>2] = $94;
  $$pre439 = HEAP32[$3>>2]|0;
  $95 = $$pre439;
 } else {
  $95 = $68;
 }
 $96 = ($95|0)==(0|0);
 do {
  if ($96) {
   $$025$i$i$i$i58 = $3;$$036$i$i$i57 = $3;
  } else {
   $$0$i$i$i$i56 = $1;$$024$i$i$i$i55 = $95;
   while(1) {
    $97 = ((($$024$i$i$i$i55)) + 16|0);
    $98 = HEAP32[$97>>2]|0;
    $99 = ($98>>>0)>(34067);
    if ($99) {
     $100 = HEAP32[$$024$i$i$i$i55>>2]|0;
     $101 = ($100|0)==(0|0);
     if ($101) {
      label = 52;
      break;
     } else {
      $$0$ph$i$i$i$i53 = $$024$i$i$i$i55;$$in$i$i$i$i52 = $100;
     }
    } else {
     $102 = ($98|0)==(34067);
     if ($102) {
      label = 56;
      break;
     }
     $103 = ((($$024$i$i$i$i55)) + 4|0);
     $104 = HEAP32[$103>>2]|0;
     $105 = ($104|0)==(0|0);
     if ($105) {
      label = 55;
      break;
     } else {
      $$0$ph$i$i$i$i53 = $103;$$in$i$i$i$i52 = $104;
     }
    }
    $$0$i$i$i$i56 = $$0$ph$i$i$i$i53;$$024$i$i$i$i55 = $$in$i$i$i$i52;
   }
   if ((label|0) == 52) {
    $$025$i$i$i$i58 = $$024$i$i$i$i55;$$036$i$i$i57 = $$024$i$i$i$i55;
    break;
   }
   else if ((label|0) == 55) {
    $$025$i$i$i$i58 = $103;$$036$i$i$i57 = $$024$i$i$i$i55;
    break;
   }
   else if ((label|0) == 56) {
    $$025$i$i$i$i58 = $$0$i$i$i$i56;$$036$i$i$i57 = $$024$i$i$i$i55;
    break;
   }
  }
 } while(0);
 $106 = HEAP32[$$025$i$i$i$i58>>2]|0;
 $107 = ($106|0)==(0|0);
 if ($107) {
  __THREW__ = 0;
  $108 = (invoke_ii(3276,20)|0);
  $109 = __THREW__; __THREW__ = 0;
  $110 = $109&1;
  if ($110) {
   $313 = $95;
   $311 = ___cxa_find_matching_catch_2()|0;
   $312 = tempRet0;
   __ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEE7destroyEPNS_11__tree_nodeIjPvEE($0,$313);
   ___resumeException($311|0);
   // unreachable;
  }
  $111 = ((($108)) + 16|0);
  HEAP32[$111>>2] = 34067;
  HEAP32[$108>>2] = 0;
  $112 = ((($108)) + 4|0);
  HEAP32[$112>>2] = 0;
  $113 = ((($108)) + 8|0);
  HEAP32[$113>>2] = $$036$i$i$i57;
  HEAP32[$$025$i$i$i$i58>>2] = $108;
  $114 = HEAP32[$0>>2]|0;
  $115 = HEAP32[$114>>2]|0;
  $116 = ($115|0)==(0|0);
  if ($116) {
   $119 = $108;
  } else {
   $117 = $115;
   HEAP32[$0>>2] = $117;
   $$pre$i$i$i$i61 = HEAP32[$$025$i$i$i$i58>>2]|0;
   $119 = $$pre$i$i$i$i61;
  }
  $118 = HEAP32[$1>>2]|0;
  __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($118,$119);
  $120 = HEAP32[$2>>2]|0;
  $121 = (($120) + 1)|0;
  HEAP32[$2>>2] = $121;
  $$pre440 = HEAP32[$3>>2]|0;
  $122 = $$pre440;
 } else {
  $122 = $95;
 }
 $123 = ($122|0)==(0|0);
 do {
  if ($123) {
   $$025$i$i$i$i74 = $3;$$036$i$i$i73 = $3;
  } else {
   $$0$i$i$i$i72 = $1;$$024$i$i$i$i71 = $122;
   while(1) {
    $124 = ((($$024$i$i$i$i71)) + 16|0);
    $125 = HEAP32[$124>>2]|0;
    $126 = ($125>>>0)>(34037);
    if ($126) {
     $127 = HEAP32[$$024$i$i$i$i71>>2]|0;
     $128 = ($127|0)==(0|0);
     if ($128) {
      label = 67;
      break;
     } else {
      $$0$ph$i$i$i$i69 = $$024$i$i$i$i71;$$in$i$i$i$i68 = $127;
     }
    } else {
     $129 = ($125|0)==(34037);
     if ($129) {
      label = 71;
      break;
     }
     $130 = ((($$024$i$i$i$i71)) + 4|0);
     $131 = HEAP32[$130>>2]|0;
     $132 = ($131|0)==(0|0);
     if ($132) {
      label = 70;
      break;
     } else {
      $$0$ph$i$i$i$i69 = $130;$$in$i$i$i$i68 = $131;
     }
    }
    $$0$i$i$i$i72 = $$0$ph$i$i$i$i69;$$024$i$i$i$i71 = $$in$i$i$i$i68;
   }
   if ((label|0) == 67) {
    $$025$i$i$i$i74 = $$024$i$i$i$i71;$$036$i$i$i73 = $$024$i$i$i$i71;
    break;
   }
   else if ((label|0) == 70) {
    $$025$i$i$i$i74 = $130;$$036$i$i$i73 = $$024$i$i$i$i71;
    break;
   }
   else if ((label|0) == 71) {
    $$025$i$i$i$i74 = $$0$i$i$i$i72;$$036$i$i$i73 = $$024$i$i$i$i71;
    break;
   }
  }
 } while(0);
 $133 = HEAP32[$$025$i$i$i$i74>>2]|0;
 $134 = ($133|0)==(0|0);
 if ($134) {
  __THREW__ = 0;
  $135 = (invoke_ii(3276,20)|0);
  $136 = __THREW__; __THREW__ = 0;
  $137 = $136&1;
  if ($137) {
   $313 = $122;
   $311 = ___cxa_find_matching_catch_2()|0;
   $312 = tempRet0;
   __ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEE7destroyEPNS_11__tree_nodeIjPvEE($0,$313);
   ___resumeException($311|0);
   // unreachable;
  }
  $138 = ((($135)) + 16|0);
  HEAP32[$138>>2] = 34037;
  HEAP32[$135>>2] = 0;
  $139 = ((($135)) + 4|0);
  HEAP32[$139>>2] = 0;
  $140 = ((($135)) + 8|0);
  HEAP32[$140>>2] = $$036$i$i$i73;
  HEAP32[$$025$i$i$i$i74>>2] = $135;
  $141 = HEAP32[$0>>2]|0;
  $142 = HEAP32[$141>>2]|0;
  $143 = ($142|0)==(0|0);
  if ($143) {
   $146 = $135;
  } else {
   $144 = $142;
   HEAP32[$0>>2] = $144;
   $$pre$i$i$i$i77 = HEAP32[$$025$i$i$i$i74>>2]|0;
   $146 = $$pre$i$i$i$i77;
  }
  $145 = HEAP32[$1>>2]|0;
  __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($145,$146);
  $147 = HEAP32[$2>>2]|0;
  $148 = (($147) + 1)|0;
  HEAP32[$2>>2] = $148;
  $$pre441 = HEAP32[$3>>2]|0;
  $149 = $$pre441;
 } else {
  $149 = $122;
 }
 $150 = ($149|0)==(0|0);
 do {
  if ($150) {
   $$025$i$i$i$i90 = $3;$$036$i$i$i89 = $3;
  } else {
   $$0$i$i$i$i88 = $1;$$024$i$i$i$i87 = $149;
   while(1) {
    $151 = ((($$024$i$i$i$i87)) + 16|0);
    $152 = HEAP32[$151>>2]|0;
    $153 = ($152>>>0)>(35866);
    if ($153) {
     $154 = HEAP32[$$024$i$i$i$i87>>2]|0;
     $155 = ($154|0)==(0|0);
     if ($155) {
      label = 82;
      break;
     } else {
      $$0$ph$i$i$i$i85 = $$024$i$i$i$i87;$$in$i$i$i$i84 = $154;
     }
    } else {
     $156 = ($152|0)==(35866);
     if ($156) {
      label = 86;
      break;
     }
     $157 = ((($$024$i$i$i$i87)) + 4|0);
     $158 = HEAP32[$157>>2]|0;
     $159 = ($158|0)==(0|0);
     if ($159) {
      label = 85;
      break;
     } else {
      $$0$ph$i$i$i$i85 = $157;$$in$i$i$i$i84 = $158;
     }
    }
    $$0$i$i$i$i88 = $$0$ph$i$i$i$i85;$$024$i$i$i$i87 = $$in$i$i$i$i84;
   }
   if ((label|0) == 82) {
    $$025$i$i$i$i90 = $$024$i$i$i$i87;$$036$i$i$i89 = $$024$i$i$i$i87;
    break;
   }
   else if ((label|0) == 85) {
    $$025$i$i$i$i90 = $157;$$036$i$i$i89 = $$024$i$i$i$i87;
    break;
   }
   else if ((label|0) == 86) {
    $$025$i$i$i$i90 = $$0$i$i$i$i88;$$036$i$i$i89 = $$024$i$i$i$i87;
    break;
   }
  }
 } while(0);
 $160 = HEAP32[$$025$i$i$i$i90>>2]|0;
 $161 = ($160|0)==(0|0);
 if ($161) {
  __THREW__ = 0;
  $162 = (invoke_ii(3276,20)|0);
  $163 = __THREW__; __THREW__ = 0;
  $164 = $163&1;
  if ($164) {
   $313 = $149;
   $311 = ___cxa_find_matching_catch_2()|0;
   $312 = tempRet0;
   __ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEE7destroyEPNS_11__tree_nodeIjPvEE($0,$313);
   ___resumeException($311|0);
   // unreachable;
  }
  $165 = ((($162)) + 16|0);
  HEAP32[$165>>2] = 35866;
  HEAP32[$162>>2] = 0;
  $166 = ((($162)) + 4|0);
  HEAP32[$166>>2] = 0;
  $167 = ((($162)) + 8|0);
  HEAP32[$167>>2] = $$036$i$i$i89;
  HEAP32[$$025$i$i$i$i90>>2] = $162;
  $168 = HEAP32[$0>>2]|0;
  $169 = HEAP32[$168>>2]|0;
  $170 = ($169|0)==(0|0);
  if ($170) {
   $173 = $162;
  } else {
   $171 = $169;
   HEAP32[$0>>2] = $171;
   $$pre$i$i$i$i93 = HEAP32[$$025$i$i$i$i90>>2]|0;
   $173 = $$pre$i$i$i$i93;
  }
  $172 = HEAP32[$1>>2]|0;
  __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($172,$173);
  $174 = HEAP32[$2>>2]|0;
  $175 = (($174) + 1)|0;
  HEAP32[$2>>2] = $175;
  $$pre442 = HEAP32[$3>>2]|0;
  $176 = $$pre442;
 } else {
  $176 = $149;
 }
 $177 = ($176|0)==(0|0);
 do {
  if ($177) {
   $$025$i$i$i$i106 = $3;$$036$i$i$i105 = $3;
  } else {
   $$0$i$i$i$i104 = $1;$$024$i$i$i$i103 = $176;
   while(1) {
    $178 = ((($$024$i$i$i$i103)) + 16|0);
    $179 = HEAP32[$178>>2]|0;
    $180 = ($179>>>0)>(37120);
    if ($180) {
     $181 = HEAP32[$$024$i$i$i$i103>>2]|0;
     $182 = ($181|0)==(0|0);
     if ($182) {
      label = 97;
      break;
     } else {
      $$0$ph$i$i$i$i101 = $$024$i$i$i$i103;$$in$i$i$i$i100 = $181;
     }
    } else {
     $183 = ($179|0)==(37120);
     if ($183) {
      label = 101;
      break;
     }
     $184 = ((($$024$i$i$i$i103)) + 4|0);
     $185 = HEAP32[$184>>2]|0;
     $186 = ($185|0)==(0|0);
     if ($186) {
      label = 100;
      break;
     } else {
      $$0$ph$i$i$i$i101 = $184;$$in$i$i$i$i100 = $185;
     }
    }
    $$0$i$i$i$i104 = $$0$ph$i$i$i$i101;$$024$i$i$i$i103 = $$in$i$i$i$i100;
   }
   if ((label|0) == 97) {
    $$025$i$i$i$i106 = $$024$i$i$i$i103;$$036$i$i$i105 = $$024$i$i$i$i103;
    break;
   }
   else if ((label|0) == 100) {
    $$025$i$i$i$i106 = $184;$$036$i$i$i105 = $$024$i$i$i$i103;
    break;
   }
   else if ((label|0) == 101) {
    $$025$i$i$i$i106 = $$0$i$i$i$i104;$$036$i$i$i105 = $$024$i$i$i$i103;
    break;
   }
  }
 } while(0);
 $187 = HEAP32[$$025$i$i$i$i106>>2]|0;
 $188 = ($187|0)==(0|0);
 if ($188) {
  __THREW__ = 0;
  $189 = (invoke_ii(3276,20)|0);
  $190 = __THREW__; __THREW__ = 0;
  $191 = $190&1;
  if ($191) {
   $313 = $176;
   $311 = ___cxa_find_matching_catch_2()|0;
   $312 = tempRet0;
   __ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEE7destroyEPNS_11__tree_nodeIjPvEE($0,$313);
   ___resumeException($311|0);
   // unreachable;
  }
  $192 = ((($189)) + 16|0);
  HEAP32[$192>>2] = 37120;
  HEAP32[$189>>2] = 0;
  $193 = ((($189)) + 4|0);
  HEAP32[$193>>2] = 0;
  $194 = ((($189)) + 8|0);
  HEAP32[$194>>2] = $$036$i$i$i105;
  HEAP32[$$025$i$i$i$i106>>2] = $189;
  $195 = HEAP32[$0>>2]|0;
  $196 = HEAP32[$195>>2]|0;
  $197 = ($196|0)==(0|0);
  if ($197) {
   $200 = $189;
  } else {
   $198 = $196;
   HEAP32[$0>>2] = $198;
   $$pre$i$i$i$i109 = HEAP32[$$025$i$i$i$i106>>2]|0;
   $200 = $$pre$i$i$i$i109;
  }
  $199 = HEAP32[$1>>2]|0;
  __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($199,$200);
  $201 = HEAP32[$2>>2]|0;
  $202 = (($201) + 1)|0;
  HEAP32[$2>>2] = $202;
  $$pre443 = HEAP32[$3>>2]|0;
  $203 = $$pre443;
 } else {
  $203 = $176;
 }
 $204 = ($203|0)==(0|0);
 do {
  if ($204) {
   $$025$i$i$i$i122 = $3;$$036$i$i$i121 = $3;
  } else {
   $$0$i$i$i$i120 = $1;$$024$i$i$i$i119 = $203;
   while(1) {
    $205 = ((($$024$i$i$i$i119)) + 16|0);
    $206 = HEAP32[$205>>2]|0;
    $207 = ($206>>>0)>(3171);
    if ($207) {
     $208 = HEAP32[$$024$i$i$i$i119>>2]|0;
     $209 = ($208|0)==(0|0);
     if ($209) {
      label = 112;
      break;
     } else {
      $$0$ph$i$i$i$i117 = $$024$i$i$i$i119;$$in$i$i$i$i116 = $208;
     }
    } else {
     $210 = ($206|0)==(3171);
     if ($210) {
      label = 116;
      break;
     }
     $211 = ((($$024$i$i$i$i119)) + 4|0);
     $212 = HEAP32[$211>>2]|0;
     $213 = ($212|0)==(0|0);
     if ($213) {
      label = 115;
      break;
     } else {
      $$0$ph$i$i$i$i117 = $211;$$in$i$i$i$i116 = $212;
     }
    }
    $$0$i$i$i$i120 = $$0$ph$i$i$i$i117;$$024$i$i$i$i119 = $$in$i$i$i$i116;
   }
   if ((label|0) == 112) {
    $$025$i$i$i$i122 = $$024$i$i$i$i119;$$036$i$i$i121 = $$024$i$i$i$i119;
    break;
   }
   else if ((label|0) == 115) {
    $$025$i$i$i$i122 = $211;$$036$i$i$i121 = $$024$i$i$i$i119;
    break;
   }
   else if ((label|0) == 116) {
    $$025$i$i$i$i122 = $$0$i$i$i$i120;$$036$i$i$i121 = $$024$i$i$i$i119;
    break;
   }
  }
 } while(0);
 $214 = HEAP32[$$025$i$i$i$i122>>2]|0;
 $215 = ($214|0)==(0|0);
 if ($215) {
  __THREW__ = 0;
  $216 = (invoke_ii(3276,20)|0);
  $217 = __THREW__; __THREW__ = 0;
  $218 = $217&1;
  if ($218) {
   $313 = $203;
   $311 = ___cxa_find_matching_catch_2()|0;
   $312 = tempRet0;
   __ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEE7destroyEPNS_11__tree_nodeIjPvEE($0,$313);
   ___resumeException($311|0);
   // unreachable;
  }
  $219 = ((($216)) + 16|0);
  HEAP32[$219>>2] = 3171;
  HEAP32[$216>>2] = 0;
  $220 = ((($216)) + 4|0);
  HEAP32[$220>>2] = 0;
  $221 = ((($216)) + 8|0);
  HEAP32[$221>>2] = $$036$i$i$i121;
  HEAP32[$$025$i$i$i$i122>>2] = $216;
  $222 = HEAP32[$0>>2]|0;
  $223 = HEAP32[$222>>2]|0;
  $224 = ($223|0)==(0|0);
  if ($224) {
   $227 = $216;
  } else {
   $225 = $223;
   HEAP32[$0>>2] = $225;
   $$pre$i$i$i$i125 = HEAP32[$$025$i$i$i$i122>>2]|0;
   $227 = $$pre$i$i$i$i125;
  }
  $226 = HEAP32[$1>>2]|0;
  __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($226,$227);
  $228 = HEAP32[$2>>2]|0;
  $229 = (($228) + 1)|0;
  HEAP32[$2>>2] = $229;
  $$pre444 = HEAP32[$3>>2]|0;
  $230 = $$pre444;
 } else {
  $230 = $203;
 }
 $231 = ($230|0)==(0|0);
 do {
  if ($231) {
   $$025$i$i$i$i138 = $3;$$036$i$i$i137 = $3;
  } else {
   $$0$i$i$i$i136 = $1;$$024$i$i$i$i135 = $230;
   while(1) {
    $232 = ((($$024$i$i$i$i135)) + 16|0);
    $233 = HEAP32[$232>>2]|0;
    $234 = ($233>>>0)>(3170);
    if ($234) {
     $235 = HEAP32[$$024$i$i$i$i135>>2]|0;
     $236 = ($235|0)==(0|0);
     if ($236) {
      label = 127;
      break;
     } else {
      $$0$ph$i$i$i$i133 = $$024$i$i$i$i135;$$in$i$i$i$i132 = $235;
     }
    } else {
     $237 = ($233|0)==(3170);
     if ($237) {
      label = 131;
      break;
     }
     $238 = ((($$024$i$i$i$i135)) + 4|0);
     $239 = HEAP32[$238>>2]|0;
     $240 = ($239|0)==(0|0);
     if ($240) {
      label = 130;
      break;
     } else {
      $$0$ph$i$i$i$i133 = $238;$$in$i$i$i$i132 = $239;
     }
    }
    $$0$i$i$i$i136 = $$0$ph$i$i$i$i133;$$024$i$i$i$i135 = $$in$i$i$i$i132;
   }
   if ((label|0) == 127) {
    $$025$i$i$i$i138 = $$024$i$i$i$i135;$$036$i$i$i137 = $$024$i$i$i$i135;
    break;
   }
   else if ((label|0) == 130) {
    $$025$i$i$i$i138 = $238;$$036$i$i$i137 = $$024$i$i$i$i135;
    break;
   }
   else if ((label|0) == 131) {
    $$025$i$i$i$i138 = $$0$i$i$i$i136;$$036$i$i$i137 = $$024$i$i$i$i135;
    break;
   }
  }
 } while(0);
 $241 = HEAP32[$$025$i$i$i$i138>>2]|0;
 $242 = ($241|0)==(0|0);
 if ($242) {
  __THREW__ = 0;
  $243 = (invoke_ii(3276,20)|0);
  $244 = __THREW__; __THREW__ = 0;
  $245 = $244&1;
  if ($245) {
   $313 = $230;
   $311 = ___cxa_find_matching_catch_2()|0;
   $312 = tempRet0;
   __ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEE7destroyEPNS_11__tree_nodeIjPvEE($0,$313);
   ___resumeException($311|0);
   // unreachable;
  }
  $246 = ((($243)) + 16|0);
  HEAP32[$246>>2] = 3170;
  HEAP32[$243>>2] = 0;
  $247 = ((($243)) + 4|0);
  HEAP32[$247>>2] = 0;
  $248 = ((($243)) + 8|0);
  HEAP32[$248>>2] = $$036$i$i$i137;
  HEAP32[$$025$i$i$i$i138>>2] = $243;
  $249 = HEAP32[$0>>2]|0;
  $250 = HEAP32[$249>>2]|0;
  $251 = ($250|0)==(0|0);
  if ($251) {
   $254 = $243;
  } else {
   $252 = $250;
   HEAP32[$0>>2] = $252;
   $$pre$i$i$i$i141 = HEAP32[$$025$i$i$i$i138>>2]|0;
   $254 = $$pre$i$i$i$i141;
  }
  $253 = HEAP32[$1>>2]|0;
  __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($253,$254);
  $255 = HEAP32[$2>>2]|0;
  $256 = (($255) + 1)|0;
  HEAP32[$2>>2] = $256;
  $$pre445 = HEAP32[$3>>2]|0;
  $257 = $$pre445;
 } else {
  $257 = $230;
 }
 $258 = ($257|0)==(0|0);
 do {
  if ($258) {
   $$025$i$i$i$i154 = $3;$$036$i$i$i153 = $3;
  } else {
   $$0$i$i$i$i152 = $1;$$024$i$i$i$i151 = $257;
   while(1) {
    $259 = ((($$024$i$i$i$i151)) + 16|0);
    $260 = HEAP32[$259>>2]|0;
    $261 = ($260>>>0)>(3168);
    if ($261) {
     $262 = HEAP32[$$024$i$i$i$i151>>2]|0;
     $263 = ($262|0)==(0|0);
     if ($263) {
      label = 142;
      break;
     } else {
      $$0$ph$i$i$i$i149 = $$024$i$i$i$i151;$$in$i$i$i$i148 = $262;
     }
    } else {
     $264 = ($260|0)==(3168);
     if ($264) {
      label = 146;
      break;
     }
     $265 = ((($$024$i$i$i$i151)) + 4|0);
     $266 = HEAP32[$265>>2]|0;
     $267 = ($266|0)==(0|0);
     if ($267) {
      label = 145;
      break;
     } else {
      $$0$ph$i$i$i$i149 = $265;$$in$i$i$i$i148 = $266;
     }
    }
    $$0$i$i$i$i152 = $$0$ph$i$i$i$i149;$$024$i$i$i$i151 = $$in$i$i$i$i148;
   }
   if ((label|0) == 142) {
    $$025$i$i$i$i154 = $$024$i$i$i$i151;$$036$i$i$i153 = $$024$i$i$i$i151;
    break;
   }
   else if ((label|0) == 145) {
    $$025$i$i$i$i154 = $265;$$036$i$i$i153 = $$024$i$i$i$i151;
    break;
   }
   else if ((label|0) == 146) {
    $$025$i$i$i$i154 = $$0$i$i$i$i152;$$036$i$i$i153 = $$024$i$i$i$i151;
    break;
   }
  }
 } while(0);
 $268 = HEAP32[$$025$i$i$i$i154>>2]|0;
 $269 = ($268|0)==(0|0);
 if ($269) {
  __THREW__ = 0;
  $270 = (invoke_ii(3276,20)|0);
  $271 = __THREW__; __THREW__ = 0;
  $272 = $271&1;
  if ($272) {
   $313 = $257;
   $311 = ___cxa_find_matching_catch_2()|0;
   $312 = tempRet0;
   __ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEE7destroyEPNS_11__tree_nodeIjPvEE($0,$313);
   ___resumeException($311|0);
   // unreachable;
  }
  $273 = ((($270)) + 16|0);
  HEAP32[$273>>2] = 3168;
  HEAP32[$270>>2] = 0;
  $274 = ((($270)) + 4|0);
  HEAP32[$274>>2] = 0;
  $275 = ((($270)) + 8|0);
  HEAP32[$275>>2] = $$036$i$i$i153;
  HEAP32[$$025$i$i$i$i154>>2] = $270;
  $276 = HEAP32[$0>>2]|0;
  $277 = HEAP32[$276>>2]|0;
  $278 = ($277|0)==(0|0);
  if ($278) {
   $281 = $270;
  } else {
   $279 = $277;
   HEAP32[$0>>2] = $279;
   $$pre$i$i$i$i157 = HEAP32[$$025$i$i$i$i154>>2]|0;
   $281 = $$pre$i$i$i$i157;
  }
  $280 = HEAP32[$1>>2]|0;
  __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($280,$281);
  $282 = HEAP32[$2>>2]|0;
  $283 = (($282) + 1)|0;
  HEAP32[$2>>2] = $283;
  $$pre446 = HEAP32[$3>>2]|0;
  $284 = $$pre446;
 } else {
  $284 = $257;
 }
 $285 = ($284|0)==(0|0);
 do {
  if ($285) {
   $$025$i$i$i$i170 = $3;$$036$i$i$i169 = $3;
  } else {
   $$0$i$i$i$i168 = $1;$$024$i$i$i$i167 = $284;
   while(1) {
    $286 = ((($$024$i$i$i$i167)) + 16|0);
    $287 = HEAP32[$286>>2]|0;
    $288 = ($287>>>0)>(3169);
    if ($288) {
     $289 = HEAP32[$$024$i$i$i$i167>>2]|0;
     $290 = ($289|0)==(0|0);
     if ($290) {
      label = 157;
      break;
     } else {
      $$0$ph$i$i$i$i165 = $$024$i$i$i$i167;$$in$i$i$i$i164 = $289;
     }
    } else {
     $291 = ($287|0)==(3169);
     if ($291) {
      label = 161;
      break;
     }
     $292 = ((($$024$i$i$i$i167)) + 4|0);
     $293 = HEAP32[$292>>2]|0;
     $294 = ($293|0)==(0|0);
     if ($294) {
      label = 160;
      break;
     } else {
      $$0$ph$i$i$i$i165 = $292;$$in$i$i$i$i164 = $293;
     }
    }
    $$0$i$i$i$i168 = $$0$ph$i$i$i$i165;$$024$i$i$i$i167 = $$in$i$i$i$i164;
   }
   if ((label|0) == 157) {
    $$025$i$i$i$i170 = $$024$i$i$i$i167;$$036$i$i$i169 = $$024$i$i$i$i167;
    break;
   }
   else if ((label|0) == 160) {
    $$025$i$i$i$i170 = $292;$$036$i$i$i169 = $$024$i$i$i$i167;
    break;
   }
   else if ((label|0) == 161) {
    $$025$i$i$i$i170 = $$0$i$i$i$i168;$$036$i$i$i169 = $$024$i$i$i$i167;
    break;
   }
  }
 } while(0);
 $295 = HEAP32[$$025$i$i$i$i170>>2]|0;
 $296 = ($295|0)==(0|0);
 if (!($296)) {
  return;
 }
 __THREW__ = 0;
 $297 = (invoke_ii(3276,20)|0);
 $298 = __THREW__; __THREW__ = 0;
 $299 = $298&1;
 if ($299) {
  $313 = $284;
  $311 = ___cxa_find_matching_catch_2()|0;
  $312 = tempRet0;
  __ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEE7destroyEPNS_11__tree_nodeIjPvEE($0,$313);
  ___resumeException($311|0);
  // unreachable;
 }
 $300 = ((($297)) + 16|0);
 HEAP32[$300>>2] = 3169;
 HEAP32[$297>>2] = 0;
 $301 = ((($297)) + 4|0);
 HEAP32[$301>>2] = 0;
 $302 = ((($297)) + 8|0);
 HEAP32[$302>>2] = $$036$i$i$i169;
 HEAP32[$$025$i$i$i$i170>>2] = $297;
 $303 = HEAP32[$0>>2]|0;
 $304 = HEAP32[$303>>2]|0;
 $305 = ($304|0)==(0|0);
 if ($305) {
  $308 = $297;
 } else {
  $306 = $304;
  HEAP32[$0>>2] = $306;
  $$pre$i$i$i$i173 = HEAP32[$$025$i$i$i$i170>>2]|0;
  $308 = $$pre$i$i$i$i173;
 }
 $307 = HEAP32[$1>>2]|0;
 __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($307,$308);
 $309 = HEAP32[$2>>2]|0;
 $310 = (($309) + 1)|0;
 HEAP32[$2>>2] = $310;
 return;
}
function __ZN16TextureGLModeSetD2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 __ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEE7destroyEPNS_11__tree_nodeIjPvEE($0,$2);
 return;
}
function __ZN3osg8StateSet9addParentEPNS_4NodeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 HEAP32[$2>>2] = $1;
 $3 = (__ZN3osg10Referenced24getGlobalReferencedMutexEv()|0);
 $4 = ($3|0)==(0|0);
 $5 = $1;
 if (!($4)) {
  $6 = HEAP32[$3>>2]|0;
  $7 = ((($6)) + 8|0);
  $8 = HEAP32[$7>>2]|0;
  (FUNCTION_TABLE_ii[$8 & 8191]($3)|0);
 }
 $9 = ((($0)) + 36|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ((($0)) + 40|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($10|0)==($12|0);
 if ($13) {
  $16 = ((($0)) + 32|0);
  __THREW__ = 0;
  invoke_vii(3952,($16|0),($2|0));
  $17 = __THREW__; __THREW__ = 0;
  $18 = $17&1;
  if ($18) {
   $22 = ___cxa_find_matching_catch_2()|0;
   $23 = tempRet0;
   if ($4) {
    ___resumeException($22|0);
    // unreachable;
   }
   $24 = HEAP32[$3>>2]|0;
   $25 = ((($24)) + 12|0);
   $26 = HEAP32[$25>>2]|0;
   __THREW__ = 0;
   (invoke_ii($26|0,($3|0))|0);
   $27 = __THREW__; __THREW__ = 0;
   $28 = $27&1;
   if ($28) {
    $29 = ___cxa_find_matching_catch_3(0|0)|0;
    $30 = tempRet0;
    ___clang_call_terminate($29);
    // unreachable;
   } else {
    ___resumeException($22|0);
    // unreachable;
   }
  }
 } else {
  HEAP32[$10>>2] = $5;
  $14 = HEAP32[$9>>2]|0;
  $15 = ((($14)) + 4|0);
  HEAP32[$9>>2] = $15;
 }
 if ($4) {
  STACKTOP = sp;return;
 }
 $19 = HEAP32[$3>>2]|0;
 $20 = ((($19)) + 12|0);
 $21 = HEAP32[$20>>2]|0;
 (FUNCTION_TABLE_ii[$21 & 8191]($3)|0);
 STACKTOP = sp;return;
}
function __ZN3osg8StateSet12removeParentEPNS_4NodeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$pre$i = 0, $$sroa$0$0$copyload$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i = 0, $scevgep5$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__ZN3osg10Referenced24getGlobalReferencedMutexEv()|0);
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = HEAP32[$2>>2]|0;
  $5 = ((($4)) + 8|0);
  $6 = HEAP32[$5>>2]|0;
  (FUNCTION_TABLE_ii[$6 & 8191]($2)|0);
 }
 $7 = ((($0)) + 32|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($0)) + 36|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8|0)==($10|0);
 $12 = $10;
 L4: do {
  if ($11) {
   $$sroa$0$0$copyload$i = $8;
   label = 6;
  } else {
   $14 = $8;
   while(1) {
    $13 = HEAP32[$14>>2]|0;
    $15 = ($13|0)==($1|0);
    if ($15) {
     $$sroa$0$0$copyload$i = $14;
     label = 6;
     break L4;
    }
    $16 = ((($14)) + 4|0);
    $17 = ($16|0)==($10|0);
    if ($17) {
     break;
    } else {
     $14 = $16;
    }
   }
  }
 } while(0);
 if ((label|0) == 6) {
  $18 = ($$sroa$0$0$copyload$i|0)==($10|0);
  if (!($18)) {
   $19 = ((($$sroa$0$0$copyload$i)) + 4|0);
   $20 = $19;
   $21 = (($12) - ($20))|0;
   $22 = $21 >> 2;
   $23 = ($22|0)==(0);
   if ($23) {
    $25 = $10;
   } else {
    _memmove(($$sroa$0$0$copyload$i|0),($19|0),($21|0))|0;
    $$pre$i = HEAP32[$9>>2]|0;
    $25 = $$pre$i;
   }
   $24 = (($$sroa$0$0$copyload$i) + ($22<<2)|0);
   $26 = ($25|0)==($24|0);
   if (!($26)) {
    $scevgep$i$i$i = ((($25)) + -4|0);
    $27 = $scevgep$i$i$i;
    $28 = $24;
    $29 = (($27) - ($28))|0;
    $30 = $29 >>> 2;
    $31 = $30 ^ -1;
    $scevgep5$i$i$i = (($25) + ($31<<2)|0);
    HEAP32[$9>>2] = $scevgep5$i$i$i;
   }
  }
 }
 if ($3) {
  return;
 }
 $32 = HEAP32[$2>>2]|0;
 $33 = ((($32)) + 12|0);
 $34 = HEAP32[$33>>2]|0;
 (FUNCTION_TABLE_ii[$34 & 8191]($2)|0);
 return;
}
function __ZN3osg8StateSet17setGlobalDefaultsEv($0) {
 $0 = $0|0;
 var $$0 = 0, $$015 = 0, $$017 = 0, $$019 = 0, $$02179 = 0, $$02378 = 0, $$12281 = 0, $$12480 = 0, $$2 = 0, $$225 = 0, $$32682 = 0, $$383 = 0, $$42784 = 0, $$485 = 0, $$5 = 0, $$528 = 0, $$7 = 0, $$730 = 0, $$off = 0, $$off31 = 0;
 var $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0;
 var $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0;
 var $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0;
 var $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0;
 var $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0;
 var $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0;
 var $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0;
 var $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0;
 var $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(64|0);
 $1 = sp + 56|0;
 $2 = sp + 52|0;
 $3 = sp + 48|0;
 $4 = sp + 36|0;
 $5 = sp + 24|0;
 $6 = sp + 12|0;
 $7 = sp;
 $8 = ((($0)) + 116|0);
 HEAP32[$8>>2] = 0;
 $9 = ((($0)) + 120|0);
 HEAP32[$9>>2] = 0;
 $10 = ((($0)) + 124|0);
 HEAP32[$10>>2] = 0;
 $11 = ((($0)) + 128|0);
 (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($11,221531)|0);
 __ZN3osg8StateSet7setModeEjj($0,2929,1);
 $12 = (__Znwj(72)|0);
 __THREW__ = 0;
 invoke_vi(3953,($12|0));
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 if ($14) {
  $37 = ___cxa_find_matching_catch_2()|0;
  $38 = tempRet0;
  __ZdlPv($12);
  $$7 = $37;$$730 = $38;
  ___resumeException($$7|0);
  // unreachable;
 }
 __ZN3osg8StateSet20setAttributeAndModesEPNS_14StateAttributeEj($0,$12,0);
 $15 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
 do {
  if ($15) {
   $16 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
   $17 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($16,150516,34)|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = ((($18)) + -12|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($17) + ($20)|0);
   __ZNKSt3__28ios_base6getlocEv($3,$21);
   __THREW__ = 0;
   $22 = (invoke_iii(3255,($3|0),(215188|0))|0);
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if (!($24)) {
    $25 = HEAP32[$22>>2]|0;
    $26 = ((($25)) + 28|0);
    $27 = HEAP32[$26>>2]|0;
    __THREW__ = 0;
    $28 = (invoke_iii($27|0,($22|0),10)|0);
    $29 = __THREW__; __THREW__ = 0;
    $30 = $29&1;
    if (!($30)) {
     __ZNSt3__26localeD2Ev($3);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($17,$28)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($17)|0);
     break;
    }
   }
   $31 = ___cxa_find_matching_catch_2()|0;
   $32 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($3|0));
   $33 = __THREW__; __THREW__ = 0;
   $34 = $33&1;
   if ($34) {
    $35 = ___cxa_find_matching_catch_3(0|0)|0;
    $36 = tempRet0;
    ___clang_call_terminate($35);
    // unreachable;
   } else {
    ___resumeException($31|0);
    // unreachable;
   }
  }
 } while(0);
 $39 = (__ZN3osg15DisplaySettings8instanceEv()|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ((($40)) + 164|0);
 $42 = HEAP32[$41>>2]|0;
 $$off = (($42) + -3)|0;
 $43 = ($$off>>>0)<(2);
 if ($43) {
  $44 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
  do {
   if ($44) {
    $45 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
    $46 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($45,150551,66)|0);
    $47 = HEAP32[$46>>2]|0;
    $48 = ((($47)) + -12|0);
    $49 = HEAP32[$48>>2]|0;
    $50 = (($46) + ($49)|0);
    __ZNKSt3__28ios_base6getlocEv($2,$50);
    __THREW__ = 0;
    $51 = (invoke_iii(3255,($2|0),(215188|0))|0);
    $52 = __THREW__; __THREW__ = 0;
    $53 = $52&1;
    if (!($53)) {
     $54 = HEAP32[$51>>2]|0;
     $55 = ((($54)) + 28|0);
     $56 = HEAP32[$55>>2]|0;
     __THREW__ = 0;
     $57 = (invoke_iii($56|0,($51|0),10)|0);
     $58 = __THREW__; __THREW__ = 0;
     $59 = $58&1;
     if (!($59)) {
      __ZNSt3__26localeD2Ev($2);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($46,$57)|0);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($46)|0);
      break;
     }
    }
    $60 = ___cxa_find_matching_catch_2()|0;
    $61 = tempRet0;
    __THREW__ = 0;
    invoke_vi(3263,($2|0));
    $62 = __THREW__; __THREW__ = 0;
    $63 = $62&1;
    if ($63) {
     $64 = ___cxa_find_matching_catch_3(0|0)|0;
     $65 = tempRet0;
     ___clang_call_terminate($64);
     // unreachable;
    } else {
     ___resumeException($60|0);
     // unreachable;
    }
   }
  } while(0);
  $66 = (__Znwj(172)|0);
  __THREW__ = 0;
  invoke_vi(3613,($66|0));
  $67 = __THREW__; __THREW__ = 0;
  $68 = $67&1;
  if ($68) {
   $121 = ___cxa_find_matching_catch_2()|0;
   $122 = tempRet0;
   __ZdlPv($66);
   $$7 = $121;$$730 = $122;
   ___resumeException($$7|0);
   // unreachable;
  }
  $69 = ((($66)) + 8|0);
  $70 = HEAP32[$69>>2]|0;HEAP32[$69>>2] = (($70+1)|0);
  __THREW__ = 0;
  $71 = (invoke_ii(3276,128)|0);
  $72 = __THREW__; __THREW__ = 0;
  $73 = $72&1;
  L31: do {
   if ($73) {
    label = 40;
   } else {
    ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;
    __THREW__ = 0;
    $74 = (invoke_ii(3276,400)|0);
    $75 = __THREW__; __THREW__ = 0;
    $76 = $75&1;
    do {
     if ($76) {
      $125 = ___cxa_find_matching_catch_2()|0;
      $126 = tempRet0;
      $$02179 = $125;$$02378 = $126;
     } else {
      HEAP32[$4>>2] = $74;
      $77 = ((($4)) + 8|0);
      HEAP32[$77>>2] = -2147483248;
      $78 = ((($4)) + 4|0);
      HEAP32[$78>>2] = 385;
      _memcpy(($74|0),(150618|0),385)|0;
      $79 = ((($74)) + 385|0);
      HEAP8[$79>>0] = 0;
      __THREW__ = 0;
      invoke_viii(3619,($71|0),35633,($4|0));
      $80 = __THREW__; __THREW__ = 0;
      $81 = $80&1;
      if ($81) {
       $$019 = 1;
      } else {
       __THREW__ = 0;
       (invoke_iii(3620,($66|0),($71|0))|0);
       $82 = __THREW__; __THREW__ = 0;
       $83 = $82&1;
       if ($83) {
        $$019 = 0;
       } else {
        $84 = ((($4)) + 11|0);
        $85 = HEAP8[$84>>0]|0;
        $86 = ($85<<24>>24)<(0);
        if ($86) {
         $87 = HEAP32[$4>>2]|0;
         __ZdlPv($87);
        }
        __THREW__ = 0;
        $88 = (invoke_ii(3276,128)|0);
        $89 = __THREW__; __THREW__ = 0;
        $90 = $89&1;
        if ($90) {
         label = 40;
         break L31;
        }
        ;HEAP32[$5>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;
        __THREW__ = 0;
        $91 = (invoke_ii(3276,256)|0);
        $92 = __THREW__; __THREW__ = 0;
        $93 = $92&1;
        do {
         if ($93) {
          $133 = ___cxa_find_matching_catch_2()|0;
          $134 = tempRet0;
          $$12281 = $133;$$12480 = $134;
         } else {
          HEAP32[$5>>2] = $91;
          $94 = ((($5)) + 8|0);
          HEAP32[$94>>2] = -2147483392;
          $95 = ((($5)) + 4|0);
          HEAP32[$95>>2] = 249;
          _memcpy(($91|0),(151004|0),249)|0;
          $96 = ((($91)) + 249|0);
          HEAP8[$96>>0] = 0;
          __THREW__ = 0;
          invoke_viii(3619,($88|0),35632,($5|0));
          $97 = __THREW__; __THREW__ = 0;
          $98 = $97&1;
          if ($98) {
           $$017 = 1;
          } else {
           __THREW__ = 0;
           (invoke_iii(3620,($66|0),($88|0))|0);
           $99 = __THREW__; __THREW__ = 0;
           $100 = $99&1;
           if ($100) {
            $$017 = 0;
           } else {
            $101 = ((($5)) + 11|0);
            $102 = HEAP8[$101>>0]|0;
            $103 = ($102<<24>>24)<(0);
            if ($103) {
             $104 = HEAP32[$5>>2]|0;
             __ZdlPv($104);
            }
            __THREW__ = 0;
            invoke_viii(3363,($0|0),($66|0),1);
            $105 = __THREW__; __THREW__ = 0;
            $106 = $105&1;
            if ($106) {
             label = 40;
             break L31;
            }
            __THREW__ = 0;
            $107 = (invoke_i(3954)|0);
            $108 = __THREW__; __THREW__ = 0;
            $109 = $108&1;
            if ($109) {
             label = 40;
             break L31;
            }
            __THREW__ = 0;
            invoke_viiii(3955,($0|0),0,($107|0),0);
            $110 = __THREW__; __THREW__ = 0;
            $111 = $110&1;
            if ($111) {
             label = 40;
             break L31;
            }
            __THREW__ = 0;
            $112 = (invoke_ii(3276,92)|0);
            $113 = __THREW__; __THREW__ = 0;
            $114 = $113&1;
            if ($114) {
             label = 40;
             break L31;
            }
            __THREW__ = 0;
            invoke_viii(3616,($112|0),(151254|0),0);
            $115 = __THREW__; __THREW__ = 0;
            $116 = $115&1;
            if ($116) {
             $141 = ___cxa_find_matching_catch_2()|0;
             $142 = tempRet0;
             __ZdlPv($112);
             $$2 = $141;$$225 = $142;
             break L31;
            }
            __THREW__ = 0;
            invoke_viii(3617,($0|0),($112|0),1);
            $117 = __THREW__; __THREW__ = 0;
            $118 = $117&1;
            if ($118) {
             label = 40;
             break L31;
            }
            $119 = HEAP32[$69>>2]|0;HEAP32[$69>>2] = (($119-1)|0);
            $120 = ($119|0)==(1);
            if (!($120)) {
             STACKTOP = sp;return;
            }
            __ZNK3osg10Referenced24signalObserversAndDeleteEbb($66,1,1);
            STACKTOP = sp;return;
           }
          }
          $135 = ___cxa_find_matching_catch_2()|0;
          $136 = tempRet0;
          $137 = ((($5)) + 11|0);
          $138 = HEAP8[$137>>0]|0;
          $139 = ($138<<24>>24)<(0);
          if ($139) {
           $140 = HEAP32[$5>>2]|0;
           __ZdlPv($140);
           if ($$017) {
            $$12281 = $135;$$12480 = $136;
            break;
           } else {
            $$2 = $135;$$225 = $136;
            break L31;
           }
          } else {
           if ($$017) {
            $$12281 = $135;$$12480 = $136;
            break;
           } else {
            $$2 = $135;$$225 = $136;
            break L31;
           }
          }
         }
        } while(0);
        __ZdlPv($88);
        $$2 = $$12281;$$225 = $$12480;
        break L31;
       }
      }
      $127 = ___cxa_find_matching_catch_2()|0;
      $128 = tempRet0;
      $129 = ((($4)) + 11|0);
      $130 = HEAP8[$129>>0]|0;
      $131 = ($130<<24>>24)<(0);
      if ($131) {
       $132 = HEAP32[$4>>2]|0;
       __ZdlPv($132);
       if ($$019) {
        $$02179 = $127;$$02378 = $128;
        break;
       } else {
        $$2 = $127;$$225 = $128;
        break L31;
       }
      } else {
       if ($$019) {
        $$02179 = $127;$$02378 = $128;
        break;
       } else {
        $$2 = $127;$$225 = $128;
        break L31;
       }
      }
     }
    } while(0);
    __ZdlPv($71);
    $$2 = $$02179;$$225 = $$02378;
   }
  } while(0);
  if ((label|0) == 40) {
   $123 = ___cxa_find_matching_catch_2()|0;
   $124 = tempRet0;
   $$2 = $123;$$225 = $124;
  }
  $143 = HEAP32[$69>>2]|0;HEAP32[$69>>2] = (($143-1)|0);
  $144 = ($143|0)==(1);
  if (!($144)) {
   $$7 = $$2;$$730 = $$225;
   ___resumeException($$7|0);
   // unreachable;
  }
  __THREW__ = 0;
  invoke_viii(3262,($66|0),1,1);
  $145 = __THREW__; __THREW__ = 0;
  $146 = $145&1;
  if ($146) {
   $251 = ___cxa_find_matching_catch_3(0|0)|0;
   $252 = tempRet0;
   ___clang_call_terminate($251);
   // unreachable;
  } else {
   $$7 = $$2;$$730 = $$225;
   ___resumeException($$7|0);
   // unreachable;
  }
 }
 $$off31 = (($42) + -1)|0;
 $147 = ($$off31>>>0)<(2);
 if (!($147)) {
  STACKTOP = sp;return;
 }
 $148 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
 do {
  if ($148) {
   $149 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
   $150 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($149,151266,66)|0);
   $151 = HEAP32[$150>>2]|0;
   $152 = ((($151)) + -12|0);
   $153 = HEAP32[$152>>2]|0;
   $154 = (($150) + ($153)|0);
   __ZNKSt3__28ios_base6getlocEv($1,$154);
   __THREW__ = 0;
   $155 = (invoke_iii(3255,($1|0),(215188|0))|0);
   $156 = __THREW__; __THREW__ = 0;
   $157 = $156&1;
   if (!($157)) {
    $158 = HEAP32[$155>>2]|0;
    $159 = ((($158)) + 28|0);
    $160 = HEAP32[$159>>2]|0;
    __THREW__ = 0;
    $161 = (invoke_iii($160|0,($155|0),10)|0);
    $162 = __THREW__; __THREW__ = 0;
    $163 = $162&1;
    if (!($163)) {
     __ZNSt3__26localeD2Ev($1);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($150,$161)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($150)|0);
     break;
    }
   }
   $164 = ___cxa_find_matching_catch_2()|0;
   $165 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($1|0));
   $166 = __THREW__; __THREW__ = 0;
   $167 = $166&1;
   if ($167) {
    $168 = ___cxa_find_matching_catch_3(0|0)|0;
    $169 = tempRet0;
    ___clang_call_terminate($168);
    // unreachable;
   } else {
    ___resumeException($164|0);
    // unreachable;
   }
  }
 } while(0);
 $170 = (__Znwj(172)|0);
 __THREW__ = 0;
 invoke_vi(3613,($170|0));
 $171 = __THREW__; __THREW__ = 0;
 $172 = $171&1;
 if ($172) {
  $225 = ___cxa_find_matching_catch_2()|0;
  $226 = tempRet0;
  __ZdlPv($170);
  $$7 = $225;$$730 = $226;
  ___resumeException($$7|0);
  // unreachable;
 }
 $173 = ((($170)) + 8|0);
 $174 = HEAP32[$173>>2]|0;HEAP32[$173>>2] = (($174+1)|0);
 __THREW__ = 0;
 $175 = (invoke_ii(3276,128)|0);
 $176 = __THREW__; __THREW__ = 0;
 $177 = $176&1;
 L101: do {
  if ($177) {
   label = 84;
  } else {
   ;HEAP32[$6>>2]=0|0;HEAP32[$6+4>>2]=0|0;HEAP32[$6+8>>2]=0|0;
   __THREW__ = 0;
   $178 = (invoke_ii(3276,272)|0);
   $179 = __THREW__; __THREW__ = 0;
   $180 = $179&1;
   do {
    if ($180) {
     $229 = ___cxa_find_matching_catch_2()|0;
     $230 = tempRet0;
     $$32682 = $230;$$383 = $229;
    } else {
     HEAP32[$6>>2] = $178;
     $181 = ((($6)) + 8|0);
     HEAP32[$181>>2] = -2147483376;
     $182 = ((($6)) + 4|0);
     HEAP32[$182>>2] = 262;
     _memcpy(($178|0),(151333|0),262)|0;
     $183 = ((($178)) + 262|0);
     HEAP8[$183>>0] = 0;
     __THREW__ = 0;
     invoke_viii(3619,($175|0),35633,($6|0));
     $184 = __THREW__; __THREW__ = 0;
     $185 = $184&1;
     if ($185) {
      $$015 = 1;
     } else {
      __THREW__ = 0;
      (invoke_iii(3620,($170|0),($175|0))|0);
      $186 = __THREW__; __THREW__ = 0;
      $187 = $186&1;
      if ($187) {
       $$015 = 0;
      } else {
       $188 = ((($6)) + 11|0);
       $189 = HEAP8[$188>>0]|0;
       $190 = ($189<<24>>24)<(0);
       if ($190) {
        $191 = HEAP32[$6>>2]|0;
        __ZdlPv($191);
       }
       __THREW__ = 0;
       $192 = (invoke_ii(3276,128)|0);
       $193 = __THREW__; __THREW__ = 0;
       $194 = $193&1;
       if ($194) {
        label = 84;
        break L101;
       }
       ;HEAP32[$7>>2]=0|0;HEAP32[$7+4>>2]=0|0;HEAP32[$7+8>>2]=0|0;
       __THREW__ = 0;
       $195 = (invoke_ii(3276,240)|0);
       $196 = __THREW__; __THREW__ = 0;
       $197 = $196&1;
       do {
        if ($197) {
         $237 = ___cxa_find_matching_catch_2()|0;
         $238 = tempRet0;
         $$42784 = $238;$$485 = $237;
        } else {
         HEAP32[$7>>2] = $195;
         $198 = ((($7)) + 8|0);
         HEAP32[$198>>2] = -2147483408;
         $199 = ((($7)) + 4|0);
         HEAP32[$199>>2] = 236;
         _memcpy(($195|0),(151596|0),236)|0;
         $200 = ((($195)) + 236|0);
         HEAP8[$200>>0] = 0;
         __THREW__ = 0;
         invoke_viii(3619,($192|0),35632,($7|0));
         $201 = __THREW__; __THREW__ = 0;
         $202 = $201&1;
         if ($202) {
          $$0 = 1;
         } else {
          __THREW__ = 0;
          (invoke_iii(3620,($170|0),($192|0))|0);
          $203 = __THREW__; __THREW__ = 0;
          $204 = $203&1;
          if ($204) {
           $$0 = 0;
          } else {
           $205 = ((($7)) + 11|0);
           $206 = HEAP8[$205>>0]|0;
           $207 = ($206<<24>>24)<(0);
           if ($207) {
            $208 = HEAP32[$7>>2]|0;
            __ZdlPv($208);
           }
           __THREW__ = 0;
           invoke_viii(3363,($0|0),($170|0),1);
           $209 = __THREW__; __THREW__ = 0;
           $210 = $209&1;
           if ($210) {
            label = 84;
            break L101;
           }
           __THREW__ = 0;
           $211 = (invoke_i(3954)|0);
           $212 = __THREW__; __THREW__ = 0;
           $213 = $212&1;
           if ($213) {
            label = 84;
            break L101;
           }
           __THREW__ = 0;
           invoke_viiii(3955,($0|0),0,($211|0),0);
           $214 = __THREW__; __THREW__ = 0;
           $215 = $214&1;
           if ($215) {
            label = 84;
            break L101;
           }
           __THREW__ = 0;
           $216 = (invoke_ii(3276,92)|0);
           $217 = __THREW__; __THREW__ = 0;
           $218 = $217&1;
           if ($218) {
            label = 84;
            break L101;
           }
           __THREW__ = 0;
           invoke_viii(3616,($216|0),(151254|0),0);
           $219 = __THREW__; __THREW__ = 0;
           $220 = $219&1;
           if ($220) {
            $245 = ___cxa_find_matching_catch_2()|0;
            $246 = tempRet0;
            __ZdlPv($216);
            $$5 = $245;$$528 = $246;
            break L101;
           }
           __THREW__ = 0;
           invoke_viii(3617,($0|0),($216|0),1);
           $221 = __THREW__; __THREW__ = 0;
           $222 = $221&1;
           if ($222) {
            label = 84;
            break L101;
           }
           $223 = HEAP32[$173>>2]|0;HEAP32[$173>>2] = (($223-1)|0);
           $224 = ($223|0)==(1);
           if (!($224)) {
            STACKTOP = sp;return;
           }
           __ZNK3osg10Referenced24signalObserversAndDeleteEbb($170,1,1);
           STACKTOP = sp;return;
          }
         }
         $239 = ___cxa_find_matching_catch_2()|0;
         $240 = tempRet0;
         $241 = ((($7)) + 11|0);
         $242 = HEAP8[$241>>0]|0;
         $243 = ($242<<24>>24)<(0);
         if ($243) {
          $244 = HEAP32[$7>>2]|0;
          __ZdlPv($244);
          if ($$0) {
           $$42784 = $240;$$485 = $239;
           break;
          } else {
           $$5 = $239;$$528 = $240;
           break L101;
          }
         } else {
          if ($$0) {
           $$42784 = $240;$$485 = $239;
           break;
          } else {
           $$5 = $239;$$528 = $240;
           break L101;
          }
         }
        }
       } while(0);
       __ZdlPv($192);
       $$5 = $$485;$$528 = $$42784;
       break L101;
      }
     }
     $231 = ___cxa_find_matching_catch_2()|0;
     $232 = tempRet0;
     $233 = ((($6)) + 11|0);
     $234 = HEAP8[$233>>0]|0;
     $235 = ($234<<24>>24)<(0);
     if ($235) {
      $236 = HEAP32[$6>>2]|0;
      __ZdlPv($236);
      if ($$015) {
       $$32682 = $232;$$383 = $231;
       break;
      } else {
       $$5 = $231;$$528 = $232;
       break L101;
      }
     } else {
      if ($$015) {
       $$32682 = $232;$$383 = $231;
       break;
      } else {
       $$5 = $231;$$528 = $232;
       break L101;
      }
     }
    }
   } while(0);
   __ZdlPv($175);
   $$5 = $$383;$$528 = $$32682;
  }
 } while(0);
 if ((label|0) == 84) {
  $227 = ___cxa_find_matching_catch_2()|0;
  $228 = tempRet0;
  $$5 = $227;$$528 = $228;
 }
 $247 = HEAP32[$173>>2]|0;HEAP32[$173>>2] = (($247-1)|0);
 $248 = ($247|0)==(1);
 if (!($248)) {
  $$7 = $$5;$$730 = $$528;
  ___resumeException($$7|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(3262,($170|0),1,1);
 $249 = __THREW__; __THREW__ = 0;
 $250 = $249&1;
 if ($250) {
  $251 = ___cxa_find_matching_catch_3(0|0)|0;
  $252 = tempRet0;
  ___clang_call_terminate($251);
  // unreachable;
 } else {
  $$7 = $$5;$$730 = $$528;
  ___resumeException($$7|0);
  // unreachable;
 }
}
function __ZN3osg8StateSet7setModeEjj($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$ph$lcssa$i$i$i$i = 0, $$0$ph13$i$i$i$i = 0, $$07$ph12$i$i$i$i = 0, $$0710$i$i$i$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp + 12|0;
 $4 = sp + 8|0;
 $5 = sp + 4|0;
 $6 = sp;
 $7 = HEAP8[206088]|0;
 $8 = ($7<<24>>24)==(0);
 do {
  if ($8) {
   $9 = (___cxa_guard_acquire(206088)|0);
   $10 = ($9|0)==(0);
   if (!($10)) {
    __THREW__ = 0;
    invoke_vi(3956,(208692|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     $13 = ___cxa_find_matching_catch_2()|0;
     $14 = tempRet0;
     ___resumeException($13|0);
     // unreachable;
    } else {
     (___cxa_atexit((3957|0),(208692|0),(___dso_handle|0))|0);
     break;
    }
   }
  }
 } while(0);
 $15 = HEAP32[(208696)>>2]|0;
 $16 = ($15|0)==(0|0);
 if (!($16)) {
  $$0$ph13$i$i$i$i = (208696);$$07$ph12$i$i$i$i = $15;
  L9: while(1) {
   $$0710$i$i$i$i = $$07$ph12$i$i$i$i;
   while(1) {
    $17 = ((($$0710$i$i$i$i)) + 16|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = ($18>>>0)<($1>>>0);
    if (!($19)) {
     break;
    }
    $22 = ((($$0710$i$i$i$i)) + 4|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = ($23|0)==(0|0);
    if ($24) {
     $$0$ph$lcssa$i$i$i$i = $$0$ph13$i$i$i$i;
     break L9;
    } else {
     $$0710$i$i$i$i = $23;
    }
   }
   $20 = HEAP32[$$0710$i$i$i$i>>2]|0;
   $21 = ($20|0)==(0|0);
   if ($21) {
    $$0$ph$lcssa$i$i$i$i = $$0710$i$i$i$i;
    break;
   } else {
    $$0$ph13$i$i$i$i = $$0710$i$i$i$i;$$07$ph12$i$i$i$i = $20;
   }
  }
  $25 = ($$0$ph$lcssa$i$i$i$i|0)==((208696)|0);
  if (!($25)) {
   $26 = ((($$0$ph$lcssa$i$i$i$i)) + 16|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = ($27>>>0)>($1>>>0);
   if (!($28)) {
    $29 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
    do {
     if ($29) {
      $30 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
      $31 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($30,152582,23)|0);
      $32 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($31,$1)|0);
      $33 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($32,152606,32)|0);
      $34 = HEAP32[$33>>2]|0;
      $35 = ((($34)) + -12|0);
      $36 = HEAP32[$35>>2]|0;
      $37 = (($33) + ($36)|0);
      __ZNKSt3__28ios_base6getlocEv($6,$37);
      __THREW__ = 0;
      $38 = (invoke_iii(3255,($6|0),(215188|0))|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       $41 = HEAP32[$38>>2]|0;
       $42 = ((($41)) + 28|0);
       $43 = HEAP32[$42>>2]|0;
       __THREW__ = 0;
       $44 = (invoke_iii($43|0,($38|0),10)|0);
       $45 = __THREW__; __THREW__ = 0;
       $46 = $45&1;
       if (!($46)) {
        __ZNSt3__26localeD2Ev($6);
        (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($33,$44)|0);
        (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($33)|0);
        break;
       }
      }
      $47 = ___cxa_find_matching_catch_2()|0;
      $48 = tempRet0;
      __THREW__ = 0;
      invoke_vi(3263,($6|0));
      $49 = __THREW__; __THREW__ = 0;
      $50 = $49&1;
      if ($50) {
       $51 = ___cxa_find_matching_catch_3(0|0)|0;
       $52 = tempRet0;
       ___clang_call_terminate($51);
       // unreachable;
      } else {
       ___resumeException($47|0);
       // unreachable;
      }
     }
    } while(0);
    $53 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
    do {
     if ($53) {
      $54 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
      $55 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($54,152639,60)|0);
      $56 = HEAP32[$55>>2]|0;
      $57 = ((($56)) + -12|0);
      $58 = HEAP32[$57>>2]|0;
      $59 = (($55) + ($58)|0);
      __ZNKSt3__28ios_base6getlocEv($5,$59);
      __THREW__ = 0;
      $60 = (invoke_iii(3255,($5|0),(215188|0))|0);
      $61 = __THREW__; __THREW__ = 0;
      $62 = $61&1;
      if (!($62)) {
       $63 = HEAP32[$60>>2]|0;
       $64 = ((($63)) + 28|0);
       $65 = HEAP32[$64>>2]|0;
       __THREW__ = 0;
       $66 = (invoke_iii($65|0,($60|0),10)|0);
       $67 = __THREW__; __THREW__ = 0;
       $68 = $67&1;
       if (!($68)) {
        __ZNSt3__26localeD2Ev($5);
        (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($55,$66)|0);
        (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($55)|0);
        break;
       }
      }
      $69 = ___cxa_find_matching_catch_2()|0;
      $70 = tempRet0;
      __THREW__ = 0;
      invoke_vi(3263,($5|0));
      $71 = __THREW__; __THREW__ = 0;
      $72 = $71&1;
      if ($72) {
       $73 = ___cxa_find_matching_catch_3(0|0)|0;
       $74 = tempRet0;
       ___clang_call_terminate($73);
       // unreachable;
      } else {
       ___resumeException($69|0);
       // unreachable;
      }
     }
    } while(0);
    $75 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
    do {
     if ($75) {
      $76 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
      $77 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($76,151965,60)|0);
      $78 = HEAP32[$77>>2]|0;
      $79 = ((($78)) + -12|0);
      $80 = HEAP32[$79>>2]|0;
      $81 = (($77) + ($80)|0);
      __ZNKSt3__28ios_base6getlocEv($4,$81);
      __THREW__ = 0;
      $82 = (invoke_iii(3255,($4|0),(215188|0))|0);
      $83 = __THREW__; __THREW__ = 0;
      $84 = $83&1;
      if (!($84)) {
       $85 = HEAP32[$82>>2]|0;
       $86 = ((($85)) + 28|0);
       $87 = HEAP32[$86>>2]|0;
       __THREW__ = 0;
       $88 = (invoke_iii($87|0,($82|0),10)|0);
       $89 = __THREW__; __THREW__ = 0;
       $90 = $89&1;
       if (!($90)) {
        __ZNSt3__26localeD2Ev($4);
        (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($77,$88)|0);
        (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($77)|0);
        break;
       }
      }
      $91 = ___cxa_find_matching_catch_2()|0;
      $92 = tempRet0;
      __THREW__ = 0;
      invoke_vi(3263,($4|0));
      $93 = __THREW__; __THREW__ = 0;
      $94 = $93&1;
      if ($94) {
       $95 = ___cxa_find_matching_catch_3(0|0)|0;
       $96 = tempRet0;
       ___clang_call_terminate($95);
       // unreachable;
      } else {
       ___resumeException($91|0);
       // unreachable;
      }
     }
    } while(0);
    __ZN3osg8StateSet14setTextureModeEjjj($0,0,$1,$2);
    STACKTOP = sp;return;
   }
  }
 }
 $97 = ($1|0)==(2903);
 if (!($97)) {
  $124 = ((($0)) + 44|0);
  __ZN3osg8StateSet7setModeERNSt3__23mapIjjNS1_4lessIjEENS1_9allocatorINS1_4pairIKjjEEEEEEjj($0,$124,$1,$2);
  STACKTOP = sp;return;
 }
 $98 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
 if ($98) {
  $99 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
  (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($99,152700,88)|0);
 }
 $100 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
 if ($100) {
  $101 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
  (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($101,152789,80)|0);
 }
 $102 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
 if (!($102)) {
  STACKTOP = sp;return;
 }
 $103 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
 $104 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($103,152870,60)|0);
 $105 = HEAP32[$104>>2]|0;
 $106 = ((($105)) + -12|0);
 $107 = HEAP32[$106>>2]|0;
 $108 = (($104) + ($107)|0);
 __ZNKSt3__28ios_base6getlocEv($3,$108);
 __THREW__ = 0;
 $109 = (invoke_iii(3255,($3|0),(215188|0))|0);
 $110 = __THREW__; __THREW__ = 0;
 $111 = $110&1;
 if (!($111)) {
  $112 = HEAP32[$109>>2]|0;
  $113 = ((($112)) + 28|0);
  $114 = HEAP32[$113>>2]|0;
  __THREW__ = 0;
  $115 = (invoke_iii($114|0,($109|0),10)|0);
  $116 = __THREW__; __THREW__ = 0;
  $117 = $116&1;
  if (!($117)) {
   __ZNSt3__26localeD2Ev($3);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($104,$115)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($104)|0);
   STACKTOP = sp;return;
  }
 }
 $118 = ___cxa_find_matching_catch_2()|0;
 $119 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($3|0));
 $120 = __THREW__; __THREW__ = 0;
 $121 = $120&1;
 if ($121) {
  $122 = ___cxa_find_matching_catch_3(0|0)|0;
  $123 = tempRet0;
  ___clang_call_terminate($122);
  // unreachable;
 } else {
  ___resumeException($118|0);
  // unreachable;
 }
}
function __ZN3osg8StateSet20setAttributeAndModesEPNS_14StateAttributeEj($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $100 = 0, $101 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $3 = sp + 24|0;
 $4 = sp + 20|0;
 $5 = sp + 16|0;
 $6 = sp;
 $7 = ($1|0)==(0|0);
 if ($7) {
  STACKTOP = sp;return;
 }
 $8 = HEAP32[$1>>2]|0;
 $9 = ((($8)) + 156|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (FUNCTION_TABLE_ii[$10 & 8191]($1)|0);
 if (!($11)) {
  $12 = $2 & 8;
  $13 = ($12|0)==(0);
  if (!($13)) {
   $14 = HEAP32[$1>>2]|0;
   $15 = ((($14)) + 148|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (FUNCTION_TABLE_ii[$16 & 8191]($1)|0);
   __ZN3osg8StateSet15removeAttributeENS_14StateAttribute4TypeEj($0,$17,0);
   STACKTOP = sp;return;
  }
  $18 = ((($0)) + 56|0);
  __ZN3osg8StateSet12setAttributeERNSt3__23mapINS1_4pairINS_14StateAttribute4TypeEjEENS3_INS_7ref_ptrIS4_EEjEENS1_4lessIS6_EENS1_9allocatorINS3_IKS6_S9_EEEEEEPS4_j($0,$18,$1,$2);
  HEAP32[$6>>2] = (66344);
  $19 = ((($6)) + 4|0);
  HEAP32[$19>>2] = $0;
  $20 = ((($6)) + 8|0);
  HEAP32[$20>>2] = $2;
  $21 = ((($6)) + 12|0);
  HEAP32[$21>>2] = 0;
  $22 = HEAP32[$1>>2]|0;
  $23 = ((($22)) + 164|0);
  $24 = HEAP32[$23>>2]|0;
  __THREW__ = 0;
  (invoke_iii($24|0,($1|0),($6|0))|0);
  $25 = __THREW__; __THREW__ = 0;
  $26 = $25&1;
  if ($26) {
   $27 = ___cxa_find_matching_catch_2()|0;
   $28 = tempRet0;
   ___resumeException($27|0);
   // unreachable;
  }
  STACKTOP = sp;return;
 }
 $29 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
 do {
  if ($29) {
   $30 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
   $31 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($30,151833,28)|0);
   $32 = HEAP32[$1>>2]|0;
   $33 = ((($32)) + 28|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = (FUNCTION_TABLE_ii[$34 & 8191]($1)|0);
   $36 = (_strlen($35)|0);
   $37 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($31,$35,$36)|0);
   $38 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($37,152130,46)|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = ((($39)) + -12|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = (($38) + ($41)|0);
   __ZNKSt3__28ios_base6getlocEv($4,$42);
   __THREW__ = 0;
   $43 = (invoke_iii(3255,($4|0),(215188|0))|0);
   $44 = __THREW__; __THREW__ = 0;
   $45 = $44&1;
   if (!($45)) {
    $46 = HEAP32[$43>>2]|0;
    $47 = ((($46)) + 28|0);
    $48 = HEAP32[$47>>2]|0;
    __THREW__ = 0;
    $49 = (invoke_iii($48|0,($43|0),10)|0);
    $50 = __THREW__; __THREW__ = 0;
    $51 = $50&1;
    if (!($51)) {
     __ZNSt3__26localeD2Ev($4);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($38,$49)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($38)|0);
     break;
    }
   }
   $52 = ___cxa_find_matching_catch_2()|0;
   $53 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($4|0));
   $54 = __THREW__; __THREW__ = 0;
   $55 = $54&1;
   if ($55) {
    $56 = ___cxa_find_matching_catch_3(0|0)|0;
    $57 = tempRet0;
    ___clang_call_terminate($56);
    // unreachable;
   } else {
    ___resumeException($52|0);
    // unreachable;
   }
  }
 } while(0);
 $58 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
 do {
  if ($58) {
   $59 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
   $60 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($59,152177,73)|0);
   $61 = HEAP32[$60>>2]|0;
   $62 = ((($61)) + -12|0);
   $63 = HEAP32[$62>>2]|0;
   $64 = (($60) + ($63)|0);
   __ZNKSt3__28ios_base6getlocEv($3,$64);
   __THREW__ = 0;
   $65 = (invoke_iii(3255,($3|0),(215188|0))|0);
   $66 = __THREW__; __THREW__ = 0;
   $67 = $66&1;
   if (!($67)) {
    $68 = HEAP32[$65>>2]|0;
    $69 = ((($68)) + 28|0);
    $70 = HEAP32[$69>>2]|0;
    __THREW__ = 0;
    $71 = (invoke_iii($70|0,($65|0),10)|0);
    $72 = __THREW__; __THREW__ = 0;
    $73 = $72&1;
    if (!($73)) {
     __ZNSt3__26localeD2Ev($3);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($60,$71)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($60)|0);
     break;
    }
   }
   $74 = ___cxa_find_matching_catch_2()|0;
   $75 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($3|0));
   $76 = __THREW__; __THREW__ = 0;
   $77 = $76&1;
   if ($77) {
    $78 = ___cxa_find_matching_catch_3(0|0)|0;
    $79 = tempRet0;
    ___clang_call_terminate($78);
    // unreachable;
   } else {
    ___resumeException($74|0);
    // unreachable;
   }
  }
 } while(0);
 $80 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
 do {
  if ($80) {
   $81 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
   $82 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($81,151965,60)|0);
   $83 = HEAP32[$82>>2]|0;
   $84 = ((($83)) + -12|0);
   $85 = HEAP32[$84>>2]|0;
   $86 = (($82) + ($85)|0);
   __ZNKSt3__28ios_base6getlocEv($5,$86);
   __THREW__ = 0;
   $87 = (invoke_iii(3255,($5|0),(215188|0))|0);
   $88 = __THREW__; __THREW__ = 0;
   $89 = $88&1;
   if (!($89)) {
    $90 = HEAP32[$87>>2]|0;
    $91 = ((($90)) + 28|0);
    $92 = HEAP32[$91>>2]|0;
    __THREW__ = 0;
    $93 = (invoke_iii($92|0,($87|0),10)|0);
    $94 = __THREW__; __THREW__ = 0;
    $95 = $94&1;
    if (!($95)) {
     __ZNSt3__26localeD2Ev($5);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($82,$93)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($82)|0);
     break;
    }
   }
   $96 = ___cxa_find_matching_catch_2()|0;
   $97 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($5|0));
   $98 = __THREW__; __THREW__ = 0;
   $99 = $98&1;
   if ($99) {
    $100 = ___cxa_find_matching_catch_3(0|0)|0;
    $101 = tempRet0;
    ___clang_call_terminate($100);
    // unreachable;
   } else {
    ___resumeException($96|0);
    // unreachable;
   }
  }
 } while(0);
 __ZN3osg8StateSet27setTextureAttributeAndModesEjPNS_14StateAttributeEj($0,0,$1,$2);
 STACKTOP = sp;return;
}
function __ZN3osg8StateSet19setTextureAttributeEjPNS_14StateAttributeEj($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $4 = sp + 8|0;
 $5 = sp + 4|0;
 $6 = sp;
 $7 = ($2|0)==(0|0);
 if ($7) {
  STACKTOP = sp;return;
 }
 $8 = HEAP32[$2>>2]|0;
 $9 = ((($8)) + 156|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (FUNCTION_TABLE_ii[$10 & 8191]($2)|0);
 if ($11) {
  $12 = ((($0)) + 80|0);
  $13 = ((($0)) + 84|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = HEAP32[$12>>2]|0;
  $16 = (($14) - ($15))|0;
  $17 = (($16|0) / 12)&-1;
  $18 = ($17>>>0)>($1>>>0);
  do {
   if (!($18)) {
    $19 = (($1) + 1)|0;
    $20 = ($19>>>0)>($17>>>0);
    $21 = $15;
    $22 = $14;
    if ($20) {
     $23 = (($19) - ($17))|0;
     __ZNSt3__26vectorINS_3mapINS_4pairIN3osg14StateAttribute4TypeEjEENS2_INS3_7ref_ptrIS4_EEjEENS_4lessIS6_EENS_9allocatorINS2_IKS6_S9_EEEEEENSC_ISG_EEE8__appendEj($12,$23);
     break;
    }
    $24 = ($19>>>0)<($17>>>0);
    if ($24) {
     $25 = (($21) + (($19*12)|0)|0);
     $26 = ($22|0)==($25|0);
     if (!($26)) {
      $28 = $22;
      while(1) {
       $27 = ((($28)) + -12|0);
       HEAP32[$13>>2] = $27;
       $29 = ((($28)) + -8|0);
       $30 = HEAP32[$29>>2]|0;
       __ZNSt3__26__treeINS_12__value_typeINS_4pairIN3osg14StateAttribute4TypeEjEENS2_INS3_7ref_ptrIS4_EEjEEEENS_19__map_value_compareIS6_SA_NS_4lessIS6_EELb1EEENS_9allocatorISA_EEE7destroyEPNS_11__tree_nodeISA_PvEE($27,$30);
       $31 = HEAP32[$13>>2]|0;
       $32 = ($31|0)==($25|0);
       if ($32) {
        break;
       } else {
        $28 = $31;
       }
      }
     }
    }
   }
  } while(0);
  $33 = HEAP32[$12>>2]|0;
  $34 = (($33) + (($1*12)|0)|0);
  __ZN3osg8StateSet12setAttributeERNSt3__23mapINS1_4pairINS_14StateAttribute4TypeEjEENS3_INS_7ref_ptrIS4_EEjEENS1_4lessIS6_EENS1_9allocatorINS3_IKS6_S9_EEEEEEPS4_j($0,$34,$2,$3);
  STACKTOP = sp;return;
 }
 $35 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
 do {
  if ($35) {
   $36 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
   $37 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($36,151833,28)|0);
   $38 = HEAP32[$2>>2]|0;
   $39 = ((($38)) + 28|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = (FUNCTION_TABLE_ii[$40 & 8191]($2)|0);
   $42 = (_strlen($41)|0);
   $43 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($37,$41,$42)|0);
   $44 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($43,151862,50)|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = ((($45)) + -12|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = (($44) + ($47)|0);
   __ZNKSt3__28ios_base6getlocEv($5,$48);
   __THREW__ = 0;
   $49 = (invoke_iii(3255,($5|0),(215188|0))|0);
   $50 = __THREW__; __THREW__ = 0;
   $51 = $50&1;
   if (!($51)) {
    $52 = HEAP32[$49>>2]|0;
    $53 = ((($52)) + 28|0);
    $54 = HEAP32[$53>>2]|0;
    __THREW__ = 0;
    $55 = (invoke_iii($54|0,($49|0),10)|0);
    $56 = __THREW__; __THREW__ = 0;
    $57 = $56&1;
    if (!($57)) {
     __ZNSt3__26localeD2Ev($5);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($44,$55)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($44)|0);
     break;
    }
   }
   $58 = ___cxa_find_matching_catch_2()|0;
   $59 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($5|0));
   $60 = __THREW__; __THREW__ = 0;
   $61 = $60&1;
   if ($61) {
    $62 = ___cxa_find_matching_catch_3(0|0)|0;
    $63 = tempRet0;
    ___clang_call_terminate($62);
    // unreachable;
   } else {
    ___resumeException($58|0);
    // unreachable;
   }
  }
 } while(0);
 $64 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
 do {
  if ($64) {
   $65 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
   $66 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($65,151913,51)|0);
   $67 = HEAP32[$66>>2]|0;
   $68 = ((($67)) + -12|0);
   $69 = HEAP32[$68>>2]|0;
   $70 = (($66) + ($69)|0);
   __ZNKSt3__28ios_base6getlocEv($4,$70);
   __THREW__ = 0;
   $71 = (invoke_iii(3255,($4|0),(215188|0))|0);
   $72 = __THREW__; __THREW__ = 0;
   $73 = $72&1;
   if (!($73)) {
    $74 = HEAP32[$71>>2]|0;
    $75 = ((($74)) + 28|0);
    $76 = HEAP32[$75>>2]|0;
    __THREW__ = 0;
    $77 = (invoke_iii($76|0,($71|0),10)|0);
    $78 = __THREW__; __THREW__ = 0;
    $79 = $78&1;
    if (!($79)) {
     __ZNSt3__26localeD2Ev($4);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($66,$77)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($66)|0);
     break;
    }
   }
   $80 = ___cxa_find_matching_catch_2()|0;
   $81 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($4|0));
   $82 = __THREW__; __THREW__ = 0;
   $83 = $82&1;
   if ($83) {
    $84 = ___cxa_find_matching_catch_3(0|0)|0;
    $85 = tempRet0;
    ___clang_call_terminate($84);
    // unreachable;
   } else {
    ___resumeException($80|0);
    // unreachable;
   }
  }
 } while(0);
 $86 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
 do {
  if ($86) {
   $87 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
   $88 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($87,151965,60)|0);
   $89 = HEAP32[$88>>2]|0;
   $90 = ((($89)) + -12|0);
   $91 = HEAP32[$90>>2]|0;
   $92 = (($88) + ($91)|0);
   __ZNKSt3__28ios_base6getlocEv($6,$92);
   __THREW__ = 0;
   $93 = (invoke_iii(3255,($6|0),(215188|0))|0);
   $94 = __THREW__; __THREW__ = 0;
   $95 = $94&1;
   if (!($95)) {
    $96 = HEAP32[$93>>2]|0;
    $97 = ((($96)) + 28|0);
    $98 = HEAP32[$97>>2]|0;
    __THREW__ = 0;
    $99 = (invoke_iii($98|0,($93|0),10)|0);
    $100 = __THREW__; __THREW__ = 0;
    $101 = $100&1;
    if (!($101)) {
     __ZNSt3__26localeD2Ev($6);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($88,$99)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($88)|0);
     break;
    }
   }
   $102 = ___cxa_find_matching_catch_2()|0;
   $103 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($6|0));
   $104 = __THREW__; __THREW__ = 0;
   $105 = $104&1;
   if ($105) {
    $106 = ___cxa_find_matching_catch_3(0|0)|0;
    $107 = tempRet0;
    ___clang_call_terminate($106);
    // unreachable;
   } else {
    ___resumeException($102|0);
    // unreachable;
   }
  }
 } while(0);
 __ZN3osg8StateSet12setAttributeEPNS_14StateAttributeEj($0,$2,$3);
 STACKTOP = sp;return;
}
function __ZN3osg8StateSet10addUniformEPNS_7UniformEj($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$$i = 0, $$$i39 = 0, $$032 = 0, $$1$i = 0, $$1$i41 = 0, $$133 = 0, $$234 = 0, $$37 = 0, $$37$ = 0, $$43657 = 0, $$43659 = 0, $$460 = 0, $$sroa$013$018$i = 0, $$sroa$013$018$i42 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $not$ = 0, $not$$i = 0, $not$$i38 = 0, $not$17$i = 0, $not$17$i40 = 0, $not$62 = 0, $not$63 = 0, $not$64 = 0, $not$65 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($1|0)==(0|0);
 if ($3) {
  return;
 }
 $4 = ((($0)) + 92|0);
 $5 = ((($1)) + 12|0);
 $6 = (__ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4pairIN3osg7ref_ptrINS9_7UniformEEEjEEEENS_19__map_value_compareIS7_SE_NS_4lessIS7_EELb1EEENS5_ISE_EEE4findIS7_EENS_15__tree_iteratorISE_PNS_11__tree_nodeISE_PvEEiEERKT_($4,$5)|0);
 $7 = ((($0)) + 96|0);
 $8 = ($6|0)==($7|0);
 if ($8) {
  $9 = (__ZNSt3__23mapINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4pairIN3osg7ref_ptrINS8_7UniformEEEjEENS_4lessIS6_EENS4_INS7_IKS6_SC_EEEEEixERSF_($4,$5)|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10|0)==($1|0);
  if (!($11)) {
   HEAP32[$9>>2] = $1;
   $12 = ((($1)) + 8|0);
   $13 = HEAP32[$12>>2]|0;HEAP32[$12>>2] = (($13+1)|0);
   $14 = ($10|0)==(0|0);
   if (!($14)) {
    $15 = ((($10)) + 8|0);
    $16 = HEAP32[$15>>2]|0;HEAP32[$15>>2] = (($16-1)|0);
    $17 = ($16|0)==(1);
    if ($17) {
     __ZNK3osg10Referenced24signalObserversAndDeleteEbb($10,1,1);
    }
   }
  }
  $18 = $2 & 6;
  $19 = ((($9)) + 4|0);
  HEAP32[$19>>2] = $18;
  __ZN3osg7Uniform9addParentEPNS_8StateSetE($1,$0);
  $20 = ((($1)) + 80|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = ($21|0)==(0|0);
  $23 = ((($1)) + 84|0);
  $24 = HEAP32[$23>>2]|0;
  $not$65 = ($24|0)!=(0|0);
  $$032 = $not$65&1;
  if ($22) {
   $$43657 = $$032;
  } else {
   $$43659 = $$032;$$460 = 1;
   label = 15;
  }
 } else {
  $25 = ((($6)) + 28|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = ($26|0)==($1|0);
  if ($27) {
   $28 = $2 & 6;
   $29 = ((($6)) + 32|0);
   HEAP32[$29>>2] = $28;
   return;
  }
  __ZN3osg7Uniform12removeParentEPNS_8StateSetE($26,$0);
  $30 = HEAP32[$25>>2]|0;
  $31 = ((($30)) + 80|0);
  $32 = HEAP32[$31>>2]|0;
  $not$ = ($32|0)!=(0|0);
  $$37 = $not$ << 31 >> 31;
  $33 = ((($30)) + 84|0);
  $34 = HEAP32[$33>>2]|0;
  $not$62 = ($34|0)!=(0|0);
  $$133 = $not$62 << 31 >> 31;
  __ZN3osg7Uniform9addParentEPNS_8StateSetE($1,$0);
  $35 = HEAP32[$25>>2]|0;
  $36 = ($35|0)==($1|0);
  if (!($36)) {
   HEAP32[$25>>2] = $1;
   $37 = ((($1)) + 8|0);
   $38 = HEAP32[$37>>2]|0;HEAP32[$37>>2] = (($38+1)|0);
   $39 = ($35|0)==(0|0);
   if (!($39)) {
    $40 = ((($35)) + 8|0);
    $41 = HEAP32[$40>>2]|0;HEAP32[$40>>2] = (($41-1)|0);
    $42 = ($41|0)==(1);
    if ($42) {
     __ZNK3osg10Referenced24signalObserversAndDeleteEbb($35,1,1);
    }
   }
  }
  $43 = HEAP32[$25>>2]|0;
  $44 = ((($43)) + 80|0);
  $45 = HEAP32[$44>>2]|0;
  $not$63 = ($45|0)!=(0|0);
  $46 = $not$63&1;
  $$37$ = (($46) + ($$37))|0;
  $47 = ((($43)) + 84|0);
  $48 = HEAP32[$47>>2]|0;
  $not$64 = ($48|0)!=(0|0);
  $49 = $not$64&1;
  $$234 = (($49) + ($$133))|0;
  $50 = $2 & 6;
  $51 = ((($6)) + 32|0);
  HEAP32[$51>>2] = $50;
  $52 = ($$37$|0)==(0);
  if ($52) {
   $$43657 = $$234;
  } else {
   $$43659 = $$234;$$460 = $$37$;
   label = 15;
  }
 }
 if ((label|0) == 15) {
  $53 = ((($0)) + 148|0);
  $54 = HEAP32[$53>>2]|0;
  $55 = (($54) + ($$460))|0;
  $56 = ((($0)) + 144|0);
  $57 = HEAP32[$56>>2]|0;
  $58 = ($57|0)==(0|0);
  if ($58) {
   $59 = ((($0)) + 32|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = ((($0)) + 36|0);
   $62 = HEAP32[$61>>2]|0;
   $63 = ($60|0)==($62|0);
   if (!($63)) {
    $not$$i38 = ($54|0)!=(0);
    $$$i39 = $not$$i38 << 31 >> 31;
    $not$17$i40 = ($55|0)!=(0);
    $64 = $not$17$i40&1;
    $$1$i41 = (($64) + ($$$i39))|0;
    $65 = ($$1$i41|0)==(0);
    if (!($65)) {
     $$sroa$013$018$i42 = $60;
     while(1) {
      $66 = HEAP32[$$sroa$013$018$i42>>2]|0;
      $67 = ((($66)) + 88|0);
      $68 = HEAP32[$67>>2]|0;
      $69 = (($68) + ($$1$i41))|0;
      __ZN3osg4Node38setNumChildrenRequiringUpdateTraversalEj($66,$69);
      $70 = ((($$sroa$013$018$i42)) + 4|0);
      $71 = HEAP32[$61>>2]|0;
      $72 = ($70|0)==($71|0);
      if ($72) {
       break;
      } else {
       $$sroa$013$018$i42 = $70;
      }
     }
    }
   }
  }
  HEAP32[$53>>2] = $55;
  $$43657 = $$43659;
 }
 $73 = ($$43657|0)==(0);
 if ($73) {
  return;
 }
 $74 = ((($0)) + 156|0);
 $75 = HEAP32[$74>>2]|0;
 $76 = (($75) + ($$43657))|0;
 $77 = ((($0)) + 152|0);
 $78 = HEAP32[$77>>2]|0;
 $79 = ($78|0)==(0|0);
 if ($79) {
  $80 = ((($0)) + 32|0);
  $81 = HEAP32[$80>>2]|0;
  $82 = ((($0)) + 36|0);
  $83 = HEAP32[$82>>2]|0;
  $84 = ($81|0)==($83|0);
  if (!($84)) {
   $not$$i = ($75|0)!=(0);
   $$$i = $not$$i << 31 >> 31;
   $not$17$i = ($76|0)!=(0);
   $85 = $not$17$i&1;
   $$1$i = (($85) + ($$$i))|0;
   $86 = ($$1$i|0)==(0);
   if (!($86)) {
    $$sroa$013$018$i = $81;
    while(1) {
     $87 = HEAP32[$$sroa$013$018$i>>2]|0;
     $88 = ((($87)) + 96|0);
     $89 = HEAP32[$88>>2]|0;
     $90 = (($89) + ($$1$i))|0;
     __ZN3osg4Node37setNumChildrenRequiringEventTraversalEj($87,$90);
     $91 = ((($$sroa$013$018$i)) + 4|0);
     $92 = HEAP32[$82>>2]|0;
     $93 = ($91|0)==($92|0);
     if ($93) {
      break;
     } else {
      $$sroa$013$018$i = $91;
     }
    }
   }
  }
 }
 HEAP32[$74>>2] = $76;
 return;
}
function __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4pairIN3osg7ref_ptrINS9_7UniformEEEjEEEENS_19__map_value_compareIS7_SE_NS_4lessIS7_EELb1EEENS5_ISE_EEE4findIS7_EENS_15__tree_iteratorISE_PNS_11__tree_nodeISE_PvEEiEERKT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$ph$lcssa$i = 0, $$0$ph15$i = 0, $$07$ph14$i = 0, $$0711$i = 0, $$sroa$0$0 = 0, $$sroa$speculated$i$i$i$i$i = 0, $$sroa$speculated$i$i$i$i$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 do {
  if (!($4)) {
   $5 = ((($1)) + 11|0);
   $6 = HEAP8[$5>>0]|0;
   $7 = ($6<<24>>24)<(0);
   $8 = ((($1)) + 4|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = $6&255;
   $11 = $7 ? $9 : $10;
   $12 = HEAP32[$1>>2]|0;
   $13 = $7 ? $12 : $1;
   $$0$ph15$i = $2;$$07$ph14$i = $3;
   L3: while(1) {
    $$0711$i = $$07$ph14$i;
    while(1) {
     $14 = ((($$0711$i)) + 16|0);
     $15 = ((($14)) + 11|0);
     $16 = HEAP8[$15>>0]|0;
     $17 = ($16<<24>>24)<(0);
     $18 = ((($$0711$i)) + 20|0);
     $19 = HEAP32[$18>>2]|0;
     $20 = $16&255;
     $21 = $17 ? $19 : $20;
     $22 = ($11>>>0)<($21>>>0);
     $$sroa$speculated$i$i$i$i$i$i = $22 ? $11 : $21;
     $23 = ($$sroa$speculated$i$i$i$i$i$i|0)==(0);
     if ($23) {
      label = 6;
     } else {
      $24 = HEAP32[$14>>2]|0;
      $25 = $17 ? $24 : $14;
      $26 = (_memcmp($25,$13,$$sroa$speculated$i$i$i$i$i$i)|0);
      $27 = ($26|0)==(0);
      if ($27) {
       label = 6;
      } else {
       $29 = ($26|0)<(0);
       if (!($29)) {
        break;
       }
      }
     }
     if ((label|0) == 6) {
      label = 0;
      $28 = ($21>>>0)<($11>>>0);
      if (!($28)) {
       break;
      }
     }
     $32 = ((($$0711$i)) + 4|0);
     $33 = HEAP32[$32>>2]|0;
     $34 = ($33|0)==(0|0);
     if ($34) {
      $$0$ph$lcssa$i = $$0$ph15$i;
      break L3;
     } else {
      $$0711$i = $33;
     }
    }
    $30 = HEAP32[$$0711$i>>2]|0;
    $31 = ($30|0)==(0|0);
    if ($31) {
     $$0$ph$lcssa$i = $$0711$i;
     break;
    } else {
     $$0$ph15$i = $$0711$i;$$07$ph14$i = $30;
    }
   }
   $35 = ($$0$ph$lcssa$i|0)==($2|0);
   if (!($35)) {
    $36 = ((($$0$ph$lcssa$i)) + 16|0);
    $37 = ((($36)) + 11|0);
    $38 = HEAP8[$37>>0]|0;
    $39 = ($38<<24>>24)<(0);
    $40 = ((($$0$ph$lcssa$i)) + 20|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = $38&255;
    $43 = $39 ? $41 : $42;
    $44 = ($43>>>0)<($11>>>0);
    $$sroa$speculated$i$i$i$i$i = $44 ? $43 : $11;
    $45 = ($$sroa$speculated$i$i$i$i$i|0)==(0);
    if (!($45)) {
     $46 = HEAP32[$36>>2]|0;
     $47 = $39 ? $46 : $36;
     $48 = (_memcmp($13,$47,$$sroa$speculated$i$i$i$i$i)|0);
     $49 = ($48|0)==(0);
     if (!($49)) {
      $51 = ($48|0)<(0);
      if ($51) {
       break;
      } else {
       $$sroa$0$0 = $$0$ph$lcssa$i;
      }
      return ($$sroa$0$0|0);
     }
    }
    $50 = ($11>>>0)<($43>>>0);
    if (!($50)) {
     $$sroa$0$0 = $$0$ph$lcssa$i;
     return ($$sroa$0$0|0);
    }
   }
  }
 } while(0);
 $$sroa$0$0 = $2;
 return ($$sroa$0$0|0);
}
function __ZN3osg8StateSet12setAttributeERNSt3__23mapINS1_4pairINS_14StateAttribute4TypeEjEENS3_INS_7ref_ptrIS4_EEjEENS1_4lessIS6_EENS1_9allocatorINS3_IKS6_S9_EEEEEEPS4_j($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$$i = 0, $$$i44 = 0, $$0 = 0, $$0$i$i = 0, $$0$ph$i$i = 0, $$0$ph$lcssa$i$i$i = 0, $$0$ph14$i$i$i = 0, $$014$i = 0, $$024$i$i = 0, $$025$i$i = 0, $$025$i53$i = 0, $$035 = 0, $$036 = 0, $$037$i = 0, $$03752$i = 0, $$07$ph13$i$i$i = 0, $$0711$i$i$i = 0, $$1 = 0, $$1$i = 0, $$1$i46 = 0;
 var $$394 = 0, $$397 = 0, $$41 = 0, $$41$ = 0, $$42 = 0, $$496 = 0, $$in$i$i = 0, $$pre$i$i = 0, $$sroa$013$018$i = 0, $$sroa$013$018$i47 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0;
 var $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0;
 var $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $not$ = 0, $not$$i = 0, $not$$i43 = 0, $not$100 = 0, $not$101 = 0, $not$102 = 0, $not$17$i = 0, $not$17$i45 = 0, $not$99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ($2|0)==(0|0);
 if ($4) {
  return;
 }
 $5 = HEAP32[$2>>2]|0;
 $6 = ((($5)) + 148|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_ii[$7 & 8191]($2)|0);
 $9 = HEAP32[$2>>2]|0;
 $10 = ((($9)) + 152|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (FUNCTION_TABLE_ii[$11 & 8191]($2)|0);
 $13 = ((($1)) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(0|0);
 do {
  if ($15) {
   label = 13;
  } else {
   $$0$ph14$i$i$i = $13;$$07$ph13$i$i$i = $14;
   L5: while(1) {
    $$0711$i$i$i = $$07$ph13$i$i$i;
    while(1) {
     $16 = ((($$0711$i$i$i)) + 16|0);
     $17 = HEAP32[$16>>2]|0;
     $18 = ($17|0)<($8|0);
     if (!($18)) {
      $19 = ($8|0)<($17|0);
      if ($19) {
       break;
      }
      $20 = ((($$0711$i$i$i)) + 20|0);
      $21 = HEAP32[$20>>2]|0;
      $22 = ($21>>>0)<($12>>>0);
      if (!($22)) {
       break;
      }
     }
     $25 = ((($$0711$i$i$i)) + 4|0);
     $26 = HEAP32[$25>>2]|0;
     $27 = ($26|0)==(0|0);
     if ($27) {
      $$0$ph$lcssa$i$i$i = $$0$ph14$i$i$i;
      break L5;
     } else {
      $$0711$i$i$i = $26;
     }
    }
    $23 = HEAP32[$$0711$i$i$i>>2]|0;
    $24 = ($23|0)==(0|0);
    if ($24) {
     $$0$ph$lcssa$i$i$i = $$0711$i$i$i;
     break;
    } else {
     $$0$ph14$i$i$i = $$0711$i$i$i;$$07$ph13$i$i$i = $23;
    }
   }
   $28 = ($$0$ph$lcssa$i$i$i|0)==($13|0);
   if ($28) {
    label = 13;
   } else {
    $29 = ((($$0$ph$lcssa$i$i$i)) + 16|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = ($8|0)<($30|0);
    if ($31) {
     label = 13;
    } else {
     $32 = ($30|0)<($8|0);
     if (!($32)) {
      $33 = ((($$0$ph$lcssa$i$i$i)) + 20|0);
      $34 = HEAP32[$33>>2]|0;
      $35 = ($12>>>0)<($34>>>0);
      if ($35) {
       label = 13;
       break;
      }
     }
     $126 = ((($$0$ph$lcssa$i$i$i)) + 24|0);
     $127 = HEAP32[$126>>2]|0;
     $128 = ($127|0)==($2|0);
     if ($128) {
      $129 = $3 & 6;
      $130 = ((($$0$ph$lcssa$i$i$i)) + 28|0);
      HEAP32[$130>>2] = $129;
      return;
     }
     __ZN3osg14StateAttribute12removeParentEPNS_8StateSetE($127,$0);
     $131 = HEAP32[$126>>2]|0;
     $132 = ((($131)) + 48|0);
     $133 = HEAP32[$132>>2]|0;
     $not$ = ($133|0)!=(0|0);
     $$41 = $not$ << 31 >> 31;
     $134 = ((($131)) + 52|0);
     $135 = HEAP32[$134>>2]|0;
     $not$99 = ($135|0)!=(0|0);
     $$036 = $not$99 << 31 >> 31;
     __ZN3osg14StateAttribute9addParentEPNS_8StateSetE($2,$0);
     $136 = HEAP32[$126>>2]|0;
     $137 = ($136|0)==($2|0);
     if (!($137)) {
      HEAP32[$126>>2] = $2;
      $138 = ((($2)) + 8|0);
      $139 = HEAP32[$138>>2]|0;HEAP32[$138>>2] = (($139+1)|0);
      $140 = ($136|0)==(0|0);
      if (!($140)) {
       $141 = ((($136)) + 8|0);
       $142 = HEAP32[$141>>2]|0;HEAP32[$141>>2] = (($142-1)|0);
       $143 = ($142|0)==(1);
       if ($143) {
        __ZNK3osg10Referenced24signalObserversAndDeleteEbb($136,1,1);
       }
      }
     }
     $144 = HEAP32[$126>>2]|0;
     $145 = ((($144)) + 48|0);
     $146 = HEAP32[$145>>2]|0;
     $not$100 = ($146|0)!=(0|0);
     $147 = $not$100&1;
     $$41$ = (($147) + ($$41))|0;
     $148 = ((($144)) + 52|0);
     $149 = HEAP32[$148>>2]|0;
     $not$101 = ($149|0)!=(0|0);
     $150 = $not$101&1;
     $$1 = (($150) + ($$036))|0;
     $151 = $3 & 6;
     $152 = ((($$0$ph$lcssa$i$i$i)) + 28|0);
     HEAP32[$152>>2] = $151;
     $153 = ($$41$|0)==(0);
     if ($153) {
      $$394 = $$1;
     } else {
      $$397 = $$1;$$496 = $$41$;
      label = 55;
     }
    }
   }
  }
 } while(0);
 L29: do {
  if ((label|0) == 13) {
   $36 = ((($2)) + 8|0);
   $37 = HEAP32[$36>>2]|0;HEAP32[$36>>2] = (($37+1)|0);
   $38 = $3 & 6;
   $39 = HEAP32[$36>>2]|0;HEAP32[$36>>2] = (($39+1)|0);
   $40 = HEAP32[$2>>2]|0;
   $41 = ((($40)) + 148|0);
   $42 = HEAP32[$41>>2]|0;
   __THREW__ = 0;
   $43 = (invoke_ii($42|0,($2|0))|0);
   $44 = __THREW__; __THREW__ = 0;
   $45 = $44&1;
   do {
    if ($45) {
     label = 43;
    } else {
     $46 = HEAP32[$2>>2]|0;
     $47 = ((($46)) + 152|0);
     $48 = HEAP32[$47>>2]|0;
     __THREW__ = 0;
     $49 = (invoke_ii($48|0,($2|0))|0);
     $50 = __THREW__; __THREW__ = 0;
     $51 = $50&1;
     if ($51) {
      label = 43;
     } else {
      $52 = HEAP32[$13>>2]|0;
      $53 = ($52|0)==(0|0);
      do {
       if ($53) {
        $$025$i$i = $13;$$037$i = $13;$68 = $52;
        label = 28;
       } else {
        $54 = ((($1)) + 4|0);
        $$0$i$i = $54;$$024$i$i = $52;$197 = $52;
        L37: while(1) {
         $55 = ((($$024$i$i)) + 16|0);
         $56 = HEAP32[$55>>2]|0;
         $57 = ($43|0)<($56|0);
         do {
          if ($57) {
           label = 21;
          } else {
           $58 = ($56|0)<($43|0);
           if (!($58)) {
            $59 = ((($$024$i$i)) + 20|0);
            $60 = HEAP32[$59>>2]|0;
            $61 = ($49>>>0)<($60>>>0);
            if ($61) {
             label = 21;
             break;
            }
            $64 = ($60>>>0)<($49>>>0);
            if (!($64)) {
             label = 26;
             break L37;
            }
           }
           $65 = ((($$024$i$i)) + 4|0);
           $66 = HEAP32[$65>>2]|0;
           $67 = ($66|0)==(0|0);
           if ($67) {
            label = 25;
            break L37;
           } else {
            $$0$ph$i$i = $65;$$in$i$i = $66;
           }
          }
         } while(0);
         if ((label|0) == 21) {
          label = 0;
          $62 = HEAP32[$$024$i$i>>2]|0;
          $63 = ($62|0)==(0|0);
          if ($63) {
           label = 22;
           break;
          } else {
           $$0$ph$i$i = $$024$i$i;$$in$i$i = $62;
          }
         }
         $$0$i$i = $$0$ph$i$i;$$024$i$i = $$in$i$i;$197 = $$in$i$i;
        }
        if ((label|0) == 22) {
         $$025$i53$i = $$024$i$i;$$03752$i = $$024$i$i;
         label = 29;
         break;
        }
        else if ((label|0) == 25) {
         $$025$i53$i = $65;$$03752$i = $$024$i$i;
         label = 29;
         break;
        }
        else if ((label|0) == 26) {
         $$025$i$i = $$0$i$i;$$037$i = $$024$i$i;$68 = $197;
         label = 28;
         break;
        }
       }
      } while(0);
      if ((label|0) == 28) {
       $69 = ($68|0)==(0|0);
       if ($69) {
        $$025$i53$i = $$025$i$i;$$03752$i = $$037$i;
        label = 29;
       } else {
        $$014$i = $68;
       }
      }
      if ((label|0) == 29) {
       __THREW__ = 0;
       $70 = (invoke_ii(3276,32)|0);
       $71 = __THREW__; __THREW__ = 0;
       $72 = $71&1;
       if ($72) {
        label = 43;
        break;
       }
       $73 = ((($70)) + 16|0);
       $74 = $73;
       $75 = $74;
       HEAP32[$75>>2] = $43;
       $76 = (($74) + 4)|0;
       $77 = $76;
       HEAP32[$77>>2] = $49;
       $78 = ((($70)) + 24|0);
       HEAP32[$78>>2] = 0;
       $79 = ((($70)) + 28|0);
       HEAP32[$79>>2] = 0;
       HEAP32[$70>>2] = 0;
       $80 = ((($70)) + 4|0);
       HEAP32[$80>>2] = 0;
       $81 = ((($70)) + 8|0);
       HEAP32[$81>>2] = $$03752$i;
       HEAP32[$$025$i53$i>>2] = $70;
       $82 = HEAP32[$1>>2]|0;
       $83 = HEAP32[$82>>2]|0;
       $84 = ($83|0)==(0|0);
       if ($84) {
        $88 = $70;
       } else {
        $85 = $83;
        HEAP32[$1>>2] = $85;
        $$pre$i$i = HEAP32[$$025$i53$i>>2]|0;
        $88 = $$pre$i$i;
       }
       $86 = ((($1)) + 4|0);
       $87 = HEAP32[$86>>2]|0;
       __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($87,$88);
       $89 = ((($1)) + 8|0);
       $90 = HEAP32[$89>>2]|0;
       $91 = (($90) + 1)|0;
       HEAP32[$89>>2] = $91;
       $$014$i = $70;
      }
      $92 = ((($$014$i)) + 24|0);
      $93 = HEAP32[$92>>2]|0;
      $94 = ($93|0)==($2|0);
      if (!($94)) {
       HEAP32[$92>>2] = $2;
       $95 = HEAP32[$36>>2]|0;HEAP32[$36>>2] = (($95+1)|0);
       $96 = ($93|0)==(0|0);
       if (!($96)) {
        $97 = ((($93)) + 8|0);
        $98 = HEAP32[$97>>2]|0;HEAP32[$97>>2] = (($98-1)|0);
        $99 = ($98|0)==(1);
        if ($99) {
         __THREW__ = 0;
         invoke_viii(3262,($93|0),1,1);
         $100 = __THREW__; __THREW__ = 0;
         $101 = $100&1;
         if ($101) {
          label = 43;
          break;
         }
        }
       }
      }
      $102 = ((($$014$i)) + 28|0);
      HEAP32[$102>>2] = $38;
      $103 = HEAP32[$36>>2]|0;HEAP32[$36>>2] = (($103-1)|0);
      $104 = ($103|0)==(1);
      if ($104) {
       __THREW__ = 0;
       invoke_viii(3262,($2|0),1,1);
       $105 = __THREW__; __THREW__ = 0;
       $106 = $105&1;
       if ($106) {
        $114 = ___cxa_find_matching_catch_2()|0;
        $115 = tempRet0;
        $$0 = $115;$$035 = $114;
        break;
       }
      }
      $107 = HEAP32[$36>>2]|0;HEAP32[$36>>2] = (($107-1)|0);
      $108 = ($107|0)==(1);
      if ($108) {
       __ZNK3osg10Referenced24signalObserversAndDeleteEbb($2,1,1);
      }
      __ZN3osg14StateAttribute9addParentEPNS_8StateSetE($2,$0);
      $109 = ((($2)) + 48|0);
      $110 = HEAP32[$109>>2]|0;
      $111 = ($110|0)==(0|0);
      $112 = ((($2)) + 52|0);
      $113 = HEAP32[$112>>2]|0;
      $not$102 = ($113|0)!=(0|0);
      $$42 = $not$102&1;
      if ($111) {
       $$394 = $$42;
       break L29;
      } else {
       $$397 = $$42;$$496 = 1;
       label = 55;
       break L29;
      }
     }
    }
   } while(0);
   if ((label|0) == 43) {
    $116 = ___cxa_find_matching_catch_2()|0;
    $117 = tempRet0;
    $118 = HEAP32[$36>>2]|0;HEAP32[$36>>2] = (($118-1)|0);
    $119 = ($118|0)==(1);
    if ($119) {
     __THREW__ = 0;
     invoke_viii(3262,($2|0),1,1);
     $120 = __THREW__; __THREW__ = 0;
     $121 = $120&1;
     if ($121) {
      $195 = ___cxa_find_matching_catch_3(0|0)|0;
      $196 = tempRet0;
      ___clang_call_terminate($195);
      // unreachable;
     } else {
      $$0 = $117;$$035 = $116;
     }
    } else {
     $$0 = $117;$$035 = $116;
    }
   }
   $122 = HEAP32[$36>>2]|0;HEAP32[$36>>2] = (($122-1)|0);
   $123 = ($122|0)==(1);
   if (!($123)) {
    ___resumeException($$035|0);
    // unreachable;
   }
   __THREW__ = 0;
   invoke_viii(3262,($2|0),1,1);
   $124 = __THREW__; __THREW__ = 0;
   $125 = $124&1;
   if ($125) {
    $195 = ___cxa_find_matching_catch_3(0|0)|0;
    $196 = tempRet0;
    ___clang_call_terminate($195);
    // unreachable;
   } else {
    ___resumeException($$035|0);
    // unreachable;
   }
  }
 } while(0);
 if ((label|0) == 55) {
  $154 = ((($0)) + 148|0);
  $155 = HEAP32[$154>>2]|0;
  $156 = (($155) + ($$496))|0;
  $157 = ((($0)) + 144|0);
  $158 = HEAP32[$157>>2]|0;
  $159 = ($158|0)==(0|0);
  if ($159) {
   $160 = ((($0)) + 32|0);
   $161 = HEAP32[$160>>2]|0;
   $162 = ((($0)) + 36|0);
   $163 = HEAP32[$162>>2]|0;
   $164 = ($161|0)==($163|0);
   if (!($164)) {
    $not$$i43 = ($155|0)!=(0);
    $$$i44 = $not$$i43 << 31 >> 31;
    $not$17$i45 = ($156|0)!=(0);
    $165 = $not$17$i45&1;
    $$1$i46 = (($165) + ($$$i44))|0;
    $166 = ($$1$i46|0)==(0);
    if (!($166)) {
     $$sroa$013$018$i47 = $161;
     while(1) {
      $167 = HEAP32[$$sroa$013$018$i47>>2]|0;
      $168 = ((($167)) + 88|0);
      $169 = HEAP32[$168>>2]|0;
      $170 = (($169) + ($$1$i46))|0;
      __ZN3osg4Node38setNumChildrenRequiringUpdateTraversalEj($167,$170);
      $171 = ((($$sroa$013$018$i47)) + 4|0);
      $172 = HEAP32[$162>>2]|0;
      $173 = ($171|0)==($172|0);
      if ($173) {
       break;
      } else {
       $$sroa$013$018$i47 = $171;
      }
     }
    }
   }
  }
  HEAP32[$154>>2] = $156;
  $$394 = $$397;
 }
 $174 = ($$394|0)==(0);
 if ($174) {
  return;
 }
 $175 = ((($0)) + 156|0);
 $176 = HEAP32[$175>>2]|0;
 $177 = (($176) + ($$394))|0;
 $178 = ((($0)) + 152|0);
 $179 = HEAP32[$178>>2]|0;
 $180 = ($179|0)==(0|0);
 if ($180) {
  $181 = ((($0)) + 32|0);
  $182 = HEAP32[$181>>2]|0;
  $183 = ((($0)) + 36|0);
  $184 = HEAP32[$183>>2]|0;
  $185 = ($182|0)==($184|0);
  if (!($185)) {
   $not$$i = ($176|0)!=(0);
   $$$i = $not$$i << 31 >> 31;
   $not$17$i = ($177|0)!=(0);
   $186 = $not$17$i&1;
   $$1$i = (($186) + ($$$i))|0;
   $187 = ($$1$i|0)==(0);
   if (!($187)) {
    $$sroa$013$018$i = $182;
    while(1) {
     $188 = HEAP32[$$sroa$013$018$i>>2]|0;
     $189 = ((($188)) + 96|0);
     $190 = HEAP32[$189>>2]|0;
     $191 = (($190) + ($$1$i))|0;
     __ZN3osg4Node37setNumChildrenRequiringEventTraversalEj($188,$191);
     $192 = ((($$sroa$013$018$i)) + 4|0);
     $193 = HEAP32[$183>>2]|0;
     $194 = ($192|0)==($193|0);
     if ($194) {
      break;
     } else {
      $$sroa$013$018$i = $192;
     }
    }
   }
  }
 }
 HEAP32[$175>>2] = $177;
 return;
}
function __ZN3osg8StateSet12setAttributeEPNS_14StateAttributeEj($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp + 8|0;
 $4 = sp + 4|0;
 $5 = sp;
 $6 = ($1|0)==(0|0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = HEAP32[$1>>2]|0;
 $8 = ((($7)) + 156|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (FUNCTION_TABLE_ii[$9 & 8191]($1)|0);
 if (!($10)) {
  $11 = ((($0)) + 56|0);
  __ZN3osg8StateSet12setAttributeERNSt3__23mapINS1_4pairINS_14StateAttribute4TypeEjEENS3_INS_7ref_ptrIS4_EEjEENS1_4lessIS6_EENS1_9allocatorINS3_IKS6_S9_EEEEEEPS4_j($0,$11,$1,$2);
  STACKTOP = sp;return;
 }
 $12 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
 do {
  if ($12) {
   $13 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
   $14 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($13,151833,28)|0);
   $15 = HEAP32[$1>>2]|0;
   $16 = ((($15)) + 28|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (FUNCTION_TABLE_ii[$17 & 8191]($1)|0);
   $19 = (_strlen($18)|0);
   $20 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($14,$18,$19)|0);
   $21 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($20,152026,37)|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = ((($22)) + -12|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = (($21) + ($24)|0);
   __ZNKSt3__28ios_base6getlocEv($5,$25);
   __THREW__ = 0;
   $26 = (invoke_iii(3255,($5|0),(215188|0))|0);
   $27 = __THREW__; __THREW__ = 0;
   $28 = $27&1;
   if (!($28)) {
    $29 = HEAP32[$26>>2]|0;
    $30 = ((($29)) + 28|0);
    $31 = HEAP32[$30>>2]|0;
    __THREW__ = 0;
    $32 = (invoke_iii($31|0,($26|0),10)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     __ZNSt3__26localeD2Ev($5);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($21,$32)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($21)|0);
     break;
    }
   }
   $35 = ___cxa_find_matching_catch_2()|0;
   $36 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($5|0));
   $37 = __THREW__; __THREW__ = 0;
   $38 = $37&1;
   if ($38) {
    $39 = ___cxa_find_matching_catch_3(0|0)|0;
    $40 = tempRet0;
    ___clang_call_terminate($39);
    // unreachable;
   } else {
    ___resumeException($35|0);
    // unreachable;
   }
  }
 } while(0);
 $41 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
 do {
  if ($41) {
   $42 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
   $43 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($42,152064,65)|0);
   $44 = HEAP32[$43>>2]|0;
   $45 = ((($44)) + -12|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = (($43) + ($46)|0);
   __ZNKSt3__28ios_base6getlocEv($4,$47);
   __THREW__ = 0;
   $48 = (invoke_iii(3255,($4|0),(215188|0))|0);
   $49 = __THREW__; __THREW__ = 0;
   $50 = $49&1;
   if (!($50)) {
    $51 = HEAP32[$48>>2]|0;
    $52 = ((($51)) + 28|0);
    $53 = HEAP32[$52>>2]|0;
    __THREW__ = 0;
    $54 = (invoke_iii($53|0,($48|0),10)|0);
    $55 = __THREW__; __THREW__ = 0;
    $56 = $55&1;
    if (!($56)) {
     __ZNSt3__26localeD2Ev($4);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($43,$54)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($43)|0);
     break;
    }
   }
   $57 = ___cxa_find_matching_catch_2()|0;
   $58 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($4|0));
   $59 = __THREW__; __THREW__ = 0;
   $60 = $59&1;
   if ($60) {
    $61 = ___cxa_find_matching_catch_3(0|0)|0;
    $62 = tempRet0;
    ___clang_call_terminate($61);
    // unreachable;
   } else {
    ___resumeException($57|0);
    // unreachable;
   }
  }
 } while(0);
 $63 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
 do {
  if ($63) {
   $64 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
   $65 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($64,151965,60)|0);
   $66 = HEAP32[$65>>2]|0;
   $67 = ((($66)) + -12|0);
   $68 = HEAP32[$67>>2]|0;
   $69 = (($65) + ($68)|0);
   __ZNKSt3__28ios_base6getlocEv($3,$69);
   __THREW__ = 0;
   $70 = (invoke_iii(3255,($3|0),(215188|0))|0);
   $71 = __THREW__; __THREW__ = 0;
   $72 = $71&1;
   if (!($72)) {
    $73 = HEAP32[$70>>2]|0;
    $74 = ((($73)) + 28|0);
    $75 = HEAP32[$74>>2]|0;
    __THREW__ = 0;
    $76 = (invoke_iii($75|0,($70|0),10)|0);
    $77 = __THREW__; __THREW__ = 0;
    $78 = $77&1;
    if (!($78)) {
     __ZNSt3__26localeD2Ev($3);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($65,$76)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($65)|0);
     break;
    }
   }
   $79 = ___cxa_find_matching_catch_2()|0;
   $80 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($3|0));
   $81 = __THREW__; __THREW__ = 0;
   $82 = $81&1;
   if ($82) {
    $83 = ___cxa_find_matching_catch_3(0|0)|0;
    $84 = tempRet0;
    ___clang_call_terminate($83);
    // unreachable;
   } else {
    ___resumeException($79|0);
    // unreachable;
   }
  }
 } while(0);
 __ZN3osg8StateSet19setTextureAttributeEjPNS_14StateAttributeEj($0,0,$1,$2);
 STACKTOP = sp;return;
}
function __ZN3osg8StateSet15removeAttributeENS_14StateAttribute4TypeEj($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$$i = 0, $$$i2 = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$ph$lcssa$i$i$i = 0, $$0$ph14$i$i$i = 0, $$07$ph13$i$i$i = 0, $$0711$i$i$i = 0, $$1$i = 0, $$1$i4 = 0, $$pre = 0, $$pre$pre = 0, $$pre30 = 0, $$pre30$pre = 0, $$sroa$013$018$i = 0, $$sroa$013$018$i5 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $not$$i = 0, $not$$i1 = 0, $not$17$i = 0, $not$17$i3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = ((($0)) + 56|0);
 $5 = ((($0)) + 60|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  STACKTOP = sp;return;
 } else {
  $$0$ph14$i$i$i = $5;$$07$ph13$i$i$i = $6;
 }
 L3: while(1) {
  $$0711$i$i$i = $$07$ph13$i$i$i;
  while(1) {
   $8 = ((($$0711$i$i$i)) + 16|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = ($9|0)<($1|0);
   if (!($10)) {
    $11 = ($9|0)>($1|0);
    if ($11) {
     break;
    }
    $12 = ((($$0711$i$i$i)) + 20|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = ($13>>>0)<($2>>>0);
    if (!($14)) {
     break;
    }
   }
   $17 = ((($$0711$i$i$i)) + 4|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = ($18|0)==(0|0);
   if ($19) {
    $$0$ph$lcssa$i$i$i = $$0$ph14$i$i$i;
    break L3;
   } else {
    $$0711$i$i$i = $18;
   }
  }
  $15 = HEAP32[$$0711$i$i$i>>2]|0;
  $16 = ($15|0)==(0|0);
  if ($16) {
   $$0$ph$lcssa$i$i$i = $$0711$i$i$i;
   break;
  } else {
   $$0$ph14$i$i$i = $$0711$i$i$i;$$07$ph13$i$i$i = $15;
  }
 }
 $20 = ($$0$ph$lcssa$i$i$i|0)==($5|0);
 if ($20) {
  STACKTOP = sp;return;
 }
 $21 = ((($$0$ph$lcssa$i$i$i)) + 16|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)>($1|0);
 if ($23) {
  STACKTOP = sp;return;
 }
 $24 = ($22|0)<($1|0);
 if (!($24)) {
  $25 = ((($$0$ph$lcssa$i$i$i)) + 20|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = ($26>>>0)>($2>>>0);
  if ($27) {
   STACKTOP = sp;return;
  }
 }
 $28 = ((($$0$ph$lcssa$i$i$i)) + 24|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ((($29)) + 48|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ($31|0)==(0|0);
 if ($32) {
  $54 = $29;
 } else {
  $33 = ((($0)) + 148|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = (($34) + -1)|0;
  $36 = ((($0)) + 144|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = ($37|0)==(0|0);
  if ($38) {
   $39 = ((($0)) + 32|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = ((($0)) + 36|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = ($40|0)==($42|0);
   if ($43) {
    $$pre = $29;
   } else {
    $not$$i1 = ($34|0)!=(0);
    $$$i2 = $not$$i1 << 31 >> 31;
    $not$17$i3 = ($35|0)!=(0);
    $44 = $not$17$i3&1;
    $$1$i4 = (($44) + ($$$i2))|0;
    $45 = ($$1$i4|0)==(0);
    if ($45) {
     $$pre = $29;
    } else {
     $$sroa$013$018$i5 = $40;
     while(1) {
      $46 = HEAP32[$$sroa$013$018$i5>>2]|0;
      $47 = ((($46)) + 88|0);
      $48 = HEAP32[$47>>2]|0;
      $49 = (($48) + ($$1$i4))|0;
      __ZN3osg4Node38setNumChildrenRequiringUpdateTraversalEj($46,$49);
      $50 = ((($$sroa$013$018$i5)) + 4|0);
      $51 = HEAP32[$41>>2]|0;
      $52 = ($50|0)==($51|0);
      if ($52) {
       break;
      } else {
       $$sroa$013$018$i5 = $50;
      }
     }
     $$pre$pre = HEAP32[$28>>2]|0;
     $$pre = $$pre$pre;
    }
   }
  } else {
   $$pre = $29;
  }
  HEAP32[$33>>2] = $35;
  $54 = $$pre;
 }
 $53 = ((($54)) + 52|0);
 $55 = HEAP32[$53>>2]|0;
 $56 = ($55|0)==(0|0);
 if ($56) {
  $77 = $54;
 } else {
  $57 = ((($0)) + 156|0);
  $58 = HEAP32[$57>>2]|0;
  $59 = (($58) + -1)|0;
  $60 = ((($0)) + 152|0);
  $61 = HEAP32[$60>>2]|0;
  $62 = ($61|0)==(0|0);
  if ($62) {
   $63 = ((($0)) + 32|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = ((($0)) + 36|0);
   $66 = HEAP32[$65>>2]|0;
   $67 = ($64|0)==($66|0);
   if ($67) {
    $$pre30 = $54;
   } else {
    $not$$i = ($58|0)!=(0);
    $$$i = $not$$i << 31 >> 31;
    $not$17$i = ($59|0)!=(0);
    $68 = $not$17$i&1;
    $$1$i = (($68) + ($$$i))|0;
    $69 = ($$1$i|0)==(0);
    if ($69) {
     $$pre30 = $54;
    } else {
     $$sroa$013$018$i = $64;
     while(1) {
      $70 = HEAP32[$$sroa$013$018$i>>2]|0;
      $71 = ((($70)) + 96|0);
      $72 = HEAP32[$71>>2]|0;
      $73 = (($72) + ($$1$i))|0;
      __ZN3osg4Node37setNumChildrenRequiringEventTraversalEj($70,$73);
      $74 = ((($$sroa$013$018$i)) + 4|0);
      $75 = HEAP32[$65>>2]|0;
      $76 = ($74|0)==($75|0);
      if ($76) {
       break;
      } else {
       $$sroa$013$018$i = $74;
      }
     }
     $$pre30$pre = HEAP32[$28>>2]|0;
     $$pre30 = $$pre30$pre;
    }
   }
  } else {
   $$pre30 = $54;
  }
  HEAP32[$57>>2] = $59;
  $77 = $$pre30;
 }
 __ZN3osg14StateAttribute12removeParentEPNS_8StateSetE($77,$0);
 $78 = HEAP32[$28>>2]|0;
 HEAP32[$3>>2] = (66344);
 $79 = ((($3)) + 4|0);
 HEAP32[$79>>2] = $0;
 $80 = ((($3)) + 8|0);
 HEAP32[$80>>2] = 8;
 $81 = ((($3)) + 12|0);
 HEAP32[$81>>2] = 0;
 $82 = HEAP32[$78>>2]|0;
 $83 = ((($82)) + 164|0);
 $84 = HEAP32[$83>>2]|0;
 __THREW__ = 0;
 (invoke_iii($84|0,($78|0),($3|0))|0);
 $85 = __THREW__; __THREW__ = 0;
 $86 = $85&1;
 if ($86) {
  $87 = ___cxa_find_matching_catch_2()|0;
  $88 = tempRet0;
  ___resumeException($87|0);
  // unreachable;
 }
 $89 = ((($$0$ph$lcssa$i$i$i)) + 4|0);
 $90 = HEAP32[$89>>2]|0;
 $91 = ($90|0)==(0|0);
 if ($91) {
  $92 = ((($$0$ph$lcssa$i$i$i)) + 8|0);
  $93 = HEAP32[$92>>2]|0;
  $94 = HEAP32[$93>>2]|0;
  $95 = ($94|0)==($$0$ph$lcssa$i$i$i|0);
  if ($95) {
   $$0$i$i$i$i = $93;
  } else {
   $99 = $92;
   while(1) {
    $98 = HEAP32[$99>>2]|0;
    $100 = ((($98)) + 8|0);
    $101 = HEAP32[$100>>2]|0;
    $102 = HEAP32[$101>>2]|0;
    $103 = ($102|0)==($98|0);
    if ($103) {
     $$0$i$i$i$i = $101;
     break;
    } else {
     $99 = $100;
    }
   }
  }
 } else {
  $$0$i$i$i$i$i = $90;
  while(1) {
   $96 = HEAP32[$$0$i$i$i$i$i>>2]|0;
   $97 = ($96|0)==(0|0);
   if ($97) {
    break;
   } else {
    $$0$i$i$i$i$i = $96;
   }
  }
  $$0$i$i$i$i = $$0$i$i$i$i$i;
 }
 $104 = HEAP32[$4>>2]|0;
 $105 = ($104|0)==($$0$ph$lcssa$i$i$i|0);
 if ($105) {
  $106 = $$0$i$i$i$i;
  HEAP32[$4>>2] = $106;
 }
 $107 = ((($0)) + 64|0);
 $108 = HEAP32[$107>>2]|0;
 $109 = (($108) + -1)|0;
 HEAP32[$107>>2] = $109;
 $110 = ((($0)) + 60|0);
 $111 = HEAP32[$110>>2]|0;
 __ZNSt3__213__tree_removeIPNS_16__tree_node_baseIPvEEEEvT_S5_($111,$$0$ph$lcssa$i$i$i);
 $112 = HEAP32[$28>>2]|0;
 $113 = ($112|0)==(0|0);
 if (!($113)) {
  $114 = ((($112)) + 8|0);
  $115 = HEAP32[$114>>2]|0;HEAP32[$114>>2] = (($115-1)|0);
  $116 = ($115|0)==(1);
  if ($116) {
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($112,1,1);
  }
 }
 __ZdlPv($$0$ph$lcssa$i$i$i);
 STACKTOP = sp;return;
}
function __ZN3osg8StateSet27setTextureAttributeAndModesEjPNS_14StateAttributeEj($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $4 = sp + 24|0;
 $5 = sp + 20|0;
 $6 = sp + 16|0;
 $7 = sp;
 $8 = ($2|0)==(0|0);
 if ($8) {
  STACKTOP = sp;return;
 }
 $9 = HEAP32[$2>>2]|0;
 $10 = ((($9)) + 156|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (FUNCTION_TABLE_ii[$11 & 8191]($2)|0);
 if ($12) {
  $13 = $3 & 8;
  $14 = ($13|0)==(0);
  if (!($14)) {
   $15 = HEAP32[$2>>2]|0;
   $16 = ((($15)) + 148|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (FUNCTION_TABLE_ii[$17 & 8191]($2)|0);
   __ZN3osg8StateSet22removeTextureAttributeEjNS_14StateAttribute4TypeE($0,$1,$18);
   STACKTOP = sp;return;
  }
  $19 = ((($0)) + 80|0);
  $20 = ((($0)) + 84|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = HEAP32[$19>>2]|0;
  $23 = (($21) - ($22))|0;
  $24 = (($23|0) / 12)&-1;
  $25 = ($24>>>0)>($1>>>0);
  do {
   if (!($25)) {
    $26 = (($1) + 1)|0;
    $27 = ($26>>>0)>($24>>>0);
    $28 = $22;
    $29 = $21;
    if ($27) {
     $30 = (($26) - ($24))|0;
     __ZNSt3__26vectorINS_3mapINS_4pairIN3osg14StateAttribute4TypeEjEENS2_INS3_7ref_ptrIS4_EEjEENS_4lessIS6_EENS_9allocatorINS2_IKS6_S9_EEEEEENSC_ISG_EEE8__appendEj($19,$30);
     break;
    }
    $31 = ($26>>>0)<($24>>>0);
    if ($31) {
     $32 = (($28) + (($26*12)|0)|0);
     $33 = ($29|0)==($32|0);
     if (!($33)) {
      $35 = $29;
      while(1) {
       $34 = ((($35)) + -12|0);
       HEAP32[$20>>2] = $34;
       $36 = ((($35)) + -8|0);
       $37 = HEAP32[$36>>2]|0;
       __ZNSt3__26__treeINS_12__value_typeINS_4pairIN3osg14StateAttribute4TypeEjEENS2_INS3_7ref_ptrIS4_EEjEEEENS_19__map_value_compareIS6_SA_NS_4lessIS6_EELb1EEENS_9allocatorISA_EEE7destroyEPNS_11__tree_nodeISA_PvEE($34,$37);
       $38 = HEAP32[$20>>2]|0;
       $39 = ($38|0)==($32|0);
       if ($39) {
        break;
       } else {
        $35 = $38;
       }
      }
     }
    }
   }
  } while(0);
  $40 = HEAP32[$19>>2]|0;
  $41 = (($40) + (($1*12)|0)|0);
  __ZN3osg8StateSet12setAttributeERNSt3__23mapINS1_4pairINS_14StateAttribute4TypeEjEENS3_INS_7ref_ptrIS4_EEjEENS1_4lessIS6_EENS1_9allocatorINS3_IKS6_S9_EEEEEEPS4_j($0,$41,$2,$3);
  HEAP32[$7>>2] = (66344);
  $42 = ((($7)) + 4|0);
  HEAP32[$42>>2] = $0;
  $43 = ((($7)) + 8|0);
  HEAP32[$43>>2] = $3;
  $44 = ((($7)) + 12|0);
  HEAP32[$44>>2] = $1;
  $45 = HEAP32[$2>>2]|0;
  $46 = ((($45)) + 164|0);
  $47 = HEAP32[$46>>2]|0;
  __THREW__ = 0;
  (invoke_iii($47|0,($2|0),($7|0))|0);
  $48 = __THREW__; __THREW__ = 0;
  $49 = $48&1;
  if ($49) {
   $50 = ___cxa_find_matching_catch_2()|0;
   $51 = tempRet0;
   ___resumeException($50|0);
   // unreachable;
  }
  STACKTOP = sp;return;
 }
 $52 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
 do {
  if ($52) {
   $53 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
   $54 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($53,152251,32)|0);
   $55 = HEAP32[$2>>2]|0;
   $56 = ((($55)) + 28|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = (FUNCTION_TABLE_ii[$57 & 8191]($2)|0);
   $59 = (_strlen($58)|0);
   $60 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($54,$58,$59)|0);
   $61 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($60,152284,58)|0);
   $62 = HEAP32[$61>>2]|0;
   $63 = ((($62)) + -12|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = (($61) + ($64)|0);
   __ZNKSt3__28ios_base6getlocEv($6,$65);
   __THREW__ = 0;
   $66 = (invoke_iii(3255,($6|0),(215188|0))|0);
   $67 = __THREW__; __THREW__ = 0;
   $68 = $67&1;
   if (!($68)) {
    $69 = HEAP32[$66>>2]|0;
    $70 = ((($69)) + 28|0);
    $71 = HEAP32[$70>>2]|0;
    __THREW__ = 0;
    $72 = (invoke_iii($71|0,($66|0),10)|0);
    $73 = __THREW__; __THREW__ = 0;
    $74 = $73&1;
    if (!($74)) {
     __ZNSt3__26localeD2Ev($6);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($61,$72)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($61)|0);
     break;
    }
   }
   $75 = ___cxa_find_matching_catch_2()|0;
   $76 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($6|0));
   $77 = __THREW__; __THREW__ = 0;
   $78 = $77&1;
   if ($78) {
    $79 = ___cxa_find_matching_catch_3(0|0)|0;
    $80 = tempRet0;
    ___clang_call_terminate($79);
    // unreachable;
   } else {
    ___resumeException($75|0);
    // unreachable;
   }
  }
 } while(0);
 $81 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
 do {
  if ($81) {
   $82 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
   $83 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($82,152343,59)|0);
   $84 = HEAP32[$83>>2]|0;
   $85 = ((($84)) + -12|0);
   $86 = HEAP32[$85>>2]|0;
   $87 = (($83) + ($86)|0);
   __ZNKSt3__28ios_base6getlocEv($5,$87);
   __THREW__ = 0;
   $88 = (invoke_iii(3255,($5|0),(215188|0))|0);
   $89 = __THREW__; __THREW__ = 0;
   $90 = $89&1;
   if (!($90)) {
    $91 = HEAP32[$88>>2]|0;
    $92 = ((($91)) + 28|0);
    $93 = HEAP32[$92>>2]|0;
    __THREW__ = 0;
    $94 = (invoke_iii($93|0,($88|0),10)|0);
    $95 = __THREW__; __THREW__ = 0;
    $96 = $95&1;
    if (!($96)) {
     __ZNSt3__26localeD2Ev($5);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($83,$94)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($83)|0);
     break;
    }
   }
   $97 = ___cxa_find_matching_catch_2()|0;
   $98 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($5|0));
   $99 = __THREW__; __THREW__ = 0;
   $100 = $99&1;
   if ($100) {
    $101 = ___cxa_find_matching_catch_3(0|0)|0;
    $102 = tempRet0;
    ___clang_call_terminate($101);
    // unreachable;
   } else {
    ___resumeException($97|0);
    // unreachable;
   }
  }
 } while(0);
 $103 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
 do {
  if ($103) {
   $104 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
   $105 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($104,151965,60)|0);
   $106 = HEAP32[$105>>2]|0;
   $107 = ((($106)) + -12|0);
   $108 = HEAP32[$107>>2]|0;
   $109 = (($105) + ($108)|0);
   __ZNKSt3__28ios_base6getlocEv($4,$109);
   __THREW__ = 0;
   $110 = (invoke_iii(3255,($4|0),(215188|0))|0);
   $111 = __THREW__; __THREW__ = 0;
   $112 = $111&1;
   if (!($112)) {
    $113 = HEAP32[$110>>2]|0;
    $114 = ((($113)) + 28|0);
    $115 = HEAP32[$114>>2]|0;
    __THREW__ = 0;
    $116 = (invoke_iii($115|0,($110|0),10)|0);
    $117 = __THREW__; __THREW__ = 0;
    $118 = $117&1;
    if (!($118)) {
     __ZNSt3__26localeD2Ev($4);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($105,$116)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($105)|0);
     break;
    }
   }
   $119 = ___cxa_find_matching_catch_2()|0;
   $120 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($4|0));
   $121 = __THREW__; __THREW__ = 0;
   $122 = $121&1;
   if ($122) {
    $123 = ___cxa_find_matching_catch_3(0|0)|0;
    $124 = tempRet0;
    ___clang_call_terminate($123);
    // unreachable;
   } else {
    ___resumeException($119|0);
    // unreachable;
   }
  }
 } while(0);
 __ZN3osg8StateSet20setAttributeAndModesEPNS_14StateAttributeEj($0,$2,$3);
 STACKTOP = sp;return;
}
function __ZN3osg8StateSet22removeTextureAttributeEjNS_14StateAttribute4TypeE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$$i = 0, $$$i9 = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$ph$lcssa$i$i$i = 0, $$0$ph14$i$i$i = 0, $$07$ph13$i$i$i = 0, $$0711$i$i$i = 0, $$1$i = 0, $$1$i11 = 0, $$pre = 0, $$pre$pre = 0, $$pre38 = 0, $$pre38$pre = 0, $$sroa$013$018$i = 0, $$sroa$013$018$i12 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $not$$i = 0, $not$$i8 = 0, $not$17$i = 0, $not$17$i10 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = ((($0)) + 80|0);
 $5 = ((($0)) + 84|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$4>>2]|0;
 $8 = (($6) - ($7))|0;
 $9 = (($8|0) / 12)&-1;
 $10 = ($9>>>0)>($1>>>0);
 $11 = $7;
 if (!($10)) {
  STACKTOP = sp;return;
 }
 $12 = (($11) + (($1*12)|0)|0);
 $13 = (((($11) + (($1*12)|0)|0)) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(0|0);
 if ($15) {
  STACKTOP = sp;return;
 } else {
  $$0$ph14$i$i$i = $13;$$07$ph13$i$i$i = $14;
 }
 L6: while(1) {
  $$0711$i$i$i = $$07$ph13$i$i$i;
  while(1) {
   $16 = ((($$0711$i$i$i)) + 16|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = ($17|0)<($2|0);
   if (!($18)) {
    break;
   }
   $21 = ((($$0711$i$i$i)) + 4|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = ($22|0)==(0|0);
   if ($23) {
    $$0$ph$lcssa$i$i$i = $$0$ph14$i$i$i;
    break L6;
   } else {
    $$0711$i$i$i = $22;
   }
  }
  $19 = HEAP32[$$0711$i$i$i>>2]|0;
  $20 = ($19|0)==(0|0);
  if ($20) {
   $$0$ph$lcssa$i$i$i = $$0711$i$i$i;
   break;
  } else {
   $$0$ph14$i$i$i = $$0711$i$i$i;$$07$ph13$i$i$i = $19;
  }
 }
 $24 = ($$0$ph$lcssa$i$i$i|0)==($13|0);
 if ($24) {
  STACKTOP = sp;return;
 }
 $25 = ((($$0$ph$lcssa$i$i$i)) + 16|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($26|0)>($2|0);
 if ($27) {
  STACKTOP = sp;return;
 }
 $28 = ($26|0)<($2|0);
 if (!($28)) {
  $29 = ((($$0$ph$lcssa$i$i$i)) + 20|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = ($30|0)==(0);
  if (!($31)) {
   STACKTOP = sp;return;
  }
 }
 $32 = ((($0)) + 68|0);
 $33 = ((($0)) + 72|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = HEAP32[$32>>2]|0;
 $36 = (($34) - ($35))|0;
 $37 = (($36|0) / 12)&-1;
 $38 = ($37>>>0)>($1>>>0);
 $39 = ((($$0$ph$lcssa$i$i$i)) + 24|0);
 do {
  if ($38) {
   $40 = HEAP32[$39>>2]|0;
   HEAP32[$3>>2] = (66344);
   $41 = ((($3)) + 4|0);
   HEAP32[$41>>2] = $0;
   $42 = ((($3)) + 8|0);
   HEAP32[$42>>2] = 8;
   $43 = ((($3)) + 12|0);
   HEAP32[$43>>2] = $1;
   $44 = HEAP32[$40>>2]|0;
   $45 = ((($44)) + 164|0);
   $46 = HEAP32[$45>>2]|0;
   __THREW__ = 0;
   (invoke_iii($46|0,($40|0),($3|0))|0);
   $47 = __THREW__; __THREW__ = 0;
   $48 = $47&1;
   if ($48) {
    $49 = ___cxa_find_matching_catch_2()|0;
    $50 = tempRet0;
    ___resumeException($49|0);
    // unreachable;
   } else {
    break;
   }
  }
 } while(0);
 $51 = HEAP32[$39>>2]|0;
 $52 = ((($51)) + 48|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = ($53|0)==(0|0);
 if ($54) {
  $76 = $51;
 } else {
  $55 = ((($0)) + 148|0);
  $56 = HEAP32[$55>>2]|0;
  $57 = (($56) + -1)|0;
  $58 = ((($0)) + 144|0);
  $59 = HEAP32[$58>>2]|0;
  $60 = ($59|0)==(0|0);
  if ($60) {
   $61 = ((($0)) + 32|0);
   $62 = HEAP32[$61>>2]|0;
   $63 = ((($0)) + 36|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = ($62|0)==($64|0);
   if ($65) {
    $$pre = $51;
   } else {
    $not$$i8 = ($56|0)!=(0);
    $$$i9 = $not$$i8 << 31 >> 31;
    $not$17$i10 = ($57|0)!=(0);
    $66 = $not$17$i10&1;
    $$1$i11 = (($66) + ($$$i9))|0;
    $67 = ($$1$i11|0)==(0);
    if ($67) {
     $$pre = $51;
    } else {
     $$sroa$013$018$i12 = $62;
     while(1) {
      $68 = HEAP32[$$sroa$013$018$i12>>2]|0;
      $69 = ((($68)) + 88|0);
      $70 = HEAP32[$69>>2]|0;
      $71 = (($70) + ($$1$i11))|0;
      __ZN3osg4Node38setNumChildrenRequiringUpdateTraversalEj($68,$71);
      $72 = ((($$sroa$013$018$i12)) + 4|0);
      $73 = HEAP32[$63>>2]|0;
      $74 = ($72|0)==($73|0);
      if ($74) {
       break;
      } else {
       $$sroa$013$018$i12 = $72;
      }
     }
     $$pre$pre = HEAP32[$39>>2]|0;
     $$pre = $$pre$pre;
    }
   }
  } else {
   $$pre = $51;
  }
  HEAP32[$55>>2] = $57;
  $76 = $$pre;
 }
 $75 = ((($76)) + 52|0);
 $77 = HEAP32[$75>>2]|0;
 $78 = ($77|0)==(0|0);
 if ($78) {
  $99 = $76;
 } else {
  $79 = ((($0)) + 156|0);
  $80 = HEAP32[$79>>2]|0;
  $81 = (($80) + -1)|0;
  $82 = ((($0)) + 152|0);
  $83 = HEAP32[$82>>2]|0;
  $84 = ($83|0)==(0|0);
  if ($84) {
   $85 = ((($0)) + 32|0);
   $86 = HEAP32[$85>>2]|0;
   $87 = ((($0)) + 36|0);
   $88 = HEAP32[$87>>2]|0;
   $89 = ($86|0)==($88|0);
   if ($89) {
    $$pre38 = $76;
   } else {
    $not$$i = ($80|0)!=(0);
    $$$i = $not$$i << 31 >> 31;
    $not$17$i = ($81|0)!=(0);
    $90 = $not$17$i&1;
    $$1$i = (($90) + ($$$i))|0;
    $91 = ($$1$i|0)==(0);
    if ($91) {
     $$pre38 = $76;
    } else {
     $$sroa$013$018$i = $86;
     while(1) {
      $92 = HEAP32[$$sroa$013$018$i>>2]|0;
      $93 = ((($92)) + 96|0);
      $94 = HEAP32[$93>>2]|0;
      $95 = (($94) + ($$1$i))|0;
      __ZN3osg4Node37setNumChildrenRequiringEventTraversalEj($92,$95);
      $96 = ((($$sroa$013$018$i)) + 4|0);
      $97 = HEAP32[$87>>2]|0;
      $98 = ($96|0)==($97|0);
      if ($98) {
       break;
      } else {
       $$sroa$013$018$i = $96;
      }
     }
     $$pre38$pre = HEAP32[$39>>2]|0;
     $$pre38 = $$pre38$pre;
    }
   }
  } else {
   $$pre38 = $76;
  }
  HEAP32[$79>>2] = $81;
  $99 = $$pre38;
 }
 __ZN3osg14StateAttribute12removeParentEPNS_8StateSetE($99,$0);
 $100 = ((($$0$ph$lcssa$i$i$i)) + 4|0);
 $101 = HEAP32[$100>>2]|0;
 $102 = ($101|0)==(0|0);
 if ($102) {
  $103 = ((($$0$ph$lcssa$i$i$i)) + 8|0);
  $104 = HEAP32[$103>>2]|0;
  $105 = HEAP32[$104>>2]|0;
  $106 = ($105|0)==($$0$ph$lcssa$i$i$i|0);
  if ($106) {
   $$0$i$i$i$i = $104;
  } else {
   $110 = $103;
   while(1) {
    $109 = HEAP32[$110>>2]|0;
    $111 = ((($109)) + 8|0);
    $112 = HEAP32[$111>>2]|0;
    $113 = HEAP32[$112>>2]|0;
    $114 = ($113|0)==($109|0);
    if ($114) {
     $$0$i$i$i$i = $112;
     break;
    } else {
     $110 = $111;
    }
   }
  }
 } else {
  $$0$i$i$i$i$i = $101;
  while(1) {
   $107 = HEAP32[$$0$i$i$i$i$i>>2]|0;
   $108 = ($107|0)==(0|0);
   if ($108) {
    break;
   } else {
    $$0$i$i$i$i$i = $107;
   }
  }
  $$0$i$i$i$i = $$0$i$i$i$i$i;
 }
 $115 = HEAP32[$12>>2]|0;
 $116 = ($115|0)==($$0$ph$lcssa$i$i$i|0);
 if ($116) {
  $117 = $$0$i$i$i$i;
  HEAP32[$12>>2] = $117;
 }
 $118 = (((($11) + (($1*12)|0)|0)) + 8|0);
 $119 = HEAP32[$118>>2]|0;
 $120 = (($119) + -1)|0;
 HEAP32[$118>>2] = $120;
 $121 = (((($11) + (($1*12)|0)|0)) + 4|0);
 $122 = HEAP32[$121>>2]|0;
 __ZNSt3__213__tree_removeIPNS_16__tree_node_baseIPvEEEEvT_S5_($122,$$0$ph$lcssa$i$i$i);
 $123 = HEAP32[$39>>2]|0;
 $124 = ($123|0)==(0|0);
 if (!($124)) {
  $125 = ((($123)) + 8|0);
  $126 = HEAP32[$125>>2]|0;HEAP32[$125>>2] = (($126-1)|0);
  $127 = ($126|0)==(1);
  if ($127) {
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($123,1,1);
  }
 }
 __ZdlPv($$0$ph$lcssa$i$i$i);
 STACKTOP = sp;return;
}
function __ZN3osg14StateAttribute9ModeUsageD2Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN23SetAssociateModesHelperD0Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($0);
 return;
}
function __ZN23SetAssociateModesHelper8usesModeEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 __ZN3osg8StateSet7setModeEjj($3,$1,$5);
 return;
}
function __ZN23SetAssociateModesHelper15usesTextureModeEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($0)) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 __ZN3osg8StateSet14setTextureModeEjjj($3,$5,$1,$7);
 return;
}
function __ZN3osg8StateSet14setTextureModeEjjj($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0$ph$lcssa$i$i$i$i = 0, $$0$ph13$i$i$i$i = 0, $$07$ph12$i$i$i$i = 0, $$0710$i$i$i$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $4 = sp + 8|0;
 $5 = sp + 4|0;
 $6 = sp;
 $7 = HEAP8[206088]|0;
 $8 = ($7<<24>>24)==(0);
 do {
  if ($8) {
   $9 = (___cxa_guard_acquire(206088)|0);
   $10 = ($9|0)==(0);
   if (!($10)) {
    __THREW__ = 0;
    invoke_vi(3956,(208692|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     $13 = ___cxa_find_matching_catch_2()|0;
     $14 = tempRet0;
     ___resumeException($13|0);
     // unreachable;
    } else {
     (___cxa_atexit((3957|0),(208692|0),(___dso_handle|0))|0);
     break;
    }
   }
  }
 } while(0);
 $15 = HEAP32[(208696)>>2]|0;
 $16 = ($15|0)==(0|0);
 if (!($16)) {
  $$0$ph13$i$i$i$i = (208696);$$07$ph12$i$i$i$i = $15;
  L9: while(1) {
   $$0710$i$i$i$i = $$07$ph12$i$i$i$i;
   while(1) {
    $17 = ((($$0710$i$i$i$i)) + 16|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = ($18>>>0)<($2>>>0);
    if (!($19)) {
     break;
    }
    $22 = ((($$0710$i$i$i$i)) + 4|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = ($23|0)==(0|0);
    if ($24) {
     $$0$ph$lcssa$i$i$i$i = $$0$ph13$i$i$i$i;
     break L9;
    } else {
     $$0710$i$i$i$i = $23;
    }
   }
   $20 = HEAP32[$$0710$i$i$i$i>>2]|0;
   $21 = ($20|0)==(0|0);
   if ($21) {
    $$0$ph$lcssa$i$i$i$i = $$0710$i$i$i$i;
    break;
   } else {
    $$0$ph13$i$i$i$i = $$0710$i$i$i$i;$$07$ph12$i$i$i$i = $20;
   }
  }
  $25 = ($$0$ph$lcssa$i$i$i$i|0)==((208696)|0);
  if (!($25)) {
   $26 = ((($$0$ph$lcssa$i$i$i$i)) + 16|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = ($27>>>0)>($2>>>0);
   if (!($28)) {
    $29 = ((($0)) + 68|0);
    $30 = ((($0)) + 72|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = HEAP32[$29>>2]|0;
    $33 = (($31) - ($32))|0;
    $34 = (($33|0) / 12)&-1;
    $35 = ($34>>>0)>($1>>>0);
    do {
     if (!($35)) {
      $36 = (($1) + 1)|0;
      $37 = ($36>>>0)>($34>>>0);
      $38 = $32;
      $39 = $31;
      if ($37) {
       $40 = (($36) - ($34))|0;
       __ZNSt3__26vectorINS_3mapIjjNS_4lessIjEENS_9allocatorINS_4pairIKjjEEEEEENS4_IS9_EEE8__appendEj($29,$40);
       break;
      }
      $41 = ($36>>>0)<($34>>>0);
      if ($41) {
       $42 = (($38) + (($36*12)|0)|0);
       $43 = ($39|0)==($42|0);
       if (!($43)) {
        $45 = $39;
        while(1) {
         $44 = ((($45)) + -12|0);
         HEAP32[$30>>2] = $44;
         $46 = ((($45)) + -8|0);
         $47 = HEAP32[$46>>2]|0;
         __ZNSt3__26__treeINS_12__value_typeIjjEENS_19__map_value_compareIjS2_NS_4lessIjEELb1EEENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($44,$47);
         $48 = HEAP32[$30>>2]|0;
         $49 = ($48|0)==($42|0);
         if ($49) {
          break;
         } else {
          $45 = $48;
         }
        }
       }
      }
     }
    } while(0);
    $50 = HEAP32[$29>>2]|0;
    $51 = (($50) + (($1*12)|0)|0);
    __ZN3osg8StateSet7setModeERNSt3__23mapIjjNS1_4lessIjEENS1_9allocatorINS1_4pairIKjjEEEEEEjj($0,$51,$2,$3);
    STACKTOP = sp;return;
   }
  }
 }
 $52 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
 do {
  if ($52) {
   $53 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
   $54 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($53,152403,27)|0);
   $55 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($54,$2)|0);
   $56 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($55,152431,44)|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = ((($57)) + -12|0);
   $59 = HEAP32[$58>>2]|0;
   $60 = (($56) + ($59)|0);
   __ZNKSt3__28ios_base6getlocEv($6,$60);
   __THREW__ = 0;
   $61 = (invoke_iii(3255,($6|0),(215188|0))|0);
   $62 = __THREW__; __THREW__ = 0;
   $63 = $62&1;
   if (!($63)) {
    $64 = HEAP32[$61>>2]|0;
    $65 = ((($64)) + 28|0);
    $66 = HEAP32[$65>>2]|0;
    __THREW__ = 0;
    $67 = (invoke_iii($66|0,($61|0),10)|0);
    $68 = __THREW__; __THREW__ = 0;
    $69 = $68&1;
    if (!($69)) {
     __ZNSt3__26localeD2Ev($6);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($56,$67)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($56)|0);
     break;
    }
   }
   $70 = ___cxa_find_matching_catch_2()|0;
   $71 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($6|0));
   $72 = __THREW__; __THREW__ = 0;
   $73 = $72&1;
   if ($73) {
    $74 = ___cxa_find_matching_catch_3(0|0)|0;
    $75 = tempRet0;
    ___clang_call_terminate($74);
    // unreachable;
   } else {
    ___resumeException($70|0);
    // unreachable;
   }
  }
 } while(0);
 $76 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
 do {
  if ($76) {
   $77 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
   $78 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($77,152476,46)|0);
   $79 = HEAP32[$78>>2]|0;
   $80 = ((($79)) + -12|0);
   $81 = HEAP32[$80>>2]|0;
   $82 = (($78) + ($81)|0);
   __ZNKSt3__28ios_base6getlocEv($5,$82);
   __THREW__ = 0;
   $83 = (invoke_iii(3255,($5|0),(215188|0))|0);
   $84 = __THREW__; __THREW__ = 0;
   $85 = $84&1;
   if (!($85)) {
    $86 = HEAP32[$83>>2]|0;
    $87 = ((($86)) + 28|0);
    $88 = HEAP32[$87>>2]|0;
    __THREW__ = 0;
    $89 = (invoke_iii($88|0,($83|0),10)|0);
    $90 = __THREW__; __THREW__ = 0;
    $91 = $90&1;
    if (!($91)) {
     __ZNSt3__26localeD2Ev($5);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($78,$89)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($78)|0);
     break;
    }
   }
   $92 = ___cxa_find_matching_catch_2()|0;
   $93 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($5|0));
   $94 = __THREW__; __THREW__ = 0;
   $95 = $94&1;
   if ($95) {
    $96 = ___cxa_find_matching_catch_3(0|0)|0;
    $97 = tempRet0;
    ___clang_call_terminate($96);
    // unreachable;
   } else {
    ___resumeException($92|0);
    // unreachable;
   }
  }
 } while(0);
 $98 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
 do {
  if ($98) {
   $99 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
   $100 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($99,151965,60)|0);
   $101 = HEAP32[$100>>2]|0;
   $102 = ((($101)) + -12|0);
   $103 = HEAP32[$102>>2]|0;
   $104 = (($100) + ($103)|0);
   __ZNKSt3__28ios_base6getlocEv($4,$104);
   __THREW__ = 0;
   $105 = (invoke_iii(3255,($4|0),(215188|0))|0);
   $106 = __THREW__; __THREW__ = 0;
   $107 = $106&1;
   if (!($107)) {
    $108 = HEAP32[$105>>2]|0;
    $109 = ((($108)) + 28|0);
    $110 = HEAP32[$109>>2]|0;
    __THREW__ = 0;
    $111 = (invoke_iii($110|0,($105|0),10)|0);
    $112 = __THREW__; __THREW__ = 0;
    $113 = $112&1;
    if (!($113)) {
     __ZNSt3__26localeD2Ev($4);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($100,$111)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($100)|0);
     break;
    }
   }
   $114 = ___cxa_find_matching_catch_2()|0;
   $115 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($4|0));
   $116 = __THREW__; __THREW__ = 0;
   $117 = $116&1;
   if ($117) {
    $118 = ___cxa_find_matching_catch_3(0|0)|0;
    $119 = tempRet0;
    ___clang_call_terminate($118);
    // unreachable;
   } else {
    ___resumeException($114|0);
    // unreachable;
   }
  }
 } while(0);
 __ZN3osg8StateSet7setModeEjj($0,$2,$3);
 STACKTOP = sp;return;
}
function __ZNSt3__26vectorINS_3mapIjjNS_4lessIjEENS_9allocatorINS_4pairIKjjEEEEEENS4_IS9_EEE8__appendEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i = 0, $$0$i13 = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $9 = 0, $scevgep = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $2 = sp;
 $3 = ((($0)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) - ($6))|0;
 $8 = (($7|0) / 12)&-1;
 $9 = ($8>>>0)<($1>>>0);
 if (!($9)) {
  $10 = $6;
  $$0$i = $1;$12 = $10;
  while(1) {
   $11 = ((($12)) + 4|0);
   HEAP32[$11>>2] = 0;
   $13 = ((($12)) + 8|0);
   HEAP32[$13>>2] = 0;
   $14 = ((($12)) + 4|0);
   HEAP32[$12>>2] = $14;
   $15 = HEAP32[$5>>2]|0;
   $16 = ((($15)) + 12|0);
   HEAP32[$5>>2] = $16;
   $17 = (($$0$i) + -1)|0;
   $18 = ($17|0)==(0);
   if ($18) {
    break;
   } else {
    $$0$i = $17;$12 = $16;
   }
  }
  STACKTOP = sp;return;
 }
 $19 = HEAP32[$0>>2]|0;
 $20 = (($6) - ($19))|0;
 $21 = (($20|0) / 12)&-1;
 $22 = (($21) + ($1))|0;
 $23 = ($22>>>0)>(357913941);
 if ($23) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $24 = ((($0)) + 8|0);
 $25 = (($4) - ($19))|0;
 $26 = (($25|0) / 12)&-1;
 $27 = ($26>>>0)<(178956970);
 $28 = $26 << 1;
 $29 = ($28>>>0)<($22>>>0);
 $$sroa$speculated$i = $29 ? $22 : $28;
 $$sroa$speculated$$i = $27 ? $$sroa$speculated$i : 357913941;
 $30 = ((($2)) + 12|0);
 HEAP32[$30>>2] = 0;
 $31 = ((($2)) + 16|0);
 HEAP32[$31>>2] = $24;
 $32 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($32) {
   $41 = 0;
  } else {
   $33 = ($$sroa$speculated$$i>>>0)>(357913941);
   if (!($33)) {
    $39 = ($$sroa$speculated$$i*12)|0;
    $40 = (__Znwj($39)|0);
    $41 = $40;
    break;
   }
   $34 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($34|0),(204840|0));
   $35 = __THREW__; __THREW__ = 0;
   $36 = $35&1;
   if ($36) {
    $37 = ___cxa_find_matching_catch_2()|0;
    $38 = tempRet0;
    ___cxa_free_exception(($34|0));
    ___resumeException($37|0);
    // unreachable;
   } else {
    HEAP32[$34>>2] = (99824);
    ___cxa_throw(($34|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 HEAP32[$2>>2] = $41;
 $42 = (($41) + (($21*12)|0)|0);
 $43 = ((($2)) + 8|0);
 HEAP32[$43>>2] = $42;
 $44 = ((($2)) + 4|0);
 HEAP32[$44>>2] = $42;
 $45 = (($41) + (($$sroa$speculated$$i*12)|0)|0);
 $46 = ((($2)) + 12|0);
 HEAP32[$46>>2] = $45;
 $$0$i13 = $1;$48 = $42;
 while(1) {
  $47 = ((($48)) + 4|0);
  HEAP32[$47>>2] = 0;
  $49 = ((($48)) + 8|0);
  HEAP32[$49>>2] = 0;
  $50 = ((($48)) + 4|0);
  HEAP32[$48>>2] = $50;
  $51 = ((($48)) + 12|0);
  $52 = (($$0$i13) + -1)|0;
  $53 = ($52|0)==(0);
  if ($53) {
   break;
  } else {
   $$0$i13 = $52;$48 = $51;
  }
 }
 $scevgep = (($41) + (($22*12)|0)|0);
 HEAP32[$43>>2] = $scevgep;
 __THREW__ = 0;
 invoke_vii(3958,($0|0),($2|0));
 $54 = __THREW__; __THREW__ = 0;
 $55 = $54&1;
 if ($55) {
  $67 = ___cxa_find_matching_catch_2()|0;
  $68 = tempRet0;
  $69 = HEAP32[$44>>2]|0;
  $70 = HEAP32[$43>>2]|0;
  $71 = ($70|0)==($69|0);
  if (!($71)) {
   $73 = $70;
   while(1) {
    $72 = ((($73)) + -12|0);
    HEAP32[$43>>2] = $72;
    $74 = ((($73)) + -8|0);
    $75 = HEAP32[$74>>2]|0;
    __ZNSt3__26__treeINS_12__value_typeIjjEENS_19__map_value_compareIjS2_NS_4lessIjEELb1EEENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($72,$75);
    $76 = HEAP32[$43>>2]|0;
    $77 = ($76|0)==($69|0);
    if ($77) {
     break;
    } else {
     $73 = $76;
    }
   }
  }
  $78 = HEAP32[$2>>2]|0;
  $79 = ($78|0)==(0|0);
  if ($79) {
   ___resumeException($67|0);
   // unreachable;
  }
  __ZdlPv($78);
  ___resumeException($67|0);
  // unreachable;
 } else {
  $56 = HEAP32[$44>>2]|0;
  $57 = HEAP32[$43>>2]|0;
  $58 = ($57|0)==($56|0);
  if (!($58)) {
   $60 = $57;
   while(1) {
    $59 = ((($60)) + -12|0);
    HEAP32[$43>>2] = $59;
    $61 = ((($60)) + -8|0);
    $62 = HEAP32[$61>>2]|0;
    __ZNSt3__26__treeINS_12__value_typeIjjEENS_19__map_value_compareIjS2_NS_4lessIjEELb1EEENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($59,$62);
    $63 = HEAP32[$43>>2]|0;
    $64 = ($63|0)==($56|0);
    if ($64) {
     break;
    } else {
     $60 = $63;
    }
   }
  }
  $65 = HEAP32[$2>>2]|0;
  $66 = ($65|0)==(0|0);
  if (!($66)) {
   __ZdlPv($65);
  }
  STACKTOP = sp;return;
 }
}
function __ZN3osg8StateSet7setModeERNSt3__23mapIjjNS1_4lessIjEENS1_9allocatorINS1_4pairIKjjEEEEEEjj($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0$i$i = 0, $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i$i = 0, $$0$ph$i$i = 0, $$0$ph$lcssa$i$i$i$i = 0, $$0$ph13$i$i$i$i = 0, $$014$i = 0, $$024$i$i = 0, $$025$i$i = 0, $$025$i47$i = 0, $$034$i = 0, $$03446$i = 0, $$07$ph12$i$i$i$i = 0, $$0710$i$i$i$i = 0, $$in$i$i = 0, $$pre$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = $3 & 8;
 $5 = ($4|0)==(0);
 $6 = ((($1)) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if ($5) {
  do {
   if ($8) {
    $$025$i$i = $6;$$034$i = $6;$52 = $7;
    label = 28;
   } else {
    $42 = ((($1)) + 4|0);
    $$0$i$i = $42;$$024$i$i = $7;$70 = $7;
    while(1) {
     $43 = ((($$024$i$i)) + 16|0);
     $44 = HEAP32[$43>>2]|0;
     $45 = ($44>>>0)>($2>>>0);
     if ($45) {
      $46 = HEAP32[$$024$i$i>>2]|0;
      $47 = ($46|0)==(0|0);
      if ($47) {
       label = 22;
       break;
      } else {
       $$0$ph$i$i = $$024$i$i;$$in$i$i = $46;
      }
     } else {
      $48 = ($44>>>0)<($2>>>0);
      if (!($48)) {
       label = 26;
       break;
      }
      $49 = ((($$024$i$i)) + 4|0);
      $50 = HEAP32[$49>>2]|0;
      $51 = ($50|0)==(0|0);
      if ($51) {
       label = 25;
       break;
      } else {
       $$0$ph$i$i = $49;$$in$i$i = $50;
      }
     }
     $$0$i$i = $$0$ph$i$i;$$024$i$i = $$in$i$i;$70 = $$in$i$i;
    }
    if ((label|0) == 22) {
     $$025$i47$i = $$024$i$i;$$03446$i = $$024$i$i;
     label = 29;
     break;
    }
    else if ((label|0) == 25) {
     $$025$i47$i = $49;$$03446$i = $$024$i$i;
     label = 29;
     break;
    }
    else if ((label|0) == 26) {
     $$025$i$i = $$0$i$i;$$034$i = $$024$i$i;$52 = $70;
     label = 28;
     break;
    }
   }
  } while(0);
  if ((label|0) == 28) {
   $53 = ($52|0)==(0|0);
   if ($53) {
    $$025$i47$i = $$025$i$i;$$03446$i = $$034$i;
    label = 29;
   } else {
    $$014$i = $52;
   }
  }
  if ((label|0) == 29) {
   $54 = (__Znwj(24)|0);
   $55 = ((($54)) + 16|0);
   HEAP32[$55>>2] = $2;
   $56 = ((($54)) + 20|0);
   HEAP32[$56>>2] = 0;
   HEAP32[$54>>2] = 0;
   $57 = ((($54)) + 4|0);
   HEAP32[$57>>2] = 0;
   $58 = ((($54)) + 8|0);
   HEAP32[$58>>2] = $$03446$i;
   HEAP32[$$025$i47$i>>2] = $54;
   $59 = HEAP32[$1>>2]|0;
   $60 = HEAP32[$59>>2]|0;
   $61 = ($60|0)==(0|0);
   if ($61) {
    $65 = $54;
   } else {
    $62 = $60;
    HEAP32[$1>>2] = $62;
    $$pre$i$i = HEAP32[$$025$i47$i>>2]|0;
    $65 = $$pre$i$i;
   }
   $63 = ((($1)) + 4|0);
   $64 = HEAP32[$63>>2]|0;
   __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($64,$65);
   $66 = ((($1)) + 8|0);
   $67 = HEAP32[$66>>2]|0;
   $68 = (($67) + 1)|0;
   HEAP32[$66>>2] = $68;
   $$014$i = $54;
  }
  $69 = ((($$014$i)) + 20|0);
  HEAP32[$69>>2] = $3;
  return;
 }
 if ($8) {
  return;
 } else {
  $$0$ph13$i$i$i$i = $6;$$07$ph12$i$i$i$i = $7;
 }
 L29: while(1) {
  $$0710$i$i$i$i = $$07$ph12$i$i$i$i;
  while(1) {
   $9 = ((($$0710$i$i$i$i)) + 16|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($10>>>0)<($2>>>0);
   if (!($11)) {
    break;
   }
   $14 = ((($$0710$i$i$i$i)) + 4|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = ($15|0)==(0|0);
   if ($16) {
    $$0$ph$lcssa$i$i$i$i = $$0$ph13$i$i$i$i;
    break L29;
   } else {
    $$0710$i$i$i$i = $15;
   }
  }
  $12 = HEAP32[$$0710$i$i$i$i>>2]|0;
  $13 = ($12|0)==(0|0);
  if ($13) {
   $$0$ph$lcssa$i$i$i$i = $$0710$i$i$i$i;
   break;
  } else {
   $$0$ph13$i$i$i$i = $$0710$i$i$i$i;$$07$ph12$i$i$i$i = $12;
  }
 }
 $17 = ($$0$ph$lcssa$i$i$i$i|0)==($6|0);
 if ($17) {
  return;
 }
 $18 = ((($$0$ph$lcssa$i$i$i$i)) + 16|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19>>>0)>($2>>>0);
 if ($20) {
  return;
 }
 $21 = ((($$0$ph$lcssa$i$i$i$i)) + 4|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0|0);
 if ($23) {
  $24 = ((($$0$ph$lcssa$i$i$i$i)) + 8|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = HEAP32[$25>>2]|0;
  $27 = ($26|0)==($$0$ph$lcssa$i$i$i$i|0);
  if ($27) {
   $$0$i$i$i$i$i = $25;
  } else {
   $31 = $24;
   while(1) {
    $30 = HEAP32[$31>>2]|0;
    $32 = ((($30)) + 8|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = HEAP32[$33>>2]|0;
    $35 = ($34|0)==($30|0);
    if ($35) {
     $$0$i$i$i$i$i = $33;
     break;
    } else {
     $31 = $32;
    }
   }
  }
 } else {
  $$0$i$i$i$i$i$i = $22;
  while(1) {
   $28 = HEAP32[$$0$i$i$i$i$i$i>>2]|0;
   $29 = ($28|0)==(0|0);
   if ($29) {
    break;
   } else {
    $$0$i$i$i$i$i$i = $28;
   }
  }
  $$0$i$i$i$i$i = $$0$i$i$i$i$i$i;
 }
 $36 = HEAP32[$1>>2]|0;
 $37 = ($36|0)==($$0$ph$lcssa$i$i$i$i|0);
 if ($37) {
  $38 = $$0$i$i$i$i$i;
  HEAP32[$1>>2] = $38;
 }
 $39 = ((($1)) + 8|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = (($40) + -1)|0;
 HEAP32[$39>>2] = $41;
 __ZNSt3__213__tree_removeIPNS_16__tree_node_baseIPvEEEEvT_S5_($7,$$0$ph$lcssa$i$i$i$i);
 __ZdlPv($$0$ph$lcssa$i$i$i$i);
 return;
}
function __ZNSt3__26vectorINS_3mapIjjNS_4lessIjEENS_9allocatorINS_4pairIKjjEEEEEENS4_IS9_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS9_RSA_EE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i$i$i$i$i$i = 0, $$0$i$i$i$i$i$i$i$i = 0, $$08$i = 0, $$byval_copy = 0, $$in8$i$i$i$i = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i$i$i$i$i$i$i = 0, $$pre$phi19Z2D = 0, $$pre$phiZ2D = 0, $$pre16 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy = sp + 12|0;
 $2 = sp + 8|0;
 $3 = sp + 4|0;
 $4 = sp;
 $5 = HEAP32[$0>>2]|0;
 $6 = ((($0)) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($1)) + 4|0);
 $9 = ($7|0)==($5|0);
 if ($9) {
  $10 = $5;
  $$pre16 = HEAP32[$8>>2]|0;
  $$pre$phi19Z2D = $8;$$pre$phiZ2D = $0;$75 = $$pre16;$76 = $10;
  HEAP32[$$pre$phiZ2D>>2] = $75;
  HEAP32[$$pre$phi19Z2D>>2] = $76;
  $77 = ((($1)) + 8|0);
  $78 = HEAP32[$6>>2]|0;
  $79 = HEAP32[$77>>2]|0;
  HEAP32[$6>>2] = $79;
  HEAP32[$77>>2] = $78;
  $80 = ((($0)) + 8|0);
  $81 = ((($1)) + 12|0);
  $82 = HEAP32[$80>>2]|0;
  $83 = HEAP32[$81>>2]|0;
  HEAP32[$80>>2] = $83;
  HEAP32[$81>>2] = $82;
  $84 = HEAP32[$$pre$phi19Z2D>>2]|0;
  HEAP32[$1>>2] = $84;
  STACKTOP = sp;return;
 }
 $$pre$i = HEAP32[$8>>2]|0;
 $$08$i = $7;$12 = $$pre$i;
 L5: while(1) {
  $11 = ((($12)) + -12|0);
  $13 = ((($$08$i)) + -12|0);
  $14 = ((($12)) + -8|0);
  HEAP32[$14>>2] = 0;
  $15 = ((($12)) + -4|0);
  HEAP32[$15>>2] = 0;
  $16 = ((($12)) + -8|0);
  HEAP32[$11>>2] = $16;
  $17 = HEAP32[$13>>2]|0;
  $18 = ((($$08$i)) + -8|0);
  $19 = ($17|0)==($18|0);
  if (!($19)) {
   $20 = $16;
   $$in8$i$i$i$i = $17;
   while(1) {
    $21 = ((($$in8$i$i$i$i)) + 16|0);
    HEAP32[$4>>2] = $20;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy>>2]=HEAP32[$4>>2]|0;
    $22 = (invoke_iiiiii(3940,($11|0),($$byval_copy|0),($2|0),($3|0),($21|0))|0);
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if ($24) {
     label = 18;
     break L5;
    }
    $25 = HEAP32[$22>>2]|0;
    $26 = ($25|0)==(0|0);
    if ($26) {
     __THREW__ = 0;
     $27 = (invoke_ii(3276,24)|0);
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      label = 18;
      break L5;
     }
     $30 = ((($27)) + 16|0);
     $31 = $21;
     $32 = $31;
     $33 = HEAP32[$32>>2]|0;
     $34 = (($31) + 4)|0;
     $35 = $34;
     $36 = HEAP32[$35>>2]|0;
     $37 = $30;
     $38 = $37;
     HEAP32[$38>>2] = $33;
     $39 = (($37) + 4)|0;
     $40 = $39;
     HEAP32[$40>>2] = $36;
     $41 = HEAP32[$2>>2]|0;
     HEAP32[$27>>2] = 0;
     $42 = ((($27)) + 4|0);
     HEAP32[$42>>2] = 0;
     $43 = ((($27)) + 8|0);
     HEAP32[$43>>2] = $41;
     HEAP32[$22>>2] = $27;
     $44 = HEAP32[$11>>2]|0;
     $45 = HEAP32[$44>>2]|0;
     $46 = ($45|0)==(0|0);
     if ($46) {
      $49 = $27;
     } else {
      $47 = $45;
      HEAP32[$11>>2] = $47;
      $$pre$i$i$i$i$i$i$i$i = HEAP32[$22>>2]|0;
      $49 = $$pre$i$i$i$i$i$i$i$i;
     }
     $48 = HEAP32[$14>>2]|0;
     __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($48,$49);
     $50 = HEAP32[$15>>2]|0;
     $51 = (($50) + 1)|0;
     HEAP32[$15>>2] = $51;
    }
    $52 = ((($$in8$i$i$i$i)) + 4|0);
    $53 = HEAP32[$52>>2]|0;
    $54 = ($53|0)==(0|0);
    if ($54) {
     $55 = ((($$in8$i$i$i$i)) + 8|0);
     $56 = HEAP32[$55>>2]|0;
     $57 = HEAP32[$56>>2]|0;
     $58 = ($57|0)==($$in8$i$i$i$i|0);
     if ($58) {
      $$0$i$i$i$i$i$i$i = $56;
     } else {
      $62 = $55;
      while(1) {
       $61 = HEAP32[$62>>2]|0;
       $63 = ((($61)) + 8|0);
       $64 = HEAP32[$63>>2]|0;
       $65 = HEAP32[$64>>2]|0;
       $66 = ($65|0)==($61|0);
       if ($66) {
        $$0$i$i$i$i$i$i$i = $64;
        break;
       } else {
        $62 = $63;
       }
      }
     }
    } else {
     $$0$i$i$i$i$i$i$i$i = $53;
     while(1) {
      $59 = HEAP32[$$0$i$i$i$i$i$i$i$i>>2]|0;
      $60 = ($59|0)==(0|0);
      if ($60) {
       break;
      } else {
       $$0$i$i$i$i$i$i$i$i = $59;
      }
     }
     $$0$i$i$i$i$i$i$i = $$0$i$i$i$i$i$i$i$i;
    }
    $67 = ($$0$i$i$i$i$i$i$i|0)==($18|0);
    if ($67) {
     break;
    } else {
     $$in8$i$i$i$i = $$0$i$i$i$i$i$i$i;
    }
   }
  }
  $71 = HEAP32[$8>>2]|0;
  $72 = ((($71)) + -12|0);
  HEAP32[$8>>2] = $72;
  $73 = ($13|0)==($5|0);
  if ($73) {
   label = 20;
   break;
  } else {
   $$08$i = $13;$12 = $72;
  }
 }
 if ((label|0) == 18) {
  $68 = ___cxa_find_matching_catch_2()|0;
  $69 = tempRet0;
  $70 = HEAP32[$16>>2]|0;
  __ZNSt3__26__treeINS_12__value_typeIjjEENS_19__map_value_compareIjS2_NS_4lessIjEELb1EEENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($11,$70);
  ___resumeException($68|0);
  // unreachable;
 }
 else if ((label|0) == 20) {
  $74 = $72;
  $$pre = HEAP32[$0>>2]|0;
  $$pre$phi19Z2D = $8;$$pre$phiZ2D = $0;$75 = $74;$76 = $$pre;
  HEAP32[$$pre$phiZ2D>>2] = $75;
  HEAP32[$$pre$phi19Z2D>>2] = $76;
  $77 = ((($1)) + 8|0);
  $78 = HEAP32[$6>>2]|0;
  $79 = HEAP32[$77>>2]|0;
  HEAP32[$6>>2] = $79;
  HEAP32[$77>>2] = $78;
  $80 = ((($0)) + 8|0);
  $81 = ((($1)) + 12|0);
  $82 = HEAP32[$80>>2]|0;
  $83 = HEAP32[$81>>2]|0;
  HEAP32[$80>>2] = $83;
  HEAP32[$81>>2] = $82;
  $84 = HEAP32[$$pre$phi19Z2D>>2]|0;
  HEAP32[$1>>2] = $84;
  STACKTOP = sp;return;
 }
}
function __ZN3osg8StateSet10removeModeEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i$i = 0, $$0$ph$lcssa$i$i$i$i = 0, $$0$ph$lcssa$i$i$i$i10 = 0, $$0$ph13$i$i$i$i = 0, $$0$ph13$i$i$i$i5 = 0, $$07$ph12$i$i$i$i = 0, $$07$ph12$i$i$i$i6 = 0, $$0710$i$i$i$i = 0, $$0710$i$i$i$i8 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp + 12|0;
 $3 = sp + 8|0;
 $4 = sp + 4|0;
 $5 = sp;
 $6 = HEAP8[206088]|0;
 $7 = ($6<<24>>24)==(0);
 do {
  if ($7) {
   $8 = (___cxa_guard_acquire(206088)|0);
   $9 = ($8|0)==(0);
   if (!($9)) {
    __THREW__ = 0;
    invoke_vi(3956,(208692|0));
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     $12 = ___cxa_find_matching_catch_2()|0;
     $13 = tempRet0;
     ___resumeException($12|0);
     // unreachable;
    } else {
     (___cxa_atexit((3957|0),(208692|0),(___dso_handle|0))|0);
     break;
    }
   }
  }
 } while(0);
 $14 = HEAP32[(208696)>>2]|0;
 $15 = ($14|0)==(0|0);
 if (!($15)) {
  $$0$ph13$i$i$i$i5 = (208696);$$07$ph12$i$i$i$i6 = $14;
  L9: while(1) {
   $$0710$i$i$i$i8 = $$07$ph12$i$i$i$i6;
   while(1) {
    $16 = ((($$0710$i$i$i$i8)) + 16|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = ($17>>>0)<($1>>>0);
    if (!($18)) {
     break;
    }
    $21 = ((($$0710$i$i$i$i8)) + 4|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = ($22|0)==(0|0);
    if ($23) {
     $$0$ph$lcssa$i$i$i$i10 = $$0$ph13$i$i$i$i5;
     break L9;
    } else {
     $$0710$i$i$i$i8 = $22;
    }
   }
   $19 = HEAP32[$$0710$i$i$i$i8>>2]|0;
   $20 = ($19|0)==(0|0);
   if ($20) {
    $$0$ph$lcssa$i$i$i$i10 = $$0710$i$i$i$i8;
    break;
   } else {
    $$0$ph13$i$i$i$i5 = $$0710$i$i$i$i8;$$07$ph12$i$i$i$i6 = $19;
   }
  }
  $24 = ($$0$ph$lcssa$i$i$i$i10|0)==((208696)|0);
  if (!($24)) {
   $25 = ((($$0$ph$lcssa$i$i$i$i10)) + 16|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = ($26>>>0)>($1>>>0);
   if (!($27)) {
    $28 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
    do {
     if ($28) {
      $29 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
      $30 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($29,152582,23)|0);
      $31 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($30,$1)|0);
      $32 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($31,152931,35)|0);
      $33 = HEAP32[$32>>2]|0;
      $34 = ((($33)) + -12|0);
      $35 = HEAP32[$34>>2]|0;
      $36 = (($32) + ($35)|0);
      __ZNKSt3__28ios_base6getlocEv($5,$36);
      __THREW__ = 0;
      $37 = (invoke_iii(3255,($5|0),(215188|0))|0);
      $38 = __THREW__; __THREW__ = 0;
      $39 = $38&1;
      if (!($39)) {
       $40 = HEAP32[$37>>2]|0;
       $41 = ((($40)) + 28|0);
       $42 = HEAP32[$41>>2]|0;
       __THREW__ = 0;
       $43 = (invoke_iii($42|0,($37|0),10)|0);
       $44 = __THREW__; __THREW__ = 0;
       $45 = $44&1;
       if (!($45)) {
        __ZNSt3__26localeD2Ev($5);
        (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($32,$43)|0);
        (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($32)|0);
        break;
       }
      }
      $46 = ___cxa_find_matching_catch_2()|0;
      $47 = tempRet0;
      __THREW__ = 0;
      invoke_vi(3263,($5|0));
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       $50 = ___cxa_find_matching_catch_3(0|0)|0;
       $51 = tempRet0;
       ___clang_call_terminate($50);
       // unreachable;
      } else {
       ___resumeException($46|0);
       // unreachable;
      }
     }
    } while(0);
    $52 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
    do {
     if ($52) {
      $53 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
      $54 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($53,152967,63)|0);
      $55 = HEAP32[$54>>2]|0;
      $56 = ((($55)) + -12|0);
      $57 = HEAP32[$56>>2]|0;
      $58 = (($54) + ($57)|0);
      __ZNKSt3__28ios_base6getlocEv($4,$58);
      __THREW__ = 0;
      $59 = (invoke_iii(3255,($4|0),(215188|0))|0);
      $60 = __THREW__; __THREW__ = 0;
      $61 = $60&1;
      if (!($61)) {
       $62 = HEAP32[$59>>2]|0;
       $63 = ((($62)) + 28|0);
       $64 = HEAP32[$63>>2]|0;
       __THREW__ = 0;
       $65 = (invoke_iii($64|0,($59|0),10)|0);
       $66 = __THREW__; __THREW__ = 0;
       $67 = $66&1;
       if (!($67)) {
        __ZNSt3__26localeD2Ev($4);
        (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($54,$65)|0);
        (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($54)|0);
        break;
       }
      }
      $68 = ___cxa_find_matching_catch_2()|0;
      $69 = tempRet0;
      __THREW__ = 0;
      invoke_vi(3263,($4|0));
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       $72 = ___cxa_find_matching_catch_3(0|0)|0;
       $73 = tempRet0;
       ___clang_call_terminate($72);
       // unreachable;
      } else {
       ___resumeException($68|0);
       // unreachable;
      }
     }
    } while(0);
    $74 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
    do {
     if ($74) {
      $75 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
      $76 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($75,151965,60)|0);
      $77 = HEAP32[$76>>2]|0;
      $78 = ((($77)) + -12|0);
      $79 = HEAP32[$78>>2]|0;
      $80 = (($76) + ($79)|0);
      __ZNKSt3__28ios_base6getlocEv($3,$80);
      __THREW__ = 0;
      $81 = (invoke_iii(3255,($3|0),(215188|0))|0);
      $82 = __THREW__; __THREW__ = 0;
      $83 = $82&1;
      if (!($83)) {
       $84 = HEAP32[$81>>2]|0;
       $85 = ((($84)) + 28|0);
       $86 = HEAP32[$85>>2]|0;
       __THREW__ = 0;
       $87 = (invoke_iii($86|0,($81|0),10)|0);
       $88 = __THREW__; __THREW__ = 0;
       $89 = $88&1;
       if (!($89)) {
        __ZNSt3__26localeD2Ev($3);
        (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($76,$87)|0);
        (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($76)|0);
        break;
       }
      }
      $90 = ___cxa_find_matching_catch_2()|0;
      $91 = tempRet0;
      __THREW__ = 0;
      invoke_vi(3263,($3|0));
      $92 = __THREW__; __THREW__ = 0;
      $93 = $92&1;
      if ($93) {
       $94 = ___cxa_find_matching_catch_3(0|0)|0;
       $95 = tempRet0;
       ___clang_call_terminate($94);
       // unreachable;
      } else {
       ___resumeException($90|0);
       // unreachable;
      }
     }
    } while(0);
    __ZN3osg8StateSet17removeTextureModeEjj($0,0,$1);
    STACKTOP = sp;return;
   }
  }
 }
 $96 = ($1|0)==(2903);
 if ($96) {
  $97 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
  if ($97) {
   $98 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
   (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($98,153031,85)|0);
  }
  $99 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
  if ($99) {
   $100 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
   (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($100,152789,80)|0);
  }
  $101 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
  if (!($101)) {
   STACKTOP = sp;return;
  }
  $102 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
  $103 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($102,152870,60)|0);
  $104 = HEAP32[$103>>2]|0;
  $105 = ((($104)) + -12|0);
  $106 = HEAP32[$105>>2]|0;
  $107 = (($103) + ($106)|0);
  __ZNKSt3__28ios_base6getlocEv($2,$107);
  __THREW__ = 0;
  $108 = (invoke_iii(3255,($2|0),(215188|0))|0);
  $109 = __THREW__; __THREW__ = 0;
  $110 = $109&1;
  if (!($110)) {
   $111 = HEAP32[$108>>2]|0;
   $112 = ((($111)) + 28|0);
   $113 = HEAP32[$112>>2]|0;
   __THREW__ = 0;
   $114 = (invoke_iii($113|0,($108|0),10)|0);
   $115 = __THREW__; __THREW__ = 0;
   $116 = $115&1;
   if (!($116)) {
    __ZNSt3__26localeD2Ev($2);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($103,$114)|0);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($103)|0);
    STACKTOP = sp;return;
   }
  }
  $117 = ___cxa_find_matching_catch_2()|0;
  $118 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3263,($2|0));
  $119 = __THREW__; __THREW__ = 0;
  $120 = $119&1;
  if ($120) {
   $121 = ___cxa_find_matching_catch_3(0|0)|0;
   $122 = tempRet0;
   ___clang_call_terminate($121);
   // unreachable;
  } else {
   ___resumeException($117|0);
   // unreachable;
  }
 }
 $123 = ((($0)) + 44|0);
 $124 = ((($0)) + 48|0);
 $125 = HEAP32[$124>>2]|0;
 $126 = ($125|0)==(0|0);
 if ($126) {
  STACKTOP = sp;return;
 } else {
  $$0$ph13$i$i$i$i = $124;$$07$ph12$i$i$i$i = $125;
 }
 L72: while(1) {
  $$0710$i$i$i$i = $$07$ph12$i$i$i$i;
  while(1) {
   $127 = ((($$0710$i$i$i$i)) + 16|0);
   $128 = HEAP32[$127>>2]|0;
   $129 = ($128>>>0)<($1>>>0);
   if (!($129)) {
    break;
   }
   $132 = ((($$0710$i$i$i$i)) + 4|0);
   $133 = HEAP32[$132>>2]|0;
   $134 = ($133|0)==(0|0);
   if ($134) {
    $$0$ph$lcssa$i$i$i$i = $$0$ph13$i$i$i$i;
    break L72;
   } else {
    $$0710$i$i$i$i = $133;
   }
  }
  $130 = HEAP32[$$0710$i$i$i$i>>2]|0;
  $131 = ($130|0)==(0|0);
  if ($131) {
   $$0$ph$lcssa$i$i$i$i = $$0710$i$i$i$i;
   break;
  } else {
   $$0$ph13$i$i$i$i = $$0710$i$i$i$i;$$07$ph12$i$i$i$i = $130;
  }
 }
 $135 = ($$0$ph$lcssa$i$i$i$i|0)==($124|0);
 if ($135) {
  STACKTOP = sp;return;
 }
 $136 = ((($$0$ph$lcssa$i$i$i$i)) + 16|0);
 $137 = HEAP32[$136>>2]|0;
 $138 = ($137>>>0)>($1>>>0);
 if ($138) {
  STACKTOP = sp;return;
 }
 $139 = ((($$0$ph$lcssa$i$i$i$i)) + 4|0);
 $140 = HEAP32[$139>>2]|0;
 $141 = ($140|0)==(0|0);
 if ($141) {
  $142 = ((($$0$ph$lcssa$i$i$i$i)) + 8|0);
  $143 = HEAP32[$142>>2]|0;
  $144 = HEAP32[$143>>2]|0;
  $145 = ($144|0)==($$0$ph$lcssa$i$i$i$i|0);
  if ($145) {
   $$0$i$i$i$i$i = $143;
  } else {
   $149 = $142;
   while(1) {
    $148 = HEAP32[$149>>2]|0;
    $150 = ((($148)) + 8|0);
    $151 = HEAP32[$150>>2]|0;
    $152 = HEAP32[$151>>2]|0;
    $153 = ($152|0)==($148|0);
    if ($153) {
     $$0$i$i$i$i$i = $151;
     break;
    } else {
     $149 = $150;
    }
   }
  }
 } else {
  $$0$i$i$i$i$i$i = $140;
  while(1) {
   $146 = HEAP32[$$0$i$i$i$i$i$i>>2]|0;
   $147 = ($146|0)==(0|0);
   if ($147) {
    break;
   } else {
    $$0$i$i$i$i$i$i = $146;
   }
  }
  $$0$i$i$i$i$i = $$0$i$i$i$i$i$i;
 }
 $154 = HEAP32[$123>>2]|0;
 $155 = ($154|0)==($$0$ph$lcssa$i$i$i$i|0);
 if ($155) {
  $156 = $$0$i$i$i$i$i;
  HEAP32[$123>>2] = $156;
 }
 $157 = ((($0)) + 52|0);
 $158 = HEAP32[$157>>2]|0;
 $159 = (($158) + -1)|0;
 HEAP32[$157>>2] = $159;
 __ZNSt3__213__tree_removeIPNS_16__tree_node_baseIPvEEEEvT_S5_($125,$$0$ph$lcssa$i$i$i$i);
 __ZdlPv($$0$ph$lcssa$i$i$i$i);
 STACKTOP = sp;return;
}
function __ZN3osg8StateSet17removeTextureModeEjj($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i$i = 0, $$0$ph$lcssa$i$i$i$i = 0, $$0$ph$lcssa$i$i$i$i11 = 0, $$0$ph13$i$i$i$i = 0, $$0$ph13$i$i$i$i6 = 0, $$07$ph12$i$i$i$i = 0, $$07$ph12$i$i$i$i7 = 0, $$0710$i$i$i$i = 0, $$0710$i$i$i$i9 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp + 8|0;
 $4 = sp + 4|0;
 $5 = sp;
 $6 = HEAP8[206088]|0;
 $7 = ($6<<24>>24)==(0);
 do {
  if ($7) {
   $8 = (___cxa_guard_acquire(206088)|0);
   $9 = ($8|0)==(0);
   if (!($9)) {
    __THREW__ = 0;
    invoke_vi(3956,(208692|0));
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     $12 = ___cxa_find_matching_catch_2()|0;
     $13 = tempRet0;
     ___resumeException($12|0);
     // unreachable;
    } else {
     (___cxa_atexit((3957|0),(208692|0),(___dso_handle|0))|0);
     break;
    }
   }
  }
 } while(0);
 $14 = HEAP32[(208696)>>2]|0;
 $15 = ($14|0)==(0|0);
 if (!($15)) {
  $$0$ph13$i$i$i$i = (208696);$$07$ph12$i$i$i$i = $14;
  L9: while(1) {
   $$0710$i$i$i$i = $$07$ph12$i$i$i$i;
   while(1) {
    $16 = ((($$0710$i$i$i$i)) + 16|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = ($17>>>0)<($2>>>0);
    if (!($18)) {
     break;
    }
    $21 = ((($$0710$i$i$i$i)) + 4|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = ($22|0)==(0|0);
    if ($23) {
     $$0$ph$lcssa$i$i$i$i = $$0$ph13$i$i$i$i;
     break L9;
    } else {
     $$0710$i$i$i$i = $22;
    }
   }
   $19 = HEAP32[$$0710$i$i$i$i>>2]|0;
   $20 = ($19|0)==(0|0);
   if ($20) {
    $$0$ph$lcssa$i$i$i$i = $$0710$i$i$i$i;
    break;
   } else {
    $$0$ph13$i$i$i$i = $$0710$i$i$i$i;$$07$ph12$i$i$i$i = $19;
   }
  }
  $24 = ($$0$ph$lcssa$i$i$i$i|0)==((208696)|0);
  if (!($24)) {
   $25 = ((($$0$ph$lcssa$i$i$i$i)) + 16|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = ($26>>>0)>($2>>>0);
   if (!($27)) {
    $28 = ((($0)) + 68|0);
    $29 = ((($0)) + 72|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = HEAP32[$28>>2]|0;
    $32 = (($30) - ($31))|0;
    $33 = (($32|0) / 12)&-1;
    $34 = ($33>>>0)>($1>>>0);
    $35 = $31;
    if (!($34)) {
     STACKTOP = sp;return;
    }
    $36 = (($35) + (($1*12)|0)|0);
    $37 = (((($35) + (($1*12)|0)|0)) + 4|0);
    $38 = HEAP32[$37>>2]|0;
    $39 = ($38|0)==(0|0);
    if ($39) {
     STACKTOP = sp;return;
    } else {
     $$0$ph13$i$i$i$i6 = $37;$$07$ph12$i$i$i$i7 = $38;
    }
    L23: while(1) {
     $$0710$i$i$i$i9 = $$07$ph12$i$i$i$i7;
     while(1) {
      $40 = ((($$0710$i$i$i$i9)) + 16|0);
      $41 = HEAP32[$40>>2]|0;
      $42 = ($41>>>0)<($2>>>0);
      if (!($42)) {
       break;
      }
      $45 = ((($$0710$i$i$i$i9)) + 4|0);
      $46 = HEAP32[$45>>2]|0;
      $47 = ($46|0)==(0|0);
      if ($47) {
       $$0$ph$lcssa$i$i$i$i11 = $$0$ph13$i$i$i$i6;
       break L23;
      } else {
       $$0710$i$i$i$i9 = $46;
      }
     }
     $43 = HEAP32[$$0710$i$i$i$i9>>2]|0;
     $44 = ($43|0)==(0|0);
     if ($44) {
      $$0$ph$lcssa$i$i$i$i11 = $$0710$i$i$i$i9;
      break;
     } else {
      $$0$ph13$i$i$i$i6 = $$0710$i$i$i$i9;$$07$ph12$i$i$i$i7 = $43;
     }
    }
    $48 = ($$0$ph$lcssa$i$i$i$i11|0)==($37|0);
    if ($48) {
     STACKTOP = sp;return;
    }
    $49 = ((($$0$ph$lcssa$i$i$i$i11)) + 16|0);
    $50 = HEAP32[$49>>2]|0;
    $51 = ($50>>>0)>($2>>>0);
    if ($51) {
     STACKTOP = sp;return;
    }
    $52 = ((($$0$ph$lcssa$i$i$i$i11)) + 4|0);
    $53 = HEAP32[$52>>2]|0;
    $54 = ($53|0)==(0|0);
    if ($54) {
     $55 = ((($$0$ph$lcssa$i$i$i$i11)) + 8|0);
     $56 = HEAP32[$55>>2]|0;
     $57 = HEAP32[$56>>2]|0;
     $58 = ($57|0)==($$0$ph$lcssa$i$i$i$i11|0);
     if ($58) {
      $$0$i$i$i$i$i = $56;
     } else {
      $62 = $55;
      while(1) {
       $61 = HEAP32[$62>>2]|0;
       $63 = ((($61)) + 8|0);
       $64 = HEAP32[$63>>2]|0;
       $65 = HEAP32[$64>>2]|0;
       $66 = ($65|0)==($61|0);
       if ($66) {
        $$0$i$i$i$i$i = $64;
        break;
       } else {
        $62 = $63;
       }
      }
     }
    } else {
     $$0$i$i$i$i$i$i = $53;
     while(1) {
      $59 = HEAP32[$$0$i$i$i$i$i$i>>2]|0;
      $60 = ($59|0)==(0|0);
      if ($60) {
       break;
      } else {
       $$0$i$i$i$i$i$i = $59;
      }
     }
     $$0$i$i$i$i$i = $$0$i$i$i$i$i$i;
    }
    $67 = HEAP32[$36>>2]|0;
    $68 = ($67|0)==($$0$ph$lcssa$i$i$i$i11|0);
    if ($68) {
     $69 = $$0$i$i$i$i$i;
     HEAP32[$36>>2] = $69;
    }
    $70 = (((($35) + (($1*12)|0)|0)) + 8|0);
    $71 = HEAP32[$70>>2]|0;
    $72 = (($71) + -1)|0;
    HEAP32[$70>>2] = $72;
    __ZNSt3__213__tree_removeIPNS_16__tree_node_baseIPvEEEEvT_S5_($38,$$0$ph$lcssa$i$i$i$i11);
    __ZdlPv($$0$ph$lcssa$i$i$i$i11);
    STACKTOP = sp;return;
   }
  }
 }
 $73 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
 do {
  if ($73) {
   $74 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
   $75 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($74,152403,27)|0);
   $76 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($75,$2)|0);
   $77 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($76,153117,47)|0);
   $78 = HEAP32[$77>>2]|0;
   $79 = ((($78)) + -12|0);
   $80 = HEAP32[$79>>2]|0;
   $81 = (($77) + ($80)|0);
   __ZNKSt3__28ios_base6getlocEv($5,$81);
   __THREW__ = 0;
   $82 = (invoke_iii(3255,($5|0),(215188|0))|0);
   $83 = __THREW__; __THREW__ = 0;
   $84 = $83&1;
   if (!($84)) {
    $85 = HEAP32[$82>>2]|0;
    $86 = ((($85)) + 28|0);
    $87 = HEAP32[$86>>2]|0;
    __THREW__ = 0;
    $88 = (invoke_iii($87|0,($82|0),10)|0);
    $89 = __THREW__; __THREW__ = 0;
    $90 = $89&1;
    if (!($90)) {
     __ZNSt3__26localeD2Ev($5);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($77,$88)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($77)|0);
     break;
    }
   }
   $91 = ___cxa_find_matching_catch_2()|0;
   $92 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($5|0));
   $93 = __THREW__; __THREW__ = 0;
   $94 = $93&1;
   if ($94) {
    $95 = ___cxa_find_matching_catch_3(0|0)|0;
    $96 = tempRet0;
    ___clang_call_terminate($95);
    // unreachable;
   } else {
    ___resumeException($91|0);
    // unreachable;
   }
  }
 } while(0);
 $97 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
 do {
  if ($97) {
   $98 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
   $99 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($98,153165,56)|0);
   $100 = HEAP32[$99>>2]|0;
   $101 = ((($100)) + -12|0);
   $102 = HEAP32[$101>>2]|0;
   $103 = (($99) + ($102)|0);
   __ZNKSt3__28ios_base6getlocEv($4,$103);
   __THREW__ = 0;
   $104 = (invoke_iii(3255,($4|0),(215188|0))|0);
   $105 = __THREW__; __THREW__ = 0;
   $106 = $105&1;
   if (!($106)) {
    $107 = HEAP32[$104>>2]|0;
    $108 = ((($107)) + 28|0);
    $109 = HEAP32[$108>>2]|0;
    __THREW__ = 0;
    $110 = (invoke_iii($109|0,($104|0),10)|0);
    $111 = __THREW__; __THREW__ = 0;
    $112 = $111&1;
    if (!($112)) {
     __ZNSt3__26localeD2Ev($4);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($99,$110)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($99)|0);
     break;
    }
   }
   $113 = ___cxa_find_matching_catch_2()|0;
   $114 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($4|0));
   $115 = __THREW__; __THREW__ = 0;
   $116 = $115&1;
   if ($116) {
    $117 = ___cxa_find_matching_catch_3(0|0)|0;
    $118 = tempRet0;
    ___clang_call_terminate($117);
    // unreachable;
   } else {
    ___resumeException($113|0);
    // unreachable;
   }
  }
 } while(0);
 $119 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
 do {
  if ($119) {
   $120 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
   $121 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($120,151965,60)|0);
   $122 = HEAP32[$121>>2]|0;
   $123 = ((($122)) + -12|0);
   $124 = HEAP32[$123>>2]|0;
   $125 = (($121) + ($124)|0);
   __ZNKSt3__28ios_base6getlocEv($3,$125);
   __THREW__ = 0;
   $126 = (invoke_iii(3255,($3|0),(215188|0))|0);
   $127 = __THREW__; __THREW__ = 0;
   $128 = $127&1;
   if (!($128)) {
    $129 = HEAP32[$126>>2]|0;
    $130 = ((($129)) + 28|0);
    $131 = HEAP32[$130>>2]|0;
    __THREW__ = 0;
    $132 = (invoke_iii($131|0,($126|0),10)|0);
    $133 = __THREW__; __THREW__ = 0;
    $134 = $133&1;
    if (!($134)) {
     __ZNSt3__26localeD2Ev($3);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($121,$132)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($121)|0);
     break;
    }
   }
   $135 = ___cxa_find_matching_catch_2()|0;
   $136 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($3|0));
   $137 = __THREW__; __THREW__ = 0;
   $138 = $137&1;
   if ($138) {
    $139 = ___cxa_find_matching_catch_3(0|0)|0;
    $140 = tempRet0;
    ___clang_call_terminate($139);
    // unreachable;
   } else {
    ___resumeException($135|0);
    // unreachable;
   }
  }
 } while(0);
 __ZN3osg8StateSet10removeModeEj($0,$2);
 STACKTOP = sp;return;
}
function __ZN3osg8StateSet38setNumChildrenRequiringUpdateTraversalEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$ = 0, $$1 = 0, $$sroa$013$018 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $not$ = 0, $not$17 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 148|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==($1|0);
 if ($4) {
  return;
 }
 $5 = ((($0)) + 144|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $8 = ((($0)) + 32|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ((($0)) + 36|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($9|0)==($11|0);
  if (!($12)) {
   $not$ = ($3|0)!=(0);
   $$ = $not$ << 31 >> 31;
   $not$17 = ($1|0)!=(0);
   $13 = $not$17&1;
   $$1 = (($$) + ($13))|0;
   $14 = ($$1|0)==(0);
   if (!($14)) {
    $$sroa$013$018 = $9;
    while(1) {
     $15 = HEAP32[$$sroa$013$018>>2]|0;
     $16 = ((($15)) + 88|0);
     $17 = HEAP32[$16>>2]|0;
     $18 = (($17) + ($$1))|0;
     __ZN3osg4Node38setNumChildrenRequiringUpdateTraversalEj($15,$18);
     $19 = ((($$sroa$013$018)) + 4|0);
     $20 = HEAP32[$10>>2]|0;
     $21 = ($19|0)==($20|0);
     if ($21) {
      break;
     } else {
      $$sroa$013$018 = $19;
     }
    }
   }
  }
 }
 HEAP32[$2>>2] = $1;
 return;
}
function __ZN3osg8StateSet15removeAttributeEPNS_14StateAttributeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$$i = 0, $$$i5 = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$ph$lcssa$i$i$i = 0, $$0$ph14$i$i$i = 0, $$07$ph13$i$i$i = 0, $$0711$i$i$i = 0, $$1$i = 0, $$1$i7 = 0, $$pre = 0, $$pre$pre = 0, $$pre33 = 0, $$pre33$pre = 0, $$pre3336 = 0, $$sroa$013$018$i = 0, $$sroa$013$018$i8 = 0, $10 = 0, $100 = 0, $101 = 0;
 var $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0;
 var $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $not$$i = 0, $not$$i4 = 0, $not$17$i = 0, $not$17$i6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = ($1|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = ((($0)) + 56|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = ((($5)) + 148|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_ii[$7 & 8191]($1)|0);
 $9 = HEAP32[$1>>2]|0;
 $10 = ((($9)) + 152|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (FUNCTION_TABLE_ii[$11 & 8191]($1)|0);
 $13 = ((($0)) + 60|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(0|0);
 if ($15) {
  STACKTOP = sp;return;
 } else {
  $$0$ph14$i$i$i = $13;$$07$ph13$i$i$i = $14;
 }
 L6: while(1) {
  $$0711$i$i$i = $$07$ph13$i$i$i;
  while(1) {
   $16 = ((($$0711$i$i$i)) + 16|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = ($17|0)<($8|0);
   if (!($18)) {
    $19 = ($8|0)<($17|0);
    if ($19) {
     break;
    }
    $20 = ((($$0711$i$i$i)) + 20|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = ($21>>>0)<($12>>>0);
    if (!($22)) {
     break;
    }
   }
   $25 = ((($$0711$i$i$i)) + 4|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = ($26|0)==(0|0);
   if ($27) {
    $$0$ph$lcssa$i$i$i = $$0$ph14$i$i$i;
    break L6;
   } else {
    $$0711$i$i$i = $26;
   }
  }
  $23 = HEAP32[$$0711$i$i$i>>2]|0;
  $24 = ($23|0)==(0|0);
  if ($24) {
   $$0$ph$lcssa$i$i$i = $$0711$i$i$i;
   break;
  } else {
   $$0$ph14$i$i$i = $$0711$i$i$i;$$07$ph13$i$i$i = $23;
  }
 }
 $28 = ($$0$ph$lcssa$i$i$i|0)==($13|0);
 if ($28) {
  STACKTOP = sp;return;
 }
 $29 = ((($$0$ph$lcssa$i$i$i)) + 16|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ($8|0)<($30|0);
 if ($31) {
  STACKTOP = sp;return;
 }
 $32 = ($30|0)<($8|0);
 if (!($32)) {
  $33 = ((($$0$ph$lcssa$i$i$i)) + 20|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = ($12>>>0)<($34>>>0);
  if ($35) {
   STACKTOP = sp;return;
  }
 }
 $36 = ((($$0$ph$lcssa$i$i$i)) + 24|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = ($37|0)==($1|0);
 if (!($38)) {
  STACKTOP = sp;return;
 }
 $39 = ((($1)) + 48|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ($40|0)==(0|0);
 if ($41) {
  $$pre3336 = $1;
 } else {
  $42 = ((($0)) + 148|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = (($43) + -1)|0;
  $45 = ((($0)) + 144|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = ($46|0)==(0|0);
  if ($47) {
   $48 = ((($0)) + 32|0);
   $49 = HEAP32[$48>>2]|0;
   $50 = ((($0)) + 36|0);
   $51 = HEAP32[$50>>2]|0;
   $52 = ($49|0)==($51|0);
   if ($52) {
    $$pre = $1;
   } else {
    $not$$i4 = ($43|0)!=(0);
    $$$i5 = $not$$i4 << 31 >> 31;
    $not$17$i6 = ($44|0)!=(0);
    $53 = $not$17$i6&1;
    $$1$i7 = (($53) + ($$$i5))|0;
    $54 = ($$1$i7|0)==(0);
    if ($54) {
     $$pre = $1;
    } else {
     $$sroa$013$018$i8 = $49;
     while(1) {
      $55 = HEAP32[$$sroa$013$018$i8>>2]|0;
      $56 = ((($55)) + 88|0);
      $57 = HEAP32[$56>>2]|0;
      $58 = (($57) + ($$1$i7))|0;
      __ZN3osg4Node38setNumChildrenRequiringUpdateTraversalEj($55,$58);
      $59 = ((($$sroa$013$018$i8)) + 4|0);
      $60 = HEAP32[$50>>2]|0;
      $61 = ($59|0)==($60|0);
      if ($61) {
       break;
      } else {
       $$sroa$013$018$i8 = $59;
      }
     }
     $$pre$pre = HEAP32[$36>>2]|0;
     $$pre = $$pre$pre;
    }
   }
  } else {
   $$pre = $1;
  }
  HEAP32[$42>>2] = $44;
  $$pre3336 = $$pre;
 }
 $62 = ((($$pre3336)) + 52|0);
 $63 = HEAP32[$62>>2]|0;
 $64 = ($63|0)==(0|0);
 if ($64) {
  $85 = $$pre3336;
 } else {
  $65 = ((($0)) + 156|0);
  $66 = HEAP32[$65>>2]|0;
  $67 = (($66) + -1)|0;
  $68 = ((($0)) + 152|0);
  $69 = HEAP32[$68>>2]|0;
  $70 = ($69|0)==(0|0);
  if ($70) {
   $71 = ((($0)) + 32|0);
   $72 = HEAP32[$71>>2]|0;
   $73 = ((($0)) + 36|0);
   $74 = HEAP32[$73>>2]|0;
   $75 = ($72|0)==($74|0);
   if ($75) {
    $$pre33 = $$pre3336;
   } else {
    $not$$i = ($66|0)!=(0);
    $$$i = $not$$i << 31 >> 31;
    $not$17$i = ($67|0)!=(0);
    $76 = $not$17$i&1;
    $$1$i = (($76) + ($$$i))|0;
    $77 = ($$1$i|0)==(0);
    if ($77) {
     $$pre33 = $$pre3336;
    } else {
     $$sroa$013$018$i = $72;
     while(1) {
      $78 = HEAP32[$$sroa$013$018$i>>2]|0;
      $79 = ((($78)) + 96|0);
      $80 = HEAP32[$79>>2]|0;
      $81 = (($80) + ($$1$i))|0;
      __ZN3osg4Node37setNumChildrenRequiringEventTraversalEj($78,$81);
      $82 = ((($$sroa$013$018$i)) + 4|0);
      $83 = HEAP32[$73>>2]|0;
      $84 = ($82|0)==($83|0);
      if ($84) {
       break;
      } else {
       $$sroa$013$018$i = $82;
      }
     }
     $$pre33$pre = HEAP32[$36>>2]|0;
     $$pre33 = $$pre33$pre;
    }
   }
  } else {
   $$pre33 = $$pre3336;
  }
  HEAP32[$65>>2] = $67;
  $85 = $$pre33;
 }
 __ZN3osg14StateAttribute12removeParentEPNS_8StateSetE($85,$0);
 $86 = HEAP32[$36>>2]|0;
 HEAP32[$2>>2] = (66344);
 $87 = ((($2)) + 4|0);
 HEAP32[$87>>2] = $0;
 $88 = ((($2)) + 8|0);
 HEAP32[$88>>2] = 8;
 $89 = ((($2)) + 12|0);
 HEAP32[$89>>2] = 0;
 $90 = HEAP32[$86>>2]|0;
 $91 = ((($90)) + 164|0);
 $92 = HEAP32[$91>>2]|0;
 __THREW__ = 0;
 (invoke_iii($92|0,($86|0),($2|0))|0);
 $93 = __THREW__; __THREW__ = 0;
 $94 = $93&1;
 if ($94) {
  $95 = ___cxa_find_matching_catch_2()|0;
  $96 = tempRet0;
  ___resumeException($95|0);
  // unreachable;
 }
 $97 = ((($$0$ph$lcssa$i$i$i)) + 4|0);
 $98 = HEAP32[$97>>2]|0;
 $99 = ($98|0)==(0|0);
 if ($99) {
  $100 = ((($$0$ph$lcssa$i$i$i)) + 8|0);
  $101 = HEAP32[$100>>2]|0;
  $102 = HEAP32[$101>>2]|0;
  $103 = ($102|0)==($$0$ph$lcssa$i$i$i|0);
  if ($103) {
   $$0$i$i$i$i = $101;
  } else {
   $107 = $100;
   while(1) {
    $106 = HEAP32[$107>>2]|0;
    $108 = ((($106)) + 8|0);
    $109 = HEAP32[$108>>2]|0;
    $110 = HEAP32[$109>>2]|0;
    $111 = ($110|0)==($106|0);
    if ($111) {
     $$0$i$i$i$i = $109;
     break;
    } else {
     $107 = $108;
    }
   }
  }
 } else {
  $$0$i$i$i$i$i = $98;
  while(1) {
   $104 = HEAP32[$$0$i$i$i$i$i>>2]|0;
   $105 = ($104|0)==(0|0);
   if ($105) {
    break;
   } else {
    $$0$i$i$i$i$i = $104;
   }
  }
  $$0$i$i$i$i = $$0$i$i$i$i$i;
 }
 $112 = HEAP32[$4>>2]|0;
 $113 = ($112|0)==($$0$ph$lcssa$i$i$i|0);
 if ($113) {
  $114 = $$0$i$i$i$i;
  HEAP32[$4>>2] = $114;
 }
 $115 = ((($0)) + 64|0);
 $116 = HEAP32[$115>>2]|0;
 $117 = (($116) + -1)|0;
 HEAP32[$115>>2] = $117;
 $118 = ((($0)) + 60|0);
 $119 = HEAP32[$118>>2]|0;
 __ZNSt3__213__tree_removeIPNS_16__tree_node_baseIPvEEEEvT_S5_($119,$$0$ph$lcssa$i$i$i);
 $120 = HEAP32[$36>>2]|0;
 $121 = ($120|0)==(0|0);
 if (!($121)) {
  $122 = ((($120)) + 8|0);
  $123 = HEAP32[$122>>2]|0;HEAP32[$122>>2] = (($123-1)|0);
  $124 = ($123|0)==(1);
  if ($124) {
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($120,1,1);
  }
 }
 __ZdlPv($$0$ph$lcssa$i$i$i);
 STACKTOP = sp;return;
}
function __ZN3osg8StateSet12getAttributeENS_14StateAttribute4TypeEj($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$i = 0, $$0$ph$lcssa$i$i$i$i = 0, $$0$ph14$i$i$i$i = 0, $$07$ph13$i$i$i$i = 0, $$0711$i$i$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 60|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  $$0$i = 0;
  return ($$0$i|0);
 } else {
  $$0$ph14$i$i$i$i = $3;$$07$ph13$i$i$i$i = $4;
 }
 L3: while(1) {
  $$0711$i$i$i$i = $$07$ph13$i$i$i$i;
  while(1) {
   $6 = ((($$0711$i$i$i$i)) + 16|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($7|0)<($1|0);
   if (!($8)) {
    $9 = ($7|0)>($1|0);
    if ($9) {
     break;
    }
    $10 = ((($$0711$i$i$i$i)) + 20|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11>>>0)<($2>>>0);
    if (!($12)) {
     break;
    }
   }
   $15 = ((($$0711$i$i$i$i)) + 4|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ($16|0)==(0|0);
   if ($17) {
    $$0$ph$lcssa$i$i$i$i = $$0$ph14$i$i$i$i;
    break L3;
   } else {
    $$0711$i$i$i$i = $16;
   }
  }
  $13 = HEAP32[$$0711$i$i$i$i>>2]|0;
  $14 = ($13|0)==(0|0);
  if ($14) {
   $$0$ph$lcssa$i$i$i$i = $$0711$i$i$i$i;
   break;
  } else {
   $$0$ph14$i$i$i$i = $$0711$i$i$i$i;$$07$ph13$i$i$i$i = $13;
  }
 }
 $18 = ($$0$ph$lcssa$i$i$i$i|0)==($3|0);
 if ($18) {
  $$0$i = 0;
  return ($$0$i|0);
 }
 $19 = ((($$0$ph$lcssa$i$i$i$i)) + 16|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)>($1|0);
 if ($21) {
  $$0$i = 0;
  return ($$0$i|0);
 }
 $22 = ($20|0)<($1|0);
 if (!($22)) {
  $23 = ((($$0$ph$lcssa$i$i$i$i)) + 20|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = ($24>>>0)>($2>>>0);
  if ($25) {
   $$0$i = 0;
   return ($$0$i|0);
  }
 }
 $26 = ((($$0$ph$lcssa$i$i$i$i)) + 24|0);
 $27 = HEAP32[$26>>2]|0;
 $$0$i = $27;
 return ($$0$i|0);
}
function __ZN3osg8StateSet10getUniformERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 92|0);
 $3 = (__ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4pairIN3osg7ref_ptrINS9_7UniformEEEjEEEENS_19__map_value_compareIS7_SE_NS_4lessIS7_EELb1EEENS5_ISE_EEE4findIS7_EENS_15__tree_iteratorISE_PNS_11__tree_nodeISE_PvEEiEERKT_($2,$1)|0);
 $4 = ((($0)) + 96|0);
 $5 = ($3|0)==($4|0);
 if ($5) {
  $$0 = 0;
  return ($$0|0);
 }
 $6 = ((($3)) + 28|0);
 $7 = HEAP32[$6>>2]|0;
 $$0 = $7;
 return ($$0|0);
}
function __ZN3osg8StateSet18getOrCreateUniformERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEENS_7Uniform4TypeEj($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ((($0)) + 92|0);
 $5 = (__ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4pairIN3osg7ref_ptrINS9_7UniformEEEjEEEENS_19__map_value_compareIS7_SE_NS_4lessIS7_EELb1EEENS5_ISE_EEE4findIS7_EENS_15__tree_iteratorISE_PNS_11__tree_nodeISE_PvEEiEERKT_($4,$1)|0);
 $6 = ((($0)) + 96|0);
 $7 = ($5|0)==($6|0);
 if (!($7)) {
  $8 = ((($5)) + 28|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ((($9)) + 44|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($11|0)==($2|0);
  if ($12) {
   $$0 = $9;
   return ($$0|0);
  }
 }
 $13 = (__Znwj(92)|0);
 __THREW__ = 0;
 invoke_viiii(3920,($13|0),($2|0),($1|0),($3|0));
 $14 = __THREW__; __THREW__ = 0;
 $15 = $14&1;
 if ($15) {
  $16 = ___cxa_find_matching_catch_2()|0;
  $17 = tempRet0;
  __ZdlPv($13);
  ___resumeException($16|0);
  // unreachable;
 }
 __ZN3osg8StateSet10addUniformEPNS_7UniformEj($0,$13,1);
 $$0 = $13;
 return ($$0|0);
}
function __ZN3osg8StateSet19getTextureAttributeEjNS_14StateAttribute4TypeE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$0$ph$lcssa$i$i$i$i = 0, $$0$ph14$i$i$i$i = 0, $$07$ph13$i$i$i$i = 0, $$0711$i$i$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 80|0);
 $4 = ((($0)) + 84|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$3>>2]|0;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 12)&-1;
 $9 = ($8>>>0)>($1>>>0);
 if (!($9)) {
  $$0 = 0;
  return ($$0|0);
 }
 $10 = $6;
 $11 = (((($10) + (($1*12)|0)|0)) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0|0);
 if ($13) {
  $$0 = 0;
  return ($$0|0);
 } else {
  $$0$ph14$i$i$i$i = $11;$$07$ph13$i$i$i$i = $12;
 }
 L6: while(1) {
  $$0711$i$i$i$i = $$07$ph13$i$i$i$i;
  while(1) {
   $14 = ((($$0711$i$i$i$i)) + 16|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = ($15|0)<($2|0);
   if (!($16)) {
    break;
   }
   $19 = ((($$0711$i$i$i$i)) + 4|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = ($20|0)==(0|0);
   if ($21) {
    $$0$ph$lcssa$i$i$i$i = $$0$ph14$i$i$i$i;
    break L6;
   } else {
    $$0711$i$i$i$i = $20;
   }
  }
  $17 = HEAP32[$$0711$i$i$i$i>>2]|0;
  $18 = ($17|0)==(0|0);
  if ($18) {
   $$0$ph$lcssa$i$i$i$i = $$0711$i$i$i$i;
   break;
  } else {
   $$0$ph14$i$i$i$i = $$0711$i$i$i$i;$$07$ph13$i$i$i$i = $17;
  }
 }
 $22 = ($$0$ph$lcssa$i$i$i$i|0)==($11|0);
 if ($22) {
  $$0 = 0;
  return ($$0|0);
 }
 $23 = ((($$0$ph$lcssa$i$i$i$i)) + 16|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)>($2|0);
 if ($25) {
  $$0 = 0;
  return ($$0|0);
 }
 $26 = ($24|0)<($2|0);
 if (!($26)) {
  $27 = ((($$0$ph$lcssa$i$i$i$i)) + 20|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = ($28|0)==(0);
  if (!($29)) {
   $$0 = 0;
   return ($$0|0);
  }
 }
 $30 = ((($$0$ph$lcssa$i$i$i$i)) + 24|0);
 $31 = HEAP32[$30>>2]|0;
 $$0 = $31;
 return ($$0|0);
}
function __ZNK3osg8StateSet19getTextureAttributeEjNS_14StateAttribute4TypeE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$0$ph$lcssa$i$i$i$i = 0, $$0$ph14$i$i$i$i = 0, $$07$ph13$i$i$i$i = 0, $$0711$i$i$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 80|0);
 $4 = ((($0)) + 84|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$3>>2]|0;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 12)&-1;
 $9 = ($8>>>0)>($1>>>0);
 if (!($9)) {
  $$0 = 0;
  return ($$0|0);
 }
 $10 = $6;
 $11 = (((($10) + (($1*12)|0)|0)) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0|0);
 if ($13) {
  $$0 = 0;
  return ($$0|0);
 } else {
  $$0$ph14$i$i$i$i = $11;$$07$ph13$i$i$i$i = $12;
 }
 L6: while(1) {
  $$0711$i$i$i$i = $$07$ph13$i$i$i$i;
  while(1) {
   $14 = ((($$0711$i$i$i$i)) + 16|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = ($15|0)<($2|0);
   if (!($16)) {
    break;
   }
   $19 = ((($$0711$i$i$i$i)) + 4|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = ($20|0)==(0|0);
   if ($21) {
    $$0$ph$lcssa$i$i$i$i = $$0$ph14$i$i$i$i;
    break L6;
   } else {
    $$0711$i$i$i$i = $20;
   }
  }
  $17 = HEAP32[$$0711$i$i$i$i>>2]|0;
  $18 = ($17|0)==(0|0);
  if ($18) {
   $$0$ph$lcssa$i$i$i$i = $$0711$i$i$i$i;
   break;
  } else {
   $$0$ph14$i$i$i$i = $$0711$i$i$i$i;$$07$ph13$i$i$i$i = $17;
  }
 }
 $22 = ($$0$ph$lcssa$i$i$i$i|0)==($11|0);
 if ($22) {
  $$0 = 0;
  return ($$0|0);
 }
 $23 = ((($$0$ph$lcssa$i$i$i$i)) + 16|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)>($2|0);
 if ($25) {
  $$0 = 0;
  return ($$0|0);
 }
 $26 = ($24|0)<($2|0);
 if (!($26)) {
  $27 = ((($$0$ph$lcssa$i$i$i$i)) + 20|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = ($28|0)==(0);
  if (!($29)) {
   $$0 = 0;
   return ($$0|0);
  }
 }
 $30 = ((($$0$ph$lcssa$i$i$i$i)) + 24|0);
 $31 = HEAP32[$30>>2]|0;
 $$0 = $31;
 return ($$0|0);
}
function __ZNK3osg8StateSet30checkValidityOfAssociatedModesERNS_5StateE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i$i$i = 0, $$0$i$i$i$i10 = 0, $$0$off0$ = 0, $$0$off0$lcssa = 0, $$0$off042 = 0, $$2$off0$lcssa = 0, $$2$off038 = 0, $$3$off0$ = 0, $$3$off0$lcssa = 0, $$3$off036 = 0, $$pre = 0, $$sroa$017$0$be = 0, $$sroa$017$035 = 0, $$sroa$023$037 = 0, $$sroa$030$0$be = 0, $$sroa$030$041 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 56|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 60|0);
 $5 = ($3|0)==($4|0);
 if ($5) {
  $$0$off0$lcssa = 1;
 } else {
  $$0$off042 = 1;$$sroa$030$041 = $3;
  while(1) {
   $11 = ((($$sroa$030$041)) + 24|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = HEAP32[$12>>2]|0;
   $14 = ((($13)) + 168|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_iii[$15 & 8191]($12,$1)|0);
   $$0$off0$ = $$0$off042 & $16;
   $17 = ((($$sroa$030$041)) + 4|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = ($18|0)==(0|0);
   if ($19) {
    $20 = ((($$sroa$030$041)) + 8|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = HEAP32[$21>>2]|0;
    $23 = ($22|0)==($$sroa$030$041|0);
    if ($23) {
     $$sroa$030$0$be = $21;
    } else {
     $28 = $20;
     while(1) {
      $27 = HEAP32[$28>>2]|0;
      $29 = ((($27)) + 8|0);
      $30 = HEAP32[$29>>2]|0;
      $31 = HEAP32[$30>>2]|0;
      $32 = ($31|0)==($27|0);
      if ($32) {
       $$sroa$030$0$be = $30;
       break;
      } else {
       $28 = $29;
      }
     }
    }
   } else {
    $$0$i$i$i$i10 = $18;
    while(1) {
     $25 = HEAP32[$$0$i$i$i$i10>>2]|0;
     $26 = ($25|0)==(0|0);
     if ($26) {
      break;
     } else {
      $$0$i$i$i$i10 = $25;
     }
    }
    $$sroa$030$0$be = $$0$i$i$i$i10;
   }
   $24 = ($$sroa$030$0$be|0)==($4|0);
   if ($24) {
    $$0$off0$lcssa = $$0$off0$;
    break;
   } else {
    $$0$off042 = $$0$off0$;$$sroa$030$041 = $$sroa$030$0$be;
   }
  }
 }
 $6 = ((($0)) + 80|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($0)) + 84|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($7|0)==($9|0);
 if ($10) {
  $$2$off0$lcssa = $$0$off0$lcssa;
  return ($$2$off0$lcssa|0);
 } else {
  $$2$off038 = $$0$off0$lcssa;$$sroa$023$037 = $7;$61 = $9;
 }
 while(1) {
  $33 = HEAP32[$$sroa$023$037>>2]|0;
  $34 = ((($$sroa$023$037)) + 4|0);
  $35 = ($33|0)==($34|0);
  if ($35) {
   $$3$off0$lcssa = $$2$off038;$38 = $61;
  } else {
   $$3$off036 = $$2$off038;$$sroa$017$035 = $33;
   while(1) {
    $39 = ((($$sroa$017$035)) + 24|0);
    $40 = HEAP32[$39>>2]|0;
    $41 = HEAP32[$40>>2]|0;
    $42 = ((($41)) + 168|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = (FUNCTION_TABLE_iii[$43 & 8191]($40,$1)|0);
    $$3$off0$ = $$3$off036 & $44;
    $45 = ((($$sroa$017$035)) + 4|0);
    $46 = HEAP32[$45>>2]|0;
    $47 = ($46|0)==(0|0);
    if ($47) {
     $48 = ((($$sroa$017$035)) + 8|0);
     $49 = HEAP32[$48>>2]|0;
     $50 = HEAP32[$49>>2]|0;
     $51 = ($50|0)==($$sroa$017$035|0);
     if ($51) {
      $$sroa$017$0$be = $49;
     } else {
      $56 = $48;
      while(1) {
       $55 = HEAP32[$56>>2]|0;
       $57 = ((($55)) + 8|0);
       $58 = HEAP32[$57>>2]|0;
       $59 = HEAP32[$58>>2]|0;
       $60 = ($59|0)==($55|0);
       if ($60) {
        $$sroa$017$0$be = $58;
        break;
       } else {
        $56 = $57;
       }
      }
     }
    } else {
     $$0$i$i$i$i = $46;
     while(1) {
      $53 = HEAP32[$$0$i$i$i$i>>2]|0;
      $54 = ($53|0)==(0|0);
      if ($54) {
       break;
      } else {
       $$0$i$i$i$i = $53;
      }
     }
     $$sroa$017$0$be = $$0$i$i$i$i;
    }
    $52 = ($$sroa$017$0$be|0)==($34|0);
    if ($52) {
     break;
    } else {
     $$3$off036 = $$3$off0$;$$sroa$017$035 = $$sroa$017$0$be;
    }
   }
   $$pre = HEAP32[$8>>2]|0;
   $$3$off0$lcssa = $$3$off0$;$38 = $$pre;
  }
  $36 = ((($$sroa$023$037)) + 12|0);
  $37 = ($36|0)==($38|0);
  if ($37) {
   $$2$off0$lcssa = $$3$off0$lcssa;
   break;
  } else {
   $$2$off038 = $$3$off0$lcssa;$$sroa$023$037 = $36;$61 = $38;
  }
 }
 return ($$2$off0$lcssa|0);
}
function __ZNK3osg8StateSet16compileGLObjectsERNS_5StateE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i$i$i = 0, $$0$i$i$i$i$us$us = 0, $$0$i$i$i$i10 = 0, $$0$i$i$i$i10$us = 0, $$pre = 0, $$pre63 = 0, $$sroa$017$0$be = 0, $$sroa$017$0$be$us$us = 0, $$sroa$017$037 = 0, $$sroa$017$037$us$us = 0, $$sroa$024$038 = 0, $$sroa$024$038$us = 0, $$sroa$031$0$be = 0, $$sroa$031$0$be$us = 0, $$sroa$031$055 = 0, $$sroa$031$055$us = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 344|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(2);
 if ($4) {
  (__ZNK3osg5State13checkGLErrorsEPKcS2_($1,153222,0)|0);
 }
 $5 = ((($0)) + 56|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($0)) + 60|0);
 $8 = ($6|0)==($7|0);
 if (!($8)) {
  if ($4) {
   $$sroa$031$055$us = $6;
   while(1) {
    $9 = ((($$sroa$031$055$us)) + 24|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = HEAP32[$10>>2]|0;
    $12 = ((($11)) + 176|0);
    $13 = HEAP32[$12>>2]|0;
    FUNCTION_TABLE_vii[$13 & 8191]($10,$1);
    $14 = HEAP32[$9>>2]|0;
    $15 = HEAP32[$14>>2]|0;
    $16 = ((($15)) + 28|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = (FUNCTION_TABLE_ii[$17 & 8191]($14)|0);
    (__ZNK3osg5State13checkGLErrorsEPKcS2_($1,153258,$18)|0);
    $19 = ((($$sroa$031$055$us)) + 4|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = ($20|0)==(0|0);
    if ($21) {
     $24 = ((($$sroa$031$055$us)) + 8|0);
     $25 = HEAP32[$24>>2]|0;
     $26 = HEAP32[$25>>2]|0;
     $27 = ($26|0)==($$sroa$031$055$us|0);
     if ($27) {
      $$sroa$031$0$be$us = $25;
     } else {
      $29 = $24;
      while(1) {
       $28 = HEAP32[$29>>2]|0;
       $30 = ((($28)) + 8|0);
       $31 = HEAP32[$30>>2]|0;
       $32 = HEAP32[$31>>2]|0;
       $33 = ($32|0)==($28|0);
       if ($33) {
        $$sroa$031$0$be$us = $31;
        break;
       } else {
        $29 = $30;
       }
      }
     }
    } else {
     $$0$i$i$i$i10$us = $20;
     while(1) {
      $22 = HEAP32[$$0$i$i$i$i10$us>>2]|0;
      $23 = ($22|0)==(0|0);
      if ($23) {
       break;
      } else {
       $$0$i$i$i$i10$us = $22;
      }
     }
     $$sroa$031$0$be$us = $$0$i$i$i$i10$us;
    }
    $34 = ($$sroa$031$0$be$us|0)==($7|0);
    if ($34) {
     break;
    } else {
     $$sroa$031$055$us = $$sroa$031$0$be$us;
    }
   }
  } else {
   $$sroa$031$055 = $6;
   while(1) {
    $72 = ((($$sroa$031$055)) + 24|0);
    $73 = HEAP32[$72>>2]|0;
    $74 = HEAP32[$73>>2]|0;
    $75 = ((($74)) + 176|0);
    $76 = HEAP32[$75>>2]|0;
    FUNCTION_TABLE_vii[$76 & 8191]($73,$1);
    $77 = ((($$sroa$031$055)) + 4|0);
    $78 = HEAP32[$77>>2]|0;
    $79 = ($78|0)==(0|0);
    if ($79) {
     $80 = ((($$sroa$031$055)) + 8|0);
     $81 = HEAP32[$80>>2]|0;
     $82 = HEAP32[$81>>2]|0;
     $83 = ($82|0)==($$sroa$031$055|0);
     if ($83) {
      $$sroa$031$0$be = $81;
     } else {
      $88 = $80;
      while(1) {
       $87 = HEAP32[$88>>2]|0;
       $89 = ((($87)) + 8|0);
       $90 = HEAP32[$89>>2]|0;
       $91 = HEAP32[$90>>2]|0;
       $92 = ($91|0)==($87|0);
       if ($92) {
        $$sroa$031$0$be = $90;
        break;
       } else {
        $88 = $89;
       }
      }
     }
    } else {
     $$0$i$i$i$i10 = $78;
     while(1) {
      $85 = HEAP32[$$0$i$i$i$i10>>2]|0;
      $86 = ($85|0)==(0|0);
      if ($86) {
       break;
      } else {
       $$0$i$i$i$i10 = $85;
      }
     }
     $$sroa$031$0$be = $$0$i$i$i$i10;
    }
    $84 = ($$sroa$031$0$be|0)==($7|0);
    if ($84) {
     break;
    } else {
     $$sroa$031$055 = $$sroa$031$0$be;
    }
   }
  }
 }
 $35 = ((($0)) + 80|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = ((($0)) + 84|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = ($36|0)==($38|0);
 if ($39) {
  return;
 }
 if ($4) {
  $$sroa$024$038$us = $36;$120 = $38;
  while(1) {
   $40 = HEAP32[$$sroa$024$038$us>>2]|0;
   $41 = ((($$sroa$024$038$us)) + 4|0);
   $42 = ($40|0)==($41|0);
   if ($42) {
    $45 = $120;
   } else {
    $$sroa$017$037$us$us = $40;
    while(1) {
     $46 = ((($$sroa$017$037$us$us)) + 24|0);
     $47 = HEAP32[$46>>2]|0;
     $48 = HEAP32[$47>>2]|0;
     $49 = ((($48)) + 176|0);
     $50 = HEAP32[$49>>2]|0;
     FUNCTION_TABLE_vii[$50 & 8191]($47,$1);
     $51 = HEAP32[$46>>2]|0;
     $52 = HEAP32[$51>>2]|0;
     $53 = ((($52)) + 28|0);
     $54 = HEAP32[$53>>2]|0;
     $55 = (FUNCTION_TABLE_ii[$54 & 8191]($51)|0);
     (__ZNK3osg5State13checkGLErrorsEPKcS2_($1,153298,$55)|0);
     $56 = ((($$sroa$017$037$us$us)) + 4|0);
     $57 = HEAP32[$56>>2]|0;
     $58 = ($57|0)==(0|0);
     if ($58) {
      $59 = ((($$sroa$017$037$us$us)) + 8|0);
      $60 = HEAP32[$59>>2]|0;
      $61 = HEAP32[$60>>2]|0;
      $62 = ($61|0)==($$sroa$017$037$us$us|0);
      if ($62) {
       $$sroa$017$0$be$us$us = $60;
      } else {
       $67 = $59;
       while(1) {
        $66 = HEAP32[$67>>2]|0;
        $68 = ((($66)) + 8|0);
        $69 = HEAP32[$68>>2]|0;
        $70 = HEAP32[$69>>2]|0;
        $71 = ($70|0)==($66|0);
        if ($71) {
         $$sroa$017$0$be$us$us = $69;
         break;
        } else {
         $67 = $68;
        }
       }
      }
     } else {
      $$0$i$i$i$i$us$us = $57;
      while(1) {
       $64 = HEAP32[$$0$i$i$i$i$us$us>>2]|0;
       $65 = ($64|0)==(0|0);
       if ($65) {
        break;
       } else {
        $$0$i$i$i$i$us$us = $64;
       }
      }
      $$sroa$017$0$be$us$us = $$0$i$i$i$i$us$us;
     }
     $63 = ($$sroa$017$0$be$us$us|0)==($41|0);
     if ($63) {
      break;
     } else {
      $$sroa$017$037$us$us = $$sroa$017$0$be$us$us;
     }
    }
    $$pre63 = HEAP32[$37>>2]|0;
    $45 = $$pre63;
   }
   $43 = ((($$sroa$024$038$us)) + 12|0);
   $44 = ($43|0)==($45|0);
   if ($44) {
    break;
   } else {
    $$sroa$024$038$us = $43;$120 = $45;
   }
  }
  return;
 } else {
  $$sroa$024$038 = $36;$121 = $38;
  while(1) {
   $93 = HEAP32[$$sroa$024$038>>2]|0;
   $94 = ((($$sroa$024$038)) + 4|0);
   $95 = ($93|0)==($94|0);
   if ($95) {
    $98 = $121;
   } else {
    $$sroa$017$037 = $93;
    while(1) {
     $99 = ((($$sroa$017$037)) + 24|0);
     $100 = HEAP32[$99>>2]|0;
     $101 = HEAP32[$100>>2]|0;
     $102 = ((($101)) + 176|0);
     $103 = HEAP32[$102>>2]|0;
     FUNCTION_TABLE_vii[$103 & 8191]($100,$1);
     $104 = ((($$sroa$017$037)) + 4|0);
     $105 = HEAP32[$104>>2]|0;
     $106 = ($105|0)==(0|0);
     if ($106) {
      $107 = ((($$sroa$017$037)) + 8|0);
      $108 = HEAP32[$107>>2]|0;
      $109 = HEAP32[$108>>2]|0;
      $110 = ($109|0)==($$sroa$017$037|0);
      if ($110) {
       $$sroa$017$0$be = $108;
      } else {
       $115 = $107;
       while(1) {
        $114 = HEAP32[$115>>2]|0;
        $116 = ((($114)) + 8|0);
        $117 = HEAP32[$116>>2]|0;
        $118 = HEAP32[$117>>2]|0;
        $119 = ($118|0)==($114|0);
        if ($119) {
         $$sroa$017$0$be = $117;
         break;
        } else {
         $115 = $116;
        }
       }
      }
     } else {
      $$0$i$i$i$i = $105;
      while(1) {
       $112 = HEAP32[$$0$i$i$i$i>>2]|0;
       $113 = ($112|0)==(0|0);
       if ($113) {
        break;
       } else {
        $$0$i$i$i$i = $112;
       }
      }
      $$sroa$017$0$be = $$0$i$i$i$i;
     }
     $111 = ($$sroa$017$0$be|0)==($94|0);
     if ($111) {
      break;
     } else {
      $$sroa$017$037 = $$sroa$017$0$be;
     }
    }
    $$pre = HEAP32[$37>>2]|0;
    $98 = $$pre;
   }
   $96 = ((($$sroa$024$038)) + 12|0);
   $97 = ($96|0)==($98|0);
   if ($97) {
    break;
   } else {
    $$sroa$024$038 = $96;$121 = $98;
   }
  }
  return;
 }
}
function __ZN3osg8StateSet19setRenderBinDetailsEiRKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEENS0_13RenderBinModeE($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ((($0)) + 120|0);
 HEAP32[$4>>2] = $3;
 $5 = ((($0)) + 124|0);
 HEAP32[$5>>2] = $1;
 $6 = ((($0)) + 128|0);
 (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEaSERKS5_($6,$2)|0);
 return;
}
function __ZN3osg8StateSet21removeAssociatedModesEPKNS_14StateAttributeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 HEAP32[$2>>2] = (66368);
 $3 = ((($2)) + 4|0);
 HEAP32[$3>>2] = $0;
 $4 = ((($2)) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = HEAP32[$1>>2]|0;
 $6 = ((($5)) + 164|0);
 $7 = HEAP32[$6>>2]|0;
 __THREW__ = 0;
 (invoke_iii($7|0,($1|0),($2|0))|0);
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $10 = ___cxa_find_matching_catch_2()|0;
  $11 = tempRet0;
  ___resumeException($10|0);
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN26RemoveAssociateModesHelperD0Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($0);
 return;
}
function __ZN26RemoveAssociateModesHelper8usesModeEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 __ZN3osg8StateSet10removeModeEj($3,$1);
 return;
}
function __ZN26RemoveAssociateModesHelper15usesTextureModeEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 __ZN3osg8StateSet17removeTextureModeEjj($3,$5,$1);
 return;
}
function __ZN3osg8StateSet18runUpdateCallbacksEPNS_11NodeVisitorE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i$i$i = 0, $$0$i$i$i$i25 = 0, $$0$i$i$i$i31 = 0, $$062 = 0, $$in = 0, $$sroa$038$0$be = 0, $$sroa$038$059 = 0, $$sroa$045$0$be = 0, $$sroa$045$060 = 0, $$sroa$052$0$be = 0, $$sroa$052$064 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $11 = 0;
 var $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 144|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = HEAP32[$3>>2]|0;
  $6 = ((($5)) + 24|0);
  $7 = HEAP32[$6>>2]|0;
  FUNCTION_TABLE_viii[$7 & 8191]($3,$0,$1);
 }
 $8 = ((($0)) + 148|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0);
 if ($10) {
  return;
 }
 $11 = ((($0)) + 56|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ((($0)) + 60|0);
 $14 = ($12|0)==($13|0);
 if (!($14)) {
  $$sroa$052$064 = $12;
  while(1) {
   $20 = ((($$sroa$052$064)) + 24|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = ((($21)) + 48|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = ($23|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$23>>2]|0;
    $26 = ((($25)) + 32|0);
    $27 = HEAP32[$26>>2]|0;
    FUNCTION_TABLE_viii[$27 & 8191]($23,$21,$1);
   }
   $28 = ((($$sroa$052$064)) + 4|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = ($29|0)==(0|0);
   if ($30) {
    $31 = ((($$sroa$052$064)) + 8|0);
    $32 = HEAP32[$31>>2]|0;
    $33 = HEAP32[$32>>2]|0;
    $34 = ($33|0)==($$sroa$052$064|0);
    if ($34) {
     $$sroa$052$0$be = $32;
    } else {
     $39 = $31;
     while(1) {
      $38 = HEAP32[$39>>2]|0;
      $40 = ((($38)) + 8|0);
      $41 = HEAP32[$40>>2]|0;
      $42 = HEAP32[$41>>2]|0;
      $43 = ($42|0)==($38|0);
      if ($43) {
       $$sroa$052$0$be = $41;
       break;
      } else {
       $39 = $40;
      }
     }
    }
   } else {
    $$0$i$i$i$i31 = $29;
    while(1) {
     $36 = HEAP32[$$0$i$i$i$i31>>2]|0;
     $37 = ($36|0)==(0|0);
     if ($37) {
      break;
     } else {
      $$0$i$i$i$i31 = $36;
     }
    }
    $$sroa$052$0$be = $$0$i$i$i$i31;
   }
   $35 = ($$sroa$052$0$be|0)==($13|0);
   if ($35) {
    break;
   } else {
    $$sroa$052$064 = $$sroa$052$0$be;
   }
  }
 }
 $15 = ((($0)) + 80|0);
 $16 = ((($0)) + 84|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = HEAP32[$15>>2]|0;
 $19 = ($17|0)==($18|0);
 if (!($19)) {
  $$062 = 0;$$in = $18;
  while(1) {
   $48 = $$in;
   $49 = (($48) + (($$062*12)|0)|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = (((($48) + (($$062*12)|0)|0)) + 4|0);
   $52 = ($50|0)==($51|0);
   if (!($52)) {
    $$sroa$045$060 = $50;
    while(1) {
     $59 = ((($$sroa$045$060)) + 24|0);
     $60 = HEAP32[$59>>2]|0;
     $61 = ((($60)) + 48|0);
     $62 = HEAP32[$61>>2]|0;
     $63 = ($62|0)==(0|0);
     if (!($63)) {
      $64 = HEAP32[$62>>2]|0;
      $65 = ((($64)) + 32|0);
      $66 = HEAP32[$65>>2]|0;
      FUNCTION_TABLE_viii[$66 & 8191]($62,$60,$1);
     }
     $67 = ((($$sroa$045$060)) + 4|0);
     $68 = HEAP32[$67>>2]|0;
     $69 = ($68|0)==(0|0);
     if ($69) {
      $70 = ((($$sroa$045$060)) + 8|0);
      $71 = HEAP32[$70>>2]|0;
      $72 = HEAP32[$71>>2]|0;
      $73 = ($72|0)==($$sroa$045$060|0);
      if ($73) {
       $$sroa$045$0$be = $71;
      } else {
       $78 = $70;
       while(1) {
        $77 = HEAP32[$78>>2]|0;
        $79 = ((($77)) + 8|0);
        $80 = HEAP32[$79>>2]|0;
        $81 = HEAP32[$80>>2]|0;
        $82 = ($81|0)==($77|0);
        if ($82) {
         $$sroa$045$0$be = $80;
         break;
        } else {
         $78 = $79;
        }
       }
      }
     } else {
      $$0$i$i$i$i25 = $68;
      while(1) {
       $75 = HEAP32[$$0$i$i$i$i25>>2]|0;
       $76 = ($75|0)==(0|0);
       if ($76) {
        break;
       } else {
        $$0$i$i$i$i25 = $75;
       }
      }
      $$sroa$045$0$be = $$0$i$i$i$i25;
     }
     $74 = ($$sroa$045$0$be|0)==($51|0);
     if ($74) {
      break;
     } else {
      $$sroa$045$060 = $$sroa$045$0$be;
     }
    }
   }
   $53 = (($$062) + 1)|0;
   $54 = HEAP32[$16>>2]|0;
   $55 = HEAP32[$15>>2]|0;
   $56 = (($54) - ($55))|0;
   $57 = (($56|0) / 12)&-1;
   $58 = ($53>>>0)<($57>>>0);
   if ($58) {
    $$062 = $53;$$in = $55;
   } else {
    break;
   }
  }
 }
 $44 = ((($0)) + 92|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = ((($0)) + 96|0);
 $47 = ($45|0)==($46|0);
 if ($47) {
  return;
 } else {
  $$sroa$038$059 = $45;
 }
 while(1) {
  $83 = ((($$sroa$038$059)) + 28|0);
  $84 = HEAP32[$83>>2]|0;
  $85 = ((($84)) + 80|0);
  $86 = HEAP32[$85>>2]|0;
  $87 = ($86|0)==(0|0);
  if (!($87)) {
   $88 = HEAP32[$86>>2]|0;
   $89 = ((($88)) + 32|0);
   $90 = HEAP32[$89>>2]|0;
   FUNCTION_TABLE_viii[$90 & 8191]($86,$84,$1);
  }
  $91 = ((($$sroa$038$059)) + 4|0);
  $92 = HEAP32[$91>>2]|0;
  $93 = ($92|0)==(0|0);
  if ($93) {
   $94 = ((($$sroa$038$059)) + 8|0);
   $95 = HEAP32[$94>>2]|0;
   $96 = HEAP32[$95>>2]|0;
   $97 = ($96|0)==($$sroa$038$059|0);
   if ($97) {
    $$sroa$038$0$be = $95;
   } else {
    $102 = $94;
    while(1) {
     $101 = HEAP32[$102>>2]|0;
     $103 = ((($101)) + 8|0);
     $104 = HEAP32[$103>>2]|0;
     $105 = HEAP32[$104>>2]|0;
     $106 = ($105|0)==($101|0);
     if ($106) {
      $$sroa$038$0$be = $104;
      break;
     } else {
      $102 = $103;
     }
    }
   }
  } else {
   $$0$i$i$i$i = $92;
   while(1) {
    $99 = HEAP32[$$0$i$i$i$i>>2]|0;
    $100 = ($99|0)==(0|0);
    if ($100) {
     break;
    } else {
     $$0$i$i$i$i = $99;
    }
   }
   $$sroa$038$0$be = $$0$i$i$i$i;
  }
  $98 = ($$sroa$038$0$be|0)==($46|0);
  if ($98) {
   break;
  } else {
   $$sroa$038$059 = $$sroa$038$0$be;
  }
 }
 return;
}
function __ZN3osg8StateSet17runEventCallbacksEPNS_11NodeVisitorE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i$i$i = 0, $$0$i$i$i$i25 = 0, $$0$i$i$i$i31 = 0, $$062 = 0, $$in = 0, $$sroa$038$0$be = 0, $$sroa$038$059 = 0, $$sroa$045$0$be = 0, $$sroa$045$060 = 0, $$sroa$052$0$be = 0, $$sroa$052$064 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $11 = 0;
 var $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 152|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = HEAP32[$3>>2]|0;
  $6 = ((($5)) + 24|0);
  $7 = HEAP32[$6>>2]|0;
  FUNCTION_TABLE_viii[$7 & 8191]($3,$0,$1);
 }
 $8 = ((($0)) + 156|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0);
 if ($10) {
  return;
 }
 $11 = ((($0)) + 56|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ((($0)) + 60|0);
 $14 = ($12|0)==($13|0);
 if (!($14)) {
  $$sroa$052$064 = $12;
  while(1) {
   $20 = ((($$sroa$052$064)) + 24|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = ((($21)) + 52|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = ($23|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$23>>2]|0;
    $26 = ((($25)) + 32|0);
    $27 = HEAP32[$26>>2]|0;
    FUNCTION_TABLE_viii[$27 & 8191]($23,$21,$1);
   }
   $28 = ((($$sroa$052$064)) + 4|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = ($29|0)==(0|0);
   if ($30) {
    $31 = ((($$sroa$052$064)) + 8|0);
    $32 = HEAP32[$31>>2]|0;
    $33 = HEAP32[$32>>2]|0;
    $34 = ($33|0)==($$sroa$052$064|0);
    if ($34) {
     $$sroa$052$0$be = $32;
    } else {
     $39 = $31;
     while(1) {
      $38 = HEAP32[$39>>2]|0;
      $40 = ((($38)) + 8|0);
      $41 = HEAP32[$40>>2]|0;
      $42 = HEAP32[$41>>2]|0;
      $43 = ($42|0)==($38|0);
      if ($43) {
       $$sroa$052$0$be = $41;
       break;
      } else {
       $39 = $40;
      }
     }
    }
   } else {
    $$0$i$i$i$i31 = $29;
    while(1) {
     $36 = HEAP32[$$0$i$i$i$i31>>2]|0;
     $37 = ($36|0)==(0|0);
     if ($37) {
      break;
     } else {
      $$0$i$i$i$i31 = $36;
     }
    }
    $$sroa$052$0$be = $$0$i$i$i$i31;
   }
   $35 = ($$sroa$052$0$be|0)==($13|0);
   if ($35) {
    break;
   } else {
    $$sroa$052$064 = $$sroa$052$0$be;
   }
  }
 }
 $15 = ((($0)) + 80|0);
 $16 = ((($0)) + 84|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = HEAP32[$15>>2]|0;
 $19 = ($17|0)==($18|0);
 if (!($19)) {
  $$062 = 0;$$in = $18;
  while(1) {
   $48 = $$in;
   $49 = (($48) + (($$062*12)|0)|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = (((($48) + (($$062*12)|0)|0)) + 4|0);
   $52 = ($50|0)==($51|0);
   if (!($52)) {
    $$sroa$045$060 = $50;
    while(1) {
     $59 = ((($$sroa$045$060)) + 24|0);
     $60 = HEAP32[$59>>2]|0;
     $61 = ((($60)) + 52|0);
     $62 = HEAP32[$61>>2]|0;
     $63 = ($62|0)==(0|0);
     if (!($63)) {
      $64 = HEAP32[$62>>2]|0;
      $65 = ((($64)) + 32|0);
      $66 = HEAP32[$65>>2]|0;
      FUNCTION_TABLE_viii[$66 & 8191]($62,$60,$1);
     }
     $67 = ((($$sroa$045$060)) + 4|0);
     $68 = HEAP32[$67>>2]|0;
     $69 = ($68|0)==(0|0);
     if ($69) {
      $70 = ((($$sroa$045$060)) + 8|0);
      $71 = HEAP32[$70>>2]|0;
      $72 = HEAP32[$71>>2]|0;
      $73 = ($72|0)==($$sroa$045$060|0);
      if ($73) {
       $$sroa$045$0$be = $71;
      } else {
       $78 = $70;
       while(1) {
        $77 = HEAP32[$78>>2]|0;
        $79 = ((($77)) + 8|0);
        $80 = HEAP32[$79>>2]|0;
        $81 = HEAP32[$80>>2]|0;
        $82 = ($81|0)==($77|0);
        if ($82) {
         $$sroa$045$0$be = $80;
         break;
        } else {
         $78 = $79;
        }
       }
      }
     } else {
      $$0$i$i$i$i25 = $68;
      while(1) {
       $75 = HEAP32[$$0$i$i$i$i25>>2]|0;
       $76 = ($75|0)==(0|0);
       if ($76) {
        break;
       } else {
        $$0$i$i$i$i25 = $75;
       }
      }
      $$sroa$045$0$be = $$0$i$i$i$i25;
     }
     $74 = ($$sroa$045$0$be|0)==($51|0);
     if ($74) {
      break;
     } else {
      $$sroa$045$060 = $$sroa$045$0$be;
     }
    }
   }
   $53 = (($$062) + 1)|0;
   $54 = HEAP32[$16>>2]|0;
   $55 = HEAP32[$15>>2]|0;
   $56 = (($54) - ($55))|0;
   $57 = (($56|0) / 12)&-1;
   $58 = ($53>>>0)<($57>>>0);
   if ($58) {
    $$062 = $53;$$in = $55;
   } else {
    break;
   }
  }
 }
 $44 = ((($0)) + 92|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = ((($0)) + 96|0);
 $47 = ($45|0)==($46|0);
 if ($47) {
  return;
 } else {
  $$sroa$038$059 = $45;
 }
 while(1) {
  $83 = ((($$sroa$038$059)) + 28|0);
  $84 = HEAP32[$83>>2]|0;
  $85 = ((($84)) + 84|0);
  $86 = HEAP32[$85>>2]|0;
  $87 = ($86|0)==(0|0);
  if (!($87)) {
   $88 = HEAP32[$86>>2]|0;
   $89 = ((($88)) + 32|0);
   $90 = HEAP32[$89>>2]|0;
   FUNCTION_TABLE_viii[$90 & 8191]($86,$84,$1);
  }
  $91 = ((($$sroa$038$059)) + 4|0);
  $92 = HEAP32[$91>>2]|0;
  $93 = ($92|0)==(0|0);
  if ($93) {
   $94 = ((($$sroa$038$059)) + 8|0);
   $95 = HEAP32[$94>>2]|0;
   $96 = HEAP32[$95>>2]|0;
   $97 = ($96|0)==($$sroa$038$059|0);
   if ($97) {
    $$sroa$038$0$be = $95;
   } else {
    $102 = $94;
    while(1) {
     $101 = HEAP32[$102>>2]|0;
     $103 = ((($101)) + 8|0);
     $104 = HEAP32[$103>>2]|0;
     $105 = HEAP32[$104>>2]|0;
     $106 = ($105|0)==($101|0);
     if ($106) {
      $$sroa$038$0$be = $104;
      break;
     } else {
      $102 = $103;
     }
    }
   }
  } else {
   $$0$i$i$i$i = $92;
   while(1) {
    $99 = HEAP32[$$0$i$i$i$i>>2]|0;
    $100 = ($99|0)==(0|0);
    if ($100) {
     break;
    } else {
     $$0$i$i$i$i = $99;
    }
   }
   $$sroa$038$0$be = $$0$i$i$i$i;
  }
  $98 = ($$sroa$038$0$be|0)==($46|0);
  if ($98) {
   break;
  } else {
   $$sroa$038$059 = $$sroa$038$0$be;
  }
 }
 return;
}
function __ZN3osg5StatsC2ERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$3 = 0, $$36 = 0, $$4 = 0, $$47 = 0, $$pre$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg10ReferencedC2Ev($0);
 HEAP32[$0>>2] = (66392);
 $2 = ((($0)) + 12|0);
 __THREW__ = 0;
 invoke_vii(3457,($2|0),($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $21 = ___cxa_find_matching_catch_2()|0;
  $22 = tempRet0;
  $$4 = $22;$$47 = $21;
 } else {
  $5 = ((($0)) + 24|0);
  __THREW__ = 0;
  invoke_vii(3507,($5|0),0);
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if ($7) {
   $23 = ___cxa_find_matching_catch_2()|0;
   $24 = tempRet0;
   $$3 = $24;$$36 = $23;
  } else {
   $8 = ((($0)) + 44|0);
   HEAP32[$8>>2] = 0;
   $9 = ((($0)) + 48|0);
   HEAP32[$9>>2] = 0;
   $10 = ((($0)) + 52|0);
   HEAP32[$10>>2] = 0;
   $11 = ((($0)) + 56|0);
   $12 = ((($0)) + 60|0);
   HEAP32[$12>>2] = 0;
   $13 = ((($0)) + 64|0);
   HEAP32[$13>>2] = 0;
   $14 = ((($0)) + 60|0);
   HEAP32[$11>>2] = $14;
   $15 = ((($0)) + 68|0);
   $16 = ((($0)) + 72|0);
   HEAP32[$16>>2] = 0;
   $17 = ((($0)) + 76|0);
   HEAP32[$17>>2] = 0;
   $18 = ((($0)) + 72|0);
   HEAP32[$15>>2] = $18;
   __THREW__ = 0;
   invoke_vii(3959,($0|0),25);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    return;
   }
   $25 = ___cxa_find_matching_catch_2()|0;
   $26 = tempRet0;
   $27 = HEAP32[$18>>2]|0;
   __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEbEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($15,$27);
   $28 = HEAP32[$14>>2]|0;
   __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEdEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($11,$28);
   $29 = HEAP32[$8>>2]|0;
   $30 = ($29|0)==(0|0);
   if (!($30)) {
    $31 = HEAP32[$9>>2]|0;
    $32 = ($31|0)==($29|0);
    if ($32) {
     $39 = $29;
    } else {
     $34 = $31;
     while(1) {
      $33 = ((($34)) + -12|0);
      HEAP32[$9>>2] = $33;
      $35 = ((($34)) + -8|0);
      $36 = HEAP32[$35>>2]|0;
      __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEdEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($33,$36);
      $37 = HEAP32[$9>>2]|0;
      $38 = ($37|0)==($29|0);
      if ($38) {
       break;
      } else {
       $34 = $37;
      }
     }
     $$pre$i = HEAP32[$8>>2]|0;
     $39 = $$pre$i;
    }
    __ZdlPv($39);
   }
   __THREW__ = 0;
   invoke_vi(707,($5|0));
   $40 = __THREW__; __THREW__ = 0;
   $41 = $40&1;
   if ($41) {
    $48 = ___cxa_find_matching_catch_3(0|0)|0;
    $49 = tempRet0;
    ___clang_call_terminate($48);
    // unreachable;
   } else {
    $$3 = $26;$$36 = $25;
   }
  }
  $42 = ((($2)) + 11|0);
  $43 = HEAP8[$42>>0]|0;
  $44 = ($43<<24>>24)<(0);
  if ($44) {
   $45 = HEAP32[$2>>2]|0;
   __ZdlPv($45);
   $$4 = $$3;$$47 = $$36;
  } else {
   $$4 = $$3;$$47 = $$36;
  }
 }
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $46 = __THREW__; __THREW__ = 0;
 $47 = $46&1;
 if ($47) {
  $48 = ___cxa_find_matching_catch_3(0|0)|0;
  $49 = tempRet0;
  ___clang_call_terminate($48);
  // unreachable;
 } else {
  ___resumeException($$47|0);
  // unreachable;
 }
}
function __ZN3osg5Stats8allocateEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$in = 0, $$pre = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 (FUNCTION_TABLE_ii[$5 & 8191]($2)|0);
 $6 = ((($0)) + 36|0);
 HEAP32[$6>>2] = 0;
 $7 = ((($0)) + 40|0);
 HEAP32[$7>>2] = 0;
 $8 = ((($0)) + 44|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($0)) + 48|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==($9|0);
 if ($12) {
  $13 = $9;
  $$in = $11;$22 = $13;
 } else {
  $15 = $11;
  while(1) {
   $14 = ((($15)) + -12|0);
   HEAP32[$10>>2] = $14;
   $16 = ((($15)) + -8|0);
   $17 = HEAP32[$16>>2]|0;
   __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEdEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($14,$17);
   $18 = HEAP32[$10>>2]|0;
   $19 = ($18|0)==($9|0);
   if ($19) {
    break;
   } else {
    $15 = $18;
   }
  }
  $$pre = HEAP32[$8>>2]|0;
  $$in = $18;$22 = $$pre;
 }
 $20 = $$in;
 $21 = (($20) - ($22))|0;
 $23 = (($21|0) / 12)&-1;
 $24 = ($23>>>0)<($1>>>0);
 $25 = $22;
 if ($24) {
  $26 = (($1) - ($23))|0;
  __THREW__ = 0;
  invoke_vii(3960,($8|0),($26|0));
  $27 = __THREW__; __THREW__ = 0;
  $28 = $27&1;
  if (!($28)) {
   $38 = HEAP32[$2>>2]|0;
   $39 = ((($38)) + 12|0);
   $40 = HEAP32[$39>>2]|0;
   (FUNCTION_TABLE_ii[$40 & 8191]($2)|0);
   return;
  }
  $41 = ___cxa_find_matching_catch_2()|0;
  $42 = tempRet0;
  $43 = HEAP32[$2>>2]|0;
  $44 = ((($43)) + 12|0);
  $45 = HEAP32[$44>>2]|0;
  __THREW__ = 0;
  (invoke_ii($45|0,($2|0))|0);
  $46 = __THREW__; __THREW__ = 0;
  $47 = $46&1;
  if ($47) {
   $48 = ___cxa_find_matching_catch_3(0|0)|0;
   $49 = tempRet0;
   ___clang_call_terminate($48);
   // unreachable;
  } else {
   ___resumeException($41|0);
   // unreachable;
  }
 }
 $29 = ($23>>>0)>($1>>>0);
 if (!($29)) {
  $38 = HEAP32[$2>>2]|0;
  $39 = ((($38)) + 12|0);
  $40 = HEAP32[$39>>2]|0;
  (FUNCTION_TABLE_ii[$40 & 8191]($2)|0);
  return;
 }
 $30 = (($25) + (($1*12)|0)|0);
 $31 = ($$in|0)==($30|0);
 if ($31) {
  $38 = HEAP32[$2>>2]|0;
  $39 = ((($38)) + 12|0);
  $40 = HEAP32[$39>>2]|0;
  (FUNCTION_TABLE_ii[$40 & 8191]($2)|0);
  return;
 } else {
  $33 = $$in;
 }
 while(1) {
  $32 = ((($33)) + -12|0);
  HEAP32[$10>>2] = $32;
  $34 = ((($33)) + -8|0);
  $35 = HEAP32[$34>>2]|0;
  __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEdEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($32,$35);
  $36 = HEAP32[$10>>2]|0;
  $37 = ($36|0)==($30|0);
  if ($37) {
   break;
  } else {
   $33 = $36;
  }
 }
 $38 = HEAP32[$2>>2]|0;
 $39 = ((($38)) + 12|0);
 $40 = HEAP32[$39>>2]|0;
 (FUNCTION_TABLE_ii[$40 & 8191]($2)|0);
 return;
}
function __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEbEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 }
 $3 = HEAP32[$1>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEbEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($0,$3);
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEbEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($0,$5);
 $6 = ((($1)) + 16|0);
 $7 = ((($6)) + 11|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = ($8<<24>>24)<(0);
 if ($9) {
  $10 = HEAP32[$6>>2]|0;
  __ZdlPv($10);
 }
 __ZdlPv($1);
 return;
}
function __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEdEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 }
 $3 = HEAP32[$1>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEdEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($0,$3);
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEdEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($0,$5);
 $6 = ((($1)) + 16|0);
 $7 = ((($6)) + 11|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = ($8<<24>>24)<(0);
 if ($9) {
  $10 = HEAP32[$6>>2]|0;
  __ZdlPv($10);
 }
 __ZdlPv($1);
 return;
}
function __ZNSt3__26vectorINS_3mapINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEdNS_4lessIS7_EENS5_INS_4pairIKS7_dEEEEEENS5_ISE_EEE8__appendEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i = 0, $$0$i13 = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $9 = 0, $scevgep = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $2 = sp;
 $3 = ((($0)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) - ($6))|0;
 $8 = (($7|0) / 12)&-1;
 $9 = ($8>>>0)<($1>>>0);
 if (!($9)) {
  $10 = $6;
  $$0$i = $1;$12 = $10;
  while(1) {
   $11 = ((($12)) + 4|0);
   HEAP32[$11>>2] = 0;
   $13 = ((($12)) + 8|0);
   HEAP32[$13>>2] = 0;
   $14 = ((($12)) + 4|0);
   HEAP32[$12>>2] = $14;
   $15 = HEAP32[$5>>2]|0;
   $16 = ((($15)) + 12|0);
   HEAP32[$5>>2] = $16;
   $17 = (($$0$i) + -1)|0;
   $18 = ($17|0)==(0);
   if ($18) {
    break;
   } else {
    $$0$i = $17;$12 = $16;
   }
  }
  STACKTOP = sp;return;
 }
 $19 = HEAP32[$0>>2]|0;
 $20 = (($6) - ($19))|0;
 $21 = (($20|0) / 12)&-1;
 $22 = (($21) + ($1))|0;
 $23 = ($22>>>0)>(357913941);
 if ($23) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $24 = ((($0)) + 8|0);
 $25 = (($4) - ($19))|0;
 $26 = (($25|0) / 12)&-1;
 $27 = ($26>>>0)<(178956970);
 $28 = $26 << 1;
 $29 = ($28>>>0)<($22>>>0);
 $$sroa$speculated$i = $29 ? $22 : $28;
 $$sroa$speculated$$i = $27 ? $$sroa$speculated$i : 357913941;
 $30 = ((($2)) + 12|0);
 HEAP32[$30>>2] = 0;
 $31 = ((($2)) + 16|0);
 HEAP32[$31>>2] = $24;
 $32 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($32) {
   $41 = 0;
  } else {
   $33 = ($$sroa$speculated$$i>>>0)>(357913941);
   if (!($33)) {
    $39 = ($$sroa$speculated$$i*12)|0;
    $40 = (__Znwj($39)|0);
    $41 = $40;
    break;
   }
   $34 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($34|0),(204840|0));
   $35 = __THREW__; __THREW__ = 0;
   $36 = $35&1;
   if ($36) {
    $37 = ___cxa_find_matching_catch_2()|0;
    $38 = tempRet0;
    ___cxa_free_exception(($34|0));
    ___resumeException($37|0);
    // unreachable;
   } else {
    HEAP32[$34>>2] = (99824);
    ___cxa_throw(($34|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 HEAP32[$2>>2] = $41;
 $42 = (($41) + (($21*12)|0)|0);
 $43 = ((($2)) + 8|0);
 HEAP32[$43>>2] = $42;
 $44 = ((($2)) + 4|0);
 HEAP32[$44>>2] = $42;
 $45 = (($41) + (($$sroa$speculated$$i*12)|0)|0);
 $46 = ((($2)) + 12|0);
 HEAP32[$46>>2] = $45;
 $$0$i13 = $1;$48 = $42;
 while(1) {
  $47 = ((($48)) + 4|0);
  HEAP32[$47>>2] = 0;
  $49 = ((($48)) + 8|0);
  HEAP32[$49>>2] = 0;
  $50 = ((($48)) + 4|0);
  HEAP32[$48>>2] = $50;
  $51 = ((($48)) + 12|0);
  $52 = (($$0$i13) + -1)|0;
  $53 = ($52|0)==(0);
  if ($53) {
   break;
  } else {
   $$0$i13 = $52;$48 = $51;
  }
 }
 $scevgep = (($41) + (($22*12)|0)|0);
 HEAP32[$43>>2] = $scevgep;
 __THREW__ = 0;
 invoke_vii(3961,($0|0),($2|0));
 $54 = __THREW__; __THREW__ = 0;
 $55 = $54&1;
 if ($55) {
  $67 = ___cxa_find_matching_catch_2()|0;
  $68 = tempRet0;
  $69 = HEAP32[$44>>2]|0;
  $70 = HEAP32[$43>>2]|0;
  $71 = ($70|0)==($69|0);
  if (!($71)) {
   $73 = $70;
   while(1) {
    $72 = ((($73)) + -12|0);
    HEAP32[$43>>2] = $72;
    $74 = ((($73)) + -8|0);
    $75 = HEAP32[$74>>2]|0;
    __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEdEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($72,$75);
    $76 = HEAP32[$43>>2]|0;
    $77 = ($76|0)==($69|0);
    if ($77) {
     break;
    } else {
     $73 = $76;
    }
   }
  }
  $78 = HEAP32[$2>>2]|0;
  $79 = ($78|0)==(0|0);
  if ($79) {
   ___resumeException($67|0);
   // unreachable;
  }
  __ZdlPv($78);
  ___resumeException($67|0);
  // unreachable;
 } else {
  $56 = HEAP32[$44>>2]|0;
  $57 = HEAP32[$43>>2]|0;
  $58 = ($57|0)==($56|0);
  if (!($58)) {
   $60 = $57;
   while(1) {
    $59 = ((($60)) + -12|0);
    HEAP32[$43>>2] = $59;
    $61 = ((($60)) + -8|0);
    $62 = HEAP32[$61>>2]|0;
    __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEdEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($59,$62);
    $63 = HEAP32[$43>>2]|0;
    $64 = ($63|0)==($56|0);
    if ($64) {
     break;
    } else {
     $60 = $63;
    }
   }
  }
  $65 = HEAP32[$2>>2]|0;
  $66 = ($65|0)==(0|0);
  if (!($66)) {
   __ZdlPv($65);
  }
  STACKTOP = sp;return;
 }
}
function __ZNSt3__26vectorINS_3mapINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEdNS_4lessIS7_EENS5_INS_4pairIKS7_dEEEEEENS5_ISE_EEE26__swap_out_circular_bufferERNS_14__split_bufferISE_RSF_EE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i$i$i$i$i$i = 0, $$0$i$i$i$i$i$i$i$i = 0, $$011$i = 0, $$byval_copy = 0, $$in10$i$i$i$i = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i$i$i$i$i$i$i = 0, $$pre$phi25Z2D = 0, $$pre$phiZ2D = 0, $$pre22 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0.0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $9 = 0, $eh$lpad$body$i$i$i$index2Z2D = 0, $eh$lpad$body$i$i$i$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy = sp + 12|0;
 $2 = sp + 8|0;
 $3 = sp + 4|0;
 $4 = sp;
 $5 = HEAP32[$0>>2]|0;
 $6 = ((($0)) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($1)) + 4|0);
 $9 = ($7|0)==($5|0);
 if ($9) {
  $10 = $5;
  $$pre22 = HEAP32[$8>>2]|0;
  $$pre$phi25Z2D = $8;$$pre$phiZ2D = $0;$72 = $$pre22;$73 = $10;
  HEAP32[$$pre$phiZ2D>>2] = $72;
  HEAP32[$$pre$phi25Z2D>>2] = $73;
  $74 = ((($1)) + 8|0);
  $75 = HEAP32[$6>>2]|0;
  $76 = HEAP32[$74>>2]|0;
  HEAP32[$6>>2] = $76;
  HEAP32[$74>>2] = $75;
  $77 = ((($0)) + 8|0);
  $78 = ((($1)) + 12|0);
  $79 = HEAP32[$77>>2]|0;
  $80 = HEAP32[$78>>2]|0;
  HEAP32[$77>>2] = $80;
  HEAP32[$78>>2] = $79;
  $81 = HEAP32[$$pre$phi25Z2D>>2]|0;
  HEAP32[$1>>2] = $81;
  STACKTOP = sp;return;
 }
 $$pre$i = HEAP32[$8>>2]|0;
 $$011$i = $7;$12 = $$pre$i;
 L5: while(1) {
  $11 = ((($12)) + -12|0);
  $13 = ((($$011$i)) + -12|0);
  $14 = ((($12)) + -8|0);
  HEAP32[$14>>2] = 0;
  $15 = ((($12)) + -4|0);
  HEAP32[$15>>2] = 0;
  $16 = ((($12)) + -8|0);
  HEAP32[$11>>2] = $16;
  $17 = HEAP32[$13>>2]|0;
  $18 = ((($$011$i)) + -8|0);
  $19 = ($17|0)==($18|0);
  if (!($19)) {
   $20 = $16;
   $$in10$i$i$i$i = $17;
   while(1) {
    $21 = ((($$in10$i$i$i$i)) + 16|0);
    HEAP32[$4>>2] = $20;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy>>2]=HEAP32[$4>>2]|0;
    $22 = (invoke_iiiiii(3962,($11|0),($$byval_copy|0),($2|0),($3|0),($21|0))|0);
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if ($24) {
     label = 20;
     break L5;
    }
    $25 = HEAP32[$22>>2]|0;
    $26 = ($25|0)==(0|0);
    if ($26) {
     __THREW__ = 0;
     $27 = (invoke_ii(3276,40)|0);
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      label = 20;
      break L5;
     }
     $30 = ((($27)) + 16|0);
     __THREW__ = 0;
     invoke_vii(3457,($30|0),($21|0));
     $31 = __THREW__; __THREW__ = 0;
     $32 = $31&1;
     if ($32) {
      label = 10;
      break L5;
     }
     $35 = ((($27)) + 32|0);
     $36 = ((($$in10$i$i$i$i)) + 32|0);
     $37 = +HEAPF64[$36>>3];
     HEAPF64[$35>>3] = $37;
     $38 = HEAP32[$2>>2]|0;
     HEAP32[$27>>2] = 0;
     $39 = ((($27)) + 4|0);
     HEAP32[$39>>2] = 0;
     $40 = ((($27)) + 8|0);
     HEAP32[$40>>2] = $38;
     HEAP32[$22>>2] = $27;
     $41 = HEAP32[$11>>2]|0;
     $42 = HEAP32[$41>>2]|0;
     $43 = ($42|0)==(0|0);
     if ($43) {
      $46 = $27;
     } else {
      $44 = $42;
      HEAP32[$11>>2] = $44;
      $$pre$i$i$i$i$i$i$i$i = HEAP32[$22>>2]|0;
      $46 = $$pre$i$i$i$i$i$i$i$i;
     }
     $45 = HEAP32[$14>>2]|0;
     __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($45,$46);
     $47 = HEAP32[$15>>2]|0;
     $48 = (($47) + 1)|0;
     HEAP32[$15>>2] = $48;
    }
    $49 = ((($$in10$i$i$i$i)) + 4|0);
    $50 = HEAP32[$49>>2]|0;
    $51 = ($50|0)==(0|0);
    if ($51) {
     $52 = ((($$in10$i$i$i$i)) + 8|0);
     $53 = HEAP32[$52>>2]|0;
     $54 = HEAP32[$53>>2]|0;
     $55 = ($54|0)==($$in10$i$i$i$i|0);
     if ($55) {
      $$0$i$i$i$i$i$i$i = $53;
     } else {
      $59 = $52;
      while(1) {
       $58 = HEAP32[$59>>2]|0;
       $60 = ((($58)) + 8|0);
       $61 = HEAP32[$60>>2]|0;
       $62 = HEAP32[$61>>2]|0;
       $63 = ($62|0)==($58|0);
       if ($63) {
        $$0$i$i$i$i$i$i$i = $61;
        break;
       } else {
        $59 = $60;
       }
      }
     }
    } else {
     $$0$i$i$i$i$i$i$i$i = $50;
     while(1) {
      $56 = HEAP32[$$0$i$i$i$i$i$i$i$i>>2]|0;
      $57 = ($56|0)==(0|0);
      if ($57) {
       break;
      } else {
       $$0$i$i$i$i$i$i$i$i = $56;
      }
     }
     $$0$i$i$i$i$i$i$i = $$0$i$i$i$i$i$i$i$i;
    }
    $64 = ($$0$i$i$i$i$i$i$i|0)==($18|0);
    if ($64) {
     break;
    } else {
     $$in10$i$i$i$i = $$0$i$i$i$i$i$i$i;
    }
   }
  }
  $68 = HEAP32[$8>>2]|0;
  $69 = ((($68)) + -12|0);
  HEAP32[$8>>2] = $69;
  $70 = ($13|0)==($5|0);
  if ($70) {
   label = 23;
   break;
  } else {
   $$011$i = $13;$12 = $69;
  }
 }
 if ((label|0) == 10) {
  $33 = ___cxa_find_matching_catch_2()|0;
  $34 = tempRet0;
  __ZdlPv($27);
  $eh$lpad$body$i$i$i$index2Z2D = $34;$eh$lpad$body$i$i$i$indexZ2D = $33;
  $67 = HEAP32[$16>>2]|0;
  __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEdEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($11,$67);
  ___resumeException($eh$lpad$body$i$i$i$indexZ2D|0);
  // unreachable;
 }
 else if ((label|0) == 20) {
  $65 = ___cxa_find_matching_catch_2()|0;
  $66 = tempRet0;
  $eh$lpad$body$i$i$i$index2Z2D = $66;$eh$lpad$body$i$i$i$indexZ2D = $65;
  $67 = HEAP32[$16>>2]|0;
  __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEdEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($11,$67);
  ___resumeException($eh$lpad$body$i$i$i$indexZ2D|0);
  // unreachable;
 }
 else if ((label|0) == 23) {
  $71 = $69;
  $$pre = HEAP32[$0>>2]|0;
  $$pre$phi25Z2D = $8;$$pre$phiZ2D = $0;$72 = $71;$73 = $$pre;
  HEAP32[$$pre$phiZ2D>>2] = $72;
  HEAP32[$$pre$phi25Z2D>>2] = $73;
  $74 = ((($1)) + 8|0);
  $75 = HEAP32[$6>>2]|0;
  $76 = HEAP32[$74>>2]|0;
  HEAP32[$6>>2] = $76;
  HEAP32[$74>>2] = $75;
  $77 = ((($0)) + 8|0);
  $78 = ((($1)) + 12|0);
  $79 = HEAP32[$77>>2]|0;
  $80 = HEAP32[$78>>2]|0;
  HEAP32[$77>>2] = $80;
  HEAP32[$78>>2] = $79;
  $81 = HEAP32[$$pre$phi25Z2D>>2]|0;
  HEAP32[$1>>2] = $81;
  STACKTOP = sp;return;
 }
}
function __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEdEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE12__find_equalIS7_EERPNS_16__tree_node_baseIPvEENS_21__tree_const_iteratorIS8_PNS_11__tree_nodeIS8_SH_EEiEERPNS_15__tree_end_nodeISJ_EESK_RKT_($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0$i$i = 0, $$0$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i$i = 0, $$08$i$i = 0, $$2 = 0, $$pre = 0, $$sroa$052$0 = 0, $$sroa$speculated$i$i$i$i$i = 0, $$sroa$speculated$i$i$i$i$i21 = 0, $$sroa$speculated$i$i$i$i$i26 = 0, $$sroa$speculated$i$i$i$i$i32 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = ((($0)) + 4|0);
 $6 = HEAP32[$1>>2]|0;
 $7 = ($6|0)==($5|0);
 $8 = $6;
 do {
  if (!($7)) {
   $9 = ((($6)) + 16|0);
   $10 = ((($9)) + 11|0);
   $11 = HEAP8[$10>>0]|0;
   $12 = ($11<<24>>24)<(0);
   $13 = ((($6)) + 20|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = $11&255;
   $16 = $12 ? $14 : $15;
   $17 = ((($4)) + 11|0);
   $18 = HEAP8[$17>>0]|0;
   $19 = ($18<<24>>24)<(0);
   $20 = ((($4)) + 4|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = $18&255;
   $23 = $19 ? $21 : $22;
   $24 = ($16>>>0)<($23>>>0);
   $$sroa$speculated$i$i$i$i$i32 = $24 ? $16 : $23;
   $25 = ($$sroa$speculated$i$i$i$i$i32|0)==(0);
   if ($25) {
    label = 4;
   } else {
    $26 = HEAP32[$4>>2]|0;
    $27 = $19 ? $26 : $4;
    $28 = HEAP32[$9>>2]|0;
    $29 = $12 ? $28 : $9;
    $30 = (_memcmp($27,$29,$$sroa$speculated$i$i$i$i$i32)|0);
    $31 = ($30|0)==(0);
    if ($31) {
     label = 4;
    } else {
     $33 = ($30|0)<(0);
     if ($33) {
      break;
     }
    }
   }
   if ((label|0) == 4) {
    $32 = ($23>>>0)<($16>>>0);
    if ($32) {
     break;
    }
   }
   $74 = ($23>>>0)<($16>>>0);
   $$sroa$speculated$i$i$i$i$i21 = $74 ? $23 : $16;
   $75 = ($$sroa$speculated$i$i$i$i$i21|0)==(0);
   if ($75) {
    label = 20;
   } else {
    $76 = HEAP32[$9>>2]|0;
    $77 = $12 ? $76 : $9;
    $78 = HEAP32[$4>>2]|0;
    $79 = $19 ? $78 : $4;
    $80 = (_memcmp($77,$79,$$sroa$speculated$i$i$i$i$i21)|0);
    $81 = ($80|0)==(0);
    if ($81) {
     label = 20;
    } else {
     $82 = ($80|0)<(0);
     if (!($82)) {
      label = 36;
     }
    }
   }
   if ((label|0) == 20) {
    if (!($24)) {
     label = 36;
    }
   }
   if ((label|0) == 36) {
    HEAP32[$2>>2] = $8;
    HEAP32[$3>>2] = $8;
    $$2 = $3;
    return ($$2|0);
   }
   $83 = ((($6)) + 4|0);
   $84 = HEAP32[$83>>2]|0;
   $85 = ($84|0)==(0|0);
   if ($85) {
    $86 = ((($6)) + 8|0);
    $87 = HEAP32[$86>>2]|0;
    $88 = HEAP32[$87>>2]|0;
    $89 = ($88|0)==($6|0);
    if ($89) {
     $$0$i$i$i$i$i = $87;
    } else {
     $93 = $86;
     while(1) {
      $92 = HEAP32[$93>>2]|0;
      $94 = ((($92)) + 8|0);
      $95 = HEAP32[$94>>2]|0;
      $96 = HEAP32[$95>>2]|0;
      $97 = ($96|0)==($92|0);
      if ($97) {
       $$0$i$i$i$i$i = $95;
       break;
      } else {
       $93 = $94;
      }
     }
    }
   } else {
    $$0$i$i$i$i$i$i = $84;
    while(1) {
     $90 = HEAP32[$$0$i$i$i$i$i$i>>2]|0;
     $91 = ($90|0)==(0|0);
     if ($91) {
      break;
     } else {
      $$0$i$i$i$i$i$i = $90;
     }
    }
    $$0$i$i$i$i$i = $$0$i$i$i$i$i$i;
   }
   $98 = ($$0$i$i$i$i$i|0)==($5|0);
   do {
    if (!($98)) {
     $99 = ((($$0$i$i$i$i$i)) + 16|0);
     $100 = ((($99)) + 11|0);
     $101 = HEAP8[$100>>0]|0;
     $102 = ($101<<24>>24)<(0);
     $103 = ((($$0$i$i$i$i$i)) + 20|0);
     $104 = HEAP32[$103>>2]|0;
     $105 = $101&255;
     $106 = $102 ? $104 : $105;
     $107 = ($106>>>0)<($23>>>0);
     $$sroa$speculated$i$i$i$i$i = $107 ? $106 : $23;
     $108 = ($$sroa$speculated$i$i$i$i$i|0)==(0);
     if ($108) {
      label = 30;
     } else {
      $109 = HEAP32[$4>>2]|0;
      $110 = $19 ? $109 : $4;
      $111 = HEAP32[$99>>2]|0;
      $112 = $102 ? $111 : $99;
      $113 = (_memcmp($110,$112,$$sroa$speculated$i$i$i$i$i)|0);
      $114 = ($113|0)==(0);
      if ($114) {
       label = 30;
      } else {
       $116 = ($113|0)<(0);
       if ($116) {
        break;
       }
      }
     }
     if ((label|0) == 30) {
      $115 = ($23>>>0)<($106>>>0);
      if ($115) {
       break;
      }
     }
     $120 = (__ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEdEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE12__find_equalIS7_EERPNS_16__tree_node_baseIPvEERPNS_15__tree_end_nodeISJ_EERKT_($0,$2,$4)|0);
     $$2 = $120;
     return ($$2|0);
    }
   } while(0);
   $117 = ((($6)) + 4|0);
   $118 = HEAP32[$117>>2]|0;
   $119 = ($118|0)==(0|0);
   if ($119) {
    HEAP32[$2>>2] = $8;
    $$2 = $83;
    return ($$2|0);
   } else {
    HEAP32[$2>>2] = $$0$i$i$i$i$i;
    $$2 = $$0$i$i$i$i$i;
    return ($$2|0);
   }
  }
 } while(0);
 $34 = HEAP32[$0>>2]|0;
 $35 = ($6|0)==($34|0);
 $$pre = HEAP32[$6>>2]|0;
 do {
  if ($35) {
   $$sroa$052$0 = $8;
  } else {
   $36 = ($$pre|0)==(0|0);
   if ($36) {
    $$0$i$i = $6;
    while(1) {
     $40 = ((($$0$i$i)) + 8|0);
     $41 = HEAP32[$40>>2]|0;
     $42 = HEAP32[$41>>2]|0;
     $43 = ($42|0)==($$0$i$i|0);
     if ($43) {
      $$0$i$i = $41;
     } else {
      $$08$i$i = $41;
      break;
     }
    }
   } else {
    $$0$i$i$i = $$pre;
    while(1) {
     $37 = ((($$0$i$i$i)) + 4|0);
     $38 = HEAP32[$37>>2]|0;
     $39 = ($38|0)==(0|0);
     if ($39) {
      $$08$i$i = $$0$i$i$i;
      break;
     } else {
      $$0$i$i$i = $38;
     }
    }
   }
   $44 = $$08$i$i;
   $45 = ((($$08$i$i)) + 16|0);
   $46 = ((($4)) + 11|0);
   $47 = HEAP8[$46>>0]|0;
   $48 = ($47<<24>>24)<(0);
   $49 = ((($4)) + 4|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = $47&255;
   $52 = $48 ? $50 : $51;
   $53 = ((($45)) + 11|0);
   $54 = HEAP8[$53>>0]|0;
   $55 = ($54<<24>>24)<(0);
   $56 = ((($$08$i$i)) + 20|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = $54&255;
   $59 = $55 ? $57 : $58;
   $60 = ($52>>>0)<($59>>>0);
   $$sroa$speculated$i$i$i$i$i26 = $60 ? $52 : $59;
   $61 = ($$sroa$speculated$i$i$i$i$i26|0)==(0);
   if ($61) {
    label = 12;
   } else {
    $62 = HEAP32[$45>>2]|0;
    $63 = $55 ? $62 : $45;
    $64 = HEAP32[$4>>2]|0;
    $65 = $48 ? $64 : $4;
    $66 = (_memcmp($63,$65,$$sroa$speculated$i$i$i$i$i26)|0);
    $67 = ($66|0)==(0);
    if ($67) {
     label = 12;
    } else {
     $69 = ($66|0)<(0);
     if ($69) {
      $$sroa$052$0 = $44;
      break;
     }
    }
   }
   if ((label|0) == 12) {
    $68 = ($59>>>0)<($52>>>0);
    if ($68) {
     $$sroa$052$0 = $44;
     break;
    }
   }
   $73 = (__ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEdEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE12__find_equalIS7_EERPNS_16__tree_node_baseIPvEERPNS_15__tree_end_nodeISJ_EERKT_($0,$2,$4)|0);
   $$2 = $73;
   return ($$2|0);
  }
 } while(0);
 $70 = ($$pre|0)==(0|0);
 if ($70) {
  HEAP32[$2>>2] = $6;
  $$2 = $6;
  return ($$2|0);
 } else {
  $71 = $$sroa$052$0;
  HEAP32[$2>>2] = $71;
  $72 = ((($71)) + 4|0);
  $$2 = $72;
  return ($$2|0);
 }
 return (0)|0;
}
function __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEdEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE12__find_equalIS7_EERPNS_16__tree_node_baseIPvEERPNS_15__tree_end_nodeISJ_EERKT_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$0$be = 0, $$024 = 0, $$024$be$in = 0, $$025 = 0, $$sroa$speculated$i$i$i$i$i = 0, $$sroa$speculated$i$i$i$i$i26 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  HEAP32[$1>>2] = $3;
  $$025 = $3;
  return ($$025|0);
 }
 $6 = ((($0)) + 4|0);
 $7 = ((($2)) + 11|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = ($8<<24>>24)<(0);
 $10 = ((($2)) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $8&255;
 $13 = $9 ? $11 : $12;
 $14 = HEAP32[$2>>2]|0;
 $15 = $9 ? $14 : $2;
 $$0 = $6;$$024 = $4;
 while(1) {
  $16 = ((($$024)) + 16|0);
  $17 = ((($16)) + 11|0);
  $18 = HEAP8[$17>>0]|0;
  $19 = ($18<<24>>24)<(0);
  $20 = ((($$024)) + 20|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = $18&255;
  $23 = $19 ? $21 : $22;
  $24 = ($23>>>0)<($13>>>0);
  $$sroa$speculated$i$i$i$i$i26 = $24 ? $23 : $13;
  $25 = ($$sroa$speculated$i$i$i$i$i26|0)==(0);
  if ($25) {
   label = 5;
  } else {
   $26 = HEAP32[$16>>2]|0;
   $27 = $19 ? $26 : $16;
   $28 = (_memcmp($15,$27,$$sroa$speculated$i$i$i$i$i26)|0);
   $29 = ($28|0)==(0);
   if ($29) {
    label = 5;
   } else {
    $31 = ($28|0)<(0);
    if ($31) {
     label = 7;
    } else {
     label = 9;
    }
   }
  }
  if ((label|0) == 5) {
   label = 0;
   $30 = ($13>>>0)<($23>>>0);
   if ($30) {
    label = 7;
   } else {
    label = 9;
   }
  }
  if ((label|0) == 7) {
   label = 0;
   $32 = HEAP32[$$024>>2]|0;
   $33 = ($32|0)==(0|0);
   if ($33) {
    label = 8;
    break;
   } else {
    $$0$be = $$024;$$024$be$in = $32;
   }
  }
  else if ((label|0) == 9) {
   label = 0;
   $34 = ($13>>>0)<($23>>>0);
   $$sroa$speculated$i$i$i$i$i = $34 ? $13 : $23;
   $35 = ($$sroa$speculated$i$i$i$i$i|0)==(0);
   if ($35) {
    label = 11;
   } else {
    $36 = HEAP32[$16>>2]|0;
    $37 = $19 ? $36 : $16;
    $38 = (_memcmp($37,$15,$$sroa$speculated$i$i$i$i$i)|0);
    $39 = ($38|0)==(0);
    if ($39) {
     label = 11;
    } else {
     $40 = ($38|0)<(0);
     if (!($40)) {
      label = 16;
      break;
     }
    }
   }
   if ((label|0) == 11) {
    label = 0;
    if (!($24)) {
     label = 16;
     break;
    }
   }
   $41 = ((($$024)) + 4|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = ($42|0)==(0|0);
   if ($43) {
    label = 15;
    break;
   } else {
    $$0$be = $41;$$024$be$in = $42;
   }
  }
  $$0 = $$0$be;$$024 = $$024$be$in;
 }
 if ((label|0) == 8) {
  HEAP32[$1>>2] = $$024;
  $$025 = $$024;
  return ($$025|0);
 }
 else if ((label|0) == 15) {
  HEAP32[$1>>2] = $$024;
  $$025 = $41;
  return ($$025|0);
 }
 else if ((label|0) == 16) {
  HEAP32[$1>>2] = $$024;
  $$025 = $$0;
  return ($$025|0);
 }
 return (0)|0;
}
function __ZN3osg5StatsD2Ev($0) {
 $0 = $0|0;
 var $$pre$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (66392);
 $1 = ((($0)) + 68|0);
 $2 = ((($0)) + 72|0);
 $3 = HEAP32[$2>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEbEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($1,$3);
 $4 = ((($0)) + 56|0);
 $5 = ((($0)) + 60|0);
 $6 = HEAP32[$5>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEdEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($4,$6);
 $7 = ((($0)) + 44|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if (!($9)) {
  $10 = ((($0)) + 48|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($11|0)==($8|0);
  if ($12) {
   $19 = $8;
  } else {
   $14 = $11;
   while(1) {
    $13 = ((($14)) + -12|0);
    HEAP32[$10>>2] = $13;
    $15 = ((($14)) + -8|0);
    $16 = HEAP32[$15>>2]|0;
    __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEdEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($13,$16);
    $17 = HEAP32[$10>>2]|0;
    $18 = ($17|0)==($8|0);
    if ($18) {
     break;
    } else {
     $14 = $17;
    }
   }
   $$pre$i = HEAP32[$7>>2]|0;
   $19 = $$pre$i;
  }
  __ZdlPv($19);
 }
 $20 = ((($0)) + 24|0);
 __THREW__ = 0;
 invoke_vi(707,($20|0));
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if (!($22)) {
  $23 = ((($0)) + 12|0);
  $24 = ((($23)) + 11|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = ($25<<24>>24)<(0);
  if (!($26)) {
   __ZN3osg10ReferencedD2Ev($0);
   return;
  }
  $27 = HEAP32[$23>>2]|0;
  __ZdlPv($27);
  __ZN3osg10ReferencedD2Ev($0);
  return;
 }
 $28 = ___cxa_find_matching_catch_2()|0;
 $29 = tempRet0;
 $30 = ((($0)) + 12|0);
 $31 = ((($30)) + 11|0);
 $32 = HEAP8[$31>>0]|0;
 $33 = ($32<<24>>24)<(0);
 if ($33) {
  $34 = HEAP32[$30>>2]|0;
  __ZdlPv($34);
 }
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $35 = __THREW__; __THREW__ = 0;
 $36 = $35&1;
 if ($36) {
  $37 = ___cxa_find_matching_catch_3(0|0)|0;
  $38 = tempRet0;
  ___clang_call_terminate($37);
  // unreachable;
 } else {
  ___resumeException($28|0);
  // unreachable;
 }
}
function __ZN3osg5StatsD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(2273,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZN3osg5Stats12setAttributeEjRKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEd($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = +$3;
 var $$$i = 0, $$$i$i = 0, $$$i37 = 0, $$0 = 0, $$031 = 0, $$03153 = 0, $$03154 = 0, $$1 = 0, $$cast = 0, $$lcssa = 0, $$sink34$index = 0, $$sink34$index3 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0;
 var $143 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $4 = sp;
 $5 = ((($0)) + 40|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($0)) + 44|0);
 $8 = ((($0)) + 48|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$7>>2]|0;
 $11 = (($9) - ($10))|0;
 $12 = (($11|0) / 12)&-1;
 $13 = ($6>>>0)<($12>>>0);
 $14 = (($6) + 1)|0;
 $15 = (($14) - ($12))|0;
 $$$i = $13 ? 0 : $15;
 $16 = ($$$i>>>0)>($1>>>0);
 if ($16) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $17 = ((($0)) + 24|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ((($18)) + 8|0);
 $20 = HEAP32[$19>>2]|0;
 (FUNCTION_TABLE_ii[$20 & 8191]($17)|0);
 $21 = HEAP32[$5>>2]|0;
 $22 = ($21>>>0)<($1>>>0);
 if ($22) {
  $$03153 = (($21) + 1)|0;
  $23 = ($$03153>>>0)>($1>>>0);
  $24 = ((($0)) + 36|0);
  $25 = HEAP32[$24>>2]|0;
  if ($23) {
   $$lcssa = $25;
  } else {
   $$03154 = $$03153;$33 = $25;
   while(1) {
    $32 = (($$03154) - ($33))|0;
    $34 = HEAP32[$8>>2]|0;
    $35 = HEAP32[$7>>2]|0;
    $36 = (($34) - ($35))|0;
    $37 = (($36|0) / 12)&-1;
    $38 = (($32>>>0) % ($37>>>0))&-1;
    $$cast = $35;
    $39 = (($$cast) + (($38*12)|0)|0);
    $40 = (((($$cast) + (($38*12)|0)|0)) + 4|0);
    $41 = HEAP32[$40>>2]|0;
    __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEdEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($39,$41);
    $42 = (((($$cast) + (($38*12)|0)|0)) + 8|0);
    HEAP32[$42>>2] = 0;
    HEAP32[$39>>2] = $40;
    HEAP32[$40>>2] = 0;
    $$031 = (($$03154) + 1)|0;
    $43 = ($$031>>>0)>($1>>>0);
    $44 = HEAP32[$24>>2]|0;
    if ($43) {
     $$lcssa = $44;
     break;
    } else {
     $$03154 = $$031;$33 = $44;
    }
   }
  }
  $26 = (($1) - ($$lcssa))|0;
  $27 = HEAP32[$8>>2]|0;
  $28 = HEAP32[$7>>2]|0;
  $29 = (($27) - ($28))|0;
  $30 = (($29|0) / 12)&-1;
  $31 = ($26>>>0)<($30>>>0);
  if (!($31)) {
   $45 = (($1>>>0) % ($30>>>0))&-1;
   $46 = (($1) - ($45))|0;
   HEAP32[$24>>2] = $46;
  }
  HEAP32[$5>>2] = $1;
  $51 = $1;
 } else {
  $51 = $21;
 }
 $47 = HEAP32[$8>>2]|0;
 $48 = HEAP32[$7>>2]|0;
 $49 = (($47) - ($48))|0;
 $50 = (($49|0) / 12)&-1;
 $52 = ($51>>>0)<($50>>>0);
 $53 = (($51) + 1)|0;
 $54 = (($53) - ($50))|0;
 $$$i$i = $52 ? 0 : $54;
 $55 = ($$$i$i>>>0)>($1>>>0);
 $56 = $48;
 do {
  if ($55) {
   label = 10;
  } else {
   $57 = ((($0)) + 36|0);
   $58 = HEAP32[$57>>2]|0;
   $59 = ($58>>>0)>($1>>>0);
   $60 = (($1) - ($58))|0;
   $61 = $59 ? $50 : 0;
   $$$i37 = (($61) + ($60))|0;
   $62 = ($$$i37|0)<(0);
   if ($62) {
    label = 10;
   } else {
    $128 = (($56) + (($$$i37*12)|0)|0);
    __THREW__ = 0;
    $129 = (invoke_iii(3963,($128|0),($2|0))|0);
    $130 = __THREW__; __THREW__ = 0;
    $131 = $130&1;
    if ($131) {
     $132 = ___cxa_find_matching_catch_2()|0;
     $133 = tempRet0;
     $$sink34$index = $132;$$sink34$index3 = $133;
     break;
    } else {
     HEAPF64[$129>>3] = $3;
     $$0 = 1;
     label = 33;
     break;
    }
   }
  }
 } while(0);
 L20: do {
  if ((label|0) == 10) {
   __THREW__ = 0;
   $63 = (invoke_ii(3265,3)|0);
   $64 = __THREW__; __THREW__ = 0;
   $65 = $64&1;
   do {
    if (!($65)) {
     if (!($63)) {
      $$0 = 0;
      label = 33;
      break L20;
     }
     __THREW__ = 0;
     $66 = (invoke_ii(3266,3)|0);
     $67 = __THREW__; __THREW__ = 0;
     $68 = $67&1;
     if (!($68)) {
      __THREW__ = 0;
      $69 = (invoke_iiii(3267,($66|0),(153397|0),53)|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if (!($71)) {
       __THREW__ = 0;
       $72 = (invoke_iii(3417,($69|0),($1|0))|0);
       $73 = __THREW__; __THREW__ = 0;
       $74 = $73&1;
       if (!($74)) {
        __THREW__ = 0;
        $75 = (invoke_iiii(3267,($72|0),(155405|0),1)|0);
        $76 = __THREW__; __THREW__ = 0;
        $77 = $76&1;
        if (!($77)) {
         $78 = ((($2)) + 11|0);
         $79 = HEAP8[$78>>0]|0;
         $80 = ($79<<24>>24)<(0);
         $81 = HEAP32[$2>>2]|0;
         $82 = $80 ? $81 : $2;
         $83 = ((($2)) + 4|0);
         $84 = HEAP32[$83>>2]|0;
         $85 = $79&255;
         $86 = $80 ? $84 : $85;
         __THREW__ = 0;
         $87 = (invoke_iiii(3267,($75|0),($82|0),($86|0))|0);
         $88 = __THREW__; __THREW__ = 0;
         $89 = $88&1;
         if (!($89)) {
          __THREW__ = 0;
          $90 = (invoke_iiii(3267,($87|0),(155405|0),1)|0);
          $91 = __THREW__; __THREW__ = 0;
          $92 = $91&1;
          if (!($92)) {
           __THREW__ = 0;
           $93 = (invoke_iid(3519,($90|0),(+$3))|0);
           $94 = __THREW__; __THREW__ = 0;
           $95 = $94&1;
           if (!($95)) {
            __THREW__ = 0;
            $96 = (invoke_iiii(3267,($93|0),(174996|0),1)|0);
            $97 = __THREW__; __THREW__ = 0;
            $98 = $97&1;
            if (!($98)) {
             $99 = HEAP32[$96>>2]|0;
             $100 = ((($99)) + -12|0);
             $101 = HEAP32[$100>>2]|0;
             $102 = (($96) + ($101)|0);
             __THREW__ = 0;
             invoke_vii(3257,($4|0),($102|0));
             $103 = __THREW__; __THREW__ = 0;
             $104 = $103&1;
             if (!($104)) {
              __THREW__ = 0;
              $105 = (invoke_iii(3255,($4|0),(215188|0))|0);
              $106 = __THREW__; __THREW__ = 0;
              $107 = $106&1;
              if (!($107)) {
               $108 = HEAP32[$105>>2]|0;
               $109 = ((($108)) + 28|0);
               $110 = HEAP32[$109>>2]|0;
               __THREW__ = 0;
               $111 = (invoke_iii($110|0,($105|0),10)|0);
               $112 = __THREW__; __THREW__ = 0;
               $113 = $112&1;
               if (!($113)) {
                __THREW__ = 0;
                invoke_vi(3263,($4|0));
                $114 = __THREW__; __THREW__ = 0;
                $115 = $114&1;
                if ($115) {
                 break;
                }
                __THREW__ = 0;
                (invoke_iii(3268,($96|0),($111|0))|0);
                $122 = __THREW__; __THREW__ = 0;
                $123 = $122&1;
                if ($123) {
                 break;
                }
                __THREW__ = 0;
                (invoke_ii(3269,($96|0))|0);
                $124 = __THREW__; __THREW__ = 0;
                $125 = $124&1;
                if ($125) {
                 break;
                } else {
                 $$0 = 0;
                 label = 33;
                 break L20;
                }
               }
              }
              $116 = ___cxa_find_matching_catch_2()|0;
              $117 = tempRet0;
              __THREW__ = 0;
              invoke_vi(3263,($4|0));
              $118 = __THREW__; __THREW__ = 0;
              $119 = $118&1;
              if ($119) {
               $120 = ___cxa_find_matching_catch_3(0|0)|0;
               $121 = tempRet0;
               ___clang_call_terminate($120);
               // unreachable;
              } else {
               $$sink34$index = $116;$$sink34$index3 = $117;
               break L20;
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   } while(0);
   $126 = ___cxa_find_matching_catch_2()|0;
   $127 = tempRet0;
   $$sink34$index = $126;$$sink34$index3 = $127;
  }
 } while(0);
 if ((label|0) == 33) {
  $134 = HEAP32[$17>>2]|0;
  $135 = ((($134)) + 12|0);
  $136 = HEAP32[$135>>2]|0;
  (FUNCTION_TABLE_ii[$136 & 8191]($17)|0);
  $$1 = $$0;
  STACKTOP = sp;return ($$1|0);
 }
 $137 = HEAP32[$17>>2]|0;
 $138 = ((($137)) + 12|0);
 $139 = HEAP32[$138>>2]|0;
 __THREW__ = 0;
 (invoke_ii($139|0,($17|0))|0);
 $140 = __THREW__; __THREW__ = 0;
 $141 = $140&1;
 if ($141) {
  $142 = ___cxa_find_matching_catch_3(0|0)|0;
  $143 = tempRet0;
  ___clang_call_terminate($142);
  // unreachable;
 } else {
  ___resumeException($$sink34$index|0);
  // unreachable;
 }
 return (0)|0;
}
function __ZNSt3__23mapINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEdNS_4lessIS6_EENS4_INS_4pairIKS6_dEEEEEixERSA_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$014 = 0, $$pre$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = (__ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEdEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE12__find_equalIS7_EERPNS_16__tree_node_baseIPvEERPNS_15__tree_end_nodeISJ_EERKT_($0,$2,$1)|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if (!($5)) {
  $$014 = $4;
  $26 = ((($$014)) + 32|0);
  STACKTOP = sp;return ($26|0);
 }
 $6 = (__Znwj(40)|0);
 $7 = ((($6)) + 16|0);
 __THREW__ = 0;
 invoke_vii(3457,($7|0),($1|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $10 = ___cxa_find_matching_catch_2()|0;
  $11 = tempRet0;
  __ZdlPv($6);
  ___resumeException($10|0);
  // unreachable;
 }
 $12 = ((($6)) + 32|0);
 HEAPF64[$12>>3] = 0.0;
 $13 = HEAP32[$2>>2]|0;
 HEAP32[$6>>2] = 0;
 $14 = ((($6)) + 4|0);
 HEAP32[$14>>2] = 0;
 $15 = ((($6)) + 8|0);
 HEAP32[$15>>2] = $13;
 HEAP32[$3>>2] = $6;
 $16 = HEAP32[$0>>2]|0;
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==(0|0);
 if ($18) {
  $22 = $6;
 } else {
  $19 = $17;
  HEAP32[$0>>2] = $19;
  $$pre$i = HEAP32[$3>>2]|0;
  $22 = $$pre$i;
 }
 $20 = ((($0)) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($21,$22);
 $23 = ((($0)) + 8|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (($24) + 1)|0;
 HEAP32[$23>>2] = $25;
 $$014 = $6;
 $26 = ((($$014)) + 32|0);
 STACKTOP = sp;return ($26|0);
}
function __ZN3osg7StencilD2Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg14StateAttributeD2Ev($0);
 return;
}
function __ZN3osg7StencilD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1573,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK3osg7Stencil9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(84)|0);
 __THREW__ = 0;
 invoke_vi(3339,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $11 = ___cxa_find_matching_catch_2()|0;
  $12 = tempRet0;
  __ZdlPv($1);
  ___resumeException($11|0);
  // unreachable;
 } else {
  HEAP32[$1>>2] = (66412);
  $4 = ((($1)) + 56|0);
  HEAP32[$4>>2] = 519;
  $5 = ((($1)) + 60|0);
  HEAP32[$5>>2] = 0;
  $6 = ((($1)) + 64|0);
  HEAP32[$6>>2] = -1;
  $7 = ((($1)) + 68|0);
  HEAP32[$7>>2] = 7680;
  $8 = ((($1)) + 72|0);
  HEAP32[$8>>2] = 7680;
  $9 = ((($1)) + 76|0);
  HEAP32[$9>>2] = 7680;
  $10 = ((($1)) + 80|0);
  HEAP32[$10>>2] = -1;
  return ($1|0);
 }
 return (0)|0;
}
function __ZNK3osg7Stencil5cloneERKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(84)|0);
 __THREW__ = 0;
 invoke_viii(3729,($2|0),($0|0),($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $26 = ___cxa_find_matching_catch_2()|0;
  $27 = tempRet0;
  __ZdlPv($2);
  ___resumeException($26|0);
  // unreachable;
 } else {
  HEAP32[$2>>2] = (66412);
  $5 = ((($2)) + 56|0);
  $6 = ((($0)) + 56|0);
  $7 = HEAP32[$6>>2]|0;
  HEAP32[$5>>2] = $7;
  $8 = ((($2)) + 60|0);
  $9 = ((($0)) + 60|0);
  $10 = HEAP32[$9>>2]|0;
  HEAP32[$8>>2] = $10;
  $11 = ((($2)) + 64|0);
  $12 = ((($0)) + 64|0);
  $13 = HEAP32[$12>>2]|0;
  HEAP32[$11>>2] = $13;
  $14 = ((($2)) + 68|0);
  $15 = ((($0)) + 68|0);
  $16 = HEAP32[$15>>2]|0;
  HEAP32[$14>>2] = $16;
  $17 = ((($2)) + 72|0);
  $18 = ((($0)) + 72|0);
  $19 = HEAP32[$18>>2]|0;
  HEAP32[$17>>2] = $19;
  $20 = ((($2)) + 76|0);
  $21 = ((($0)) + 76|0);
  $22 = HEAP32[$21>>2]|0;
  HEAP32[$20>>2] = $22;
  $23 = ((($2)) + 80|0);
  $24 = ((($0)) + 80|0);
  $25 = HEAP32[$24>>2]|0;
  HEAP32[$23>>2] = $25;
  return ($2|0);
 }
 return (0)|0;
}
function __ZNK3osg7Stencil12isSameKindAsEPKNS_6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,26720,0)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK3osg7Stencil11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175113|0);
}
function __ZNK3osg7Stencil9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (153451|0);
}
function __ZNK3osg7Stencil7getTypeEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 24;
}
function __ZNK3osg7Stencil7compareERKNS_14StateAttributeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$ = 0, $$$ = 0, $$2 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $2 = ($0|0)==($1|0);
 if ($2) {
  $$2 = 0;
  return ($$2|0);
 }
 $3 = ($0|0)==(0|0);
 if ($3) {
  ___cxa_bad_typeid();
  // unreachable;
 }
 $4 = HEAP32[$0>>2]|0;
 $5 = ((($4)) + -4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$1>>2]|0;
 $8 = ((($7)) + -4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($6)) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($9)) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($11>>>0)<($13>>>0);
 if ($14) {
  $$2 = -1;
  return ($$2|0);
 }
 $15 = ($11|0)==($13|0);
 if (!($15)) {
  $$2 = 1;
  return ($$2|0);
 }
 $16 = ((($0)) + 56|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ((($1)) + 56|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($17|0)<($19|0);
 if ($20) {
  $$2 = -1;
  return ($$2|0);
 }
 $21 = ($19|0)<($17|0);
 if ($21) {
  $$2 = 1;
  return ($$2|0);
 }
 $22 = ((($0)) + 60|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ((($1)) + 60|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($23|0)<($25|0);
 if ($26) {
  $$2 = -1;
  return ($$2|0);
 }
 $27 = ($25|0)<($23|0);
 if ($27) {
  $$2 = 1;
  return ($$2|0);
 }
 $28 = ((($0)) + 64|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ((($1)) + 64|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ($29>>>0)<($31>>>0);
 if ($32) {
  $$2 = -1;
  return ($$2|0);
 }
 $33 = ($31>>>0)<($29>>>0);
 if ($33) {
  $$2 = 1;
  return ($$2|0);
 }
 $34 = ((($0)) + 68|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = ((($1)) + 68|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = ($35|0)<($37|0);
 if ($38) {
  $$2 = -1;
  return ($$2|0);
 }
 $39 = ($37|0)<($35|0);
 if ($39) {
  $$2 = 1;
  return ($$2|0);
 }
 $40 = ((($0)) + 72|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = ((($1)) + 72|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = ($41|0)<($43|0);
 if ($44) {
  $$2 = -1;
  return ($$2|0);
 }
 $45 = ($43|0)<($41|0);
 if ($45) {
  $$2 = 1;
  return ($$2|0);
 }
 $46 = ((($0)) + 76|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = ((($1)) + 76|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = ($47|0)<($49|0);
 if ($50) {
  $$2 = -1;
  return ($$2|0);
 }
 $51 = ($49|0)<($47|0);
 if ($51) {
  $$2 = 1;
  return ($$2|0);
 } else {
  $52 = ((($0)) + 80|0);
  $53 = HEAP32[$52>>2]|0;
  $54 = ((($1)) + 80|0);
  $55 = HEAP32[$54>>2]|0;
  $56 = ($53>>>0)<($55>>>0);
  $57 = ($55>>>0)<($53>>>0);
  $$ = $57&1;
  $$$ = $56 ? -1 : $$;
  return ($$$|0);
 }
 return (0)|0;
}
function __ZNK3osg7Stencil12getModeUsageERNS_14StateAttribute9ModeUsageE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 8191]($1,2960);
 return 1;
}
function __ZNK3osg7Stencil5applyERNS_5StateE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$$i = 0, $$$i16 = 0, $$$i20 = 0, $$cmp$i = 0, $$cmp$i15 = 0, $$cmp$i19 = 0, $$off$i = 0, $$off$i14 = 0, $$off$i18 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 784|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 68|0);
 $5 = HEAP32[$4>>2]|0;
 $$off$i18 = (($5) + -34055)|0;
 $$cmp$i19 = ($$off$i18>>>0)>(1);
 if ($$cmp$i19) {
  $31 = $5;
 } else {
  $6 = ($5|0)==(34055);
  $7 = $6 ? 7682 : 7683;
  $8 = ((($3)) + 1188|0);
  $9 = HEAP8[$8>>0]|0;
  $10 = ($9<<24>>24)==(0);
  $$$i20 = $10 ? $7 : $5;
  $31 = $$$i20;
 }
 $11 = ((($0)) + 72|0);
 $12 = HEAP32[$11>>2]|0;
 $$off$i14 = (($12) + -34055)|0;
 $$cmp$i15 = ($$off$i14>>>0)>(1);
 if ($$cmp$i15) {
  $32 = $12;
 } else {
  $13 = ($12|0)==(34055);
  $14 = $13 ? 7682 : 7683;
  $15 = ((($3)) + 1188|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = ($16<<24>>24)==(0);
  $$$i16 = $17 ? $14 : $12;
  $32 = $$$i16;
 }
 $18 = ((($0)) + 76|0);
 $19 = HEAP32[$18>>2]|0;
 $$off$i = (($19) + -34055)|0;
 $$cmp$i = ($$off$i>>>0)>(1);
 if ($$cmp$i) {
  $33 = $19;
 } else {
  $20 = ($19|0)==(34055);
  $21 = $20 ? 7682 : 7683;
  $22 = ((($3)) + 1188|0);
  $23 = HEAP8[$22>>0]|0;
  $24 = ($23<<24>>24)==(0);
  $$$i = $24 ? $21 : $19;
  $33 = $$$i;
 }
 $25 = ((($0)) + 56|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ((($0)) + 60|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = ((($0)) + 64|0);
 $30 = HEAP32[$29>>2]|0;
 _glStencilFunc(($26|0),($28|0),($30|0));
 _glStencilOp(($31|0),($32|0),($33|0));
 $34 = ((($0)) + 80|0);
 $35 = HEAP32[$34>>2]|0;
 _glStencilMask(($35|0));
 return;
}
function __ZN3osg7StencilC2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg14StateAttributeC2Ev($0);
 HEAP32[$0>>2] = (66412);
 $1 = ((($0)) + 56|0);
 HEAP32[$1>>2] = 519;
 $2 = ((($0)) + 60|0);
 HEAP32[$2>>2] = 0;
 $3 = ((($0)) + 64|0);
 HEAP32[$3>>2] = -1;
 $4 = ((($0)) + 68|0);
 HEAP32[$4>>2] = 7680;
 $5 = ((($0)) + 72|0);
 HEAP32[$5>>2] = 7680;
 $6 = ((($0)) + 76|0);
 HEAP32[$6>>2] = 7680;
 $7 = ((($0)) + 80|0);
 HEAP32[$7>>2] = -1;
 return;
}
function __ZN3osg6TexMatD2Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg14StateAttributeD2Ev($0);
 return;
}
function __ZN3osg6TexMatD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1573,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK3osg6TexMat9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(192)|0);
 __THREW__ = 0;
 invoke_vi(3339,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $14 = ___cxa_find_matching_catch_2()|0;
  $15 = tempRet0;
  $eh$lpad$body$index2Z2D = $15;$eh$lpad$body$indexZ2D = $14;
  __ZdlPv($1);
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 HEAP32[$1>>2] = (66600);
 $4 = ((($1)) + 56|0);
 __THREW__ = 0;
 invoke_vi(3299,($4|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if (!($6)) {
  $13 = ((($1)) + 184|0);
  HEAP8[$13>>0] = 0;
  return ($1|0);
 }
 $7 = ___cxa_find_matching_catch_2()|0;
 $8 = tempRet0;
 __THREW__ = 0;
 invoke_vi(1573,($1|0));
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if ($10) {
  $11 = ___cxa_find_matching_catch_3(0|0)|0;
  $12 = tempRet0;
  ___clang_call_terminate($11);
  // unreachable;
 } else {
  $eh$lpad$body$index2Z2D = $8;$eh$lpad$body$indexZ2D = $7;
  __ZdlPv($1);
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 return (0)|0;
}
function __ZNK3osg6TexMat5cloneERKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0.0, $13 = 0, $14 = 0, $15 = 0.0, $16 = 0, $17 = 0, $18 = 0.0, $19 = 0, $2 = 0, $20 = 0, $21 = 0.0, $22 = 0, $23 = 0, $24 = 0.0, $25 = 0, $26 = 0, $27 = 0.0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0.0, $31 = 0, $32 = 0, $33 = 0.0, $34 = 0, $35 = 0, $36 = 0.0, $37 = 0, $38 = 0, $39 = 0.0, $4 = 0, $40 = 0, $41 = 0, $42 = 0.0, $43 = 0, $44 = 0, $45 = 0.0, $46 = 0;
 var $47 = 0, $48 = 0.0, $49 = 0, $5 = 0, $50 = 0, $51 = 0.0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = 0.0, $7 = 0, $8 = 0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(192)|0);
 __THREW__ = 0;
 invoke_viii(3729,($2|0),($0|0),($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $56 = ___cxa_find_matching_catch_2()|0;
  $57 = tempRet0;
  __ZdlPv($2);
  ___resumeException($56|0);
  // unreachable;
 } else {
  HEAP32[$2>>2] = (66600);
  $5 = ((($0)) + 56|0);
  $6 = +HEAPF64[$5>>3];
  $7 = ((($2)) + 56|0);
  HEAPF64[$7>>3] = $6;
  $8 = ((($0)) + 64|0);
  $9 = +HEAPF64[$8>>3];
  $10 = ((($2)) + 64|0);
  HEAPF64[$10>>3] = $9;
  $11 = ((($0)) + 72|0);
  $12 = +HEAPF64[$11>>3];
  $13 = ((($2)) + 72|0);
  HEAPF64[$13>>3] = $12;
  $14 = ((($0)) + 80|0);
  $15 = +HEAPF64[$14>>3];
  $16 = ((($2)) + 80|0);
  HEAPF64[$16>>3] = $15;
  $17 = ((($0)) + 88|0);
  $18 = +HEAPF64[$17>>3];
  $19 = ((($2)) + 88|0);
  HEAPF64[$19>>3] = $18;
  $20 = ((($0)) + 96|0);
  $21 = +HEAPF64[$20>>3];
  $22 = ((($2)) + 96|0);
  HEAPF64[$22>>3] = $21;
  $23 = ((($0)) + 104|0);
  $24 = +HEAPF64[$23>>3];
  $25 = ((($2)) + 104|0);
  HEAPF64[$25>>3] = $24;
  $26 = ((($0)) + 112|0);
  $27 = +HEAPF64[$26>>3];
  $28 = ((($2)) + 112|0);
  HEAPF64[$28>>3] = $27;
  $29 = ((($0)) + 120|0);
  $30 = +HEAPF64[$29>>3];
  $31 = ((($2)) + 120|0);
  HEAPF64[$31>>3] = $30;
  $32 = ((($0)) + 128|0);
  $33 = +HEAPF64[$32>>3];
  $34 = ((($2)) + 128|0);
  HEAPF64[$34>>3] = $33;
  $35 = ((($0)) + 136|0);
  $36 = +HEAPF64[$35>>3];
  $37 = ((($2)) + 136|0);
  HEAPF64[$37>>3] = $36;
  $38 = ((($0)) + 144|0);
  $39 = +HEAPF64[$38>>3];
  $40 = ((($2)) + 144|0);
  HEAPF64[$40>>3] = $39;
  $41 = ((($0)) + 152|0);
  $42 = +HEAPF64[$41>>3];
  $43 = ((($2)) + 152|0);
  HEAPF64[$43>>3] = $42;
  $44 = ((($0)) + 160|0);
  $45 = +HEAPF64[$44>>3];
  $46 = ((($2)) + 160|0);
  HEAPF64[$46>>3] = $45;
  $47 = ((($0)) + 168|0);
  $48 = +HEAPF64[$47>>3];
  $49 = ((($2)) + 168|0);
  HEAPF64[$49>>3] = $48;
  $50 = ((($0)) + 176|0);
  $51 = +HEAPF64[$50>>3];
  $52 = ((($2)) + 176|0);
  HEAPF64[$52>>3] = $51;
  $53 = ((($2)) + 184|0);
  $54 = ((($0)) + 184|0);
  $55 = HEAP8[$54>>0]|0;
  HEAP8[$53>>0] = $55;
  return ($2|0);
 }
 return (0)|0;
}
function __ZNK3osg6TexMat12isSameKindAsEPKNS_6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,26736,0)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK3osg6TexMat11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175113|0);
}
function __ZNK3osg6TexMat9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (153522|0);
}
function __ZNK3osg6TexMat7getTypeEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 19;
}
function __ZNK3osg6TexMat18isTextureAttributeEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 1;
}
function __ZNK3osg6TexMat7compareERKNS_14StateAttributeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$2 = 0, $$lobit = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($0|0)==($1|0);
 if ($2) {
  $$2 = 0;
  return ($$2|0);
 }
 $3 = ($0|0)==(0|0);
 if ($3) {
  ___cxa_bad_typeid();
  // unreachable;
 }
 $4 = HEAP32[$0>>2]|0;
 $5 = ((($4)) + -4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$1>>2]|0;
 $8 = ((($7)) + -4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($6)) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($9)) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($11>>>0)<($13>>>0);
 if ($14) {
  $$2 = -1;
  return ($$2|0);
 }
 $15 = ($11|0)==($13|0);
 if (!($15)) {
  $$2 = 1;
  return ($$2|0);
 }
 $16 = ((($0)) + 56|0);
 $17 = ((($1)) + 56|0);
 $18 = (__ZNK3osg7Matrixd7compareERKS0_($16,$17)|0);
 $19 = ($18|0)<(0);
 if ($19) {
  $$2 = -1;
  return ($$2|0);
 }
 $20 = (__ZNK3osg7Matrixd7compareERKS0_($17,$16)|0);
 $$lobit = $20 >>> 31;
 $$2 = $$lobit;
 return ($$2|0);
}
function __ZNK3osg6TexMat5applyERNS_5StateE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $4 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
 $5 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($4,153474,47)|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($6)) + -12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($5) + ($8)|0);
 __ZNKSt3__28ios_base6getlocEv($2,$9);
 __THREW__ = 0;
 $10 = (invoke_iii(3255,($2|0),(215188|0))|0);
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if (!($12)) {
  $13 = HEAP32[$10>>2]|0;
  $14 = ((($13)) + 28|0);
  $15 = HEAP32[$14>>2]|0;
  __THREW__ = 0;
  $16 = (invoke_iii($15|0,($10|0),10)|0);
  $17 = __THREW__; __THREW__ = 0;
  $18 = $17&1;
  if (!($18)) {
   __ZNSt3__26localeD2Ev($2);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($5,$16)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($5)|0);
   STACKTOP = sp;return;
  }
 }
 $19 = ___cxa_find_matching_catch_2()|0;
 $20 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($2|0));
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if ($22) {
  $23 = ___cxa_find_matching_catch_3(0|0)|0;
  $24 = tempRet0;
  ___clang_call_terminate($23);
  // unreachable;
 } else {
  ___resumeException($19|0);
  // unreachable;
 }
}
function __ZN3osg6TexMatC2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg14StateAttributeC2Ev($0);
 HEAP32[$0>>2] = (66600);
 $1 = ((($0)) + 56|0);
 __THREW__ = 0;
 invoke_vi(3299,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  $4 = ((($0)) + 184|0);
  HEAP8[$4>>0] = 0;
  return;
 }
 $5 = ___cxa_find_matching_catch_2()|0;
 $6 = tempRet0;
 __THREW__ = 0;
 invoke_vi(1573,($0|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch_3(0|0)|0;
  $10 = tempRet0;
  ___clang_call_terminate($9);
  // unreachable;
 } else {
  ___resumeException($5|0);
  // unreachable;
 }
}
function __ZN3osg7Texture9asTextureEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ($0|0);
}
function __ZNK3osg7Texture9asTextureEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ($0|0);
}
function __ZNK3osg7Texture18isTextureAttributeEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 1;
}
function __ZN3osg9Texture1D17copyTexSubImage1DERNS_5StateEiiii($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $6 = sp;
 $7 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
 if (!($7)) {
  STACKTOP = sp;return;
 }
 $8 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
 $9 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($8,153560,56)|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ((($10)) + -12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($9) + ($12)|0);
 __ZNKSt3__28ios_base6getlocEv($6,$13);
 __THREW__ = 0;
 $14 = (invoke_iii(3255,($6|0),(215188|0))|0);
 $15 = __THREW__; __THREW__ = 0;
 $16 = $15&1;
 if (!($16)) {
  $17 = HEAP32[$14>>2]|0;
  $18 = ((($17)) + 28|0);
  $19 = HEAP32[$18>>2]|0;
  __THREW__ = 0;
  $20 = (invoke_iii($19|0,($14|0),10)|0);
  $21 = __THREW__; __THREW__ = 0;
  $22 = $21&1;
  if (!($22)) {
   __ZNSt3__26localeD2Ev($6);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($9,$20)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($9)|0);
   STACKTOP = sp;return;
  }
 }
 $23 = ___cxa_find_matching_catch_2()|0;
 $24 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($6|0));
 $25 = __THREW__; __THREW__ = 0;
 $26 = $25&1;
 if ($26) {
  $27 = ___cxa_find_matching_catch_3(0|0)|0;
  $28 = tempRet0;
  ___clang_call_terminate($27);
  // unreachable;
 } else {
  ___resumeException($23|0);
  // unreachable;
 }
}
function __ZN3osg9Texture2DD2Ev($0) {
 $0 = $0|0;
 var $$1 = 0, $$13 = 0, $$2 = 0, $$24 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i$i$i6 = 0, $scevgep5$i$i$i$i = 0, $scevgep5$i$i$i$i7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (66788);
 __THREW__ = 0;
 invoke_vii(3964,($0|0),(0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if ($2) {
   $30 = ___cxa_find_matching_catch_2()|0;
   $31 = tempRet0;
   $32 = ((($0)) + 260|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = ($33|0)==(0|0);
   if (!($34)) {
    $35 = ((($0)) + 264|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = ($36|0)==($33|0);
    if (!($37)) {
     $scevgep$i$i$i$i6 = ((($36)) + -4|0);
     $38 = $scevgep$i$i$i$i6;
     $39 = $33;
     $40 = (($38) - ($39))|0;
     $41 = $40 >>> 2;
     $42 = $41 ^ -1;
     $scevgep5$i$i$i$i7 = (($36) + ($42<<2)|0);
     HEAP32[$35>>2] = $scevgep5$i$i$i$i7;
    }
    __ZdlPv($33);
   }
   $45 = ((($0)) + 256|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = ($46|0)==(0|0);
   if (!($47)) {
    $48 = ((($46)) + 8|0);
    $49 = HEAP32[$48>>2]|0;HEAP32[$48>>2] = (($49-1)|0);
    $50 = ($49|0)==(1);
    if ($50) {
     __THREW__ = 0;
     invoke_viii(3262,($46|0),1,1);
     $51 = __THREW__; __THREW__ = 0;
     $52 = $51&1;
     if ($52) {
      $65 = ___cxa_find_matching_catch_3(0|0)|0;
      $66 = tempRet0;
      ___clang_call_terminate($65);
      // unreachable;
     }
    }
   }
   HEAP32[$45>>2] = 0;
   $$1 = $31;$$13 = $30;
   label = 23;
  } else {
   $3 = ((($0)) + 260|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = ($4|0)==(0|0);
   if (!($5)) {
    $6 = ((($0)) + 264|0);
    $7 = HEAP32[$6>>2]|0;
    $8 = ($7|0)==($4|0);
    if (!($8)) {
     $scevgep$i$i$i$i = ((($7)) + -4|0);
     $9 = $scevgep$i$i$i$i;
     $10 = $4;
     $11 = (($9) - ($10))|0;
     $12 = $11 >>> 2;
     $13 = $12 ^ -1;
     $scevgep5$i$i$i$i = (($7) + ($13<<2)|0);
     HEAP32[$6>>2] = $scevgep5$i$i$i$i;
    }
    __ZdlPv($4);
   }
   $14 = ((($0)) + 256|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = ($15|0)==(0|0);
   if (!($16)) {
    $17 = ((($15)) + 8|0);
    $18 = HEAP32[$17>>2]|0;HEAP32[$17>>2] = (($18-1)|0);
    $19 = ($18|0)==(1);
    if ($19) {
     __THREW__ = 0;
     invoke_viii(3262,($15|0),1,1);
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      $43 = ___cxa_find_matching_catch_2()|0;
      $44 = tempRet0;
      $$1 = $44;$$13 = $43;
      label = 23;
      break;
     }
    }
   }
   HEAP32[$14>>2] = 0;
   $22 = ((($0)) + 240|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = ($23|0)==(0|0);
   if ($24) {
    HEAP32[$22>>2] = 0;
    __ZN3osg7TextureD2Ev($0);
    return;
   }
   $25 = ((($23)) + 8|0);
   $26 = HEAP32[$25>>2]|0;HEAP32[$25>>2] = (($26-1)|0);
   $27 = ($26|0)==(1);
   if (!($27)) {
    HEAP32[$22>>2] = 0;
    __ZN3osg7TextureD2Ev($0);
    return;
   }
   __THREW__ = 0;
   invoke_viii(3262,($23|0),1,1);
   $28 = __THREW__; __THREW__ = 0;
   $29 = $28&1;
   if ($29) {
    $53 = ___cxa_find_matching_catch_2()|0;
    $54 = tempRet0;
    $$2 = $54;$$24 = $53;
    break;
   } else {
    HEAP32[$22>>2] = 0;
    __ZN3osg7TextureD2Ev($0);
    return;
   }
  }
 } while(0);
 if ((label|0) == 23) {
  $55 = ((($0)) + 240|0);
  $56 = HEAP32[$55>>2]|0;
  $57 = ($56|0)==(0|0);
  if (!($57)) {
   $58 = ((($56)) + 8|0);
   $59 = HEAP32[$58>>2]|0;HEAP32[$58>>2] = (($59-1)|0);
   $60 = ($59|0)==(1);
   if ($60) {
    __THREW__ = 0;
    invoke_viii(3262,($56|0),1,1);
    $61 = __THREW__; __THREW__ = 0;
    $62 = $61&1;
    if ($62) {
     $65 = ___cxa_find_matching_catch_3(0|0)|0;
     $66 = tempRet0;
     ___clang_call_terminate($65);
     // unreachable;
    }
   }
  }
  HEAP32[$55>>2] = 0;
  $$2 = $$1;$$24 = $$13;
 }
 __THREW__ = 0;
 invoke_vi(2335,($0|0));
 $63 = __THREW__; __THREW__ = 0;
 $64 = $63&1;
 if ($64) {
  $65 = ___cxa_find_matching_catch_3(0|0)|0;
  $66 = tempRet0;
  ___clang_call_terminate($65);
  // unreachable;
 } else {
  ___resumeException($$24|0);
  // unreachable;
 }
}
function __ZN3osg9Texture2DD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(2297,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK3osg9Texture2D9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(272)|0);
 __THREW__ = 0;
 invoke_vi(3965,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch_2()|0;
  $5 = tempRet0;
  __ZdlPv($1);
  ___resumeException($4|0);
  // unreachable;
 } else {
  return ($1|0);
 }
 return (0)|0;
}
function __ZNK3osg9Texture2D5cloneERKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(272)|0);
 __THREW__ = 0;
 invoke_viii(3966,($2|0),($0|0),($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch_2()|0;
  $6 = tempRet0;
  __ZdlPv($2);
  ___resumeException($5|0);
  // unreachable;
 } else {
  return ($2|0);
 }
 return (0)|0;
}
function __ZNK3osg9Texture2D12isSameKindAsEPKNS_6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,26784,0)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK3osg9Texture2D11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175113|0);
}
function __ZNK3osg9Texture2D9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (153640|0);
}
function __ZNK3osg9Texture2D7getTypeEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function __ZNK3osg9Texture2D7compareERKNS_14StateAttributeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$$45 = 0, $$45 = 0, $$6 = 0, $$pre = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($0|0)==($1|0);
 if ($2) {
  $$6 = 0;
  return ($$6|0);
 }
 $3 = ($0|0)==(0|0);
 if ($3) {
  ___cxa_bad_typeid();
  // unreachable;
 }
 $4 = HEAP32[$0>>2]|0;
 $5 = ((($4)) + -4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$1>>2]|0;
 $8 = ((($7)) + -4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($6)) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($9)) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($11>>>0)<($13>>>0);
 if ($14) {
  $$6 = -1;
  return ($$6|0);
 }
 $15 = ($11|0)==($13|0);
 if (!($15)) {
  $$6 = 1;
  return ($$6|0);
 }
 $16 = ((($0)) + 240|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ((($1)) + 240|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($17|0)==($19|0);
 do {
  if ($20) {
   $28 = $17;
   label = 12;
  } else {
   $21 = ($17|0)==(0|0);
   $22 = ($19|0)!=(0|0);
   if ($21) {
    if ($22) {
     $$6 = -1;
    } else {
     label = 13;
     break;
    }
    return ($$6|0);
   }
   if (!($22)) {
    $$6 = 1;
    return ($$6|0);
   }
   $23 = HEAP32[$17>>2]|0;
   $24 = ((($23)) + 172|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = (FUNCTION_TABLE_iii[$25 & 8191]($17,$19)|0);
   $27 = ($26|0)==(0);
   if ($27) {
    $$pre = HEAP32[$16>>2]|0;
    $28 = $$pre;
    label = 12;
    break;
   } else {
    $$6 = $26;
    return ($$6|0);
   }
  }
 } while(0);
 if ((label|0) == 12) {
  $29 = ($28|0)==(0|0);
  if ($29) {
   label = 13;
  }
 }
 if ((label|0) == 13) {
  $30 = HEAP32[$18>>2]|0;
  $31 = ($30|0)==(0|0);
  if ($31) {
   $32 = (__ZNK3osg7Texture21compareTextureObjectsERKS0_($0,$1)|0);
   $33 = ($32|0)==(0);
   if (!($33)) {
    $$6 = $32;
    return ($$6|0);
   }
  }
 }
 $34 = (__ZNK3osg7Texture14compareTextureERKS0_($0,$1)|0);
 $35 = ($34|0)==(0);
 if (!($35)) {
  $$6 = $34;
  return ($$6|0);
 }
 $36 = ((($0)) + 244|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = ($37|0)==(0);
 if (!($38)) {
  $39 = ((($1)) + 244|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = ($40|0)==(0);
  if (!($41)) {
   $42 = ($37|0)<($40|0);
   if ($42) {
    $$6 = -1;
    return ($$6|0);
   }
   $43 = ($40|0)<($37|0);
   if ($43) {
    $$6 = 1;
    return ($$6|0);
   }
  }
 }
 $44 = ((($0)) + 248|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = ($45|0)==(0);
 if (!($46)) {
  $47 = ((($1)) + 248|0);
  $48 = HEAP32[$47>>2]|0;
  $49 = ($48|0)==(0);
  if (!($49)) {
   $50 = ($45|0)<($48|0);
   if ($50) {
    $$6 = -1;
    return ($$6|0);
   }
   $51 = ($48|0)<($45|0);
   if ($51) {
    $$6 = 1;
    return ($$6|0);
   }
  }
 }
 $52 = ((($0)) + 256|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = ((($1)) + 256|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = ($53>>>0)<($55>>>0);
 $57 = ($55>>>0)<($53>>>0);
 $$45 = $57&1;
 $$$45 = $56 ? -1 : $$45;
 return ($$$45|0);
}
function __ZNK3osg9Texture2D5applyERNS_5StateE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$ = 0, $$153 = 0, $$155 = 0, $$2 = 0, $$pr = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i$i103 = 0, $$pre$i$i67 = 0, $$pre$i$i75 = 0, $$pre$i$i85 = 0, $$pre$i$i95 = 0, $$pre$pre = 0, $$pre$pre$i = 0, $$pre$pre$i$i = 0, $$pre$pre$i$i63 = 0, $$pre$pre$i$i71 = 0, $$pre$pre$i$i81 = 0, $$pre$pre$i$i91 = 0;
 var $$pre$pre$i$i99 = 0, $$pre128 = 0, $$pre128$pre = 0, $$pre131 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0;
 var $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0;
 var $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0;
 var $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0;
 var $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0;
 var $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0;
 var $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0;
 var $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0;
 var $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0;
 var $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0;
 var $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0;
 var $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0;
 var $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0;
 var $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0;
 var $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0;
 var $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0;
 var $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0;
 var $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0;
 var $529 = 0, $53 = 0, $530 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i100 = 0, $scevgep$i$i$i$i$i64 = 0, $scevgep$i$i$i$i$i72 = 0, $scevgep$i$i$i$i$i82 = 0, $scevgep$i$i$i$i$i92 = 0;
 var $scevgep5$i$i$i$i = 0, $scevgep5$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i101 = 0, $scevgep5$i$i$i$i$i65 = 0, $scevgep5$i$i$i$i$i73 = 0, $scevgep5$i$i$i$i$i83 = 0, $scevgep5$i$i$i$i$i93 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $2 = sp + 28|0;
 $3 = sp + 24|0;
 $4 = sp + 20|0;
 $5 = sp + 16|0;
 $6 = sp + 12|0;
 $7 = sp + 8|0;
 $8 = sp + 4|0;
 $9 = sp;
 $10 = ((($1)) + 124|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($0)) + 224|0);
 $13 = ((($0)) + 228|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP32[$12>>2]|0;
 $16 = (($14) - ($15))|0;
 $17 = $16 >> 2;
 $18 = ($17>>>0)>($11>>>0);
 L1: do {
  if (!($18)) {
   $19 = (($11) + 1)|0;
   $20 = ($19>>>0)>($17>>>0);
   $21 = $15;
   $22 = $14;
   if ($20) {
    $23 = (($19) - ($17))|0;
    __ZNSt3__26vectorIN3osg7ref_ptrINS1_7Texture13TextureObjectEEENS_9allocatorIS5_EEE8__appendEj($12,$23);
    break;
   }
   $24 = ($19>>>0)<($17>>>0);
   if ($24) {
    $25 = (($21) + ($19<<2)|0);
    $26 = ($22|0)==($25|0);
    if (!($26)) {
     $28 = $22;
     while(1) {
      $27 = ((($28)) + -4|0);
      HEAP32[$13>>2] = $27;
      $29 = HEAP32[$27>>2]|0;
      $30 = ($29|0)==(0|0);
      if (!($30)) {
       $31 = ((($29)) + 8|0);
       $32 = HEAP32[$31>>2]|0;HEAP32[$31>>2] = (($32-1)|0);
       $33 = ($32|0)==(1);
       if ($33) {
        __THREW__ = 0;
        invoke_viii(3262,($29|0),1,1);
        $34 = __THREW__; __THREW__ = 0;
        $35 = $34&1;
        if ($35) {
         break;
        }
       }
      }
      HEAP32[$27>>2] = 0;
      $36 = HEAP32[$13>>2]|0;
      $37 = ($36|0)==($25|0);
      if ($37) {
       break L1;
      } else {
       $28 = $36;
      }
     }
     $38 = ___cxa_find_matching_catch_2()|0;
     $39 = tempRet0;
     ___cxa_call_unexpected(($38|0));
     // unreachable;
    }
   }
  }
 } while(0);
 $40 = HEAP32[$12>>2]|0;
 $41 = (($40) + ($11<<2)|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ($42|0)==(0|0);
 $$pre131 = ((($0)) + 256|0);
 do {
  if ($43) {
   label = 77;
  } else {
   $44 = HEAP32[$$pre131>>2]|0;
   $45 = ($44|0)==(0|0);
   if ($45) {
    $46 = ((($0)) + 240|0);
    $47 = HEAP32[$46>>2]|0;
    $48 = ($47|0)==(0|0);
    if (!($48)) {
     $49 = ((($0)) + 260|0);
     $50 = ((($0)) + 264|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = HEAP32[$49>>2]|0;
     $53 = (($51) - ($52))|0;
     $54 = $53 >> 2;
     $55 = ($54>>>0)>($11>>>0);
     $56 = $52;
     if ($55) {
      $70 = $56;$73 = $47;
     } else {
      $57 = (($11) + 1)|0;
      HEAP32[$7>>2] = 0;
      $58 = ($57>>>0)>($54>>>0);
      $59 = $51;
      if ($58) {
       $60 = (($57) - ($54))|0;
       __ZNSt3__26vectorIjNS_9allocatorIjEEE8__appendEjRKj($49,$60,$7);
       $$pre$pre$i$i = HEAP32[$49>>2]|0;
       $$pre$pre = HEAP32[$46>>2]|0;
       $$pre = $$pre$pre;$$pre$i$i = $$pre$pre$i$i;
      } else {
       $61 = ($57>>>0)<($54>>>0);
       if ($61) {
        $62 = (($56) + ($57<<2)|0);
        $63 = ($59|0)==($62|0);
        if ($63) {
         $$pre = $47;$$pre$i$i = $56;
        } else {
         $scevgep$i$i$i$i$i = ((($59)) + -4|0);
         $64 = $scevgep$i$i$i$i$i;
         $65 = $62;
         $66 = (($64) - ($65))|0;
         $67 = $66 >>> 2;
         $68 = $67 ^ -1;
         $scevgep5$i$i$i$i$i = (($59) + ($68<<2)|0);
         HEAP32[$50>>2] = $scevgep5$i$i$i$i$i;
         $$pre = $47;$$pre$i$i = $56;
        }
       } else {
        $$pre = $47;$$pre$i$i = $56;
       }
      }
      $70 = $$pre$i$i;$73 = $$pre;
     }
     $69 = (($70) + ($11<<2)|0);
     $71 = HEAP32[$69>>2]|0;
     $72 = ((($73)) + 32|0);
     $74 = HEAP32[$72>>2]|0;
     $75 = ($71|0)==($74|0);
     if (!($75)) {
      $76 = (__ZNK3osg9Texture2D18textureObjectValidERNS_5StateE($0,$1)|0);
      if (!($76)) {
       label = 24;
      }
     }
    }
   } else {
    $77 = HEAP32[$44>>2]|0;
    $78 = ((($77)) + 12|0);
    $79 = HEAP32[$78>>2]|0;
    $80 = (FUNCTION_TABLE_iiii[$79 & 8191]($44,$0,$1)|0);
    if (!($80)) {
     label = 24;
    }
   }
   if ((label|0) == 24) {
    $81 = HEAP32[$13>>2]|0;
    $82 = HEAP32[$12>>2]|0;
    $83 = (($81) - ($82))|0;
    $84 = $83 >> 2;
    $85 = ($84>>>0)>($11>>>0);
    L33: do {
     if (!($85)) {
      $86 = (($11) + 1)|0;
      $87 = ($86>>>0)>($84>>>0);
      $88 = $82;
      $89 = $81;
      if ($87) {
       $90 = (($86) - ($84))|0;
       __ZNSt3__26vectorIN3osg7ref_ptrINS1_7Texture13TextureObjectEEENS_9allocatorIS5_EEE8__appendEj($12,$90);
       break;
      }
      $91 = ($86>>>0)<($84>>>0);
      if ($91) {
       $92 = (($88) + ($86<<2)|0);
       $93 = ($89|0)==($92|0);
       if (!($93)) {
        $95 = $89;
        while(1) {
         $94 = ((($95)) + -4|0);
         HEAP32[$13>>2] = $94;
         $96 = HEAP32[$94>>2]|0;
         $97 = ($96|0)==(0|0);
         if (!($97)) {
          $98 = ((($96)) + 8|0);
          $99 = HEAP32[$98>>2]|0;HEAP32[$98>>2] = (($99-1)|0);
          $100 = ($99|0)==(1);
          if ($100) {
           __THREW__ = 0;
           invoke_viii(3262,($96|0),1,1);
           $101 = __THREW__; __THREW__ = 0;
           $102 = $101&1;
           if ($102) {
            break;
           }
          }
         }
         HEAP32[$94>>2] = 0;
         $103 = HEAP32[$13>>2]|0;
         $104 = ($103|0)==($92|0);
         if ($104) {
          break L33;
         } else {
          $95 = $103;
         }
        }
        $105 = ___cxa_find_matching_catch_2()|0;
        $106 = tempRet0;
        ___cxa_call_unexpected(($105|0));
        // unreachable;
       }
      }
     }
    } while(0);
    $107 = HEAP32[$12>>2]|0;
    $108 = (($107) + ($11<<2)|0);
    $109 = HEAP32[$108>>2]|0;
    __ZN3osg7Texture13TextureObject7releaseEv($109);
    $110 = HEAP32[$13>>2]|0;
    $111 = HEAP32[$12>>2]|0;
    $112 = (($110) - ($111))|0;
    $113 = $112 >> 2;
    $114 = ($113>>>0)>($11>>>0);
    L47: do {
     if (!($114)) {
      $115 = (($11) + 1)|0;
      $116 = ($115>>>0)>($113>>>0);
      $117 = $111;
      $118 = $110;
      if ($116) {
       $119 = (($115) - ($113))|0;
       __ZNSt3__26vectorIN3osg7ref_ptrINS1_7Texture13TextureObjectEEENS_9allocatorIS5_EEE8__appendEj($12,$119);
       break;
      }
      $120 = ($115>>>0)<($113>>>0);
      if ($120) {
       $121 = (($117) + ($115<<2)|0);
       $122 = ($118|0)==($121|0);
       if (!($122)) {
        $124 = $118;
        while(1) {
         $123 = ((($124)) + -4|0);
         HEAP32[$13>>2] = $123;
         $125 = HEAP32[$123>>2]|0;
         $126 = ($125|0)==(0|0);
         if (!($126)) {
          $127 = ((($125)) + 8|0);
          $128 = HEAP32[$127>>2]|0;HEAP32[$127>>2] = (($128-1)|0);
          $129 = ($128|0)==(1);
          if ($129) {
           __THREW__ = 0;
           invoke_viii(3262,($125|0),1,1);
           $130 = __THREW__; __THREW__ = 0;
           $131 = $130&1;
           if ($131) {
            break;
           }
          }
         }
         HEAP32[$123>>2] = 0;
         $132 = HEAP32[$13>>2]|0;
         $133 = ($132|0)==($121|0);
         if ($133) {
          break L47;
         } else {
          $124 = $132;
         }
        }
        $134 = ___cxa_find_matching_catch_2()|0;
        $135 = tempRet0;
        ___cxa_call_unexpected(($134|0));
        // unreachable;
       }
      }
     }
    } while(0);
    $136 = HEAP32[$12>>2]|0;
    $137 = (($136) + ($11<<2)|0);
    $138 = HEAP32[$137>>2]|0;
    $139 = ($138|0)==(0|0);
    if ($139) {
     label = 77;
     break;
    }
    HEAP32[$137>>2] = 0;
    $140 = ((($138)) + 8|0);
    $141 = HEAP32[$140>>2]|0;HEAP32[$140>>2] = (($141-1)|0);
    $142 = ($141|0)==(1);
    if (!($142)) {
     label = 77;
     break;
    }
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($138,1,1);
    label = 77;
    break;
   }
   __ZN3osg7Texture13TextureObject4bindEv($42);
   $143 = HEAP32[$10>>2]|0;
   $144 = ((($0)) + 56|0);
   $145 = ((($0)) + 60|0);
   $146 = HEAP32[$145>>2]|0;
   $147 = HEAP32[$144>>2]|0;
   $148 = (($146) - ($147))|0;
   $149 = $148 >> 2;
   $150 = ($149>>>0)>($143>>>0);
   $151 = $147;
   if ($150) {
    $165 = $151;
   } else {
    $152 = (($143) + 1)|0;
    HEAP32[$6>>2] = 0;
    $153 = ($152>>>0)>($149>>>0);
    $154 = $146;
    if ($153) {
     $155 = (($152) - ($149))|0;
     __ZNSt3__26vectorIjNS_9allocatorIjEEE8__appendEjRKj($144,$155,$6);
     $$pre$pre$i$i63 = HEAP32[$144>>2]|0;
     $$pre$i$i67 = $$pre$pre$i$i63;
    } else {
     $156 = ($152>>>0)<($149>>>0);
     if ($156) {
      $157 = (($151) + ($152<<2)|0);
      $158 = ($154|0)==($157|0);
      if ($158) {
       $$pre$i$i67 = $151;
      } else {
       $scevgep$i$i$i$i$i64 = ((($154)) + -4|0);
       $159 = $scevgep$i$i$i$i$i64;
       $160 = $157;
       $161 = (($159) - ($160))|0;
       $162 = $161 >>> 2;
       $163 = $162 ^ -1;
       $scevgep5$i$i$i$i$i65 = (($154) + ($163<<2)|0);
       HEAP32[$145>>2] = $scevgep5$i$i$i$i$i65;
       $$pre$i$i67 = $151;
      }
     } else {
      $$pre$i$i67 = $151;
     }
    }
    $165 = $$pre$i$i67;
   }
   $164 = (($165) + ($143<<2)|0);
   $166 = HEAP32[$164>>2]|0;
   $167 = ($166|0)==(0);
   if (!($167)) {
    __ZNK3osg7Texture18applyTexParametersEjRNS_5StateE($0,3553,$1);
   }
   $168 = HEAP32[$$pre131>>2]|0;
   $169 = ($168|0)==(0|0);
   if (!($169)) {
    $170 = HEAP32[$168>>2]|0;
    $171 = ((($170)) + 24|0);
    $172 = HEAP32[$171>>2]|0;
    FUNCTION_TABLE_viii[$172 & 8191]($168,$0,$1);
    $$2 = $42;
    break;
   }
   $173 = ((($0)) + 240|0);
   $174 = HEAP32[$173>>2]|0;
   $175 = ($174|0)==(0|0);
   if (!($175)) {
    $176 = ((($0)) + 260|0);
    $177 = ((($0)) + 264|0);
    $178 = HEAP32[$177>>2]|0;
    $179 = HEAP32[$176>>2]|0;
    $180 = (($178) - ($179))|0;
    $181 = $180 >> 2;
    $182 = ($181>>>0)>($11>>>0);
    $183 = $179;
    if ($182) {
     $197 = $183;$200 = $174;
    } else {
     $184 = (($11) + 1)|0;
     HEAP32[$5>>2] = 0;
     $185 = ($184>>>0)>($181>>>0);
     $186 = $178;
     if ($185) {
      $187 = (($184) - ($181))|0;
      __ZNSt3__26vectorIjNS_9allocatorIjEEE8__appendEjRKj($176,$187,$5);
      $$pre$pre$i$i71 = HEAP32[$176>>2]|0;
      $$pre128$pre = HEAP32[$173>>2]|0;
      $$pre$i$i75 = $$pre$pre$i$i71;$$pre128 = $$pre128$pre;
     } else {
      $188 = ($184>>>0)<($181>>>0);
      if ($188) {
       $189 = (($183) + ($184<<2)|0);
       $190 = ($186|0)==($189|0);
       if ($190) {
        $$pre$i$i75 = $183;$$pre128 = $174;
       } else {
        $scevgep$i$i$i$i$i72 = ((($186)) + -4|0);
        $191 = $scevgep$i$i$i$i$i72;
        $192 = $189;
        $193 = (($191) - ($192))|0;
        $194 = $193 >>> 2;
        $195 = $194 ^ -1;
        $scevgep5$i$i$i$i$i73 = (($186) + ($195<<2)|0);
        HEAP32[$177>>2] = $scevgep5$i$i$i$i$i73;
        $$pre$i$i75 = $183;$$pre128 = $174;
       }
      } else {
       $$pre$i$i75 = $183;$$pre128 = $174;
      }
     }
     $197 = $$pre$i$i75;$200 = $$pre128;
    }
    $196 = (($197) + ($11<<2)|0);
    $198 = HEAP32[$196>>2]|0;
    $199 = ((($200)) + 32|0);
    $201 = HEAP32[$199>>2]|0;
    $202 = ($198|0)==($201|0);
    if (!($202)) {
     $203 = ((($0)) + 244|0);
     $204 = HEAP32[$203>>2]|0;
     $205 = ((($0)) + 248|0);
     $206 = HEAP32[$205>>2]|0;
     $207 = ((($0)) + 172|0);
     $208 = HEAP32[$207>>2]|0;
     $209 = ((($0)) + 252|0);
     $210 = HEAP32[$209>>2]|0;
     __ZNK3osg7Texture23applyTexImage2D_subloadERNS_5StateEjPKNS_5ImageEiiii($0,$1,3553,$200,$204,$206,$208,$210);
     $211 = HEAP32[$173>>2]|0;
     $212 = ((($211)) + 32|0);
     $213 = HEAP32[$212>>2]|0;
     $214 = HEAP32[$177>>2]|0;
     $215 = HEAP32[$176>>2]|0;
     $216 = (($214) - ($215))|0;
     $217 = $216 >> 2;
     $218 = ($217>>>0)>($11>>>0);
     $219 = $215;
     if ($218) {
      $233 = $219;
     } else {
      $220 = (($11) + 1)|0;
      HEAP32[$3>>2] = 0;
      $221 = ($220>>>0)>($217>>>0);
      $222 = $214;
      if ($221) {
       $223 = (($220) - ($217))|0;
       __ZNSt3__26vectorIjNS_9allocatorIjEEE8__appendEjRKj($176,$223,$3);
       $$pre$pre$i$i91 = HEAP32[$176>>2]|0;
       $$pre$i$i95 = $$pre$pre$i$i91;
      } else {
       $224 = ($220>>>0)<($217>>>0);
       if ($224) {
        $225 = (($219) + ($220<<2)|0);
        $226 = ($222|0)==($225|0);
        if ($226) {
         $$pre$i$i95 = $219;
        } else {
         $scevgep$i$i$i$i$i92 = ((($222)) + -4|0);
         $227 = $scevgep$i$i$i$i$i92;
         $228 = $225;
         $229 = (($227) - ($228))|0;
         $230 = $229 >>> 2;
         $231 = $230 ^ -1;
         $scevgep5$i$i$i$i$i93 = (($222) + ($231<<2)|0);
         HEAP32[$177>>2] = $scevgep5$i$i$i$i$i93;
         $$pre$i$i95 = $219;
        }
       } else {
        $$pre$i$i95 = $219;
       }
      }
      $233 = $$pre$i$i95;
     }
     $232 = (($233) + ($11<<2)|0);
     HEAP32[$232>>2] = $213;
     $$2 = $42;
     break;
    }
   }
   $234 = ((($0)) + 236|0);
   $235 = HEAP32[$234>>2]|0;
   $236 = ($235|0)==(0|0);
   if ($236) {
    $$2 = $42;
   } else {
    $237 = HEAP32[$235>>2]|0;
    $238 = ((($237)) + 176|0);
    $239 = HEAP32[$238>>2]|0;
    FUNCTION_TABLE_vii[$239 & 8191]($235,1028);
    $$2 = $42;
   }
  }
 } while(0);
 L102: do {
  if ((label|0) == 77) {
   $240 = HEAP32[$$pre131>>2]|0;
   $241 = ($240|0)==(0|0);
   if ($241) {
    $371 = ((($0)) + 240|0);
    $372 = HEAP32[$371>>2]|0;
    $373 = ($372|0)==(0|0);
    if (!($373)) {
     $374 = ((($372)) + 112|0);
     $375 = HEAP32[$374>>2]|0;
     $376 = ($375|0)==(0|0);
     if (!($376)) {
      $377 = ((($372)) + 8|0);
      $378 = HEAP32[$377>>2]|0;HEAP32[$377>>2] = (($378+1)|0);
      $379 = HEAP32[$0>>2]|0;
      $380 = ((($379)) + 212|0);
      $381 = HEAP32[$380>>2]|0;
      __THREW__ = 0;
      invoke_vi($381|0,($0|0));
      $382 = __THREW__; __THREW__ = 0;
      $383 = $382&1;
      L109: do {
       if (!($383)) {
        $384 = ((($0)) + 244|0);
        $385 = ((($0)) + 248|0);
        $386 = ((($0)) + 252|0);
        __THREW__ = 0;
        invoke_viiiiii(3968,($0|0),($1|0),($372|0),($384|0),($385|0),($386|0));
        $387 = __THREW__; __THREW__ = 0;
        $388 = $387&1;
        if (!($388)) {
         $389 = HEAP32[$386>>2]|0;
         $390 = ((($0)) + 172|0);
         $391 = HEAP32[$390>>2]|0;
         $392 = HEAP32[$384>>2]|0;
         $393 = HEAP32[$385>>2]|0;
         $394 = ((($0)) + 160|0);
         $395 = HEAP32[$394>>2]|0;
         __THREW__ = 0;
         $396 = (invoke_iiiiiiiiii(3969,($0|0),($11|0),3553,($389|0),($391|0),($392|0),($393|0),1,($395|0))|0);
         $397 = __THREW__; __THREW__ = 0;
         $398 = $397&1;
         if (!($398)) {
          __THREW__ = 0;
          invoke_vi(3970,($396|0));
          $399 = __THREW__; __THREW__ = 0;
          $400 = $399&1;
          if (!($400)) {
           __THREW__ = 0;
           invoke_viii(3971,($0|0),3553,($1|0));
           $401 = __THREW__; __THREW__ = 0;
           $402 = $401&1;
           if (!($402)) {
            $403 = ((($396)) + 64|0);
            $404 = HEAP8[$403>>0]|0;
            $405 = ($404<<24>>24)==(0);
            if ($405) {
             label = 132;
            } else {
             __THREW__ = 0;
             $406 = (invoke_ii(3972,($372|0))|0);
             $407 = __THREW__; __THREW__ = 0;
             $408 = $407&1;
             if ($408) {
              break;
             }
             if ($406) {
              $409 = HEAP32[$384>>2]|0;
              $410 = HEAP32[$385>>2]|0;
              $411 = HEAP32[$390>>2]|0;
              $412 = HEAP32[$386>>2]|0;
              __THREW__ = 0;
              invoke_viiiiiiii(3973,($0|0),($1|0),3553,($372|0),($409|0),($410|0),($411|0),($412|0));
              $413 = __THREW__; __THREW__ = 0;
              $414 = $413&1;
              if ($414) {
               break;
              }
             } else {
              label = 132;
             }
            }
            if ((label|0) == 132) {
             $415 = HEAP32[$384>>2]|0;
             $416 = HEAP32[$385>>2]|0;
             $417 = HEAP32[$386>>2]|0;
             __THREW__ = 0;
             invoke_viiiiiii(3974,($0|0),($1|0),3553,($372|0),($415|0),($416|0),($417|0));
             $418 = __THREW__; __THREW__ = 0;
             $419 = $418&1;
             if ($419) {
              break;
             }
             HEAP8[$403>>0] = 1;
            }
            $420 = ((($372)) + 32|0);
            $421 = HEAP32[$420>>2]|0;
            $422 = ((($0)) + 260|0);
            $423 = ((($0)) + 264|0);
            $424 = HEAP32[$423>>2]|0;
            $425 = HEAP32[$422>>2]|0;
            $426 = (($424) - ($425))|0;
            $427 = $426 >> 2;
            $428 = ($427>>>0)>($11>>>0);
            $429 = $425;
            if ($428) {
             $445 = $429;
            } else {
             $430 = (($11) + 1)|0;
             HEAP32[$4>>2] = 0;
             $431 = ($430>>>0)>($427>>>0);
             $432 = $424;
             do {
              if ($431) {
               $433 = (($430) - ($427))|0;
               __THREW__ = 0;
               invoke_viii(3755,($422|0),($433|0),($4|0));
               $434 = __THREW__; __THREW__ = 0;
               $435 = $434&1;
               if ($435) {
                break L109;
               }
               $$pre$pre$i$i81 = HEAP32[$422>>2]|0;
               $$pre$i$i85 = $$pre$pre$i$i81;
              } else {
               $436 = ($430>>>0)<($427>>>0);
               if ($436) {
                $437 = (($429) + ($430<<2)|0);
                $438 = ($432|0)==($437|0);
                if ($438) {
                 $$pre$i$i85 = $429;
                 break;
                }
                $scevgep$i$i$i$i$i82 = ((($432)) + -4|0);
                $439 = $scevgep$i$i$i$i$i82;
                $440 = $437;
                $441 = (($439) - ($440))|0;
                $442 = $441 >>> 2;
                $443 = $442 ^ -1;
                $scevgep5$i$i$i$i$i83 = (($432) + ($443<<2)|0);
                HEAP32[$423>>2] = $scevgep5$i$i$i$i$i83;
                $$pre$i$i85 = $429;
               } else {
                $$pre$i$i85 = $429;
               }
              }
             } while(0);
             $445 = $$pre$i$i85;
            }
            $444 = (($445) + ($11<<2)|0);
            HEAP32[$444>>2] = $421;
            $446 = ((($0)) + 121|0);
            $447 = HEAP8[$446>>0]|0;
            $448 = ($447<<24>>24)==(0);
            do {
             if (!($448)) {
              $449 = ((($1)) + 680|0);
              $450 = HEAP32[$449>>2]|0;
              $451 = ($450|0)==(0);
              if ($451) {
               __THREW__ = 0;
               $452 = (invoke_ii(3975,($0|0))|0);
               $453 = __THREW__; __THREW__ = 0;
               $454 = $453&1;
               if ($454) {
                break L109;
               }
               if (!($452)) {
                break;
               }
               $455 = ((($372)) + 24|0);
               $456 = HEAP32[$455>>2]|0;
               $457 = ($456|0)==(1);
               if (!($457)) {
                break;
               }
               $458 = HEAP32[$371>>2]|0;
               $459 = ($458|0)==(0|0);
               if ($459) {
                break;
               }
               HEAP32[$371>>2] = 0;
               $460 = ((($458)) + 8|0);
               $461 = HEAP32[$460>>2]|0;HEAP32[$460>>2] = (($461-1)|0);
               $462 = ($461|0)==(1);
               if (!($462)) {
                break;
               }
               __THREW__ = 0;
               invoke_viii(3262,($458|0),1,1);
               $463 = __THREW__; __THREW__ = 0;
               $464 = $463&1;
               if ($464) {
                break L109;
               }
              }
             }
            } while(0);
            $465 = HEAP32[$377>>2]|0;HEAP32[$377>>2] = (($465-1)|0);
            $466 = ($465|0)==(1);
            if (!($466)) {
             $$2 = $396;
             break L102;
            }
            __ZNK3osg10Referenced24signalObserversAndDeleteEbb($372,1,1);
            $$2 = $396;
            break L102;
           }
          }
         }
        }
       }
      } while(0);
      $467 = ___cxa_find_matching_catch_2()|0;
      $468 = tempRet0;
      $469 = HEAP32[$377>>2]|0;HEAP32[$377>>2] = (($469-1)|0);
      $470 = ($469|0)==(1);
      if (!($470)) {
       $$153 = $468;$$155 = $467;
       ___resumeException($$155|0);
       // unreachable;
      }
      __THREW__ = 0;
      invoke_viii(3262,($372|0),1,1);
      $471 = __THREW__; __THREW__ = 0;
      $472 = $471&1;
      if ($472) {
       $529 = ___cxa_find_matching_catch_3(0|0)|0;
       $530 = tempRet0;
       ___clang_call_terminate($529);
       // unreachable;
      } else {
       $$153 = $468;$$155 = $467;
       ___resumeException($$155|0);
       // unreachable;
      }
     }
    }
    $473 = ((($0)) + 244|0);
    $474 = HEAP32[$473>>2]|0;
    $475 = ($474|0)==(0);
    if (!($475)) {
     $476 = ((($0)) + 248|0);
     $477 = HEAP32[$476>>2]|0;
     $478 = ($477|0)==(0);
     if (!($478)) {
      $479 = ((($0)) + 172|0);
      $480 = HEAP32[$479>>2]|0;
      $481 = ($480|0)==(0);
      if (!($481)) {
       $482 = ((($0)) + 252|0);
       $483 = HEAP32[$482>>2]|0;
       $484 = ((($0)) + 160|0);
       $485 = HEAP32[$484>>2]|0;
       $486 = (__ZNK3osg7Texture30generateAndAssignTextureObjectEjjijiiii($0,$11,3553,$483,$480,$474,$477,1,$485)|0);
       __ZN3osg7Texture13TextureObject4bindEv($486);
       __ZNK3osg7Texture18applyTexParametersEjRNS_5StateE($0,3553,$1);
       $487 = HEAP32[$479>>2]|0;
       $488 = HEAP32[$473>>2]|0;
       $489 = HEAP32[$476>>2]|0;
       $490 = HEAP32[$484>>2]|0;
       $491 = ((($0)) + 176|0);
       $492 = HEAP32[$491>>2]|0;
       $493 = ($492|0)==(0);
       $$ = $493 ? $487 : $492;
       $494 = ((($0)) + 180|0);
       $495 = HEAP32[$494>>2]|0;
       $496 = ($495|0)==(0);
       $497 = $496 ? 5121 : $495;
       _glTexImage2D(3553,0,($487|0),($488|0),($489|0),($490|0),($$|0),($497|0),(0|0));
       $498 = ((($0)) + 236|0);
       $499 = HEAP32[$498>>2]|0;
       $500 = ($499|0)==(0|0);
       if ($500) {
        $$2 = $486;
        break;
       }
       $501 = HEAP32[$499>>2]|0;
       $502 = ((($501)) + 176|0);
       $503 = HEAP32[$502>>2]|0;
       FUNCTION_TABLE_vii[$503 & 8191]($499,1028);
       $$2 = $486;
       break;
      }
     }
    }
    _glBindTexture(3553,0);
    STACKTOP = sp;return;
   }
   $242 = HEAP32[$240>>2]|0;
   $243 = ((($242)) + 16|0);
   $244 = HEAP32[$243>>2]|0;
   FUNCTION_TABLE_viiii[$244 & 8191]($9,$240,$0,$1);
   $245 = HEAP32[$13>>2]|0;
   $246 = HEAP32[$12>>2]|0;
   $247 = (($245) - ($246))|0;
   $248 = $247 >> 2;
   $249 = ($248>>>0)>($11>>>0);
   L159: do {
    if ($249) {
     label = 88;
    } else {
     $250 = (($11) + 1)|0;
     $251 = ($250>>>0)>($248>>>0);
     $252 = $246;
     $253 = $245;
     if ($251) {
      $254 = (($250) - ($248))|0;
      __THREW__ = 0;
      invoke_vii(3967,($12|0),($254|0));
      $255 = __THREW__; __THREW__ = 0;
      $256 = $255&1;
      if ($256) {
       break;
      } else {
       label = 88;
       break;
      }
     }
     $257 = ($250>>>0)<($248>>>0);
     if ($257) {
      $258 = (($252) + ($250<<2)|0);
      $259 = ($253|0)==($258|0);
      if ($259) {
       label = 88;
      } else {
       $261 = $253;
       while(1) {
        $260 = ((($261)) + -4|0);
        HEAP32[$13>>2] = $260;
        $262 = HEAP32[$260>>2]|0;
        $263 = ($262|0)==(0|0);
        if (!($263)) {
         $264 = ((($262)) + 8|0);
         $265 = HEAP32[$264>>2]|0;HEAP32[$264>>2] = (($265-1)|0);
         $266 = ($265|0)==(1);
         if ($266) {
          __THREW__ = 0;
          invoke_viii(3262,($262|0),1,1);
          $267 = __THREW__; __THREW__ = 0;
          $268 = $267&1;
          if ($268) {
           break;
          }
         }
        }
        HEAP32[$260>>2] = 0;
        $269 = HEAP32[$13>>2]|0;
        $270 = ($269|0)==($258|0);
        if ($270) {
         label = 88;
         break L159;
        } else {
         $261 = $269;
        }
       }
       $271 = ___cxa_find_matching_catch_2()|0;
       $272 = tempRet0;
       ___cxa_call_unexpected(($271|0));
       // unreachable;
      }
     } else {
      label = 88;
     }
    }
   } while(0);
   do {
    if ((label|0) == 88) {
     $273 = HEAP32[$12>>2]|0;
     $274 = (($273) + ($11<<2)|0);
     $275 = HEAP32[$274>>2]|0;
     $276 = HEAP32[$9>>2]|0;
     $277 = ($275|0)==($276|0);
     if ($277) {
      $287 = $275;
     } else {
      HEAP32[$274>>2] = $276;
      $278 = ($276|0)==(0|0);
      if (!($278)) {
       $279 = ((($276)) + 8|0);
       $280 = HEAP32[$279>>2]|0;HEAP32[$279>>2] = (($280+1)|0);
      }
      $281 = ($275|0)==(0|0);
      if (!($281)) {
       $282 = ((($275)) + 8|0);
       $283 = HEAP32[$282>>2]|0;HEAP32[$282>>2] = (($283-1)|0);
       $284 = ($283|0)==(1);
       if ($284) {
        __THREW__ = 0;
        invoke_viii(3262,($275|0),1,1);
        $285 = __THREW__; __THREW__ = 0;
        $286 = $285&1;
        if ($286) {
         break;
        }
       }
      }
      $$pr = HEAP32[$9>>2]|0;
      $287 = $$pr;
     }
     $288 = ($287|0)==(0|0);
     if (!($288)) {
      $289 = ((($287)) + 8|0);
      $290 = HEAP32[$289>>2]|0;HEAP32[$289>>2] = (($290-1)|0);
      $291 = ($290|0)==(1);
      if ($291) {
       __ZNK3osg10Referenced24signalObserversAndDeleteEbb($287,1,1);
      }
     }
     $292 = HEAP32[$13>>2]|0;
     $293 = HEAP32[$12>>2]|0;
     $294 = (($292) - ($293))|0;
     $295 = $294 >> 2;
     $296 = ($295>>>0)>($11>>>0);
     L188: do {
      if (!($296)) {
       $297 = (($11) + 1)|0;
       $298 = ($297>>>0)>($295>>>0);
       $299 = $293;
       $300 = $292;
       if ($298) {
        $301 = (($297) - ($295))|0;
        __ZNSt3__26vectorIN3osg7ref_ptrINS1_7Texture13TextureObjectEEENS_9allocatorIS5_EEE8__appendEj($12,$301);
        break;
       }
       $302 = ($297>>>0)<($295>>>0);
       if ($302) {
        $303 = (($299) + ($297<<2)|0);
        $304 = ($300|0)==($303|0);
        if (!($304)) {
         $306 = $300;
         while(1) {
          $305 = ((($306)) + -4|0);
          HEAP32[$13>>2] = $305;
          $307 = HEAP32[$305>>2]|0;
          $308 = ($307|0)==(0|0);
          if (!($308)) {
           $309 = ((($307)) + 8|0);
           $310 = HEAP32[$309>>2]|0;HEAP32[$309>>2] = (($310-1)|0);
           $311 = ($310|0)==(1);
           if ($311) {
            __THREW__ = 0;
            invoke_viii(3262,($307|0),1,1);
            $312 = __THREW__; __THREW__ = 0;
            $313 = $312&1;
            if ($313) {
             break;
            }
           }
          }
          HEAP32[$305>>2] = 0;
          $314 = HEAP32[$13>>2]|0;
          $315 = ($314|0)==($303|0);
          if ($315) {
           break L188;
          } else {
           $306 = $314;
          }
         }
         $316 = ___cxa_find_matching_catch_2()|0;
         $317 = tempRet0;
         ___cxa_call_unexpected(($316|0));
         // unreachable;
        }
       }
      }
     } while(0);
     $318 = HEAP32[$12>>2]|0;
     $319 = (($318) + ($11<<2)|0);
     $320 = HEAP32[$319>>2]|0;
     __ZN3osg7Texture13TextureObject4bindEv($320);
     __ZNK3osg7Texture18applyTexParametersEjRNS_5StateE($0,3553,$1);
     $321 = HEAP32[$$pre131>>2]|0;
     $322 = HEAP32[$321>>2]|0;
     $323 = ((($322)) + 20|0);
     $324 = HEAP32[$323>>2]|0;
     FUNCTION_TABLE_viii[$324 & 8191]($321,$0,$1);
     $325 = ((($0)) + 252|0);
     $326 = HEAP32[$325>>2]|0;
     $327 = ((($0)) + 172|0);
     $328 = HEAP32[$327>>2]|0;
     $329 = ((($0)) + 244|0);
     $330 = HEAP32[$329>>2]|0;
     $331 = ((($0)) + 248|0);
     $332 = HEAP32[$331>>2]|0;
     $333 = ((($0)) + 160|0);
     $334 = HEAP32[$333>>2]|0;
     __ZN3osg7Texture13TextureObject12setAllocatedEijiiii($320,$326,$328,$330,$332,1,$334);
     $335 = ((($0)) + 240|0);
     $336 = HEAP32[$335>>2]|0;
     $337 = ($336|0)==(0|0);
     if ($337) {
      $$2 = $320;
      break L102;
     }
     $338 = ((($336)) + 32|0);
     $339 = HEAP32[$338>>2]|0;
     $340 = ((($0)) + 260|0);
     $341 = ((($0)) + 264|0);
     $342 = HEAP32[$341>>2]|0;
     $343 = HEAP32[$340>>2]|0;
     $344 = (($342) - ($343))|0;
     $345 = $344 >> 2;
     $346 = ($345>>>0)>($11>>>0);
     $347 = $343;
     if ($346) {
      $361 = $347;
     } else {
      $348 = (($11) + 1)|0;
      HEAP32[$2>>2] = 0;
      $349 = ($348>>>0)>($345>>>0);
      $350 = $342;
      if ($349) {
       $351 = (($348) - ($345))|0;
       __ZNSt3__26vectorIjNS_9allocatorIjEEE8__appendEjRKj($340,$351,$2);
       $$pre$pre$i$i99 = HEAP32[$340>>2]|0;
       $$pre$i$i103 = $$pre$pre$i$i99;
      } else {
       $352 = ($348>>>0)<($345>>>0);
       if ($352) {
        $353 = (($347) + ($348<<2)|0);
        $354 = ($350|0)==($353|0);
        if ($354) {
         $$pre$i$i103 = $347;
        } else {
         $scevgep$i$i$i$i$i100 = ((($350)) + -4|0);
         $355 = $scevgep$i$i$i$i$i100;
         $356 = $353;
         $357 = (($355) - ($356))|0;
         $358 = $357 >>> 2;
         $359 = $358 ^ -1;
         $scevgep5$i$i$i$i$i101 = (($350) + ($359<<2)|0);
         HEAP32[$341>>2] = $scevgep5$i$i$i$i$i101;
         $$pre$i$i103 = $347;
        }
       } else {
        $$pre$i$i103 = $347;
       }
      }
      $361 = $$pre$i$i103;
     }
     $360 = (($361) + ($11<<2)|0);
     HEAP32[$360>>2] = $339;
     $$2 = $320;
     break L102;
    }
   } while(0);
   $362 = ___cxa_find_matching_catch_2()|0;
   $363 = tempRet0;
   $364 = HEAP32[$9>>2]|0;
   $365 = ($364|0)==(0|0);
   if (!($365)) {
    $366 = ((($364)) + 8|0);
    $367 = HEAP32[$366>>2]|0;HEAP32[$366>>2] = (($367-1)|0);
    $368 = ($367|0)==(1);
    if ($368) {
     __THREW__ = 0;
     invoke_viii(3262,($364|0),1,1);
     $369 = __THREW__; __THREW__ = 0;
     $370 = $369&1;
     if ($370) {
      $529 = ___cxa_find_matching_catch_3(0|0)|0;
      $530 = tempRet0;
      ___clang_call_terminate($529);
      // unreachable;
     }
    }
   }
   $$153 = $363;$$155 = $362;
   ___resumeException($$155|0);
   // unreachable;
  }
 } while(0);
 $504 = ($$2|0)==(0|0);
 if ($504) {
  STACKTOP = sp;return;
 }
 $505 = ((($0)) + 68|0);
 $506 = ((($0)) + 72|0);
 $507 = HEAP32[$506>>2]|0;
 $508 = HEAP32[$505>>2]|0;
 $509 = (($507) - ($508))|0;
 $510 = $509 >> 2;
 $511 = ($510>>>0)>($11>>>0);
 $512 = $508;
 if ($511) {
  $526 = $512;
 } else {
  $513 = (($11) + 1)|0;
  HEAP32[$8>>2] = 0;
  $514 = ($513>>>0)>($510>>>0);
  $515 = $507;
  if ($514) {
   $516 = (($513) - ($510))|0;
   __ZNSt3__26vectorIjNS_9allocatorIjEEE8__appendEjRKj($505,$516,$8);
   $$pre$pre$i = HEAP32[$505>>2]|0;
   $$pre$i = $$pre$pre$i;
  } else {
   $517 = ($513>>>0)<($510>>>0);
   if ($517) {
    $518 = (($512) + ($513<<2)|0);
    $519 = ($515|0)==($518|0);
    if ($519) {
     $$pre$i = $512;
    } else {
     $scevgep$i$i$i$i = ((($515)) + -4|0);
     $520 = $scevgep$i$i$i$i;
     $521 = $518;
     $522 = (($520) - ($521))|0;
     $523 = $522 >>> 2;
     $524 = $523 ^ -1;
     $scevgep5$i$i$i$i = (($515) + ($524<<2)|0);
     HEAP32[$506>>2] = $scevgep5$i$i$i$i;
     $$pre$i = $512;
    }
   } else {
    $$pre$i = $512;
   }
  }
  $526 = $$pre$i;
 }
 $525 = (($526) + ($11<<2)|0);
 $527 = HEAP32[$525>>2]|0;
 $528 = ($527|0)==(0);
 if ($528) {
  STACKTOP = sp;return;
 }
 __ZNK3osg7Texture14generateMipmapERNS_5StateE($0,$1);
 STACKTOP = sp;return;
}
function __ZNK3osg9Texture2D16getTextureTargetEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 3553;
}
function __ZNK3osg9Texture2D15getTextureWidthEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 244|0);
 $2 = HEAP32[$1>>2]|0;
 return ($2|0);
}
function __ZNK3osg9Texture2D16getTextureHeightEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 248|0);
 $2 = HEAP32[$1>>2]|0;
 return ($2|0);
}
function __ZNK3osg9Texture2D15getTextureDepthEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 1;
}
function __ZN3osg9Texture2D8setImageEjPNS_5ImageE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg9Texture2D8setImageEPNS_5ImageE($0,$2);
 return;
}
function __ZN3osg9Texture2D8getImageEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 240|0);
 $3 = HEAP32[$2>>2]|0;
 return ($3|0);
}
function __ZNK3osg9Texture2D8getImageEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 240|0);
 $3 = HEAP32[$2>>2]|0;
 return ($3|0);
}
function __ZNK3osg9Texture2D12getNumImagesEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 1;
}
function __ZNK3osg9Texture2D21computeInternalFormatEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 240|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  __ZNK3osg7Texture25computeInternalFormatTypeEv($0);
  return;
 } else {
  __ZNK3osg7Texture30computeInternalFormatWithImageERKNS_5ImageE($0,$2);
  return;
 }
}
function __ZNK3osg9Texture2D14allocateMipmapERNS_5StateE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$ = 0, $$$033 = 0, $$033 = 0, $$03337 = 0, $$03341 = 0, $$034 = 0, $$03438 = 0, $$03442 = 0, $$040 = 0, $$135 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond39 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 124|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 224|0);
 $5 = ((($0)) + 228|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$4>>2]|0;
 $8 = (($6) - ($7))|0;
 $9 = $8 >> 2;
 $10 = ($9>>>0)>($3>>>0);
 L1: do {
  if (!($10)) {
   $11 = (($3) + 1)|0;
   $12 = ($11>>>0)>($9>>>0);
   $13 = $7;
   $14 = $6;
   if ($12) {
    $15 = (($11) - ($9))|0;
    __ZNSt3__26vectorIN3osg7ref_ptrINS1_7Texture13TextureObjectEEENS_9allocatorIS5_EEE8__appendEj($4,$15);
    break;
   }
   $16 = ($11>>>0)<($9>>>0);
   if ($16) {
    $17 = (($13) + ($11<<2)|0);
    $18 = ($14|0)==($17|0);
    if (!($18)) {
     $20 = $14;
     while(1) {
      $19 = ((($20)) + -4|0);
      HEAP32[$5>>2] = $19;
      $21 = HEAP32[$19>>2]|0;
      $22 = ($21|0)==(0|0);
      if (!($22)) {
       $23 = ((($21)) + 8|0);
       $24 = HEAP32[$23>>2]|0;HEAP32[$23>>2] = (($24-1)|0);
       $25 = ($24|0)==(1);
       if ($25) {
        __THREW__ = 0;
        invoke_viii(3262,($21|0),1,1);
        $26 = __THREW__; __THREW__ = 0;
        $27 = $26&1;
        if ($27) {
         break;
        }
       }
      }
      HEAP32[$19>>2] = 0;
      $28 = HEAP32[$5>>2]|0;
      $29 = ($28|0)==($17|0);
      if ($29) {
       break L1;
      } else {
       $20 = $28;
      }
     }
     $30 = ___cxa_find_matching_catch_2()|0;
     $31 = tempRet0;
     ___cxa_call_unexpected(($30|0));
     // unreachable;
    }
   }
  }
 } while(0);
 $32 = HEAP32[$4>>2]|0;
 $33 = (($32) + ($3<<2)|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)==(0|0);
 if ($35) {
  return;
 }
 $36 = ((($0)) + 244|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = ($37|0)==(0);
 if ($38) {
  return;
 }
 $39 = ((($0)) + 248|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ($40|0)==(0);
 if ($41) {
  return;
 }
 __ZN3osg7Texture13TextureObject4bindEv($34);
 $42 = HEAP32[$36>>2]|0;
 $43 = HEAP32[$39>>2]|0;
 $44 = (__ZN3osg5Image27computeNumberOfMipmapLevelsEiii($42,$43,1)|0);
 $$03337 = $42 >> 1;
 $$03438 = $43 >> 1;
 $45 = ($44|0)<(2);
 $46 = $$03337 | $$03438;
 $47 = ($46|0)==(0);
 $or$cond39 = $45 | $47;
 if (!($or$cond39)) {
  $48 = ((($0)) + 172|0);
  $49 = ((($0)) + 160|0);
  $50 = ((($0)) + 176|0);
  $51 = ((($0)) + 180|0);
  $$03341 = $$03337;$$03442 = $$03438;$$040 = 1;
  while(1) {
   $54 = ($$03341|0)==(0);
   $$$033 = $54 ? 1 : $$03341;
   $55 = ($$03442|0)==(0);
   $$135 = $55 ? 1 : $$03442;
   $56 = HEAP32[$48>>2]|0;
   $57 = HEAP32[$49>>2]|0;
   $58 = HEAP32[$50>>2]|0;
   $59 = ($58|0)==(0);
   $$ = $59 ? $56 : $58;
   $60 = HEAP32[$51>>2]|0;
   $61 = ($60|0)==(0);
   $62 = $61 ? 5121 : $60;
   _glTexImage2D(3553,($$040|0),($56|0),($$$033|0),($$135|0),($57|0),($$|0),($62|0),(0|0));
   $63 = (($$040) + 1)|0;
   $$033 = $$$033 >> 1;
   $$034 = $$135 >> 1;
   $64 = ($63|0)>=($44|0);
   $65 = $$033 | $$034;
   $66 = ($65|0)==(0);
   $or$cond = $64 | $66;
   if ($or$cond) {
    break;
   } else {
    $$03341 = $$033;$$03442 = $$034;$$040 = $63;
   }
  }
 }
 $52 = ((($1)) + 688|0);
 $53 = HEAP32[$52>>2]|0;
 __ZN3osg5State27haveAppliedTextureAttributeEjPKNS_14StateAttributeE($1,$53,$0);
 return;
}
function __ZN3osg9Texture2D8setImageEPNS_5ImageE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$cast$i$i = 0, $$cast$i2$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $smax = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 240|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==($1|0);
 if ($4) {
  return;
 }
 $5 = ($3|0)==(0|0);
 if (!($5)) {
  $6 = ((($3)) + 48|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($7) + -1)|0;
  HEAP32[$6>>2] = $8;
  $9 = HEAP32[$3>>2]|0;
  $10 = ((($9)) + 204|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (FUNCTION_TABLE_ii[$11 & 8191]($3)|0);
  if ($12) {
   __ZN3osg14StateAttribute17setUpdateCallbackEPNS_22StateAttributeCallbackE($0,0);
   $13 = ((($0)) + 24|0);
   HEAP32[$13>>2] = 1;
  }
 }
 $14 = HEAP32[$2>>2]|0;
 $15 = ($14|0)==($1|0);
 if (!($15)) {
  HEAP32[$2>>2] = $1;
  $16 = ($1|0)==(0|0);
  if (!($16)) {
   $17 = ((($1)) + 8|0);
   $18 = HEAP32[$17>>2]|0;HEAP32[$17>>2] = (($18+1)|0);
  }
  $19 = ($14|0)==(0|0);
  if (!($19)) {
   $20 = ((($14)) + 8|0);
   $21 = HEAP32[$20>>2]|0;HEAP32[$20>>2] = (($21-1)|0);
   $22 = ($21|0)==(1);
   if ($22) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($14,1,1);
   }
  }
 }
 $23 = ((($0)) + 260|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ((($0)) + 264|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = $24;
 $28 = (($26) - ($27))|0;
 $29 = ($28|0)>(0);
 if ($29) {
  $30 = $28 >>> 2;
  $31 = $30 ^ 1073741823;
  $32 = ($30|0)==(0);
  $smax = $32 ? $31 : 1073741822;
  $33 = (($smax) + ($30))|0;
  $34 = $33 << 2;
  $35 = (($34) + 8)|0;
  _memset(($24|0),0,($35|0))|0;
 }
 $36 = HEAP32[$2>>2]|0;
 $37 = ($36|0)==(0|0);
 if ($37) {
  return;
 }
 $38 = ((($36)) + 48|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($39) + 1)|0;
 HEAP32[$38>>2] = $40;
 $41 = HEAP32[$36>>2]|0;
 $42 = ((($41)) + 204|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = (FUNCTION_TABLE_ii[$43 & 8191]($36)|0);
 if (!($44)) {
  return;
 }
 $45 = (__Znwj(44)|0);
 dest=$45; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $46 = ((($45)) + 12|0);
 __THREW__ = 0;
 invoke_vi(3282,($46|0));
 $47 = __THREW__; __THREW__ = 0;
 $48 = $47&1;
 if ($48) {
  $70 = ___cxa_find_matching_catch_2()|0;
  $71 = tempRet0;
  __ZdlPv($45);
  ___resumeException($70|0);
  // unreachable;
 }
 HEAP32[$46>>2] = (63412);
 $49 = ((($45)) + 24|0);
 ;HEAP32[$49>>2]=0|0;HEAP32[$49+4>>2]=0|0;HEAP32[$49+8>>2]=0|0;
 $50 = ((($45)) + 36|0);
 HEAP32[$50>>2] = 2;
 $51 = ((($45)) + 40|0);
 HEAP32[$51>>2] = 0;
 $52 = ((($45)) + 4|0);
 $53 = HEAP32[(62180)>>2]|0;
 HEAP32[$52>>2] = $53;
 $54 = HEAP32[(62184)>>2]|0;
 $$cast$i$i = $53;
 $55 = ((($$cast$i$i)) + -12|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = (($52) + ($56)|0);
 HEAP32[$57>>2] = $54;
 $58 = ((($45)) + 8|0);
 HEAP32[$58>>2] = 0;
 $59 = HEAP32[(62160)>>2]|0;
 HEAP32[$45>>2] = $59;
 $60 = HEAP32[(62164)>>2]|0;
 $$cast$i2$i = $59;
 $61 = ((($$cast$i2$i)) + -12|0);
 $62 = HEAP32[$61>>2]|0;
 $63 = (($45) + ($62)|0);
 HEAP32[$63>>2] = $60;
 $64 = HEAP32[(62168)>>2]|0;
 $65 = HEAP32[$45>>2]|0;
 $66 = ((($65)) + -16|0);
 $67 = HEAP32[$66>>2]|0;
 $68 = (($45) + ($67)|0);
 HEAP32[$68>>2] = $64;
 HEAP32[$45>>2] = (61612);
 HEAP32[$52>>2] = (61768);
 HEAP32[$46>>2] = (62016);
 __ZN3osg14StateAttribute17setUpdateCallbackEPNS_22StateAttributeCallbackE($0,$45);
 $69 = ((($0)) + 24|0);
 HEAP32[$69>>2] = 0;
 return;
}
function __ZNK3osg9Texture2D18textureObjectValidERNS_5StateE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $8 = 0, $9 = 0, $or$cond$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp + 8|0;
 $3 = sp + 4|0;
 $4 = sp;
 $5 = ((($1)) + 124|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($0)) + 224|0);
 $8 = ((($0)) + 228|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$7>>2]|0;
 $11 = (($9) - ($10))|0;
 $12 = $11 >> 2;
 $13 = ($12>>>0)>($6>>>0);
 L1: do {
  if (!($13)) {
   $14 = (($6) + 1)|0;
   $15 = ($14>>>0)>($12>>>0);
   $16 = $10;
   $17 = $9;
   if ($15) {
    $18 = (($14) - ($12))|0;
    __ZNSt3__26vectorIN3osg7ref_ptrINS1_7Texture13TextureObjectEEENS_9allocatorIS5_EEE8__appendEj($7,$18);
    break;
   }
   $19 = ($14>>>0)<($12>>>0);
   if ($19) {
    $20 = (($16) + ($14<<2)|0);
    $21 = ($17|0)==($20|0);
    if (!($21)) {
     $23 = $17;
     while(1) {
      $22 = ((($23)) + -4|0);
      HEAP32[$8>>2] = $22;
      $24 = HEAP32[$22>>2]|0;
      $25 = ($24|0)==(0|0);
      if (!($25)) {
       $26 = ((($24)) + 8|0);
       $27 = HEAP32[$26>>2]|0;HEAP32[$26>>2] = (($27-1)|0);
       $28 = ($27|0)==(1);
       if ($28) {
        __THREW__ = 0;
        invoke_viii(3262,($24|0),1,1);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         break;
        }
       }
      }
      HEAP32[$22>>2] = 0;
      $31 = HEAP32[$8>>2]|0;
      $32 = ($31|0)==($20|0);
      if ($32) {
       break L1;
      } else {
       $23 = $31;
      }
     }
     $33 = ___cxa_find_matching_catch_2()|0;
     $34 = tempRet0;
     ___cxa_call_unexpected(($33|0));
     // unreachable;
    }
   }
  }
 } while(0);
 $35 = HEAP32[$7>>2]|0;
 $36 = (($35) + ($6<<2)|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = ($37|0)==(0|0);
 if ($38) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $39 = ((($0)) + 240|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ($40|0)==(0|0);
 if ($41) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $42 = HEAP32[$0>>2]|0;
 $43 = ((($42)) + 212|0);
 $44 = HEAP32[$43>>2]|0;
 FUNCTION_TABLE_vi[$44 & 8191]($0);
 $45 = HEAP32[$39>>2]|0;
 __ZNK3osg7Texture32computeRequiredTextureDimensionsERNS_5StateERKNS_5ImageERiS6_S6_($0,$1,$45,$2,$3,$4);
 $46 = HEAP32[$4>>2]|0;
 $47 = ((($0)) + 172|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = HEAP32[$2>>2]|0;
 $50 = HEAP32[$3>>2]|0;
 $51 = ((($0)) + 160|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = ((($37)) + 64|0);
 $54 = HEAP8[$53>>0]|0;
 $55 = ($54<<24>>24)==(0);
 if ($55) {
  $78 = 0;
 } else {
  $56 = ((($37)) + 28|0);
  $57 = HEAP32[$56>>2]|0;
  $58 = ($57|0)==(0);
  if ($58) {
   $78 = 0;
  } else {
   $59 = ((($37)) + 16|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = ($60|0)==(3553);
   if ($61) {
    $62 = ((($37)) + 20|0);
    $63 = HEAP32[$62>>2]|0;
    $64 = ($63|0)==($46|0);
    if ($64) {
     $65 = ((($37)) + 24|0);
     $66 = HEAP32[$65>>2]|0;
     $67 = ($66|0)==($48|0);
     $68 = ($57|0)==($49|0);
     $or$cond$i = $68 & $67;
     if ($or$cond$i) {
      $69 = ((($37)) + 32|0);
      $70 = HEAP32[$69>>2]|0;
      $71 = ($70|0)==($50|0);
      if ($71) {
       $72 = ((($37)) + 36|0);
       $73 = HEAP32[$72>>2]|0;
       $74 = ($73|0)==(1);
       if ($74) {
        $75 = ((($37)) + 40|0);
        $76 = HEAP32[$75>>2]|0;
        $77 = ($76|0)==($52|0);
        $78 = $77;
       } else {
        $78 = 0;
       }
      } else {
       $78 = 0;
      }
     } else {
      $78 = 0;
     }
    } else {
     $78 = 0;
    }
   } else {
    $78 = 0;
   }
  }
 }
 $$0 = $78;
 STACKTOP = sp;return ($$0|0);
}
function __ZN3osg9Texture2DC2ERKS0_RKNS_6CopyOpE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$010 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $eh$lpad$body$index3Z2D = 0, $eh$lpad$body$indexZ2D = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i$i$i$i = 0, $scevgep5$i$i$i$i = 0, $scevgep5$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg7TextureC2ERKS0_RKNS_6CopyOpE($0,$1,$2);
 HEAP32[$0>>2] = (66788);
 $3 = ((($0)) + 240|0);
 HEAP32[$3>>2] = 0;
 $4 = ((($0)) + 244|0);
 $5 = ((($1)) + 244|0);
 $6 = HEAP32[$5>>2]|0;
 HEAP32[$4>>2] = $6;
 $7 = ((($0)) + 248|0);
 $8 = ((($1)) + 248|0);
 $9 = HEAP32[$8>>2]|0;
 HEAP32[$7>>2] = $9;
 $10 = ((($0)) + 252|0);
 $11 = ((($1)) + 252|0);
 $12 = HEAP32[$11>>2]|0;
 HEAP32[$10>>2] = $12;
 $13 = ((($0)) + 256|0);
 $14 = ((($1)) + 256|0);
 $15 = HEAP32[$14>>2]|0;
 HEAP32[$13>>2] = $15;
 $16 = ($15|0)==(0|0);
 if (!($16)) {
  $17 = ((($15)) + 8|0);
  $18 = HEAP32[$17>>2]|0;HEAP32[$17>>2] = (($18+1)|0);
 }
 $19 = ((($0)) + 260|0);
 __THREW__ = 0;
 $20 = (invoke_i(3285)|0);
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 L4: do {
  if ($22) {
   label = 17;
  } else {
   $23 = HEAP32[$20>>2]|0;
   __THREW__ = 0;
   $24 = (invoke_ii(3286,($23|0))|0);
   $25 = __THREW__; __THREW__ = 0;
   $26 = $25&1;
   if ($26) {
    label = 17;
   } else {
    HEAP32[$19>>2] = 0;
    $27 = ((($0)) + 264|0);
    HEAP32[$27>>2] = 0;
    $28 = ((($0)) + 268|0);
    HEAP32[$28>>2] = 0;
    $29 = ($24|0)==(0);
    do {
     if (!($29)) {
      $30 = ($24>>>0)>(1073741823);
      if ($30) {
       __THREW__ = 0;
       invoke_vi(3307,($19|0));
       $31 = __THREW__; __THREW__ = 0;
      } else {
       $32 = $24 << 2;
       __THREW__ = 0;
       $33 = (invoke_ii(3276,($32|0))|0);
       $34 = __THREW__; __THREW__ = 0;
       $35 = $34&1;
       if (!($35)) {
        HEAP32[$19>>2] = $33;
        $36 = (($33) + ($24<<2)|0);
        $37 = ((($0)) + 268|0);
        HEAP32[$37>>2] = $36;
        _memset(($33|0),0,($32|0))|0;
        HEAP32[$27>>2] = $36;
        break;
       }
      }
      $38 = ___cxa_find_matching_catch_2()|0;
      $39 = tempRet0;
      $40 = HEAP32[$19>>2]|0;
      $41 = ($40|0)==(0|0);
      if ($41) {
       $eh$lpad$body$index3Z2D = $39;$eh$lpad$body$indexZ2D = $38;
       label = 18;
       break L4;
      }
      $42 = HEAP32[$27>>2]|0;
      $43 = ($42|0)==($40|0);
      if (!($43)) {
       $scevgep$i$i$i$i$i = ((($42)) + -4|0);
       $44 = $scevgep$i$i$i$i$i;
       $45 = $40;
       $46 = (($44) - ($45))|0;
       $47 = $46 >>> 2;
       $48 = $47 ^ -1;
       $scevgep5$i$i$i$i$i = (($42) + ($48<<2)|0);
       HEAP32[$27>>2] = $scevgep5$i$i$i$i$i;
      }
      __ZdlPv($40);
      $eh$lpad$body$index3Z2D = $39;$eh$lpad$body$indexZ2D = $38;
      label = 18;
      break L4;
     }
    } while(0);
    $49 = HEAP32[$2>>2]|0;
    $50 = ((($49)) + 36|0);
    $51 = HEAP32[$50>>2]|0;
    $52 = ((($1)) + 240|0);
    $53 = HEAP32[$52>>2]|0;
    __THREW__ = 0;
    $54 = (invoke_iii($51|0,($2|0),($53|0))|0);
    $55 = __THREW__; __THREW__ = 0;
    $56 = $55&1;
    if (!($56)) {
     __THREW__ = 0;
     invoke_vii(3964,($0|0),($54|0));
     $57 = __THREW__; __THREW__ = 0;
     $58 = $57&1;
     if (!($58)) {
      return;
     }
    }
    $61 = ___cxa_find_matching_catch_2()|0;
    $62 = tempRet0;
    $63 = HEAP32[$19>>2]|0;
    $64 = ($63|0)==(0|0);
    if ($64) {
     $$0 = $62;$$010 = $61;
    } else {
     $65 = HEAP32[$27>>2]|0;
     $66 = ($65|0)==($63|0);
     if (!($66)) {
      $scevgep$i$i$i$i = ((($65)) + -4|0);
      $67 = $scevgep$i$i$i$i;
      $68 = $63;
      $69 = (($67) - ($68))|0;
      $70 = $69 >>> 2;
      $71 = $70 ^ -1;
      $scevgep5$i$i$i$i = (($65) + ($71<<2)|0);
      HEAP32[$27>>2] = $scevgep5$i$i$i$i;
     }
     __ZdlPv($63);
     $$0 = $62;$$010 = $61;
    }
   }
  }
 } while(0);
 if ((label|0) == 17) {
  $59 = ___cxa_find_matching_catch_2()|0;
  $60 = tempRet0;
  $eh$lpad$body$index3Z2D = $60;$eh$lpad$body$indexZ2D = $59;
  label = 18;
 }
 if ((label|0) == 18) {
  $$0 = $eh$lpad$body$index3Z2D;$$010 = $eh$lpad$body$indexZ2D;
 }
 $72 = HEAP32[$13>>2]|0;
 $73 = ($72|0)==(0|0);
 if (!($73)) {
  $74 = ((($72)) + 8|0);
  $75 = HEAP32[$74>>2]|0;HEAP32[$74>>2] = (($75-1)|0);
  $76 = ($75|0)==(1);
  if ($76) {
   __THREW__ = 0;
   invoke_viii(3262,($72|0),1,1);
   $77 = __THREW__; __THREW__ = 0;
   $78 = $77&1;
   if ($78) {
    $88 = ___cxa_find_matching_catch_3(0|0)|0;
    $89 = tempRet0;
    ___clang_call_terminate($88);
    // unreachable;
   }
  }
 }
 HEAP32[$13>>2] = 0;
 $79 = HEAP32[$3>>2]|0;
 $80 = ($79|0)==(0|0);
 if (!($80)) {
  $81 = ((($79)) + 8|0);
  $82 = HEAP32[$81>>2]|0;HEAP32[$81>>2] = (($82-1)|0);
  $83 = ($82|0)==(1);
  if ($83) {
   __THREW__ = 0;
   invoke_viii(3262,($79|0),1,1);
   $84 = __THREW__; __THREW__ = 0;
   $85 = $84&1;
   if ($85) {
    $88 = ___cxa_find_matching_catch_3(0|0)|0;
    $89 = tempRet0;
    ___clang_call_terminate($88);
    // unreachable;
   }
  }
 }
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vi(2335,($0|0));
 $86 = __THREW__; __THREW__ = 0;
 $87 = $86&1;
 if ($87) {
  $88 = ___cxa_find_matching_catch_3(0|0)|0;
  $89 = tempRet0;
  ___clang_call_terminate($88);
  // unreachable;
 } else {
  ___resumeException($$010|0);
  // unreachable;
 }
}
function __ZN3osg9Texture2DC2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index3Z2D = 0, $eh$lpad$body$indexZ2D = 0, $scevgep$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg7TextureC2Ev($0);
 HEAP32[$0>>2] = (66788);
 $1 = ((($0)) + 240|0);
 $2 = ((($0)) + 256|0);
 $3 = ((($0)) + 260|0);
 ;HEAP32[$1>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;HEAP32[$1+12>>2]=0|0;HEAP32[$1+16>>2]=0|0;
 __THREW__ = 0;
 $4 = (invoke_i(3285)|0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  label = 13;
 } else {
  $7 = HEAP32[$4>>2]|0;
  __THREW__ = 0;
  $8 = (invoke_ii(3286,($7|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if ($10) {
   label = 13;
  } else {
   HEAP32[$3>>2] = 0;
   $11 = ((($0)) + 264|0);
   HEAP32[$11>>2] = 0;
   $12 = ((($0)) + 268|0);
   HEAP32[$12>>2] = 0;
   $13 = ($8|0)==(0);
   if ($13) {
    $33 = ((($0)) + 120|0);
    HEAP8[$33>>0] = 1;
    return;
   }
   $14 = ($8>>>0)>(1073741823);
   if ($14) {
    __THREW__ = 0;
    invoke_vi(3307,($3|0));
    $15 = __THREW__; __THREW__ = 0;
   } else {
    $16 = $8 << 2;
    __THREW__ = 0;
    $17 = (invoke_ii(3276,($16|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     HEAP32[$3>>2] = $17;
     $20 = (($17) + ($8<<2)|0);
     $21 = ((($0)) + 268|0);
     HEAP32[$21>>2] = $20;
     _memset(($17|0),0,($16|0))|0;
     HEAP32[$11>>2] = $20;
     $33 = ((($0)) + 120|0);
     HEAP8[$33>>0] = 1;
     return;
    }
   }
   $22 = ___cxa_find_matching_catch_2()|0;
   $23 = tempRet0;
   $24 = HEAP32[$3>>2]|0;
   $25 = ($24|0)==(0|0);
   if ($25) {
    $eh$lpad$body$index3Z2D = $23;$eh$lpad$body$indexZ2D = $22;
   } else {
    $26 = HEAP32[$11>>2]|0;
    $27 = ($26|0)==($24|0);
    if (!($27)) {
     $scevgep$i$i$i$i$i = ((($26)) + -4|0);
     $28 = $scevgep$i$i$i$i$i;
     $29 = $24;
     $30 = (($28) - ($29))|0;
     $31 = $30 >>> 2;
     $32 = $31 ^ -1;
     $scevgep5$i$i$i$i$i = (($26) + ($32<<2)|0);
     HEAP32[$11>>2] = $scevgep5$i$i$i$i$i;
    }
    __ZdlPv($24);
    $eh$lpad$body$index3Z2D = $23;$eh$lpad$body$indexZ2D = $22;
   }
  }
 }
 if ((label|0) == 13) {
  $34 = ___cxa_find_matching_catch_2()|0;
  $35 = tempRet0;
  $eh$lpad$body$index3Z2D = $35;$eh$lpad$body$indexZ2D = $34;
 }
 $36 = HEAP32[$2>>2]|0;
 $37 = ($36|0)==(0|0);
 if (!($37)) {
  $38 = ((($36)) + 8|0);
  $39 = HEAP32[$38>>2]|0;HEAP32[$38>>2] = (($39-1)|0);
  $40 = ($39|0)==(1);
  if ($40) {
   __THREW__ = 0;
   invoke_viii(3262,($36|0),1,1);
   $41 = __THREW__; __THREW__ = 0;
   $42 = $41&1;
   if ($42) {
    $52 = ___cxa_find_matching_catch_3(0|0)|0;
    $53 = tempRet0;
    ___clang_call_terminate($52);
    // unreachable;
   }
  }
 }
 HEAP32[$2>>2] = 0;
 $43 = HEAP32[$1>>2]|0;
 $44 = ($43|0)==(0|0);
 if (!($44)) {
  $45 = ((($43)) + 8|0);
  $46 = HEAP32[$45>>2]|0;HEAP32[$45>>2] = (($46-1)|0);
  $47 = ($46|0)==(1);
  if ($47) {
   __THREW__ = 0;
   invoke_viii(3262,($43|0),1,1);
   $48 = __THREW__; __THREW__ = 0;
   $49 = $48&1;
   if ($49) {
    $52 = ___cxa_find_matching_catch_3(0|0)|0;
    $53 = tempRet0;
    ___clang_call_terminate($52);
    // unreachable;
   }
  }
 }
 HEAP32[$1>>2] = 0;
 __THREW__ = 0;
 invoke_vi(2335,($0|0));
 $50 = __THREW__; __THREW__ = 0;
 $51 = $50&1;
 if ($51) {
  $52 = ___cxa_find_matching_catch_3(0|0)|0;
  $53 = tempRet0;
  ___clang_call_terminate($52);
  // unreachable;
 } else {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
}
function __ZN3osg9Texture2DC2EPNS_5ImageE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$03 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index3Z2D = 0, $eh$lpad$body$indexZ2D = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i$i$i$i = 0, $scevgep5$i$i$i$i = 0, $scevgep5$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg7TextureC2Ev($0);
 HEAP32[$0>>2] = (66788);
 $2 = ((($0)) + 240|0);
 $3 = ((($0)) + 256|0);
 $4 = ((($0)) + 260|0);
 ;HEAP32[$2>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;HEAP32[$2+12>>2]=0|0;HEAP32[$2+16>>2]=0|0;
 __THREW__ = 0;
 $5 = (invoke_i(3285)|0);
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 L1: do {
  if ($7) {
   label = 14;
  } else {
   $8 = HEAP32[$5>>2]|0;
   __THREW__ = 0;
   $9 = (invoke_ii(3286,($8|0))|0);
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if ($11) {
    label = 14;
   } else {
    HEAP32[$4>>2] = 0;
    $12 = ((($0)) + 264|0);
    HEAP32[$12>>2] = 0;
    $13 = ((($0)) + 268|0);
    HEAP32[$13>>2] = 0;
    $14 = ($9|0)==(0);
    do {
     if (!($14)) {
      $15 = ($9>>>0)>(1073741823);
      if ($15) {
       __THREW__ = 0;
       invoke_vi(3307,($4|0));
       $16 = __THREW__; __THREW__ = 0;
      } else {
       $17 = $9 << 2;
       __THREW__ = 0;
       $18 = (invoke_ii(3276,($17|0))|0);
       $19 = __THREW__; __THREW__ = 0;
       $20 = $19&1;
       if (!($20)) {
        HEAP32[$4>>2] = $18;
        $21 = (($18) + ($9<<2)|0);
        $22 = ((($0)) + 268|0);
        HEAP32[$22>>2] = $21;
        _memset(($18|0),0,($17|0))|0;
        HEAP32[$12>>2] = $21;
        break;
       }
      }
      $23 = ___cxa_find_matching_catch_2()|0;
      $24 = tempRet0;
      $25 = HEAP32[$4>>2]|0;
      $26 = ($25|0)==(0|0);
      if ($26) {
       $eh$lpad$body$index3Z2D = $24;$eh$lpad$body$indexZ2D = $23;
       label = 15;
       break L1;
      }
      $27 = HEAP32[$12>>2]|0;
      $28 = ($27|0)==($25|0);
      if (!($28)) {
       $scevgep$i$i$i$i$i = ((($27)) + -4|0);
       $29 = $scevgep$i$i$i$i$i;
       $30 = $25;
       $31 = (($29) - ($30))|0;
       $32 = $31 >>> 2;
       $33 = $32 ^ -1;
       $scevgep5$i$i$i$i$i = (($27) + ($33<<2)|0);
       HEAP32[$12>>2] = $scevgep5$i$i$i$i$i;
      }
      __ZdlPv($25);
      $eh$lpad$body$index3Z2D = $24;$eh$lpad$body$indexZ2D = $23;
      label = 15;
      break L1;
     }
    } while(0);
    $34 = ((($0)) + 120|0);
    HEAP8[$34>>0] = 1;
    __THREW__ = 0;
    invoke_vii(3964,($0|0),($1|0));
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if (!($36)) {
     return;
    }
    $39 = ___cxa_find_matching_catch_2()|0;
    $40 = tempRet0;
    $41 = HEAP32[$4>>2]|0;
    $42 = ($41|0)==(0|0);
    if ($42) {
     $$0 = $40;$$03 = $39;
    } else {
     $43 = HEAP32[$12>>2]|0;
     $44 = ($43|0)==($41|0);
     if (!($44)) {
      $scevgep$i$i$i$i = ((($43)) + -4|0);
      $45 = $scevgep$i$i$i$i;
      $46 = $41;
      $47 = (($45) - ($46))|0;
      $48 = $47 >>> 2;
      $49 = $48 ^ -1;
      $scevgep5$i$i$i$i = (($43) + ($49<<2)|0);
      HEAP32[$12>>2] = $scevgep5$i$i$i$i;
     }
     __ZdlPv($41);
     $$0 = $40;$$03 = $39;
    }
   }
  }
 } while(0);
 if ((label|0) == 14) {
  $37 = ___cxa_find_matching_catch_2()|0;
  $38 = tempRet0;
  $eh$lpad$body$index3Z2D = $38;$eh$lpad$body$indexZ2D = $37;
  label = 15;
 }
 if ((label|0) == 15) {
  $$0 = $eh$lpad$body$index3Z2D;$$03 = $eh$lpad$body$indexZ2D;
 }
 $50 = HEAP32[$3>>2]|0;
 $51 = ($50|0)==(0|0);
 if (!($51)) {
  $52 = ((($50)) + 8|0);
  $53 = HEAP32[$52>>2]|0;HEAP32[$52>>2] = (($53-1)|0);
  $54 = ($53|0)==(1);
  if ($54) {
   __THREW__ = 0;
   invoke_viii(3262,($50|0),1,1);
   $55 = __THREW__; __THREW__ = 0;
   $56 = $55&1;
   if ($56) {
    $66 = ___cxa_find_matching_catch_3(0|0)|0;
    $67 = tempRet0;
    ___clang_call_terminate($66);
    // unreachable;
   }
  }
 }
 HEAP32[$3>>2] = 0;
 $57 = HEAP32[$2>>2]|0;
 $58 = ($57|0)==(0|0);
 if (!($58)) {
  $59 = ((($57)) + 8|0);
  $60 = HEAP32[$59>>2]|0;HEAP32[$59>>2] = (($60-1)|0);
  $61 = ($60|0)==(1);
  if ($61) {
   __THREW__ = 0;
   invoke_viii(3262,($57|0),1,1);
   $62 = __THREW__; __THREW__ = 0;
   $63 = $62&1;
   if ($63) {
    $66 = ___cxa_find_matching_catch_3(0|0)|0;
    $67 = tempRet0;
    ___clang_call_terminate($66);
    // unreachable;
   }
  }
 }
 HEAP32[$2>>2] = 0;
 __THREW__ = 0;
 invoke_vi(2335,($0|0));
 $64 = __THREW__; __THREW__ = 0;
 $65 = $64&1;
 if ($65) {
  $66 = ___cxa_find_matching_catch_3(0|0)|0;
  $67 = tempRet0;
  ___clang_call_terminate($66);
  // unreachable;
 } else {
  ___resumeException($$03|0);
  // unreachable;
 }
}
function __ZN3osg9Texture2D14copyTexImage2DERNS_5StateEiiii($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$042$off044 = 0, $$048 = 0, $$cmp = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $or$cond = 0, $or$cond47 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $6 = sp;
 $7 = ((($1)) + 124|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($0)) + 172|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0);
 if ($11) {
  HEAP32[$9>>2] = 6408;
 }
 $12 = ((($0)) + 224|0);
 $13 = ((($0)) + 228|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP32[$12>>2]|0;
 $16 = (($14) - ($15))|0;
 $17 = $16 >> 2;
 $18 = ($17>>>0)>($8>>>0);
 L4: do {
  if (!($18)) {
   $19 = (($8) + 1)|0;
   $20 = ($19>>>0)>($17>>>0);
   $21 = $15;
   $22 = $14;
   if ($20) {
    $23 = (($19) - ($17))|0;
    __ZNSt3__26vectorIN3osg7ref_ptrINS1_7Texture13TextureObjectEEENS_9allocatorIS5_EEE8__appendEj($12,$23);
    break;
   }
   $24 = ($19>>>0)<($17>>>0);
   if ($24) {
    $25 = (($21) + ($19<<2)|0);
    $26 = ($22|0)==($25|0);
    if (!($26)) {
     $28 = $22;
     while(1) {
      $27 = ((($28)) + -4|0);
      HEAP32[$13>>2] = $27;
      $29 = HEAP32[$27>>2]|0;
      $30 = ($29|0)==(0|0);
      if (!($30)) {
       $31 = ((($29)) + 8|0);
       $32 = HEAP32[$31>>2]|0;HEAP32[$31>>2] = (($32-1)|0);
       $33 = ($32|0)==(1);
       if ($33) {
        __THREW__ = 0;
        invoke_viii(3262,($29|0),1,1);
        $34 = __THREW__; __THREW__ = 0;
        $35 = $34&1;
        if ($35) {
         break;
        }
       }
      }
      HEAP32[$27>>2] = 0;
      $36 = HEAP32[$13>>2]|0;
      $37 = ($36|0)==($25|0);
      if ($37) {
       break L4;
      } else {
       $28 = $36;
      }
     }
     $38 = ___cxa_find_matching_catch_2()|0;
     $39 = tempRet0;
     ___cxa_call_unexpected(($38|0));
     // unreachable;
    }
   }
  }
 } while(0);
 $40 = HEAP32[$12>>2]|0;
 $41 = (($40) + ($8<<2)|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ($42|0)==(0|0);
 if (!($43)) {
  $44 = ((($0)) + 244|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = ($45|0)==($4|0);
  if ($46) {
   $47 = ((($0)) + 248|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = ($48|0)==($5|0);
   if ($49) {
    __ZN3osg9Texture2D17copyTexSubImage2DERNS_5StateEiiiiii($0,$1,0,0,$2,$3,$4,$5);
    STACKTOP = sp;return;
   }
  }
  __ZN3osg7Texture18dirtyTextureObjectEv($0);
 }
 $50 = ((($0)) + 240|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = ($51|0)==(0|0);
 if (!($52)) {
  HEAP32[$50>>2] = 0;
  $53 = ((($51)) + 8|0);
  $54 = HEAP32[$53>>2]|0;HEAP32[$53>>2] = (($54-1)|0);
  $55 = ($54|0)==(1);
  if ($55) {
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($51,1,1);
  }
 }
 $56 = ((($0)) + 92|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = $57 & -2;
 $$cmp = ($58|0)==(9728);
 if ($$cmp) {
  $59 = ((($0)) + 244|0);
  HEAP32[$59>>2] = $4;
  $60 = ((($0)) + 248|0);
  HEAP32[$60>>2] = $5;
  $61 = ((($0)) + 252|0);
  HEAP32[$61>>2] = 1;
  $$042$off044 = 0;$96 = 1;
 } else {
  $62 = (__ZNK3osg7Texture33isHardwareMipmapGenerationEnabledERKNS_5StateE($0,$1)|0);
  if (!($62)) {
   $63 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
   do {
    if ($63) {
     $64 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
     $65 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($64,153667,98)|0);
     $66 = HEAP32[$65>>2]|0;
     $67 = ((($66)) + -12|0);
     $68 = HEAP32[$67>>2]|0;
     $69 = (($65) + ($68)|0);
     __ZNKSt3__28ios_base6getlocEv($6,$69);
     __THREW__ = 0;
     $70 = (invoke_iii(3255,($6|0),(215188|0))|0);
     $71 = __THREW__; __THREW__ = 0;
     $72 = $71&1;
     if (!($72)) {
      $73 = HEAP32[$70>>2]|0;
      $74 = ((($73)) + 28|0);
      $75 = HEAP32[$74>>2]|0;
      __THREW__ = 0;
      $76 = (invoke_iii($75|0,($70|0),10)|0);
      $77 = __THREW__; __THREW__ = 0;
      $78 = $77&1;
      if (!($78)) {
       __ZNSt3__26localeD2Ev($6);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($65,$76)|0);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($65)|0);
       break;
      }
     }
     $79 = ___cxa_find_matching_catch_2()|0;
     $80 = tempRet0;
     __THREW__ = 0;
     invoke_vi(3263,($6|0));
     $81 = __THREW__; __THREW__ = 0;
     $82 = $81&1;
     if ($82) {
      $83 = ___cxa_find_matching_catch_3(0|0)|0;
      $84 = tempRet0;
      ___clang_call_terminate($83);
      // unreachable;
     } else {
      ___resumeException($79|0);
      // unreachable;
     }
    }
   } while(0);
   HEAP32[$56>>2] = 9729;
  }
  $85 = ((($0)) + 244|0);
  HEAP32[$85>>2] = $4;
  $86 = ((($0)) + 248|0);
  HEAP32[$86>>2] = $5;
  $87 = ((($0)) + 252|0);
  HEAP32[$87>>2] = 1;
  $88 = ($4|0)>(1);
  $89 = ($5|0)>(1);
  $or$cond47 = $88 | $89;
  if ($or$cond47) {
   $$048 = 1;$92 = 1;
   while(1) {
    $90 = $$048 << 1;
    $91 = (($92) + 1)|0;
    $93 = ($90|0)<($4|0);
    $94 = ($90|0)<($5|0);
    $or$cond = $93 | $94;
    if ($or$cond) {
     $$048 = $90;$92 = $91;
    } else {
     break;
    }
   }
   HEAP32[$87>>2] = $91;
   $$042$off044 = $62;$96 = $91;
  } else {
   $$042$off044 = $62;$96 = 1;
  }
 }
 $95 = HEAP32[$9>>2]|0;
 $97 = (__ZNK3osg7Texture30generateAndAssignTextureObjectEjjijiiii($0,$8,3553,$96,$95,$4,$5,1,0)|0);
 __ZN3osg7Texture13TextureObject4bindEv($97);
 __ZNK3osg7Texture18applyTexParametersEjRNS_5StateE($0,3553,$1);
 $98 = (__ZNK3osg7Texture20mipmapBeforeTexImageERKNS_5StateEb($0,$1,$$042$off044)|0);
 $99 = HEAP32[$9>>2]|0;
 _glCopyTexImage2D(3553,0,($99|0),($2|0),($3|0),($4|0),($5|0),0);
 __ZNK3osg7Texture19mipmapAfterTexImageERNS_5StateENS0_18GenerateMipmapModeE($0,$1,$98);
 $100 = ((($97)) + 64|0);
 HEAP8[$100>>0] = 1;
 $101 = ((($1)) + 688|0);
 $102 = HEAP32[$101>>2]|0;
 __ZN3osg5State27haveAppliedTextureAttributeEjPKNS_14StateAttributeE($1,$102,$0);
 STACKTOP = sp;return;
}
function __ZN3osg9Texture2D17copyTexSubImage2DERNS_5StateEiiiiii($0,$1,$2,$3,$4,$5,$6,$7) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 var $$0$off0 = 0, $$cmp = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $8 = sp;
 $9 = ((($1)) + 124|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ((($0)) + 172|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0);
 if ($13) {
  HEAP32[$11>>2] = 6408;
 }
 $14 = ((($0)) + 224|0);
 $15 = ((($0)) + 228|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = HEAP32[$14>>2]|0;
 $18 = (($16) - ($17))|0;
 $19 = $18 >> 2;
 $20 = ($19>>>0)>($10>>>0);
 L4: do {
  if (!($20)) {
   $21 = (($10) + 1)|0;
   $22 = ($21>>>0)>($19>>>0);
   $23 = $17;
   $24 = $16;
   if ($22) {
    $25 = (($21) - ($19))|0;
    __ZNSt3__26vectorIN3osg7ref_ptrINS1_7Texture13TextureObjectEEENS_9allocatorIS5_EEE8__appendEj($14,$25);
    break;
   }
   $26 = ($21>>>0)<($19>>>0);
   if ($26) {
    $27 = (($23) + ($21<<2)|0);
    $28 = ($24|0)==($27|0);
    if (!($28)) {
     $30 = $24;
     while(1) {
      $29 = ((($30)) + -4|0);
      HEAP32[$15>>2] = $29;
      $31 = HEAP32[$29>>2]|0;
      $32 = ($31|0)==(0|0);
      if (!($32)) {
       $33 = ((($31)) + 8|0);
       $34 = HEAP32[$33>>2]|0;HEAP32[$33>>2] = (($34-1)|0);
       $35 = ($34|0)==(1);
       if ($35) {
        __THREW__ = 0;
        invoke_viii(3262,($31|0),1,1);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break;
        }
       }
      }
      HEAP32[$29>>2] = 0;
      $38 = HEAP32[$15>>2]|0;
      $39 = ($38|0)==($27|0);
      if ($39) {
       break L4;
      } else {
       $30 = $38;
      }
     }
     $40 = ___cxa_find_matching_catch_2()|0;
     $41 = tempRet0;
     ___cxa_call_unexpected(($40|0));
     // unreachable;
    }
   }
  }
 } while(0);
 $42 = HEAP32[$14>>2]|0;
 $43 = (($42) + ($10<<2)|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = ($44|0)==(0|0);
 if ($45) {
  __ZN3osg9Texture2D14copyTexImage2DERNS_5StateEiiii($0,$1,$4,$5,$6,$7);
  STACKTOP = sp;return;
 }
 __ZN3osg7Texture13TextureObject4bindEv($44);
 __ZNK3osg7Texture18applyTexParametersEjRNS_5StateE($0,3553,$1);
 $46 = ((($0)) + 92|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = $47 & -2;
 $$cmp = ($48|0)==(9728);
 if ($$cmp) {
  $$0$off0 = 0;
 } else {
  $49 = (__ZNK3osg7Texture33isHardwareMipmapGenerationEnabledERKNS_5StateE($0,$1)|0);
  if ($49) {
   $$0$off0 = 1;
  } else {
   $50 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
   do {
    if ($50) {
     $51 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
     $52 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($51,153667,98)|0);
     $53 = HEAP32[$52>>2]|0;
     $54 = ((($53)) + -12|0);
     $55 = HEAP32[$54>>2]|0;
     $56 = (($52) + ($55)|0);
     __ZNKSt3__28ios_base6getlocEv($8,$56);
     __THREW__ = 0;
     $57 = (invoke_iii(3255,($8|0),(215188|0))|0);
     $58 = __THREW__; __THREW__ = 0;
     $59 = $58&1;
     if (!($59)) {
      $60 = HEAP32[$57>>2]|0;
      $61 = ((($60)) + 28|0);
      $62 = HEAP32[$61>>2]|0;
      __THREW__ = 0;
      $63 = (invoke_iii($62|0,($57|0),10)|0);
      $64 = __THREW__; __THREW__ = 0;
      $65 = $64&1;
      if (!($65)) {
       __ZNSt3__26localeD2Ev($8);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($52,$63)|0);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($52)|0);
       break;
      }
     }
     $66 = ___cxa_find_matching_catch_2()|0;
     $67 = tempRet0;
     __THREW__ = 0;
     invoke_vi(3263,($8|0));
     $68 = __THREW__; __THREW__ = 0;
     $69 = $68&1;
     if ($69) {
      $70 = ___cxa_find_matching_catch_3(0|0)|0;
      $71 = tempRet0;
      ___clang_call_terminate($70);
      // unreachable;
     } else {
      ___resumeException($66|0);
      // unreachable;
     }
    }
   } while(0);
   HEAP32[$46>>2] = 9729;
   $$0$off0 = 0;
  }
 }
 $72 = (__ZNK3osg7Texture20mipmapBeforeTexImageERKNS_5StateEb($0,$1,$$0$off0)|0);
 _glCopyTexSubImage2D(3553,0,($2|0),($3|0),($4|0),($5|0),($6|0),($7|0));
 __ZNK3osg7Texture19mipmapAfterTexImageERNS_5StateENS0_18GenerateMipmapModeE($0,$1,$72);
 $73 = ((($1)) + 688|0);
 $74 = HEAP32[$73>>2]|0;
 __ZN3osg5State27haveAppliedTextureAttributeEjPKNS_14StateAttributeE($1,$74,$0);
 STACKTOP = sp;return;
}
function __ZN3osg9Texture3D17copyTexSubImage3DERNS_5StateEiiiiiii($0,$1,$2,$3,$4,$5,$6,$7,$8) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 $8 = $8|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $70 = 0, $71 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $9 = sp;
 $10 = ((($1)) + 124|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($1)) + 784|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($0)) + 224|0);
 $15 = ((($0)) + 228|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = HEAP32[$14>>2]|0;
 $18 = (($16) - ($17))|0;
 $19 = $18 >> 2;
 $20 = ($19>>>0)>($11>>>0);
 L1: do {
  if (!($20)) {
   $21 = (($11) + 1)|0;
   $22 = ($21>>>0)>($19>>>0);
   $23 = $17;
   $24 = $16;
   if ($22) {
    $25 = (($21) - ($19))|0;
    __ZNSt3__26vectorIN3osg7ref_ptrINS1_7Texture13TextureObjectEEENS_9allocatorIS5_EEE8__appendEj($14,$25);
    break;
   }
   $26 = ($21>>>0)<($19>>>0);
   if ($26) {
    $27 = (($23) + ($21<<2)|0);
    $28 = ($24|0)==($27|0);
    if (!($28)) {
     $30 = $24;
     while(1) {
      $29 = ((($30)) + -4|0);
      HEAP32[$15>>2] = $29;
      $31 = HEAP32[$29>>2]|0;
      $32 = ($31|0)==(0|0);
      if (!($32)) {
       $33 = ((($31)) + 8|0);
       $34 = HEAP32[$33>>2]|0;HEAP32[$33>>2] = (($34-1)|0);
       $35 = ($34|0)==(1);
       if ($35) {
        __THREW__ = 0;
        invoke_viii(3262,($31|0),1,1);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break;
        }
       }
      }
      HEAP32[$29>>2] = 0;
      $38 = HEAP32[$15>>2]|0;
      $39 = ($38|0)==($27|0);
      if ($39) {
       break L1;
      } else {
       $30 = $38;
      }
     }
     $40 = ___cxa_find_matching_catch_2()|0;
     $41 = tempRet0;
     ___cxa_call_unexpected(($40|0));
     // unreachable;
    }
   }
  }
 } while(0);
 $42 = HEAP32[$14>>2]|0;
 $43 = (($42) + ($11<<2)|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = ($44|0)==(0|0);
 if (!($45)) {
  __ZN3osg7Texture13TextureObject4bindEv($44);
  __ZNK3osg7Texture18applyTexParametersEjRNS_5StateE($0,32879,$1);
  $46 = ((($13)) + 1120|0);
  $47 = HEAP32[$46>>2]|0;
  FUNCTION_TABLE_viiiiiiiii[$47 & 8191](32879,0,$2,$3,$4,$5,$6,$7,$8);
  $48 = ((($1)) + 688|0);
  $49 = HEAP32[$48>>2]|0;
  __ZN3osg5State27haveAppliedTextureAttributeEjPKNS_14StateAttributeE($1,$49,$0);
  STACKTOP = sp;return;
 }
 $50 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
 if (!($50)) {
  STACKTOP = sp;return;
 }
 $51 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
 $52 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($51,153812,92)|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = ((($53)) + -12|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = (($52) + ($55)|0);
 __ZNKSt3__28ios_base6getlocEv($9,$56);
 __THREW__ = 0;
 $57 = (invoke_iii(3255,($9|0),(215188|0))|0);
 $58 = __THREW__; __THREW__ = 0;
 $59 = $58&1;
 if (!($59)) {
  $60 = HEAP32[$57>>2]|0;
  $61 = ((($60)) + 28|0);
  $62 = HEAP32[$61>>2]|0;
  __THREW__ = 0;
  $63 = (invoke_iii($62|0,($57|0),10)|0);
  $64 = __THREW__; __THREW__ = 0;
  $65 = $64&1;
  if (!($65)) {
   __ZNSt3__26localeD2Ev($9);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($52,$63)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($52)|0);
   STACKTOP = sp;return;
  }
 }
 $66 = ___cxa_find_matching_catch_2()|0;
 $67 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($9|0));
 $68 = __THREW__; __THREW__ = 0;
 $69 = $68&1;
 if ($69) {
  $70 = ___cxa_find_matching_catch_3(0|0)|0;
  $71 = tempRet0;
  ___clang_call_terminate($70);
  // unreachable;
 } else {
  ___resumeException($66|0);
  // unreachable;
 }
}
function __ZN3osg16TextureObjectSetD2Ev($0) {
 $0 = $0|0;
 var $$023$i$i = 0, $$023$i$i4 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (67964);
 $1 = ((($0)) + 80|0);
 $2 = ((($0)) + 88|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 L1: do {
  if (!($4)) {
   $5 = ((($0)) + 84|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = HEAP32[$1>>2]|0;
   $8 = ((($7)) + 4|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = HEAP32[$6>>2]|0;
   $11 = ((($10)) + 4|0);
   HEAP32[$11>>2] = $9;
   $12 = HEAP32[$8>>2]|0;
   HEAP32[$12>>2] = $10;
   HEAP32[$2>>2] = 0;
   $13 = ($6|0)==($1|0);
   if (!($13)) {
    $$023$i$i = $6;
    while(1) {
     $14 = ((($$023$i$i)) + 4|0);
     $15 = HEAP32[$14>>2]|0;
     $16 = ((($$023$i$i)) + 8|0);
     $17 = HEAP32[$16>>2]|0;
     $18 = ($17|0)==(0|0);
     if (!($18)) {
      $19 = ((($17)) + 8|0);
      $20 = HEAP32[$19>>2]|0;HEAP32[$19>>2] = (($20-1)|0);
      $21 = ($20|0)==(1);
      if ($21) {
       __THREW__ = 0;
       invoke_viii(3262,($17|0),1,1);
       $22 = __THREW__; __THREW__ = 0;
       $23 = $22&1;
       if ($23) {
        break;
       }
      }
     }
     __ZdlPv($$023$i$i);
     $24 = ($15|0)==($1|0);
     if ($24) {
      break L1;
     } else {
      $$023$i$i = $15;
     }
    }
    $25 = ___cxa_find_matching_catch_2()|0;
    $26 = tempRet0;
    ___cxa_call_unexpected(($25|0));
    // unreachable;
   }
  }
 } while(0);
 $27 = ((($0)) + 68|0);
 $28 = ((($0)) + 76|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ($29|0)==(0);
 L11: do {
  if (!($30)) {
   $31 = ((($0)) + 72|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = HEAP32[$27>>2]|0;
   $34 = ((($33)) + 4|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = HEAP32[$32>>2]|0;
   $37 = ((($36)) + 4|0);
   HEAP32[$37>>2] = $35;
   $38 = HEAP32[$34>>2]|0;
   HEAP32[$38>>2] = $36;
   HEAP32[$28>>2] = 0;
   $39 = ($32|0)==($27|0);
   if (!($39)) {
    $$023$i$i4 = $32;
    while(1) {
     $40 = ((($$023$i$i4)) + 4|0);
     $41 = HEAP32[$40>>2]|0;
     $42 = ((($$023$i$i4)) + 8|0);
     $43 = HEAP32[$42>>2]|0;
     $44 = ($43|0)==(0|0);
     if (!($44)) {
      $45 = ((($43)) + 8|0);
      $46 = HEAP32[$45>>2]|0;HEAP32[$45>>2] = (($46-1)|0);
      $47 = ($46|0)==(1);
      if ($47) {
       __THREW__ = 0;
       invoke_viii(3262,($43|0),1,1);
       $48 = __THREW__; __THREW__ = 0;
       $49 = $48&1;
       if ($49) {
        break;
       }
      }
     }
     __ZdlPv($$023$i$i4);
     $50 = ($41|0)==($27|0);
     if ($50) {
      break L11;
     } else {
      $$023$i$i4 = $41;
     }
    }
    $51 = ___cxa_find_matching_catch_2()|0;
    $52 = tempRet0;
    ___cxa_call_unexpected(($51|0));
    // unreachable;
   }
  }
 } while(0);
 $53 = ((($0)) + 12|0);
 __THREW__ = 0;
 invoke_vi(707,($53|0));
 $54 = __THREW__; __THREW__ = 0;
 $55 = $54&1;
 if (!($55)) {
  __ZN3osg10ReferencedD2Ev($0);
  return;
 }
 $56 = ___cxa_find_matching_catch_2()|0;
 $57 = tempRet0;
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $58 = __THREW__; __THREW__ = 0;
 $59 = $58&1;
 if ($59) {
  $60 = ___cxa_find_matching_catch_3(0|0)|0;
  $61 = tempRet0;
  ___clang_call_terminate($60);
  // unreachable;
 } else {
  ___resumeException($56|0);
  // unreachable;
 }
}
function __ZN3osg16TextureObjectSetD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(2323,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZN3osg20TextureObjectManagerD2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (67984);
 $1 = ((($0)) + 44|0);
 $2 = ((($0)) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIN3osg7Texture14TextureProfileENS2_7ref_ptrINS2_16TextureObjectSetEEEEENS_19__map_value_compareIS4_S8_NS_4lessIS4_EELb1EEENS_9allocatorIS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($1,$3);
 __ZN3osg21GraphicsObjectManagerD2Ev($0);
 return;
}
function __ZN3osg20TextureObjectManagerD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (67984);
 $1 = ((($0)) + 44|0);
 $2 = ((($0)) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIN3osg7Texture14TextureProfileENS2_7ref_ptrINS2_16TextureObjectSetEEEEENS_19__map_value_compareIS4_S8_NS_4lessIS4_EELb1EEENS_9allocatorIS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($1,$3);
 __THREW__ = 0;
 invoke_vi(1861,($0|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch_2()|0;
  $7 = tempRet0;
  __ZdlPv($0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZN3osg20TextureObjectManager8newFrameEPNS_10FrameStampE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $6 = ((($0)) + 56|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($7) + 1)|0;
  HEAP32[$6>>2] = $8;
 } else {
  $3 = ((($1)) + 12|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ((($0)) + 56|0);
  HEAP32[$5>>2] = $4;
 }
 $9 = ((($0)) + 60|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 1)|0;
 HEAP32[$9>>2] = $11;
 return;
}
function __ZN3osg20TextureObjectManager10resetStatsEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 60|0);
 HEAP32[$1>>2] = 0;
 $2 = ((($0)) + 64|0);
 HEAP32[$2>>2] = 0;
 $3 = ((($0)) + 72|0);
 HEAPF64[$3>>3] = 0.0;
 $4 = ((($0)) + 80|0);
 HEAP32[$4>>2] = 0;
 $5 = ((($0)) + 88|0);
 HEAPF64[$5>>3] = 0.0;
 return;
}
function __ZN3osg20TextureObjectManager11reportStatsERNSt3__213basic_ostreamIcNS1_11char_traitsIcEEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$ = 0.0, $10 = 0.0, $100 = 0, $101 = 0.0, $102 = 0, $103 = 0, $104 = 0.0, $105 = 0.0, $106 = 0.0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0;
 var $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0.0;
 var $135 = 0, $136 = 0.0, $137 = 0.0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0;
 var $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0.0, $69 = 0, $7 = 0, $70 = 0, $71 = 0.0, $72 = 0.0, $73 = 0.0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $2 = sp + 16|0;
 $3 = sp + 12|0;
 $4 = sp + 8|0;
 $5 = sp + 4|0;
 $6 = sp;
 $7 = ((($0)) + 60|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0);
 $10 = (+($8>>>0));
 $$ = $9 ? 1.0 : $10;
 $11 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($1,154405,36)|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ((($12)) + -12|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($11) + ($14)|0);
 __ZNKSt3__28ios_base6getlocEv($6,$15);
 __THREW__ = 0;
 $16 = (invoke_iii(3255,($6|0),(215188|0))|0);
 $17 = __THREW__; __THREW__ = 0;
 $18 = $17&1;
 if (!($18)) {
  $19 = HEAP32[$16>>2]|0;
  $20 = ((($19)) + 28|0);
  $21 = HEAP32[$20>>2]|0;
  __THREW__ = 0;
  $22 = (invoke_iii($21|0,($16|0),10)|0);
  $23 = __THREW__; __THREW__ = 0;
  $24 = $23&1;
  if (!($24)) {
   __ZNSt3__26localeD2Ev($6);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($11,$22)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($11)|0);
   $31 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($1,154442,30)|0);
   $32 = ((($0)) + 28|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($31,$33)|0);
   $35 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($34,154473,29)|0);
   $36 = ((($0)) + 32|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($35,$37)|0);
   $39 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($38,154503,22)|0);
   $40 = ((($0)) + 36|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($39,$41)|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = ((($43)) + -12|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = (($42) + ($45)|0);
   __ZNKSt3__28ios_base6getlocEv($5,$46);
   __THREW__ = 0;
   $47 = (invoke_iii(3255,($5|0),(215188|0))|0);
   $48 = __THREW__; __THREW__ = 0;
   $49 = $48&1;
   if (!($49)) {
    $50 = HEAP32[$47>>2]|0;
    $51 = ((($50)) + 28|0);
    $52 = HEAP32[$51>>2]|0;
    __THREW__ = 0;
    $53 = (invoke_iii($52|0,($47|0),10)|0);
    $54 = __THREW__; __THREW__ = 0;
    $55 = $54&1;
    if (!($55)) {
     __ZNSt3__26localeD2Ev($5);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($42,$53)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($42)|0);
     $62 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($1,154526,23)|0);
     $63 = ((($0)) + 80|0);
     $64 = HEAP32[$63>>2]|0;
     $65 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($62,$64)|0);
     $66 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($65,154550,16)|0);
     $67 = ((($0)) + 88|0);
     $68 = +HEAPF64[$67>>3];
     $69 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEd($66,$68)|0);
     $70 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($69,154567,18)|0);
     $71 = +HEAPF64[$67>>3];
     $72 = $71 / $$;
     $73 = $72 * 1000.0;
     $74 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEd($70,$73)|0);
     $75 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($74,163681,2)|0);
     $76 = HEAP32[$75>>2]|0;
     $77 = ((($76)) + -12|0);
     $78 = HEAP32[$77>>2]|0;
     $79 = (($75) + ($78)|0);
     __ZNKSt3__28ios_base6getlocEv($4,$79);
     __THREW__ = 0;
     $80 = (invoke_iii(3255,($4|0),(215188|0))|0);
     $81 = __THREW__; __THREW__ = 0;
     $82 = $81&1;
     if (!($82)) {
      $83 = HEAP32[$80>>2]|0;
      $84 = ((($83)) + 28|0);
      $85 = HEAP32[$84>>2]|0;
      __THREW__ = 0;
      $86 = (invoke_iii($85|0,($80|0),10)|0);
      $87 = __THREW__; __THREW__ = 0;
      $88 = $87&1;
      if (!($88)) {
       __ZNSt3__26localeD2Ev($4);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($75,$86)|0);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($75)|0);
       $95 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($1,154586,21)|0);
       $96 = ((($0)) + 64|0);
       $97 = HEAP32[$96>>2]|0;
       $98 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($95,$97)|0);
       $99 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($98,154608,14)|0);
       $100 = ((($0)) + 72|0);
       $101 = +HEAPF64[$100>>3];
       $102 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEd($99,$101)|0);
       $103 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($102,154567,18)|0);
       $104 = +HEAPF64[$100>>3];
       $105 = $104 / $$;
       $106 = $105 * 1000.0;
       $107 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEd($103,$106)|0);
       $108 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($107,163681,2)|0);
       $109 = HEAP32[$108>>2]|0;
       $110 = ((($109)) + -12|0);
       $111 = HEAP32[$110>>2]|0;
       $112 = (($108) + ($111)|0);
       __ZNKSt3__28ios_base6getlocEv($3,$112);
       __THREW__ = 0;
       $113 = (invoke_iii(3255,($3|0),(215188|0))|0);
       $114 = __THREW__; __THREW__ = 0;
       $115 = $114&1;
       if (!($115)) {
        $116 = HEAP32[$113>>2]|0;
        $117 = ((($116)) + 28|0);
        $118 = HEAP32[$117>>2]|0;
        __THREW__ = 0;
        $119 = (invoke_iii($118|0,($113|0),10)|0);
        $120 = __THREW__; __THREW__ = 0;
        $121 = $120&1;
        if (!($121)) {
         __ZNSt3__26localeD2Ev($3);
         (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($108,$119)|0);
         (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($108)|0);
         $128 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($1,154165,27)|0);
         $129 = ((($0)) + 40|0);
         $130 = HEAP32[$129>>2]|0;
         $131 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($128,$130)|0);
         $132 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($131,154193,20)|0);
         $133 = HEAP32[$40>>2]|0;
         $134 = (+($133>>>0));
         $135 = HEAP32[$129>>2]|0;
         $136 = (+($135>>>0));
         $137 = $134 / $136;
         $138 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEd($132,$137)|0);
         $139 = HEAP32[$138>>2]|0;
         $140 = ((($139)) + -12|0);
         $141 = HEAP32[$140>>2]|0;
         $142 = (($138) + ($141)|0);
         __ZNKSt3__28ios_base6getlocEv($2,$142);
         __THREW__ = 0;
         $143 = (invoke_iii(3255,($2|0),(215188|0))|0);
         $144 = __THREW__; __THREW__ = 0;
         $145 = $144&1;
         if (!($145)) {
          $146 = HEAP32[$143>>2]|0;
          $147 = ((($146)) + 28|0);
          $148 = HEAP32[$147>>2]|0;
          __THREW__ = 0;
          $149 = (invoke_iii($148|0,($143|0),10)|0);
          $150 = __THREW__; __THREW__ = 0;
          $151 = $150&1;
          if (!($151)) {
           __ZNSt3__26localeD2Ev($2);
           (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($138,$149)|0);
           (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($138)|0);
           $158 = HEAP32[$0>>2]|0;
           $159 = ((($158)) + 24|0);
           $160 = HEAP32[$159>>2]|0;
           FUNCTION_TABLE_vii[$160 & 8191]($0,$1);
           STACKTOP = sp;return;
          }
         }
         $152 = ___cxa_find_matching_catch_2()|0;
         $153 = tempRet0;
         __THREW__ = 0;
         invoke_vi(3263,($2|0));
         $154 = __THREW__; __THREW__ = 0;
         $155 = $154&1;
         if ($155) {
          $156 = ___cxa_find_matching_catch_3(0|0)|0;
          $157 = tempRet0;
          ___clang_call_terminate($156);
          // unreachable;
         } else {
          ___resumeException($152|0);
          // unreachable;
         }
        }
       }
       $122 = ___cxa_find_matching_catch_2()|0;
       $123 = tempRet0;
       __THREW__ = 0;
       invoke_vi(3263,($3|0));
       $124 = __THREW__; __THREW__ = 0;
       $125 = $124&1;
       if ($125) {
        $126 = ___cxa_find_matching_catch_3(0|0)|0;
        $127 = tempRet0;
        ___clang_call_terminate($126);
        // unreachable;
       } else {
        ___resumeException($122|0);
        // unreachable;
       }
      }
     }
     $89 = ___cxa_find_matching_catch_2()|0;
     $90 = tempRet0;
     __THREW__ = 0;
     invoke_vi(3263,($4|0));
     $91 = __THREW__; __THREW__ = 0;
     $92 = $91&1;
     if ($92) {
      $93 = ___cxa_find_matching_catch_3(0|0)|0;
      $94 = tempRet0;
      ___clang_call_terminate($93);
      // unreachable;
     } else {
      ___resumeException($89|0);
      // unreachable;
     }
    }
   }
   $56 = ___cxa_find_matching_catch_2()|0;
   $57 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($5|0));
   $58 = __THREW__; __THREW__ = 0;
   $59 = $58&1;
   if ($59) {
    $60 = ___cxa_find_matching_catch_3(0|0)|0;
    $61 = tempRet0;
    ___clang_call_terminate($60);
    // unreachable;
   } else {
    ___resumeException($56|0);
    // unreachable;
   }
  }
 }
 $25 = ___cxa_find_matching_catch_2()|0;
 $26 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($6|0));
 $27 = __THREW__; __THREW__ = 0;
 $28 = $27&1;
 if ($28) {
  $29 = ___cxa_find_matching_catch_3(0|0)|0;
  $30 = tempRet0;
  ___clang_call_terminate($29);
  // unreachable;
 } else {
  ___resumeException($25|0);
  // unreachable;
 }
}
function __ZNK3osg20TextureObjectManager14recomputeStatsERNSt3__213basic_ostreamIcNS1_11char_traitsIcEEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i = 0, $$0$i$i$i$i = 0, $$0$i49 = 0, $$0$i56 = 0, $$0$lcssa = 0, $$040$lcssa = 0, $$04078 = 0, $$042$lcssa = 0, $$04277 = 0, $$043$lcssa = 0, $$04376 = 0, $$06$lcssa$i = 0, $$06$lcssa$i51 = 0, $$06$lcssa$i58 = 0, $$068$i = 0, $$068$i48 = 0, $$068$i55 = 0, $$07$i = 0, $$07$i53 = 0, $$079 = 0;
 var $$09$i = 0, $$09$i47 = 0, $$09$i54 = 0, $$sroa$063$0$be = 0, $$sroa$063$075 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0;
 var $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0.0, $64 = 0, $65 = 0.0, $66 = 0.0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $2 = sp + 16|0;
 $3 = sp + 12|0;
 $4 = sp + 8|0;
 $5 = sp + 4|0;
 $6 = sp;
 $7 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($1,154063,38)|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($8)) + -12|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($7) + ($10)|0);
 __ZNKSt3__28ios_base6getlocEv($6,$11);
 __THREW__ = 0;
 $12 = (invoke_iii(3255,($6|0),(215188|0))|0);
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 if (!($14)) {
  $15 = HEAP32[$12>>2]|0;
  $16 = ((($15)) + 28|0);
  $17 = HEAP32[$16>>2]|0;
  __THREW__ = 0;
  $18 = (invoke_iii($17|0,($12|0),10)|0);
  $19 = __THREW__; __THREW__ = 0;
  $20 = $19&1;
  if (!($20)) {
   __ZNSt3__26localeD2Ev($6);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($7,$18)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($7)|0);
   $27 = ((($0)) + 44|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = ((($0)) + 48|0);
   $30 = ($28|0)==($29|0);
   L4: do {
    if ($30) {
     $$0$lcssa = 0;$$040$lcssa = 0;$$042$lcssa = 0;$$043$lcssa = 0;
    } else {
     $$04078 = 0;$$04277 = 0;$$04376 = 0;$$079 = 0;$$sroa$063$075 = $28;
     while(1) {
      $90 = ((($$sroa$063$075)) + 48|0);
      $91 = HEAP32[$90>>2]|0;
      $92 = ((($91)) + 92|0);
      $$07$i = HEAP32[$92>>2]|0;
      $93 = ($$07$i|0)==(0|0);
      if ($93) {
       $$06$lcssa$i = 0;
      } else {
       $$068$i = 0;$$09$i = $$07$i;
       while(1) {
        $94 = (($$068$i) + 1)|0;
        $95 = ((($$09$i)) + 56|0);
        $$0$i = HEAP32[$95>>2]|0;
        $96 = ($$0$i|0)==(0|0);
        if ($96) {
         $$06$lcssa$i = $94;
         break;
        } else {
         $$068$i = $94;$$09$i = $$0$i;
        }
       }
      }
      $97 = (($$06$lcssa$i) + ($$079))|0;
      $98 = ((($91)) + 64|0);
      $99 = HEAP32[$98>>2]|0;
      $100 = (($99) + ($$04376))|0;
      $101 = ((($91)) + 76|0);
      $102 = HEAP32[$101>>2]|0;
      $103 = (($102) + ($$04277))|0;
      $104 = ((($91)) + 88|0);
      $105 = ((($91)) + 60|0);
      $106 = HEAP32[$105>>2]|0;
      if ($93) {
       $$06$lcssa$i51 = 0;
      } else {
       $$068$i48 = 0;$$09$i47 = $$07$i;
       while(1) {
        $107 = (($$068$i48) + 1)|0;
        $108 = ((($$09$i47)) + 56|0);
        $$0$i49 = HEAP32[$108>>2]|0;
        $109 = ($$0$i49|0)==(0|0);
        if ($109) {
         $$06$lcssa$i51 = $107;
         break;
        } else {
         $$068$i48 = $107;$$09$i47 = $$0$i49;
        }
       }
      }
      $110 = (($102) + ($$06$lcssa$i51))|0;
      $111 = Math_imul($110, $106)|0;
      $112 = (($111) + ($$04078))|0;
      $113 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($1,154214,8)|0);
      $114 = HEAP32[$105>>2]|0;
      $115 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($113,$114)|0);
      $116 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($115,154223,38)|0);
      $$07$i53 = HEAP32[$92>>2]|0;
      $117 = ($$07$i53|0)==(0|0);
      if ($117) {
       $$06$lcssa$i58 = 0;
      } else {
       $$068$i55 = 0;$$09$i54 = $$07$i53;
       while(1) {
        $118 = (($$068$i55) + 1)|0;
        $119 = ((($$09$i54)) + 56|0);
        $$0$i56 = HEAP32[$119>>2]|0;
        $120 = ($$0$i56|0)==(0|0);
        if ($120) {
         $$06$lcssa$i58 = $118;
         break;
        } else {
         $$068$i55 = $118;$$09$i54 = $$0$i56;
        }
       }
      }
      $121 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($116,$$06$lcssa$i58)|0);
      $122 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($121,154262,30)|0);
      $123 = HEAP32[$98>>2]|0;
      $124 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($122,$123)|0);
      $125 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($124,154293,21)|0);
      $126 = HEAP32[$101>>2]|0;
      $127 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($125,$126)|0);
      $128 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($127,154315,28)|0);
      $129 = HEAP32[$104>>2]|0;
      $130 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($128,$129)|0);
      $131 = HEAP32[$130>>2]|0;
      $132 = ((($131)) + -12|0);
      $133 = HEAP32[$132>>2]|0;
      $134 = (($130) + ($133)|0);
      __ZNKSt3__28ios_base6getlocEv($3,$134);
      __THREW__ = 0;
      $135 = (invoke_iii(3255,($3|0),(215188|0))|0);
      $136 = __THREW__; __THREW__ = 0;
      $137 = $136&1;
      if ($137) {
       break;
      }
      $138 = HEAP32[$135>>2]|0;
      $139 = ((($138)) + 28|0);
      $140 = HEAP32[$139>>2]|0;
      __THREW__ = 0;
      $141 = (invoke_iii($140|0,($135|0),10)|0);
      $142 = __THREW__; __THREW__ = 0;
      $143 = $142&1;
      if ($143) {
       break;
      }
      __ZNSt3__26localeD2Ev($3);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($130,$141)|0);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($130)|0);
      $150 = ((($$sroa$063$075)) + 4|0);
      $151 = HEAP32[$150>>2]|0;
      $152 = ($151|0)==(0|0);
      if ($152) {
       $153 = ((($$sroa$063$075)) + 8|0);
       $154 = HEAP32[$153>>2]|0;
       $155 = HEAP32[$154>>2]|0;
       $156 = ($155|0)==($$sroa$063$075|0);
       if ($156) {
        $$sroa$063$0$be = $154;
       } else {
        $161 = $153;
        while(1) {
         $160 = HEAP32[$161>>2]|0;
         $162 = ((($160)) + 8|0);
         $163 = HEAP32[$162>>2]|0;
         $164 = HEAP32[$163>>2]|0;
         $165 = ($164|0)==($160|0);
         if ($165) {
          $$sroa$063$0$be = $163;
          break;
         } else {
          $161 = $162;
         }
        }
       }
      } else {
       $$0$i$i$i$i = $151;
       while(1) {
        $158 = HEAP32[$$0$i$i$i$i>>2]|0;
        $159 = ($158|0)==(0|0);
        if ($159) {
         break;
        } else {
         $$0$i$i$i$i = $158;
        }
       }
       $$sroa$063$0$be = $$0$i$i$i$i;
      }
      $157 = ($$sroa$063$0$be|0)==($29|0);
      if ($157) {
       $$0$lcssa = $97;$$040$lcssa = $112;$$042$lcssa = $103;$$043$lcssa = $100;
       break L4;
      } else {
       $$04078 = $112;$$04277 = $103;$$04376 = $100;$$079 = $97;$$sroa$063$075 = $$sroa$063$0$be;
      }
     }
     $144 = ___cxa_find_matching_catch_2()|0;
     $145 = tempRet0;
     __THREW__ = 0;
     invoke_vi(3263,($3|0));
     $146 = __THREW__; __THREW__ = 0;
     $147 = $146&1;
     if ($147) {
      $148 = ___cxa_find_matching_catch_3(0|0)|0;
      $149 = tempRet0;
      ___clang_call_terminate($148);
      // unreachable;
     } else {
      ___resumeException($144|0);
      // unreachable;
     }
    }
   } while(0);
   $31 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($1,154102,21)|0);
   $32 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($31,$$0$lcssa)|0);
   $33 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($32,154124,12)|0);
   $34 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($33,$$043$lcssa)|0);
   $35 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($34,154137,13)|0);
   $36 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($35,$$042$lcssa)|0);
   $37 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($36,154151,13)|0);
   $38 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($37,$$040$lcssa)|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = ((($39)) + -12|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = (($38) + ($41)|0);
   __ZNKSt3__28ios_base6getlocEv($5,$42);
   __THREW__ = 0;
   $43 = (invoke_iii(3255,($5|0),(215188|0))|0);
   $44 = __THREW__; __THREW__ = 0;
   $45 = $44&1;
   if (!($45)) {
    $46 = HEAP32[$43>>2]|0;
    $47 = ((($46)) + 28|0);
    $48 = HEAP32[$47>>2]|0;
    __THREW__ = 0;
    $49 = (invoke_iii($48|0,($43|0),10)|0);
    $50 = __THREW__; __THREW__ = 0;
    $51 = $50&1;
    if (!($51)) {
     __ZNSt3__26localeD2Ev($5);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($38,$49)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($38)|0);
     $58 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($1,154165,27)|0);
     $59 = ((($0)) + 40|0);
     $60 = HEAP32[$59>>2]|0;
     $61 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($58,$60)|0);
     $62 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($61,154193,20)|0);
     $63 = (+($$040$lcssa>>>0));
     $64 = HEAP32[$59>>2]|0;
     $65 = (+($64>>>0));
     $66 = $63 / $65;
     $67 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEd($62,$66)|0);
     $68 = HEAP32[$67>>2]|0;
     $69 = ((($68)) + -12|0);
     $70 = HEAP32[$69>>2]|0;
     $71 = (($67) + ($70)|0);
     __ZNKSt3__28ios_base6getlocEv($4,$71);
     __THREW__ = 0;
     $72 = (invoke_iii(3255,($4|0),(215188|0))|0);
     $73 = __THREW__; __THREW__ = 0;
     $74 = $73&1;
     if (!($74)) {
      $75 = HEAP32[$72>>2]|0;
      $76 = ((($75)) + 28|0);
      $77 = HEAP32[$76>>2]|0;
      __THREW__ = 0;
      $78 = (invoke_iii($77|0,($72|0),10)|0);
      $79 = __THREW__; __THREW__ = 0;
      $80 = $79&1;
      if (!($80)) {
       __ZNSt3__26localeD2Ev($4);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($67,$78)|0);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($67)|0);
       $87 = ((($0)) + 36|0);
       $88 = HEAP32[$87>>2]|0;
       $89 = ($$040$lcssa|0)==($88|0);
       if ($89) {
        STACKTOP = sp;return;
       }
       $166 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($1,154344,33)|0);
       $167 = HEAP32[$87>>2]|0;
       $168 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($166,$167)|0);
       $169 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($168,154378,26)|0);
       $170 = HEAP32[$87>>2]|0;
       $171 = (($170) - ($$040$lcssa))|0;
       $172 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi($169,$171)|0);
       $173 = HEAP32[$172>>2]|0;
       $174 = ((($173)) + -12|0);
       $175 = HEAP32[$174>>2]|0;
       $176 = (($172) + ($175)|0);
       __ZNKSt3__28ios_base6getlocEv($2,$176);
       __THREW__ = 0;
       $177 = (invoke_iii(3255,($2|0),(215188|0))|0);
       $178 = __THREW__; __THREW__ = 0;
       $179 = $178&1;
       if (!($179)) {
        $180 = HEAP32[$177>>2]|0;
        $181 = ((($180)) + 28|0);
        $182 = HEAP32[$181>>2]|0;
        __THREW__ = 0;
        $183 = (invoke_iii($182|0,($177|0),10)|0);
        $184 = __THREW__; __THREW__ = 0;
        $185 = $184&1;
        if (!($185)) {
         __ZNSt3__26localeD2Ev($2);
         (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($172,$183)|0);
         (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($172)|0);
         STACKTOP = sp;return;
        }
       }
       $186 = ___cxa_find_matching_catch_2()|0;
       $187 = tempRet0;
       __THREW__ = 0;
       invoke_vi(3263,($2|0));
       $188 = __THREW__; __THREW__ = 0;
       $189 = $188&1;
       if ($189) {
        $190 = ___cxa_find_matching_catch_3(0|0)|0;
        $191 = tempRet0;
        ___clang_call_terminate($190);
        // unreachable;
       } else {
        ___resumeException($186|0);
        // unreachable;
       }
      }
     }
     $81 = ___cxa_find_matching_catch_2()|0;
     $82 = tempRet0;
     __THREW__ = 0;
     invoke_vi(3263,($4|0));
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if ($84) {
      $85 = ___cxa_find_matching_catch_3(0|0)|0;
      $86 = tempRet0;
      ___clang_call_terminate($85);
      // unreachable;
     } else {
      ___resumeException($81|0);
      // unreachable;
     }
    }
   }
   $52 = ___cxa_find_matching_catch_2()|0;
   $53 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($5|0));
   $54 = __THREW__; __THREW__ = 0;
   $55 = $54&1;
   if ($55) {
    $56 = ___cxa_find_matching_catch_3(0|0)|0;
    $57 = tempRet0;
    ___clang_call_terminate($56);
    // unreachable;
   } else {
    ___resumeException($52|0);
    // unreachable;
   }
  }
 }
 $21 = ___cxa_find_matching_catch_2()|0;
 $22 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($6|0));
 $23 = __THREW__; __THREW__ = 0;
 $24 = $23&1;
 if ($24) {
  $25 = ___cxa_find_matching_catch_3(0|0)|0;
  $26 = tempRet0;
  ___clang_call_terminate($25);
  // unreachable;
 } else {
  ___resumeException($21|0);
  // unreachable;
 }
}
function __ZN3osg20TextureObjectManager21flushDeletedGLObjectsEdRd($0,$1,$2) {
 $0 = $0|0;
 $1 = +$1;
 $2 = $2|0;
 var $$0$i$i$i$i = 0, $$sroa$06$0$be = 0, $$sroa$06$012 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0.0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0.0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond11 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 44|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 48|0);
 $6 = ($4|0)!=($5|0);
 $7 = +HEAPF64[$2>>3];
 $8 = $7 > 0.0;
 $or$cond11 = $6 & $8;
 if ($or$cond11) {
  $$sroa$06$012 = $4;
 } else {
  return;
 }
 while(1) {
  $9 = ((($$sroa$06$012)) + 48|0);
  $10 = HEAP32[$9>>2]|0;
  __ZN3osg16TextureObjectSet26flushDeletedTextureObjectsEdRd($10,0.0,$2);
  $11 = ((($$sroa$06$012)) + 4|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($12|0)==(0|0);
  if ($13) {
   $14 = ((($$sroa$06$012)) + 8|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = HEAP32[$15>>2]|0;
   $17 = ($16|0)==($$sroa$06$012|0);
   if ($17) {
    $$sroa$06$0$be = $15;
   } else {
    $24 = $14;
    while(1) {
     $23 = HEAP32[$24>>2]|0;
     $25 = ((($23)) + 8|0);
     $26 = HEAP32[$25>>2]|0;
     $27 = HEAP32[$26>>2]|0;
     $28 = ($27|0)==($23|0);
     if ($28) {
      $$sroa$06$0$be = $26;
      break;
     } else {
      $24 = $25;
     }
    }
   }
  } else {
   $$0$i$i$i$i = $12;
   while(1) {
    $21 = HEAP32[$$0$i$i$i$i>>2]|0;
    $22 = ($21|0)==(0|0);
    if ($22) {
     break;
    } else {
     $$0$i$i$i$i = $21;
    }
   }
   $$sroa$06$0$be = $$0$i$i$i$i;
  }
  $18 = ($$sroa$06$0$be|0)!=($5|0);
  $19 = +HEAPF64[$2>>3];
  $20 = $19 > 0.0;
  $or$cond = $18 & $20;
  if ($or$cond) {
   $$sroa$06$012 = $$sroa$06$0$be;
  } else {
   break;
  }
 }
 return;
}
function __ZN3osg20TextureObjectManager24flushAllDeletedGLObjectsEv($0) {
 $0 = $0|0;
 var $$0$i$i$i$i = 0, $$sroa$02$0$be = 0, $$sroa$02$06 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 44|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 48|0);
 $4 = ($2|0)==($3|0);
 if ($4) {
  return;
 } else {
  $$sroa$02$06 = $2;
 }
 while(1) {
  $5 = ((($$sroa$02$06)) + 48|0);
  $6 = HEAP32[$5>>2]|0;
  __ZN3osg16TextureObjectSet29flushAllDeletedTextureObjectsEv($6);
  $7 = ((($$sroa$02$06)) + 4|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)==(0|0);
  if ($9) {
   $10 = ((($$sroa$02$06)) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = HEAP32[$11>>2]|0;
   $13 = ($12|0)==($$sroa$02$06|0);
   if ($13) {
    $$sroa$02$0$be = $11;
   } else {
    $18 = $10;
    while(1) {
     $17 = HEAP32[$18>>2]|0;
     $19 = ((($17)) + 8|0);
     $20 = HEAP32[$19>>2]|0;
     $21 = HEAP32[$20>>2]|0;
     $22 = ($21|0)==($17|0);
     if ($22) {
      $$sroa$02$0$be = $20;
      break;
     } else {
      $18 = $19;
     }
    }
   }
  } else {
   $$0$i$i$i$i = $8;
   while(1) {
    $15 = HEAP32[$$0$i$i$i$i>>2]|0;
    $16 = ($15|0)==(0|0);
    if ($16) {
     break;
    } else {
     $$0$i$i$i$i = $15;
    }
   }
   $$sroa$02$0$be = $$0$i$i$i$i;
  }
  $14 = ($$sroa$02$0$be|0)==($3|0);
  if ($14) {
   break;
  } else {
   $$sroa$02$06 = $$sroa$02$0$be;
  }
 }
 return;
}
function __ZN3osg20TextureObjectManager18deleteAllGLObjectsEv($0) {
 $0 = $0|0;
 var $$0$i$i$i$i = 0, $$sroa$02$0$be = 0, $$sroa$02$06 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 44|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 48|0);
 $4 = ($2|0)==($3|0);
 if ($4) {
  return;
 } else {
  $$sroa$02$06 = $2;
 }
 while(1) {
  $5 = ((($$sroa$02$06)) + 48|0);
  $6 = HEAP32[$5>>2]|0;
  __ZN3osg16TextureObjectSet23deleteAllTextureObjectsEv($6);
  $7 = ((($$sroa$02$06)) + 4|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)==(0|0);
  if ($9) {
   $10 = ((($$sroa$02$06)) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = HEAP32[$11>>2]|0;
   $13 = ($12|0)==($$sroa$02$06|0);
   if ($13) {
    $$sroa$02$0$be = $11;
   } else {
    $18 = $10;
    while(1) {
     $17 = HEAP32[$18>>2]|0;
     $19 = ((($17)) + 8|0);
     $20 = HEAP32[$19>>2]|0;
     $21 = HEAP32[$20>>2]|0;
     $22 = ($21|0)==($17|0);
     if ($22) {
      $$sroa$02$0$be = $20;
      break;
     } else {
      $18 = $19;
     }
    }
   }
  } else {
   $$0$i$i$i$i = $8;
   while(1) {
    $15 = HEAP32[$$0$i$i$i$i>>2]|0;
    $16 = ($15|0)==(0|0);
    if ($16) {
     break;
    } else {
     $$0$i$i$i$i = $15;
    }
   }
   $$sroa$02$0$be = $$0$i$i$i$i;
  }
  $14 = ($$sroa$02$0$be|0)==($3|0);
  if ($14) {
   break;
  } else {
   $$sroa$02$06 = $$sroa$02$0$be;
  }
 }
 return;
}
function __ZN3osg20TextureObjectManager19discardAllGLObjectsEv($0) {
 $0 = $0|0;
 var $$0$i$i$i$i = 0, $$sroa$02$0$be = 0, $$sroa$02$06 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 44|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 48|0);
 $4 = ($2|0)==($3|0);
 if ($4) {
  return;
 } else {
  $$sroa$02$06 = $2;
 }
 while(1) {
  $5 = ((($$sroa$02$06)) + 48|0);
  $6 = HEAP32[$5>>2]|0;
  __ZN3osg16TextureObjectSet24discardAllTextureObjectsEv($6);
  $7 = ((($$sroa$02$06)) + 4|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)==(0|0);
  if ($9) {
   $10 = ((($$sroa$02$06)) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = HEAP32[$11>>2]|0;
   $13 = ($12|0)==($$sroa$02$06|0);
   if ($13) {
    $$sroa$02$0$be = $11;
   } else {
    $18 = $10;
    while(1) {
     $17 = HEAP32[$18>>2]|0;
     $19 = ((($17)) + 8|0);
     $20 = HEAP32[$19>>2]|0;
     $21 = HEAP32[$20>>2]|0;
     $22 = ($21|0)==($17|0);
     if ($22) {
      $$sroa$02$0$be = $20;
      break;
     } else {
      $18 = $19;
     }
    }
   }
  } else {
   $$0$i$i$i$i = $8;
   while(1) {
    $15 = HEAP32[$$0$i$i$i$i>>2]|0;
    $16 = ($15|0)==(0|0);
    if ($16) {
     break;
    } else {
     $$0$i$i$i$i = $15;
    }
   }
   $$sroa$02$0$be = $$0$i$i$i$i;
  }
  $14 = ($$sroa$02$0$be|0)==($3|0);
  if ($14) {
   break;
  } else {
   $$sroa$02$06 = $$sroa$02$0$be;
  }
 }
 return;
}
function __ZN3osg16TextureObjectSet24discardAllTextureObjectsEv($0) {
 $0 = $0|0;
 var $$012 = 0, $$013 = 0, $$023$i$i = 0, $$023$i$i15 = 0, $$040 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 92|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 L1: do {
  if (!($3)) {
   $4 = ((($0)) + 28|0);
   $$040 = $2;
   L3: while(1) {
    $5 = ((($$040)) + 8|0);
    $6 = HEAP32[$5>>2]|0;HEAP32[$5>>2] = (($6+1)|0);
    $7 = ((($$040)) + 56|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = ((($$040)) + 60|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = ($10|0)==(0|0);
    if (!($11)) {
     $12 = ((($10)) + 8|0);
     $13 = HEAP32[$12>>2]|0;HEAP32[$12>>2] = (($13+1)|0);
     $14 = HEAP32[$4>>2]|0;
     $15 = ((($10)) + 224|0);
     $16 = ((($10)) + 228|0);
     $17 = HEAP32[$16>>2]|0;
     $18 = HEAP32[$15>>2]|0;
     $19 = (($17) - ($18))|0;
     $20 = $19 >> 2;
     $21 = ($20>>>0)>($14>>>0);
     do {
      if (!($21)) {
       $22 = (($14) + 1)|0;
       $23 = ($22>>>0)>($20>>>0);
       $24 = $18;
       $25 = $17;
       if ($23) {
        $26 = (($22) - ($20))|0;
        __THREW__ = 0;
        invoke_vii(3967,($15|0),($26|0));
        $27 = __THREW__; __THREW__ = 0;
        $28 = $27&1;
        if ($28) {
         label = 17;
         break L3;
        } else {
         break;
        }
       }
       $29 = ($22>>>0)<($20>>>0);
       if ($29) {
        $30 = (($24) + ($22<<2)|0);
        $31 = ($25|0)==($30|0);
        if (!($31)) {
         $33 = $25;
         while(1) {
          $32 = ((($33)) + -4|0);
          HEAP32[$16>>2] = $32;
          $34 = HEAP32[$32>>2]|0;
          $35 = ($34|0)==(0|0);
          if (!($35)) {
           $36 = ((($34)) + 8|0);
           $37 = HEAP32[$36>>2]|0;HEAP32[$36>>2] = (($37-1)|0);
           $38 = ($37|0)==(1);
           if ($38) {
            __THREW__ = 0;
            invoke_viii(3262,($34|0),1,1);
            $39 = __THREW__; __THREW__ = 0;
            $40 = $39&1;
            if ($40) {
             label = 13;
             break L3;
            }
           }
          }
          HEAP32[$32>>2] = 0;
          $41 = HEAP32[$16>>2]|0;
          $42 = ($41|0)==($30|0);
          if ($42) {
           break;
          } else {
           $33 = $41;
          }
         }
        }
       }
      }
     } while(0);
     $45 = HEAP32[$15>>2]|0;
     $46 = (($45) + ($14<<2)|0);
     $47 = HEAP32[$46>>2]|0;
     $48 = ($47|0)==(0|0);
     if (!($48)) {
      HEAP32[$46>>2] = 0;
      $49 = ((($47)) + 8|0);
      $50 = HEAP32[$49>>2]|0;HEAP32[$49>>2] = (($50-1)|0);
      $51 = ($50|0)==(1);
      if ($51) {
       __THREW__ = 0;
       invoke_viii(3262,($47|0),1,1);
       $52 = __THREW__; __THREW__ = 0;
       $53 = $52&1;
       if ($53) {
        label = 17;
        break;
       }
      }
     }
     $60 = HEAP32[$12>>2]|0;HEAP32[$12>>2] = (($60-1)|0);
     $61 = ($60|0)==(1);
     if ($61) {
      __THREW__ = 0;
      invoke_viii(3262,($10|0),1,1);
      $62 = __THREW__; __THREW__ = 0;
      $63 = $62&1;
      if ($63) {
       label = 24;
       break;
      }
     }
    }
    $64 = HEAP32[$5>>2]|0;HEAP32[$5>>2] = (($64-1)|0);
    $65 = ($64|0)==(1);
    if ($65) {
     __ZNK3osg10Referenced24signalObserversAndDeleteEbb($$040,1,1);
    }
    $66 = ($8|0)==(0|0);
    if ($66) {
     break L1;
    } else {
     $$040 = $8;
    }
   }
   if ((label|0) == 13) {
    $43 = ___cxa_find_matching_catch_2()|0;
    $44 = tempRet0;
    ___cxa_call_unexpected(($43|0));
    // unreachable;
   }
   else if ((label|0) == 17) {
    $54 = ___cxa_find_matching_catch_2()|0;
    $55 = tempRet0;
    $56 = HEAP32[$12>>2]|0;HEAP32[$12>>2] = (($56-1)|0);
    $57 = ($56|0)==(1);
    if ($57) {
     __THREW__ = 0;
     invoke_viii(3262,($10|0),1,1);
     $58 = __THREW__; __THREW__ = 0;
     $59 = $58&1;
     if ($59) {
      $142 = ___cxa_find_matching_catch_3(0|0)|0;
      $143 = tempRet0;
      ___clang_call_terminate($142);
      // unreachable;
     } else {
      $$012 = $55;$$013 = $54;
     }
    } else {
     $$012 = $55;$$013 = $54;
    }
   }
   else if ((label|0) == 24) {
    $67 = ___cxa_find_matching_catch_2()|0;
    $68 = tempRet0;
    $$012 = $68;$$013 = $67;
   }
   $69 = HEAP32[$5>>2]|0;HEAP32[$5>>2] = (($69-1)|0);
   $70 = ($69|0)==(1);
   if (!($70)) {
    ___resumeException($$013|0);
    // unreachable;
   }
   __THREW__ = 0;
   invoke_viii(3262,($$040|0),1,1);
   $71 = __THREW__; __THREW__ = 0;
   $72 = $71&1;
   if ($72) {
    $142 = ___cxa_find_matching_catch_3(0|0)|0;
    $143 = tempRet0;
    ___clang_call_terminate($142);
    // unreachable;
   } else {
    ___resumeException($$013|0);
    // unreachable;
   }
  }
 } while(0);
 HEAP32[$1>>2] = 0;
 $73 = ((($0)) + 96|0);
 HEAP32[$73>>2] = 0;
 $74 = ((($0)) + 80|0);
 $75 = ((($0)) + 88|0);
 $76 = HEAP32[$75>>2]|0;
 $77 = ($76|0)==(0);
 L43: do {
  if (!($77)) {
   $78 = ((($0)) + 84|0);
   $79 = HEAP32[$78>>2]|0;
   $80 = HEAP32[$74>>2]|0;
   $81 = ((($80)) + 4|0);
   $82 = HEAP32[$81>>2]|0;
   $83 = HEAP32[$79>>2]|0;
   $84 = ((($83)) + 4|0);
   HEAP32[$84>>2] = $82;
   $85 = HEAP32[$81>>2]|0;
   HEAP32[$85>>2] = $83;
   HEAP32[$75>>2] = 0;
   $86 = ($79|0)==($74|0);
   if (!($86)) {
    $$023$i$i15 = $79;
    while(1) {
     $87 = ((($$023$i$i15)) + 4|0);
     $88 = HEAP32[$87>>2]|0;
     $89 = ((($$023$i$i15)) + 8|0);
     $90 = HEAP32[$89>>2]|0;
     $91 = ($90|0)==(0|0);
     if (!($91)) {
      $92 = ((($90)) + 8|0);
      $93 = HEAP32[$92>>2]|0;HEAP32[$92>>2] = (($93-1)|0);
      $94 = ($93|0)==(1);
      if ($94) {
       __THREW__ = 0;
       invoke_viii(3262,($90|0),1,1);
       $95 = __THREW__; __THREW__ = 0;
       $96 = $95&1;
       if ($96) {
        break;
       }
      }
     }
     __ZdlPv($$023$i$i15);
     $97 = ($88|0)==($74|0);
     if ($97) {
      break L43;
     } else {
      $$023$i$i15 = $88;
     }
    }
    $98 = ___cxa_find_matching_catch_2()|0;
    $99 = tempRet0;
    ___cxa_call_unexpected(($98|0));
    // unreachable;
   }
  }
 } while(0);
 $100 = ((($0)) + 68|0);
 $101 = ((($0)) + 76|0);
 $102 = HEAP32[$101>>2]|0;
 $103 = ($102|0)==(0);
 L53: do {
  if (!($103)) {
   $104 = ((($0)) + 72|0);
   $105 = HEAP32[$104>>2]|0;
   $106 = HEAP32[$100>>2]|0;
   $107 = ((($106)) + 4|0);
   $108 = HEAP32[$107>>2]|0;
   $109 = HEAP32[$105>>2]|0;
   $110 = ((($109)) + 4|0);
   HEAP32[$110>>2] = $108;
   $111 = HEAP32[$107>>2]|0;
   HEAP32[$111>>2] = $109;
   HEAP32[$101>>2] = 0;
   $112 = ($105|0)==($100|0);
   if (!($112)) {
    $$023$i$i = $105;
    while(1) {
     $113 = ((($$023$i$i)) + 4|0);
     $114 = HEAP32[$113>>2]|0;
     $115 = ((($$023$i$i)) + 8|0);
     $116 = HEAP32[$115>>2]|0;
     $117 = ($116|0)==(0|0);
     if (!($117)) {
      $118 = ((($116)) + 8|0);
      $119 = HEAP32[$118>>2]|0;HEAP32[$118>>2] = (($119-1)|0);
      $120 = ($119|0)==(1);
      if ($120) {
       __THREW__ = 0;
       invoke_viii(3262,($116|0),1,1);
       $121 = __THREW__; __THREW__ = 0;
       $122 = $121&1;
       if ($122) {
        break;
       }
      }
     }
     __ZdlPv($$023$i$i);
     $123 = ($114|0)==($100|0);
     if ($123) {
      break L53;
     } else {
      $$023$i$i = $114;
     }
    }
    $124 = ___cxa_find_matching_catch_2()|0;
    $125 = tempRet0;
    ___cxa_call_unexpected(($124|0));
    // unreachable;
   }
  }
 } while(0);
 $126 = ((($0)) + 64|0);
 $127 = HEAP32[$126>>2]|0;
 HEAP32[$126>>2] = 0;
 $128 = ((($0)) + 60|0);
 $129 = HEAP32[$128>>2]|0;
 $130 = Math_imul($129, $127)|0;
 $131 = ((($0)) + 24|0);
 $132 = HEAP32[$131>>2]|0;
 $133 = ((($132)) + 36|0);
 $134 = HEAP32[$133>>2]|0;
 $135 = (($134) - ($130))|0;
 HEAP32[$133>>2] = $135;
 $136 = ((($132)) + 32|0);
 $137 = HEAP32[$136>>2]|0;
 $138 = (($137) - ($127))|0;
 HEAP32[$136>>2] = $138;
 $139 = ((($132)) + 64|0);
 $140 = HEAP32[$139>>2]|0;
 $141 = (($140) + ($127))|0;
 HEAP32[$139>>2] = $141;
 return;
}
function __ZN3osg16TextureObjectSet23deleteAllTextureObjectsEv($0) {
 $0 = $0|0;
 var $$013$lcssa = 0, $$01365 = 0, $$066 = 0, $$2 = 0, $$217 = 0, $$3 = 0, $$318 = 0, $$pre$i = 0, $$sink$i = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 (FUNCTION_TABLE_ii[$4 & 8191]($1)|0);
 $5 = ((($0)) + 88|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if (!($7)) {
  __THREW__ = 0;
  invoke_vi(3976,($0|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if ($9) {
   $10 = ___cxa_find_matching_catch_2()|0;
   $11 = tempRet0;
   $12 = HEAP32[$1>>2]|0;
   $13 = ((($12)) + 12|0);
   $14 = HEAP32[$13>>2]|0;
   __THREW__ = 0;
   (invoke_ii($14|0,($1|0))|0);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if ($16) {
    $136 = ___cxa_find_matching_catch_3(0|0)|0;
    $137 = tempRet0;
    ___clang_call_terminate($136);
    // unreachable;
   }
   $$3 = $11;$$318 = $10;
   ___resumeException($$318|0);
   // unreachable;
  }
 }
 $17 = HEAP32[$1>>2]|0;
 $18 = ((($17)) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 (FUNCTION_TABLE_ii[$19 & 8191]($1)|0);
 $20 = ((($0)) + 92|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0|0);
 if ($22) {
  $$013$lcssa = 0;
  $128 = ((($0)) + 24|0);
  $129 = HEAP32[$128>>2]|0;
  $130 = ((($129)) + 32|0);
  $131 = HEAP32[$130>>2]|0;
  $132 = (($131) + ($$013$lcssa))|0;
  HEAP32[$130>>2] = $132;
  $133 = ((($129)) + 28|0);
  $134 = HEAP32[$133>>2]|0;
  $135 = (($134) - ($$013$lcssa))|0;
  HEAP32[$133>>2] = $135;
  __ZN3osg16TextureObjectSet29flushAllDeletedTextureObjectsEv($0);
  return;
 }
 $23 = ((($0)) + 68|0);
 $24 = ((($0)) + 76|0);
 $25 = ((($0)) + 96|0);
 $26 = ((($0)) + 28|0);
 $$01365 = 0;$$066 = $21;
 L12: while(1) {
  $27 = ((($$066)) + 8|0);
  $28 = HEAP32[$27>>2]|0;HEAP32[$27>>2] = (($28+1)|0);
  $29 = ((($$066)) + 56|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = HEAP32[$27>>2]|0;HEAP32[$27>>2] = (($31+1)|0);
  __THREW__ = 0;
  $32 = (invoke_ii(3276,12)|0);
  $33 = __THREW__; __THREW__ = 0;
  $34 = $33&1;
  if ($34) {
   label = 28;
   break;
  }
  $35 = ((($32)) + 8|0);
  HEAP32[$35>>2] = $$066;
  $36 = HEAP32[$27>>2]|0;HEAP32[$27>>2] = (($36+1)|0);
  $37 = ((($32)) + 4|0);
  HEAP32[$37>>2] = $23;
  $38 = HEAP32[$23>>2]|0;
  HEAP32[$32>>2] = $38;
  $39 = ((($38)) + 4|0);
  HEAP32[$39>>2] = $32;
  HEAP32[$23>>2] = $32;
  $40 = HEAP32[$24>>2]|0;
  $41 = (($40) + 1)|0;
  HEAP32[$24>>2] = $41;
  $42 = HEAP32[$27>>2]|0;HEAP32[$27>>2] = (($42-1)|0);
  $43 = ($42|0)==(1);
  if ($43) {
   __THREW__ = 0;
   invoke_viii(3262,($$066|0),1,1);
   $44 = __THREW__; __THREW__ = 0;
   $45 = $44&1;
   if ($45) {
    label = 27;
    break;
   }
  }
  $46 = ((($$066)) + 52|0);
  $47 = HEAP32[$46>>2]|0;
  $48 = ($47|0)==(0|0);
  $49 = HEAP32[$29>>2]|0;
  if ($48) {
   $51 = $49;
   HEAP32[$20>>2] = $49;
   $52 = $51;
  } else {
   $50 = ((($47)) + 56|0);
   HEAP32[$50>>2] = $49;
   $$pre$i = HEAP32[$29>>2]|0;
   $52 = $$pre$i;
  }
  $53 = ($52|0)==(0|0);
  $54 = ((($52)) + 52|0);
  $$sink$i = $53 ? $25 : $54;
  HEAP32[$$sink$i>>2] = $47;
  HEAP32[$29>>2] = 0;
  HEAP32[$46>>2] = 0;
  $55 = (($$01365) + 1)|0;
  $56 = ((($$066)) + 60|0);
  $57 = HEAP32[$56>>2]|0;
  $58 = ($57|0)==(0|0);
  if (!($58)) {
   $59 = ((($57)) + 8|0);
   $60 = HEAP32[$59>>2]|0;HEAP32[$59>>2] = (($60+1)|0);
   $61 = HEAP32[$26>>2]|0;
   $62 = ((($57)) + 224|0);
   $63 = ((($57)) + 228|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = HEAP32[$62>>2]|0;
   $66 = (($64) - ($65))|0;
   $67 = $66 >> 2;
   $68 = ($67>>>0)>($61>>>0);
   do {
    if (!($68)) {
     $69 = (($61) + 1)|0;
     $70 = ($69>>>0)>($67>>>0);
     $71 = $65;
     $72 = $64;
     if ($70) {
      $73 = (($69) - ($67))|0;
      __THREW__ = 0;
      invoke_vii(3967,($62|0),($73|0));
      $74 = __THREW__; __THREW__ = 0;
      $75 = $74&1;
      if ($75) {
       label = 30;
       break L12;
      } else {
       break;
      }
     }
     $76 = ($69>>>0)<($67>>>0);
     if ($76) {
      $77 = (($71) + ($69<<2)|0);
      $78 = ($72|0)==($77|0);
      if (!($78)) {
       $80 = $72;
       while(1) {
        $79 = ((($80)) + -4|0);
        HEAP32[$63>>2] = $79;
        $81 = HEAP32[$79>>2]|0;
        $82 = ($81|0)==(0|0);
        if (!($82)) {
         $83 = ((($81)) + 8|0);
         $84 = HEAP32[$83>>2]|0;HEAP32[$83>>2] = (($84-1)|0);
         $85 = ($84|0)==(1);
         if ($85) {
          __THREW__ = 0;
          invoke_viii(3262,($81|0),1,1);
          $86 = __THREW__; __THREW__ = 0;
          $87 = $86&1;
          if ($87) {
           label = 22;
           break L12;
          }
         }
        }
        HEAP32[$79>>2] = 0;
        $88 = HEAP32[$63>>2]|0;
        $89 = ($88|0)==($77|0);
        if ($89) {
         break;
        } else {
         $80 = $88;
        }
       }
      }
     }
    }
   } while(0);
   $92 = HEAP32[$62>>2]|0;
   $93 = (($92) + ($61<<2)|0);
   $94 = HEAP32[$93>>2]|0;
   $95 = ($94|0)==(0|0);
   if (!($95)) {
    HEAP32[$93>>2] = 0;
    $96 = ((($94)) + 8|0);
    $97 = HEAP32[$96>>2]|0;HEAP32[$96>>2] = (($97-1)|0);
    $98 = ($97|0)==(1);
    if ($98) {
     __THREW__ = 0;
     invoke_viii(3262,($94|0),1,1);
     $99 = __THREW__; __THREW__ = 0;
     $100 = $99&1;
     if ($100) {
      label = 30;
      break;
     }
    }
   }
   $115 = HEAP32[$59>>2]|0;HEAP32[$59>>2] = (($115-1)|0);
   $116 = ($115|0)==(1);
   if ($116) {
    __THREW__ = 0;
    invoke_viii(3262,($57|0),1,1);
    $117 = __THREW__; __THREW__ = 0;
    $118 = $117&1;
    if ($118) {
     label = 37;
     break;
    }
   }
  }
  $119 = HEAP32[$27>>2]|0;HEAP32[$27>>2] = (($119-1)|0);
  $120 = ($119|0)==(1);
  if ($120) {
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($$066,1,1);
  }
  $121 = ($30|0)==(0|0);
  if ($121) {
   $$013$lcssa = $55;
   label = 40;
   break;
  } else {
   $$01365 = $55;$$066 = $30;
  }
 }
 if ((label|0) == 22) {
  $90 = ___cxa_find_matching_catch_2()|0;
  $91 = tempRet0;
  ___cxa_call_unexpected(($90|0));
  // unreachable;
 }
 else if ((label|0) == 27) {
  $101 = ___cxa_find_matching_catch_2()|0;
  $102 = tempRet0;
  $$2 = $102;$$217 = $101;
 }
 else if ((label|0) == 28) {
  $103 = ___cxa_find_matching_catch_2()|0;
  $104 = tempRet0;
  $105 = HEAP32[$27>>2]|0;HEAP32[$27>>2] = (($105-1)|0);
  $106 = ($105|0)==(1);
  if ($106) {
   __THREW__ = 0;
   invoke_viii(3262,($$066|0),1,1);
   $107 = __THREW__; __THREW__ = 0;
   $108 = $107&1;
   if ($108) {
    $136 = ___cxa_find_matching_catch_3(0|0)|0;
    $137 = tempRet0;
    ___clang_call_terminate($136);
    // unreachable;
   } else {
    $$2 = $104;$$217 = $103;
   }
  } else {
   $$2 = $104;$$217 = $103;
  }
 }
 else if ((label|0) == 30) {
  $109 = ___cxa_find_matching_catch_2()|0;
  $110 = tempRet0;
  $111 = HEAP32[$59>>2]|0;HEAP32[$59>>2] = (($111-1)|0);
  $112 = ($111|0)==(1);
  if ($112) {
   __THREW__ = 0;
   invoke_viii(3262,($57|0),1,1);
   $113 = __THREW__; __THREW__ = 0;
   $114 = $113&1;
   if ($114) {
    $136 = ___cxa_find_matching_catch_3(0|0)|0;
    $137 = tempRet0;
    ___clang_call_terminate($136);
    // unreachable;
   } else {
    $$2 = $110;$$217 = $109;
   }
  } else {
   $$2 = $110;$$217 = $109;
  }
 }
 else if ((label|0) == 37) {
  $122 = ___cxa_find_matching_catch_2()|0;
  $123 = tempRet0;
  $$2 = $123;$$217 = $122;
 }
 else if ((label|0) == 40) {
  $128 = ((($0)) + 24|0);
  $129 = HEAP32[$128>>2]|0;
  $130 = ((($129)) + 32|0);
  $131 = HEAP32[$130>>2]|0;
  $132 = (($131) + ($$013$lcssa))|0;
  HEAP32[$130>>2] = $132;
  $133 = ((($129)) + 28|0);
  $134 = HEAP32[$133>>2]|0;
  $135 = (($134) - ($$013$lcssa))|0;
  HEAP32[$133>>2] = $135;
  __ZN3osg16TextureObjectSet29flushAllDeletedTextureObjectsEv($0);
  return;
 }
 $124 = HEAP32[$27>>2]|0;HEAP32[$27>>2] = (($124-1)|0);
 $125 = ($124|0)==(1);
 if (!($125)) {
  $$3 = $$2;$$318 = $$217;
  ___resumeException($$318|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(3262,($$066|0),1,1);
 $126 = __THREW__; __THREW__ = 0;
 $127 = $126&1;
 if ($127) {
  $136 = ___cxa_find_matching_catch_3(0|0)|0;
  $137 = tempRet0;
  ___clang_call_terminate($136);
  // unreachable;
 } else {
  $$3 = $$2;$$318 = $$217;
  ___resumeException($$318|0);
  // unreachable;
 }
}
function __ZN3osg16TextureObjectSet36handlePendingOrphandedTextureObjectsEv($0) {
 $0 = $0|0;
 var $$023$i$i = 0, $$pre$i = 0, $$sink$i = 0, $$sroa$019$0 = 0, $$sroa$019$028 = 0, $$sroa$019$029 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 80|0);
 $2 = ((($0)) + 88|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  return;
 }
 $5 = ((($0)) + 84|0);
 $$sroa$019$028 = HEAP32[$5>>2]|0;
 $6 = $$sroa$019$028;
 $7 = ($6|0)==($1|0);
 L4: do {
  if (!($7)) {
   $8 = ((($0)) + 68|0);
   $9 = ((($0)) + 76|0);
   $10 = ((($0)) + 92|0);
   $11 = ((($0)) + 96|0);
   $$sroa$019$029 = $$sroa$019$028;$74 = $6;
   while(1) {
    $43 = $$sroa$019$029;
    $44 = ((($43)) + 8|0);
    $45 = HEAP32[$44>>2]|0;
    $46 = ($45|0)==(0|0);
    if (!($46)) {
     $47 = ((($45)) + 8|0);
     $48 = HEAP32[$47>>2]|0;HEAP32[$47>>2] = (($48+1)|0);
    }
    __THREW__ = 0;
    $49 = (invoke_ii(3276,12)|0);
    $50 = __THREW__; __THREW__ = 0;
    $51 = $50&1;
    if ($51) {
     break;
    }
    $52 = ((($49)) + 8|0);
    HEAP32[$52>>2] = $45;
    if (!($46)) {
     $53 = ((($45)) + 8|0);
     $54 = HEAP32[$53>>2]|0;HEAP32[$53>>2] = (($54+1)|0);
    }
    $55 = ((($49)) + 4|0);
    HEAP32[$55>>2] = $8;
    $56 = HEAP32[$8>>2]|0;
    HEAP32[$49>>2] = $56;
    $57 = ((($56)) + 4|0);
    HEAP32[$57>>2] = $49;
    HEAP32[$8>>2] = $49;
    $58 = HEAP32[$9>>2]|0;
    $59 = (($58) + 1)|0;
    HEAP32[$9>>2] = $59;
    if (!($46)) {
     $60 = ((($45)) + 8|0);
     $61 = HEAP32[$60>>2]|0;HEAP32[$60>>2] = (($61-1)|0);
     $62 = ($61|0)==(1);
     if ($62) {
      __ZNK3osg10Referenced24signalObserversAndDeleteEbb($45,1,1);
     }
    }
    $63 = ((($45)) + 52|0);
    $64 = HEAP32[$63>>2]|0;
    $65 = ($64|0)==(0|0);
    $66 = ((($45)) + 56|0);
    $67 = HEAP32[$66>>2]|0;
    if ($65) {
     $69 = $67;
     HEAP32[$10>>2] = $67;
     $70 = $69;
    } else {
     $68 = ((($64)) + 56|0);
     HEAP32[$68>>2] = $67;
     $$pre$i = HEAP32[$66>>2]|0;
     $70 = $$pre$i;
    }
    $71 = ($70|0)==(0|0);
    $72 = ((($70)) + 52|0);
    $$sink$i = $71 ? $11 : $72;
    HEAP32[$$sink$i>>2] = $64;
    HEAP32[$66>>2] = 0;
    HEAP32[$63>>2] = 0;
    $73 = ((($74)) + 4|0);
    $$sroa$019$0 = HEAP32[$73>>2]|0;
    $75 = $$sroa$019$0;
    $76 = ($75|0)==($1|0);
    if ($76) {
     break L4;
    } else {
     $$sroa$019$029 = $$sroa$019$0;$74 = $75;
    }
   }
   $77 = ___cxa_find_matching_catch_2()|0;
   $78 = tempRet0;
   if ($46) {
    ___resumeException($77|0);
    // unreachable;
   }
   $79 = ((($45)) + 8|0);
   $80 = HEAP32[$79>>2]|0;HEAP32[$79>>2] = (($80-1)|0);
   $81 = ($80|0)==(1);
   if (!($81)) {
    ___resumeException($77|0);
    // unreachable;
   }
   __THREW__ = 0;
   invoke_viii(3262,($45|0),1,1);
   $82 = __THREW__; __THREW__ = 0;
   $83 = $82&1;
   if ($83) {
    $84 = ___cxa_find_matching_catch_3(0|0)|0;
    $85 = tempRet0;
    ___clang_call_terminate($84);
    // unreachable;
   } else {
    ___resumeException($77|0);
    // unreachable;
   }
  }
 } while(0);
 $12 = ((($0)) + 24|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($13)) + 32|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($15) + ($3))|0;
 HEAP32[$14>>2] = $16;
 $17 = ((($13)) + 28|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($18) - ($3))|0;
 HEAP32[$17>>2] = $19;
 $20 = HEAP32[$2>>2]|0;
 $21 = ($20|0)==(0);
 if ($21) {
  return;
 }
 $22 = HEAP32[$5>>2]|0;
 $23 = HEAP32[$1>>2]|0;
 $24 = ((($23)) + 4|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = HEAP32[$22>>2]|0;
 $27 = ((($26)) + 4|0);
 HEAP32[$27>>2] = $25;
 $28 = HEAP32[$24>>2]|0;
 HEAP32[$28>>2] = $26;
 HEAP32[$2>>2] = 0;
 $29 = ($22|0)==($1|0);
 if ($29) {
  return;
 } else {
  $$023$i$i = $22;
 }
 while(1) {
  $30 = ((($$023$i$i)) + 4|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = ((($$023$i$i)) + 8|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = ($33|0)==(0|0);
  if (!($34)) {
   $35 = ((($33)) + 8|0);
   $36 = HEAP32[$35>>2]|0;HEAP32[$35>>2] = (($36-1)|0);
   $37 = ($36|0)==(1);
   if ($37) {
    __THREW__ = 0;
    invoke_viii(3262,($33|0),1,1);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     label = 10;
     break;
    }
   }
  }
  __ZdlPv($$023$i$i);
  $40 = ($31|0)==($1|0);
  if ($40) {
   label = 27;
   break;
  } else {
   $$023$i$i = $31;
  }
 }
 if ((label|0) == 10) {
  $41 = ___cxa_find_matching_catch_2()|0;
  $42 = tempRet0;
  ___cxa_call_unexpected(($41|0));
  // unreachable;
 }
 else if ((label|0) == 27) {
  return;
 }
}
function __ZN3osg16TextureObjectSet29flushAllDeletedTextureObjectsEv($0) {
 $0 = $0|0;
 var $$023$i$i = 0, $$sroa$08$0 = 0, $$sroa$08$017 = 0, $$sroa$08$018 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $2 = ((($0)) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 (FUNCTION_TABLE_ii[$5 & 8191]($2)|0);
 $6 = ((($0)) + 88|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0);
 if (!($8)) {
  __THREW__ = 0;
  invoke_vi(3976,($0|0));
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if ($10) {
   $11 = ___cxa_find_matching_catch_2()|0;
   $12 = tempRet0;
   $13 = HEAP32[$2>>2]|0;
   $14 = ((($13)) + 12|0);
   $15 = HEAP32[$14>>2]|0;
   __THREW__ = 0;
   (invoke_ii($15|0,($2|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if ($17) {
    $76 = ___cxa_find_matching_catch_3(0|0)|0;
    $77 = tempRet0;
    ___clang_call_terminate($76);
    // unreachable;
   } else {
    ___resumeException($11|0);
    // unreachable;
   }
  }
 }
 $18 = HEAP32[$2>>2]|0;
 $19 = ((($18)) + 12|0);
 $20 = HEAP32[$19>>2]|0;
 (FUNCTION_TABLE_ii[$20 & 8191]($2)|0);
 $21 = ((($0)) + 68|0);
 $22 = ((($0)) + 72|0);
 $$sroa$08$017 = HEAP32[$22>>2]|0;
 $23 = $$sroa$08$017;
 $24 = ($23|0)==($21|0);
 if (!($24)) {
  $$sroa$08$018 = $$sroa$08$017;$73 = $23;
  while(1) {
   $67 = $$sroa$08$018;
   $68 = ((($67)) + 8|0);
   $69 = HEAP32[$68>>2]|0;
   $70 = ((($69)) + 12|0);
   $71 = HEAP32[$70>>2]|0;
   HEAP32[$1>>2] = $71;
   _glDeleteTextures(1,($1|0));
   $72 = ((($73)) + 4|0);
   $$sroa$08$0 = HEAP32[$72>>2]|0;
   $74 = $$sroa$08$0;
   $75 = ($74|0)==($21|0);
   if ($75) {
    break;
   } else {
    $$sroa$08$018 = $$sroa$08$0;$73 = $74;
   }
  }
 }
 $25 = ((($0)) + 76|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ((($0)) + 64|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($28) - ($26))|0;
 HEAP32[$27>>2] = $29;
 $30 = ((($0)) + 60|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = Math_imul($31, $26)|0;
 $33 = ((($0)) + 24|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ((($34)) + 36|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = (($36) - ($32))|0;
 HEAP32[$35>>2] = $37;
 $38 = ((($34)) + 32|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($39) - ($26))|0;
 HEAP32[$38>>2] = $40;
 $41 = ((($34)) + 64|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = (($42) + ($26))|0;
 HEAP32[$41>>2] = $43;
 $44 = HEAP32[$25>>2]|0;
 $45 = ($44|0)==(0);
 if ($45) {
  STACKTOP = sp;return;
 }
 $46 = HEAP32[$22>>2]|0;
 $47 = HEAP32[$21>>2]|0;
 $48 = ((($47)) + 4|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = HEAP32[$46>>2]|0;
 $51 = ((($50)) + 4|0);
 HEAP32[$51>>2] = $49;
 $52 = HEAP32[$48>>2]|0;
 HEAP32[$52>>2] = $50;
 HEAP32[$25>>2] = 0;
 $53 = ($46|0)==($21|0);
 if ($53) {
  STACKTOP = sp;return;
 } else {
  $$023$i$i = $46;
 }
 while(1) {
  $54 = ((($$023$i$i)) + 4|0);
  $55 = HEAP32[$54>>2]|0;
  $56 = ((($$023$i$i)) + 8|0);
  $57 = HEAP32[$56>>2]|0;
  $58 = ($57|0)==(0|0);
  if (!($58)) {
   $59 = ((($57)) + 8|0);
   $60 = HEAP32[$59>>2]|0;HEAP32[$59>>2] = (($60-1)|0);
   $61 = ($60|0)==(1);
   if ($61) {
    __THREW__ = 0;
    invoke_viii(3262,($57|0),1,1);
    $62 = __THREW__; __THREW__ = 0;
    $63 = $62&1;
    if ($63) {
     label = 12;
     break;
    }
   }
  }
  __ZdlPv($$023$i$i);
  $64 = ($55|0)==($21|0);
  if ($64) {
   label = 13;
   break;
  } else {
   $$023$i$i = $55;
  }
 }
 if ((label|0) == 12) {
  $65 = ___cxa_find_matching_catch_2()|0;
  $66 = tempRet0;
  ___cxa_call_unexpected(($65|0));
  // unreachable;
 }
 else if ((label|0) == 13) {
  STACKTOP = sp;return;
 }
}
function __ZN3osg16TextureObjectSet26flushDeletedTextureObjectsEdRd($0,$1,$2) {
 $0 = $0|0;
 $1 = +$1;
 $2 = $2|0;
 var $$0 = 0, $$024 = 0, $$026$lcssa$ph = 0, $$026$lcssa101 = 0, $$02695 = 0, $$1 = 0, $$125 = 0, $$lcssa88$ph = 0, $$not = 0, $$pre = 0, $$sink$i$i = 0.0, $$sink$i$i36 = 0.0, $$sroa$050$0 = 0, $$sroa$050$094 = 0, $$sroa$050$096 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0;
 var $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0;
 var $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0.0, $132 = 0, $133 = 0, $134 = 0.0, $135 = 0.0, $136 = 0.0, $137 = 0.0, $138 = 0.0, $139 = 0, $14 = 0;
 var $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0;
 var $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0;
 var $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0;
 var $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0.0, $207 = 0, $208 = 0, $209 = 0.0, $21 = 0, $210 = 0.0, $211 = 0, $212 = 0.0;
 var $213 = 0.0, $214 = 0.0, $215 = 0.0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0.0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0.0, $47 = 0.0, $48 = 0.0;
 var $49 = 0.0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $or$cond87 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp + 8|0;
 $4 = sp + 4|0;
 $5 = sp;
 $6 = ((($0)) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($7)) + 8|0);
 $9 = HEAP32[$8>>2]|0;
 (FUNCTION_TABLE_ii[$9 & 8191]($6)|0);
 $10 = ((($0)) + 88|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0);
 if (!($12)) {
  __THREW__ = 0;
  invoke_vi(3976,($0|0));
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if ($14) {
   $15 = ___cxa_find_matching_catch_2()|0;
   $16 = tempRet0;
   $17 = HEAP32[$6>>2]|0;
   $18 = ((($17)) + 12|0);
   $19 = HEAP32[$18>>2]|0;
   __THREW__ = 0;
   (invoke_ii($19|0,($6|0))|0);
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if ($21) {
    $222 = ___cxa_find_matching_catch_3(0|0)|0;
    $223 = tempRet0;
    ___clang_call_terminate($222);
    // unreachable;
   }
   $$1 = $15;$$125 = $16;
   ___resumeException($$1|0);
   // unreachable;
  }
 }
 $22 = HEAP32[$6>>2]|0;
 $23 = ((($22)) + 12|0);
 $24 = HEAP32[$23>>2]|0;
 (FUNCTION_TABLE_ii[$24 & 8191]($6)|0);
 $25 = ((($0)) + 60|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($26|0)==(0);
 if (!($27)) {
  $28 = ((($0)) + 24|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = ((($29)) + 36|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = ((($29)) + 40|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = ($31>>>0)>($33>>>0);
  if (!($34)) {
   STACKTOP = sp;return;
  }
 }
 $35 = ((($0)) + 76|0);
 $36 = HEAP32[$35>>2]|0;
 $$not = ($36|0)!=(0);
 $37 = +HEAPF64[$2>>3];
 $38 = !($37 <= 0.0);
 $or$cond = $$not & $38;
 if (!($or$cond)) {
  STACKTOP = sp;return;
 }
 $39 = ((($0)) + 24|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ((($40)) + 36|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ((($40)) + 40|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = (($42) - ($44))|0;
 if ($27) {
  $87 = $36;
 } else {
  $46 = (+($45>>>0));
  $47 = (+($26>>>0));
  $48 = $46 / $47;
  $49 = (+Math_ceil((+$48)));
  $50 = (~~(($49))>>>0);
  $87 = $50;
 }
 $51 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
 do {
  if ($51) {
   $52 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
   $53 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($52,153930,34)|0);
   $54 = HEAP32[$39>>2]|0;
   $55 = ((($54)) + 36|0);
   $56 = HEAP32[$55>>2]|0;
   $57 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($53,$56)|0);
   $58 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($57,153965,34)|0);
   $59 = HEAP32[$39>>2]|0;
   $60 = ((($59)) + 40|0);
   $61 = HEAP32[$60>>2]|0;
   $62 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($58,$61)|0);
   $63 = HEAP32[$62>>2]|0;
   $64 = ((($63)) + -12|0);
   $65 = HEAP32[$64>>2]|0;
   $66 = (($62) + ($65)|0);
   __ZNKSt3__28ios_base6getlocEv($4,$66);
   __THREW__ = 0;
   $67 = (invoke_iii(3255,($4|0),(215188|0))|0);
   $68 = __THREW__; __THREW__ = 0;
   $69 = $68&1;
   if (!($69)) {
    $70 = HEAP32[$67>>2]|0;
    $71 = ((($70)) + 28|0);
    $72 = HEAP32[$71>>2]|0;
    __THREW__ = 0;
    $73 = (invoke_iii($72|0,($67|0),10)|0);
    $74 = __THREW__; __THREW__ = 0;
    $75 = $74&1;
    if (!($75)) {
     __ZNSt3__26localeD2Ev($4);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($62,$73)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($62)|0);
     break;
    }
   }
   $76 = ___cxa_find_matching_catch_2()|0;
   $77 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($4|0));
   $78 = __THREW__; __THREW__ = 0;
   $79 = $78&1;
   if ($79) {
    $80 = ___cxa_find_matching_catch_3(0|0)|0;
    $81 = tempRet0;
    ___clang_call_terminate($80);
    // unreachable;
   } else {
    ___resumeException($76|0);
    // unreachable;
   }
  }
 } while(0);
 $82 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
 do {
  if ($82) {
   $83 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
   $84 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($83,154000,19)|0);
   $85 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($84,$45)|0);
   $86 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($85,154020,26)|0);
   $88 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($86,$87)|0);
   $89 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($88,154047,6)|0);
   $90 = HEAP32[$35>>2]|0;
   $91 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($89,$90)|0);
   $92 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($91,154054,8)|0);
   $93 = HEAP32[$92>>2]|0;
   $94 = ((($93)) + -12|0);
   $95 = HEAP32[$94>>2]|0;
   $96 = (($92) + ($95)|0);
   __ZNKSt3__28ios_base6getlocEv($3,$96);
   __THREW__ = 0;
   $97 = (invoke_iii(3255,($3|0),(215188|0))|0);
   $98 = __THREW__; __THREW__ = 0;
   $99 = $98&1;
   if (!($99)) {
    $100 = HEAP32[$97>>2]|0;
    $101 = ((($100)) + 28|0);
    $102 = HEAP32[$101>>2]|0;
    __THREW__ = 0;
    $103 = (invoke_iii($102|0,($97|0),10)|0);
    $104 = __THREW__; __THREW__ = 0;
    $105 = $104&1;
    if (!($105)) {
     __ZNSt3__26localeD2Ev($3);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($92,$103)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($92)|0);
     break;
    }
   }
   $106 = ___cxa_find_matching_catch_2()|0;
   $107 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($3|0));
   $108 = __THREW__; __THREW__ = 0;
   $109 = $108&1;
   if ($109) {
    $110 = ___cxa_find_matching_catch_3(0|0)|0;
    $111 = tempRet0;
    ___clang_call_terminate($110);
    // unreachable;
   } else {
    ___resumeException($106|0);
    // unreachable;
   }
  }
 } while(0);
 $112 = (__ZN3osg5Timer8instanceEv()|0);
 $113 = (__ZNK3osg5Timer4tickEv($112)|0);
 $114 = tempRet0;
 $115 = ((($0)) + 72|0);
 $$sroa$050$094 = HEAP32[$115>>2]|0;
 $116 = ((($0)) + 68|0);
 $117 = $$sroa$050$094;
 $118 = ($117|0)==($116|0);
 L39: do {
  if ($118) {
   $$026$lcssa101 = 0;
   label = 42;
  } else {
   $119 = ((($112)) + 8|0);
   $$02695 = 0;$$sroa$050$096 = $$sroa$050$094;$150 = $117;
   while(1) {
    __THREW__ = 0;
    $120 = (invoke_ii(3385,($112|0))|0);
    $121 = tempRet0;
    $122 = __THREW__; __THREW__ = 0;
    $123 = $122&1;
    if ($123) {
     label = 33;
     break;
    }
    $124 = ($121>>>0)>($114>>>0);
    $125 = ($120>>>0)>($113>>>0);
    $126 = ($121|0)==($114|0);
    $127 = $126 & $125;
    $128 = $124 | $127;
    if ($128) {
     $129 = (_i64Subtract(($120|0),($121|0),($113|0),($114|0))|0);
     $130 = tempRet0;
     $131 = (+($129>>>0)) + (4294967296.0*(+($130>>>0)));
     $$sink$i$i36 = $131;
    } else {
     $132 = (_i64Subtract(($113|0),($114|0),($120|0),($121|0))|0);
     $133 = tempRet0;
     $134 = (+($132>>>0)) + (4294967296.0*(+($133>>>0)));
     $135 = -$134;
     $$sink$i$i36 = $135;
    }
    $136 = +HEAPF64[$119>>3];
    $137 = $$sink$i$i36 * $136;
    $138 = +HEAPF64[$2>>3];
    $139 = $137 < $138;
    $140 = ($$02695>>>0)<($87>>>0);
    $or$cond87 = $140 & $139;
    if (!($or$cond87)) {
     $$026$lcssa$ph = $$02695;$$lcssa88$ph = $150;
     label = 36;
     break;
    }
    $141 = $$sroa$050$096;
    $142 = ((($141)) + 8|0);
    $143 = HEAP32[$142>>2]|0;
    $144 = ((($143)) + 12|0);
    $145 = HEAP32[$144>>2]|0;
    HEAP32[$5>>2] = $145;
    __THREW__ = 0;
    invoke_vii(3977,1,($5|0));
    $146 = __THREW__; __THREW__ = 0;
    $147 = $146&1;
    if ($147) {
     label = 35;
     break;
    }
    $148 = (($$02695) + 1)|0;
    $149 = ((($150)) + 4|0);
    $$sroa$050$0 = HEAP32[$149>>2]|0;
    $151 = $$sroa$050$0;
    $152 = ($151|0)==($116|0);
    if ($152) {
     $$026$lcssa$ph = $148;$$lcssa88$ph = $116;
     label = 36;
     break;
    } else {
     $$02695 = $148;$$sroa$050$096 = $$sroa$050$0;$150 = $151;
    }
   }
   if ((label|0) == 33) {
    $153 = ___cxa_find_matching_catch_2()|0;
    $154 = tempRet0;
    $$0 = $153;$$024 = $154;
    break;
   }
   else if ((label|0) == 35) {
    $157 = ___cxa_find_matching_catch_2()|0;
    $158 = tempRet0;
    $$0 = $157;$$024 = $158;
    break;
   }
   else if ((label|0) == 36) {
    $$pre = HEAP32[$115>>2]|0;
    $159 = ($$pre|0)==($$lcssa88$ph|0);
    if ($159) {
     $$026$lcssa101 = $$026$lcssa$ph;
     label = 42;
     break;
    }
    $160 = HEAP32[$$lcssa88$ph>>2]|0;
    $161 = ((($160)) + 4|0);
    $162 = HEAP32[$161>>2]|0;
    $163 = HEAP32[$$pre>>2]|0;
    $164 = ((($163)) + 4|0);
    HEAP32[$164>>2] = $162;
    $165 = HEAP32[$161>>2]|0;
    HEAP32[$165>>2] = $163;
    $167 = $$pre;
    while(1) {
     $166 = ((($167)) + 4|0);
     $168 = HEAP32[$166>>2]|0;
     $169 = HEAP32[$35>>2]|0;
     $170 = (($169) + -1)|0;
     HEAP32[$35>>2] = $170;
     $171 = ((($167)) + 8|0);
     $172 = HEAP32[$171>>2]|0;
     $173 = ($172|0)==(0|0);
     if (!($173)) {
      $174 = ((($172)) + 8|0);
      $175 = HEAP32[$174>>2]|0;HEAP32[$174>>2] = (($175-1)|0);
      $176 = ($175|0)==(1);
      if ($176) {
       __THREW__ = 0;
       invoke_viii(3262,($172|0),1,1);
       $177 = __THREW__; __THREW__ = 0;
       $178 = $177&1;
       if ($178) {
        break;
       }
      }
     }
     __ZdlPv($167);
     $179 = ($168|0)==($$lcssa88$ph|0);
     if ($179) {
      $$026$lcssa101 = $$026$lcssa$ph;
      label = 42;
      break L39;
     } else {
      $167 = $168;
     }
    }
    $217 = ___cxa_find_matching_catch_2()|0;
    $218 = tempRet0;
    $$0 = $217;$$024 = $218;
    break;
   }
  }
 } while(0);
 do {
  if ((label|0) == 42) {
   $180 = ((($0)) + 64|0);
   $181 = HEAP32[$180>>2]|0;
   $182 = (($181) - ($$026$lcssa101))|0;
   HEAP32[$180>>2] = $182;
   $183 = HEAP32[$25>>2]|0;
   $184 = Math_imul($183, $$026$lcssa101)|0;
   $185 = HEAP32[$39>>2]|0;
   $186 = ((($185)) + 36|0);
   $187 = HEAP32[$186>>2]|0;
   $188 = (($187) - ($184))|0;
   HEAP32[$186>>2] = $188;
   $189 = ((($185)) + 32|0);
   $190 = HEAP32[$189>>2]|0;
   $191 = (($190) - ($$026$lcssa101))|0;
   HEAP32[$189>>2] = $191;
   $192 = ((($185)) + 64|0);
   $193 = HEAP32[$192>>2]|0;
   $194 = (($193) + ($$026$lcssa101))|0;
   HEAP32[$192>>2] = $194;
   __THREW__ = 0;
   $195 = (invoke_ii(3385,($112|0))|0);
   $196 = tempRet0;
   $197 = __THREW__; __THREW__ = 0;
   $198 = $197&1;
   if ($198) {
    $155 = ___cxa_find_matching_catch_2()|0;
    $156 = tempRet0;
    $$0 = $155;$$024 = $156;
    break;
   }
   $199 = ($196>>>0)>($114>>>0);
   $200 = ($195>>>0)>($113>>>0);
   $201 = ($196|0)==($114|0);
   $202 = $201 & $200;
   $203 = $199 | $202;
   if ($203) {
    $204 = (_i64Subtract(($195|0),($196|0),($113|0),($114|0))|0);
    $205 = tempRet0;
    $206 = (+($204>>>0)) + (4294967296.0*(+($205>>>0)));
    $$sink$i$i = $206;
   } else {
    $207 = (_i64Subtract(($113|0),($114|0),($195|0),($196|0))|0);
    $208 = tempRet0;
    $209 = (+($207>>>0)) + (4294967296.0*(+($208>>>0)));
    $210 = -$209;
    $$sink$i$i = $210;
   }
   $211 = ((($112)) + 8|0);
   $212 = +HEAPF64[$211>>3];
   $213 = $$sink$i$i * $212;
   $214 = +HEAPF64[$2>>3];
   $215 = $214 - $213;
   HEAPF64[$2>>3] = $215;
   (__ZNK3osg5Timer4tickEv($112)|0);
   $216 = tempRet0;
   STACKTOP = sp;return;
  }
 } while(0);
 __THREW__ = 0;
 (invoke_ii(3385,($112|0))|0);
 $219 = tempRet0;
 $220 = __THREW__; __THREW__ = 0;
 $221 = $220&1;
 if ($221) {
  $222 = ___cxa_find_matching_catch_3(0|0)|0;
  $223 = tempRet0;
  ___clang_call_terminate($222);
  // unreachable;
 } else {
  $$1 = $$0;$$125 = $$024;
  ___resumeException($$1|0);
  // unreachable;
 }
}
function __ZNSt3__26__treeINS_12__value_typeIN3osg7Texture14TextureProfileENS2_7ref_ptrINS2_16TextureObjectSetEEEEENS_19__map_value_compareIS4_S8_NS_4lessIS4_EELb1EEENS_9allocatorIS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 }
 $3 = HEAP32[$1>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIN3osg7Texture14TextureProfileENS2_7ref_ptrINS2_16TextureObjectSetEEEEENS_19__map_value_compareIS4_S8_NS_4lessIS4_EELb1EEENS_9allocatorIS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($0,$3);
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIN3osg7Texture14TextureProfileENS2_7ref_ptrINS2_16TextureObjectSetEEEEENS_19__map_value_compareIS4_S8_NS_4lessIS4_EELb1EEENS_9allocatorIS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($0,$5);
 $6 = ((($1)) + 48|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = ((($7)) + 8|0);
  $10 = HEAP32[$9>>2]|0;HEAP32[$9>>2] = (($10-1)|0);
  $11 = ($10|0)==(1);
  if ($11) {
   __THREW__ = 0;
   invoke_viii(3262,($7|0),1,1);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if ($13) {
    $14 = ___cxa_find_matching_catch_2()|0;
    $15 = tempRet0;
    ___cxa_call_unexpected(($14|0));
    // unreachable;
   }
  }
 }
 __ZdlPv($1);
 return;
}
function __ZN3osg7TextureD2Ev($0) {
 $0 = $0|0;
 var $$0 = 0, $$02 = 0, $$pre$i$i = 0, $$pre$i$i16 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i$i$i20 = 0, $scevgep$i$i$i$i25 = 0, $scevgep$i$i$i$i6 = 0, $scevgep5$i$i$i$i = 0, $scevgep5$i$i$i$i21 = 0;
 var $scevgep5$i$i$i$i26 = 0, $scevgep5$i$i$i$i7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (68036);
 __THREW__ = 0;
 invoke_vi(3978,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if ($2) {
   $53 = ___cxa_find_matching_catch_2()|0;
   $54 = tempRet0;
   $55 = ((($0)) + 236|0);
   $56 = HEAP32[$55>>2]|0;
   $57 = ($56|0)==(0|0);
   if (!($57)) {
    $58 = ((($56)) + 8|0);
    $59 = HEAP32[$58>>2]|0;HEAP32[$58>>2] = (($59-1)|0);
    $60 = ($59|0)==(1);
    if ($60) {
     __THREW__ = 0;
     invoke_viii(3262,($56|0),1,1);
     $61 = __THREW__; __THREW__ = 0;
     $62 = $61&1;
     if ($62) {
      $109 = ___cxa_find_matching_catch_3(0|0)|0;
      $110 = tempRet0;
      ___clang_call_terminate($109);
      // unreachable;
     }
    }
   }
   HEAP32[$55>>2] = 0;
   $$0 = $54;$$02 = $53;
  } else {
   $3 = ((($0)) + 236|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = ($4|0)==(0|0);
   if (!($5)) {
    $6 = ((($4)) + 8|0);
    $7 = HEAP32[$6>>2]|0;HEAP32[$6>>2] = (($7-1)|0);
    $8 = ($7|0)==(1);
    if ($8) {
     __THREW__ = 0;
     invoke_viii(3262,($4|0),1,1);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      $63 = ___cxa_find_matching_catch_2()|0;
      $64 = tempRet0;
      $$0 = $64;$$02 = $63;
      break;
     }
    }
   }
   HEAP32[$3>>2] = 0;
   $11 = ((($0)) + 224|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = ($12|0)==(0|0);
   if (!($13)) {
    $14 = ((($0)) + 228|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = ($15|0)==($12|0);
    do {
     if ($16) {
      $30 = $12;
     } else {
      $18 = $15;
      while(1) {
       $17 = ((($18)) + -4|0);
       HEAP32[$14>>2] = $17;
       $19 = HEAP32[$17>>2]|0;
       $20 = ($19|0)==(0|0);
       if (!($20)) {
        $21 = ((($19)) + 8|0);
        $22 = HEAP32[$21>>2]|0;HEAP32[$21>>2] = (($22-1)|0);
        $23 = ($22|0)==(1);
        if ($23) {
         __THREW__ = 0;
         invoke_viii(3262,($19|0),1,1);
         $24 = __THREW__; __THREW__ = 0;
         $25 = $24&1;
         if ($25) {
          label = 11;
          break;
         }
        }
       }
       HEAP32[$17>>2] = 0;
       $26 = HEAP32[$14>>2]|0;
       $27 = ($26|0)==($12|0);
       if ($27) {
        label = 12;
        break;
       } else {
        $18 = $26;
       }
      }
      if ((label|0) == 11) {
       $28 = ___cxa_find_matching_catch_2()|0;
       $29 = tempRet0;
       ___cxa_call_unexpected(($28|0));
       // unreachable;
      }
      else if ((label|0) == 12) {
       $$pre$i$i = HEAP32[$11>>2]|0;
       $30 = $$pre$i$i;
       break;
      }
     }
    } while(0);
    __ZdlPv($30);
   }
   $31 = ((($0)) + 68|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ($32|0)==(0|0);
   if (!($33)) {
    $34 = ((($0)) + 72|0);
    $35 = HEAP32[$34>>2]|0;
    $36 = ($35|0)==($32|0);
    if (!($36)) {
     $scevgep$i$i$i$i = ((($35)) + -4|0);
     $37 = $scevgep$i$i$i$i;
     $38 = $32;
     $39 = (($37) - ($38))|0;
     $40 = $39 >>> 2;
     $41 = $40 ^ -1;
     $scevgep5$i$i$i$i = (($35) + ($41<<2)|0);
     HEAP32[$34>>2] = $scevgep5$i$i$i$i;
    }
    __ZdlPv($32);
   }
   $42 = ((($0)) + 56|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = ($43|0)==(0|0);
   if ($44) {
    __ZN3osg14StateAttributeD2Ev($0);
    return;
   }
   $45 = ((($0)) + 60|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = ($46|0)==($43|0);
   if (!($47)) {
    $scevgep$i$i$i$i6 = ((($46)) + -4|0);
    $48 = $scevgep$i$i$i$i6;
    $49 = $43;
    $50 = (($48) - ($49))|0;
    $51 = $50 >>> 2;
    $52 = $51 ^ -1;
    $scevgep5$i$i$i$i7 = (($46) + ($52<<2)|0);
    HEAP32[$45>>2] = $scevgep5$i$i$i$i7;
   }
   __ZdlPv($43);
   __ZN3osg14StateAttributeD2Ev($0);
   return;
  }
 } while(0);
 $65 = ((($0)) + 224|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = ($66|0)==(0|0);
 if (!($67)) {
  $68 = ((($0)) + 228|0);
  $69 = HEAP32[$68>>2]|0;
  $70 = ($69|0)==($66|0);
  do {
   if ($70) {
    $84 = $66;
   } else {
    $72 = $69;
    while(1) {
     $71 = ((($72)) + -4|0);
     HEAP32[$68>>2] = $71;
     $73 = HEAP32[$71>>2]|0;
     $74 = ($73|0)==(0|0);
     if (!($74)) {
      $75 = ((($73)) + 8|0);
      $76 = HEAP32[$75>>2]|0;HEAP32[$75>>2] = (($76-1)|0);
      $77 = ($76|0)==(1);
      if ($77) {
       __THREW__ = 0;
       invoke_viii(3262,($73|0),1,1);
       $78 = __THREW__; __THREW__ = 0;
       $79 = $78&1;
       if ($79) {
        label = 34;
        break;
       }
      }
     }
     HEAP32[$71>>2] = 0;
     $80 = HEAP32[$68>>2]|0;
     $81 = ($80|0)==($66|0);
     if ($81) {
      label = 35;
      break;
     } else {
      $72 = $80;
     }
    }
    if ((label|0) == 34) {
     $82 = ___cxa_find_matching_catch_2()|0;
     $83 = tempRet0;
     ___cxa_call_unexpected(($82|0));
     // unreachable;
    }
    else if ((label|0) == 35) {
     $$pre$i$i16 = HEAP32[$65>>2]|0;
     $84 = $$pre$i$i16;
     break;
    }
   }
  } while(0);
  __ZdlPv($84);
 }
 $85 = ((($0)) + 68|0);
 $86 = HEAP32[$85>>2]|0;
 $87 = ($86|0)==(0|0);
 if (!($87)) {
  $88 = ((($0)) + 72|0);
  $89 = HEAP32[$88>>2]|0;
  $90 = ($89|0)==($86|0);
  if (!($90)) {
   $scevgep$i$i$i$i20 = ((($89)) + -4|0);
   $91 = $scevgep$i$i$i$i20;
   $92 = $86;
   $93 = (($91) - ($92))|0;
   $94 = $93 >>> 2;
   $95 = $94 ^ -1;
   $scevgep5$i$i$i$i21 = (($89) + ($95<<2)|0);
   HEAP32[$88>>2] = $scevgep5$i$i$i$i21;
  }
  __ZdlPv($86);
 }
 $96 = ((($0)) + 56|0);
 $97 = HEAP32[$96>>2]|0;
 $98 = ($97|0)==(0|0);
 if (!($98)) {
  $99 = ((($0)) + 60|0);
  $100 = HEAP32[$99>>2]|0;
  $101 = ($100|0)==($97|0);
  if (!($101)) {
   $scevgep$i$i$i$i25 = ((($100)) + -4|0);
   $102 = $scevgep$i$i$i$i25;
   $103 = $97;
   $104 = (($102) - ($103))|0;
   $105 = $104 >>> 2;
   $106 = $105 ^ -1;
   $scevgep5$i$i$i$i26 = (($100) + ($106<<2)|0);
   HEAP32[$99>>2] = $scevgep5$i$i$i$i26;
  }
  __ZdlPv($97);
 }
 __THREW__ = 0;
 invoke_vi(1573,($0|0));
 $107 = __THREW__; __THREW__ = 0;
 $108 = $107&1;
 if ($108) {
  $109 = ___cxa_find_matching_catch_3(0|0)|0;
  $110 = tempRet0;
  ___clang_call_terminate($109);
  // unreachable;
 } else {
  ___resumeException($$02|0);
  // unreachable;
 }
}
function __ZN3osg7TextureD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(2335,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK3osg7Texture12isSameKindAsEPKNS_6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,26864,0)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK3osg7Texture11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175113|0);
}
function __ZNK3osg7Texture9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (154652|0);
}
function __ZN3osg7Texture21resizeGLObjectBuffersEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i$i$i3 = 0, $scevgep5$i$i$i$i = 0, $scevgep5$i$i$i$i4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp + 4|0;
 $3 = sp;
 $4 = ((($0)) + 224|0);
 $5 = ((($0)) + 228|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$4>>2]|0;
 $8 = (($6) - ($7))|0;
 $9 = $8 >> 2;
 $10 = ($9>>>0)<($1>>>0);
 $11 = $7;
 $12 = $6;
 L1: do {
  if ($10) {
   $13 = (($1) - ($9))|0;
   __ZNSt3__26vectorIN3osg7ref_ptrINS1_7Texture13TextureObjectEEENS_9allocatorIS5_EEE8__appendEj($4,$13);
  } else {
   $14 = ($9>>>0)>($1>>>0);
   if ($14) {
    $15 = (($11) + ($1<<2)|0);
    $16 = ($12|0)==($15|0);
    if (!($16)) {
     $18 = $12;
     while(1) {
      $17 = ((($18)) + -4|0);
      HEAP32[$5>>2] = $17;
      $19 = HEAP32[$17>>2]|0;
      $20 = ($19|0)==(0|0);
      if (!($20)) {
       $21 = ((($19)) + 8|0);
       $22 = HEAP32[$21>>2]|0;HEAP32[$21>>2] = (($22-1)|0);
       $23 = ($22|0)==(1);
       if ($23) {
        __THREW__ = 0;
        invoke_viii(3262,($19|0),1,1);
        $24 = __THREW__; __THREW__ = 0;
        $25 = $24&1;
        if ($25) {
         break;
        }
       }
      }
      HEAP32[$17>>2] = 0;
      $26 = HEAP32[$5>>2]|0;
      $27 = ($26|0)==($15|0);
      if ($27) {
       break L1;
      } else {
       $18 = $26;
      }
     }
     $28 = ___cxa_find_matching_catch_2()|0;
     $29 = tempRet0;
     ___cxa_call_unexpected(($28|0));
     // unreachable;
    }
   }
  }
 } while(0);
 $30 = ((($0)) + 56|0);
 HEAP32[$3>>2] = 0;
 $31 = ((($0)) + 60|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = HEAP32[$30>>2]|0;
 $34 = (($32) - ($33))|0;
 $35 = $34 >> 2;
 $36 = ($35>>>0)<($1>>>0);
 $37 = $33;
 $38 = $32;
 if ($36) {
  $39 = (($1) - ($35))|0;
  __ZNSt3__26vectorIjNS_9allocatorIjEEE8__appendEjRKj($30,$39,$3);
 } else {
  $40 = ($35>>>0)>($1>>>0);
  if ($40) {
   $41 = (($37) + ($1<<2)|0);
   $42 = ($38|0)==($41|0);
   if (!($42)) {
    $scevgep$i$i$i$i = ((($38)) + -4|0);
    $43 = $scevgep$i$i$i$i;
    $44 = $41;
    $45 = (($43) - ($44))|0;
    $46 = $45 >>> 2;
    $47 = $46 ^ -1;
    $scevgep5$i$i$i$i = (($38) + ($47<<2)|0);
    HEAP32[$31>>2] = $scevgep5$i$i$i$i;
   }
  }
 }
 $48 = ((($0)) + 68|0);
 HEAP32[$2>>2] = 0;
 $49 = ((($0)) + 72|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = HEAP32[$48>>2]|0;
 $52 = (($50) - ($51))|0;
 $53 = $52 >> 2;
 $54 = ($53>>>0)<($1>>>0);
 $55 = $51;
 $56 = $50;
 if ($54) {
  $57 = (($1) - ($53))|0;
  __ZNSt3__26vectorIjNS_9allocatorIjEEE8__appendEjRKj($48,$57,$2);
  STACKTOP = sp;return;
 }
 $58 = ($53>>>0)>($1>>>0);
 if (!($58)) {
  STACKTOP = sp;return;
 }
 $59 = (($55) + ($1<<2)|0);
 $60 = ($56|0)==($59|0);
 if ($60) {
  STACKTOP = sp;return;
 }
 $scevgep$i$i$i$i3 = ((($56)) + -4|0);
 $61 = $scevgep$i$i$i$i3;
 $62 = $59;
 $63 = (($61) - ($62))|0;
 $64 = $63 >>> 2;
 $65 = $64 ^ -1;
 $scevgep5$i$i$i$i4 = (($56) + ($65<<2)|0);
 HEAP32[$49>>2] = $scevgep5$i$i$i$i4;
 STACKTOP = sp;return;
}
function __ZNK3osg7Texture16releaseGLObjectsEPNS_5StateE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$pre = 0, $10 = 0, $100 = 0, $101 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN3osg7Texture18dirtyTextureObjectEv($0);
  return;
 }
 $3 = ((($1)) + 124|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 224|0);
 $6 = ((($0)) + 228|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$5>>2]|0;
 $9 = (($7) - ($8))|0;
 $10 = $9 >> 2;
 $11 = ($10>>>0)>($4>>>0);
 L5: do {
  if (!($11)) {
   $12 = (($4) + 1)|0;
   $13 = ($12>>>0)>($10>>>0);
   $14 = $8;
   $15 = $7;
   if ($13) {
    $16 = (($12) - ($10))|0;
    __ZNSt3__26vectorIN3osg7ref_ptrINS1_7Texture13TextureObjectEEENS_9allocatorIS5_EEE8__appendEj($5,$16);
    break;
   }
   $17 = ($12>>>0)<($10>>>0);
   if ($17) {
    $18 = (($14) + ($12<<2)|0);
    $19 = ($15|0)==($18|0);
    if (!($19)) {
     $21 = $15;
     while(1) {
      $20 = ((($21)) + -4|0);
      HEAP32[$6>>2] = $20;
      $22 = HEAP32[$20>>2]|0;
      $23 = ($22|0)==(0|0);
      if (!($23)) {
       $24 = ((($22)) + 8|0);
       $25 = HEAP32[$24>>2]|0;HEAP32[$24>>2] = (($25-1)|0);
       $26 = ($25|0)==(1);
       if ($26) {
        __THREW__ = 0;
        invoke_viii(3262,($22|0),1,1);
        $27 = __THREW__; __THREW__ = 0;
        $28 = $27&1;
        if ($28) {
         break;
        }
       }
      }
      HEAP32[$20>>2] = 0;
      $29 = HEAP32[$6>>2]|0;
      $30 = ($29|0)==($18|0);
      if ($30) {
       break L5;
      } else {
       $21 = $29;
      }
     }
     $31 = ___cxa_find_matching_catch_2()|0;
     $32 = tempRet0;
     ___cxa_call_unexpected(($31|0));
     // unreachable;
    }
   }
  }
 } while(0);
 $33 = HEAP32[$5>>2]|0;
 $34 = (($33) + ($4<<2)|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = ($35|0)==(0|0);
 if ($36) {
  return;
 }
 $37 = $33;
 $38 = HEAP32[$6>>2]|0;
 $39 = (($38) - ($37))|0;
 $40 = $39 >> 2;
 $41 = ($40>>>0)>($4>>>0);
 L22: do {
  if (!($41)) {
   $42 = (($4) + 1)|0;
   $43 = ($42>>>0)>($40>>>0);
   $44 = $38;
   if ($43) {
    $45 = (($42) - ($40))|0;
    __ZNSt3__26vectorIN3osg7ref_ptrINS1_7Texture13TextureObjectEEENS_9allocatorIS5_EEE8__appendEj($5,$45);
    break;
   }
   $46 = ($42>>>0)<($40>>>0);
   if ($46) {
    $47 = (($33) + ($42<<2)|0);
    $48 = ($44|0)==($47|0);
    if (!($48)) {
     $50 = $44;
     while(1) {
      $49 = ((($50)) + -4|0);
      HEAP32[$6>>2] = $49;
      $51 = HEAP32[$49>>2]|0;
      $52 = ($51|0)==(0|0);
      if (!($52)) {
       $53 = ((($51)) + 8|0);
       $54 = HEAP32[$53>>2]|0;HEAP32[$53>>2] = (($54-1)|0);
       $55 = ($54|0)==(1);
       if ($55) {
        __THREW__ = 0;
        invoke_viii(3262,($51|0),1,1);
        $56 = __THREW__; __THREW__ = 0;
        $57 = $56&1;
        if ($57) {
         break;
        }
       }
      }
      HEAP32[$49>>2] = 0;
      $58 = HEAP32[$6>>2]|0;
      $59 = ($58|0)==($47|0);
      if ($59) {
       break L22;
      } else {
       $50 = $58;
      }
     }
     $60 = ___cxa_find_matching_catch_2()|0;
     $61 = tempRet0;
     ___cxa_call_unexpected(($60|0));
     // unreachable;
    }
   }
  }
 } while(0);
 $62 = HEAP32[$5>>2]|0;
 $63 = (($62) + ($4<<2)|0);
 $64 = HEAP32[$63>>2]|0;
 $65 = ((($64)) + 48|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = ($66|0)==(0|0);
 $68 = $62;
 if ($67) {
  $71 = $68;
 } else {
  __ZN3osg16TextureObjectSet6orphanEPNS_7Texture13TextureObjectE($66,$64);
  $$pre = HEAP32[$5>>2]|0;
  $71 = $$pre;
 }
 $69 = HEAP32[$6>>2]|0;
 $70 = (($69) - ($71))|0;
 $72 = $70 >> 2;
 $73 = ($72>>>0)>($4>>>0);
 L39: do {
  if (!($73)) {
   $74 = (($4) + 1)|0;
   $75 = ($74>>>0)>($72>>>0);
   $76 = $71;
   $77 = $69;
   if ($75) {
    $78 = (($74) - ($72))|0;
    __ZNSt3__26vectorIN3osg7ref_ptrINS1_7Texture13TextureObjectEEENS_9allocatorIS5_EEE8__appendEj($5,$78);
    break;
   }
   $79 = ($74>>>0)<($72>>>0);
   if ($79) {
    $80 = (($76) + ($74<<2)|0);
    $81 = ($77|0)==($80|0);
    if (!($81)) {
     $83 = $77;
     while(1) {
      $82 = ((($83)) + -4|0);
      HEAP32[$6>>2] = $82;
      $84 = HEAP32[$82>>2]|0;
      $85 = ($84|0)==(0|0);
      if (!($85)) {
       $86 = ((($84)) + 8|0);
       $87 = HEAP32[$86>>2]|0;HEAP32[$86>>2] = (($87-1)|0);
       $88 = ($87|0)==(1);
       if ($88) {
        __THREW__ = 0;
        invoke_viii(3262,($84|0),1,1);
        $89 = __THREW__; __THREW__ = 0;
        $90 = $89&1;
        if ($90) {
         break;
        }
       }
      }
      HEAP32[$82>>2] = 0;
      $91 = HEAP32[$6>>2]|0;
      $92 = ($91|0)==($80|0);
      if ($92) {
       break L39;
      } else {
       $83 = $91;
      }
     }
     $93 = ___cxa_find_matching_catch_2()|0;
     $94 = tempRet0;
     ___cxa_call_unexpected(($93|0));
     // unreachable;
    }
   }
  }
 } while(0);
 $95 = HEAP32[$5>>2]|0;
 $96 = (($95) + ($4<<2)|0);
 $97 = HEAP32[$96>>2]|0;
 $98 = ($97|0)==(0|0);
 if ($98) {
  return;
 }
 HEAP32[$96>>2] = 0;
 $99 = ((($97)) + 8|0);
 $100 = HEAP32[$99>>2]|0;HEAP32[$99>>2] = (($100-1)|0);
 $101 = ($100|0)==(1);
 if (!($101)) {
  return;
 }
 __ZNK3osg10Referenced24signalObserversAndDeleteEbb($97,1,1);
 return;
}
function __ZNK3osg7Texture7getTypeEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function __ZNK3osg7Texture16compileGLObjectsERNS_5StateE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $3 = ((($2)) + 172|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 8191]($0,$1);
 return;
}
function __ZNK3osg7Texture15getTextureWidthEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function __ZNK3osg7Texture16getTextureHeightEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function __ZNK3osg7Texture15getTextureDepthEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function __ZN3osg7Texture18dirtyTextureObjectEv($0) {
 $0 = $0|0;
 var $$012 = 0, $$pre = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 224|0);
 $2 = ((($0)) + 228|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$1>>2]|0;
 $5 = ($3|0)==($4|0);
 if ($5) {
  return;
 }
 $$012 = 0;$12 = $3;$6 = $4;
 L4: while(1) {
  $7 = $6;
  $8 = (($7) + ($$012<<2)|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($9|0)==(0|0);
  if (!($10)) {
   $11 = (($12) - ($6))|0;
   $13 = $11 >> 2;
   $14 = ($13>>>0)>($$012>>>0);
   do {
    if (!($14)) {
     $15 = (($$012) + 1)|0;
     $16 = ($15>>>0)>($13>>>0);
     $17 = $6;
     $18 = $12;
     if ($16) {
      $19 = (($15) - ($13))|0;
      __ZNSt3__26vectorIN3osg7ref_ptrINS1_7Texture13TextureObjectEEENS_9allocatorIS5_EEE8__appendEj($1,$19);
      break;
     }
     $20 = ($15>>>0)<($13>>>0);
     if ($20) {
      $21 = (($17) + ($15<<2)|0);
      $22 = ($18|0)==($21|0);
      if (!($22)) {
       $24 = $18;
       while(1) {
        $23 = ((($24)) + -4|0);
        HEAP32[$2>>2] = $23;
        $25 = HEAP32[$23>>2]|0;
        $26 = ($25|0)==(0|0);
        if (!($26)) {
         $27 = ((($25)) + 8|0);
         $28 = HEAP32[$27>>2]|0;HEAP32[$27>>2] = (($28-1)|0);
         $29 = ($28|0)==(1);
         if ($29) {
          __THREW__ = 0;
          invoke_viii(3262,($25|0),1,1);
          $30 = __THREW__; __THREW__ = 0;
          $31 = $30&1;
          if ($31) {
           label = 14;
           break L4;
          }
         }
        }
        HEAP32[$23>>2] = 0;
        $32 = HEAP32[$2>>2]|0;
        $33 = ($32|0)==($21|0);
        if ($33) {
         break;
        } else {
         $24 = $32;
        }
       }
      }
     }
    }
   } while(0);
   $36 = HEAP32[$1>>2]|0;
   $37 = (($36) + ($$012<<2)|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = ((($38)) + 48|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = ($40|0)==(0|0);
   $42 = $36;
   if ($41) {
    $45 = $42;
   } else {
    __ZN3osg16TextureObjectSet6orphanEPNS_7Texture13TextureObjectE($40,$38);
    $$pre = HEAP32[$1>>2]|0;
    $45 = $$pre;
   }
   $43 = HEAP32[$2>>2]|0;
   $44 = (($43) - ($45))|0;
   $46 = $44 >> 2;
   $47 = ($46>>>0)>($$012>>>0);
   do {
    if (!($47)) {
     $48 = (($$012) + 1)|0;
     $49 = ($48>>>0)>($46>>>0);
     $50 = $45;
     $51 = $43;
     if ($49) {
      $52 = (($48) - ($46))|0;
      __ZNSt3__26vectorIN3osg7ref_ptrINS1_7Texture13TextureObjectEEENS_9allocatorIS5_EEE8__appendEj($1,$52);
      break;
     }
     $53 = ($48>>>0)<($46>>>0);
     if ($53) {
      $54 = (($50) + ($48<<2)|0);
      $55 = ($51|0)==($54|0);
      if (!($55)) {
       $57 = $51;
       while(1) {
        $56 = ((($57)) + -4|0);
        HEAP32[$2>>2] = $56;
        $58 = HEAP32[$56>>2]|0;
        $59 = ($58|0)==(0|0);
        if (!($59)) {
         $60 = ((($58)) + 8|0);
         $61 = HEAP32[$60>>2]|0;HEAP32[$60>>2] = (($61-1)|0);
         $62 = ($61|0)==(1);
         if ($62) {
          __THREW__ = 0;
          invoke_viii(3262,($58|0),1,1);
          $63 = __THREW__; __THREW__ = 0;
          $64 = $63&1;
          if ($64) {
           label = 26;
           break L4;
          }
         }
        }
        HEAP32[$56>>2] = 0;
        $65 = HEAP32[$2>>2]|0;
        $66 = ($65|0)==($54|0);
        if ($66) {
         break;
        } else {
         $57 = $65;
        }
       }
      }
     }
    }
   } while(0);
   $69 = HEAP32[$1>>2]|0;
   $70 = (($69) + ($$012<<2)|0);
   $71 = HEAP32[$70>>2]|0;
   $72 = ($71|0)==(0|0);
   if (!($72)) {
    HEAP32[$70>>2] = 0;
    $73 = ((($71)) + 8|0);
    $74 = HEAP32[$73>>2]|0;HEAP32[$73>>2] = (($74-1)|0);
    $75 = ($74|0)==(1);
    if ($75) {
     __ZNK3osg10Referenced24signalObserversAndDeleteEbb($71,1,1);
    }
   }
  }
  $76 = (($$012) + 1)|0;
  $77 = HEAP32[$2>>2]|0;
  $78 = HEAP32[$1>>2]|0;
  $79 = (($77) - ($78))|0;
  $80 = $79 >> 2;
  $81 = ($76>>>0)<($80>>>0);
  if ($81) {
   $$012 = $76;$12 = $77;$6 = $78;
  } else {
   label = 3;
   break;
  }
 }
 if ((label|0) == 3) {
  return;
 }
 else if ((label|0) == 14) {
  $34 = ___cxa_find_matching_catch_2()|0;
  $35 = tempRet0;
  ___cxa_call_unexpected(($34|0));
  // unreachable;
 }
 else if ((label|0) == 26) {
  $67 = ___cxa_find_matching_catch_2()|0;
  $68 = tempRet0;
  ___cxa_call_unexpected(($67|0));
  // unreachable;
 }
}
function __ZN3osg16TextureObjectSet6orphanEPNS_7Texture13TextureObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$04 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 (FUNCTION_TABLE_ii[$5 & 8191]($2)|0);
 $6 = ((($1)) + 60|0);
 HEAP32[$6>>2] = 0;
 $7 = ($1|0)==(0|0);
 if (!($7)) {
  $8 = ((($1)) + 8|0);
  $9 = HEAP32[$8>>2]|0;HEAP32[$8>>2] = (($9+1)|0);
 }
 $10 = ((($0)) + 80|0);
 __THREW__ = 0;
 $11 = (invoke_ii(3276,12)|0);
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 do {
  if ($13) {
   $33 = ___cxa_find_matching_catch_2()|0;
   $34 = tempRet0;
   if ($7) {
    $$0 = $34;$$04 = $33;
   } else {
    $35 = ((($1)) + 8|0);
    $36 = HEAP32[$35>>2]|0;HEAP32[$35>>2] = (($36-1)|0);
    $37 = ($36|0)==(1);
    if ($37) {
     __THREW__ = 0;
     invoke_viii(3262,($1|0),1,1);
     $38 = __THREW__; __THREW__ = 0;
     $39 = $38&1;
     if ($39) {
      $45 = ___cxa_find_matching_catch_3(0|0)|0;
      $46 = tempRet0;
      ___clang_call_terminate($45);
      // unreachable;
     } else {
      $$0 = $34;$$04 = $33;
     }
    } else {
     $$0 = $34;$$04 = $33;
    }
   }
  } else {
   $14 = ((($11)) + 8|0);
   HEAP32[$14>>2] = $1;
   if (!($7)) {
    $15 = ((($1)) + 8|0);
    $16 = HEAP32[$15>>2]|0;HEAP32[$15>>2] = (($16+1)|0);
   }
   $17 = ((($11)) + 4|0);
   HEAP32[$17>>2] = $10;
   $18 = HEAP32[$10>>2]|0;
   HEAP32[$11>>2] = $18;
   $19 = ((($18)) + 4|0);
   HEAP32[$19>>2] = $11;
   HEAP32[$10>>2] = $11;
   $20 = ((($0)) + 88|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = (($21) + 1)|0;
   HEAP32[$20>>2] = $22;
   if ($7) {
    $28 = HEAP32[$2>>2]|0;
    $29 = ((($28)) + 12|0);
    $30 = HEAP32[$29>>2]|0;
    (FUNCTION_TABLE_ii[$30 & 8191]($2)|0);
    return;
   }
   $23 = ((($1)) + 8|0);
   $24 = HEAP32[$23>>2]|0;HEAP32[$23>>2] = (($24-1)|0);
   $25 = ($24|0)==(1);
   if (!($25)) {
    $28 = HEAP32[$2>>2]|0;
    $29 = ((($28)) + 12|0);
    $30 = HEAP32[$29>>2]|0;
    (FUNCTION_TABLE_ii[$30 & 8191]($2)|0);
    return;
   }
   __THREW__ = 0;
   invoke_viii(3262,($1|0),1,1);
   $26 = __THREW__; __THREW__ = 0;
   $27 = $26&1;
   if ($27) {
    $31 = ___cxa_find_matching_catch_2()|0;
    $32 = tempRet0;
    $$0 = $32;$$04 = $31;
    break;
   } else {
    $28 = HEAP32[$2>>2]|0;
    $29 = ((($28)) + 12|0);
    $30 = HEAP32[$29>>2]|0;
    (FUNCTION_TABLE_ii[$30 & 8191]($2)|0);
    return;
   }
  }
 } while(0);
 $40 = HEAP32[$2>>2]|0;
 $41 = ((($40)) + 12|0);
 $42 = HEAP32[$41>>2]|0;
 __THREW__ = 0;
 (invoke_ii($42|0,($2|0))|0);
 $43 = __THREW__; __THREW__ = 0;
 $44 = $43&1;
 if ($44) {
  $45 = ___cxa_find_matching_catch_3(0|0)|0;
  $46 = tempRet0;
  ___clang_call_terminate($45);
  // unreachable;
 } else {
  ___resumeException($$04|0);
  // unreachable;
 }
}
function __ZN3osg7Texture13TextureObjectD2Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg14GraphicsObjectD2Ev($0);
 return;
}
function __ZN3osg7Texture13TextureObjectD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1859,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __GLOBAL__sub_I_Texture_cpp() {
 var $$0$i = 0, $$0$i6 = 0, $$01$i = 0, $$01$i5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0, $9 = 0, dest = 0, label = 0;
 var sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $0 = sp + 36|0;
 $1 = sp + 24|0;
 $2 = sp + 12|0;
 $3 = sp;
 HEAPF32[52176] = 1.0;
 HEAPF32[(208708)>>2] = 0.0;
 HEAPF32[(208712)>>2] = 0.0;
 HEAPF32[52179] = 0.0;
 HEAPF32[(208720)>>2] = 1.0;
 HEAPF32[(208724)>>2] = 0.0;
 HEAPF32[52182] = 0.0;
 HEAPF32[(208732)>>2] = 0.0;
 HEAPF32[(208736)>>2] = 1.0;
 $4 = (__Znwj(32)|0);
 HEAP32[$0>>2] = $4;
 $5 = ((($0)) + 8|0);
 HEAP32[$5>>2] = -2147483616;
 $6 = ((($0)) + 4|0);
 HEAP32[$6>>2] = 20;
 dest=$4; src=154705; stop=dest+20|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $7 = ((($4)) + 20|0);
 HEAP8[$7>>0] = 0;
 ;HEAP32[$1>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;
 __THREW__ = 0;
 $8 = (invoke_ii(3276,48)|0);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if ($10) {
  $27 = ___cxa_find_matching_catch_2()|0;
  $28 = tempRet0;
  $$0$i6 = $28;$$01$i5 = $27;
 } else {
  HEAP32[$1>>2] = $8;
  $11 = ((($1)) + 8|0);
  HEAP32[$11>>2] = -2147483600;
  $12 = ((($1)) + 4|0);
  HEAP32[$12>>2] = 33;
  dest=$8; src=154726; stop=dest+33|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
  $13 = ((($8)) + 33|0);
  HEAP8[$13>>0] = 0;
  __THREW__ = 0;
  $14 = (invoke_i(3459)|0);
  $15 = __THREW__; __THREW__ = 0;
  $16 = $15&1;
  if (!($16)) {
   __THREW__ = 0;
   invoke_viiii(3460,($14|0),2,($0|0),($1|0));
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if (!($18)) {
    $19 = ((($1)) + 11|0);
    $20 = HEAP8[$19>>0]|0;
    $21 = ($20<<24>>24)<(0);
    if ($21) {
     $22 = HEAP32[$1>>2]|0;
     __ZdlPv($22);
    }
    $23 = ((($0)) + 11|0);
    $24 = HEAP8[$23>>0]|0;
    $25 = ($24<<24>>24)<(0);
    if ($25) {
     $26 = HEAP32[$0>>2]|0;
     __ZdlPv($26);
    }
    $39 = (__Znwj(32)|0);
    HEAP32[$2>>2] = $39;
    $40 = ((($2)) + 8|0);
    HEAP32[$40>>2] = -2147483616;
    $41 = ((($2)) + 4|0);
    HEAP32[$41>>2] = 22;
    dest=$39; src=154760; stop=dest+22|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
    $42 = ((($39)) + 22|0);
    HEAP8[$42>>0] = 0;
    ;HEAP32[$3>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;
    __THREW__ = 0;
    $43 = (invoke_ii(3276,128)|0);
    $44 = __THREW__; __THREW__ = 0;
    $45 = $44&1;
    if ($45) {
     $62 = ___cxa_find_matching_catch_2()|0;
     $63 = tempRet0;
     $$0$i = $63;$$01$i = $62;
    } else {
     HEAP32[$3>>2] = $43;
     $46 = ((($3)) + 8|0);
     HEAP32[$46>>2] = -2147483520;
     $47 = ((($3)) + 4|0);
     HEAP32[$47>>2] = 114;
     dest=$43; src=154783; stop=dest+114|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
     $48 = ((($43)) + 114|0);
     HEAP8[$48>>0] = 0;
     __THREW__ = 0;
     $49 = (invoke_i(3459)|0);
     $50 = __THREW__; __THREW__ = 0;
     $51 = $50&1;
     if (!($51)) {
      __THREW__ = 0;
      invoke_viiii(3460,($49|0),2,($2|0),($3|0));
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if (!($53)) {
       $54 = ((($3)) + 11|0);
       $55 = HEAP8[$54>>0]|0;
       $56 = ($55<<24>>24)<(0);
       if ($56) {
        $57 = HEAP32[$3>>2]|0;
        __ZdlPv($57);
       }
       $58 = ((($2)) + 11|0);
       $59 = HEAP8[$58>>0]|0;
       $60 = ($59<<24>>24)<(0);
       if (!($60)) {
        STACKTOP = sp;return;
       }
       $61 = HEAP32[$2>>2]|0;
       __ZdlPv($61);
       STACKTOP = sp;return;
      }
     }
     $64 = ___cxa_find_matching_catch_2()|0;
     $65 = tempRet0;
     $66 = ((($3)) + 11|0);
     $67 = HEAP8[$66>>0]|0;
     $68 = ($67<<24>>24)<(0);
     if ($68) {
      $69 = HEAP32[$3>>2]|0;
      __ZdlPv($69);
      $$0$i = $65;$$01$i = $64;
     } else {
      $$0$i = $65;$$01$i = $64;
     }
    }
    $70 = ((($2)) + 11|0);
    $71 = HEAP8[$70>>0]|0;
    $72 = ($71<<24>>24)<(0);
    if (!($72)) {
     ___resumeException($$01$i|0);
     // unreachable;
    }
    $73 = HEAP32[$2>>2]|0;
    __ZdlPv($73);
    ___resumeException($$01$i|0);
    // unreachable;
   }
  }
  $29 = ___cxa_find_matching_catch_2()|0;
  $30 = tempRet0;
  $31 = ((($1)) + 11|0);
  $32 = HEAP8[$31>>0]|0;
  $33 = ($32<<24>>24)<(0);
  if ($33) {
   $34 = HEAP32[$1>>2]|0;
   __ZdlPv($34);
   $$0$i6 = $30;$$01$i5 = $29;
  } else {
   $$0$i6 = $30;$$01$i5 = $29;
  }
 }
 $35 = ((($0)) + 11|0);
 $36 = HEAP8[$35>>0]|0;
 $37 = ($36<<24>>24)<(0);
 if (!($37)) {
  ___resumeException($$01$i5|0);
  // unreachable;
 }
 $38 = HEAP32[$0>>2]|0;
 __ZdlPv($38);
 ___resumeException($$01$i5|0);
 // unreachable;
}
function __ZN3osg7Texture13TextureObject4bindEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 _glBindTexture(($2|0),($4|0));
 $5 = ((($0)) + 48|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  return;
 }
 __ZN3osg16TextureObjectSet10moveToBackEPNS_7Texture13TextureObjectE($6,$0);
 return;
}
function __ZN3osg16TextureObjectSet10moveToBackEPNS_7Texture13TextureObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$pre = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp + 4|0;
 $3 = sp;
 $4 = ((($0)) + 24|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($5)) + 56|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($1)) + 68|0);
 HEAP32[$8>>2] = $7;
 $9 = ((($0)) + 96|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==($1|0);
 if ($11) {
  STACKTOP = sp;return;
 }
 $12 = ($10|0)==(0|0);
 if ($12) {
  $13 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
  do {
   if ($13) {
    $14 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
    $15 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($14,154898,53)|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = ((($16)) + -12|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = (($15) + ($18)|0);
    __ZNKSt3__28ios_base6getlocEv($2,$19);
    __THREW__ = 0;
    $20 = (invoke_iii(3255,($2|0),(215188|0))|0);
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if (!($22)) {
     $23 = HEAP32[$20>>2]|0;
     $24 = ((($23)) + 28|0);
     $25 = HEAP32[$24>>2]|0;
     __THREW__ = 0;
     $26 = (invoke_iii($25|0,($20|0),10)|0);
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     if (!($28)) {
      __ZNSt3__26localeD2Ev($2);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($15,$26)|0);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($15)|0);
      break;
     }
    }
    $29 = ___cxa_find_matching_catch_2()|0;
    $30 = tempRet0;
    __THREW__ = 0;
    invoke_vi(3263,($2|0));
    $31 = __THREW__; __THREW__ = 0;
    $32 = $31&1;
    if ($32) {
     $33 = ___cxa_find_matching_catch_3(0|0)|0;
     $34 = tempRet0;
     ___clang_call_terminate($33);
     // unreachable;
    } else {
     ___resumeException($29|0);
     // unreachable;
    }
   }
  } while(0);
  $35 = ((($0)) + 92|0);
  HEAP32[$35>>2] = $1;
  HEAP32[$9>>2] = $1;
  STACKTOP = sp;return;
 }
 $36 = ((($1)) + 56|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = ($37|0)==(0|0);
 if (!($38)) {
  $61 = ((($1)) + 52|0);
  $62 = HEAP32[$61>>2]|0;
  $63 = ($62|0)==(0|0);
  if ($63) {
   $65 = ((($0)) + 92|0);
   HEAP32[$65>>2] = $37;
   $67 = $37;
  } else {
   $64 = ((($62)) + 56|0);
   HEAP32[$64>>2] = $37;
   $$pre = HEAP32[$36>>2]|0;
   $67 = $$pre;
  }
  $66 = ((($67)) + 52|0);
  HEAP32[$66>>2] = $62;
  $68 = ((($10)) + 56|0);
  HEAP32[$68>>2] = $1;
  HEAP32[$61>>2] = $10;
  HEAP32[$36>>2] = 0;
  HEAP32[$9>>2] = $1;
  STACKTOP = sp;return;
 }
 $39 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
 if (!($39)) {
  STACKTOP = sp;return;
 }
 $40 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
 $41 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($40,154952,60)|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ((($42)) + -12|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = (($41) + ($44)|0);
 __ZNKSt3__28ios_base6getlocEv($3,$45);
 __THREW__ = 0;
 $46 = (invoke_iii(3255,($3|0),(215188|0))|0);
 $47 = __THREW__; __THREW__ = 0;
 $48 = $47&1;
 if (!($48)) {
  $49 = HEAP32[$46>>2]|0;
  $50 = ((($49)) + 28|0);
  $51 = HEAP32[$50>>2]|0;
  __THREW__ = 0;
  $52 = (invoke_iii($51|0,($46|0),10)|0);
  $53 = __THREW__; __THREW__ = 0;
  $54 = $53&1;
  if (!($54)) {
   __ZNSt3__26localeD2Ev($3);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($41,$52)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($41)|0);
   STACKTOP = sp;return;
  }
 }
 $55 = ___cxa_find_matching_catch_2()|0;
 $56 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($3|0));
 $57 = __THREW__; __THREW__ = 0;
 $58 = $57&1;
 if ($58) {
  $59 = ___cxa_find_matching_catch_3(0|0)|0;
  $60 = tempRet0;
  ___clang_call_terminate($59);
  // unreachable;
 } else {
  ___resumeException($55|0);
  // unreachable;
 }
}
function __ZN3osg7Texture13TextureObject7releaseEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 48|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  return;
 }
 __ZN3osg16TextureObjectSet6orphanEPNS_7Texture13TextureObjectE($2,$0);
 return;
}
function __ZN3osg7Texture13TextureObject12setAllocatedEijiiii($0,$1,$2,$3,$4,$5,$6) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 var $$phi$trans$insert = 0, $$pre = 0, $$pre$i$i = 0, $$pre15 = 0, $$sink$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $9 = 0, $or$cond$i = 0, $or$cond$i14 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $7 = ((($0)) + 64|0);
 HEAP8[$7>>0] = 1;
 $8 = ((($0)) + 16|0);
 $9 = ((($0)) + 28|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0);
 if (!($11)) {
  $12 = ((($0)) + 20|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($13|0)==($1|0);
  if ($14) {
   $15 = ((($0)) + 24|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ($16|0)==($2|0);
   $18 = ($10|0)==($3|0);
   $or$cond$i = $18 & $17;
   if ($or$cond$i) {
    $19 = ((($0)) + 32|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = ($20|0)==($4|0);
    if ($21) {
     $22 = ((($0)) + 36|0);
     $23 = HEAP32[$22>>2]|0;
     $24 = ($23|0)==($5|0);
     if ($24) {
      $25 = ((($0)) + 40|0);
      $26 = HEAP32[$25>>2]|0;
      $27 = ($26|0)==($6|0);
      if ($27) {
       return;
      }
     }
    }
   }
  }
 }
 $28 = ((($0)) + 44|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ((($0)) + 20|0);
 HEAP32[$30>>2] = $1;
 $31 = ((($0)) + 24|0);
 HEAP32[$31>>2] = $2;
 HEAP32[$9>>2] = $3;
 $32 = ((($0)) + 32|0);
 HEAP32[$32>>2] = $4;
 $33 = ((($0)) + 36|0);
 HEAP32[$33>>2] = $5;
 $34 = ((($0)) + 40|0);
 HEAP32[$34>>2] = $6;
 __ZN3osg7Texture14TextureProfile11computeSizeEv($8);
 $35 = ((($0)) + 48|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = ($36|0)==(0|0);
 if ($37) {
  return;
 }
 $38 = ((($36)) + 24|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (__ZN3osg20TextureObjectManager19getTextureObjectSetERKNS_7Texture14TextureProfileE($39,$8)|0);
 $41 = ($40|0)!=($36|0);
 $42 = ($40|0)!=(0|0);
 $or$cond$i14 = $41 & $42;
 if ($or$cond$i14) {
  $43 = ((($36)) + 64|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = (($44) + -1)|0;
  HEAP32[$43>>2] = $45;
  $46 = ((($0)) + 52|0);
  $47 = HEAP32[$46>>2]|0;
  $48 = ($47|0)==(0|0);
  $49 = ((($0)) + 56|0);
  $50 = HEAP32[$49>>2]|0;
  if ($48) {
   $52 = $50;
   $53 = ((($36)) + 92|0);
   HEAP32[$53>>2] = $50;
   $54 = $52;
  } else {
   $51 = ((($47)) + 56|0);
   HEAP32[$51>>2] = $50;
   $$pre$i$i = HEAP32[$49>>2]|0;
   $54 = $$pre$i$i;
  }
  $55 = ($54|0)==(0|0);
  $56 = ((($36)) + 96|0);
  $57 = ((($54)) + 52|0);
  $$sink$i$i = $55 ? $56 : $57;
  HEAP32[$$sink$i$i>>2] = $47;
  HEAP32[$49>>2] = 0;
  HEAP32[$46>>2] = 0;
  HEAP32[$35>>2] = $40;
  $58 = ((($40)) + 64|0);
  $59 = HEAP32[$58>>2]|0;
  $60 = (($59) + 1)|0;
  HEAP32[$58>>2] = $60;
  $61 = ((($40)) + 24|0);
  $62 = HEAP32[$61>>2]|0;
  $63 = ((($62)) + 56|0);
  $64 = HEAP32[$63>>2]|0;
  $65 = ((($0)) + 68|0);
  HEAP32[$65>>2] = $64;
  $66 = ((($40)) + 96|0);
  $67 = HEAP32[$66>>2]|0;
  $68 = ($67|0)==(0|0);
  $69 = $67;
  if (!($68)) {
   $70 = ((($67)) + 56|0);
   HEAP32[$70>>2] = $0;
  }
  HEAP32[$46>>2] = $69;
  $71 = ((($40)) + 92|0);
  $72 = HEAP32[$71>>2]|0;
  $73 = ($72|0)==(0|0);
  if ($73) {
   HEAP32[$71>>2] = $0;
  }
  HEAP32[$66>>2] = $0;
  $75 = $62;
 } else {
  $$pre = HEAP32[$35>>2]|0;
  $$phi$trans$insert = ((($$pre)) + 24|0);
  $$pre15 = HEAP32[$$phi$trans$insert>>2]|0;
  $75 = $$pre15;
 }
 $74 = ((($75)) + 36|0);
 $76 = HEAP32[$74>>2]|0;
 $77 = (($76) - ($29))|0;
 HEAP32[$74>>2] = $77;
 $78 = HEAP32[$28>>2]|0;
 $79 = (($77) + ($78))|0;
 HEAP32[$74>>2] = $79;
 return;
}
function __ZN3osg7Texture14TextureProfile11computeSizeEv($0) {
 $0 = $0|0;
 var $$011 = 0, $$01113 = 0, $$01115 = 0, $$012 = 0, $$014 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0.0, $13 = 0.0, $14 = 0.0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $switch$split102D = 0, $switch$split12D = 0, $switch$split132D = 0, $switch$split162D = 0, $switch$split2D = 0, $switch$split42D = 0, $switch$split72D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $switch$split2D = ($2|0)<(35841);
 L1: do {
  if ($switch$split2D) {
   $switch$split12D = ($2|0)<(33776);
   if (!($switch$split12D)) {
    switch ($2|0) {
    case 34025:  {
     $$012 = 4;
     break L1;
     break;
    }
    case 34028:  {
     $$012 = 4;
     break L1;
     break;
    }
    case 34027:  {
     $$012 = 4;
     break L1;
     break;
    }
    case 33776:  {
     $$012 = 4;
     break L1;
     break;
    }
    case 33777:  {
     $$012 = 4;
     break L1;
     break;
    }
    case 34029:  {
     $$012 = 8;
     break L1;
     break;
    }
    case 33778:  {
     $$012 = 8;
     break L1;
     break;
    }
    case 33779:  {
     $$012 = 8;
     break L1;
     break;
    }
    case 35840:  {
     $$012 = 4;
     break L1;
     break;
    }
    default: {
     $$012 = 32;
     break L1;
    }
    }
   }
   $switch$split42D = ($2|0)<(6407);
   if ($switch$split42D) {
    $switch$split72D = ($2|0)<(3);
    if ($switch$split72D) {
     switch ($2|0) {
     case 1:  {
      $$012 = 8;
      break L1;
      break;
     }
     case 2:  {
      $$012 = 16;
      break L1;
      break;
     }
     default: {
      $$012 = 32;
      break L1;
     }
     }
    }
    $switch$split132D = ($2|0)<(6406);
    if ($switch$split132D) {
     switch ($2|0) {
     case 3:  {
      break;
     }
     default: {
      $$012 = 32;
      break L1;
     }
     }
     $$012 = 24;
     break;
    } else {
     switch ($2|0) {
     case 6406:  {
      break;
     }
     default: {
      $$012 = 32;
      break L1;
     }
     }
     $$012 = 8;
     break;
    }
   }
   $switch$split102D = ($2|0)<(6410);
   if ($switch$split102D) {
    switch ($2|0) {
    case 6409:  {
     $$012 = 8;
     break L1;
     break;
    }
    case 6407:  {
     $$012 = 24;
     break L1;
     break;
    }
    default: {
     $$012 = 32;
     break L1;
    }
    }
   }
   $switch$split162D = ($2|0)<(32841);
   if ($switch$split162D) {
    switch ($2|0) {
    case 6410:  {
     break;
    }
    default: {
     $$012 = 32;
     break L1;
    }
    }
    $$012 = 16;
    break;
   }
   switch ($2|0) {
   case 32841:  {
    $$012 = 8;
    break L1;
    break;
   }
   case 32992:  {
    $$012 = 24;
    break L1;
    break;
   }
   default: {
    $$012 = 32;
    break L1;
   }
   }
  } else {
   do {
    switch ($2|0) {
    case 37491:  {
     $$012 = 8;
     break L1;
     break;
    }
    case 37490:  {
     $$012 = 8;
     break L1;
     break;
    }
    case 36284:  {
     $$012 = 4;
     break L1;
     break;
    }
    case 36283:  {
     $$012 = 4;
     break L1;
     break;
    }
    case 36286:  {
     $$012 = 8;
     break L1;
     break;
    }
    case 36285:  {
     $$012 = 8;
     break L1;
     break;
    }
    case 35841:  {
     $$012 = 2;
     break L1;
     break;
    }
    case 35843:  {
     $$012 = 2;
     break L1;
     break;
    }
    case 35842:  {
     $$012 = 4;
     break L1;
     break;
    }
    case 36196:  {
     $$012 = 4;
     break L1;
     break;
    }
    case 37492:  {
     $$012 = 4;
     break L1;
     break;
    }
    case 37493:  {
     $$012 = 4;
     break L1;
     break;
    }
    case 37494:  {
     $$012 = 8;
     break L1;
     break;
    }
    case 37495:  {
     $$012 = 8;
     break L1;
     break;
    }
    case 37496:  {
     $$012 = 8;
     break L1;
     break;
    }
    case 37497:  {
     $$012 = 8;
     break L1;
     break;
    }
    case 37488:  {
     $$012 = 4;
     break L1;
     break;
    }
    case 37489:  {
     $$012 = 4;
     break L1;
     break;
    }
    default: {
     $$012 = 32;
     break L1;
    }
    }
   } while(0);
  }
 } while(0);
 $3 = ((($0)) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($0)) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = Math_imul($4, $$012)|0;
 $10 = Math_imul($9, $6)|0;
 $11 = Math_imul($10, $8)|0;
 $12 = (+($11>>>0));
 $13 = $12 * 0.125;
 $14 = (+Math_ceil((+$13)));
 $15 = (~~(($14))>>>0);
 $16 = ((($0)) + 28|0);
 HEAP32[$16>>2] = $15;
 $17 = ((($0)) + 4|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ($18|0)>(1);
 if (!($19)) {
  return;
 }
 $$01113 = $15 >>> 2;
 $20 = ($$01113|0)==(0);
 if ($20) {
  return;
 } else {
  $$01115 = $$01113;$$014 = 0;$22 = $15;
 }
 while(1) {
  $21 = (($22) + ($$01115))|0;
  $23 = (($$014) + 1)|0;
  $$011 = $$01115 >>> 2;
  $24 = ($23|0)<($18|0);
  $25 = ($$011|0)!=(0);
  $26 = $24 & $25;
  if ($26) {
   $$01115 = $$011;$$014 = $23;$22 = $21;
  } else {
   break;
  }
 }
 HEAP32[$16>>2] = $21;
 return;
}
function __ZN3osg20TextureObjectManager19getTextureObjectSetERKNS_7Texture14TextureProfileE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$014$i = 0, $$pre$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = ((($0)) + 44|0);
 $4 = (__ZNSt3__26__treeINS_12__value_typeIN3osg7Texture14TextureProfileENS2_7ref_ptrINS2_16TextureObjectSetEEEEENS_19__map_value_compareIS4_S8_NS_4lessIS4_EELb1EEENS_9allocatorIS8_EEE12__find_equalIS4_EERPNS_16__tree_node_baseIPvEERPNS_15__tree_end_nodeISK_EERKT_($3,$2,$1)|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $7 = (__Znwj(52)|0);
  $8 = ((($7)) + 16|0);
  ;HEAP32[$8>>2]=HEAP32[$1>>2]|0;HEAP32[$8+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$8+12>>2]=HEAP32[$1+12>>2]|0;HEAP32[$8+16>>2]=HEAP32[$1+16>>2]|0;HEAP32[$8+20>>2]=HEAP32[$1+20>>2]|0;HEAP32[$8+24>>2]=HEAP32[$1+24>>2]|0;HEAP32[$8+28>>2]=HEAP32[$1+28>>2]|0;
  $9 = ((($7)) + 48|0);
  HEAP32[$9>>2] = 0;
  $10 = HEAP32[$2>>2]|0;
  HEAP32[$7>>2] = 0;
  $11 = ((($7)) + 4|0);
  HEAP32[$11>>2] = 0;
  $12 = ((($7)) + 8|0);
  HEAP32[$12>>2] = $10;
  HEAP32[$4>>2] = $7;
  $13 = HEAP32[$3>>2]|0;
  $14 = HEAP32[$13>>2]|0;
  $15 = ($14|0)==(0|0);
  if ($15) {
   $19 = $7;
  } else {
   $16 = $14;
   HEAP32[$3>>2] = $16;
   $$pre$i$i = HEAP32[$4>>2]|0;
   $19 = $$pre$i$i;
  }
  $17 = ((($0)) + 48|0);
  $18 = HEAP32[$17>>2]|0;
  __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($18,$19);
  $20 = ((($0)) + 52|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = (($21) + 1)|0;
  HEAP32[$20>>2] = $22;
  $$014$i = $7;
 } else {
  $$014$i = $5;
 }
 $23 = ((($$014$i)) + 48|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)==(0|0);
 if (!($25)) {
  $62 = HEAP32[$23>>2]|0;
  STACKTOP = sp;return ($62|0);
 }
 $26 = (__Znwj(100)|0);
 __THREW__ = 0;
 invoke_vi(3282,($26|0));
 $27 = __THREW__; __THREW__ = 0;
 $28 = $27&1;
 if ($28) {
  $60 = ___cxa_find_matching_catch_2()|0;
  $61 = tempRet0;
  $eh$lpad$body$index2Z2D = $61;$eh$lpad$body$indexZ2D = $60;
  __ZdlPv($26);
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 HEAP32[$26>>2] = (67964);
 $29 = ((($26)) + 12|0);
 __THREW__ = 0;
 invoke_vii(3507,($29|0),0);
 $30 = __THREW__; __THREW__ = 0;
 $31 = $30&1;
 if ($31) {
  $32 = ___cxa_find_matching_catch_2()|0;
  $33 = tempRet0;
  __THREW__ = 0;
  invoke_vi(712,($26|0));
  $34 = __THREW__; __THREW__ = 0;
  $35 = $34&1;
  if ($35) {
   $36 = ___cxa_find_matching_catch_3(0|0)|0;
   $37 = tempRet0;
   ___clang_call_terminate($36);
   // unreachable;
  } else {
   $eh$lpad$body$index2Z2D = $33;$eh$lpad$body$indexZ2D = $32;
   __ZdlPv($26);
   ___resumeException($eh$lpad$body$indexZ2D|0);
   // unreachable;
  }
 }
 $38 = ((($26)) + 24|0);
 HEAP32[$38>>2] = $0;
 $39 = ((($26)) + 28|0);
 $40 = ((($0)) + 24|0);
 $41 = HEAP32[$40>>2]|0;
 HEAP32[$39>>2] = $41;
 $42 = ((($26)) + 32|0);
 ;HEAP32[$42>>2]=HEAP32[$1>>2]|0;HEAP32[$42+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$42+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$42+12>>2]=HEAP32[$1+12>>2]|0;HEAP32[$42+16>>2]=HEAP32[$1+16>>2]|0;HEAP32[$42+20>>2]=HEAP32[$1+20>>2]|0;HEAP32[$42+24>>2]=HEAP32[$1+24>>2]|0;HEAP32[$42+28>>2]=HEAP32[$1+28>>2]|0;
 $43 = ((($26)) + 64|0);
 HEAP32[$43>>2] = 0;
 $44 = ((($26)) + 68|0);
 HEAP32[$44>>2] = $44;
 $45 = ((($26)) + 72|0);
 HEAP32[$45>>2] = $44;
 $46 = ((($26)) + 76|0);
 HEAP32[$46>>2] = 0;
 $47 = ((($26)) + 80|0);
 HEAP32[$47>>2] = $47;
 $48 = ((($26)) + 84|0);
 HEAP32[$48>>2] = $47;
 $49 = ((($26)) + 88|0);
 HEAP32[$49>>2] = 0;
 $50 = ((($26)) + 92|0);
 HEAP32[$50>>2] = 0;
 $51 = ((($26)) + 96|0);
 HEAP32[$51>>2] = 0;
 $52 = HEAP32[$23>>2]|0;
 $53 = ($52|0)==($26|0);
 if ($53) {
  $62 = HEAP32[$23>>2]|0;
  STACKTOP = sp;return ($62|0);
 }
 HEAP32[$23>>2] = $26;
 $54 = ((($26)) + 8|0);
 $55 = HEAP32[$54>>2]|0;HEAP32[$54>>2] = (($55+1)|0);
 $56 = ($52|0)==(0|0);
 if ($56) {
  $62 = HEAP32[$23>>2]|0;
  STACKTOP = sp;return ($62|0);
 }
 $57 = ((($52)) + 8|0);
 $58 = HEAP32[$57>>2]|0;HEAP32[$57>>2] = (($58-1)|0);
 $59 = ($58|0)==(1);
 if (!($59)) {
  $62 = HEAP32[$23>>2]|0;
  STACKTOP = sp;return ($62|0);
 }
 __ZNK3osg10Referenced24signalObserversAndDeleteEbb($52,1,1);
 $62 = HEAP32[$23>>2]|0;
 STACKTOP = sp;return ($62|0);
}
function __ZNSt3__26__treeINS_12__value_typeIN3osg7Texture14TextureProfileENS2_7ref_ptrINS2_16TextureObjectSetEEEEENS_19__map_value_compareIS4_S8_NS_4lessIS4_EELb1EEENS_9allocatorIS8_EEE12__find_equalIS4_EERPNS_16__tree_node_baseIPvEERPNS_15__tree_end_nodeISK_EERKT_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$0$ph = 0, $$024 = 0, $$025 = 0, $$in = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  HEAP32[$1>>2] = $3;
  $$025 = $3;
  return ($$025|0);
 }
 $6 = ((($0)) + 4|0);
 $7 = ((($2)) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$2>>2]|0;
 $10 = ((($2)) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($2)) + 8|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($2)) + 12|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ((($2)) + 16|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ((($2)) + 20|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ((($2)) + 24|0);
 $21 = HEAP32[$20>>2]|0;
 $$0 = $6;$$024 = $4;
 L5: while(1) {
  $22 = ((($$024)) + 16|0);
  $23 = ((($$024)) + 44|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = ($8>>>0)<($24>>>0);
  do {
   if ($25) {
    label = 19;
   } else {
    $26 = ($24>>>0)<($8>>>0);
    if (!($26)) {
     $27 = HEAP32[$22>>2]|0;
     $28 = ($9>>>0)<($27>>>0);
     if ($28) {
      label = 19;
      break;
     }
     $29 = ($27>>>0)<($9>>>0);
     if (!($29)) {
      $30 = ((($$024)) + 20|0);
      $31 = HEAP32[$30>>2]|0;
      $32 = ($11|0)<($31|0);
      if ($32) {
       label = 19;
       break;
      }
      $33 = ($31|0)<($11|0);
      if (!($33)) {
       $34 = ((($$024)) + 24|0);
       $35 = HEAP32[$34>>2]|0;
       $36 = ($13>>>0)<($35>>>0);
       if ($36) {
        label = 19;
        break;
       }
       $37 = ($35>>>0)<($13>>>0);
       if (!($37)) {
        $38 = ((($$024)) + 28|0);
        $39 = HEAP32[$38>>2]|0;
        $40 = ($15|0)<($39|0);
        if ($40) {
         label = 19;
         break;
        }
        $41 = ($39|0)<($15|0);
        if (!($41)) {
         $42 = ((($$024)) + 32|0);
         $43 = HEAP32[$42>>2]|0;
         $44 = ($17|0)<($43|0);
         if ($44) {
          label = 19;
          break;
         }
         $45 = ($43|0)<($17|0);
         if (!($45)) {
          $46 = ((($$024)) + 36|0);
          $47 = HEAP32[$46>>2]|0;
          $48 = ($19|0)<($47|0);
          if ($48) {
           label = 19;
           break;
          }
          $49 = ($47|0)<($19|0);
          if (!($49)) {
           $50 = ((($$024)) + 40|0);
           $51 = HEAP32[$50>>2]|0;
           $52 = ($21|0)<($51|0);
           if ($52) {
            label = 19;
            break;
           }
          }
         }
        }
       }
      }
     }
     $55 = HEAP32[$22>>2]|0;
     $56 = ($55>>>0)<($9>>>0);
     if (!($56)) {
      $57 = ($9>>>0)<($55>>>0);
      if ($57) {
       label = 36;
       break L5;
      }
      $58 = ((($$024)) + 20|0);
      $59 = HEAP32[$58>>2]|0;
      $60 = ($59|0)<($11|0);
      if (!($60)) {
       $61 = ($11|0)<($59|0);
       if ($61) {
        label = 36;
        break L5;
       }
       $62 = ((($$024)) + 24|0);
       $63 = HEAP32[$62>>2]|0;
       $64 = ($63>>>0)<($13>>>0);
       if (!($64)) {
        $65 = ($13>>>0)<($63>>>0);
        if ($65) {
         label = 36;
         break L5;
        }
        $66 = ((($$024)) + 28|0);
        $67 = HEAP32[$66>>2]|0;
        $68 = ($67|0)<($15|0);
        if (!($68)) {
         $69 = ($15|0)<($67|0);
         if ($69) {
          label = 36;
          break L5;
         }
         $70 = ((($$024)) + 32|0);
         $71 = HEAP32[$70>>2]|0;
         $72 = ($71|0)<($17|0);
         if (!($72)) {
          $73 = ($17|0)<($71|0);
          if ($73) {
           label = 36;
           break L5;
          }
          $74 = ((($$024)) + 36|0);
          $75 = HEAP32[$74>>2]|0;
          $76 = ($75|0)<($19|0);
          if (!($76)) {
           $77 = ($19|0)<($75|0);
           if ($77) {
            label = 36;
            break L5;
           }
           $78 = ((($$024)) + 40|0);
           $79 = HEAP32[$78>>2]|0;
           $80 = ($79|0)<($21|0);
           if (!($80)) {
            label = 36;
            break L5;
           }
          }
         }
        }
       }
      }
     }
    }
    $81 = ((($$024)) + 4|0);
    $82 = HEAP32[$81>>2]|0;
    $83 = ($82|0)==(0|0);
    if ($83) {
     label = 35;
     break L5;
    } else {
     $$0$ph = $81;$$in = $82;
    }
   }
  } while(0);
  if ((label|0) == 19) {
   label = 0;
   $53 = HEAP32[$$024>>2]|0;
   $54 = ($53|0)==(0|0);
   if ($54) {
    label = 20;
    break;
   } else {
    $$0$ph = $$024;$$in = $53;
   }
  }
  $$0 = $$0$ph;$$024 = $$in;
 }
 if ((label|0) == 20) {
  HEAP32[$1>>2] = $$024;
  $$025 = $$024;
  return ($$025|0);
 }
 else if ((label|0) == 35) {
  HEAP32[$1>>2] = $$024;
  $$025 = $81;
  return ($$025|0);
 }
 else if ((label|0) == 36) {
  HEAP32[$1>>2] = $$024;
  $$025 = $$0;
  return ($$025|0);
 }
 return (0)|0;
}
function __ZN3osg16TextureObjectSet15takeFromOrphansEPNS_7TextureE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$pre = 0, $$pre12 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = ((($1)) + 72|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($5)) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 HEAP32[$0>>2] = $7;
 $8 = ($7|0)==(0|0);
 if ($8) {
  $12 = $5;
 } else {
  $9 = ((($7)) + 8|0);
  $10 = HEAP32[$9>>2]|0;HEAP32[$9>>2] = (($10+1)|0);
  $$pre = HEAP32[$4>>2]|0;
  $12 = $$pre;
 }
 $11 = ((($12)) + 4|0);
 $13 = HEAP32[$11>>2]|0;
 $14 = HEAP32[$12>>2]|0;
 $15 = ((($14)) + 4|0);
 HEAP32[$15>>2] = $13;
 $16 = HEAP32[$11>>2]|0;
 HEAP32[$16>>2] = $14;
 $17 = ((($1)) + 76|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($18) + -1)|0;
 HEAP32[$17>>2] = $19;
 $20 = ((($12)) + 8|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0|0);
 if ($22) {
  label = 6;
 } else {
  $23 = ((($21)) + 8|0);
  $24 = HEAP32[$23>>2]|0;HEAP32[$23>>2] = (($24-1)|0);
  $25 = ($24|0)==(1);
  if ($25) {
   __THREW__ = 0;
   invoke_viii(3262,($21|0),1,1);
   $26 = __THREW__; __THREW__ = 0;
   $27 = $26&1;
   if ($27) {
    label = 28;
   } else {
    label = 6;
   }
  } else {
   label = 6;
  }
 }
 do {
  if ((label|0) == 6) {
   __ZdlPv($12);
   $28 = HEAP32[$0>>2]|0;
   $29 = ((($28)) + 60|0);
   HEAP32[$29>>2] = $2;
   $30 = ((($1)) + 24|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = ((($31)) + 32|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = (($33) + -1)|0;
   HEAP32[$32>>2] = $34;
   $35 = ((($31)) + 28|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 1)|0;
   HEAP32[$35>>2] = $37;
   $38 = ((($28)) + 52|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = ($39|0)==(0|0);
   if ($40) {
    $41 = ((($28)) + 56|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = ($42|0)==(0|0);
    if ($43) {
     $46 = ((($31)) + 56|0);
     $47 = HEAP32[$46>>2]|0;
     $48 = ((($28)) + 68|0);
     HEAP32[$48>>2] = $47;
     $49 = ((($1)) + 96|0);
     $50 = HEAP32[$49>>2]|0;
     $51 = ($50|0)==(0|0);
     $52 = $50;
     if (!($51)) {
      $53 = ((($50)) + 56|0);
      HEAP32[$53>>2] = $28;
     }
     HEAP32[$38>>2] = $52;
     $54 = ((($1)) + 92|0);
     $55 = HEAP32[$54>>2]|0;
     $56 = ($55|0)==(0|0);
     if ($56) {
      HEAP32[$54>>2] = $28;
     }
     HEAP32[$49>>2] = $28;
    } else {
     label = 8;
    }
   } else {
    label = 8;
   }
   if ((label|0) == 8) {
    __THREW__ = 0;
    invoke_vii(3979,($1|0),($28|0));
    $44 = __THREW__; __THREW__ = 0;
    $45 = $44&1;
    if ($45) {
     label = 28;
     break;
    }
   }
   __THREW__ = 0;
   $57 = (invoke_ii(3265,4)|0);
   $58 = __THREW__; __THREW__ = 0;
   $59 = $58&1;
   if ($59) {
    label = 28;
   } else {
    if (!($57)) {
     STACKTOP = sp;return;
    }
    __THREW__ = 0;
    $60 = (invoke_ii(3266,4)|0);
    $61 = __THREW__; __THREW__ = 0;
    $62 = $61&1;
    if ($62) {
     label = 28;
    } else {
     __THREW__ = 0;
     $63 = (invoke_iiii(3267,($60|0),(155013|0),53)|0);
     $64 = __THREW__; __THREW__ = 0;
     $65 = $64&1;
     if ($65) {
      label = 28;
     } else {
      $66 = ((($1)) + 64|0);
      $67 = HEAP32[$66>>2]|0;
      __THREW__ = 0;
      $68 = (invoke_iii(3417,($63|0),($67|0))|0);
      $69 = __THREW__; __THREW__ = 0;
      $70 = $69&1;
      if ($70) {
       label = 28;
      } else {
       $71 = HEAP32[$68>>2]|0;
       $72 = ((($71)) + -12|0);
       $73 = HEAP32[$72>>2]|0;
       $74 = (($68) + ($73)|0);
       __THREW__ = 0;
       invoke_vii(3257,($3|0),($74|0));
       $75 = __THREW__; __THREW__ = 0;
       $76 = $75&1;
       if ($76) {
        label = 28;
       } else {
        __THREW__ = 0;
        $77 = (invoke_iii(3255,($3|0),(215188|0))|0);
        $78 = __THREW__; __THREW__ = 0;
        $79 = $78&1;
        if (!($79)) {
         $80 = HEAP32[$77>>2]|0;
         $81 = ((($80)) + 28|0);
         $82 = HEAP32[$81>>2]|0;
         __THREW__ = 0;
         $83 = (invoke_iii($82|0,($77|0),10)|0);
         $84 = __THREW__; __THREW__ = 0;
         $85 = $84&1;
         if (!($85)) {
          __THREW__ = 0;
          invoke_vi(3263,($3|0));
          $92 = __THREW__; __THREW__ = 0;
          $93 = $92&1;
          if ($93) {
           label = 28;
           break;
          }
          __THREW__ = 0;
          (invoke_iii(3268,($68|0),($83|0))|0);
          $94 = __THREW__; __THREW__ = 0;
          $95 = $94&1;
          if ($95) {
           label = 28;
           break;
          }
          __THREW__ = 0;
          (invoke_ii(3269,($68|0))|0);
          $96 = __THREW__; __THREW__ = 0;
          $97 = $96&1;
          if ($97) {
           label = 28;
           break;
          }
          STACKTOP = sp;return;
         }
        }
        $86 = ___cxa_find_matching_catch_2()|0;
        $87 = tempRet0;
        __THREW__ = 0;
        invoke_vi(3263,($3|0));
        $88 = __THREW__; __THREW__ = 0;
        $89 = $88&1;
        if ($89) {
         $90 = ___cxa_find_matching_catch_3(0|0)|0;
         $91 = tempRet0;
         ___clang_call_terminate($90);
         // unreachable;
        } else {
         $100 = $28;$eh$lpad$body$index2Z2D = $87;$eh$lpad$body$indexZ2D = $86;
         break;
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 28) {
  $98 = ___cxa_find_matching_catch_2()|0;
  $99 = tempRet0;
  $$pre12 = HEAP32[$0>>2]|0;
  $100 = $$pre12;$eh$lpad$body$index2Z2D = $99;$eh$lpad$body$indexZ2D = $98;
 }
 $101 = ($100|0)==(0|0);
 if ($101) {
  HEAP32[$0>>2] = 0;
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 $102 = ((($100)) + 8|0);
 $103 = HEAP32[$102>>2]|0;HEAP32[$102>>2] = (($103-1)|0);
 $104 = ($103|0)==(1);
 if (!($104)) {
  HEAP32[$0>>2] = 0;
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(3262,($100|0),1,1);
 $105 = __THREW__; __THREW__ = 0;
 $106 = $105&1;
 if ($106) {
  $107 = ___cxa_find_matching_catch_3(0|0)|0;
  $108 = tempRet0;
  ___clang_call_terminate($107);
  // unreachable;
 } else {
  HEAP32[$0>>2] = 0;
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
}
function __ZN3osg16TextureObjectSet14takeOrGenerateEPNS_7TextureE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$012 = 0, $$3 = 0, $$315 = 0, $$5 = 0, $$517 = 0, $$pre = 0, $$pre92 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0;
 var $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0;
 var $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0;
 var $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0;
 var $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0;
 var $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0;
 var $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0;
 var $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0;
 var $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0;
 var $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0;
 var $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0;
 var $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index9Z2D = 0, $eh$lpad$body$indexZ2D = 0, $eh$lpad$body40$index3Z2D = 0;
 var $eh$lpad$body40$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp + 12|0;
 $4 = sp + 8|0;
 $5 = sp + 4|0;
 $6 = sp;
 $7 = ((($1)) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($8)) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 (FUNCTION_TABLE_ii[$10 & 8191]($7)|0);
 $11 = ((($1)) + 88|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0);
 if (!($13)) {
  __THREW__ = 0;
  invoke_vi(3976,($1|0));
  $14 = __THREW__; __THREW__ = 0;
  $15 = $14&1;
  if (!($15)) {
   __THREW__ = 0;
   invoke_viii(3980,($0|0),($1|0),($2|0));
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $347 = HEAP32[$7>>2]|0;
    $348 = ((($347)) + 12|0);
    $349 = HEAP32[$348>>2]|0;
    (FUNCTION_TABLE_ii[$349 & 8191]($7)|0);
    STACKTOP = sp;return;
   }
  }
  $18 = ___cxa_find_matching_catch_2()|0;
  $19 = tempRet0;
  $20 = HEAP32[$7>>2]|0;
  $21 = ((($20)) + 12|0);
  $22 = HEAP32[$21>>2]|0;
  __THREW__ = 0;
  (invoke_ii($22|0,($7|0))|0);
  $23 = __THREW__; __THREW__ = 0;
  $24 = $23&1;
  if ($24) {
   $350 = ___cxa_find_matching_catch_3(0|0)|0;
   $351 = tempRet0;
   ___clang_call_terminate($350);
   // unreachable;
  }
  $$5 = $18;$$517 = $19;
  ___resumeException($$5|0);
  // unreachable;
 }
 $25 = HEAP32[$7>>2]|0;
 $26 = ((($25)) + 12|0);
 $27 = HEAP32[$26>>2]|0;
 (FUNCTION_TABLE_ii[$27 & 8191]($7)|0);
 $28 = ((($1)) + 76|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ($29|0)==(0);
 if (!($30)) {
  __ZN3osg16TextureObjectSet15takeFromOrphansEPNS_7TextureE($0,$1,$2);
  STACKTOP = sp;return;
 }
 $31 = ((($1)) + 24|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = ((($32)) + 56|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ((($32)) + 40|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = ($36|0)==(0);
 if (!($37)) {
  $38 = ((($1)) + 60|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = ((($32)) + 36|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = (($41) + ($39))|0;
  $43 = ($42>>>0)>($36>>>0);
  if ($43) {
   $44 = ((($1)) + 64|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = ($45>>>0)>(1);
   if ($46) {
    $47 = ((($1)) + 92|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = ($48|0)==(0|0);
    if (!($49)) {
     $50 = ((($48)) + 68|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = ($51>>>0)<($34>>>0);
     if ($52) {
      $53 = HEAP32[$7>>2]|0;
      $54 = ((($53)) + 8|0);
      $55 = HEAP32[$54>>2]|0;
      (FUNCTION_TABLE_ii[$55 & 8191]($7)|0);
      $56 = HEAP32[$47>>2]|0;
      HEAP32[$0>>2] = $56;
      $57 = ((($56)) + 8|0);
      $58 = HEAP32[$57>>2]|0;HEAP32[$57>>2] = (($58+1)|0);
      $$pre = HEAP32[$0>>2]|0;
      $59 = ((($$pre)) + 60|0);
      $60 = HEAP32[$59>>2]|0;
      $61 = ($60|0)==(0|0);
      L23: do {
       if ($61) {
        __THREW__ = 0;
        $181 = (invoke_ii(3265,4)|0);
        $182 = __THREW__; __THREW__ = 0;
        $183 = $182&1;
        if ($183) {
         label = 50;
        } else {
         if ($181) {
          __THREW__ = 0;
          $184 = (invoke_ii(3266,4)|0);
          $185 = __THREW__; __THREW__ = 0;
          $186 = $185&1;
          if ($186) {
           label = 50;
          } else {
           __THREW__ = 0;
           $187 = (invoke_iiii(3267,($184|0),(155160|0),49)|0);
           $188 = __THREW__; __THREW__ = 0;
           $189 = $188&1;
           if ($189) {
            label = 50;
           } else {
            __THREW__ = 0;
            $190 = (invoke_iii(3275,($187|0),($$pre|0))|0);
            $191 = __THREW__; __THREW__ = 0;
            $192 = $191&1;
            if ($192) {
             label = 50;
            } else {
             $193 = HEAP32[$190>>2]|0;
             $194 = ((($193)) + -12|0);
             $195 = HEAP32[$194>>2]|0;
             $196 = (($190) + ($195)|0);
             __THREW__ = 0;
             invoke_vii(3257,($3|0),($196|0));
             $197 = __THREW__; __THREW__ = 0;
             $198 = $197&1;
             if ($198) {
              label = 50;
             } else {
              __THREW__ = 0;
              $199 = (invoke_iii(3255,($3|0),(215188|0))|0);
              $200 = __THREW__; __THREW__ = 0;
              $201 = $200&1;
              if (!($201)) {
               $202 = HEAP32[$199>>2]|0;
               $203 = ((($202)) + 28|0);
               $204 = HEAP32[$203>>2]|0;
               __THREW__ = 0;
               $205 = (invoke_iii($204|0,($199|0),10)|0);
               $206 = __THREW__; __THREW__ = 0;
               $207 = $206&1;
               if (!($207)) {
                __THREW__ = 0;
                invoke_vi(3263,($3|0));
                $214 = __THREW__; __THREW__ = 0;
                $215 = $214&1;
                if ($215) {
                 label = 50;
                 break;
                }
                __THREW__ = 0;
                (invoke_iii(3268,($190|0),($205|0))|0);
                $216 = __THREW__; __THREW__ = 0;
                $217 = $216&1;
                if ($217) {
                 label = 50;
                 break;
                }
                __THREW__ = 0;
                (invoke_ii(3269,($190|0))|0);
                $218 = __THREW__; __THREW__ = 0;
                $219 = $218&1;
                if ($219) {
                 label = 50;
                 break;
                } else {
                 $220 = $$pre;
                 label = 68;
                 break;
                }
               }
              }
              $208 = ___cxa_find_matching_catch_2()|0;
              $209 = tempRet0;
              __THREW__ = 0;
              invoke_vi(3263,($3|0));
              $210 = __THREW__; __THREW__ = 0;
              $211 = $210&1;
              if ($211) {
               $212 = ___cxa_find_matching_catch_3(0|0)|0;
               $213 = tempRet0;
               ___clang_call_terminate($212);
               // unreachable;
              } else {
               $eh$lpad$body40$index3Z2D = $209;$eh$lpad$body40$indexZ2D = $208;
               label = 51;
               break;
              }
             }
            }
           }
          }
         } else {
          $220 = $$pre;
          label = 68;
         }
        }
       } else {
        $62 = ((($60)) + 8|0);
        $63 = HEAP32[$62>>2]|0;HEAP32[$62>>2] = (($63+1)|0);
        $64 = ((($1)) + 28|0);
        $65 = HEAP32[$64>>2]|0;
        $66 = ((($60)) + 224|0);
        $67 = ((($60)) + 228|0);
        $68 = HEAP32[$67>>2]|0;
        $69 = HEAP32[$66>>2]|0;
        $70 = (($68) - ($69))|0;
        $71 = $70 >> 2;
        $72 = ($71>>>0)>($65>>>0);
        L41: do {
         if (!($72)) {
          $73 = (($65) + 1)|0;
          $74 = ($73>>>0)>($71>>>0);
          $75 = $69;
          $76 = $68;
          if ($74) {
           $77 = (($73) - ($71))|0;
           __THREW__ = 0;
           invoke_vii(3967,($66|0),($77|0));
           $78 = __THREW__; __THREW__ = 0;
           $79 = $78&1;
           if ($79) {
            label = 50;
            break L23;
           } else {
            break;
           }
          }
          $80 = ($73>>>0)<($71>>>0);
          if ($80) {
           $81 = (($75) + ($73<<2)|0);
           $82 = ($76|0)==($81|0);
           if (!($82)) {
            $84 = $76;
            while(1) {
             $83 = ((($84)) + -4|0);
             HEAP32[$67>>2] = $83;
             $85 = HEAP32[$83>>2]|0;
             $86 = ($85|0)==(0|0);
             if (!($86)) {
              $87 = ((($85)) + 8|0);
              $88 = HEAP32[$87>>2]|0;HEAP32[$87>>2] = (($88-1)|0);
              $89 = ($88|0)==(1);
              if ($89) {
               __THREW__ = 0;
               invoke_viii(3262,($85|0),1,1);
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if ($91) {
                break;
               }
              }
             }
             HEAP32[$83>>2] = 0;
             $92 = HEAP32[$67>>2]|0;
             $93 = ($92|0)==($81|0);
             if ($93) {
              break L41;
             } else {
              $84 = $92;
             }
            }
            $94 = ___cxa_find_matching_catch_2()|0;
            $95 = tempRet0;
            ___cxa_call_unexpected(($94|0));
            // unreachable;
           }
          }
         }
        } while(0);
        $96 = HEAP32[$66>>2]|0;
        $97 = (($96) + ($65<<2)|0);
        $98 = HEAP32[$97>>2]|0;
        $99 = ($98|0)==(0|0);
        if (!($99)) {
         HEAP32[$97>>2] = 0;
         $100 = ((($98)) + 8|0);
         $101 = HEAP32[$100>>2]|0;HEAP32[$100>>2] = (($101-1)|0);
         $102 = ($101|0)==(1);
         if ($102) {
          __THREW__ = 0;
          invoke_viii(3262,($98|0),1,1);
          $103 = __THREW__; __THREW__ = 0;
          $104 = $103&1;
          if ($104) {
           label = 50;
           break;
          }
         }
        }
        __THREW__ = 0;
        $105 = (invoke_ii(3265,4)|0);
        $106 = __THREW__; __THREW__ = 0;
        $107 = $106&1;
        if ($107) {
         label = 50;
        } else {
         if (!($105)) {
          $$pre92 = HEAP32[$0>>2]|0;
          $220 = $$pre92;
          label = 68;
          break;
         }
         __THREW__ = 0;
         $108 = (invoke_ii(3266,4)|0);
         $109 = __THREW__; __THREW__ = 0;
         $110 = $109&1;
         if ($110) {
          label = 50;
         } else {
          __THREW__ = 0;
          $111 = (invoke_iiii(3267,($108|0),(155067|0),17)|0);
          $112 = __THREW__; __THREW__ = 0;
          $113 = $112&1;
          if ($113) {
           label = 50;
          } else {
           __THREW__ = 0;
           $114 = (invoke_iii(3275,($111|0),($1|0))|0);
           $115 = __THREW__; __THREW__ = 0;
           $116 = $115&1;
           if ($116) {
            label = 50;
           } else {
            __THREW__ = 0;
            $117 = (invoke_iiii(3267,($114|0),(155085|0),34)|0);
            $118 = __THREW__; __THREW__ = 0;
            $119 = $118&1;
            if ($119) {
             label = 50;
            } else {
             $120 = HEAP32[$0>>2]|0;
             __THREW__ = 0;
             $121 = (invoke_iii(3275,($117|0),($120|0))|0);
             $122 = __THREW__; __THREW__ = 0;
             $123 = $122&1;
             if ($123) {
              label = 50;
             } else {
              __THREW__ = 0;
              $124 = (invoke_iiii(3267,($121|0),(155120|0),22)|0);
              $125 = __THREW__; __THREW__ = 0;
              $126 = $125&1;
              if ($126) {
               label = 50;
              } else {
               $127 = HEAP32[$44>>2]|0;
               __THREW__ = 0;
               $128 = (invoke_iii(3417,($124|0),($127|0))|0);
               $129 = __THREW__; __THREW__ = 0;
               $130 = $129&1;
               if ($130) {
                label = 50;
                break;
               }
               __THREW__ = 0;
               $131 = (invoke_iiii(3267,($128|0),(155143|0),7)|0);
               $132 = __THREW__; __THREW__ = 0;
               $133 = $132&1;
               if ($133) {
                label = 50;
                break;
               }
               $134 = ((($1)) + 44|0);
               $135 = HEAP32[$134>>2]|0;
               __THREW__ = 0;
               $136 = (invoke_iii(3863,($131|0),($135|0))|0);
               $137 = __THREW__; __THREW__ = 0;
               $138 = $137&1;
               if ($138) {
                label = 50;
                break;
               }
               __THREW__ = 0;
               $139 = (invoke_iiii(3267,($136|0),(155151|0),8)|0);
               $140 = __THREW__; __THREW__ = 0;
               $141 = $140&1;
               if ($141) {
                label = 50;
                break;
               }
               $142 = ((($1)) + 48|0);
               $143 = HEAP32[$142>>2]|0;
               __THREW__ = 0;
               $144 = (invoke_iii(3863,($139|0),($143|0))|0);
               $145 = __THREW__; __THREW__ = 0;
               $146 = $145&1;
               if ($146) {
                label = 50;
                break;
               }
               $147 = HEAP32[$144>>2]|0;
               $148 = ((($147)) + -12|0);
               $149 = HEAP32[$148>>2]|0;
               $150 = (($144) + ($149)|0);
               __THREW__ = 0;
               invoke_vii(3257,($4|0),($150|0));
               $151 = __THREW__; __THREW__ = 0;
               $152 = $151&1;
               if ($152) {
                label = 50;
                break;
               }
               __THREW__ = 0;
               $153 = (invoke_iii(3255,($4|0),(215188|0))|0);
               $154 = __THREW__; __THREW__ = 0;
               $155 = $154&1;
               do {
                if (!($155)) {
                 $156 = HEAP32[$153>>2]|0;
                 $157 = ((($156)) + 28|0);
                 $158 = HEAP32[$157>>2]|0;
                 __THREW__ = 0;
                 $159 = (invoke_iii($158|0,($153|0),10)|0);
                 $160 = __THREW__; __THREW__ = 0;
                 $161 = $160&1;
                 if ($161) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3263,($4|0));
                 $168 = __THREW__; __THREW__ = 0;
                 $169 = $168&1;
                 if ($169) {
                  label = 50;
                  break L23;
                 }
                 __THREW__ = 0;
                 (invoke_iii(3268,($144|0),($159|0))|0);
                 $170 = __THREW__; __THREW__ = 0;
                 $171 = $170&1;
                 if ($171) {
                  label = 50;
                  break L23;
                 }
                 __THREW__ = 0;
                 (invoke_ii(3269,($144|0))|0);
                 $172 = __THREW__; __THREW__ = 0;
                 $173 = $172&1;
                 if ($173) {
                  label = 50;
                  break L23;
                 } else {
                  $220 = $120;
                  label = 68;
                  break L23;
                 }
                }
               } while(0);
               $162 = ___cxa_find_matching_catch_2()|0;
               $163 = tempRet0;
               __THREW__ = 0;
               invoke_vi(3263,($4|0));
               $164 = __THREW__; __THREW__ = 0;
               $165 = $164&1;
               if ($165) {
                $166 = ___cxa_find_matching_catch_3(0|0)|0;
                $167 = tempRet0;
                ___clang_call_terminate($166);
                // unreachable;
               } else {
                $eh$lpad$body40$index3Z2D = $163;$eh$lpad$body40$indexZ2D = $162;
                label = 51;
                break;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      } while(0);
      do {
       if ((label|0) == 68) {
        __THREW__ = 0;
        invoke_vii(3979,($1|0),($220|0));
        $221 = __THREW__; __THREW__ = 0;
        $222 = $221&1;
        if ($222) {
         label = 50;
        } else {
         $223 = ((($220)) + 60|0);
         HEAP32[$223>>2] = $2;
         if (!($61)) {
          $224 = ((($60)) + 8|0);
          $225 = HEAP32[$224>>2]|0;HEAP32[$224>>2] = (($225-1)|0);
          $226 = ($225|0)==(1);
          if ($226) {
           __THREW__ = 0;
           invoke_viii(3262,($60|0),1,1);
           $227 = __THREW__; __THREW__ = 0;
           $228 = $227&1;
           if ($228) {
            $232 = ___cxa_find_matching_catch_2()|0;
            $233 = tempRet0;
            $$0 = $232;$$012 = $233;
            break;
           }
          }
         }
         $229 = HEAP32[$7>>2]|0;
         $230 = ((($229)) + 12|0);
         $231 = HEAP32[$230>>2]|0;
         (FUNCTION_TABLE_ii[$231 & 8191]($7)|0);
         STACKTOP = sp;return;
        }
       }
      } while(0);
      if ((label|0) == 50) {
       $174 = ___cxa_find_matching_catch_2()|0;
       $175 = tempRet0;
       $eh$lpad$body40$index3Z2D = $175;$eh$lpad$body40$indexZ2D = $174;
       label = 51;
      }
      if ((label|0) == 51) {
       if ($61) {
        $$0 = $eh$lpad$body40$indexZ2D;$$012 = $eh$lpad$body40$index3Z2D;
       } else {
        $176 = ((($60)) + 8|0);
        $177 = HEAP32[$176>>2]|0;HEAP32[$176>>2] = (($177-1)|0);
        $178 = ($177|0)==(1);
        if ($178) {
         __THREW__ = 0;
         invoke_viii(3262,($60|0),1,1);
         $179 = __THREW__; __THREW__ = 0;
         $180 = $179&1;
         if ($180) {
          $350 = ___cxa_find_matching_catch_3(0|0)|0;
          $351 = tempRet0;
          ___clang_call_terminate($350);
          // unreachable;
         } else {
          $$0 = $eh$lpad$body40$indexZ2D;$$012 = $eh$lpad$body40$index3Z2D;
         }
        } else {
         $$0 = $eh$lpad$body40$indexZ2D;$$012 = $eh$lpad$body40$index3Z2D;
        }
       }
      }
      $234 = HEAP32[$0>>2]|0;
      $235 = ($234|0)==(0|0);
      if (!($235)) {
       $236 = ((($234)) + 8|0);
       $237 = HEAP32[$236>>2]|0;HEAP32[$236>>2] = (($237-1)|0);
       $238 = ($237|0)==(1);
       if ($238) {
        __THREW__ = 0;
        invoke_viii(3262,($234|0),1,1);
        $239 = __THREW__; __THREW__ = 0;
        $240 = $239&1;
        if ($240) {
         $350 = ___cxa_find_matching_catch_3(0|0)|0;
         $351 = tempRet0;
         ___clang_call_terminate($350);
         // unreachable;
        }
       }
      }
      HEAP32[$0>>2] = 0;
      $241 = HEAP32[$7>>2]|0;
      $242 = ((($241)) + 12|0);
      $243 = HEAP32[$242>>2]|0;
      __THREW__ = 0;
      (invoke_ii($243|0,($7|0))|0);
      $244 = __THREW__; __THREW__ = 0;
      $245 = $244&1;
      if ($245) {
       $350 = ___cxa_find_matching_catch_3(0|0)|0;
       $351 = tempRet0;
       ___clang_call_terminate($350);
       // unreachable;
      } else {
       $$5 = $$0;$$517 = $$012;
       ___resumeException($$5|0);
       // unreachable;
      }
     }
    }
   }
  }
 }
 _glGenTextures(1,($6|0));
 $246 = (__Znwj(80)|0);
 $247 = HEAP32[$6>>2]|0;
 __THREW__ = 0;
 invoke_vi(3853,($246|0));
 $248 = __THREW__; __THREW__ = 0;
 $249 = $248&1;
 if ($249) {
  $336 = ___cxa_find_matching_catch_2()|0;
  $337 = tempRet0;
  __ZdlPv($246);
  $$3 = $336;$$315 = $337;
 } else {
  $250 = ((($1)) + 32|0);
  HEAP32[$246>>2] = (68264);
  $251 = ((($246)) + 12|0);
  HEAP32[$251>>2] = $247;
  $252 = ((($246)) + 16|0);
  ;HEAP32[$252>>2]=HEAP32[$250>>2]|0;HEAP32[$252+4>>2]=HEAP32[$250+4>>2]|0;HEAP32[$252+8>>2]=HEAP32[$250+8>>2]|0;HEAP32[$252+12>>2]=HEAP32[$250+12>>2]|0;HEAP32[$252+16>>2]=HEAP32[$250+16>>2]|0;HEAP32[$252+20>>2]=HEAP32[$250+20>>2]|0;HEAP32[$252+24>>2]=HEAP32[$250+24>>2]|0;HEAP32[$252+28>>2]=HEAP32[$250+28>>2]|0;
  $253 = ((($246)) + 48|0);
  HEAP32[$253>>2] = 0;
  $254 = ((($246)) + 52|0);
  HEAP32[$254>>2] = 0;
  $255 = ((($246)) + 56|0);
  HEAP32[$255>>2] = 0;
  $256 = ((($246)) + 60|0);
  HEAP32[$256>>2] = $2;
  $257 = ((($246)) + 64|0);
  HEAP8[$257>>0] = 0;
  $258 = ((($246)) + 68|0);
  HEAP32[$258>>2] = 0;
  $259 = ((($246)) + 72|0);
  HEAPF64[$259>>3] = 0.0;
  $260 = ((($246)) + 8|0);
  $261 = HEAP32[$260>>2]|0;HEAP32[$260>>2] = (($261+1)|0);
  HEAP32[$253>>2] = $1;
  $262 = ((($1)) + 64|0);
  $263 = HEAP32[$262>>2]|0;
  $264 = (($263) + 1)|0;
  HEAP32[$262>>2] = $264;
  $265 = ((($1)) + 60|0);
  $266 = HEAP32[$265>>2]|0;
  $267 = HEAP32[$31>>2]|0;
  $268 = ((($267)) + 36|0);
  $269 = HEAP32[$268>>2]|0;
  $270 = (($269) + ($266))|0;
  HEAP32[$268>>2] = $270;
  $271 = ((($267)) + 28|0);
  $272 = HEAP32[$271>>2]|0;
  $273 = (($272) + 1)|0;
  HEAP32[$271>>2] = $273;
  $274 = HEAP32[$254>>2]|0;
  $275 = ($274|0)==(0|0);
  if ($275) {
   $276 = HEAP32[$255>>2]|0;
   $277 = ($276|0)==(0|0);
   if ($277) {
    $280 = ((($267)) + 56|0);
    $281 = HEAP32[$280>>2]|0;
    HEAP32[$258>>2] = $281;
    $282 = ((($1)) + 96|0);
    $283 = HEAP32[$282>>2]|0;
    $284 = ($283|0)==(0|0);
    $285 = $283;
    if (!($284)) {
     $286 = ((($283)) + 56|0);
     HEAP32[$286>>2] = $246;
    }
    HEAP32[$254>>2] = $285;
    $287 = ((($1)) + 92|0);
    $288 = HEAP32[$287>>2]|0;
    $289 = ($288|0)==(0|0);
    if ($289) {
     HEAP32[$287>>2] = $246;
    }
    HEAP32[$282>>2] = $246;
    label = 87;
   } else {
    label = 81;
   }
  } else {
   label = 81;
  }
  if ((label|0) == 81) {
   __THREW__ = 0;
   invoke_vii(3979,($1|0),($246|0));
   $278 = __THREW__; __THREW__ = 0;
   $279 = $278&1;
   if ($279) {
    label = 104;
   } else {
    label = 87;
   }
  }
  L124: do {
   if ((label|0) == 87) {
    __THREW__ = 0;
    $290 = (invoke_ii(3265,4)|0);
    $291 = __THREW__; __THREW__ = 0;
    $292 = $291&1;
    if ($292) {
     label = 104;
    } else {
     do {
      if ($290) {
       __THREW__ = 0;
       $293 = (invoke_ii(3266,4)|0);
       $294 = __THREW__; __THREW__ = 0;
       $295 = $294&1;
       if ($295) {
        label = 104;
        break L124;
       }
       __THREW__ = 0;
       $296 = (invoke_iiii(3267,($293|0),(155210|0),12)|0);
       $297 = __THREW__; __THREW__ = 0;
       $298 = $297&1;
       if ($298) {
        label = 104;
        break L124;
       }
       __THREW__ = 0;
       $299 = (invoke_iii(3275,($296|0),($1|0))|0);
       $300 = __THREW__; __THREW__ = 0;
       $301 = $300&1;
       if ($301) {
        label = 104;
        break L124;
       }
       __THREW__ = 0;
       $302 = (invoke_iiii(3267,($299|0),(155223|0),37)|0);
       $303 = __THREW__; __THREW__ = 0;
       $304 = $303&1;
       if ($304) {
        label = 104;
        break L124;
       }
       $305 = HEAP32[$262>>2]|0;
       __THREW__ = 0;
       $306 = (invoke_iii(3417,($302|0),($305|0))|0);
       $307 = __THREW__; __THREW__ = 0;
       $308 = $307&1;
       if ($308) {
        label = 104;
        break L124;
       }
       $309 = HEAP32[$306>>2]|0;
       $310 = ((($309)) + -12|0);
       $311 = HEAP32[$310>>2]|0;
       $312 = (($306) + ($311)|0);
       __THREW__ = 0;
       invoke_vii(3257,($5|0),($312|0));
       $313 = __THREW__; __THREW__ = 0;
       $314 = $313&1;
       if ($314) {
        label = 104;
        break L124;
       }
       __THREW__ = 0;
       $315 = (invoke_iii(3255,($5|0),(215188|0))|0);
       $316 = __THREW__; __THREW__ = 0;
       $317 = $316&1;
       if (!($317)) {
        $318 = HEAP32[$315>>2]|0;
        $319 = ((($318)) + 28|0);
        $320 = HEAP32[$319>>2]|0;
        __THREW__ = 0;
        $321 = (invoke_iii($320|0,($315|0),10)|0);
        $322 = __THREW__; __THREW__ = 0;
        $323 = $322&1;
        if (!($323)) {
         __THREW__ = 0;
         invoke_vi(3263,($5|0));
         $330 = __THREW__; __THREW__ = 0;
         $331 = $330&1;
         if ($331) {
          label = 104;
          break L124;
         }
         __THREW__ = 0;
         (invoke_iii(3268,($306|0),($321|0))|0);
         $332 = __THREW__; __THREW__ = 0;
         $333 = $332&1;
         if ($333) {
          label = 104;
          break L124;
         }
         __THREW__ = 0;
         (invoke_ii(3269,($306|0))|0);
         $334 = __THREW__; __THREW__ = 0;
         $335 = $334&1;
         if ($335) {
          label = 104;
          break L124;
         } else {
          break;
         }
        }
       }
       $324 = ___cxa_find_matching_catch_2()|0;
       $325 = tempRet0;
       __THREW__ = 0;
       invoke_vi(3263,($5|0));
       $326 = __THREW__; __THREW__ = 0;
       $327 = $326&1;
       if ($327) {
        $328 = ___cxa_find_matching_catch_3(0|0)|0;
        $329 = tempRet0;
        ___clang_call_terminate($328);
        // unreachable;
       } else {
        $eh$lpad$body$index9Z2D = $325;$eh$lpad$body$indexZ2D = $324;
        break L124;
       }
      }
     } while(0);
     HEAP32[$0>>2] = $246;
     $344 = HEAP32[$260>>2]|0;HEAP32[$260>>2] = (($344+1)|0);
     $345 = HEAP32[$260>>2]|0;HEAP32[$260>>2] = (($345-1)|0);
     $346 = ($345|0)==(1);
     if ($346) {
      __ZNK3osg10Referenced24signalObserversAndDeleteEbb($246,1,1);
     }
     STACKTOP = sp;return;
    }
   }
  } while(0);
  if ((label|0) == 104) {
   $338 = ___cxa_find_matching_catch_2()|0;
   $339 = tempRet0;
   $eh$lpad$body$index9Z2D = $339;$eh$lpad$body$indexZ2D = $338;
  }
  $340 = HEAP32[$260>>2]|0;HEAP32[$260>>2] = (($340-1)|0);
  $341 = ($340|0)==(1);
  if ($341) {
   __THREW__ = 0;
   invoke_viii(3262,($246|0),1,1);
   $342 = __THREW__; __THREW__ = 0;
   $343 = $342&1;
   if ($343) {
    $350 = ___cxa_find_matching_catch_3(0|0)|0;
    $351 = tempRet0;
    ___clang_call_terminate($350);
    // unreachable;
   }
  }
  $$3 = $eh$lpad$body$indexZ2D;$$315 = $eh$lpad$body$index9Z2D;
 }
 $$5 = $$3;$$517 = $$315;
 ___resumeException($$5|0);
 // unreachable;
}
function __ZN3osg20TextureObjectManagerC2Ej($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = (__Znwj(32)|0);
 HEAP32[$2>>2] = $3;
 $4 = ((($2)) + 8|0);
 HEAP32[$4>>2] = -2147483616;
 $5 = ((($2)) + 4|0);
 HEAP32[$5>>2] = 20;
 dest=$3; src=155261; stop=dest+20|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $6 = ((($3)) + 20|0);
 HEAP8[$6>>0] = 0;
 __THREW__ = 0;
 invoke_viii(3719,($0|0),($2|0),($1|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if (!($8)) {
  $9 = ((($2)) + 11|0);
  $10 = HEAP8[$9>>0]|0;
  $11 = ($10<<24>>24)<(0);
  if ($11) {
   $12 = HEAP32[$2>>2]|0;
   __ZdlPv($12);
  }
  HEAP32[$0>>2] = (67984);
  $13 = ((($0)) + 28|0);
  $14 = ((($0)) + 48|0);
  HEAP32[$14>>2] = 0;
  $15 = ((($0)) + 52|0);
  HEAP32[$15>>2] = 0;
  $16 = ((($0)) + 48|0);
  $17 = ((($0)) + 44|0);
  ;HEAP32[$13>>2]=0|0;HEAP32[$13+4>>2]=0|0;HEAP32[$13+8>>2]=0|0;HEAP32[$13+12>>2]=0|0;
  HEAP32[$17>>2] = $16;
  $18 = ((($0)) + 56|0);
  HEAP32[$18>>2] = 0;
  $19 = ((($0)) + 60|0);
  HEAP32[$19>>2] = 0;
  $20 = ((($0)) + 64|0);
  HEAP32[$20>>2] = 0;
  $21 = ((($0)) + 72|0);
  HEAPF64[$21>>3] = 0.0;
  $22 = ((($0)) + 80|0);
  HEAP32[$22>>2] = 0;
  $23 = ((($0)) + 88|0);
  HEAPF64[$23>>3] = 0.0;
  STACKTOP = sp;return;
 }
 $24 = ___cxa_find_matching_catch_2()|0;
 $25 = tempRet0;
 $26 = ((($2)) + 11|0);
 $27 = HEAP8[$26>>0]|0;
 $28 = ($27<<24>>24)<(0);
 if (!($28)) {
  ___resumeException($24|0);
  // unreachable;
 }
 $29 = HEAP32[$2>>2]|0;
 __ZdlPv($29);
 ___resumeException($24|0);
 // unreachable;
}
function __ZN3osg20TextureObjectManager21setMaxTexturePoolSizeEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = ((($0)) + 40|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==($1|0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $6 = ((($0)) + 36|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7>>>0)>($1>>>0);
 do {
  if ($8) {
   $9 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
   if ($9) {
    $10 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
    $11 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($10,155282,32)|0);
    $12 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($11,$1)|0);
    $13 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($12,155315,41)|0);
    $14 = HEAP32[$6>>2]|0;
    $15 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($13,$14)|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = ((($16)) + -12|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = (($15) + ($18)|0);
    __ZNKSt3__28ios_base6getlocEv($2,$19);
    __THREW__ = 0;
    $20 = (invoke_iii(3255,($2|0),(215188|0))|0);
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if (!($22)) {
     $23 = HEAP32[$20>>2]|0;
     $24 = ((($23)) + 28|0);
     $25 = HEAP32[$24>>2]|0;
     __THREW__ = 0;
     $26 = (invoke_iii($25|0,($20|0),10)|0);
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     if (!($28)) {
      __ZNSt3__26localeD2Ev($2);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($15,$26)|0);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($15)|0);
      break;
     }
    }
    $29 = ___cxa_find_matching_catch_2()|0;
    $30 = tempRet0;
    __THREW__ = 0;
    invoke_vi(3263,($2|0));
    $31 = __THREW__; __THREW__ = 0;
    $32 = $31&1;
    if ($32) {
     $33 = ___cxa_find_matching_catch_3(0|0)|0;
     $34 = tempRet0;
     ___clang_call_terminate($33);
     // unreachable;
    } else {
     ___resumeException($29|0);
     // unreachable;
    }
   }
  }
 } while(0);
 HEAP32[$3>>2] = $1;
 STACKTOP = sp;return;
}
function __ZN3osg20TextureObjectManager21generateTextureObjectEPKNS_7TextureEjijiiii($0,$1,$2,$3,$4,$5,$6,$7,$8,$9) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 $8 = $8|0;
 $9 = $9|0;
 var $$011$i = 0, $$01113$i = 0, $$01115$i = 0, $$012$i = 0, $$014$i = 0, $$sink$i$i$i = 0.0, $$sink$i$i$i17 = 0.0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0.0, $29 = 0.0, $30 = 0.0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0.0, $55 = 0, $56 = 0, $57 = 0.0, $58 = 0.0, $59 = 0, $60 = 0.0, $61 = 0.0, $62 = 0.0;
 var $63 = 0.0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0.0, $78 = 0, $79 = 0, $80 = 0.0, $81 = 0.0, $82 = 0;
 var $83 = 0.0, $84 = 0.0, $85 = 0.0, $86 = 0.0, $87 = 0, $88 = 0, $switch$split122D = 0, $switch$split152D = 0, $switch$split182D = 0, $switch$split2D = 0, $switch$split32D = 0, $switch$split62D = 0, $switch$split92D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $10 = sp;
 $11 = ((($1)) + 88|0);
 $12 = (__ZN3osg5Timer8instanceEv()|0);
 $13 = (__ZNK3osg5Timer4tickEv($12)|0);
 $14 = tempRet0;
 $15 = ((($1)) + 80|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + 1)|0;
 HEAP32[$15>>2] = $17;
 HEAP32[$10>>2] = $3;
 $18 = ((($10)) + 4|0);
 HEAP32[$18>>2] = $4;
 $19 = ((($10)) + 8|0);
 HEAP32[$19>>2] = $5;
 $20 = ((($10)) + 12|0);
 HEAP32[$20>>2] = $6;
 $21 = ((($10)) + 16|0);
 HEAP32[$21>>2] = $7;
 $22 = ((($10)) + 20|0);
 HEAP32[$22>>2] = $8;
 $23 = ((($10)) + 24|0);
 HEAP32[$23>>2] = $9;
 $24 = ((($10)) + 28|0);
 HEAP32[$24>>2] = 0;
 $switch$split2D = ($5|0)<(35841);
 L1: do {
  if ($switch$split2D) {
   $switch$split32D = ($5|0)<(33776);
   if (!($switch$split32D)) {
    switch ($5|0) {
    case 34025:  {
     $$012$i = 4;
     break L1;
     break;
    }
    case 34028:  {
     $$012$i = 4;
     break L1;
     break;
    }
    case 34027:  {
     $$012$i = 4;
     break L1;
     break;
    }
    case 33776:  {
     $$012$i = 4;
     break L1;
     break;
    }
    case 33777:  {
     $$012$i = 4;
     break L1;
     break;
    }
    case 34029:  {
     $$012$i = 8;
     break L1;
     break;
    }
    case 33778:  {
     $$012$i = 8;
     break L1;
     break;
    }
    case 33779:  {
     $$012$i = 8;
     break L1;
     break;
    }
    case 35840:  {
     $$012$i = 4;
     break L1;
     break;
    }
    default: {
     $$012$i = 32;
     break L1;
    }
    }
   }
   $switch$split62D = ($5|0)<(6407);
   if ($switch$split62D) {
    $switch$split92D = ($5|0)<(3);
    if ($switch$split92D) {
     switch ($5|0) {
     case 1:  {
      $$012$i = 8;
      break L1;
      break;
     }
     case 2:  {
      $$012$i = 16;
      break L1;
      break;
     }
     default: {
      $$012$i = 32;
      break L1;
     }
     }
    }
    $switch$split152D = ($5|0)<(6406);
    if ($switch$split152D) {
     switch ($5|0) {
     case 3:  {
      break;
     }
     default: {
      $$012$i = 32;
      break L1;
     }
     }
     $$012$i = 24;
     break;
    } else {
     switch ($5|0) {
     case 6406:  {
      break;
     }
     default: {
      $$012$i = 32;
      break L1;
     }
     }
     $$012$i = 8;
     break;
    }
   }
   $switch$split122D = ($5|0)<(6410);
   if ($switch$split122D) {
    switch ($5|0) {
    case 6409:  {
     $$012$i = 8;
     break L1;
     break;
    }
    case 6407:  {
     $$012$i = 24;
     break L1;
     break;
    }
    default: {
     $$012$i = 32;
     break L1;
    }
    }
   }
   $switch$split182D = ($5|0)<(32841);
   if ($switch$split182D) {
    switch ($5|0) {
    case 6410:  {
     break;
    }
    default: {
     $$012$i = 32;
     break L1;
    }
    }
    $$012$i = 16;
    break;
   }
   switch ($5|0) {
   case 32841:  {
    $$012$i = 8;
    break L1;
    break;
   }
   case 32992:  {
    $$012$i = 24;
    break L1;
    break;
   }
   default: {
    $$012$i = 32;
    break L1;
   }
   }
  } else {
   do {
    switch ($5|0) {
    case 37491:  {
     $$012$i = 8;
     break L1;
     break;
    }
    case 37490:  {
     $$012$i = 8;
     break L1;
     break;
    }
    case 36284:  {
     $$012$i = 4;
     break L1;
     break;
    }
    case 36283:  {
     $$012$i = 4;
     break L1;
     break;
    }
    case 36286:  {
     $$012$i = 8;
     break L1;
     break;
    }
    case 36285:  {
     $$012$i = 8;
     break L1;
     break;
    }
    case 35841:  {
     $$012$i = 2;
     break L1;
     break;
    }
    case 35843:  {
     $$012$i = 2;
     break L1;
     break;
    }
    case 35842:  {
     $$012$i = 4;
     break L1;
     break;
    }
    case 36196:  {
     $$012$i = 4;
     break L1;
     break;
    }
    case 37492:  {
     $$012$i = 4;
     break L1;
     break;
    }
    case 37493:  {
     $$012$i = 4;
     break L1;
     break;
    }
    case 37494:  {
     $$012$i = 8;
     break L1;
     break;
    }
    case 37495:  {
     $$012$i = 8;
     break L1;
     break;
    }
    case 37496:  {
     $$012$i = 8;
     break L1;
     break;
    }
    case 37497:  {
     $$012$i = 8;
     break L1;
     break;
    }
    case 37488:  {
     $$012$i = 4;
     break L1;
     break;
    }
    case 37489:  {
     $$012$i = 4;
     break L1;
     break;
    }
    default: {
     $$012$i = 32;
     break L1;
    }
    }
   } while(0);
  }
 } while(0);
 $25 = Math_imul($$012$i, $6)|0;
 $26 = Math_imul($25, $7)|0;
 $27 = Math_imul($26, $8)|0;
 $28 = (+($27>>>0));
 $29 = $28 * 0.125;
 $30 = (+Math_ceil((+$29)));
 $31 = (~~(($30))>>>0);
 HEAP32[$24>>2] = $31;
 $32 = ($4|0)>(1);
 if ($32) {
  $$01113$i = $31 >>> 2;
  $33 = ($$01113$i|0)==(0);
  if (!($33)) {
   $$01115$i = $$01113$i;$$014$i = 0;$35 = $31;
   while(1) {
    $34 = (($$01115$i) + ($35))|0;
    $36 = (($$014$i) + 1)|0;
    $$011$i = $$01115$i >>> 2;
    $37 = ($36|0)<($4|0);
    $38 = ($$011$i|0)!=(0);
    $39 = $38 & $37;
    if ($39) {
     $$01115$i = $$011$i;$$014$i = $36;$35 = $34;
    } else {
     break;
    }
   }
   HEAP32[$24>>2] = $34;
  }
 }
 __THREW__ = 0;
 $40 = (invoke_iii(3981,($1|0),($10|0))|0);
 $41 = __THREW__; __THREW__ = 0;
 $42 = $41&1;
 if (!($42)) {
  __THREW__ = 0;
  invoke_viii(3982,($0|0),($40|0),($2|0));
  $43 = __THREW__; __THREW__ = 0;
  $44 = $43&1;
  if (!($44)) {
   $45 = (__ZNK3osg5Timer4tickEv($12)|0);
   $46 = tempRet0;
   $47 = ($46>>>0)>($14>>>0);
   $48 = ($45>>>0)>($13>>>0);
   $49 = ($46|0)==($14|0);
   $50 = $49 & $48;
   $51 = $47 | $50;
   if ($51) {
    $52 = (_i64Subtract(($45|0),($46|0),($13|0),($14|0))|0);
    $53 = tempRet0;
    $54 = (+($52>>>0)) + (4294967296.0*(+($53>>>0)));
    $$sink$i$i$i = $54;
    $59 = ((($12)) + 8|0);
    $60 = +HEAPF64[$59>>3];
    $61 = $$sink$i$i$i * $60;
    $62 = +HEAPF64[$11>>3];
    $63 = $61 + $62;
    HEAPF64[$11>>3] = $63;
    STACKTOP = sp;return;
   } else {
    $55 = (_i64Subtract(($13|0),($14|0),($45|0),($46|0))|0);
    $56 = tempRet0;
    $57 = (+($55>>>0)) + (4294967296.0*(+($56>>>0)));
    $58 = -$57;
    $$sink$i$i$i = $58;
    $59 = ((($12)) + 8|0);
    $60 = +HEAPF64[$59>>3];
    $61 = $$sink$i$i$i * $60;
    $62 = +HEAPF64[$11>>3];
    $63 = $61 + $62;
    HEAPF64[$11>>3] = $63;
    STACKTOP = sp;return;
   }
  }
 }
 $64 = ___cxa_find_matching_catch_2()|0;
 $65 = tempRet0;
 __THREW__ = 0;
 $66 = (invoke_ii(3385,($12|0))|0);
 $67 = tempRet0;
 $68 = __THREW__; __THREW__ = 0;
 $69 = $68&1;
 if ($69) {
  $87 = ___cxa_find_matching_catch_3(0|0)|0;
  $88 = tempRet0;
  ___clang_call_terminate($87);
  // unreachable;
 }
 $70 = ($67>>>0)>($14>>>0);
 $71 = ($66>>>0)>($13>>>0);
 $72 = ($67|0)==($14|0);
 $73 = $72 & $71;
 $74 = $70 | $73;
 if ($74) {
  $75 = (_i64Subtract(($66|0),($67|0),($13|0),($14|0))|0);
  $76 = tempRet0;
  $77 = (+($75>>>0)) + (4294967296.0*(+($76>>>0)));
  $$sink$i$i$i17 = $77;
  $82 = ((($12)) + 8|0);
  $83 = +HEAPF64[$82>>3];
  $84 = $$sink$i$i$i17 * $83;
  $85 = +HEAPF64[$11>>3];
  $86 = $84 + $85;
  HEAPF64[$11>>3] = $86;
  ___resumeException($64|0);
  // unreachable;
 } else {
  $78 = (_i64Subtract(($13|0),($14|0),($66|0),($67|0))|0);
  $79 = tempRet0;
  $80 = (+($78>>>0)) + (4294967296.0*(+($79>>>0)));
  $81 = -$80;
  $$sink$i$i$i17 = $81;
  $82 = ((($12)) + 8|0);
  $83 = +HEAPF64[$82>>3];
  $84 = $$sink$i$i$i17 * $83;
  $85 = +HEAPF64[$11>>3];
  $86 = $84 + $85;
  HEAPF64[$11>>3] = $86;
  ___resumeException($64|0);
  // unreachable;
 }
}
function __ZNK3osg7Texture30generateAndAssignTextureObjectEjj($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$pr = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = (__ZN3osg22getOrCreateContextDataEj($1)|0);
 $5 = (__ZN3osg11ContextData3getINS_20TextureObjectManagerEEEPT_v($4)|0);
 __ZN3osg20TextureObjectManager21generateTextureObjectEPKNS_7TextureEjijiiii($3,$5,$0,$2,0,0,0,0,0,0);
 $6 = ((($0)) + 224|0);
 $7 = ((($0)) + 228|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$6>>2]|0;
 $10 = (($8) - ($9))|0;
 $11 = $10 >> 2;
 $12 = ($11>>>0)>($1>>>0);
 L1: do {
  if ($12) {
   label = 11;
  } else {
   $13 = (($1) + 1)|0;
   $14 = ($13>>>0)>($11>>>0);
   $15 = $9;
   $16 = $8;
   if ($14) {
    $17 = (($13) - ($11))|0;
    __THREW__ = 0;
    invoke_vii(3967,($6|0),($17|0));
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     break;
    } else {
     label = 11;
     break;
    }
   }
   $20 = ($13>>>0)<($11>>>0);
   if ($20) {
    $21 = (($15) + ($13<<2)|0);
    $22 = ($16|0)==($21|0);
    if ($22) {
     label = 11;
    } else {
     $24 = $16;
     while(1) {
      $23 = ((($24)) + -4|0);
      HEAP32[$7>>2] = $23;
      $25 = HEAP32[$23>>2]|0;
      $26 = ($25|0)==(0|0);
      if (!($26)) {
       $27 = ((($25)) + 8|0);
       $28 = HEAP32[$27>>2]|0;HEAP32[$27>>2] = (($28-1)|0);
       $29 = ($28|0)==(1);
       if ($29) {
        __THREW__ = 0;
        invoke_viii(3262,($25|0),1,1);
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if ($31) {
         break;
        }
       }
      }
      HEAP32[$23>>2] = 0;
      $32 = HEAP32[$7>>2]|0;
      $33 = ($32|0)==($21|0);
      if ($33) {
       label = 11;
       break L1;
      } else {
       $24 = $32;
      }
     }
     $34 = ___cxa_find_matching_catch_2()|0;
     $35 = tempRet0;
     ___cxa_call_unexpected(($34|0));
     // unreachable;
    }
   } else {
    label = 11;
   }
  }
 } while(0);
 do {
  if ((label|0) == 11) {
   $36 = HEAP32[$6>>2]|0;
   $37 = (($36) + ($1<<2)|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = HEAP32[$3>>2]|0;
   $40 = ($38|0)==($39|0);
   if ($40) {
    $50 = $38;
   } else {
    HEAP32[$37>>2] = $39;
    $41 = ($39|0)==(0|0);
    if (!($41)) {
     $42 = ((($39)) + 8|0);
     $43 = HEAP32[$42>>2]|0;HEAP32[$42>>2] = (($43+1)|0);
    }
    $44 = ($38|0)==(0|0);
    if (!($44)) {
     $45 = ((($38)) + 8|0);
     $46 = HEAP32[$45>>2]|0;HEAP32[$45>>2] = (($46-1)|0);
     $47 = ($46|0)==(1);
     if ($47) {
      __THREW__ = 0;
      invoke_viii(3262,($38|0),1,1);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       break;
      }
     }
    }
    $$pr = HEAP32[$3>>2]|0;
    $50 = $$pr;
   }
   $51 = ($50|0)==(0|0);
   if (!($51)) {
    $52 = ((($50)) + 8|0);
    $53 = HEAP32[$52>>2]|0;HEAP32[$52>>2] = (($53-1)|0);
    $54 = ($53|0)==(1);
    if ($54) {
     __ZNK3osg10Referenced24signalObserversAndDeleteEbb($50,1,1);
    }
   }
   $55 = HEAP32[$7>>2]|0;
   $56 = HEAP32[$6>>2]|0;
   $57 = (($55) - ($56))|0;
   $58 = $57 >> 2;
   $59 = ($58>>>0)>($1>>>0);
   if ($59) {
    $81 = HEAP32[$6>>2]|0;
    $82 = (($81) + ($1<<2)|0);
    $83 = HEAP32[$82>>2]|0;
    STACKTOP = sp;return ($83|0);
   }
   $60 = (($1) + 1)|0;
   $61 = ($60>>>0)>($58>>>0);
   $62 = $56;
   $63 = $55;
   if ($61) {
    $64 = (($60) - ($58))|0;
    __ZNSt3__26vectorIN3osg7ref_ptrINS1_7Texture13TextureObjectEEENS_9allocatorIS5_EEE8__appendEj($6,$64);
    $81 = HEAP32[$6>>2]|0;
    $82 = (($81) + ($1<<2)|0);
    $83 = HEAP32[$82>>2]|0;
    STACKTOP = sp;return ($83|0);
   }
   $65 = ($60>>>0)<($58>>>0);
   if (!($65)) {
    $81 = HEAP32[$6>>2]|0;
    $82 = (($81) + ($1<<2)|0);
    $83 = HEAP32[$82>>2]|0;
    STACKTOP = sp;return ($83|0);
   }
   $66 = (($62) + ($60<<2)|0);
   $67 = ($63|0)==($66|0);
   if ($67) {
    $81 = HEAP32[$6>>2]|0;
    $82 = (($81) + ($1<<2)|0);
    $83 = HEAP32[$82>>2]|0;
    STACKTOP = sp;return ($83|0);
   } else {
    $69 = $63;
   }
   while(1) {
    $68 = ((($69)) + -4|0);
    HEAP32[$7>>2] = $68;
    $70 = HEAP32[$68>>2]|0;
    $71 = ($70|0)==(0|0);
    if (!($71)) {
     $72 = ((($70)) + 8|0);
     $73 = HEAP32[$72>>2]|0;HEAP32[$72>>2] = (($73-1)|0);
     $74 = ($73|0)==(1);
     if ($74) {
      __THREW__ = 0;
      invoke_viii(3262,($70|0),1,1);
      $75 = __THREW__; __THREW__ = 0;
      $76 = $75&1;
      if ($76) {
       label = 30;
       break;
      }
     }
    }
    HEAP32[$68>>2] = 0;
    $77 = HEAP32[$7>>2]|0;
    $78 = ($77|0)==($66|0);
    if ($78) {
     label = 31;
     break;
    } else {
     $69 = $77;
    }
   }
   if ((label|0) == 30) {
    $79 = ___cxa_find_matching_catch_2()|0;
    $80 = tempRet0;
    ___cxa_call_unexpected(($79|0));
    // unreachable;
   }
   else if ((label|0) == 31) {
    $81 = HEAP32[$6>>2]|0;
    $82 = (($81) + ($1<<2)|0);
    $83 = HEAP32[$82>>2]|0;
    STACKTOP = sp;return ($83|0);
   }
  }
 } while(0);
 $84 = ___cxa_find_matching_catch_2()|0;
 $85 = tempRet0;
 $86 = HEAP32[$3>>2]|0;
 $87 = ($86|0)==(0|0);
 if ($87) {
  ___resumeException($84|0);
  // unreachable;
 }
 $88 = ((($86)) + 8|0);
 $89 = HEAP32[$88>>2]|0;HEAP32[$88>>2] = (($89-1)|0);
 $90 = ($89|0)==(1);
 if (!($90)) {
  ___resumeException($84|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(3262,($86|0),1,1);
 $91 = __THREW__; __THREW__ = 0;
 $92 = $91&1;
 if ($92) {
  $93 = ___cxa_find_matching_catch_3(0|0)|0;
  $94 = tempRet0;
  ___clang_call_terminate($93);
  // unreachable;
 } else {
  ___resumeException($84|0);
  // unreachable;
 }
 return (0)|0;
}
function __ZNK3osg7Texture30generateAndAssignTextureObjectEjjijiiii($0,$1,$2,$3,$4,$5,$6,$7,$8) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 $8 = $8|0;
 var $$pr = 0, $10 = 0, $100 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $9 = sp;
 $10 = (__ZN3osg22getOrCreateContextDataEj($1)|0);
 $11 = (__ZN3osg11ContextData3getINS_20TextureObjectManagerEEEPT_v($10)|0);
 __ZN3osg20TextureObjectManager21generateTextureObjectEPKNS_7TextureEjijiiii($9,$11,$0,$2,$3,$4,$5,$6,$7,$8);
 $12 = ((($0)) + 224|0);
 $13 = ((($0)) + 228|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP32[$12>>2]|0;
 $16 = (($14) - ($15))|0;
 $17 = $16 >> 2;
 $18 = ($17>>>0)>($1>>>0);
 L1: do {
  if ($18) {
   label = 11;
  } else {
   $19 = (($1) + 1)|0;
   $20 = ($19>>>0)>($17>>>0);
   $21 = $15;
   $22 = $14;
   if ($20) {
    $23 = (($19) - ($17))|0;
    __THREW__ = 0;
    invoke_vii(3967,($12|0),($23|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    } else {
     label = 11;
     break;
    }
   }
   $26 = ($19>>>0)<($17>>>0);
   if ($26) {
    $27 = (($21) + ($19<<2)|0);
    $28 = ($22|0)==($27|0);
    if ($28) {
     label = 11;
    } else {
     $30 = $22;
     while(1) {
      $29 = ((($30)) + -4|0);
      HEAP32[$13>>2] = $29;
      $31 = HEAP32[$29>>2]|0;
      $32 = ($31|0)==(0|0);
      if (!($32)) {
       $33 = ((($31)) + 8|0);
       $34 = HEAP32[$33>>2]|0;HEAP32[$33>>2] = (($34-1)|0);
       $35 = ($34|0)==(1);
       if ($35) {
        __THREW__ = 0;
        invoke_viii(3262,($31|0),1,1);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break;
        }
       }
      }
      HEAP32[$29>>2] = 0;
      $38 = HEAP32[$13>>2]|0;
      $39 = ($38|0)==($27|0);
      if ($39) {
       label = 11;
       break L1;
      } else {
       $30 = $38;
      }
     }
     $40 = ___cxa_find_matching_catch_2()|0;
     $41 = tempRet0;
     ___cxa_call_unexpected(($40|0));
     // unreachable;
    }
   } else {
    label = 11;
   }
  }
 } while(0);
 do {
  if ((label|0) == 11) {
   $42 = HEAP32[$12>>2]|0;
   $43 = (($42) + ($1<<2)|0);
   $44 = HEAP32[$43>>2]|0;
   $45 = HEAP32[$9>>2]|0;
   $46 = ($44|0)==($45|0);
   if ($46) {
    $56 = $44;
   } else {
    HEAP32[$43>>2] = $45;
    $47 = ($45|0)==(0|0);
    if (!($47)) {
     $48 = ((($45)) + 8|0);
     $49 = HEAP32[$48>>2]|0;HEAP32[$48>>2] = (($49+1)|0);
    }
    $50 = ($44|0)==(0|0);
    if (!($50)) {
     $51 = ((($44)) + 8|0);
     $52 = HEAP32[$51>>2]|0;HEAP32[$51>>2] = (($52-1)|0);
     $53 = ($52|0)==(1);
     if ($53) {
      __THREW__ = 0;
      invoke_viii(3262,($44|0),1,1);
      $54 = __THREW__; __THREW__ = 0;
      $55 = $54&1;
      if ($55) {
       break;
      }
     }
    }
    $$pr = HEAP32[$9>>2]|0;
    $56 = $$pr;
   }
   $57 = ($56|0)==(0|0);
   if (!($57)) {
    $58 = ((($56)) + 8|0);
    $59 = HEAP32[$58>>2]|0;HEAP32[$58>>2] = (($59-1)|0);
    $60 = ($59|0)==(1);
    if ($60) {
     __ZNK3osg10Referenced24signalObserversAndDeleteEbb($56,1,1);
    }
   }
   $61 = HEAP32[$13>>2]|0;
   $62 = HEAP32[$12>>2]|0;
   $63 = (($61) - ($62))|0;
   $64 = $63 >> 2;
   $65 = ($64>>>0)>($1>>>0);
   if ($65) {
    $87 = HEAP32[$12>>2]|0;
    $88 = (($87) + ($1<<2)|0);
    $89 = HEAP32[$88>>2]|0;
    STACKTOP = sp;return ($89|0);
   }
   $66 = (($1) + 1)|0;
   $67 = ($66>>>0)>($64>>>0);
   $68 = $62;
   $69 = $61;
   if ($67) {
    $70 = (($66) - ($64))|0;
    __ZNSt3__26vectorIN3osg7ref_ptrINS1_7Texture13TextureObjectEEENS_9allocatorIS5_EEE8__appendEj($12,$70);
    $87 = HEAP32[$12>>2]|0;
    $88 = (($87) + ($1<<2)|0);
    $89 = HEAP32[$88>>2]|0;
    STACKTOP = sp;return ($89|0);
   }
   $71 = ($66>>>0)<($64>>>0);
   if (!($71)) {
    $87 = HEAP32[$12>>2]|0;
    $88 = (($87) + ($1<<2)|0);
    $89 = HEAP32[$88>>2]|0;
    STACKTOP = sp;return ($89|0);
   }
   $72 = (($68) + ($66<<2)|0);
   $73 = ($69|0)==($72|0);
   if ($73) {
    $87 = HEAP32[$12>>2]|0;
    $88 = (($87) + ($1<<2)|0);
    $89 = HEAP32[$88>>2]|0;
    STACKTOP = sp;return ($89|0);
   } else {
    $75 = $69;
   }
   while(1) {
    $74 = ((($75)) + -4|0);
    HEAP32[$13>>2] = $74;
    $76 = HEAP32[$74>>2]|0;
    $77 = ($76|0)==(0|0);
    if (!($77)) {
     $78 = ((($76)) + 8|0);
     $79 = HEAP32[$78>>2]|0;HEAP32[$78>>2] = (($79-1)|0);
     $80 = ($79|0)==(1);
     if ($80) {
      __THREW__ = 0;
      invoke_viii(3262,($76|0),1,1);
      $81 = __THREW__; __THREW__ = 0;
      $82 = $81&1;
      if ($82) {
       label = 30;
       break;
      }
     }
    }
    HEAP32[$74>>2] = 0;
    $83 = HEAP32[$13>>2]|0;
    $84 = ($83|0)==($72|0);
    if ($84) {
     label = 31;
     break;
    } else {
     $75 = $83;
    }
   }
   if ((label|0) == 30) {
    $85 = ___cxa_find_matching_catch_2()|0;
    $86 = tempRet0;
    ___cxa_call_unexpected(($85|0));
    // unreachable;
   }
   else if ((label|0) == 31) {
    $87 = HEAP32[$12>>2]|0;
    $88 = (($87) + ($1<<2)|0);
    $89 = HEAP32[$88>>2]|0;
    STACKTOP = sp;return ($89|0);
   }
  }
 } while(0);
 $90 = ___cxa_find_matching_catch_2()|0;
 $91 = tempRet0;
 $92 = HEAP32[$9>>2]|0;
 $93 = ($92|0)==(0|0);
 if ($93) {
  ___resumeException($90|0);
  // unreachable;
 }
 $94 = ((($92)) + 8|0);
 $95 = HEAP32[$94>>2]|0;HEAP32[$94>>2] = (($95-1)|0);
 $96 = ($95|0)==(1);
 if (!($96)) {
  ___resumeException($90|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(3262,($92|0),1,1);
 $97 = __THREW__; __THREW__ = 0;
 $98 = $97&1;
 if ($98) {
  $99 = ___cxa_find_matching_catch_3(0|0)|0;
  $100 = tempRet0;
  ___clang_call_terminate($99);
  // unreachable;
 } else {
  ___resumeException($90|0);
  // unreachable;
 }
 return (0)|0;
}
function __ZN3osg7TextureC2Ev($0) {
 $0 = $0|0;
 var $$0 = 0, $$02 = 0, $$1 = 0, $$13 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index3Z2D = 0, $eh$lpad$body$indexZ2D = 0, $eh$lpad$body16$index10Z2D = 0, $eh$lpad$body16$indexZ2D = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i8 = 0, $scevgep$i$i$i$i21 = 0, $scevgep5$i$i$i$i = 0, $scevgep5$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i9 = 0, $scevgep5$i$i$i$i22 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 __ZN3osg14StateAttributeC2Ev($0);
 HEAP32[$0>>2] = (68036);
 $1 = ((($0)) + 56|0);
 __THREW__ = 0;
 $2 = (invoke_i(3285)|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 L1: do {
  if ($4) {
   label = 27;
  } else {
   $5 = HEAP32[$2>>2]|0;
   __THREW__ = 0;
   $6 = (invoke_ii(3286,($5|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    label = 27;
   } else {
    HEAP32[$1>>2] = 0;
    $9 = ((($0)) + 60|0);
    HEAP32[$9>>2] = 0;
    $10 = ((($0)) + 64|0);
    HEAP32[$10>>2] = 0;
    $11 = ($6|0)==(0);
    do {
     if (!($11)) {
      $12 = ($6>>>0)>(1073741823);
      if ($12) {
       __THREW__ = 0;
       invoke_vi(3307,($1|0));
       $13 = __THREW__; __THREW__ = 0;
      } else {
       $14 = $6 << 2;
       __THREW__ = 0;
       $15 = (invoke_ii(3276,($14|0))|0);
       $16 = __THREW__; __THREW__ = 0;
       $17 = $16&1;
       if (!($17)) {
        HEAP32[$1>>2] = $15;
        $18 = (($15) + ($6<<2)|0);
        $19 = ((($0)) + 64|0);
        HEAP32[$19>>2] = $18;
        _memset(($15|0),0,($14|0))|0;
        HEAP32[$9>>2] = $18;
        break;
       }
      }
      $20 = ___cxa_find_matching_catch_2()|0;
      $21 = tempRet0;
      $22 = HEAP32[$1>>2]|0;
      $23 = ($22|0)==(0|0);
      if ($23) {
       $eh$lpad$body$index3Z2D = $21;$eh$lpad$body$indexZ2D = $20;
       label = 28;
       break L1;
      }
      $24 = HEAP32[$9>>2]|0;
      $25 = ($24|0)==($22|0);
      if (!($25)) {
       $scevgep$i$i$i$i$i = ((($24)) + -4|0);
       $26 = $scevgep$i$i$i$i$i;
       $27 = $22;
       $28 = (($26) - ($27))|0;
       $29 = $28 >>> 2;
       $30 = $29 ^ -1;
       $scevgep5$i$i$i$i$i = (($24) + ($30<<2)|0);
       HEAP32[$9>>2] = $scevgep5$i$i$i$i$i;
      }
      __ZdlPv($22);
      $eh$lpad$body$index3Z2D = $21;$eh$lpad$body$indexZ2D = $20;
      label = 28;
      break L1;
     }
    } while(0);
    $31 = ((($0)) + 68|0);
    __THREW__ = 0;
    $32 = (invoke_i(3285)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    L16: do {
     if ($34) {
      label = 29;
     } else {
      $35 = HEAP32[$32>>2]|0;
      __THREW__ = 0;
      $36 = (invoke_ii(3286,($35|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       label = 29;
      } else {
       HEAP32[$31>>2] = 0;
       $39 = ((($0)) + 72|0);
       HEAP32[$39>>2] = 0;
       $40 = ((($0)) + 76|0);
       HEAP32[$40>>2] = 0;
       $41 = ($36|0)==(0);
       do {
        if (!($41)) {
         $42 = ($36>>>0)>(1073741823);
         if ($42) {
          __THREW__ = 0;
          invoke_vi(3307,($31|0));
          $43 = __THREW__; __THREW__ = 0;
         } else {
          $44 = $36 << 2;
          __THREW__ = 0;
          $45 = (invoke_ii(3276,($44|0))|0);
          $46 = __THREW__; __THREW__ = 0;
          $47 = $46&1;
          if (!($47)) {
           HEAP32[$31>>2] = $45;
           $48 = (($45) + ($36<<2)|0);
           $49 = ((($0)) + 76|0);
           HEAP32[$49>>2] = $48;
           _memset(($45|0),0,($44|0))|0;
           HEAP32[$39>>2] = $48;
           break;
          }
         }
         $50 = ___cxa_find_matching_catch_2()|0;
         $51 = tempRet0;
         $52 = HEAP32[$31>>2]|0;
         $53 = ($52|0)==(0|0);
         if ($53) {
          $eh$lpad$body16$index10Z2D = $51;$eh$lpad$body16$indexZ2D = $50;
          label = 30;
          break L16;
         }
         $54 = HEAP32[$39>>2]|0;
         $55 = ($54|0)==($52|0);
         if (!($55)) {
          $scevgep$i$i$i$i$i8 = ((($54)) + -4|0);
          $56 = $scevgep$i$i$i$i$i8;
          $57 = $52;
          $58 = (($56) - ($57))|0;
          $59 = $58 >>> 2;
          $60 = $59 ^ -1;
          $scevgep5$i$i$i$i$i9 = (($54) + ($60<<2)|0);
          HEAP32[$39>>2] = $scevgep5$i$i$i$i$i9;
         }
         __ZdlPv($52);
         $eh$lpad$body16$index10Z2D = $51;$eh$lpad$body16$indexZ2D = $50;
         label = 30;
         break L16;
        }
       } while(0);
       $61 = ((($0)) + 80|0);
       HEAP32[$61>>2] = 10496;
       $62 = ((($0)) + 84|0);
       HEAP32[$62>>2] = 10496;
       $63 = ((($0)) + 88|0);
       HEAP32[$63>>2] = 10496;
       $64 = ((($0)) + 92|0);
       HEAP32[$64>>2] = 9987;
       $65 = ((($0)) + 96|0);
       HEAP32[$65>>2] = 9729;
       $66 = ((($0)) + 100|0);
       HEAPF32[$66>>2] = 1.0;
       $67 = ((($0)) + 104|0);
       HEAP32[$67>>2] = 6403;
       $68 = ((($0)) + 108|0);
       HEAP32[$68>>2] = 6404;
       $69 = ((($0)) + 112|0);
       HEAP32[$69>>2] = 6405;
       $70 = ((($0)) + 116|0);
       HEAP32[$70>>2] = 6406;
       $71 = ((($0)) + 120|0);
       HEAP8[$71>>0] = 1;
       $72 = ((($0)) + 121|0);
       HEAP8[$72>>0] = 0;
       $73 = ((($0)) + 122|0);
       HEAP8[$73>>0] = 0;
       $74 = ((($0)) + 123|0);
       HEAP8[$74>>0] = 1;
       $75 = ((($0)) + 128|0);
       $76 = ((($0)) + 188|0);
       dest=$75; stop=dest+56|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));HEAP8[$75+56>>0]=0|0;
       HEAP32[$76>>2] = 515;
       $77 = ((($0)) + 192|0);
       HEAP32[$77>>2] = 6409;
       $78 = ((($0)) + 196|0);
       $79 = ((($0)) + 212|0);
       HEAP32[$79>>2] = 0;
       $80 = ((($0)) + 216|0);
       HEAP32[$80>>2] = 0;
       $81 = ((($0)) + 220|0);
       HEAP32[$81>>2] = 0;
       $82 = ((($0)) + 224|0);
       ;HEAP32[$78>>2]=0|0;HEAP32[$78+4>>2]=0|0;HEAP32[$78+8>>2]=0|0;HEAP8[$78+12>>0]=0|0;
       __THREW__ = 0;
       $83 = (invoke_i(3285)|0);
       $84 = __THREW__; __THREW__ = 0;
       $85 = $84&1;
       if (!($85)) {
        $86 = HEAP32[$83>>2]|0;
        __THREW__ = 0;
        $87 = (invoke_ii(3286,($86|0))|0);
        $88 = __THREW__; __THREW__ = 0;
        $89 = $88&1;
        if (!($89)) {
         __THREW__ = 0;
         invoke_vii(3983,($82|0),($87|0));
         $90 = __THREW__; __THREW__ = 0;
         $91 = $90&1;
         if (!($91)) {
          $92 = ((($0)) + 236|0);
          HEAP32[$92>>2] = 0;
          return;
         }
        }
       }
       $97 = ___cxa_find_matching_catch_2()|0;
       $98 = tempRet0;
       $99 = HEAP32[$31>>2]|0;
       $100 = ($99|0)==(0|0);
       if ($100) {
        $$0 = $98;$$02 = $97;
       } else {
        $101 = HEAP32[$39>>2]|0;
        $102 = ($101|0)==($99|0);
        if (!($102)) {
         $scevgep$i$i$i$i = ((($101)) + -4|0);
         $103 = $scevgep$i$i$i$i;
         $104 = $99;
         $105 = (($103) - ($104))|0;
         $106 = $105 >>> 2;
         $107 = $106 ^ -1;
         $scevgep5$i$i$i$i = (($101) + ($107<<2)|0);
         HEAP32[$39>>2] = $scevgep5$i$i$i$i;
        }
        __ZdlPv($99);
        $$0 = $98;$$02 = $97;
       }
      }
     }
    } while(0);
    if ((label|0) == 29) {
     $95 = ___cxa_find_matching_catch_2()|0;
     $96 = tempRet0;
     $eh$lpad$body16$index10Z2D = $96;$eh$lpad$body16$indexZ2D = $95;
     label = 30;
    }
    if ((label|0) == 30) {
     $$0 = $eh$lpad$body16$index10Z2D;$$02 = $eh$lpad$body16$indexZ2D;
    }
    $108 = HEAP32[$1>>2]|0;
    $109 = ($108|0)==(0|0);
    if ($109) {
     $$1 = $$0;$$13 = $$02;
    } else {
     $110 = HEAP32[$9>>2]|0;
     $111 = ($110|0)==($108|0);
     if (!($111)) {
      $scevgep$i$i$i$i21 = ((($110)) + -4|0);
      $112 = $scevgep$i$i$i$i21;
      $113 = $108;
      $114 = (($112) - ($113))|0;
      $115 = $114 >>> 2;
      $116 = $115 ^ -1;
      $scevgep5$i$i$i$i22 = (($110) + ($116<<2)|0);
      HEAP32[$9>>2] = $scevgep5$i$i$i$i22;
     }
     __ZdlPv($108);
     $$1 = $$0;$$13 = $$02;
    }
   }
  }
 } while(0);
 if ((label|0) == 27) {
  $93 = ___cxa_find_matching_catch_2()|0;
  $94 = tempRet0;
  $eh$lpad$body$index3Z2D = $94;$eh$lpad$body$indexZ2D = $93;
  label = 28;
 }
 if ((label|0) == 28) {
  $$1 = $eh$lpad$body$index3Z2D;$$13 = $eh$lpad$body$indexZ2D;
 }
 __THREW__ = 0;
 invoke_vi(1573,($0|0));
 $117 = __THREW__; __THREW__ = 0;
 $118 = $117&1;
 if ($118) {
  $119 = ___cxa_find_matching_catch_3(0|0)|0;
  $120 = tempRet0;
  ___clang_call_terminate($119);
  // unreachable;
 } else {
  ___resumeException($$13|0);
  // unreachable;
 }
}
function __ZNSt3__26vectorIN3osg7ref_ptrINS1_7Texture13TextureObjectEEENS_9allocatorIS5_EEEC2Ej($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$pre$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = 0;
 $2 = ((($0)) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = ((($0)) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = ($1|0)==(0);
 if ($4) {
  return;
 }
 $5 = ($1>>>0)>(1073741823);
 if ($5) {
  __THREW__ = 0;
  invoke_vi(3307,($0|0));
  $6 = __THREW__; __THREW__ = 0;
 } else {
  $7 = $1 << 2;
  __THREW__ = 0;
  $8 = (invoke_ii(3276,($7|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   HEAP32[$0>>2] = $8;
   $11 = (($8) + ($1<<2)|0);
   $12 = ((($0)) + 8|0);
   HEAP32[$12>>2] = $11;
   _memset(($8|0),0,($7|0))|0;
   HEAP32[$2>>2] = $11;
   return;
  }
 }
 $13 = ___cxa_find_matching_catch_2()|0;
 $14 = tempRet0;
 $15 = HEAP32[$0>>2]|0;
 $16 = ($15|0)==(0|0);
 if ($16) {
  ___resumeException($13|0);
  // unreachable;
 }
 $17 = HEAP32[$2>>2]|0;
 $18 = ($17|0)==($15|0);
 do {
  if ($18) {
   $32 = $15;
  } else {
   $20 = $17;
   while(1) {
    $19 = ((($20)) + -4|0);
    HEAP32[$2>>2] = $19;
    $21 = HEAP32[$19>>2]|0;
    $22 = ($21|0)==(0|0);
    if (!($22)) {
     $23 = ((($21)) + 8|0);
     $24 = HEAP32[$23>>2]|0;HEAP32[$23>>2] = (($24-1)|0);
     $25 = ($24|0)==(1);
     if ($25) {
      __THREW__ = 0;
      invoke_viii(3262,($21|0),1,1);
      $26 = __THREW__; __THREW__ = 0;
      $27 = $26&1;
      if ($27) {
       label = 12;
       break;
      }
     }
    }
    HEAP32[$19>>2] = 0;
    $28 = HEAP32[$2>>2]|0;
    $29 = ($28|0)==($15|0);
    if ($29) {
     label = 13;
     break;
    } else {
     $20 = $28;
    }
   }
   if ((label|0) == 12) {
    $30 = ___cxa_find_matching_catch_2()|0;
    $31 = tempRet0;
    ___cxa_call_unexpected(($30|0));
    // unreachable;
   }
   else if ((label|0) == 13) {
    $$pre$i = HEAP32[$0>>2]|0;
    $32 = $$pre$i;
    break;
   }
  }
 } while(0);
 __ZdlPv($32);
 ___resumeException($13|0);
 // unreachable;
}
function __ZN3osg7TextureC2ERKS0_RKNS_6CopyOpE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$026 = 0, $$1 = 0, $$127 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index3Z2D = 0, $eh$lpad$body$indexZ2D = 0, $eh$lpad$body40$index10Z2D = 0, $eh$lpad$body40$indexZ2D = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i32 = 0;
 var $scevgep$i$i$i$i45 = 0, $scevgep5$i$i$i$i = 0, $scevgep5$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i33 = 0, $scevgep5$i$i$i$i46 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg14StateAttributeC2ERKS0_RKNS_6CopyOpE($0,$1,$2);
 HEAP32[$0>>2] = (68036);
 $3 = ((($0)) + 56|0);
 __THREW__ = 0;
 $4 = (invoke_i(3285)|0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 L1: do {
  if ($6) {
   label = 27;
  } else {
   $7 = HEAP32[$4>>2]|0;
   __THREW__ = 0;
   $8 = (invoke_ii(3286,($7|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if ($10) {
    label = 27;
   } else {
    HEAP32[$3>>2] = 0;
    $11 = ((($0)) + 60|0);
    HEAP32[$11>>2] = 0;
    $12 = ((($0)) + 64|0);
    HEAP32[$12>>2] = 0;
    $13 = ($8|0)==(0);
    do {
     if (!($13)) {
      $14 = ($8>>>0)>(1073741823);
      if ($14) {
       __THREW__ = 0;
       invoke_vi(3307,($3|0));
       $15 = __THREW__; __THREW__ = 0;
      } else {
       $16 = $8 << 2;
       __THREW__ = 0;
       $17 = (invoke_ii(3276,($16|0))|0);
       $18 = __THREW__; __THREW__ = 0;
       $19 = $18&1;
       if (!($19)) {
        HEAP32[$3>>2] = $17;
        $20 = (($17) + ($8<<2)|0);
        $21 = ((($0)) + 64|0);
        HEAP32[$21>>2] = $20;
        _memset(($17|0),0,($16|0))|0;
        HEAP32[$11>>2] = $20;
        break;
       }
      }
      $22 = ___cxa_find_matching_catch_2()|0;
      $23 = tempRet0;
      $24 = HEAP32[$3>>2]|0;
      $25 = ($24|0)==(0|0);
      if ($25) {
       $eh$lpad$body$index3Z2D = $23;$eh$lpad$body$indexZ2D = $22;
       label = 28;
       break L1;
      }
      $26 = HEAP32[$11>>2]|0;
      $27 = ($26|0)==($24|0);
      if (!($27)) {
       $scevgep$i$i$i$i$i = ((($26)) + -4|0);
       $28 = $scevgep$i$i$i$i$i;
       $29 = $24;
       $30 = (($28) - ($29))|0;
       $31 = $30 >>> 2;
       $32 = $31 ^ -1;
       $scevgep5$i$i$i$i$i = (($26) + ($32<<2)|0);
       HEAP32[$11>>2] = $scevgep5$i$i$i$i$i;
      }
      __ZdlPv($24);
      $eh$lpad$body$index3Z2D = $23;$eh$lpad$body$indexZ2D = $22;
      label = 28;
      break L1;
     }
    } while(0);
    $33 = ((($0)) + 68|0);
    __THREW__ = 0;
    $34 = (invoke_i(3285)|0);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    L16: do {
     if ($36) {
      label = 29;
     } else {
      $37 = HEAP32[$34>>2]|0;
      __THREW__ = 0;
      $38 = (invoke_ii(3286,($37|0))|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if ($40) {
       label = 29;
      } else {
       HEAP32[$33>>2] = 0;
       $41 = ((($0)) + 72|0);
       HEAP32[$41>>2] = 0;
       $42 = ((($0)) + 76|0);
       HEAP32[$42>>2] = 0;
       $43 = ($38|0)==(0);
       do {
        if (!($43)) {
         $44 = ($38>>>0)>(1073741823);
         if ($44) {
          __THREW__ = 0;
          invoke_vi(3307,($33|0));
          $45 = __THREW__; __THREW__ = 0;
         } else {
          $46 = $38 << 2;
          __THREW__ = 0;
          $47 = (invoke_ii(3276,($46|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if (!($49)) {
           HEAP32[$33>>2] = $47;
           $50 = (($47) + ($38<<2)|0);
           $51 = ((($0)) + 76|0);
           HEAP32[$51>>2] = $50;
           _memset(($47|0),0,($46|0))|0;
           HEAP32[$41>>2] = $50;
           break;
          }
         }
         $52 = ___cxa_find_matching_catch_2()|0;
         $53 = tempRet0;
         $54 = HEAP32[$33>>2]|0;
         $55 = ($54|0)==(0|0);
         if ($55) {
          $eh$lpad$body40$index10Z2D = $53;$eh$lpad$body40$indexZ2D = $52;
          label = 30;
          break L16;
         }
         $56 = HEAP32[$41>>2]|0;
         $57 = ($56|0)==($54|0);
         if (!($57)) {
          $scevgep$i$i$i$i$i32 = ((($56)) + -4|0);
          $58 = $scevgep$i$i$i$i$i32;
          $59 = $54;
          $60 = (($58) - ($59))|0;
          $61 = $60 >>> 2;
          $62 = $61 ^ -1;
          $scevgep5$i$i$i$i$i33 = (($56) + ($62<<2)|0);
          HEAP32[$41>>2] = $scevgep5$i$i$i$i$i33;
         }
         __ZdlPv($54);
         $eh$lpad$body40$index10Z2D = $53;$eh$lpad$body40$indexZ2D = $52;
         label = 30;
         break L16;
        }
       } while(0);
       $63 = ((($0)) + 80|0);
       $64 = ((($1)) + 80|0);
       $65 = HEAP32[$64>>2]|0;
       HEAP32[$63>>2] = $65;
       $66 = ((($0)) + 84|0);
       $67 = ((($1)) + 84|0);
       $68 = HEAP32[$67>>2]|0;
       HEAP32[$66>>2] = $68;
       $69 = ((($0)) + 88|0);
       $70 = ((($1)) + 88|0);
       $71 = HEAP32[$70>>2]|0;
       HEAP32[$69>>2] = $71;
       $72 = ((($0)) + 92|0);
       $73 = ((($1)) + 92|0);
       $74 = HEAP32[$73>>2]|0;
       HEAP32[$72>>2] = $74;
       $75 = ((($0)) + 96|0);
       $76 = ((($1)) + 96|0);
       $77 = HEAP32[$76>>2]|0;
       HEAP32[$75>>2] = $77;
       $78 = ((($0)) + 100|0);
       $79 = ((($1)) + 100|0);
       $80 = HEAP32[$79>>2]|0;
       HEAP32[$78>>2] = $80;
       $81 = ((($0)) + 104|0);
       $82 = ((($1)) + 104|0);
       ;HEAP32[$81>>2]=HEAP32[$82>>2]|0;HEAP32[$81+4>>2]=HEAP32[$82+4>>2]|0;HEAP32[$81+8>>2]=HEAP32[$82+8>>2]|0;HEAP32[$81+12>>2]=HEAP32[$82+12>>2]|0;
       $83 = ((($0)) + 120|0);
       $84 = ((($1)) + 120|0);
       $85 = HEAP8[$84>>0]|0;
       HEAP8[$83>>0] = $85;
       $86 = ((($0)) + 121|0);
       $87 = ((($1)) + 121|0);
       $88 = HEAP8[$87>>0]|0;
       HEAP8[$86>>0] = $88;
       $89 = ((($0)) + 122|0);
       $90 = ((($1)) + 122|0);
       $91 = HEAP8[$90>>0]|0;
       HEAP8[$89>>0] = $91;
       $92 = ((($0)) + 123|0);
       $93 = ((($1)) + 123|0);
       $94 = HEAP8[$93>>0]|0;
       HEAP8[$92>>0] = $94;
       $95 = ((($0)) + 128|0);
       $96 = ((($1)) + 128|0);
       ;HEAP32[$95>>2]=HEAP32[$96>>2]|0;HEAP32[$95+4>>2]=HEAP32[$96+4>>2]|0;HEAP32[$95+8>>2]=HEAP32[$96+8>>2]|0;HEAP32[$95+12>>2]=HEAP32[$96+12>>2]|0;HEAP32[$95+16>>2]=HEAP32[$96+16>>2]|0;HEAP32[$95+20>>2]=HEAP32[$96+20>>2]|0;HEAP32[$95+24>>2]=HEAP32[$96+24>>2]|0;HEAP32[$95+28>>2]=HEAP32[$96+28>>2]|0;
       $97 = ((($0)) + 160|0);
       $98 = ((($1)) + 160|0);
       $99 = HEAP32[$98>>2]|0;
       HEAP32[$97>>2] = $99;
       $100 = ((($0)) + 164|0);
       $101 = ((($1)) + 164|0);
       $102 = HEAP32[$101>>2]|0;
       HEAP32[$100>>2] = $102;
       $103 = ((($0)) + 168|0);
       $104 = ((($1)) + 168|0);
       $105 = HEAP32[$104>>2]|0;
       HEAP32[$103>>2] = $105;
       $106 = ((($0)) + 172|0);
       $107 = ((($1)) + 172|0);
       $108 = HEAP32[$107>>2]|0;
       HEAP32[$106>>2] = $108;
       $109 = ((($0)) + 176|0);
       $110 = ((($1)) + 176|0);
       $111 = HEAP32[$110>>2]|0;
       HEAP32[$109>>2] = $111;
       $112 = ((($0)) + 180|0);
       $113 = ((($1)) + 180|0);
       $114 = HEAP32[$113>>2]|0;
       HEAP32[$112>>2] = $114;
       $115 = ((($0)) + 184|0);
       $116 = ((($1)) + 184|0);
       $117 = HEAP8[$116>>0]|0;
       HEAP8[$115>>0] = $117;
       $118 = ((($0)) + 188|0);
       $119 = ((($1)) + 188|0);
       $120 = HEAP32[$119>>2]|0;
       HEAP32[$118>>2] = $120;
       $121 = ((($0)) + 192|0);
       $122 = ((($1)) + 192|0);
       $123 = HEAP32[$122>>2]|0;
       HEAP32[$121>>2] = $123;
       $124 = ((($0)) + 196|0);
       $125 = ((($1)) + 196|0);
       $126 = HEAP32[$125>>2]|0;
       HEAP32[$124>>2] = $126;
       $127 = ((($0)) + 200|0);
       HEAP32[$127>>2] = 0;
       $128 = ((($0)) + 204|0);
       HEAP32[$128>>2] = 0;
       $129 = ((($0)) + 208|0);
       HEAP8[$129>>0] = 0;
       $130 = ((($0)) + 212|0);
       HEAP32[$130>>2] = 0;
       $131 = ((($0)) + 216|0);
       HEAP32[$131>>2] = 0;
       $132 = ((($0)) + 220|0);
       HEAP32[$132>>2] = 0;
       $133 = ((($0)) + 224|0);
       __THREW__ = 0;
       $134 = (invoke_i(3285)|0);
       $135 = __THREW__; __THREW__ = 0;
       $136 = $135&1;
       if (!($136)) {
        $137 = HEAP32[$134>>2]|0;
        __THREW__ = 0;
        $138 = (invoke_ii(3286,($137|0))|0);
        $139 = __THREW__; __THREW__ = 0;
        $140 = $139&1;
        if (!($140)) {
         __THREW__ = 0;
         invoke_vii(3983,($133|0),($138|0));
         $141 = __THREW__; __THREW__ = 0;
         $142 = $141&1;
         if (!($142)) {
          $143 = ((($0)) + 236|0);
          HEAP32[$143>>2] = 0;
          return;
         }
        }
       }
       $148 = ___cxa_find_matching_catch_2()|0;
       $149 = tempRet0;
       $150 = HEAP32[$33>>2]|0;
       $151 = ($150|0)==(0|0);
       if ($151) {
        $$0 = $149;$$026 = $148;
       } else {
        $152 = HEAP32[$41>>2]|0;
        $153 = ($152|0)==($150|0);
        if (!($153)) {
         $scevgep$i$i$i$i = ((($152)) + -4|0);
         $154 = $scevgep$i$i$i$i;
         $155 = $150;
         $156 = (($154) - ($155))|0;
         $157 = $156 >>> 2;
         $158 = $157 ^ -1;
         $scevgep5$i$i$i$i = (($152) + ($158<<2)|0);
         HEAP32[$41>>2] = $scevgep5$i$i$i$i;
        }
        __ZdlPv($150);
        $$0 = $149;$$026 = $148;
       }
      }
     }
    } while(0);
    if ((label|0) == 29) {
     $146 = ___cxa_find_matching_catch_2()|0;
     $147 = tempRet0;
     $eh$lpad$body40$index10Z2D = $147;$eh$lpad$body40$indexZ2D = $146;
     label = 30;
    }
    if ((label|0) == 30) {
     $$0 = $eh$lpad$body40$index10Z2D;$$026 = $eh$lpad$body40$indexZ2D;
    }
    $159 = HEAP32[$3>>2]|0;
    $160 = ($159|0)==(0|0);
    if ($160) {
     $$1 = $$0;$$127 = $$026;
    } else {
     $161 = HEAP32[$11>>2]|0;
     $162 = ($161|0)==($159|0);
     if (!($162)) {
      $scevgep$i$i$i$i45 = ((($161)) + -4|0);
      $163 = $scevgep$i$i$i$i45;
      $164 = $159;
      $165 = (($163) - ($164))|0;
      $166 = $165 >>> 2;
      $167 = $166 ^ -1;
      $scevgep5$i$i$i$i46 = (($161) + ($167<<2)|0);
      HEAP32[$11>>2] = $scevgep5$i$i$i$i46;
     }
     __ZdlPv($159);
     $$1 = $$0;$$127 = $$026;
    }
   }
  }
 } while(0);
 if ((label|0) == 27) {
  $144 = ___cxa_find_matching_catch_2()|0;
  $145 = tempRet0;
  $eh$lpad$body$index3Z2D = $145;$eh$lpad$body$indexZ2D = $144;
  label = 28;
 }
 if ((label|0) == 28) {
  $$1 = $eh$lpad$body$index3Z2D;$$127 = $eh$lpad$body$indexZ2D;
 }
 __THREW__ = 0;
 invoke_vi(1573,($0|0));
 $168 = __THREW__; __THREW__ = 0;
 $169 = $168&1;
 if ($169) {
  $170 = ___cxa_find_matching_catch_3(0|0)|0;
  $171 = tempRet0;
  ___clang_call_terminate($170);
  // unreachable;
 } else {
  ___resumeException($$127|0);
  // unreachable;
 }
}
function __ZNK3osg7Texture14compareTextureERKS0_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$ = 0, $$$ = 0, $$0 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0.0, $13 = 0, $130 = 0, $131 = 0.0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0.0, $34 = 0, $35 = 0.0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 80|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($1)) + 80|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)<($5|0);
 if ($6) {
  $$0 = -1;
  return ($$0|0);
 }
 $7 = ($5|0)<($3|0);
 if ($7) {
  $$0 = 1;
  return ($$0|0);
 }
 $8 = ((($0)) + 84|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($1)) + 84|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($9|0)<($11|0);
 if ($12) {
  $$0 = -1;
  return ($$0|0);
 }
 $13 = ($11|0)<($9|0);
 if ($13) {
  $$0 = 1;
  return ($$0|0);
 }
 $14 = ((($0)) + 88|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ((($1)) + 88|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($15|0)<($17|0);
 if ($18) {
  $$0 = -1;
  return ($$0|0);
 }
 $19 = ($17|0)<($15|0);
 if ($19) {
  $$0 = 1;
  return ($$0|0);
 }
 $20 = ((($0)) + 92|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ((($1)) + 92|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($21|0)<($23|0);
 if ($24) {
  $$0 = -1;
  return ($$0|0);
 }
 $25 = ($23|0)<($21|0);
 if ($25) {
  $$0 = 1;
  return ($$0|0);
 }
 $26 = ((($0)) + 96|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ((($1)) + 96|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ($27|0)<($29|0);
 if ($30) {
  $$0 = -1;
  return ($$0|0);
 }
 $31 = ($29|0)<($27|0);
 if ($31) {
  $$0 = 1;
  return ($$0|0);
 }
 $32 = ((($0)) + 100|0);
 $33 = +HEAPF32[$32>>2];
 $34 = ((($1)) + 100|0);
 $35 = +HEAPF32[$34>>2];
 $36 = $33 < $35;
 if ($36) {
  $$0 = -1;
  return ($$0|0);
 }
 $37 = $35 < $33;
 if ($37) {
  $$0 = 1;
  return ($$0|0);
 }
 $38 = ((($0)) + 104|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = ((($1)) + 104|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = ($39|0)<($41|0);
 if ($42) {
  $$0 = -1;
  return ($$0|0);
 }
 $43 = ($39|0)>($41|0);
 if ($43) {
  $$0 = 1;
  return ($$0|0);
 }
 $44 = ((($0)) + 108|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = ((($1)) + 108|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = ($45|0)<($47|0);
 if ($48) {
  $$0 = -1;
  return ($$0|0);
 }
 $49 = ($45|0)>($47|0);
 if (!($49)) {
  $50 = ((($0)) + 112|0);
  $51 = HEAP32[$50>>2]|0;
  $52 = ((($1)) + 112|0);
  $53 = HEAP32[$52>>2]|0;
  $54 = ($51|0)<($53|0);
  if ($54) {
   $$0 = -1;
   return ($$0|0);
  }
  $55 = ($51|0)>($53|0);
  if (!($55)) {
   $56 = ((($0)) + 116|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = ((($1)) + 116|0);
   $59 = HEAP32[$58>>2]|0;
   $60 = ($57|0)<($59|0);
   if ($60) {
    $$0 = -1;
    return ($$0|0);
   }
  }
 }
 $61 = ((($1)) + 108|0);
 $62 = HEAP32[$61>>2]|0;
 $63 = ((($0)) + 108|0);
 $64 = HEAP32[$63>>2]|0;
 $65 = ($62|0)<($64|0);
 if ($65) {
  $$0 = 1;
  return ($$0|0);
 }
 $66 = ($62|0)>($64|0);
 do {
  if (!($66)) {
   $67 = ((($1)) + 112|0);
   $68 = HEAP32[$67>>2]|0;
   $69 = ((($0)) + 112|0);
   $70 = HEAP32[$69>>2]|0;
   $71 = ($68|0)<($70|0);
   if ($71) {
    $$0 = 1;
    return ($$0|0);
   }
   $72 = ($68|0)>($70|0);
   if ($72) {
    break;
   }
   $73 = ((($1)) + 116|0);
   $74 = HEAP32[$73>>2]|0;
   $75 = ((($0)) + 116|0);
   $76 = HEAP32[$75>>2]|0;
   $77 = ($74|0)<($76|0);
   if ($77) {
    $$0 = 1;
   } else {
    break;
   }
   return ($$0|0);
  }
 } while(0);
 $78 = ((($0)) + 120|0);
 $79 = HEAP8[$78>>0]|0;
 $80 = ((($1)) + 120|0);
 $81 = HEAP8[$80>>0]|0;
 $82 = ($79&255)<($81&255);
 if ($82) {
  $$0 = -1;
  return ($$0|0);
 }
 $83 = ($81&255)<($79&255);
 if ($83) {
  $$0 = 1;
  return ($$0|0);
 }
 $84 = ((($0)) + 164|0);
 $85 = HEAP32[$84>>2]|0;
 $86 = ((($1)) + 164|0);
 $87 = HEAP32[$86>>2]|0;
 $88 = ($85|0)<($87|0);
 if ($88) {
  $$0 = -1;
  return ($$0|0);
 }
 $89 = ($87|0)<($85|0);
 if ($89) {
  $$0 = 1;
  return ($$0|0);
 }
 $90 = ((($0)) + 172|0);
 $91 = HEAP32[$90>>2]|0;
 $92 = ($91|0)==(0);
 do {
  if (!($92)) {
   $93 = ((($1)) + 172|0);
   $94 = HEAP32[$93>>2]|0;
   $95 = ($94|0)==(0);
   if ($95) {
    break;
   }
   $96 = ($91|0)<($94|0);
   if ($96) {
    $$0 = -1;
    return ($$0|0);
   }
   $97 = ($94|0)<($91|0);
   if ($97) {
    $$0 = 1;
   } else {
    break;
   }
   return ($$0|0);
  }
 } while(0);
 $98 = ((($0)) + 176|0);
 $99 = HEAP32[$98>>2]|0;
 $100 = ((($1)) + 176|0);
 $101 = HEAP32[$100>>2]|0;
 $102 = ($99>>>0)<($101>>>0);
 if ($102) {
  $$0 = -1;
  return ($$0|0);
 }
 $103 = ($101>>>0)<($99>>>0);
 if ($103) {
  $$0 = 1;
  return ($$0|0);
 }
 $104 = ((($0)) + 180|0);
 $105 = HEAP32[$104>>2]|0;
 $106 = ((($1)) + 180|0);
 $107 = HEAP32[$106>>2]|0;
 $108 = ($105>>>0)<($107>>>0);
 if ($108) {
  $$0 = -1;
  return ($$0|0);
 }
 $109 = ($107>>>0)<($105>>>0);
 if ($109) {
  $$0 = 1;
  return ($$0|0);
 }
 $110 = ((($0)) + 184|0);
 $111 = HEAP8[$110>>0]|0;
 $112 = ((($1)) + 184|0);
 $113 = HEAP8[$112>>0]|0;
 $114 = ($111&255)<($113&255);
 if ($114) {
  $$0 = -1;
  return ($$0|0);
 }
 $115 = ($113&255)<($111&255);
 if ($115) {
  $$0 = 1;
  return ($$0|0);
 }
 $116 = ((($0)) + 188|0);
 $117 = HEAP32[$116>>2]|0;
 $118 = ((($1)) + 188|0);
 $119 = HEAP32[$118>>2]|0;
 $120 = ($117|0)<($119|0);
 if ($120) {
  $$0 = -1;
  return ($$0|0);
 }
 $121 = ($119|0)<($117|0);
 if ($121) {
  $$0 = 1;
  return ($$0|0);
 }
 $122 = ((($0)) + 192|0);
 $123 = HEAP32[$122>>2]|0;
 $124 = ((($1)) + 192|0);
 $125 = HEAP32[$124>>2]|0;
 $126 = ($123|0)<($125|0);
 if ($126) {
  $$0 = -1;
  return ($$0|0);
 }
 $127 = ($125|0)<($123|0);
 if ($127) {
  $$0 = 1;
  return ($$0|0);
 }
 $128 = ((($0)) + 196|0);
 $129 = +HEAPF32[$128>>2];
 $130 = ((($1)) + 196|0);
 $131 = +HEAPF32[$130>>2];
 $132 = $129 < $131;
 if ($132) {
  $$0 = -1;
  return ($$0|0);
 }
 $133 = $131 < $129;
 if ($133) {
  $$0 = 1;
  return ($$0|0);
 }
 $134 = ((($0)) + 121|0);
 $135 = HEAP8[$134>>0]|0;
 $136 = ((($1)) + 121|0);
 $137 = HEAP8[$136>>0]|0;
 $138 = ($135&255)<($137&255);
 if ($138) {
  $$0 = -1;
  return ($$0|0);
 }
 $139 = ($137&255)<($135&255);
 if ($139) {
  $$0 = 1;
  return ($$0|0);
 }
 $140 = ((($0)) + 122|0);
 $141 = HEAP8[$140>>0]|0;
 $142 = ((($1)) + 122|0);
 $143 = HEAP8[$142>>0]|0;
 $144 = ($141&255)<($143&255);
 if ($144) {
  $$0 = -1;
  return ($$0|0);
 }
 $145 = ($143&255)<($141&255);
 if ($145) {
  $$0 = 1;
  return ($$0|0);
 }
 $146 = ((($0)) + 123|0);
 $147 = HEAP8[$146>>0]|0;
 $148 = ((($1)) + 123|0);
 $149 = HEAP8[$148>>0]|0;
 $150 = ($147&255)<($149&255);
 if ($150) {
  $$0 = -1;
  return ($$0|0);
 }
 $151 = ($149&255)<($147&255);
 if ($151) {
  $$0 = 1;
  return ($$0|0);
 } else {
  $152 = ((($0)) + 168|0);
  $153 = HEAP32[$152>>2]|0;
  $154 = ((($1)) + 168|0);
  $155 = HEAP32[$154>>2]|0;
  $156 = ($153|0)<($155|0);
  $157 = ($155|0)<($153|0);
  $$ = $157&1;
  $$$ = $156 ? -1 : $$;
  return ($$$|0);
 }
 return (0)|0;
}
function __ZNK3osg7Texture21compareTextureObjectsERKS0_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$01324 = 0, $$pre = 0, $$pre27 = 0, $$pre28 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 224|0);
 $3 = ((($0)) + 228|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$2>>2]|0;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 2;
 $8 = ((($1)) + 224|0);
 $9 = ((($1)) + 228|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$8>>2]|0;
 $12 = (($10) - ($11))|0;
 $13 = $12 >> 2;
 $14 = ($7>>>0)<($13>>>0);
 $15 = $5;
 if ($14) {
  $113 = -1;
  return ($113|0);
 }
 $16 = ($13>>>0)<($7>>>0);
 if ($16) {
  $113 = 1;
  return ($113|0);
 }
 $17 = ($4|0)==($5|0);
 if ($17) {
  $113 = 0;
  return ($113|0);
 }
 $$01324 = 0;$25 = $15;$28 = $11;$29 = $10;
 L10: while(1) {
  $24 = (($25) + ($$01324<<2)|0);
  $26 = HEAP32[$24>>2]|0;
  $27 = (($29) - ($28))|0;
  $30 = $27 >> 2;
  $31 = ($30>>>0)>($$01324>>>0);
  do {
   if (!($31)) {
    $32 = (($$01324) + 1)|0;
    $33 = ($32>>>0)>($30>>>0);
    $34 = $28;
    $35 = $29;
    if ($33) {
     $36 = (($32) - ($30))|0;
     __ZNSt3__26vectorIN3osg7ref_ptrINS1_7Texture13TextureObjectEEENS_9allocatorIS5_EEE8__appendEj($8,$36);
     break;
    }
    $37 = ($32>>>0)<($30>>>0);
    if ($37) {
     $38 = (($34) + ($32<<2)|0);
     $39 = ($35|0)==($38|0);
     if (!($39)) {
      $41 = $35;
      while(1) {
       $40 = ((($41)) + -4|0);
       HEAP32[$9>>2] = $40;
       $42 = HEAP32[$40>>2]|0;
       $43 = ($42|0)==(0|0);
       if (!($43)) {
        $44 = ((($42)) + 8|0);
        $45 = HEAP32[$44>>2]|0;HEAP32[$44>>2] = (($45-1)|0);
        $46 = ($45|0)==(1);
        if ($46) {
         __THREW__ = 0;
         invoke_viii(3262,($42|0),1,1);
         $47 = __THREW__; __THREW__ = 0;
         $48 = $47&1;
         if ($48) {
          label = 16;
          break L10;
         }
        }
       }
       HEAP32[$40>>2] = 0;
       $49 = HEAP32[$9>>2]|0;
       $50 = ($49|0)==($38|0);
       if ($50) {
        break;
       } else {
        $41 = $49;
       }
      }
     }
    }
   }
  } while(0);
  $53 = HEAP32[$8>>2]|0;
  $54 = (($53) + ($$01324<<2)|0);
  $55 = HEAP32[$54>>2]|0;
  $56 = ($26>>>0)<($55>>>0);
  if ($56) {
   $113 = -1;
   label = 39;
   break;
  }
  $57 = $53;
  $58 = HEAP32[$9>>2]|0;
  $59 = (($58) - ($57))|0;
  $60 = $59 >> 2;
  $61 = ($60>>>0)>($$01324>>>0);
  do {
   if (!($61)) {
    $62 = (($$01324) + 1)|0;
    $63 = ($62>>>0)>($60>>>0);
    $64 = $58;
    if ($63) {
     $65 = (($62) - ($60))|0;
     __ZNSt3__26vectorIN3osg7ref_ptrINS1_7Texture13TextureObjectEEENS_9allocatorIS5_EEE8__appendEj($8,$65);
     break;
    }
    $66 = ($62>>>0)<($60>>>0);
    if ($66) {
     $67 = (($53) + ($62<<2)|0);
     $68 = ($64|0)==($67|0);
     if (!($68)) {
      $70 = $64;
      while(1) {
       $69 = ((($70)) + -4|0);
       HEAP32[$9>>2] = $69;
       $71 = HEAP32[$69>>2]|0;
       $72 = ($71|0)==(0|0);
       if (!($72)) {
        $73 = ((($71)) + 8|0);
        $74 = HEAP32[$73>>2]|0;HEAP32[$73>>2] = (($74-1)|0);
        $75 = ($74|0)==(1);
        if ($75) {
         __THREW__ = 0;
         invoke_viii(3262,($71|0),1,1);
         $76 = __THREW__; __THREW__ = 0;
         $77 = $76&1;
         if ($77) {
          label = 27;
          break L10;
         }
        }
       }
       HEAP32[$69>>2] = 0;
       $78 = HEAP32[$9>>2]|0;
       $79 = ($78|0)==($67|0);
       if ($79) {
        break;
       } else {
        $70 = $78;
       }
      }
     }
    }
   }
  } while(0);
  $82 = HEAP32[$8>>2]|0;
  $83 = (($82) + ($$01324<<2)|0);
  $84 = HEAP32[$83>>2]|0;
  $85 = HEAP32[$3>>2]|0;
  $86 = HEAP32[$2>>2]|0;
  $87 = (($85) - ($86))|0;
  $88 = $87 >> 2;
  $89 = ($88>>>0)>($$01324>>>0);
  $$pre28 = (($$01324) + 1)|0;
  do {
   if (!($89)) {
    $90 = ($$pre28>>>0)>($88>>>0);
    $91 = $86;
    $92 = $85;
    if ($90) {
     $93 = (($$pre28) - ($88))|0;
     __ZNSt3__26vectorIN3osg7ref_ptrINS1_7Texture13TextureObjectEEENS_9allocatorIS5_EEE8__appendEj($2,$93);
     break;
    }
    $94 = ($$pre28>>>0)<($88>>>0);
    if ($94) {
     $95 = (($91) + ($$pre28<<2)|0);
     $96 = ($92|0)==($95|0);
     if (!($96)) {
      $98 = $92;
      while(1) {
       $97 = ((($98)) + -4|0);
       HEAP32[$3>>2] = $97;
       $99 = HEAP32[$97>>2]|0;
       $100 = ($99|0)==(0|0);
       if (!($100)) {
        $101 = ((($99)) + 8|0);
        $102 = HEAP32[$101>>2]|0;HEAP32[$101>>2] = (($102-1)|0);
        $103 = ($102|0)==(1);
        if ($103) {
         __THREW__ = 0;
         invoke_viii(3262,($99|0),1,1);
         $104 = __THREW__; __THREW__ = 0;
         $105 = $104&1;
         if ($105) {
          label = 37;
          break L10;
         }
        }
       }
       HEAP32[$97>>2] = 0;
       $106 = HEAP32[$3>>2]|0;
       $107 = ($106|0)==($95|0);
       if ($107) {
        break;
       } else {
        $98 = $106;
       }
      }
     }
    }
   }
  } while(0);
  $18 = HEAP32[$2>>2]|0;
  $110 = (($18) + ($$01324<<2)|0);
  $111 = HEAP32[$110>>2]|0;
  $112 = ($84>>>0)<($111>>>0);
  if ($112) {
   $113 = 1;
   label = 39;
   break;
  }
  $19 = $18;
  $20 = HEAP32[$3>>2]|0;
  $21 = (($20) - ($19))|0;
  $22 = $21 >> 2;
  $23 = ($$pre28>>>0)<($22>>>0);
  if (!($23)) {
   $113 = 0;
   label = 39;
   break;
  }
  $$pre = HEAP32[$9>>2]|0;
  $$pre27 = HEAP32[$8>>2]|0;
  $$01324 = $$pre28;$25 = $18;$28 = $$pre27;$29 = $$pre;
 }
 if ((label|0) == 16) {
  $51 = ___cxa_find_matching_catch_2()|0;
  $52 = tempRet0;
  ___cxa_call_unexpected(($51|0));
  // unreachable;
 }
 else if ((label|0) == 27) {
  $80 = ___cxa_find_matching_catch_2()|0;
  $81 = tempRet0;
  ___cxa_call_unexpected(($80|0));
  // unreachable;
 }
 else if ((label|0) == 37) {
  $108 = ___cxa_find_matching_catch_2()|0;
  $109 = tempRet0;
  ___cxa_call_unexpected(($108|0));
  // unreachable;
 }
 else if ((label|0) == 39) {
  return ($113|0);
 }
 return (0)|0;
}
function __ZN3osg7Texture7setWrapENS0_13WrapParameterENS0_8WrapModeE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$02$i$i$i$i$i$i = 0, $$02$i$i$i$i$i$i11 = 0, $$02$i$i$i$i$i$i7 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 switch ($1|0) {
 case 0:  {
  $4 = ((($0)) + 80|0);
  HEAP32[$4>>2] = $2;
  $5 = ((($0)) + 56|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ((($0)) + 60|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = $6;
  $10 = (($8) - ($9))|0;
  $11 = ($10|0)>(0);
  if (!($11)) {
   STACKTOP = sp;return;
  }
  $12 = $10 >>> 2;
  $$02$i$i$i$i$i$i = $12;$13 = $6;
  while(1) {
   HEAP32[$13>>2] = 1;
   $14 = ((($13)) + 4|0);
   $15 = (($$02$i$i$i$i$i$i) + -1)|0;
   $16 = ($$02$i$i$i$i$i$i|0)>(1);
   if ($16) {
    $$02$i$i$i$i$i$i = $15;$13 = $14;
   } else {
    break;
   }
  }
  STACKTOP = sp;return;
  break;
 }
 case 1:  {
  $17 = ((($0)) + 84|0);
  HEAP32[$17>>2] = $2;
  $18 = ((($0)) + 56|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = ((($0)) + 60|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = $19;
  $23 = (($21) - ($22))|0;
  $24 = ($23|0)>(0);
  if (!($24)) {
   STACKTOP = sp;return;
  }
  $25 = $23 >>> 2;
  $$02$i$i$i$i$i$i7 = $25;$26 = $19;
  while(1) {
   HEAP32[$26>>2] = 1;
   $27 = ((($26)) + 4|0);
   $28 = (($$02$i$i$i$i$i$i7) + -1)|0;
   $29 = ($$02$i$i$i$i$i$i7|0)>(1);
   if ($29) {
    $$02$i$i$i$i$i$i7 = $28;$26 = $27;
   } else {
    break;
   }
  }
  STACKTOP = sp;return;
  break;
 }
 case 2:  {
  $30 = ((($0)) + 88|0);
  HEAP32[$30>>2] = $2;
  $31 = ((($0)) + 56|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = ((($0)) + 60|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = $32;
  $36 = (($34) - ($35))|0;
  $37 = ($36|0)>(0);
  if (!($37)) {
   STACKTOP = sp;return;
  }
  $38 = $36 >>> 2;
  $$02$i$i$i$i$i$i11 = $38;$39 = $32;
  while(1) {
   HEAP32[$39>>2] = 1;
   $40 = ((($39)) + 4|0);
   $41 = (($$02$i$i$i$i$i$i11) + -1)|0;
   $42 = ($$02$i$i$i$i$i$i11|0)>(1);
   if ($42) {
    $$02$i$i$i$i$i$i11 = $41;$39 = $40;
   } else {
    break;
   }
  }
  STACKTOP = sp;return;
  break;
 }
 default: {
  $43 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
  if (!($43)) {
   STACKTOP = sp;return;
  }
  $44 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
  $45 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($44,155357,47)|0);
  $46 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($45,$1)|0);
  $47 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($46,155405,1)|0);
  $48 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($47,$2)|0);
  $49 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($48,174996,1)|0);
  $50 = HEAP32[$49>>2]|0;
  $51 = ((($50)) + -12|0);
  $52 = HEAP32[$51>>2]|0;
  $53 = (($49) + ($52)|0);
  __ZNKSt3__28ios_base6getlocEv($3,$53);
  __THREW__ = 0;
  $54 = (invoke_iii(3255,($3|0),(215188|0))|0);
  $55 = __THREW__; __THREW__ = 0;
  $56 = $55&1;
  if (!($56)) {
   $57 = HEAP32[$54>>2]|0;
   $58 = ((($57)) + 28|0);
   $59 = HEAP32[$58>>2]|0;
   __THREW__ = 0;
   $60 = (invoke_iii($59|0,($54|0),10)|0);
   $61 = __THREW__; __THREW__ = 0;
   $62 = $61&1;
   if (!($62)) {
    __ZNSt3__26localeD2Ev($3);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($49,$60)|0);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($49)|0);
    STACKTOP = sp;return;
   }
  }
  $63 = ___cxa_find_matching_catch_2()|0;
  $64 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3263,($3|0));
  $65 = __THREW__; __THREW__ = 0;
  $66 = $65&1;
  if ($66) {
   $67 = ___cxa_find_matching_catch_3(0|0)|0;
   $68 = tempRet0;
   ___clang_call_terminate($67);
   // unreachable;
  } else {
   ___resumeException($63|0);
   // unreachable;
  }
 }
 }
}
function __ZN3osg7Texture9setFilterENS0_15FilterParameterENS0_10FilterModeE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$02$i$i$i$i$i$i = 0, $$02$i$i$i$i$i$i6 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 switch ($1|0) {
 case 0:  {
  $4 = ((($0)) + 92|0);
  HEAP32[$4>>2] = $2;
  $5 = ((($0)) + 56|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ((($0)) + 60|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = $6;
  $10 = (($8) - ($9))|0;
  $11 = ($10|0)>(0);
  if (!($11)) {
   STACKTOP = sp;return;
  }
  $12 = $10 >>> 2;
  $$02$i$i$i$i$i$i = $12;$13 = $6;
  while(1) {
   HEAP32[$13>>2] = 1;
   $14 = ((($13)) + 4|0);
   $15 = (($$02$i$i$i$i$i$i) + -1)|0;
   $16 = ($$02$i$i$i$i$i$i|0)>(1);
   if ($16) {
    $$02$i$i$i$i$i$i = $15;$13 = $14;
   } else {
    break;
   }
  }
  STACKTOP = sp;return;
  break;
 }
 case 1:  {
  $17 = ((($0)) + 96|0);
  HEAP32[$17>>2] = $2;
  $18 = ((($0)) + 56|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = ((($0)) + 60|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = $19;
  $23 = (($21) - ($22))|0;
  $24 = ($23|0)>(0);
  if (!($24)) {
   STACKTOP = sp;return;
  }
  $25 = $23 >>> 2;
  $$02$i$i$i$i$i$i6 = $25;$26 = $19;
  while(1) {
   HEAP32[$26>>2] = 1;
   $27 = ((($26)) + 4|0);
   $28 = (($$02$i$i$i$i$i$i6) + -1)|0;
   $29 = ($$02$i$i$i$i$i$i6|0)>(1);
   if ($29) {
    $$02$i$i$i$i$i$i6 = $28;$26 = $27;
   } else {
    break;
   }
  }
  STACKTOP = sp;return;
  break;
 }
 default: {
  $30 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
  if (!($30)) {
   STACKTOP = sp;return;
  }
  $31 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
  $32 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($31,155407,49)|0);
  $33 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($32,$1)|0);
  $34 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($33,155405,1)|0);
  $35 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($34,$2)|0);
  $36 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($35,174996,1)|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = ((($37)) + -12|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = (($36) + ($39)|0);
  __ZNKSt3__28ios_base6getlocEv($3,$40);
  __THREW__ = 0;
  $41 = (invoke_iii(3255,($3|0),(215188|0))|0);
  $42 = __THREW__; __THREW__ = 0;
  $43 = $42&1;
  if (!($43)) {
   $44 = HEAP32[$41>>2]|0;
   $45 = ((($44)) + 28|0);
   $46 = HEAP32[$45>>2]|0;
   __THREW__ = 0;
   $47 = (invoke_iii($46|0,($41|0),10)|0);
   $48 = __THREW__; __THREW__ = 0;
   $49 = $48&1;
   if (!($49)) {
    __ZNSt3__26localeD2Ev($3);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($36,$47)|0);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($36)|0);
    STACKTOP = sp;return;
   }
  }
  $50 = ___cxa_find_matching_catch_2()|0;
  $51 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3263,($3|0));
  $52 = __THREW__; __THREW__ = 0;
  $53 = $52&1;
  if ($53) {
   $54 = ___cxa_find_matching_catch_3(0|0)|0;
   $55 = tempRet0;
   ___clang_call_terminate($54);
   // unreachable;
  } else {
   ___resumeException($50|0);
   // unreachable;
  }
 }
 }
}
function __ZNK3osg7Texture9getFilterENS0_15FilterParameterE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$0$in = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 switch ($1|0) {
 case 0:  {
  $3 = ((($0)) + 92|0);
  $$0$in = $3;
  $$0 = HEAP32[$$0$in>>2]|0;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 1:  {
  $4 = ((($0)) + 96|0);
  $$0$in = $4;
  $$0 = HEAP32[$$0$in>>2]|0;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 default: {
  $5 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
  do {
   if ($5) {
    $6 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
    $7 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($6,155457,55)|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = ((($8)) + -12|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (($7) + ($10)|0);
    __ZNKSt3__28ios_base6getlocEv($2,$11);
    __THREW__ = 0;
    $12 = (invoke_iii(3255,($2|0),(215188|0))|0);
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if (!($14)) {
     $15 = HEAP32[$12>>2]|0;
     $16 = ((($15)) + 28|0);
     $17 = HEAP32[$16>>2]|0;
     __THREW__ = 0;
     $18 = (invoke_iii($17|0,($12|0),10)|0);
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if (!($20)) {
      __ZNSt3__26localeD2Ev($2);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($7,$18)|0);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($7)|0);
      break;
     }
    }
    $21 = ___cxa_find_matching_catch_2()|0;
    $22 = tempRet0;
    __THREW__ = 0;
    invoke_vi(3263,($2|0));
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if ($24) {
     $25 = ___cxa_find_matching_catch_3(0|0)|0;
     $26 = tempRet0;
     ___clang_call_terminate($25);
     // unreachable;
    } else {
     ___resumeException($21|0);
     // unreachable;
    }
   }
  } while(0);
  $27 = ((($0)) + 92|0);
  $$0$in = $27;
  $$0 = HEAP32[$$0$in>>2]|0;
  STACKTOP = sp;return ($$0|0);
 }
 }
 return (0)|0;
}
function __ZN3osg7Texture16setMaxAnisotropyEf($0,$1) {
 $0 = $0|0;
 $1 = +$1;
 var $$02$i$i$i$i$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0.0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 100|0);
 $3 = +HEAPF32[$2>>2];
 $4 = $3 != $1;
 if (!($4)) {
  return;
 }
 HEAPF32[$2>>2] = $1;
 $5 = ((($0)) + 56|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($0)) + 60|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $6;
 $10 = (($8) - ($9))|0;
 $11 = ($10|0)>(0);
 if (!($11)) {
  return;
 }
 $12 = $10 >>> 2;
 $$02$i$i$i$i$i$i = $12;$13 = $6;
 while(1) {
  HEAP32[$13>>2] = 1;
  $14 = ((($13)) + 4|0);
  $15 = (($$02$i$i$i$i$i$i) + -1)|0;
  $16 = ($$02$i$i$i$i$i$i|0)>(1);
  if ($16) {
   $$02$i$i$i$i$i$i = $15;$13 = $14;
  } else {
   break;
  }
 }
 return;
}
function __ZNK3osg7Texture30computeInternalFormatWithImageERKNS_5ImageE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$1 = 0, $$2$ph46$sink = 0, $$sink$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $9 = 0, $switch$split102D = 0, $switch$split12D = 0, $switch$split132D = 0, $switch$split162D = 0, $switch$split192D = 0, $switch$split222D = 0, $switch$split252D = 0, $switch$split282D = 0, $switch$split2D = 0, $switch$split312D = 0, $switch$split342D = 0, $switch$split372D = 0, $switch$split402D = 0, $switch$split42D = 0, $switch$split432D = 0;
 var $switch$split462D = 0, $switch$split492D = 0, $switch$split522D = 0, $switch$split552D = 0, $switch$split582D = 0, $switch$split612D = 0, $switch$split72D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 88|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 164|0);
 $5 = HEAP32[$4>>2]|0;
 L1: do {
  switch ($5|0) {
  case 0:  {
   $$1 = $3;
   label = 56;
   break;
  }
  case 1:  {
   $6 = ((($0)) + 172|0);
   $7 = HEAP32[$6>>2]|0;
   $$1 = $7;
   label = 56;
   break;
  }
  default: {
   $8 = (__ZN3osg12GLExtensions3GetEjb(0,1)|0);
   $9 = HEAP32[$4>>2]|0;
   do {
    switch ($9|0) {
    case 2:  {
     $10 = ((($8)) + 1043|0);
     $11 = HEAP8[$10>>0]|0;
     $12 = ($11<<24>>24)==(0);
     if ($12) {
      $$1 = $3;
      label = 56;
      break L1;
     }
     $13 = ((($1)) + 92|0);
     $14 = HEAP32[$13>>2]|0;
     $switch$split2D = ($14|0)<(6407);
     if ($switch$split2D) {
      $switch$split372D = ($14|0)<(3);
      if ($switch$split372D) {
       switch ($14|0) {
       case 1:  {
        $$2$ph46$sink = 34025;
        label = 65;
        break L1;
        break;
       }
       case 2:  {
        break;
       }
       default: {
        $$1 = $3;
        label = 56;
        break L1;
       }
       }
       $$2$ph46$sink = 34027;
       label = 65;
       break L1;
      }
      $switch$split492D = ($14|0)<(4);
      if ($switch$split492D) {
       switch ($14|0) {
       case 3:  {
        break;
       }
       default: {
        $$1 = $3;
        label = 56;
        break L1;
       }
       }
       $$2$ph46$sink = 34029;
       label = 65;
       break L1;
      }
      $switch$split582D = ($14|0)<(6406);
      if (!($switch$split582D)) {
       switch ($14|0) {
       case 6406:  {
        $$2$ph46$sink = 34025;
        label = 65;
        break L1;
        break;
       }
       default: {
        $$1 = $3;
        label = 56;
        break L1;
       }
       }
      }
      switch ($14|0) {
      case 4:  {
       break;
      }
      default: {
       $$1 = $3;
       label = 56;
       break L1;
      }
      }
      $$2$ph46$sink = 34030;
      label = 65;
      break L1;
     }
     $switch$split402D = ($14|0)<(6409);
     if ($switch$split402D) {
      switch ($14|0) {
      case 6407:  {
       $$2$ph46$sink = 34029;
       label = 65;
       break L1;
       break;
      }
      case 6408:  {
       $$2$ph46$sink = 34030;
       label = 65;
       break L1;
       break;
      }
      default: {
       $$1 = $3;
       label = 56;
       break L1;
      }
      }
     }
     $switch$split522D = ($14|0)<(6410);
     if ($switch$split522D) {
      switch ($14|0) {
      case 6409:  {
       break;
      }
      default: {
       $$1 = $3;
       label = 56;
       break L1;
      }
      }
      $$2$ph46$sink = 34026;
      label = 65;
      break L1;
     }
     $switch$split612D = ($14|0)<(32841);
     if ($switch$split612D) {
      switch ($14|0) {
      case 6410:  {
       break;
      }
      default: {
       $$1 = $3;
       label = 56;
       break L1;
      }
      }
      $$2$ph46$sink = 34027;
      label = 65;
      break L1;
     } else {
      switch ($14|0) {
      case 32841:  {
       break;
      }
      default: {
       $$1 = $3;
       label = 56;
       break L1;
      }
      }
      $$2$ph46$sink = 34028;
      label = 65;
      break L1;
     }
     break;
    }
    case 3:  {
     $15 = ((($8)) + 1044|0);
     $16 = HEAP8[$15>>0]|0;
     $17 = ($16<<24>>24)==(0);
     if ($17) {
      $$1 = $3;
      label = 56;
      break L1;
     }
     $18 = ((($1)) + 92|0);
     $19 = HEAP32[$18>>2]|0;
     $switch$split12D = ($19|0)<(6407);
     L38: do {
      if ($switch$split12D) {
       switch ($19|0) {
       case 3:  {
        $$2$ph46$sink = 33776;
        label = 65;
        break L1;
        break;
       }
       case 4:  {
        break;
       }
       default: {
        break L38;
       }
       }
       $$2$ph46$sink = 33777;
       label = 65;
       break L1;
      } else {
       switch ($19|0) {
       case 6407:  {
        $$2$ph46$sink = 33776;
        label = 65;
        break L1;
        break;
       }
       case 6408:  {
        break;
       }
       default: {
        break L38;
       }
       }
       $$2$ph46$sink = 33777;
       label = 65;
       break L1;
      }
     } while(0);
     $20 = HEAP32[$2>>2]|0;
     $$1 = $20;
     label = 56;
     break L1;
     break;
    }
    case 12:  {
     $21 = ((($8)) + 1044|0);
     $22 = HEAP8[$21>>0]|0;
     $23 = ($22<<24>>24)==(0);
     if ($23) {
      $$1 = $3;
      label = 56;
      break L1;
     }
     $24 = ((($1)) + 92|0);
     $25 = HEAP32[$24>>2]|0;
     $switch$split42D = ($25|0)<(6407);
     if ($switch$split42D) {
      switch ($25|0) {
      case 4: case 3:  {
       $$2$ph46$sink = 33776;
       label = 65;
       break L1;
       break;
      }
      default: {
      }
      }
     } else {
      switch ($25|0) {
      case 6408: case 6407:  {
       $$2$ph46$sink = 33776;
       label = 65;
       break L1;
       break;
      }
      default: {
      }
      }
     }
     $26 = HEAP32[$2>>2]|0;
     $$1 = $26;
     label = 56;
     break L1;
     break;
    }
    case 13:  {
     $27 = ((($8)) + 1044|0);
     $28 = HEAP8[$27>>0]|0;
     $29 = ($28<<24>>24)==(0);
     if ($29) {
      $$1 = $3;
      label = 56;
      break L1;
     }
     $30 = ((($1)) + 92|0);
     $31 = HEAP32[$30>>2]|0;
     $switch$split72D = ($31|0)<(6407);
     if ($switch$split72D) {
      switch ($31|0) {
      case 4: case 3:  {
       $$2$ph46$sink = 33777;
       label = 65;
       break L1;
       break;
      }
      default: {
      }
      }
     } else {
      switch ($31|0) {
      case 6408: case 6407:  {
       $$2$ph46$sink = 33777;
       label = 65;
       break L1;
       break;
      }
      default: {
      }
      }
     }
     $32 = HEAP32[$2>>2]|0;
     $$1 = $32;
     label = 56;
     break L1;
     break;
    }
    case 4:  {
     $33 = ((($8)) + 1044|0);
     $34 = HEAP8[$33>>0]|0;
     $35 = ($34<<24>>24)==(0);
     if ($35) {
      $$1 = $3;
      label = 56;
      break L1;
     }
     $36 = ((($1)) + 92|0);
     $37 = HEAP32[$36>>2]|0;
     $switch$split102D = ($37|0)<(6407);
     if ($switch$split102D) {
      switch ($37|0) {
      case 3:  {
       $$2$ph46$sink = 33776;
       label = 65;
       break L1;
       break;
      }
      case 4:  {
       label = 27;
       break;
      }
      default: {
       label = 28;
      }
      }
     } else {
      switch ($37|0) {
      case 6407:  {
       $$2$ph46$sink = 33776;
       label = 65;
       break L1;
       break;
      }
      case 6408:  {
       label = 27;
       break;
      }
      default: {
       label = 28;
      }
      }
     }
     if ((label|0) == 27) {
      $$2$ph46$sink = 33778;
      label = 65;
      break L1;
     }
     else if ((label|0) == 28) {
      $38 = HEAP32[$2>>2]|0;
      $$1 = $38;
      label = 56;
      break L1;
     }
     break;
    }
    case 5:  {
     $39 = ((($8)) + 1044|0);
     $40 = HEAP8[$39>>0]|0;
     $41 = ($40<<24>>24)==(0);
     if ($41) {
      $$1 = $3;
      label = 56;
      break L1;
     }
     $42 = ((($1)) + 92|0);
     $43 = HEAP32[$42>>2]|0;
     $switch$split132D = ($43|0)<(6407);
     if ($switch$split132D) {
      switch ($43|0) {
      case 3:  {
       $$2$ph46$sink = 33776;
       label = 65;
       break L1;
       break;
      }
      case 4:  {
       label = 31;
       break;
      }
      default: {
       label = 32;
      }
      }
     } else {
      switch ($43|0) {
      case 6407:  {
       $$2$ph46$sink = 33776;
       label = 65;
       break L1;
       break;
      }
      case 6408:  {
       label = 31;
       break;
      }
      default: {
       label = 32;
      }
      }
     }
     if ((label|0) == 31) {
      $$2$ph46$sink = 33779;
      label = 65;
      break L1;
     }
     else if ((label|0) == 32) {
      $44 = HEAP32[$2>>2]|0;
      $$1 = $44;
      label = 56;
      break L1;
     }
     break;
    }
    case 6:  {
     $45 = ((($8)) + 1045|0);
     $46 = HEAP8[$45>>0]|0;
     $47 = ($46<<24>>24)==(0);
     if ($47) {
      $$1 = $3;
      label = 56;
      break L1;
     }
     $48 = ((($1)) + 92|0);
     $49 = HEAP32[$48>>2]|0;
     $switch$split162D = ($49|0)<(6407);
     if ($switch$split162D) {
      switch ($49|0) {
      case 3:  {
       $$2$ph46$sink = 35841;
       label = 65;
       break L1;
       break;
      }
      case 4:  {
       label = 35;
       break;
      }
      default: {
       label = 36;
      }
      }
     } else {
      switch ($49|0) {
      case 6407:  {
       $$2$ph46$sink = 35841;
       label = 65;
       break L1;
       break;
      }
      case 6408:  {
       label = 35;
       break;
      }
      default: {
       label = 36;
      }
      }
     }
     if ((label|0) == 35) {
      $$2$ph46$sink = 35843;
      label = 65;
      break L1;
     }
     else if ((label|0) == 36) {
      $50 = HEAP32[$2>>2]|0;
      $$1 = $50;
      label = 56;
      break L1;
     }
     break;
    }
    case 7:  {
     $51 = ((($8)) + 1046|0);
     $52 = HEAP8[$51>>0]|0;
     $53 = ($52<<24>>24)==(0);
     if ($53) {
      $$1 = $3;
      label = 56;
      break L1;
     }
     $54 = ((($1)) + 92|0);
     $55 = HEAP32[$54>>2]|0;
     $switch$split192D = ($55|0)<(6407);
     if ($switch$split192D) {
      switch ($55|0) {
      case 3:  {
       $$2$ph46$sink = 35840;
       label = 65;
       break L1;
       break;
      }
      case 4:  {
       label = 39;
       break;
      }
      default: {
       label = 40;
      }
      }
     } else {
      switch ($55|0) {
      case 6407:  {
       $$2$ph46$sink = 35840;
       label = 65;
       break L1;
       break;
      }
      case 6408:  {
       label = 39;
       break;
      }
      default: {
       label = 40;
      }
      }
     }
     if ((label|0) == 39) {
      $$2$ph46$sink = 35842;
      label = 65;
      break L1;
     }
     else if ((label|0) == 40) {
      $56 = HEAP32[$2>>2]|0;
      $$1 = $56;
      label = 56;
      break L1;
     }
     break;
    }
    case 8:  {
     $57 = ((($8)) + 1047|0);
     $58 = HEAP8[$57>>0]|0;
     $59 = ($58<<24>>24)==(0);
     if ($59) {
      $$1 = $3;
      label = 56;
      break L1;
     }
     $60 = ((($1)) + 92|0);
     $61 = HEAP32[$60>>2]|0;
     $switch$split222D = ($61|0)<(6407);
     if ($switch$split222D) {
      switch ($61|0) {
      case 3:  {
       $$2$ph46$sink = 36196;
       label = 65;
       break L1;
       break;
      }
      default: {
      }
      }
     } else {
      switch ($61|0) {
      case 6407:  {
       $$2$ph46$sink = 36196;
       label = 65;
       break L1;
       break;
      }
      default: {
      }
      }
     }
     $62 = HEAP32[$2>>2]|0;
     $$1 = $62;
     label = 56;
     break L1;
     break;
    }
    case 9:  {
     $63 = ((($8)) + 1048|0);
     $64 = HEAP8[$63>>0]|0;
     $65 = ($64<<24>>24)==(0);
     if ($65) {
      $$1 = $3;
      label = 56;
      break L1;
     }
     $66 = ((($1)) + 92|0);
     $67 = HEAP32[$66>>2]|0;
     $switch$split252D = ($67|0)<(6403);
     L96: do {
      if ($switch$split252D) {
       switch ($67|0) {
       case 1:  {
        $$2$ph46$sink = 37488;
        label = 65;
        break L1;
        break;
       }
       case 2:  {
        label = 46;
        break;
       }
       case 3:  {
        label = 47;
        break;
       }
       case 4:  {
        label = 48;
        break;
       }
       default: {
        label = 49;
       }
       }
      } else {
       $switch$split432D = ($67|0)<(6408);
       if ($switch$split432D) {
        switch ($67|0) {
        case 6403:  {
         $$2$ph46$sink = 37488;
         label = 65;
         break L1;
         break;
        }
        case 6407:  {
         label = 47;
         break L96;
         break;
        }
        default: {
         label = 49;
         break L96;
        }
        }
       }
       $switch$split552D = ($67|0)<(33319);
       if ($switch$split552D) {
        switch ($67|0) {
        case 6408:  {
         label = 48;
         break L96;
         break;
        }
        default: {
         label = 49;
         break L96;
        }
        }
       } else {
        switch ($67|0) {
        case 33319:  {
         label = 46;
         break L96;
         break;
        }
        default: {
         label = 49;
         break L96;
        }
        }
       }
      }
     } while(0);
     if ((label|0) == 46) {
      $$2$ph46$sink = 37490;
      label = 65;
      break L1;
     }
     else if ((label|0) == 47) {
      $$2$ph46$sink = 37492;
      label = 65;
      break L1;
     }
     else if ((label|0) == 48) {
      $$2$ph46$sink = 37496;
      label = 65;
      break L1;
     }
     else if ((label|0) == 49) {
      $68 = HEAP32[$2>>2]|0;
      $$1 = $68;
      label = 56;
      break L1;
     }
     break;
    }
    case 10:  {
     $69 = ((($8)) + 1049|0);
     $70 = HEAP8[$69>>0]|0;
     $71 = ($70<<24>>24)==(0);
     if ($71) {
      $$1 = $3;
      label = 56;
      break L1;
     }
     $72 = ((($1)) + 92|0);
     $73 = HEAP32[$72>>2]|0;
     $switch$split282D = ($73|0)<(6407);
     if ($switch$split282D) {
      switch ($73|0) {
      case 4: case 3:  {
       $$2$ph46$sink = 36283;
       label = 65;
       break L1;
       break;
      }
      default: {
      }
      }
     } else {
      switch ($73|0) {
      case 6408: case 6407:  {
       $$2$ph46$sink = 36283;
       label = 65;
       break L1;
       break;
      }
      default: {
      }
      }
     }
     $74 = HEAP32[$2>>2]|0;
     $$1 = $74;
     label = 56;
     break L1;
     break;
    }
    case 11:  {
     $75 = ((($8)) + 1049|0);
     $76 = HEAP8[$75>>0]|0;
     $77 = ($76<<24>>24)==(0);
     if ($77) {
      $$1 = $3;
      label = 56;
      break L1;
     }
     $78 = ((($1)) + 92|0);
     $79 = HEAP32[$78>>2]|0;
     $switch$split312D = ($79|0)<(6407);
     if ($switch$split312D) {
      switch ($79|0) {
      case 4: case 3:  {
       $$2$ph46$sink = 36285;
       label = 65;
       break L1;
       break;
      }
      default: {
      }
      }
     } else {
      switch ($79|0) {
      case 6408: case 6407:  {
       $$2$ph46$sink = 36285;
       label = 65;
       break L1;
       break;
      }
      default: {
      }
      }
     }
     $80 = HEAP32[$2>>2]|0;
     $$1 = $80;
     label = 56;
     break L1;
     break;
    }
    default: {
     $$1 = $3;
     label = 56;
     break L1;
    }
    }
   } while(0);
  }
  }
 } while(0);
 L123: do {
  if ((label|0) == 56) {
   $switch$split342D = ($$1|0)<(4);
   L125: do {
    if ($switch$split342D) {
     switch ($$1|0) {
     case 1:  {
      $$2$ph46$sink = 6409;
      label = 65;
      break L123;
      break;
     }
     case 2:  {
      $$2$ph46$sink = 6410;
      label = 65;
      break L123;
      break;
     }
     case 3:  {
      $$2$ph46$sink = 6407;
      label = 65;
      break L123;
      break;
     }
     default: {
      break L125;
     }
     }
    } else {
     $switch$split462D = ($$1|0)<(32849);
     if ($switch$split462D) {
      switch ($$1|0) {
      case 4:  {
       break;
      }
      default: {
       break L125;
      }
      }
      $$2$ph46$sink = 6408;
      label = 65;
      break L123;
     }
     switch ($$1|0) {
     case 32849:  {
      $$2$ph46$sink = 6407;
      label = 65;
      break L123;
      break;
     }
     case 32856:  {
      $$2$ph46$sink = 6408;
      label = 65;
      break L123;
      break;
     }
     default: {
      break L125;
     }
     }
    }
   } while(0);
   $81 = ((($0)) + 172|0);
   HEAP32[$81>>2] = $$1;
   switch ($$1|0) {
   case 36225: case 36219: case 36213: case 36223: case 36217: case 36211: case 36224: case 36218: case 36212: case 33330: case 33332: case 33334: case 33336: case 33338: case 33340: case 36221: case 36215: case 36209: case 36220: case 36214: case 36208:  {
    $$sink$i = 4;
    $83 = ((($0)) + 168|0);
    HEAP32[$83>>2] = $$sink$i;
    return;
    break;
   }
   case 34847: case 34841: case 34845: case 34839: case 34846: case 34840: case 33325: case 33326: case 33327: case 33328: case 34843: case 34837: case 34842: case 34836:  {
    $$sink$i = 1;
    $83 = ((($0)) + 168|0);
    HEAP32[$83>>2] = $$sink$i;
    return;
    break;
   }
   case 36243: case 36237: case 36231: case 36241: case 36235: case 36229: case 36242: case 36236: case 36230: case 33329: case 33331: case 33333: case 33335: case 33337: case 33339: case 36239: case 36233: case 36227: case 36238: case 36232: case 36226:  {
    $$sink$i = 2;
    $83 = ((($0)) + 168|0);
    HEAP32[$83>>2] = $$sink$i;
    return;
    break;
   }
   default: {
    break L123;
   }
   }
  }
 } while(0);
 if ((label|0) == 65) {
  $82 = ((($0)) + 172|0);
  HEAP32[$82>>2] = $$2$ph46$sink;
 }
 $$sink$i = 0;
 $83 = ((($0)) + 168|0);
 HEAP32[$83>>2] = $$sink$i;
 return;
}
function __ZNK3osg7Texture25computeInternalFormatTypeEv($0) {
 $0 = $0|0;
 var $$sink = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 172|0);
 $2 = HEAP32[$1>>2]|0;
 switch ($2|0) {
 case 36225: case 36219: case 36213: case 36223: case 36217: case 36211: case 36224: case 36218: case 36212: case 33330: case 33332: case 33334: case 33336: case 33338: case 33340: case 36221: case 36215: case 36209: case 36220: case 36214: case 36208:  {
  $$sink = 4;
  break;
 }
 case 36243: case 36237: case 36231: case 36241: case 36235: case 36229: case 36242: case 36236: case 36230: case 33329: case 33331: case 33333: case 33335: case 33337: case 33339: case 36239: case 36233: case 36227: case 36238: case 36232: case 36226:  {
  $$sink = 2;
  break;
 }
 case 34847: case 34841: case 34845: case 34839: case 34846: case 34840: case 33325: case 33326: case 33327: case 33328: case 34843: case 34837: case 34842: case 34836:  {
  $$sink = 1;
  break;
 }
 default: {
  $$sink = 0;
 }
 }
 $3 = ((($0)) + 168|0);
 HEAP32[$3>>2] = $$sink;
 return;
}
function __ZN3osg7Texture26isCompressedInternalFormatEi($0) {
 $0 = $0|0;
 var $$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 switch ($0|0) {
 case 35843: case 35842: case 35841: case 35840: case 37491: case 37490: case 37489: case 37488: case 37497: case 37496: case 37495: case 37494: case 37493: case 37492: case 36196: case 36285: case 36286: case 36283: case 36284: case 33779: case 33778: case 33777: case 33776: case 34029: case 34030: case 34026: case 34027: case 34028: case 34025:  {
  $$0 = 1;
  break;
 }
 default: {
  $$0 = 0;
 }
 }
 return ($$0|0);
}
function __ZN3osg7Texture17getCompressedSizeEjiiiRiS1_($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$ = 0, $$091 = 0, $$093 = 0, $$96 = 0, $$off = 0, $$off94 = 0, $$sink = 0, $$sink$sink = 0, $$sink101 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $6 = sp;
 $7 = $0 | 1;
 L1: do {
  switch ($7|0) {
  case 33777:  {
   $$sink = 8;
   break;
  }
  case 33779:  {
   $$sink = 16;
   break;
  }
  default: {
   switch ($0|0) {
   case 36196: case 37492: case 37493: case 37494: case 37495:  {
    $$sink = 8;
    break L1;
    break;
   }
   default: {
   }
   }
   switch ($7|0) {
   case 37491: case 37497:  {
    $$sink = 16;
    break L1;
    break;
   }
   case 37489:  {
    $$sink = 8;
    break L1;
    break;
   }
   default: {
   }
   }
   $$off = (($0) + -36283)|0;
   $8 = ($$off>>>0)<(2);
   if ($8) {
    $$sink = 8;
   } else {
    $$off94 = (($0) + -36285)|0;
    $9 = ($$off94>>>0)<(2);
    if ($9) {
     $$sink = 16;
    } else {
     $10 = $0 | 2;
     switch ($10|0) {
     case 35843:  {
      HEAP32[$4>>2] = 32;
      $11 = (($1|0) / 8)&-1;
      $12 = (($2|0) / 4)&-1;
      $13 = ($1|0)<(16);
      $$ = $13 ? 2 : $11;
      $14 = ($2|0)<(8);
      $$093 = $14 ? 2 : $12;
      $15 = Math_imul($$093, $$)|0;
      $$sink$sink = 8;$$sink101 = $15;
      $51 = Math_imul($$sink101, $$sink$sink)|0;
      HEAP32[$5>>2] = $51;
      STACKTOP = sp;return;
      break;
     }
     case 35842:  {
      HEAP32[$4>>2] = 16;
      $16 = (($1|0) / 4)&-1;
      $17 = (($2|0) / 4)&-1;
      $18 = ($1|0)<(8);
      $$96 = $18 ? 2 : $16;
      $19 = ($2|0)<(8);
      $$091 = $19 ? 2 : $17;
      $20 = Math_imul($$091, $$96)|0;
      $$sink$sink = 8;$$sink101 = $20;
      $51 = Math_imul($$sink101, $$sink$sink)|0;
      HEAP32[$5>>2] = $51;
      STACKTOP = sp;return;
      break;
     }
     default: {
      $21 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
      if (!($21)) {
       $$sink = 0;
       break L1;
      }
      $22 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
      $23 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($22,155513,84)|0);
      $24 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($23,$0)|0);
      $25 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($24,155598,14)|0);
      $26 = HEAP32[$25>>2]|0;
      $27 = ((($26)) + -12|0);
      $28 = HEAP32[$27>>2]|0;
      $29 = (($25) + ($28)|0);
      __ZNKSt3__28ios_base6getlocEv($6,$29);
      __THREW__ = 0;
      $30 = (invoke_iii(3255,($6|0),(215188|0))|0);
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if (!($32)) {
       $33 = HEAP32[$30>>2]|0;
       $34 = ((($33)) + 28|0);
       $35 = HEAP32[$34>>2]|0;
       __THREW__ = 0;
       $36 = (invoke_iii($35|0,($30|0),10)|0);
       $37 = __THREW__; __THREW__ = 0;
       $38 = $37&1;
       if (!($38)) {
        __ZNSt3__26localeD2Ev($6);
        (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($25,$36)|0);
        (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($25)|0);
        $$sink = 0;
        break L1;
       }
      }
      $39 = ___cxa_find_matching_catch_2()|0;
      $40 = tempRet0;
      __THREW__ = 0;
      invoke_vi(3263,($6|0));
      $41 = __THREW__; __THREW__ = 0;
      $42 = $41&1;
      if ($42) {
       $43 = ___cxa_find_matching_catch_3(0|0)|0;
       $44 = tempRet0;
       ___clang_call_terminate($43);
       // unreachable;
      } else {
       ___resumeException($39|0);
       // unreachable;
      }
     }
     }
    }
   }
  }
  }
 } while(0);
 HEAP32[$4>>2] = $$sink;
 $45 = (($1) + 3)|0;
 $46 = (($45|0) / 4)&-1;
 $47 = (($2) + 3)|0;
 $48 = (($47|0) / 4)&-1;
 $49 = Math_imul($46, $3)|0;
 $50 = Math_imul($49, $48)|0;
 $$sink$sink = $$sink;$$sink101 = $50;
 $51 = Math_imul($$sink101, $$sink$sink)|0;
 HEAP32[$5>>2] = $51;
 STACKTOP = sp;return;
}
function __ZNK3osg7Texture18applyTexParametersEjRNS_5StateE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$$ = 0, $$$196$$196 = 0, $$$297 = 0, $$$3$$3 = 0, $$$5 = 0, $$088$ = 0, $$196 = 0, $$3 = 0, $$391 = 0, $$492$$391 = 0, $$694 = 0, $$99$ = 0, $$pre$i$i = 0, $$pre$pre$i$i = 0, $$sink = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0;
 var $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0;
 var $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0.0, $138 = 0, $139 = 0, $14 = 0;
 var $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0.0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0.0, $152 = 0, $153 = 0, $154 = 0, $155 = 0.0, $156 = 0, $157 = 0, $158 = 0;
 var $159 = 0.0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0.0, $165 = 0, $166 = 0, $167 = 0, $168 = 0.0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0.0, $173 = 0, $174 = 0, $175 = 0, $176 = 0.0;
 var $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0.0, $182 = 0.0, $183 = 0, $184 = 0, $185 = 0.0, $186 = 0.0, $187 = 0, $188 = 0, $189 = 0.0, $19 = 0, $190 = 0.0, $191 = 0, $192 = 0, $193 = 0.0, $194 = 0.0;
 var $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0.0, $21 = 0, $210 = 0, $211 = 0, $212 = 0;
 var $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0;
 var $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0;
 var $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0;
 var $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0;
 var $286 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $cond = 0;
 var $scevgep$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i = 0, $switch$split2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(64|0);
 $3 = sp + 48|0;
 $4 = sp + 32|0;
 $5 = sp + 16|0;
 $6 = sp;
 $7 = ((($2)) + 124|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($2)) + 784|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ((($0)) + 224|0);
 $12 = ((($0)) + 228|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = HEAP32[$11>>2]|0;
 $15 = (($13) - ($14))|0;
 $16 = $15 >> 2;
 $17 = ($16>>>0)>($8>>>0);
 L1: do {
  if (!($17)) {
   $18 = (($8) + 1)|0;
   $19 = ($18>>>0)>($16>>>0);
   $20 = $14;
   $21 = $13;
   if ($19) {
    $22 = (($18) - ($16))|0;
    __ZNSt3__26vectorIN3osg7ref_ptrINS1_7Texture13TextureObjectEEENS_9allocatorIS5_EEE8__appendEj($11,$22);
    break;
   }
   $23 = ($18>>>0)<($16>>>0);
   if ($23) {
    $24 = (($20) + ($18<<2)|0);
    $25 = ($21|0)==($24|0);
    if (!($25)) {
     $27 = $21;
     while(1) {
      $26 = ((($27)) + -4|0);
      HEAP32[$12>>2] = $26;
      $28 = HEAP32[$26>>2]|0;
      $29 = ($28|0)==(0|0);
      if (!($29)) {
       $30 = ((($28)) + 8|0);
       $31 = HEAP32[$30>>2]|0;HEAP32[$30>>2] = (($31-1)|0);
       $32 = ($31|0)==(1);
       if ($32) {
        __THREW__ = 0;
        invoke_viii(3262,($28|0),1,1);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break;
        }
       }
      }
      HEAP32[$26>>2] = 0;
      $35 = HEAP32[$12>>2]|0;
      $36 = ($35|0)==($24|0);
      if ($36) {
       break L1;
      } else {
       $27 = $35;
      }
     }
     $37 = ___cxa_find_matching_catch_2()|0;
     $38 = tempRet0;
     ___cxa_call_unexpected(($37|0));
     // unreachable;
    }
   }
  }
 } while(0);
 $39 = HEAP32[$11>>2]|0;
 $40 = (($39) + ($8<<2)|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = ($41|0)==(0|0);
 if (!($42)) {
  $43 = ((($41)) + 12|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = ((($0)) + 12|0);
  $46 = ((($10)) + 1688|0);
  $47 = HEAP32[$46>>2]|0;
  $48 = ($47|0)==(0|0);
  if (!($48)) {
   $49 = ((($45)) + 11|0);
   $50 = HEAP8[$49>>0]|0;
   $51 = ($50<<24>>24)<(0);
   $52 = ((($0)) + 16|0);
   $53 = HEAP32[$52>>2]|0;
   $54 = $50&255;
   $55 = $51 ? $53 : $54;
   $56 = ($55|0)==(0);
   if (!($56)) {
    $57 = HEAP32[$45>>2]|0;
    $58 = $51 ? $57 : $45;
    FUNCTION_TABLE_viiii[$47 & 8191](5890,$44,$55,$58);
   }
  }
 }
 $59 = ((($0)) + 80|0);
 $60 = HEAP32[$59>>2]|0;
 $61 = ((($0)) + 84|0);
 $62 = HEAP32[$61>>2]|0;
 $63 = ((($0)) + 88|0);
 $64 = HEAP32[$63>>2]|0;
 $65 = ((($10)) + 1051|0);
 $66 = HEAP8[$65>>0]|0;
 $67 = ($66<<24>>24)==(0);
 $68 = ($60|0)==(33648);
 $69 = ($62|0)==(33648);
 $70 = ($64|0)==(33648);
 $71 = $70 & $67;
 $$99$ = $71 ? 10497 : $64;
 $72 = $69 & $67;
 $$088$ = $72 ? 10497 : $62;
 $73 = $68 & $67;
 $$$ = $73 ? 10497 : $60;
 $74 = ((($10)) + 1052|0);
 $75 = HEAP8[$74>>0]|0;
 $76 = ($75<<24>>24)==(0);
 $77 = ($$$|0)==(33071);
 $78 = ($$088$|0)==(33071);
 $79 = ($$99$|0)==(33071);
 $80 = $76 & $79;
 $$196 = $80 ? 10496 : $$99$;
 $81 = $76 & $78;
 $$391 = $81 ? 10496 : $$088$;
 $82 = $76 & $77;
 $$3 = $82 ? 10496 : $$$;
 $83 = ((($10)) + 1053|0);
 $84 = HEAP8[$83>>0]|0;
 $85 = ($84<<24>>24)==(0);
 $86 = ($$3|0)==(33069);
 $87 = ($$391|0)==(33069);
 $88 = ($$196|0)==(33069);
 $89 = $85 & $88;
 $$$196$$196 = $89 ? 10496 : $$196;
 $90 = $85 & $87;
 $$492$$391 = $90 ? 10496 : $$391;
 $91 = $85 & $86;
 $$$3$$3 = $91 ? 10496 : $$3;
 $92 = ($$$3$$3|0)==(10496);
 $$$5 = $92 ? 33071 : $$$3$$3;
 $93 = ($$492$$391|0)==(10496);
 $$694 = $93 ? 33071 : $$492$$391;
 $94 = ($$$196$$196|0)==(10496);
 $$$297 = $94 ? 33071 : $$$196$$196;
 $95 = HEAP32[$0>>2]|0;
 $96 = ((($95)) + 204|0);
 $97 = HEAP32[$96>>2]|0;
 $98 = (FUNCTION_TABLE_iii[$97 & 8191]($0,0)|0);
 $99 = ($98|0)==(0|0);
 if (!($99)) {
  $100 = ((($98)) + 116|0);
  $101 = HEAP32[$100>>2]|0;
  $102 = ((($98)) + 120|0);
  $103 = HEAP32[$102>>2]|0;
  $104 = ($101|0)==($103|0);
  $105 = $103;
  $106 = $101;
  if (!($104)) {
   $107 = ((($10)) + 1059|0);
   $108 = HEAP8[$107>>0]|0;
   $109 = ($108<<24>>24)==(0);
   if (!($109)) {
    $110 = (($105) - ($106))|0;
    $111 = $110 >> 2;
    $112 = (($111) + 1)|0;
    $113 = ((($98)) + 72|0);
    $114 = HEAP32[$113>>2]|0;
    $115 = ((($98)) + 76|0);
    $116 = HEAP32[$115>>2]|0;
    $117 = ((($98)) + 80|0);
    $118 = HEAP32[$117>>2]|0;
    $119 = (__ZN3osg5Image27computeNumberOfMipmapLevelsEiii($114,$116,$118)|0);
    $120 = ($112|0)<($119|0);
    if ($120) {
     $121 = ((($98)) + 116|0);
     $122 = HEAP32[$102>>2]|0;
     $123 = HEAP32[$121>>2]|0;
     $124 = (($122) - ($123))|0;
     $125 = $124 >> 2;
     _glTexParameteri(($1|0),33085,($125|0));
    }
   }
  }
 }
 _glTexParameteri(($1|0),10242,($$$5|0));
 $cond = ($1|0)==(3552);
 if (!($cond)) {
  _glTexParameteri(($1|0),10243,($$694|0));
  $126 = ($1|0)==(32879);
  if ($126) {
   _glTexParameteri(32879,32882,($$$297|0));
  }
 }
 $127 = ((($0)) + 92|0);
 $128 = HEAP32[$127>>2]|0;
 _glTexParameteri(($1|0),10241,($128|0));
 $129 = ((($0)) + 96|0);
 $130 = HEAP32[$129>>2]|0;
 _glTexParameteri(($1|0),10240,($130|0));
 $131 = ((($10)) + 1041|0);
 $132 = HEAP8[$131>>0]|0;
 $133 = ($132<<24>>24)==(0);
 L30: do {
  if (!($133)) {
   $134 = ((($0)) + 168|0);
   $135 = HEAP32[$134>>2]|0;
   switch ($135|0) {
   case 4: case 2:  {
    break L30;
    break;
   }
   default: {
   }
   }
   $136 = ((($0)) + 100|0);
   $137 = +HEAPF32[$136>>2];
   _glTexParameterf(($1|0),34046,(+$137));
  }
 } while(0);
 $138 = ((($10)) + 1042|0);
 $139 = HEAP8[$138>>0]|0;
 $140 = ($139<<24>>24)==(0);
 if (!($140)) {
  $141 = ((($0)) + 104|0);
  _glTexParameteriv(($1|0),36422,($141|0));
 }
 $142 = HEAP8[$83>>0]|0;
 $143 = ($142<<24>>24)==(0);
 L37: do {
  if (!($143)) {
   $144 = ((($0)) + 168|0);
   $145 = HEAP32[$144>>2]|0;
   switch ($145|0) {
   case 2:  {
    $146 = ((($0)) + 128|0);
    $147 = +HEAPF64[$146>>3];
    $148 = (~~(($147)));
    HEAP32[$4>>2] = $148;
    $149 = ((($4)) + 4|0);
    $150 = ((($0)) + 136|0);
    $151 = +HEAPF64[$150>>3];
    $152 = (~~(($151)));
    HEAP32[$149>>2] = $152;
    $153 = ((($4)) + 8|0);
    $154 = ((($0)) + 144|0);
    $155 = +HEAPF64[$154>>3];
    $156 = (~~(($155)));
    HEAP32[$153>>2] = $156;
    $157 = ((($4)) + 12|0);
    $158 = ((($0)) + 152|0);
    $159 = +HEAPF64[$158>>3];
    $160 = (~~(($159)));
    HEAP32[$157>>2] = $160;
    $161 = ((($10)) + 1092|0);
    $162 = HEAP32[$161>>2]|0;
    FUNCTION_TABLE_viii[$162 & 8191]($1,4100,$4);
    break L37;
    break;
   }
   case 4:  {
    $163 = ((($0)) + 128|0);
    $164 = +HEAPF64[$163>>3];
    $165 = (~~(($164))>>>0);
    HEAP32[$5>>2] = $165;
    $166 = ((($5)) + 4|0);
    $167 = ((($0)) + 136|0);
    $168 = +HEAPF64[$167>>3];
    $169 = (~~(($168))>>>0);
    HEAP32[$166>>2] = $169;
    $170 = ((($5)) + 8|0);
    $171 = ((($0)) + 144|0);
    $172 = +HEAPF64[$171>>3];
    $173 = (~~(($172))>>>0);
    HEAP32[$170>>2] = $173;
    $174 = ((($5)) + 12|0);
    $175 = ((($0)) + 152|0);
    $176 = +HEAPF64[$175>>3];
    $177 = (~~(($176))>>>0);
    HEAP32[$174>>2] = $177;
    $178 = ((($10)) + 1096|0);
    $179 = HEAP32[$178>>2]|0;
    FUNCTION_TABLE_viii[$179 & 8191]($1,4100,$5);
    break L37;
    break;
   }
   default: {
    $180 = ((($0)) + 128|0);
    $181 = +HEAPF64[$180>>3];
    $182 = $181;
    HEAPF32[$6>>2] = $182;
    $183 = ((($6)) + 4|0);
    $184 = ((($0)) + 136|0);
    $185 = +HEAPF64[$184>>3];
    $186 = $185;
    HEAPF32[$183>>2] = $186;
    $187 = ((($6)) + 8|0);
    $188 = ((($0)) + 144|0);
    $189 = +HEAPF64[$188>>3];
    $190 = $189;
    HEAPF32[$187>>2] = $190;
    $191 = ((($6)) + 12|0);
    $192 = ((($0)) + 152|0);
    $193 = +HEAPF64[$192>>3];
    $194 = $193;
    HEAPF32[$191>>2] = $194;
    _glTexParameterfv(($1|0),4100,($6|0));
    break L37;
   }
   }
  }
 } while(0);
 $195 = ((($10)) + 1057|0);
 $196 = HEAP8[$195>>0]|0;
 $197 = ($196<<24>>24)==(0);
 L44: do {
  if (!($197)) {
   $switch$split2D = ($1|0)<(34037);
   if ($switch$split2D) {
    switch ($1|0) {
    case 3552: case 3553:  {
     break;
    }
    default: {
     break L44;
    }
    }
   } else {
    switch ($1|0) {
    case 34037: case 34067: case 35866:  {
     break;
    }
    default: {
     break L44;
    }
    }
   }
   $198 = ((($0)) + 168|0);
   $199 = HEAP32[$198>>2]|0;
   switch ($199|0) {
   case 4: case 2:  {
    break L44;
    break;
   }
   default: {
   }
   }
   $200 = ((($0)) + 184|0);
   $201 = HEAP8[$200>>0]|0;
   $202 = ($201<<24>>24)==(0);
   if ($202) {
    _glTexParameteri(($1|0),34892,0);
    break;
   }
   _glTexParameteri(($1|0),34892,34894);
   $203 = ((($0)) + 188|0);
   $204 = HEAP32[$203>>2]|0;
   _glTexParameteri(($1|0),34893,($204|0));
   $205 = ((($10)) + 1058|0);
   $206 = HEAP8[$205>>0]|0;
   $207 = ($206<<24>>24)==(0);
   if (!($207)) {
    $208 = ((($0)) + 196|0);
    $209 = +HEAPF32[$208>>2];
    $210 = $209 > 0.0;
    if ($210) {
     _glTexParameterf(($1|0),32959,(+$209));
    }
   }
  }
 } while(0);
 $211 = ((($10)) + 1100|0);
 $212 = HEAP32[$211>>2]|0;
 $213 = ($212|0)==(0|0);
 if (!($213)) {
  $214 = ((($0)) + 216|0);
  $215 = HEAP32[$214>>2]|0;
  $216 = ($215|0)==(0);
  if (!($216)) {
   $217 = HEAP32[$12>>2]|0;
   $218 = HEAP32[$11>>2]|0;
   $219 = (($217) - ($218))|0;
   $220 = $219 >> 2;
   $221 = ($220>>>0)>($8>>>0);
   L60: do {
    if (!($221)) {
     $222 = (($8) + 1)|0;
     $223 = ($222>>>0)>($220>>>0);
     $224 = $218;
     $225 = $217;
     if ($223) {
      $226 = (($222) - ($220))|0;
      __ZNSt3__26vectorIN3osg7ref_ptrINS1_7Texture13TextureObjectEEENS_9allocatorIS5_EEE8__appendEj($11,$226);
      break;
     }
     $227 = ($222>>>0)<($220>>>0);
     if ($227) {
      $228 = (($224) + ($222<<2)|0);
      $229 = ($225|0)==($228|0);
      if (!($229)) {
       $231 = $225;
       while(1) {
        $230 = ((($231)) + -4|0);
        HEAP32[$12>>2] = $230;
        $232 = HEAP32[$230>>2]|0;
        $233 = ($232|0)==(0|0);
        if (!($233)) {
         $234 = ((($232)) + 8|0);
         $235 = HEAP32[$234>>2]|0;HEAP32[$234>>2] = (($235-1)|0);
         $236 = ($235|0)==(1);
         if ($236) {
          __THREW__ = 0;
          invoke_viii(3262,($232|0),1,1);
          $237 = __THREW__; __THREW__ = 0;
          $238 = $237&1;
          if ($238) {
           break;
          }
         }
        }
        HEAP32[$230>>2] = 0;
        $239 = HEAP32[$12>>2]|0;
        $240 = ($239|0)==($228|0);
        if ($240) {
         break L60;
        } else {
         $231 = $239;
        }
       }
       $241 = ___cxa_find_matching_catch_2()|0;
       $242 = tempRet0;
       ___cxa_call_unexpected(($241|0));
       // unreachable;
      }
     }
    }
   } while(0);
   $243 = HEAP32[$11>>2]|0;
   $244 = (($243) + ($8<<2)|0);
   $245 = HEAP32[$244>>2]|0;
   $246 = ($245|0)==(0|0);
   if (!($246)) {
    $247 = HEAP32[$211>>2]|0;
    $248 = ((($0)) + 200|0);
    $249 = HEAP32[$248>>2]|0;
    $250 = ((($245)) + 12|0);
    $251 = HEAP32[$250>>2]|0;
    $252 = ((($0)) + 204|0);
    $253 = HEAP32[$252>>2]|0;
    $254 = ((($0)) + 208|0);
    $255 = HEAP8[$254>>0]|0;
    $256 = ((($0)) + 212|0);
    $257 = HEAP32[$256>>2]|0;
    $258 = HEAP32[$214>>2]|0;
    $259 = ((($0)) + 220|0);
    $260 = HEAP32[$259>>2]|0;
    $261 = ($260|0)!=(0);
    $262 = ((($0)) + 172|0);
    $$sink = $261 ? $259 : $262;
    $263 = HEAP32[$$sink>>2]|0;
    FUNCTION_TABLE_viiiiiii[$247 & 8191]($249,$251,$253,$255,$257,$258,$263);
   }
  }
 }
 $264 = HEAP32[$7>>2]|0;
 $265 = ((($0)) + 56|0);
 $266 = ((($0)) + 60|0);
 $267 = HEAP32[$266>>2]|0;
 $268 = HEAP32[$265>>2]|0;
 $269 = (($267) - ($268))|0;
 $270 = $269 >> 2;
 $271 = ($270>>>0)>($264>>>0);
 $272 = $268;
 if ($271) {
  $286 = $272;
  $285 = (($286) + ($264<<2)|0);
  HEAP32[$285>>2] = 0;
  STACKTOP = sp;return;
 }
 $273 = (($264) + 1)|0;
 HEAP32[$3>>2] = 0;
 $274 = ($273>>>0)>($270>>>0);
 $275 = $267;
 if ($274) {
  $276 = (($273) - ($270))|0;
  __ZNSt3__26vectorIjNS_9allocatorIjEEE8__appendEjRKj($265,$276,$3);
  $$pre$pre$i$i = HEAP32[$265>>2]|0;
  $$pre$i$i = $$pre$pre$i$i;
 } else {
  $277 = ($273>>>0)<($270>>>0);
  if ($277) {
   $278 = (($272) + ($273<<2)|0);
   $279 = ($275|0)==($278|0);
   if ($279) {
    $$pre$i$i = $272;
   } else {
    $scevgep$i$i$i$i$i = ((($275)) + -4|0);
    $280 = $scevgep$i$i$i$i$i;
    $281 = $278;
    $282 = (($280) - ($281))|0;
    $283 = $282 >>> 2;
    $284 = $283 ^ -1;
    $scevgep5$i$i$i$i$i = (($275) + ($284<<2)|0);
    HEAP32[$266>>2] = $scevgep5$i$i$i$i$i;
    $$pre$i$i = $272;
   }
  } else {
   $$pre$i$i = $272;
  }
 }
 $286 = $$pre$i$i;
 $285 = (($286) + ($264<<2)|0);
 HEAP32[$285>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNK3osg7Texture32computeRequiredTextureDimensionsERNS_5StateERKNS_5ImageERiS6_S6_($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$$035 = 0, $$034 = 0, $$035 = 0, $$039 = 0, $$1 = 0, $$lcssa$sink = 0, $$pre = 0, $$sink$i = 0, $$sink$in$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond37 = 0, $storemerge38 = 0, $switch = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $6 = ((($1)) + 784|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($0)) + 123|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = ($9<<24>>24)==(0);
 $11 = ((($0)) + 92|0);
 if ($10) {
  $12 = HEAP32[$11>>2]|0;
  $13 = $12 | 1;
  $14 = ($13|0)==(9729);
  $15 = ((($7)) + 1067|0);
  $16 = ((($7)) + 1068|0);
  $$sink$in$i = $14 ? $16 : $15;
  $$sink$i = HEAP8[$$sink$in$i>>0]|0;
  $17 = ($$sink$i<<24>>24)==(0);
  if ($17) {
   label = 4;
  } else {
   $18 = ((($2)) + 72|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ((($2)) + 76|0);
   $21 = HEAP32[$20>>2]|0;
   $$034 = $21;$$035 = $19;$44 = $12;
  }
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  $22 = ((($2)) + 72|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = ((($0)) + 160|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = $25 << 1;
  $27 = (($23) - ($26))|0;
  $28 = (__ZN3osg5Image24computeNearestPowerOfTwoEif($27,0.5)|0);
  $29 = HEAP32[$24>>2]|0;
  $30 = $29 << 1;
  $31 = (($30) + ($28))|0;
  $32 = ((($2)) + 76|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = (($33) - ($30))|0;
  $35 = (__ZN3osg5Image24computeNearestPowerOfTwoEif($34,0.5)|0);
  $36 = HEAP32[$24>>2]|0;
  $37 = $36 << 1;
  $38 = (($37) + ($35))|0;
  $$pre = HEAP32[$11>>2]|0;
  $$034 = $38;$$035 = $31;$44 = $$pre;
 }
 $39 = ((($7)) + 1060|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ($$035|0)>($40|0);
 $$$035 = $41 ? $40 : $$035;
 $42 = ($$034|0)>($40|0);
 $$1 = $42 ? $40 : $$034;
 HEAP32[$3>>2] = $$$035;
 HEAP32[$4>>2] = $$1;
 $43 = $44 & -2;
 $switch = ($43|0)==(9728);
 do {
  if ($switch) {
   $$lcssa$sink = 1;
  } else {
   $45 = ((($2)) + 116|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = ((($2)) + 120|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = ($46|0)==($48|0);
   if (!($49)) {
    $52 = $46;
    $53 = $48;
    $54 = (($53) - ($52))|0;
    $55 = $54 >> 2;
    $56 = (($55) + 1)|0;
    $$lcssa$sink = $56;
    break;
   }
   HEAP32[$5>>2] = 1;
   $50 = ($$$035|0)>(1);
   $51 = ($$1|0)>(1);
   $or$cond37 = $50 | $51;
   if ($or$cond37) {
    $$039 = 1;$storemerge38 = 1;
    while(1) {
     $57 = $$039 << 1;
     $58 = (($storemerge38) + 1)|0;
     $59 = ($57|0)<($$$035|0);
     $60 = ($57|0)<($$1|0);
     $or$cond = $59 | $60;
     if ($or$cond) {
      $$039 = $57;$storemerge38 = $58;
     } else {
      $$lcssa$sink = $58;
      break;
     }
    }
   } else {
    return;
   }
  }
 } while(0);
 HEAP32[$5>>2] = $$lcssa$sink;
 return;
}
function __ZNK3osg7Texture26areAllTextureObjectsLoadedEv($0) {
 $0 = $0|0;
 var $$068 = 0, $$pre = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__ZN3osg15DisplaySettings8instanceEv()|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (__ZNK3osg15DisplaySettings30getMaxNumberOfGraphicsContextsEv($2)|0);
 $4 = ($3|0)==(0);
 if ($4) {
  $40 = 1;
  return ($40|0);
 }
 $5 = ((($0)) + 224|0);
 $6 = ((($0)) + 228|0);
 $$068 = 0;
 L4: while(1) {
  $11 = HEAP32[$6>>2]|0;
  $12 = HEAP32[$5>>2]|0;
  $13 = (($11) - ($12))|0;
  $14 = $13 >> 2;
  $15 = ($14>>>0)>($$068>>>0);
  $$pre = (($$068) + 1)|0;
  do {
   if (!($15)) {
    $16 = ($$pre>>>0)>($14>>>0);
    $17 = $12;
    $18 = $11;
    if ($16) {
     $19 = (($$pre) - ($14))|0;
     __ZNSt3__26vectorIN3osg7ref_ptrINS1_7Texture13TextureObjectEEENS_9allocatorIS5_EEE8__appendEj($5,$19);
     break;
    }
    $20 = ($$pre>>>0)<($14>>>0);
    if ($20) {
     $21 = (($17) + ($$pre<<2)|0);
     $22 = ($18|0)==($21|0);
     if (!($22)) {
      $24 = $18;
      while(1) {
       $23 = ((($24)) + -4|0);
       HEAP32[$6>>2] = $23;
       $25 = HEAP32[$23>>2]|0;
       $26 = ($25|0)==(0|0);
       if (!($26)) {
        $27 = ((($25)) + 8|0);
        $28 = HEAP32[$27>>2]|0;HEAP32[$27>>2] = (($28-1)|0);
        $29 = ($28|0)==(1);
        if ($29) {
         __THREW__ = 0;
         invoke_viii(3262,($25|0),1,1);
         $30 = __THREW__; __THREW__ = 0;
         $31 = $30&1;
         if ($31) {
          label = 13;
          break L4;
         }
        }
       }
       HEAP32[$23>>2] = 0;
       $32 = HEAP32[$6>>2]|0;
       $33 = ($32|0)==($21|0);
       if ($33) {
        break;
       } else {
        $24 = $32;
       }
      }
     }
    }
   }
  } while(0);
  $36 = HEAP32[$5>>2]|0;
  $37 = (($36) + ($$068<<2)|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = ($38|0)==(0|0);
  if ($39) {
   $40 = 0;
   label = 15;
   break;
  }
  $7 = (__ZN3osg15DisplaySettings8instanceEv()|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (__ZNK3osg15DisplaySettings30getMaxNumberOfGraphicsContextsEv($8)|0);
  $10 = ($$pre>>>0)<($9>>>0);
  if ($10) {
   $$068 = $$pre;
  } else {
   $40 = 1;
   label = 15;
   break;
  }
 }
 if ((label|0) == 13) {
  $34 = ___cxa_find_matching_catch_2()|0;
  $35 = tempRet0;
  ___cxa_call_unexpected(($34|0));
  // unreachable;
 }
 else if ((label|0) == 15) {
  return ($40|0);
 }
 return (0)|0;
}
function __ZNK3osg7Texture20applyTexImage2D_loadERNS_5StateEjPKNS_5ImageEiii($0,$1,$2,$3,$4,$5,$6) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 var $$$0258 = 0, $$$2260 = 0, $$$4262 = 0, $$$6264 = 0, $$$i = 0, $$$i291 = 0, $$$not300 = 0, $$0$i = 0, $$0$i292 = 0, $$0$i293 = 0, $$0$i295 = 0, $$0$i297 = 0, $$01215$i = 0, $$0248313 = 0, $$0249312 = 0, $$0250317 = 0, $$0251322 = 0, $$0252327 = 0, $$0253332 = 0, $$0254 = 0;
 var $$0256331 = 0, $$0258330 = 0, $$0266 = 0, $$0267 = 0, $$0810$i = 0, $$1257 = 0, $$1268 = 0, $$2260325 = 0, $$2326 = 0, $$3 = 0, $$306 = 0, $$4262320 = 0, $$4321 = 0, $$5 = 0, $$6264315 = 0, $$6316 = 0, $$7 = 0, $$cmp = 0, $$not = 0, $$ph = 0;
 var $$sink = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0;
 var $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0;
 var $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0;
 var $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0;
 var $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0;
 var $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0;
 var $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0;
 var $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0;
 var $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0;
 var $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0;
 var $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0;
 var $299 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0;
 var $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0;
 var $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0;
 var $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0;
 var $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0;
 var $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0;
 var $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0;
 var $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0;
 var $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0;
 var $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0;
 var $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0;
 var $499 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $brmerge272 = 0, $brmerge273 = 0, $brmerge301 = 0, $brmerge302 = 0, $or$cond$i = 0, $or$cond13$i = 0, $or$cond15$i = 0, $or$cond17$i = 0, $or$cond19$i = 0, $or$cond21$i = 0, $or$cond23$i = 0, $or$cond25$i = 0, $or$cond277 = 0, $or$cond277329 = 0, $or$cond279 = 0, $or$cond279324 = 0, $or$cond281 = 0, $or$cond281319 = 0, $or$cond283 = 0;
 var $or$cond283314 = 0, $or$cond284 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(112|0);
 $7 = sp + 104|0;
 $8 = sp + 100|0;
 $9 = sp + 96|0;
 $10 = sp + 92|0;
 $11 = sp + 88|0;
 $12 = sp + 24|0;
 $13 = sp + 20|0;
 $14 = sp + 16|0;
 $15 = sp + 12|0;
 $16 = sp + 8|0;
 $17 = sp + 4|0;
 $18 = sp;
 $19 = ($3|0)==(0|0);
 if ($19) {
  STACKTOP = sp;return;
 }
 $20 = ((($3)) + 112|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0|0);
 if ($22) {
  STACKTOP = sp;return;
 }
 $23 = ((($1)) + 784|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ((($3)) + 92|0);
 $26 = HEAP32[$25>>2]|0;
 switch ($26|0) {
 case 35843: case 35842: case 35841: case 35840: case 37491: case 37490: case 37489: case 37488: case 37497: case 37496: case 37495: case 37494: case 37493: case 37492: case 36196: case 36285: case 36286: case 36283: case 36284: case 33779: case 33778: case 33777: case 33776: case 34029: case 34030: case 34026: case 34027: case 34028: case 34025:  {
  $$0$i = 1;
  break;
 }
 default: {
  $$0$i = 0;
 }
 }
 $27 = ((($0)) + 172|0);
 $28 = HEAP32[$27>>2]|0;
 L10: do {
  switch ($28|0) {
  case 35843: case 35842: case 35841: case 35840: case 37491: case 37490: case 37489: case 37488: case 37497: case 37496: case 37495: case 37494: case 37493: case 37492: case 36196: case 36285: case 36286: case 36283: case 36284: case 33779: case 33778: case 33777: case 33776: case 34029: case 34030: case 34026: case 34027: case 34028: case 34025:  {
   $29 = $5 | $4;
   $30 = $29 & -4;
   $31 = ($30|0)==($29|0);
   if (!($31)) {
    $32 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
    if ($32) {
     $33 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
     $34 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($33,155613,83)|0);
     $35 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi($34,$4)|0);
     $36 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($35,193998,1)|0);
     $37 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi($36,$5)|0);
     (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($37,155697,30)|0);
    }
    $38 = HEAP32[$27>>2]|0;
    switch ($38|0) {
    case 34029: case 37493: case 37492: case 36196: case 35840: case 35841: case 33776:  {
     $$sink = 6407;
     break;
    }
    case 34030: case 37497: case 37496: case 37495: case 37494: case 35842: case 35843: case 33779: case 33778: case 33777:  {
     $$sink = 6408;
     break;
    }
    case 34025:  {
     $$sink = 6406;
     break;
    }
    case 34026:  {
     $$sink = 6409;
     break;
    }
    case 34027:  {
     $$sink = 6410;
     break;
    }
    case 34028:  {
     $$sink = 32841;
     break;
    }
    case 36283: case 36284: case 37489: case 37488:  {
     $$sink = 6403;
     break;
    }
    case 36285: case 36286: case 37491: case 37490:  {
     $$sink = 33319;
     break;
    }
    default: {
     break L10;
    }
    }
    HEAP32[$27>>2] = $$sink;
   }
   break;
  }
  default: {
  }
  }
 } while(0);
 $39 = ((($3)) + 100|0);
 $40 = HEAP32[$39>>2]|0;
 _glPixelStorei(3317,($40|0));
 $41 = ((($3)) + 84|0);
 $42 = ((($24)) + 1064|0);
 $43 = HEAP8[$42>>0]|0;
 $44 = ($43<<24>>24)==(0);
 if ($44) {
  $506 = 0;
 } else {
  $45 = ((($0)) + 122|0);
  $46 = HEAP8[$45>>0]|0;
  $47 = ($46<<24>>24)==(0);
  if ($47) {
   $506 = 0;
  } else {
   _glPixelStorei(34226,1);
   $506 = 1;
  }
 }
 $48 = ((($3)) + 72|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = ($49|0)==($4|0);
 if ($50) {
  $51 = HEAP32[$20>>2]|0;
  $52 = ((($3)) + 76|0);
  $53 = HEAP32[$52>>2]|0;
  $54 = ($53|0)==($5|0);
  if ($54) {
   $$0267 = $51;$233 = 0;
  } else {
   label = 23;
  }
 } else {
  label = 23;
 }
 if ((label|0) == 23) {
  $55 = ((($3)) + 116|0);
  $56 = HEAP32[$55>>2]|0;
  $57 = ((($3)) + 120|0);
  $58 = HEAP32[$57>>2]|0;
  $59 = ($56|0)==($58|0);
  if (!($59)) {
   $60 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
   if (!($60)) {
    STACKTOP = sp;return;
   }
   $61 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
   $62 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($61,155728,75)|0);
   $63 = HEAP32[$62>>2]|0;
   $64 = ((($63)) + -12|0);
   $65 = HEAP32[$64>>2]|0;
   $66 = (($62) + ($65)|0);
   __ZNKSt3__28ios_base6getlocEv($10,$66);
   __THREW__ = 0;
   $67 = (invoke_iii(3255,($10|0),(215188|0))|0);
   $68 = __THREW__; __THREW__ = 0;
   $69 = $68&1;
   if (!($69)) {
    $70 = HEAP32[$67>>2]|0;
    $71 = ((($70)) + 28|0);
    $72 = HEAP32[$71>>2]|0;
    __THREW__ = 0;
    $73 = (invoke_iii($72|0,($67|0),10)|0);
    $74 = __THREW__; __THREW__ = 0;
    $75 = $74&1;
    if (!($75)) {
     __ZNSt3__26localeD2Ev($10);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($62,$73)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($62)|0);
     STACKTOP = sp;return;
    }
   }
   $76 = ___cxa_find_matching_catch_2()|0;
   $77 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($10|0));
   $78 = __THREW__; __THREW__ = 0;
   $79 = $78&1;
   if ($79) {
    $80 = ___cxa_find_matching_catch_3(0|0)|0;
    $81 = tempRet0;
    ___clang_call_terminate($80);
    // unreachable;
   } else {
    ___resumeException($76|0);
    // unreachable;
   }
  }
  if ($$0$i) {
   $82 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
   if (!($82)) {
    STACKTOP = sp;return;
   }
   $83 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
   $84 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($83,155804,76)|0);
   $85 = HEAP32[$84>>2]|0;
   $86 = ((($85)) + -12|0);
   $87 = HEAP32[$86>>2]|0;
   $88 = (($84) + ($87)|0);
   __ZNKSt3__28ios_base6getlocEv($9,$88);
   __THREW__ = 0;
   $89 = (invoke_iii(3255,($9|0),(215188|0))|0);
   $90 = __THREW__; __THREW__ = 0;
   $91 = $90&1;
   if (!($91)) {
    $92 = HEAP32[$89>>2]|0;
    $93 = ((($92)) + 28|0);
    $94 = HEAP32[$93>>2]|0;
    __THREW__ = 0;
    $95 = (invoke_iii($94|0,($89|0),10)|0);
    $96 = __THREW__; __THREW__ = 0;
    $97 = $96&1;
    if (!($97)) {
     __ZNSt3__26localeD2Ev($9);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($84,$95)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($84)|0);
     STACKTOP = sp;return;
    }
   }
   $98 = ___cxa_find_matching_catch_2()|0;
   $99 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($9|0));
   $100 = __THREW__; __THREW__ = 0;
   $101 = $100&1;
   if ($101) {
    $102 = ___cxa_find_matching_catch_3(0|0)|0;
    $103 = tempRet0;
    ___clang_call_terminate($102);
    // unreachable;
   } else {
    ___resumeException($98|0);
    // unreachable;
   }
  }
  $104 = HEAP32[$25>>2]|0;
  $105 = ((($3)) + 96|0);
  $106 = HEAP32[$105>>2]|0;
  $107 = HEAP32[$39>>2]|0;
  $108 = (__ZN3osg5Image22computeRowWidthInBytesEijji($4,$104,$106,$107)|0);
  $109 = Math_imul($108, $5)|0;
  $110 = (__Znaj($109)|0);
  $111 = ((($3)) + 52|0);
  $112 = ((($111)) + 11|0);
  $113 = HEAP8[$112>>0]|0;
  $114 = ($113<<24>>24)<(0);
  if ($114) {
   $115 = ((($3)) + 56|0);
   $116 = HEAP32[$115>>2]|0;
   $118 = $116;
  } else {
   $117 = $113&255;
   $118 = $117;
  }
  $119 = ($118|0)==(0);
  $120 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
  do {
   if ($119) {
    if ($120) {
     $163 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
     $164 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($163,155913,20)|0);
     $165 = HEAP32[$48>>2]|0;
     $166 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi($164,$165)|0);
     $167 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($166,155405,1)|0);
     $168 = ((($3)) + 76|0);
     $169 = HEAP32[$168>>2]|0;
     $170 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi($167,$169)|0);
     $171 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($170,155906,6)|0);
     $172 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi($171,$4)|0);
     $173 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($172,155405,1)|0);
     $174 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi($173,$5)|0);
     $175 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($174,174996,1)|0);
     $176 = HEAP32[$175>>2]|0;
     $177 = ((($176)) + -12|0);
     $178 = HEAP32[$177>>2]|0;
     $179 = (($175) + ($178)|0);
     __ZNKSt3__28ios_base6getlocEv($7,$179);
     __THREW__ = 0;
     $180 = (invoke_iii(3255,($7|0),(215188|0))|0);
     $181 = __THREW__; __THREW__ = 0;
     $182 = $181&1;
     if (!($182)) {
      $183 = HEAP32[$180>>2]|0;
      $184 = ((($183)) + 28|0);
      $185 = HEAP32[$184>>2]|0;
      __THREW__ = 0;
      $186 = (invoke_iii($185|0,($180|0),10)|0);
      $187 = __THREW__; __THREW__ = 0;
      $188 = $187&1;
      if (!($188)) {
       __ZNSt3__26localeD2Ev($7);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($175,$186)|0);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($175)|0);
       break;
      }
     }
     $189 = ___cxa_find_matching_catch_2()|0;
     $190 = tempRet0;
     __THREW__ = 0;
     invoke_vi(3263,($7|0));
     $191 = __THREW__; __THREW__ = 0;
     $192 = $191&1;
     if ($192) {
      $193 = ___cxa_find_matching_catch_3(0|0)|0;
      $194 = tempRet0;
      ___clang_call_terminate($193);
      // unreachable;
     } else {
      ___resumeException($189|0);
      // unreachable;
     }
    }
   } else {
    if ($120) {
     $121 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
     $122 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($121,155881,15)|0);
     $123 = HEAP8[$112>>0]|0;
     $124 = ($123<<24>>24)<(0);
     $125 = HEAP32[$111>>2]|0;
     $126 = $124 ? $125 : $111;
     $127 = ((($3)) + 56|0);
     $128 = HEAP32[$127>>2]|0;
     $129 = $123&255;
     $130 = $124 ? $128 : $129;
     $131 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($122,$126,$130)|0);
     $132 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($131,155897,8)|0);
     $133 = HEAP32[$48>>2]|0;
     $134 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi($132,$133)|0);
     $135 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($134,155405,1)|0);
     $136 = ((($3)) + 76|0);
     $137 = HEAP32[$136>>2]|0;
     $138 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi($135,$137)|0);
     $139 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($138,155906,6)|0);
     $140 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi($139,$4)|0);
     $141 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($140,155405,1)|0);
     $142 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi($141,$5)|0);
     $143 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($142,174996,1)|0);
     $144 = HEAP32[$143>>2]|0;
     $145 = ((($144)) + -12|0);
     $146 = HEAP32[$145>>2]|0;
     $147 = (($143) + ($146)|0);
     __ZNKSt3__28ios_base6getlocEv($8,$147);
     __THREW__ = 0;
     $148 = (invoke_iii(3255,($8|0),(215188|0))|0);
     $149 = __THREW__; __THREW__ = 0;
     $150 = $149&1;
     if (!($150)) {
      $151 = HEAP32[$148>>2]|0;
      $152 = ((($151)) + 28|0);
      $153 = HEAP32[$152>>2]|0;
      __THREW__ = 0;
      $154 = (invoke_iii($153|0,($148|0),10)|0);
      $155 = __THREW__; __THREW__ = 0;
      $156 = $155&1;
      if (!($156)) {
       __ZNSt3__26localeD2Ev($8);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($143,$154)|0);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($143)|0);
       break;
      }
     }
     $157 = ___cxa_find_matching_catch_2()|0;
     $158 = tempRet0;
     __THREW__ = 0;
     invoke_vi(3263,($8|0));
     $159 = __THREW__; __THREW__ = 0;
     $160 = $159&1;
     if ($160) {
      $161 = ___cxa_find_matching_catch_3(0|0)|0;
      $162 = tempRet0;
      ___clang_call_terminate($161);
      // unreachable;
     } else {
      ___resumeException($157|0);
      // unreachable;
     }
    }
   }
  } while(0);
  __ZN3osg17PixelStorageModesC2Ev($12);
  $195 = HEAP32[$39>>2]|0;
  HEAP32[$12>>2] = $195;
  $196 = HEAP32[$41>>2]|0;
  $197 = ((($12)) + 4|0);
  HEAP32[$197>>2] = $196;
  $198 = ((($12)) + 32|0);
  HEAP32[$198>>2] = $195;
  $199 = HEAP32[$25>>2]|0;
  $200 = HEAP32[$48>>2]|0;
  $201 = ((($3)) + 76|0);
  $202 = HEAP32[$201>>2]|0;
  $203 = HEAP32[$105>>2]|0;
  $204 = HEAP32[$20>>2]|0;
  (__ZN3osg13gluScaleImageEPNS_17PixelStorageModesEjiijPKviijPv($12,$199,$200,$202,$203,$204,$4,$5,$203,$110)|0);
  $$0267 = $110;$233 = 1;
 }
 $205 = ((($0)) + 92|0);
 $206 = HEAP32[$205>>2]|0;
 $207 = $206 & -2;
 $$cmp = ($207|0)!=(9728);
 if ($$cmp) {
  $208 = ((($3)) + 116|0);
  $209 = HEAP32[$208>>2]|0;
  $210 = ((($3)) + 120|0);
  $211 = HEAP32[$210>>2]|0;
  $212 = ($209|0)==($211|0);
  if ($212) {
   $213 = ((($0)) + 120|0);
   $214 = HEAP8[$213>>0]|0;
   $215 = ($214<<24>>24)==(0);
   if ($215) {
    $234 = 1;$258 = 0;$brmerge302 = 0;
   } else {
    $216 = HEAP32[$23>>2]|0;
    $217 = ((($216)) + 1054|0);
    $218 = HEAP8[$217>>0]|0;
    $219 = ($218<<24>>24)==(0);
    if ($219) {
     $220 = ((($216)) + 1252|0);
     $221 = HEAP8[$220>>0]|0;
     $222 = ($221<<24>>24)==(0);
     if ($222) {
      $234 = $212;$258 = 0;$brmerge302 = 0;
     } else {
      $223 = ((($216)) + 1324|0);
      $224 = HEAP32[$223>>2]|0;
      $225 = ($224|0)==(0|0);
      if ($225) {
       $234 = $212;$258 = 0;$brmerge302 = 0;
      } else {
       $$ph = 1;
       label = 64;
      }
     }
    } else {
     $$ph = 1;
     label = 64;
    }
   }
  } else {
   $234 = 0;$258 = 0;$brmerge302 = 0;
  }
 } else {
  $$ph = 0;
  label = 64;
 }
 if ((label|0) == 64) {
  $$$not300 = $$cmp ^ 1;
  $brmerge301 = $$ph | $$$not300;
  $234 = 0;$258 = $$ph;$brmerge302 = $brmerge301;
 }
 $226 = ((($3)) + 40|0);
 $227 = HEAP32[$226>>2]|0;
 $228 = ($227|0)==(0|0);
 if ($228) {
  $$0266 = 0;$$1268 = $$0267;
 } else {
  $229 = ((($1)) + 124|0);
  $230 = HEAP32[$229>>2]|0;
  $231 = (__ZNK3osg12BufferObject25getOrCreateGLBufferObjectEj($227,$230)|0);
  $232 = ($231|0)==(0|0);
  $brmerge272 = $233 | $232;
  $brmerge273 = $234 | $brmerge272;
  if ($brmerge273) {
   $$0266 = 0;$$1268 = $$0267;
  } else {
   $235 = ((($1)) + 696|0);
   $236 = HEAP32[$235>>2]|0;
   $237 = ($236|0)==($231|0);
   if (!($237)) {
    $238 = ((($231)) + 36|0);
    $239 = HEAP8[$238>>0]|0;
    $240 = ($239<<24>>24)==(0);
    if ($240) {
     $241 = ((($231)) + 72|0);
     $242 = HEAP32[$241>>2]|0;
     $243 = ((($242)) + 724|0);
     $244 = HEAP32[$243>>2]|0;
     $245 = ((($231)) + 20|0);
     $246 = HEAP32[$245>>2]|0;
     $247 = ((($231)) + 16|0);
     $248 = HEAP32[$247>>2]|0;
     FUNCTION_TABLE_vii[$244 & 8191]($246,$248);
     $249 = ((($231)) + 56|0);
     $250 = HEAP32[$249>>2]|0;
     $251 = ($250|0)==(0|0);
     if (!($251)) {
      __ZN3osg17GLBufferObjectSet10moveToBackEPNS_14GLBufferObjectE($250,$231);
     }
    } else {
     __ZN3osg14GLBufferObject13compileBufferEv($231);
    }
    HEAP32[$235>>2] = $231;
   }
   $252 = ((($3)) + 36|0);
   $253 = HEAP32[$252>>2]|0;
   $254 = ((($231)) + 40|0);
   $255 = HEAP32[$254>>2]|0;
   $256 = (((($255) + (($253*20)|0)|0)) + 12|0);
   $257 = HEAP32[$256>>2]|0;
   $$0266 = $231;$$1268 = $257;
  }
 }
 L108: do {
  if ($brmerge302) {
   $$$i = $258&1;
   if ($$0$i) {
    $265 = ((($24)) + 1076|0);
    $266 = HEAP32[$265>>2]|0;
    $267 = ($266|0)==(0|0);
    if (!($267)) {
     $268 = HEAP32[$27>>2]|0;
     __ZN3osg7Texture17getCompressedSizeEjiiiRiS1_($268,$4,$5,1,$13,$14);
     $269 = HEAP32[$265>>2]|0;
     $270 = HEAP32[$27>>2]|0;
     $271 = HEAP32[$14>>2]|0;
     FUNCTION_TABLE_viiiiiiii[$269 & 8191]($2,0,$270,$4,$5,0,$271,$$1268);
    }
   } else {
    $259 = HEAP32[$27>>2]|0;
    $260 = ((($0)) + 160|0);
    $261 = HEAP32[$260>>2]|0;
    $262 = HEAP32[$25>>2]|0;
    $263 = ((($3)) + 96|0);
    $264 = HEAP32[$263>>2]|0;
    _glTexImage2D(($2|0),0,($259|0),($4|0),($5|0),($261|0),($262|0),($264|0),($$1268|0));
   }
   __ZNK3osg7Texture19mipmapAfterTexImageERNS_5StateENS0_18GenerateMipmapModeE($0,$1,$$$i);
  } else {
   $272 = ((($3)) + 116|0);
   $273 = HEAP32[$272>>2]|0;
   $274 = ((($3)) + 120|0);
   $275 = HEAP32[$274>>2]|0;
   $276 = ($273|0)==($275|0);
   if ($276) {
    if (!($$0$i)) {
     $456 = HEAP32[$27>>2]|0;
     $457 = HEAP32[$25>>2]|0;
     $458 = ((($3)) + 96|0);
     $459 = HEAP32[$458>>2]|0;
     (__ZN3osg17gluBuild2DMipmapsEjiiijjPKv($2,$456,$4,$5,$457,$459,$$1268)|0);
     $460 = HEAP32[$48>>2]|0;
     $461 = ((($3)) + 76|0);
     $462 = HEAP32[$461>>2]|0;
     $463 = $462 | $460;
     $464 = ($463|0)==(0);
     if ($464) {
      break;
     } else {
      $$0248313 = $462;$$0249312 = $460;
     }
     while(1) {
      $465 = $$0249312 >> 1;
      $466 = $$0248313 >> 1;
      $467 = $466 | $465;
      $468 = ($467|0)==(0);
      if ($468) {
       break L108;
      } else {
       $$0248313 = $466;$$0249312 = $465;
      }
     }
    }
    $469 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
    if (!($469)) {
     break;
    }
    $470 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
    $471 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($470,155934,47)|0);
    $472 = HEAP32[$471>>2]|0;
    $473 = ((($472)) + -12|0);
    $474 = HEAP32[$473>>2]|0;
    $475 = (($471) + ($474)|0);
    __ZNKSt3__28ios_base6getlocEv($11,$475);
    __THREW__ = 0;
    $476 = (invoke_iii(3255,($11|0),(215188|0))|0);
    $477 = __THREW__; __THREW__ = 0;
    $478 = $477&1;
    if (!($478)) {
     $479 = HEAP32[$476>>2]|0;
     $480 = ((($479)) + 28|0);
     $481 = HEAP32[$480>>2]|0;
     __THREW__ = 0;
     $482 = (invoke_iii($481|0,($476|0),10)|0);
     $483 = __THREW__; __THREW__ = 0;
     $484 = $483&1;
     if (!($484)) {
      __ZNSt3__26localeD2Ev($11);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($471,$482)|0);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($471)|0);
      break;
     }
    }
    $485 = ___cxa_find_matching_catch_2()|0;
    $486 = tempRet0;
    __THREW__ = 0;
    invoke_vi(3263,($11|0));
    $487 = __THREW__; __THREW__ = 0;
    $488 = $487&1;
    if ($488) {
     $489 = ___cxa_find_matching_catch_3(0|0)|0;
     $490 = tempRet0;
     ___clang_call_terminate($489);
     // unreachable;
    } else {
     ___resumeException($485|0);
     // unreachable;
    }
   }
   $277 = $273;
   $278 = $275;
   $279 = ((($3)) + 116|0);
   $280 = (($278) - ($277))|0;
   $281 = $280 >> 2;
   $282 = (($281) + 1)|0;
   $283 = ((($24)) + 1066|0);
   $284 = HEAP8[$283>>0]|0;
   $285 = ($284<<24>>24)==(0);
   if (!($285)) {
    $286 = ((($24)) + 1072|0);
    $287 = HEAP32[$286>>2]|0;
    $288 = ($287|0)==(0|0);
    L134: do {
     if ($288) {
      $$0254 = 0;
     } else {
      $289 = ((($0)) + 160|0);
      $290 = HEAP32[$289>>2]|0;
      $291 = ($290|0)==(0);
      if ($291) {
       $292 = HEAP32[$27>>2]|0;
       if ($$0$i) {
        $312 = HEAP32[16959]|0;
        $313 = ($312|0)==($292|0);
        $314 = HEAP32[(67848)>>2]|0;
        $315 = ($314|0)==($292|0);
        $or$cond$i = $313 | $315;
        $316 = HEAP32[(67860)>>2]|0;
        $317 = ($316|0)==($292|0);
        $or$cond13$i = $or$cond$i | $317;
        $318 = HEAP32[(67872)>>2]|0;
        $319 = ($318|0)==($292|0);
        $or$cond15$i = $or$cond13$i | $319;
        $320 = HEAP32[(67884)>>2]|0;
        $321 = ($320|0)==($292|0);
        $or$cond17$i = $or$cond15$i | $321;
        $322 = HEAP32[(67896)>>2]|0;
        $323 = ($322|0)==($292|0);
        $or$cond19$i = $or$cond17$i | $323;
        $324 = HEAP32[(67908)>>2]|0;
        $325 = ($324|0)==($292|0);
        $or$cond21$i = $or$cond19$i | $325;
        $326 = HEAP32[(67920)>>2]|0;
        $327 = ($326|0)==($292|0);
        $or$cond23$i = $or$cond21$i | $327;
        $328 = HEAP32[(67932)>>2]|0;
        $329 = ($328|0)==($292|0);
        $or$cond25$i = $or$cond23$i | $329;
        $330 = HEAP32[(67944)>>2]|0;
        $331 = ($330|0)==($292|0);
        $$$i291 = $or$cond25$i | $331;
        $$306 = $$$i291 ? $292 : 0;
        $$0254 = $$306;
        break;
       } else {
        $$0810$i = 0;
       }
       while(1) {
        $295 = (67008 + (($$0810$i*12)|0)|0);
        $296 = HEAP32[$295>>2]|0;
        $297 = ($296|0)==($292|0);
        $293 = (($$0810$i) + 1)|0;
        if ($297) {
         $$0254 = $292;
         break L134;
        }
        $294 = ($293>>>0)<(69);
        if ($294) {
         $$0810$i = $293;
        } else {
         break;
        }
       }
       $298 = ((($3)) + 88|0);
       $299 = HEAP32[$298>>2]|0;
       $300 = ((($3)) + 96|0);
       $301 = HEAP32[$300>>2]|0;
       $$01215$i = 0;
       while(1) {
        $302 = (((67008 + (($$01215$i*12)|0)|0)) + 4|0);
        $303 = HEAP32[$302>>2]|0;
        $304 = ($303|0)==($299|0);
        if ($304) {
         $305 = (((67008 + (($$01215$i*12)|0)|0)) + 8|0);
         $306 = HEAP32[$305>>2]|0;
         $307 = ($306|0)==($301|0);
         if ($307) {
          break;
         }
        }
        $308 = (($$01215$i) + 1)|0;
        $309 = ($308>>>0)<(69);
        if ($309) {
         $$01215$i = $308;
        } else {
         $$0254 = 0;
         break L134;
        }
       }
       $310 = (67008 + (($$01215$i*12)|0)|0);
       $311 = HEAP32[$310>>2]|0;
       $$0254 = $311;
      } else {
       $$0254 = 0;
      }
     }
    } while(0);
    $332 = ($$0254|0)!=(0);
    $333 = $332&1;
    $334 = $284&255;
    $335 = $333 & $334;
    $336 = ($335|0)==(0);
    if (!($336)) {
     FUNCTION_TABLE_viiiii[$287 & 8191]($2,$282,$$0254,$4,$5);
     if (!($$0$i)) {
      $337 = ($280|0)<(0);
      $338 = $5 | $4;
      $339 = ($338|0)==(0);
      $or$cond277329 = $337 | $339;
      if ($or$cond277329) {
       break;
      }
      $340 = ((($3)) + 96|0);
      $$0253332 = 0;$$0256331 = $5;$$0258330 = $4;
      while(1) {
       $341 = ($$0258330|0)==(0);
       $$$0258 = $341 ? 1 : $$0258330;
       $342 = ($$0256331|0)==(0);
       $$1257 = $342 ? 1 : $$0256331;
       $343 = HEAP32[$25>>2]|0;
       $344 = HEAP32[$340>>2]|0;
       $345 = ($$0253332|0)==(0);
       if ($345) {
        $$0$i292 = 0;
       } else {
        $346 = HEAP32[$274>>2]|0;
        $347 = HEAP32[$279>>2]|0;
        $348 = (($346) - ($347))|0;
        $349 = $348 >> 2;
        $350 = (($349) + 1)|0;
        $351 = ($350>>>0)>($$0253332>>>0);
        if ($351) {
         $352 = $347;
         $353 = (($$0253332) + -1)|0;
         $354 = (($352) + ($353<<2)|0);
         $355 = HEAP32[$354>>2]|0;
         $$0$i292 = $355;
        } else {
         $$0$i292 = 0;
        }
       }
       $356 = (($$1268) + ($$0$i292)|0);
       _glTexSubImage2D(($2|0),($$0253332|0),0,0,($$$0258|0),($$1257|0),($343|0),($344|0),($356|0));
       $357 = $$$0258 >> 1;
       $358 = $$1257 >> 1;
       $359 = (($$0253332) + 1)|0;
       $360 = ($$0253332|0)>=($281|0);
       $361 = $358 | $357;
       $362 = ($361|0)==(0);
       $or$cond277 = $360 | $362;
       if ($or$cond277) {
        break L108;
       } else {
        $$0253332 = $359;$$0256331 = $358;$$0258330 = $357;
       }
      }
     }
     $363 = ((($24)) + 1076|0);
     $364 = HEAP32[$363>>2]|0;
     $365 = ($364|0)==(0|0);
     if ($365) {
      break;
     }
     $366 = ($280|0)<(0);
     $367 = $5 | $4;
     $368 = ($367|0)==(0);
     $or$cond279324 = $366 | $368;
     if (!($or$cond279324)) {
      $369 = ((($3)) + 88|0);
      $370 = ((($24)) + 1080|0);
      $$0252327 = 0;$$2260325 = $4;$$2326 = $5;
      while(1) {
       $371 = ($$2260325|0)==(0);
       $$$2260 = $371 ? 1 : $$2260325;
       $372 = ($$2326|0)==(0);
       $$3 = $372 ? 1 : $$2326;
       $373 = HEAP32[$369>>2]|0;
       __ZN3osg7Texture17getCompressedSizeEjiiiRiS1_($373,$$$2260,$$3,1,$15,$16);
       $374 = HEAP32[$370>>2]|0;
       $375 = HEAP32[$25>>2]|0;
       $376 = HEAP32[$16>>2]|0;
       $377 = ($$0252327|0)==(0);
       do {
        if ($377) {
         $$0$i293 = 0;
        } else {
         $378 = HEAP32[$274>>2]|0;
         $379 = HEAP32[$279>>2]|0;
         $380 = (($378) - ($379))|0;
         $381 = $380 >> 2;
         $382 = (($381) + 1)|0;
         $383 = ($382>>>0)>($$0252327>>>0);
         if (!($383)) {
          $$0$i293 = 0;
          break;
         }
         $384 = $379;
         $385 = (($$0252327) + -1)|0;
         $386 = (($384) + ($385<<2)|0);
         $387 = HEAP32[$386>>2]|0;
         $$0$i293 = $387;
        }
       } while(0);
       $388 = (($$1268) + ($$0$i293)|0);
       FUNCTION_TABLE_viiiiiiiii[$374 & 8191]($2,$$0252327,0,0,$$$2260,$$3,$375,$376,$388);
       $389 = $$$2260 >> 1;
       $390 = $$3 >> 1;
       $391 = (($$0252327) + 1)|0;
       $392 = ($$0252327|0)>=($281|0);
       $393 = $390 | $389;
       $394 = ($393|0)==(0);
       $or$cond279 = $392 | $394;
       if ($or$cond279) {
        break;
       } else {
        $$0252327 = $391;$$2260325 = $389;$$2326 = $390;
       }
      }
     }
     break;
    }
   }
   if (!($$0$i)) {
    $395 = ($280|0)<(0);
    $396 = $5 | $4;
    $397 = ($396|0)==(0);
    $or$cond281319 = $395 | $397;
    if ($or$cond281319) {
     break;
    }
    $398 = ((($0)) + 160|0);
    $399 = ((($3)) + 96|0);
    $$0251322 = 0;$$4262320 = $4;$$4321 = $5;
    while(1) {
     $400 = ($$4262320|0)==(0);
     $$$4262 = $400 ? 1 : $$4262320;
     $401 = ($$4321|0)==(0);
     $$5 = $401 ? 1 : $$4321;
     $402 = HEAP32[$27>>2]|0;
     $403 = HEAP32[$398>>2]|0;
     $404 = HEAP32[$25>>2]|0;
     $405 = HEAP32[$399>>2]|0;
     $406 = ($$0251322|0)==(0);
     if ($406) {
      $$0$i295 = 0;
     } else {
      $407 = HEAP32[$274>>2]|0;
      $408 = HEAP32[$279>>2]|0;
      $409 = (($407) - ($408))|0;
      $410 = $409 >> 2;
      $411 = (($410) + 1)|0;
      $412 = ($411>>>0)>($$0251322>>>0);
      if ($412) {
       $413 = $408;
       $414 = (($$0251322) + -1)|0;
       $415 = (($413) + ($414<<2)|0);
       $416 = HEAP32[$415>>2]|0;
       $$0$i295 = $416;
      } else {
       $$0$i295 = 0;
      }
     }
     $417 = (($$1268) + ($$0$i295)|0);
     _glTexImage2D(($2|0),($$0251322|0),($402|0),($$$4262|0),($$5|0),($403|0),($404|0),($405|0),($417|0));
     $418 = $$$4262 >> 1;
     $419 = $$5 >> 1;
     $420 = (($$0251322) + 1)|0;
     $421 = ($$0251322|0)>=($281|0);
     $422 = $419 | $418;
     $423 = ($422|0)==(0);
     $or$cond281 = $421 | $423;
     if ($or$cond281) {
      break L108;
     } else {
      $$0251322 = $420;$$4262320 = $418;$$4321 = $419;
     }
    }
   }
   $424 = ((($24)) + 1076|0);
   $425 = HEAP32[$424>>2]|0;
   $426 = ($425|0)==(0|0);
   if (!($426)) {
    $427 = ($280|0)<(0);
    $428 = $5 | $4;
    $429 = ($428|0)==(0);
    $or$cond283314 = $427 | $429;
    if (!($or$cond283314)) {
     $430 = ((($0)) + 160|0);
     $$0250317 = 0;$$6264315 = $4;$$6316 = $5;
     while(1) {
      $431 = ($$6264315|0)==(0);
      $$$6264 = $431 ? 1 : $$6264315;
      $432 = ($$6316|0)==(0);
      $$7 = $432 ? 1 : $$6316;
      $433 = HEAP32[$27>>2]|0;
      __ZN3osg7Texture17getCompressedSizeEjiiiRiS1_($433,$$$6264,$$7,1,$17,$18);
      $434 = HEAP32[$424>>2]|0;
      $435 = HEAP32[$27>>2]|0;
      $436 = HEAP32[$430>>2]|0;
      $437 = HEAP32[$18>>2]|0;
      $438 = ($$0250317|0)==(0);
      if ($438) {
       $$0$i297 = 0;
      } else {
       $439 = HEAP32[$274>>2]|0;
       $440 = HEAP32[$279>>2]|0;
       $441 = (($439) - ($440))|0;
       $442 = $441 >> 2;
       $443 = (($442) + 1)|0;
       $444 = ($443>>>0)>($$0250317>>>0);
       if ($444) {
        $445 = $440;
        $446 = (($$0250317) + -1)|0;
        $447 = (($445) + ($446<<2)|0);
        $448 = HEAP32[$447>>2]|0;
        $$0$i297 = $448;
       } else {
        $$0$i297 = 0;
       }
      }
      $449 = (($$1268) + ($$0$i297)|0);
      FUNCTION_TABLE_viiiiiiii[$434 & 8191]($2,$$0250317,$435,$$$6264,$$7,$436,$437,$449);
      $450 = $$$6264 >> 1;
      $451 = $$7 >> 1;
      $452 = (($$0250317) + 1)|0;
      $453 = ($$0250317|0)>=($281|0);
      $454 = $451 | $450;
      $455 = ($454|0)==(0);
      $or$cond283 = $453 | $455;
      if ($or$cond283) {
       break;
      } else {
       $$0250317 = $452;$$6264315 = $450;$$6316 = $451;
      }
     }
    }
   }
  }
 } while(0);
 $491 = ($$0266|0)==(0|0);
 if (!($491)) {
  $492 = ((($1)) + 696|0);
  $493 = HEAP32[$492>>2]|0;
  $494 = ($493|0)==(0|0);
  if (!($494)) {
   $495 = ((($1)) + 772|0);
   $496 = HEAP32[$495>>2]|0;
   FUNCTION_TABLE_vii[$496 & 8191](35052,0);
   HEAP32[$492>>2] = 0;
  }
  $497 = HEAP32[$226>>2]|0;
  $498 = ((($497)) + 44|0);
  $499 = HEAP8[$498>>0]|0;
  $500 = ($499<<24>>24)==(0);
  if (!($500)) {
   __ZN3osg14GLBufferObject24setBufferDataHasBeenReadEPKNS_10BufferDataE($$0266,$3);
   $501 = (__ZNK3osg14GLBufferObject24hasAllBufferDataBeenReadEv($$0266)|0);
   if ($501) {
    $502 = HEAP32[$497>>2]|0;
    $503 = ((($502)) + 136|0);
    $504 = HEAP32[$503>>2]|0;
    FUNCTION_TABLE_vii[$504 & 8191]($497,$1);
   }
  }
 }
 $$not = $233 ^ 1;
 $505 = ($$1268|0)==(0|0);
 $or$cond284 = $505 | $$not;
 if (!($or$cond284)) {
  __ZdaPv($$1268);
 }
 if (!($506)) {
  STACKTOP = sp;return;
 }
 _glPixelStorei(34226,0);
 STACKTOP = sp;return;
}
function __ZNK3osg7Texture19mipmapAfterTexImageERNS_5StateENS0_18GenerateMipmapModeE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 switch ($2|0) {
 case 1:  {
  $3 = ((($1)) + 124|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ((($0)) + 224|0);
  $6 = ((($0)) + 228|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = HEAP32[$5>>2]|0;
  $9 = (($7) - ($8))|0;
  $10 = $9 >> 2;
  $11 = ($10>>>0)>($4>>>0);
  L3: do {
   if (!($11)) {
    $12 = (($4) + 1)|0;
    $13 = ($12>>>0)>($10>>>0);
    $14 = $8;
    $15 = $7;
    if ($13) {
     $16 = (($12) - ($10))|0;
     __ZNSt3__26vectorIN3osg7ref_ptrINS1_7Texture13TextureObjectEEENS_9allocatorIS5_EEE8__appendEj($5,$16);
     break;
    }
    $17 = ($12>>>0)<($10>>>0);
    if ($17) {
     $18 = (($14) + ($12<<2)|0);
     $19 = ($15|0)==($18|0);
     if (!($19)) {
      $21 = $15;
      while(1) {
       $20 = ((($21)) + -4|0);
       HEAP32[$6>>2] = $20;
       $22 = HEAP32[$20>>2]|0;
       $23 = ($22|0)==(0|0);
       if (!($23)) {
        $24 = ((($22)) + 8|0);
        $25 = HEAP32[$24>>2]|0;HEAP32[$24>>2] = (($25-1)|0);
        $26 = ($25|0)==(1);
        if ($26) {
         __THREW__ = 0;
         invoke_viii(3262,($22|0),1,1);
         $27 = __THREW__; __THREW__ = 0;
         $28 = $27&1;
         if ($28) {
          break;
         }
        }
       }
       HEAP32[$20>>2] = 0;
       $29 = HEAP32[$6>>2]|0;
       $30 = ($29|0)==($18|0);
       if ($30) {
        break L3;
       } else {
        $21 = $29;
       }
      }
      $31 = ___cxa_find_matching_catch_2()|0;
      $32 = tempRet0;
      ___cxa_call_unexpected(($31|0));
      // unreachable;
     }
    }
   }
  } while(0);
  $33 = HEAP32[$5>>2]|0;
  $34 = (($33) + ($4<<2)|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = ($35|0)==(0|0);
  if ($36) {
   return;
  }
  $37 = ((($1)) + 784|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = ((($38)) + 1324|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = ((($35)) + 16|0);
  $42 = HEAP32[$41>>2]|0;
  FUNCTION_TABLE_vi[$40 & 8191]($42);
  return;
  break;
 }
 case 2:  {
  _glTexParameteri(3553,33169,0);
  return;
  break;
 }
 default: {
  return;
 }
 }
}
function __ZNK3osg7Texture33isHardwareMipmapGenerationEnabledERKNS_5StateE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 120|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  $$1 = 0;
  return ($$1|0);
 }
 $5 = ((($1)) + 784|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($6)) + 1054|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = ($8<<24>>24)==(0);
 if (!($9)) {
  $$1 = 1;
  return ($$1|0);
 }
 $10 = ((($6)) + 1252|0);
 $11 = HEAP8[$10>>0]|0;
 $12 = ($11<<24>>24)==(0);
 if (!($12)) {
  $13 = ((($6)) + 1324|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = ($14|0)==(0|0);
  if (!($15)) {
   $$1 = 1;
   return ($$1|0);
  }
 }
 $$1 = 0;
 return ($$1|0);
}
function __ZNK3osg7Texture20mipmapBeforeTexImageERKNS_5StateEb($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$ = $2&1;
 return ($$|0);
}
function __ZNK3osg7Texture23applyTexImage2D_subloadERNS_5StateEjPKNS_5ImageEiiii($0,$1,$2,$3,$4,$5,$6,$7) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 var $$$0183 = 0, $$$2185 = 0, $$$i = 0, $$$not209 = 0, $$0$i = 0, $$0$i202 = 0, $$0$i204 = 0, $$0181221 = 0, $$0182220 = 0, $$0183219 = 0, $$0187 = 0, $$0188 = 0, $$0217 = 0, $$1 = 0, $$1189 = 0, $$2185215 = 0, $$2216 = 0, $$3 = 0, $$cmp = 0, $$not = 0;
 var $$ph = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0;
 var $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0;
 var $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0;
 var $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0;
 var $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0;
 var $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0;
 var $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0;
 var $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0;
 var $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0;
 var $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0;
 var $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0;
 var $299 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0;
 var $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $brmerge192 = 0, $brmerge193 = 0, $brmerge210 = 0, $brmerge211 = 0, $or$cond197 = 0, $or$cond197218 = 0, $or$cond199 = 0, $or$cond199214 = 0, $or$cond200 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(96|0);
 $8 = sp + 92|0;
 $9 = sp + 88|0;
 $10 = sp + 84|0;
 $11 = sp + 80|0;
 $12 = sp + 16|0;
 $13 = sp + 12|0;
 $14 = sp + 8|0;
 $15 = sp + 4|0;
 $16 = sp;
 $17 = ($3|0)==(0|0);
 if ($17) {
  STACKTOP = sp;return;
 }
 $18 = ((($3)) + 112|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)==(0|0);
 if ($20) {
  STACKTOP = sp;return;
 }
 $21 = ((($3)) + 72|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==($4|0);
 if ($23) {
  $24 = ((($3)) + 76|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = ($25|0)==($5|0);
  if ($26) {
   $27 = ((($3)) + 88|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = ($28|0)==($6|0);
   if ($29) {
    $30 = ((($0)) + 172|0);
    $31 = HEAP32[$30>>2]|0;
    switch ($31|0) {
    case 35843: case 35842: case 35841: case 35840: case 37491: case 37490: case 37489: case 37488: case 37497: case 37496: case 37495: case 37494: case 37493: case 37492: case 36196: case 36285: case 36286: case 36283: case 36284: case 33779: case 33778: case 33777: case 33776: case 34029: case 34030: case 34026: case 34027: case 34028: case 34025:  {
     $32 = $5 | $4;
     $33 = $32 & -4;
     $34 = ($33|0)==($32|0);
     if (!($34)) {
      __ZNK3osg7Texture20applyTexImage2D_loadERNS_5StateEjPKNS_5ImageEiii($0,$1,$2,$3,$4,$5,0);
      STACKTOP = sp;return;
     }
     break;
    }
    default: {
    }
    }
    $35 = ((($1)) + 124|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = ((($1)) + 784|0);
    $38 = HEAP32[$37>>2]|0;
    $39 = ((($3)) + 92|0);
    $40 = HEAP32[$39>>2]|0;
    switch ($40|0) {
    case 35843: case 35842: case 35841: case 35840: case 37491: case 37490: case 37489: case 37488: case 37497: case 37496: case 37495: case 37494: case 37493: case 37492: case 36196: case 36285: case 36286: case 36283: case 36284: case 33779: case 33778: case 33777: case 33776: case 34029: case 34030: case 34026: case 34027: case 34028: case 34025:  {
     $$0$i204 = 1;
     break;
    }
    default: {
     $$0$i204 = 0;
    }
    }
    $41 = ((($3)) + 100|0);
    $42 = HEAP32[$41>>2]|0;
    _glPixelStorei(3317,($42|0));
    $43 = HEAP32[$21>>2]|0;
    $44 = ($43|0)==($4|0);
    if ($44) {
     $45 = HEAP32[$18>>2]|0;
     $46 = HEAP32[$24>>2]|0;
     $47 = ($46|0)==($5|0);
     if ($47) {
      $$0188 = $45;$219 = 0;
     } else {
      label = 14;
     }
    } else {
     label = 14;
    }
    if ((label|0) == 14) {
     $48 = ((($3)) + 116|0);
     $49 = HEAP32[$48>>2]|0;
     $50 = ((($3)) + 120|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = ($49|0)==($51|0);
     if (!($52)) {
      $53 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
      if (!($53)) {
       STACKTOP = sp;return;
      }
      $54 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
      $55 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($54,155728,75)|0);
      $56 = HEAP32[$55>>2]|0;
      $57 = ((($56)) + -12|0);
      $58 = HEAP32[$57>>2]|0;
      $59 = (($55) + ($58)|0);
      __ZNKSt3__28ios_base6getlocEv($10,$59);
      __THREW__ = 0;
      $60 = (invoke_iii(3255,($10|0),(215188|0))|0);
      $61 = __THREW__; __THREW__ = 0;
      $62 = $61&1;
      if (!($62)) {
       $63 = HEAP32[$60>>2]|0;
       $64 = ((($63)) + 28|0);
       $65 = HEAP32[$64>>2]|0;
       __THREW__ = 0;
       $66 = (invoke_iii($65|0,($60|0),10)|0);
       $67 = __THREW__; __THREW__ = 0;
       $68 = $67&1;
       if (!($68)) {
        __ZNSt3__26localeD2Ev($10);
        (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($55,$66)|0);
        (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($55)|0);
        STACKTOP = sp;return;
       }
      }
      $69 = ___cxa_find_matching_catch_2()|0;
      $70 = tempRet0;
      __THREW__ = 0;
      invoke_vi(3263,($10|0));
      $71 = __THREW__; __THREW__ = 0;
      $72 = $71&1;
      if ($72) {
       $73 = ___cxa_find_matching_catch_3(0|0)|0;
       $74 = tempRet0;
       ___clang_call_terminate($73);
       // unreachable;
      } else {
       ___resumeException($69|0);
       // unreachable;
      }
     }
     if ($$0$i204) {
      $75 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
      if (!($75)) {
       STACKTOP = sp;return;
      }
      $76 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
      $77 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($76,155804,76)|0);
      $78 = HEAP32[$77>>2]|0;
      $79 = ((($78)) + -12|0);
      $80 = HEAP32[$79>>2]|0;
      $81 = (($77) + ($80)|0);
      __ZNKSt3__28ios_base6getlocEv($9,$81);
      __THREW__ = 0;
      $82 = (invoke_iii(3255,($9|0),(215188|0))|0);
      $83 = __THREW__; __THREW__ = 0;
      $84 = $83&1;
      if (!($84)) {
       $85 = HEAP32[$82>>2]|0;
       $86 = ((($85)) + 28|0);
       $87 = HEAP32[$86>>2]|0;
       __THREW__ = 0;
       $88 = (invoke_iii($87|0,($82|0),10)|0);
       $89 = __THREW__; __THREW__ = 0;
       $90 = $89&1;
       if (!($90)) {
        __ZNSt3__26localeD2Ev($9);
        (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($77,$88)|0);
        (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($77)|0);
        STACKTOP = sp;return;
       }
      }
      $91 = ___cxa_find_matching_catch_2()|0;
      $92 = tempRet0;
      __THREW__ = 0;
      invoke_vi(3263,($9|0));
      $93 = __THREW__; __THREW__ = 0;
      $94 = $93&1;
      if ($94) {
       $95 = ___cxa_find_matching_catch_3(0|0)|0;
       $96 = tempRet0;
       ___clang_call_terminate($95);
       // unreachable;
      } else {
       ___resumeException($91|0);
       // unreachable;
      }
     }
     $97 = HEAP32[$39>>2]|0;
     $98 = ((($3)) + 96|0);
     $99 = HEAP32[$98>>2]|0;
     $100 = HEAP32[$41>>2]|0;
     $101 = (__ZN3osg5Image22computeRowWidthInBytesEijji($4,$97,$99,$100)|0);
     $102 = Math_imul($101, $5)|0;
     $103 = (__Znaj($102)|0);
     $104 = ((($3)) + 52|0);
     $105 = ((($104)) + 11|0);
     $106 = HEAP8[$105>>0]|0;
     $107 = ($106<<24>>24)<(0);
     if ($107) {
      $108 = ((($3)) + 56|0);
      $109 = HEAP32[$108>>2]|0;
      $111 = $109;
     } else {
      $110 = $106&255;
      $111 = $110;
     }
     $112 = ($111|0)==(0);
     $113 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
     do {
      if ($112) {
       if ($113) {
        $155 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
        $156 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($155,155913,20)|0);
        $157 = HEAP32[$21>>2]|0;
        $158 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi($156,$157)|0);
        $159 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($158,155405,1)|0);
        $160 = HEAP32[$24>>2]|0;
        $161 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi($159,$160)|0);
        $162 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($161,155906,6)|0);
        $163 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi($162,$4)|0);
        $164 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($163,155405,1)|0);
        $165 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi($164,$5)|0);
        $166 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($165,174996,1)|0);
        $167 = HEAP32[$166>>2]|0;
        $168 = ((($167)) + -12|0);
        $169 = HEAP32[$168>>2]|0;
        $170 = (($166) + ($169)|0);
        __ZNKSt3__28ios_base6getlocEv($11,$170);
        __THREW__ = 0;
        $171 = (invoke_iii(3255,($11|0),(215188|0))|0);
        $172 = __THREW__; __THREW__ = 0;
        $173 = $172&1;
        if (!($173)) {
         $174 = HEAP32[$171>>2]|0;
         $175 = ((($174)) + 28|0);
         $176 = HEAP32[$175>>2]|0;
         __THREW__ = 0;
         $177 = (invoke_iii($176|0,($171|0),10)|0);
         $178 = __THREW__; __THREW__ = 0;
         $179 = $178&1;
         if (!($179)) {
          __ZNSt3__26localeD2Ev($11);
          (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($166,$177)|0);
          (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($166)|0);
          break;
         }
        }
        $180 = ___cxa_find_matching_catch_2()|0;
        $181 = tempRet0;
        __THREW__ = 0;
        invoke_vi(3263,($11|0));
        $182 = __THREW__; __THREW__ = 0;
        $183 = $182&1;
        if ($183) {
         $184 = ___cxa_find_matching_catch_3(0|0)|0;
         $185 = tempRet0;
         ___clang_call_terminate($184);
         // unreachable;
        } else {
         ___resumeException($180|0);
         // unreachable;
        }
       }
      } else {
       if ($113) {
        $114 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
        $115 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($114,155881,15)|0);
        $116 = HEAP8[$105>>0]|0;
        $117 = ($116<<24>>24)<(0);
        $118 = HEAP32[$104>>2]|0;
        $119 = $117 ? $118 : $104;
        $120 = ((($3)) + 56|0);
        $121 = HEAP32[$120>>2]|0;
        $122 = $116&255;
        $123 = $117 ? $121 : $122;
        $124 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($115,$119,$123)|0);
        $125 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($124,155897,8)|0);
        $126 = HEAP32[$21>>2]|0;
        $127 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi($125,$126)|0);
        $128 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($127,155405,1)|0);
        $129 = HEAP32[$24>>2]|0;
        $130 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi($128,$129)|0);
        $131 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($130,155906,6)|0);
        $132 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi($131,$4)|0);
        $133 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($132,155405,1)|0);
        $134 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi($133,$5)|0);
        $135 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($134,174996,1)|0);
        $136 = HEAP32[$135>>2]|0;
        $137 = ((($136)) + -12|0);
        $138 = HEAP32[$137>>2]|0;
        $139 = (($135) + ($138)|0);
        __ZNKSt3__28ios_base6getlocEv($8,$139);
        __THREW__ = 0;
        $140 = (invoke_iii(3255,($8|0),(215188|0))|0);
        $141 = __THREW__; __THREW__ = 0;
        $142 = $141&1;
        if (!($142)) {
         $143 = HEAP32[$140>>2]|0;
         $144 = ((($143)) + 28|0);
         $145 = HEAP32[$144>>2]|0;
         __THREW__ = 0;
         $146 = (invoke_iii($145|0,($140|0),10)|0);
         $147 = __THREW__; __THREW__ = 0;
         $148 = $147&1;
         if (!($148)) {
          __ZNSt3__26localeD2Ev($8);
          (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($135,$146)|0);
          (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($135)|0);
          break;
         }
        }
        $149 = ___cxa_find_matching_catch_2()|0;
        $150 = tempRet0;
        __THREW__ = 0;
        invoke_vi(3263,($8|0));
        $151 = __THREW__; __THREW__ = 0;
        $152 = $151&1;
        if ($152) {
         $153 = ___cxa_find_matching_catch_3(0|0)|0;
         $154 = tempRet0;
         ___clang_call_terminate($153);
         // unreachable;
        } else {
         ___resumeException($149|0);
         // unreachable;
        }
       }
      }
     } while(0);
     __ZN3osg17PixelStorageModesC2Ev($12);
     $186 = HEAP32[$41>>2]|0;
     HEAP32[$12>>2] = $186;
     $187 = ((($12)) + 32|0);
     HEAP32[$187>>2] = $186;
     $188 = HEAP32[$39>>2]|0;
     $189 = HEAP32[$21>>2]|0;
     $190 = HEAP32[$24>>2]|0;
     $191 = HEAP32[$98>>2]|0;
     $192 = HEAP32[$18>>2]|0;
     (__ZN3osg13gluScaleImageEPNS_17PixelStorageModesEjiijPKviijPv($12,$188,$189,$190,$191,$192,$4,$5,$191,$103)|0);
     $$0188 = $103;$219 = 1;
    }
    $193 = ((($0)) + 92|0);
    $194 = HEAP32[$193>>2]|0;
    $195 = $194 & -2;
    $$cmp = ($195|0)!=(9728);
    if ($$cmp) {
     $196 = ((($3)) + 116|0);
     $197 = HEAP32[$196>>2]|0;
     $198 = ((($3)) + 120|0);
     $199 = HEAP32[$198>>2]|0;
     $200 = ($197|0)==($199|0);
     if ($200) {
      $201 = ((($0)) + 120|0);
      $202 = HEAP8[$201>>0]|0;
      $203 = ($202<<24>>24)==(0);
      if ($203) {
       $220 = 1;$244 = 0;$brmerge211 = 0;
      } else {
       $204 = HEAP32[$37>>2]|0;
       $205 = ((($204)) + 1054|0);
       $206 = HEAP8[$205>>0]|0;
       $207 = ($206<<24>>24)==(0);
       if ($207) {
        $208 = ((($204)) + 1252|0);
        $209 = HEAP8[$208>>0]|0;
        $210 = ($209<<24>>24)==(0);
        if ($210) {
         $220 = $200;$244 = 0;$brmerge211 = 0;
        } else {
         $211 = ((($204)) + 1324|0);
         $212 = HEAP32[$211>>2]|0;
         $213 = ($212|0)==(0|0);
         if ($213) {
          $220 = $200;$244 = 0;$brmerge211 = 0;
         } else {
          $$ph = 1;
          label = 55;
         }
        }
       } else {
        $$ph = 1;
        label = 55;
       }
      }
     } else {
      $220 = 0;$244 = 0;$brmerge211 = 0;
     }
    } else {
     $$ph = 0;
     label = 55;
    }
    if ((label|0) == 55) {
     $$$not209 = $$cmp ^ 1;
     $brmerge210 = $$ph | $$$not209;
     $220 = 0;$244 = $$ph;$brmerge211 = $brmerge210;
    }
    $214 = ((($3)) + 40|0);
    $215 = HEAP32[$214>>2]|0;
    $216 = ($215|0)==(0|0);
    if ($216) {
     $$0187 = 0;$$1189 = $$0188;
    } else {
     $217 = (__ZNK3osg12BufferObject25getOrCreateGLBufferObjectEj($215,$36)|0);
     $218 = ($217|0)==(0|0);
     $brmerge192 = $219 | $218;
     $brmerge193 = $220 | $brmerge192;
     if ($brmerge193) {
      $$0187 = 0;$$1189 = $$0188;
     } else {
      $221 = ((($1)) + 696|0);
      $222 = HEAP32[$221>>2]|0;
      $223 = ($222|0)==($217|0);
      if (!($223)) {
       $224 = ((($217)) + 36|0);
       $225 = HEAP8[$224>>0]|0;
       $226 = ($225<<24>>24)==(0);
       if ($226) {
        $227 = ((($217)) + 72|0);
        $228 = HEAP32[$227>>2]|0;
        $229 = ((($228)) + 724|0);
        $230 = HEAP32[$229>>2]|0;
        $231 = ((($217)) + 20|0);
        $232 = HEAP32[$231>>2]|0;
        $233 = ((($217)) + 16|0);
        $234 = HEAP32[$233>>2]|0;
        FUNCTION_TABLE_vii[$230 & 8191]($232,$234);
        $235 = ((($217)) + 56|0);
        $236 = HEAP32[$235>>2]|0;
        $237 = ($236|0)==(0|0);
        if (!($237)) {
         __ZN3osg17GLBufferObjectSet10moveToBackEPNS_14GLBufferObjectE($236,$217);
        }
       } else {
        __ZN3osg14GLBufferObject13compileBufferEv($217);
       }
       HEAP32[$221>>2] = $217;
      }
      $238 = ((($3)) + 36|0);
      $239 = HEAP32[$238>>2]|0;
      $240 = ((($217)) + 40|0);
      $241 = HEAP32[$240>>2]|0;
      $242 = (((($241) + (($239*20)|0)|0)) + 12|0);
      $243 = HEAP32[$242>>2]|0;
      $$0187 = $217;$$1189 = $243;
     }
    }
    L97: do {
     if ($brmerge211) {
      $$$i = $244&1;
      if ($$0$i204) {
       $248 = ((($38)) + 1076|0);
       $249 = HEAP32[$248>>2]|0;
       $250 = ($249|0)==(0|0);
       if (!($250)) {
        $251 = HEAP32[$27>>2]|0;
        __ZN3osg7Texture17getCompressedSizeEjiiiRiS1_($251,$4,$5,1,$13,$14);
        $252 = ((($38)) + 1080|0);
        $253 = HEAP32[$252>>2]|0;
        $254 = HEAP32[$39>>2]|0;
        $255 = HEAP32[$14>>2]|0;
        FUNCTION_TABLE_viiiiiiiii[$253 & 8191]($2,0,0,0,$4,$5,$254,$255,$$1189);
       }
      } else {
       $245 = HEAP32[$39>>2]|0;
       $246 = ((($3)) + 96|0);
       $247 = HEAP32[$246>>2]|0;
       _glTexSubImage2D(($2|0),0,0,0,($4|0),($5|0),($245|0),($247|0),($$1189|0));
      }
      __ZNK3osg7Texture19mipmapAfterTexImageERNS_5StateENS0_18GenerateMipmapModeE($0,$1,$$$i);
     } else {
      $256 = ((($3)) + 116|0);
      $257 = HEAP32[$256>>2]|0;
      $258 = ((($3)) + 120|0);
      $259 = HEAP32[$258>>2]|0;
      $260 = ($257|0)==($259|0);
      if ($260) {
       __ZNK3osg7Texture20applyTexImage2D_loadERNS_5StateEjPKNS_5ImageEiii($0,$1,$2,$3,$4,$5,0);
       break;
      }
      $261 = $257;
      $262 = $259;
      $263 = ((($3)) + 116|0);
      $264 = (($262) - ($261))|0;
      $265 = $264 >> 2;
      if (!($$0$i204)) {
       $266 = ($264|0)<(0);
       $267 = $5 | $4;
       $268 = ($267|0)==(0);
       $or$cond197218 = $266 | $268;
       if ($or$cond197218) {
        break;
       }
       $269 = ((($3)) + 96|0);
       $$0181221 = 0;$$0182220 = $5;$$0183219 = $4;
       while(1) {
        $270 = ($$0183219|0)==(0);
        $$$0183 = $270 ? 1 : $$0183219;
        $271 = ($$0182220|0)==(0);
        $$1 = $271 ? 1 : $$0182220;
        $272 = HEAP32[$39>>2]|0;
        $273 = HEAP32[$269>>2]|0;
        $274 = ($$0181221|0)==(0);
        if ($274) {
         $$0$i202 = 0;
        } else {
         $275 = HEAP32[$258>>2]|0;
         $276 = HEAP32[$263>>2]|0;
         $277 = (($275) - ($276))|0;
         $278 = $277 >> 2;
         $279 = (($278) + 1)|0;
         $280 = ($279>>>0)>($$0181221>>>0);
         if ($280) {
          $281 = $276;
          $282 = (($$0181221) + -1)|0;
          $283 = (($281) + ($282<<2)|0);
          $284 = HEAP32[$283>>2]|0;
          $$0$i202 = $284;
         } else {
          $$0$i202 = 0;
         }
        }
        $285 = (($$1189) + ($$0$i202)|0);
        _glTexSubImage2D(($2|0),($$0181221|0),0,0,($$$0183|0),($$1|0),($272|0),($273|0),($285|0));
        $286 = $$$0183 >> 1;
        $287 = $$1 >> 1;
        $288 = (($$0181221) + 1)|0;
        $289 = ($$0181221|0)>=($265|0);
        $290 = $287 | $286;
        $291 = ($290|0)==(0);
        $or$cond197 = $289 | $291;
        if ($or$cond197) {
         break L97;
        } else {
         $$0181221 = $288;$$0182220 = $287;$$0183219 = $286;
        }
       }
      }
      $292 = ((($38)) + 1076|0);
      $293 = HEAP32[$292>>2]|0;
      $294 = ($293|0)==(0|0);
      if (!($294)) {
       $295 = ($264|0)<(0);
       $296 = $5 | $4;
       $297 = ($296|0)==(0);
       $or$cond199214 = $295 | $297;
       if (!($or$cond199214)) {
        $298 = ((($38)) + 1080|0);
        $$0217 = 0;$$2185215 = $4;$$2216 = $5;
        while(1) {
         $299 = ($$2185215|0)==(0);
         $$$2185 = $299 ? 1 : $$2185215;
         $300 = ($$2216|0)==(0);
         $$3 = $300 ? 1 : $$2216;
         $301 = HEAP32[$27>>2]|0;
         __ZN3osg7Texture17getCompressedSizeEjiiiRiS1_($301,$$$2185,$$3,1,$15,$16);
         $302 = HEAP32[$298>>2]|0;
         $303 = HEAP32[$39>>2]|0;
         $304 = HEAP32[$16>>2]|0;
         $305 = ($$0217|0)==(0);
         if ($305) {
          $$0$i = 0;
         } else {
          $306 = HEAP32[$258>>2]|0;
          $307 = HEAP32[$263>>2]|0;
          $308 = (($306) - ($307))|0;
          $309 = $308 >> 2;
          $310 = (($309) + 1)|0;
          $311 = ($310>>>0)>($$0217>>>0);
          if ($311) {
           $312 = $307;
           $313 = (($$0217) + -1)|0;
           $314 = (($312) + ($313<<2)|0);
           $315 = HEAP32[$314>>2]|0;
           $$0$i = $315;
          } else {
           $$0$i = 0;
          }
         }
         $316 = (($$1189) + ($$0$i)|0);
         FUNCTION_TABLE_viiiiiiiii[$302 & 8191]($2,$$0217,0,0,$$$2185,$$3,$303,$304,$316);
         $317 = $$$2185 >> 1;
         $318 = $$3 >> 1;
         $319 = (($$0217) + 1)|0;
         $320 = ($$0217|0)>=($265|0);
         $321 = $318 | $317;
         $322 = ($321|0)==(0);
         $or$cond199 = $320 | $322;
         if ($or$cond199) {
          break;
         } else {
          $$0217 = $319;$$2185215 = $317;$$2216 = $318;
         }
        }
       }
      }
     }
    } while(0);
    $323 = ($$0187|0)==(0|0);
    if (!($323)) {
     $324 = ((($1)) + 696|0);
     $325 = HEAP32[$324>>2]|0;
     $326 = ($325|0)==(0|0);
     if (!($326)) {
      $327 = ((($1)) + 772|0);
      $328 = HEAP32[$327>>2]|0;
      FUNCTION_TABLE_vii[$328 & 8191](35052,0);
      HEAP32[$324>>2] = 0;
     }
    }
    $$not = $219 ^ 1;
    $329 = ($$1189|0)==(0|0);
    $or$cond200 = $329 | $$not;
    if ($or$cond200) {
     STACKTOP = sp;return;
    }
    __ZdaPv($$1189);
    STACKTOP = sp;return;
   }
  }
 }
 __ZNK3osg7Texture20applyTexImage2D_loadERNS_5StateEjPKNS_5ImageEiii($0,$1,$2,$3,$4,$5,0);
 STACKTOP = sp;return;
}
function __ZNK3osg7Texture14generateMipmapERNS_5StateE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$pre$i = 0, $$pre$pre$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $scevgep$i$i$i$i = 0, $scevgep5$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = ((($1)) + 124|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 224|0);
 $6 = ((($0)) + 228|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$5>>2]|0;
 $9 = (($7) - ($8))|0;
 $10 = $9 >> 2;
 $11 = ($10>>>0)>($4>>>0);
 L1: do {
  if (!($11)) {
   $12 = (($4) + 1)|0;
   $13 = ($12>>>0)>($10>>>0);
   $14 = $8;
   $15 = $7;
   if ($13) {
    $16 = (($12) - ($10))|0;
    __ZNSt3__26vectorIN3osg7ref_ptrINS1_7Texture13TextureObjectEEENS_9allocatorIS5_EEE8__appendEj($5,$16);
    break;
   }
   $17 = ($12>>>0)<($10>>>0);
   if ($17) {
    $18 = (($14) + ($12<<2)|0);
    $19 = ($15|0)==($18|0);
    if (!($19)) {
     $21 = $15;
     while(1) {
      $20 = ((($21)) + -4|0);
      HEAP32[$6>>2] = $20;
      $22 = HEAP32[$20>>2]|0;
      $23 = ($22|0)==(0|0);
      if (!($23)) {
       $24 = ((($22)) + 8|0);
       $25 = HEAP32[$24>>2]|0;HEAP32[$24>>2] = (($25-1)|0);
       $26 = ($25|0)==(1);
       if ($26) {
        __THREW__ = 0;
        invoke_viii(3262,($22|0),1,1);
        $27 = __THREW__; __THREW__ = 0;
        $28 = $27&1;
        if ($28) {
         break;
        }
       }
      }
      HEAP32[$20>>2] = 0;
      $29 = HEAP32[$6>>2]|0;
      $30 = ($29|0)==($18|0);
      if ($30) {
       break L1;
      } else {
       $21 = $29;
      }
     }
     $31 = ___cxa_find_matching_catch_2()|0;
     $32 = tempRet0;
     ___cxa_call_unexpected(($31|0));
     // unreachable;
    }
   }
  }
 } while(0);
 $33 = HEAP32[$5>>2]|0;
 $34 = (($33) + ($4<<2)|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = ($35|0)==(0|0);
 if ($36) {
  STACKTOP = sp;return;
 }
 $37 = ((($0)) + 68|0);
 $38 = ((($0)) + 72|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = HEAP32[$37>>2]|0;
 $41 = (($39) - ($40))|0;
 $42 = $41 >> 2;
 $43 = ($42>>>0)>($4>>>0);
 $44 = $40;
 if ($43) {
  $58 = $44;
 } else {
  $45 = (($4) + 1)|0;
  HEAP32[$2>>2] = 0;
  $46 = ($45>>>0)>($42>>>0);
  $47 = $39;
  if ($46) {
   $48 = (($45) - ($42))|0;
   __ZNSt3__26vectorIjNS_9allocatorIjEEE8__appendEjRKj($37,$48,$2);
   $$pre$pre$i = HEAP32[$37>>2]|0;
   $$pre$i = $$pre$pre$i;
  } else {
   $49 = ($45>>>0)<($42>>>0);
   if ($49) {
    $50 = (($44) + ($45<<2)|0);
    $51 = ($47|0)==($50|0);
    if ($51) {
     $$pre$i = $44;
    } else {
     $scevgep$i$i$i$i = ((($47)) + -4|0);
     $52 = $scevgep$i$i$i$i;
     $53 = $50;
     $54 = (($52) - ($53))|0;
     $55 = $54 >>> 2;
     $56 = $55 ^ -1;
     $scevgep5$i$i$i$i = (($47) + ($56<<2)|0);
     HEAP32[$38>>2] = $scevgep5$i$i$i$i;
     $$pre$i = $44;
    }
   } else {
    $$pre$i = $44;
   }
  }
  $58 = $$pre$i;
 }
 $57 = (($58) + ($4<<2)|0);
 HEAP32[$57>>2] = 0;
 $59 = ((($0)) + 168|0);
 $60 = HEAP32[$59>>2]|0;
 switch ($60|0) {
 case 4: case 2:  {
  $61 = HEAP32[$0>>2]|0;
  $62 = ((($61)) + 216|0);
  $63 = HEAP32[$62>>2]|0;
  FUNCTION_TABLE_vii[$63 & 8191]($0,$1);
  STACKTOP = sp;return;
  break;
 }
 default: {
 }
 }
 $64 = ((($1)) + 784|0);
 $65 = HEAP32[$64>>2]|0;
 $66 = ((($65)) + 1252|0);
 $67 = HEAP8[$66>>0]|0;
 $68 = ($67<<24>>24)==(0);
 if (!($68)) {
  $69 = ((($65)) + 1324|0);
  $70 = HEAP32[$69>>2]|0;
  $71 = ($70|0)==(0|0);
  if (!($71)) {
   $72 = ((($35)) + 16|0);
   $73 = HEAP32[$72>>2]|0;
   $74 = ((($35)) + 12|0);
   $75 = HEAP32[$74>>2]|0;
   _glBindTexture(($73|0),($75|0));
   $76 = ((($35)) + 48|0);
   $77 = HEAP32[$76>>2]|0;
   $78 = ($77|0)==(0|0);
   if (!($78)) {
    __ZN3osg16TextureObjectSet10moveToBackEPNS_7Texture13TextureObjectE($77,$35);
   }
   $79 = HEAP32[$69>>2]|0;
   $80 = HEAP32[$72>>2]|0;
   FUNCTION_TABLE_vi[$79 & 8191]($80);
   $81 = ((($1)) + 688|0);
   $82 = HEAP32[$81>>2]|0;
   __ZN3osg5State27haveAppliedTextureAttributeEjPKNS_14StateAttributeE($1,$82,$0);
   STACKTOP = sp;return;
  }
 }
 $83 = HEAP32[$0>>2]|0;
 $84 = ((($83)) + 216|0);
 $85 = HEAP32[$84>>2]|0;
 FUNCTION_TABLE_vii[$85 & 8191]($0,$1);
 STACKTOP = sp;return;
}
function __ZN3osg14TextureCubeMap22copyTexSubImageCubeMapERNS_5StateEiiiiiii($0,$1,$2,$3,$4,$5,$6,$7,$8) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 $8 = $8|0;
 var $$0$off0 = 0, $$039 = 0, $$cmp = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $9 = sp + 4|0;
 $10 = sp;
 $11 = ((($1)) + 124|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ((($1)) + 784|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ((($14)) + 37|0);
 $16 = HEAP8[$15>>0]|0;
 $17 = ($16<<24>>24)==(0);
 if ($17) {
  STACKTOP = sp;return;
 }
 $18 = ((($0)) + 172|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)==(0);
 if ($20) {
  HEAP32[$18>>2] = 6408;
 }
 $21 = ((($0)) + 224|0);
 $22 = ((($0)) + 228|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = HEAP32[$21>>2]|0;
 $25 = (($23) - ($24))|0;
 $26 = $25 >> 2;
 $27 = ($26>>>0)>($12>>>0);
 L7: do {
  if (!($27)) {
   $28 = (($12) + 1)|0;
   $29 = ($28>>>0)>($26>>>0);
   $30 = $24;
   $31 = $23;
   if ($29) {
    $32 = (($28) - ($26))|0;
    __ZNSt3__26vectorIN3osg7ref_ptrINS1_7Texture13TextureObjectEEENS_9allocatorIS5_EEE8__appendEj($21,$32);
    break;
   }
   $33 = ($28>>>0)<($26>>>0);
   if ($33) {
    $34 = (($30) + ($28<<2)|0);
    $35 = ($31|0)==($34|0);
    if (!($35)) {
     $37 = $31;
     while(1) {
      $36 = ((($37)) + -4|0);
      HEAP32[$22>>2] = $36;
      $38 = HEAP32[$36>>2]|0;
      $39 = ($38|0)==(0|0);
      if (!($39)) {
       $40 = ((($38)) + 8|0);
       $41 = HEAP32[$40>>2]|0;HEAP32[$40>>2] = (($41-1)|0);
       $42 = ($41|0)==(1);
       if ($42) {
        __THREW__ = 0;
        invoke_viii(3262,($38|0),1,1);
        $43 = __THREW__; __THREW__ = 0;
        $44 = $43&1;
        if ($44) {
         break;
        }
       }
      }
      HEAP32[$36>>2] = 0;
      $45 = HEAP32[$22>>2]|0;
      $46 = ($45|0)==($34|0);
      if ($46) {
       break L7;
      } else {
       $37 = $45;
      }
     }
     $47 = ___cxa_find_matching_catch_2()|0;
     $48 = tempRet0;
     ___cxa_call_unexpected(($47|0));
     // unreachable;
    }
   }
  }
 } while(0);
 $49 = HEAP32[$21>>2]|0;
 $50 = (($49) + ($12<<2)|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = ($51|0)==(0|0);
 if ($52) {
  $53 = ((($0)) + 264|0);
  $54 = HEAP32[$53>>2]|0;
  $55 = ($54|0)==(0);
  if ($55) {
   HEAP32[$53>>2] = $7;
  }
  $56 = ((($0)) + 268|0);
  $57 = HEAP32[$56>>2]|0;
  $58 = ($57|0)==(0);
  if ($58) {
   HEAP32[$56>>2] = $8;
  }
  $59 = HEAP32[$0>>2]|0;
  $60 = ((($59)) + 172|0);
  $61 = HEAP32[$60>>2]|0;
  FUNCTION_TABLE_vii[$61 & 8191]($0,$1);
  $62 = HEAP32[$22>>2]|0;
  $63 = HEAP32[$21>>2]|0;
  $64 = (($62) - ($63))|0;
  $65 = $64 >> 2;
  $66 = ($65>>>0)>($12>>>0);
  L29: do {
   if (!($66)) {
    $67 = (($12) + 1)|0;
    $68 = ($67>>>0)>($65>>>0);
    $69 = $63;
    $70 = $62;
    if ($68) {
     $71 = (($67) - ($65))|0;
     __ZNSt3__26vectorIN3osg7ref_ptrINS1_7Texture13TextureObjectEEENS_9allocatorIS5_EEE8__appendEj($21,$71);
     break;
    }
    $72 = ($67>>>0)<($65>>>0);
    if ($72) {
     $73 = (($69) + ($67<<2)|0);
     $74 = ($70|0)==($73|0);
     if (!($74)) {
      $76 = $70;
      while(1) {
       $75 = ((($76)) + -4|0);
       HEAP32[$22>>2] = $75;
       $77 = HEAP32[$75>>2]|0;
       $78 = ($77|0)==(0|0);
       if (!($78)) {
        $79 = ((($77)) + 8|0);
        $80 = HEAP32[$79>>2]|0;HEAP32[$79>>2] = (($80-1)|0);
        $81 = ($80|0)==(1);
        if ($81) {
         __THREW__ = 0;
         invoke_viii(3262,($77|0),1,1);
         $82 = __THREW__; __THREW__ = 0;
         $83 = $82&1;
         if ($83) {
          break;
         }
        }
       }
       HEAP32[$75>>2] = 0;
       $84 = HEAP32[$22>>2]|0;
       $85 = ($84|0)==($73|0);
       if ($85) {
        break L29;
       } else {
        $76 = $84;
       }
      }
      $86 = ___cxa_find_matching_catch_2()|0;
      $87 = tempRet0;
      ___cxa_call_unexpected(($86|0));
      // unreachable;
     }
    }
   }
  } while(0);
  $88 = HEAP32[$21>>2]|0;
  $89 = (($88) + ($12<<2)|0);
  $90 = HEAP32[$89>>2]|0;
  $91 = ($90|0)==(0|0);
  if ($91) {
   $92 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
   if (!($92)) {
    STACKTOP = sp;return;
   }
   $93 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
   $94 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($93,156005,92)|0);
   $95 = HEAP32[$94>>2]|0;
   $96 = ((($95)) + -12|0);
   $97 = HEAP32[$96>>2]|0;
   $98 = (($94) + ($97)|0);
   __ZNKSt3__28ios_base6getlocEv($9,$98);
   __THREW__ = 0;
   $99 = (invoke_iii(3255,($9|0),(215188|0))|0);
   $100 = __THREW__; __THREW__ = 0;
   $101 = $100&1;
   if (!($101)) {
    $102 = HEAP32[$99>>2]|0;
    $103 = ((($102)) + 28|0);
    $104 = HEAP32[$103>>2]|0;
    __THREW__ = 0;
    $105 = (invoke_iii($104|0,($99|0),10)|0);
    $106 = __THREW__; __THREW__ = 0;
    $107 = $106&1;
    if (!($107)) {
     __ZNSt3__26localeD2Ev($9);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($94,$105)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($94)|0);
     STACKTOP = sp;return;
    }
   }
   $108 = ___cxa_find_matching_catch_2()|0;
   $109 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($9|0));
   $110 = __THREW__; __THREW__ = 0;
   $111 = $110&1;
   if ($111) {
    $112 = ___cxa_find_matching_catch_3(0|0)|0;
    $113 = tempRet0;
    ___clang_call_terminate($112);
    // unreachable;
   } else {
    ___resumeException($108|0);
    // unreachable;
   }
  } else {
   $$039 = $90;
  }
 } else {
  $$039 = $51;
 }
 $114 = (68276 + ($2<<2)|0);
 $115 = HEAP32[$114>>2]|0;
 __ZN3osg7Texture13TextureObject4bindEv($$039);
 __ZNK3osg7Texture18applyTexParametersEjRNS_5StateE($0,34067,$1);
 $116 = ((($0)) + 92|0);
 $117 = HEAP32[$116>>2]|0;
 $118 = $117 & -2;
 $$cmp = ($118|0)==(9728);
 if ($$cmp) {
  $$0$off0 = 0;
 } else {
  $119 = (__ZNK3osg7Texture33isHardwareMipmapGenerationEnabledERKNS_5StateE($0,$1)|0);
  if ($119) {
   $$0$off0 = 1;
  } else {
   $120 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
   do {
    if ($120) {
     $121 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
     $122 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($121,156098,103)|0);
     $123 = HEAP32[$122>>2]|0;
     $124 = ((($123)) + -12|0);
     $125 = HEAP32[$124>>2]|0;
     $126 = (($122) + ($125)|0);
     __ZNKSt3__28ios_base6getlocEv($10,$126);
     __THREW__ = 0;
     $127 = (invoke_iii(3255,($10|0),(215188|0))|0);
     $128 = __THREW__; __THREW__ = 0;
     $129 = $128&1;
     if (!($129)) {
      $130 = HEAP32[$127>>2]|0;
      $131 = ((($130)) + 28|0);
      $132 = HEAP32[$131>>2]|0;
      __THREW__ = 0;
      $133 = (invoke_iii($132|0,($127|0),10)|0);
      $134 = __THREW__; __THREW__ = 0;
      $135 = $134&1;
      if (!($135)) {
       __ZNSt3__26localeD2Ev($10);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($122,$133)|0);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($122)|0);
       break;
      }
     }
     $136 = ___cxa_find_matching_catch_2()|0;
     $137 = tempRet0;
     __THREW__ = 0;
     invoke_vi(3263,($10|0));
     $138 = __THREW__; __THREW__ = 0;
     $139 = $138&1;
     if ($139) {
      $140 = ___cxa_find_matching_catch_3(0|0)|0;
      $141 = tempRet0;
      ___clang_call_terminate($140);
      // unreachable;
     } else {
      ___resumeException($136|0);
      // unreachable;
     }
    }
   } while(0);
   HEAP32[$116>>2] = 9729;
   $$0$off0 = 0;
  }
 }
 $142 = (__ZNK3osg7Texture20mipmapBeforeTexImageERKNS_5StateEb($0,$1,$$0$off0)|0);
 _glCopyTexSubImage2D(($115|0),0,($3|0),($4|0),($5|0),($6|0),($7|0),($8|0));
 __ZNK3osg7Texture19mipmapAfterTexImageERNS_5StateENS0_18GenerateMipmapModeE($0,$1,$142);
 $143 = ((($1)) + 688|0);
 $144 = HEAP32[$143>>2]|0;
 __ZN3osg5State27haveAppliedTextureAttributeEjPKNS_14StateAttributeE($1,$144,$0);
 STACKTOP = sp;return;
}
function __ZN3osg16TextureRectangleD2Ev($0) {
 $0 = $0|0;
 var $$1 = 0, $$13 = 0, $$2 = 0, $$24 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i$i$i6 = 0, $scevgep5$i$i$i$i = 0, $scevgep5$i$i$i$i7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (68308);
 __THREW__ = 0;
 invoke_vii(3984,($0|0),(0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if ($2) {
   $30 = ___cxa_find_matching_catch_2()|0;
   $31 = tempRet0;
   $32 = ((($0)) + 256|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = ($33|0)==(0|0);
   if (!($34)) {
    $35 = ((($0)) + 260|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = ($36|0)==($33|0);
    if (!($37)) {
     $scevgep$i$i$i$i6 = ((($36)) + -4|0);
     $38 = $scevgep$i$i$i$i6;
     $39 = $33;
     $40 = (($38) - ($39))|0;
     $41 = $40 >>> 2;
     $42 = $41 ^ -1;
     $scevgep5$i$i$i$i7 = (($36) + ($42<<2)|0);
     HEAP32[$35>>2] = $scevgep5$i$i$i$i7;
    }
    __ZdlPv($33);
   }
   $45 = ((($0)) + 252|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = ($46|0)==(0|0);
   if (!($47)) {
    $48 = ((($46)) + 8|0);
    $49 = HEAP32[$48>>2]|0;HEAP32[$48>>2] = (($49-1)|0);
    $50 = ($49|0)==(1);
    if ($50) {
     __THREW__ = 0;
     invoke_viii(3262,($46|0),1,1);
     $51 = __THREW__; __THREW__ = 0;
     $52 = $51&1;
     if ($52) {
      $65 = ___cxa_find_matching_catch_3(0|0)|0;
      $66 = tempRet0;
      ___clang_call_terminate($65);
      // unreachable;
     }
    }
   }
   HEAP32[$45>>2] = 0;
   $$1 = $31;$$13 = $30;
   label = 23;
  } else {
   $3 = ((($0)) + 256|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = ($4|0)==(0|0);
   if (!($5)) {
    $6 = ((($0)) + 260|0);
    $7 = HEAP32[$6>>2]|0;
    $8 = ($7|0)==($4|0);
    if (!($8)) {
     $scevgep$i$i$i$i = ((($7)) + -4|0);
     $9 = $scevgep$i$i$i$i;
     $10 = $4;
     $11 = (($9) - ($10))|0;
     $12 = $11 >>> 2;
     $13 = $12 ^ -1;
     $scevgep5$i$i$i$i = (($7) + ($13<<2)|0);
     HEAP32[$6>>2] = $scevgep5$i$i$i$i;
    }
    __ZdlPv($4);
   }
   $14 = ((($0)) + 252|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = ($15|0)==(0|0);
   if (!($16)) {
    $17 = ((($15)) + 8|0);
    $18 = HEAP32[$17>>2]|0;HEAP32[$17>>2] = (($18-1)|0);
    $19 = ($18|0)==(1);
    if ($19) {
     __THREW__ = 0;
     invoke_viii(3262,($15|0),1,1);
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      $43 = ___cxa_find_matching_catch_2()|0;
      $44 = tempRet0;
      $$1 = $44;$$13 = $43;
      label = 23;
      break;
     }
    }
   }
   HEAP32[$14>>2] = 0;
   $22 = ((($0)) + 240|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = ($23|0)==(0|0);
   if ($24) {
    HEAP32[$22>>2] = 0;
    __ZN3osg7TextureD2Ev($0);
    return;
   }
   $25 = ((($23)) + 8|0);
   $26 = HEAP32[$25>>2]|0;HEAP32[$25>>2] = (($26-1)|0);
   $27 = ($26|0)==(1);
   if (!($27)) {
    HEAP32[$22>>2] = 0;
    __ZN3osg7TextureD2Ev($0);
    return;
   }
   __THREW__ = 0;
   invoke_viii(3262,($23|0),1,1);
   $28 = __THREW__; __THREW__ = 0;
   $29 = $28&1;
   if ($29) {
    $53 = ___cxa_find_matching_catch_2()|0;
    $54 = tempRet0;
    $$2 = $54;$$24 = $53;
    break;
   } else {
    HEAP32[$22>>2] = 0;
    __ZN3osg7TextureD2Ev($0);
    return;
   }
  }
 } while(0);
 if ((label|0) == 23) {
  $55 = ((($0)) + 240|0);
  $56 = HEAP32[$55>>2]|0;
  $57 = ($56|0)==(0|0);
  if (!($57)) {
   $58 = ((($56)) + 8|0);
   $59 = HEAP32[$58>>2]|0;HEAP32[$58>>2] = (($59-1)|0);
   $60 = ($59|0)==(1);
   if ($60) {
    __THREW__ = 0;
    invoke_viii(3262,($56|0),1,1);
    $61 = __THREW__; __THREW__ = 0;
    $62 = $61&1;
    if ($62) {
     $65 = ___cxa_find_matching_catch_3(0|0)|0;
     $66 = tempRet0;
     ___clang_call_terminate($65);
     // unreachable;
    }
   }
  }
  HEAP32[$55>>2] = 0;
  $$2 = $$1;$$24 = $$13;
 }
 __THREW__ = 0;
 invoke_vi(2335,($0|0));
 $63 = __THREW__; __THREW__ = 0;
 $64 = $63&1;
 if ($64) {
  $65 = ___cxa_find_matching_catch_3(0|0)|0;
  $66 = tempRet0;
  ___clang_call_terminate($65);
  // unreachable;
 } else {
  ___resumeException($$24|0);
  // unreachable;
 }
}
function __ZN3osg16TextureRectangleD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(2346,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK3osg16TextureRectangle9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(272)|0);
 __THREW__ = 0;
 invoke_vi(3331,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch_2()|0;
  $5 = tempRet0;
  __ZdlPv($1);
  ___resumeException($4|0);
  // unreachable;
 } else {
  return ($1|0);
 }
 return (0)|0;
}
function __ZNK3osg16TextureRectangle5cloneERKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(272)|0);
 __THREW__ = 0;
 invoke_viii(3985,($2|0),($0|0),($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch_2()|0;
  $6 = tempRet0;
  __ZdlPv($2);
  ___resumeException($5|0);
  // unreachable;
 } else {
  return ($2|0);
 }
 return (0)|0;
}
function __ZNK3osg16TextureRectangle12isSameKindAsEPKNS_6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,26912,0)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK3osg16TextureRectangle11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175113|0);
}
function __ZNK3osg16TextureRectangle9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (156423|0);
}
function __ZNK3osg16TextureRectangle7getTypeEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function __ZNK3osg16TextureRectangle7compareERKNS_14StateAttributeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$$43 = 0, $$43 = 0, $$6 = 0, $$pre = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($0|0)==($1|0);
 if ($2) {
  $$6 = 0;
  return ($$6|0);
 }
 $3 = ($0|0)==(0|0);
 if ($3) {
  ___cxa_bad_typeid();
  // unreachable;
 }
 $4 = HEAP32[$0>>2]|0;
 $5 = ((($4)) + -4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$1>>2]|0;
 $8 = ((($7)) + -4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($6)) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($9)) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($11>>>0)<($13>>>0);
 if ($14) {
  $$6 = -1;
  return ($$6|0);
 }
 $15 = ($11|0)==($13|0);
 if (!($15)) {
  $$6 = 1;
  return ($$6|0);
 }
 $16 = ((($0)) + 240|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ((($1)) + 240|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($17|0)==($19|0);
 do {
  if ($20) {
   $28 = $17;
   label = 12;
  } else {
   $21 = ($17|0)==(0|0);
   $22 = ($19|0)!=(0|0);
   if ($21) {
    if ($22) {
     $$6 = -1;
    } else {
     label = 13;
     break;
    }
    return ($$6|0);
   }
   if (!($22)) {
    $$6 = 1;
    return ($$6|0);
   }
   $23 = HEAP32[$17>>2]|0;
   $24 = ((($23)) + 172|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = (FUNCTION_TABLE_iii[$25 & 8191]($17,$19)|0);
   $27 = ($26|0)==(0);
   if ($27) {
    $$pre = HEAP32[$16>>2]|0;
    $28 = $$pre;
    label = 12;
    break;
   } else {
    $$6 = $26;
    return ($$6|0);
   }
  }
 } while(0);
 if ((label|0) == 12) {
  $29 = ($28|0)==(0|0);
  if ($29) {
   label = 13;
  }
 }
 if ((label|0) == 13) {
  $30 = HEAP32[$18>>2]|0;
  $31 = ($30|0)==(0|0);
  if ($31) {
   $32 = (__ZNK3osg7Texture21compareTextureObjectsERKS0_($0,$1)|0);
   $33 = ($32|0)==(0);
   if (!($33)) {
    $$6 = $32;
    return ($$6|0);
   }
  }
 }
 $34 = (__ZNK3osg7Texture14compareTextureERKS0_($0,$1)|0);
 $35 = ($34|0)==(0);
 if (!($35)) {
  $$6 = $34;
  return ($$6|0);
 }
 $36 = ((($0)) + 244|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = ((($1)) + 244|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = ($37|0)<($39|0);
 if ($40) {
  $$6 = -1;
  return ($$6|0);
 }
 $41 = ($39|0)<($37|0);
 if ($41) {
  $$6 = 1;
  return ($$6|0);
 }
 $42 = ((($0)) + 248|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = ((($1)) + 248|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = ($43|0)<($45|0);
 if ($46) {
  $$6 = -1;
  return ($$6|0);
 }
 $47 = ($45|0)<($43|0);
 if ($47) {
  $$6 = 1;
  return ($$6|0);
 } else {
  $48 = ((($0)) + 252|0);
  $49 = HEAP32[$48>>2]|0;
  $50 = ((($1)) + 252|0);
  $51 = HEAP32[$50>>2]|0;
  $52 = ($49>>>0)<($51>>>0);
  $53 = ($51>>>0)<($49>>>0);
  $$43 = $53&1;
  $$$43 = $52 ? -1 : $$43;
  return ($$$43|0);
 }
 return (0)|0;
}
function __ZNK3osg16TextureRectangle5applyERNS_5StateE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$ = 0, $$0 = 0, $$1 = 0, $$181 = 0, $$pre = 0, $$pre$i$i = 0, $$pre$i$i54 = 0, $$pre$i$i61 = 0, $$pre$i$i69 = 0, $$pre$pre = 0, $$pre$pre$i$i = 0, $$pre$pre$i$i50 = 0, $$pre$pre$i$i57 = 0, $$pre$pre$i$i65 = 0, $$pre82 = 0, $$pre82$pre = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0;
 var $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0;
 var $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0;
 var $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0;
 var $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0;
 var $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0;
 var $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0;
 var $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0;
 var $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0;
 var $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0;
 var $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0;
 var $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0;
 var $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0;
 var $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0;
 var $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0;
 var $392 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $or$cond$i = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i51 = 0, $scevgep$i$i$i$i$i58 = 0, $scevgep$i$i$i$i$i66 = 0, $scevgep5$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i52 = 0, $scevgep5$i$i$i$i$i59 = 0, $scevgep5$i$i$i$i$i67 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $2 = sp + 28|0;
 $3 = sp + 24|0;
 $4 = sp + 20|0;
 $5 = sp + 16|0;
 $6 = sp + 12|0;
 $7 = sp + 8|0;
 $8 = sp + 4|0;
 $9 = sp;
 $10 = ((($1)) + 784|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11)) + 36|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = ($13<<24>>24)==(0);
 if ($14) {
  $15 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
  if (!($15)) {
   STACKTOP = sp;return;
  }
  $16 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
  $17 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($16,156321,101)|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = ((($18)) + -12|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = (($17) + ($20)|0);
  __ZNKSt3__28ios_base6getlocEv($5,$21);
  __THREW__ = 0;
  $22 = (invoke_iii(3255,($5|0),(215188|0))|0);
  $23 = __THREW__; __THREW__ = 0;
  $24 = $23&1;
  if (!($24)) {
   $25 = HEAP32[$22>>2]|0;
   $26 = ((($25)) + 28|0);
   $27 = HEAP32[$26>>2]|0;
   __THREW__ = 0;
   $28 = (invoke_iii($27|0,($22|0),10)|0);
   $29 = __THREW__; __THREW__ = 0;
   $30 = $29&1;
   if (!($30)) {
    __ZNSt3__26localeD2Ev($5);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($17,$28)|0);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($17)|0);
    STACKTOP = sp;return;
   }
  }
  $31 = ___cxa_find_matching_catch_2()|0;
  $32 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3263,($5|0));
  $33 = __THREW__; __THREW__ = 0;
  $34 = $33&1;
  if ($34) {
   $35 = ___cxa_find_matching_catch_3(0|0)|0;
   $36 = tempRet0;
   ___clang_call_terminate($35);
   // unreachable;
  } else {
   ___resumeException($31|0);
   // unreachable;
  }
 }
 $37 = ((($1)) + 124|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = ((($0)) + 224|0);
 $40 = ((($0)) + 228|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = HEAP32[$39>>2]|0;
 $43 = (($41) - ($42))|0;
 $44 = $43 >> 2;
 $45 = ($44>>>0)>($38>>>0);
 L15: do {
  if (!($45)) {
   $46 = (($38) + 1)|0;
   $47 = ($46>>>0)>($44>>>0);
   $48 = $42;
   $49 = $41;
   if ($47) {
    $50 = (($46) - ($44))|0;
    __ZNSt3__26vectorIN3osg7ref_ptrINS1_7Texture13TextureObjectEEENS_9allocatorIS5_EEE8__appendEj($39,$50);
    break;
   }
   $51 = ($46>>>0)<($44>>>0);
   if ($51) {
    $52 = (($48) + ($46<<2)|0);
    $53 = ($49|0)==($52|0);
    if (!($53)) {
     $55 = $49;
     while(1) {
      $54 = ((($55)) + -4|0);
      HEAP32[$40>>2] = $54;
      $56 = HEAP32[$54>>2]|0;
      $57 = ($56|0)==(0|0);
      if (!($57)) {
       $58 = ((($56)) + 8|0);
       $59 = HEAP32[$58>>2]|0;HEAP32[$58>>2] = (($59-1)|0);
       $60 = ($59|0)==(1);
       if ($60) {
        __THREW__ = 0;
        invoke_viii(3262,($56|0),1,1);
        $61 = __THREW__; __THREW__ = 0;
        $62 = $61&1;
        if ($62) {
         break;
        }
       }
      }
      HEAP32[$54>>2] = 0;
      $63 = HEAP32[$40>>2]|0;
      $64 = ($63|0)==($52|0);
      if ($64) {
       break L15;
      } else {
       $55 = $63;
      }
     }
     $65 = ___cxa_find_matching_catch_2()|0;
     $66 = tempRet0;
     ___cxa_call_unexpected(($65|0));
     // unreachable;
    }
   }
  }
 } while(0);
 $67 = HEAP32[$39>>2]|0;
 $68 = (($67) + ($38<<2)|0);
 $69 = HEAP32[$68>>2]|0;
 $70 = ($69|0)==(0|0);
 do {
  if (!($70)) {
   $71 = ((($0)) + 240|0);
   $72 = HEAP32[$71>>2]|0;
   $73 = ($72|0)==(0|0);
   if ($73) {
    $$181 = $69;
   } else {
    $74 = ((($0)) + 256|0);
    $75 = ((($0)) + 260|0);
    $76 = HEAP32[$75>>2]|0;
    $77 = HEAP32[$74>>2]|0;
    $78 = (($76) - ($77))|0;
    $79 = $78 >> 2;
    $80 = ($79>>>0)>($38>>>0);
    $81 = $77;
    if ($80) {
     $95 = $81;$98 = $72;
    } else {
     $82 = (($38) + 1)|0;
     HEAP32[$6>>2] = 0;
     $83 = ($82>>>0)>($79>>>0);
     $84 = $76;
     if ($83) {
      $85 = (($82) - ($79))|0;
      __ZNSt3__26vectorIjNS_9allocatorIjEEE8__appendEjRKj($74,$85,$6);
      $$pre$pre$i$i = HEAP32[$74>>2]|0;
      $$pre$pre = HEAP32[$71>>2]|0;
      $$pre = $$pre$pre;$$pre$i$i = $$pre$pre$i$i;
     } else {
      $86 = ($82>>>0)<($79>>>0);
      if ($86) {
       $87 = (($81) + ($82<<2)|0);
       $88 = ($84|0)==($87|0);
       if ($88) {
        $$pre = $72;$$pre$i$i = $81;
       } else {
        $scevgep$i$i$i$i$i = ((($84)) + -4|0);
        $89 = $scevgep$i$i$i$i$i;
        $90 = $87;
        $91 = (($89) - ($90))|0;
        $92 = $91 >>> 2;
        $93 = $92 ^ -1;
        $scevgep5$i$i$i$i$i = (($84) + ($93<<2)|0);
        HEAP32[$75>>2] = $scevgep5$i$i$i$i$i;
        $$pre = $72;$$pre$i$i = $81;
       }
      } else {
       $$pre = $72;$$pre$i$i = $81;
      }
     }
     $95 = $$pre$i$i;$98 = $$pre;
    }
    $94 = (($95) + ($38<<2)|0);
    $96 = HEAP32[$94>>2]|0;
    $97 = ((($98)) + 32|0);
    $99 = HEAP32[$97>>2]|0;
    $100 = ($96|0)==($99|0);
    if ($100) {
     $$1 = $69;
    } else {
     $101 = HEAP32[$0>>2]|0;
     $102 = ((($101)) + 212|0);
     $103 = HEAP32[$102>>2]|0;
     FUNCTION_TABLE_vi[$103 & 8191]($0);
     $104 = HEAP32[$71>>2]|0;
     __ZNK3osg7Texture32computeRequiredTextureDimensionsERNS_5StateERKNS_5ImageERiS6_S6_($0,$1,$104,$7,$8,$9);
     $105 = HEAP32[$9>>2]|0;
     $106 = ((($0)) + 172|0);
     $107 = HEAP32[$106>>2]|0;
     $108 = HEAP32[$7>>2]|0;
     $109 = HEAP32[$8>>2]|0;
     $110 = ((($0)) + 160|0);
     $111 = HEAP32[$110>>2]|0;
     $112 = ((($69)) + 64|0);
     $113 = HEAP8[$112>>0]|0;
     $114 = ($113<<24>>24)==(0);
     if ($114) {
      label = 37;
     } else {
      $115 = ((($69)) + 28|0);
      $116 = HEAP32[$115>>2]|0;
      $117 = ($116|0)==(0);
      if ($117) {
       label = 37;
      } else {
       $118 = ((($69)) + 16|0);
       $119 = HEAP32[$118>>2]|0;
       $120 = ($119|0)==(34037);
       if ($120) {
        $121 = ((($69)) + 20|0);
        $122 = HEAP32[$121>>2]|0;
        $123 = ($122|0)==($105|0);
        if ($123) {
         $124 = ((($69)) + 24|0);
         $125 = HEAP32[$124>>2]|0;
         $126 = ($125|0)==($107|0);
         $127 = ($116|0)==($108|0);
         $or$cond$i = $127 & $126;
         if ($or$cond$i) {
          $128 = ((($69)) + 32|0);
          $129 = HEAP32[$128>>2]|0;
          $130 = ($129|0)==($109|0);
          if ($130) {
           $131 = ((($69)) + 36|0);
           $132 = HEAP32[$131>>2]|0;
           $133 = ($132|0)==(1);
           if ($133) {
            $134 = ((($69)) + 40|0);
            $135 = HEAP32[$134>>2]|0;
            $136 = ($135|0)==($111|0);
            if ($136) {
             $$0 = $69;
            } else {
             label = 37;
            }
           } else {
            label = 37;
           }
          } else {
           label = 37;
          }
         } else {
          label = 37;
         }
        } else {
         label = 37;
        }
       } else {
        label = 37;
       }
      }
     }
     if ((label|0) == 37) {
      $137 = HEAP32[$40>>2]|0;
      $138 = HEAP32[$39>>2]|0;
      $139 = (($137) - ($138))|0;
      $140 = $139 >> 2;
      $141 = ($140>>>0)>($38>>>0);
      L54: do {
       if (!($141)) {
        $142 = (($38) + 1)|0;
        $143 = ($142>>>0)>($140>>>0);
        $144 = $138;
        $145 = $137;
        if ($143) {
         $146 = (($142) - ($140))|0;
         __ZNSt3__26vectorIN3osg7ref_ptrINS1_7Texture13TextureObjectEEENS_9allocatorIS5_EEE8__appendEj($39,$146);
         break;
        }
        $147 = ($142>>>0)<($140>>>0);
        if ($147) {
         $148 = (($144) + ($142<<2)|0);
         $149 = ($145|0)==($148|0);
         if (!($149)) {
          $151 = $145;
          while(1) {
           $150 = ((($151)) + -4|0);
           HEAP32[$40>>2] = $150;
           $152 = HEAP32[$150>>2]|0;
           $153 = ($152|0)==(0|0);
           if (!($153)) {
            $154 = ((($152)) + 8|0);
            $155 = HEAP32[$154>>2]|0;HEAP32[$154>>2] = (($155-1)|0);
            $156 = ($155|0)==(1);
            if ($156) {
             __THREW__ = 0;
             invoke_viii(3262,($152|0),1,1);
             $157 = __THREW__; __THREW__ = 0;
             $158 = $157&1;
             if ($158) {
              break;
             }
            }
           }
           HEAP32[$150>>2] = 0;
           $159 = HEAP32[$40>>2]|0;
           $160 = ($159|0)==($148|0);
           if ($160) {
            break L54;
           } else {
            $151 = $159;
           }
          }
          $161 = ___cxa_find_matching_catch_2()|0;
          $162 = tempRet0;
          ___cxa_call_unexpected(($161|0));
          // unreachable;
         }
        }
       }
      } while(0);
      $163 = HEAP32[$39>>2]|0;
      $164 = (($163) + ($38<<2)|0);
      $165 = HEAP32[$164>>2]|0;
      __ZN3osg7Texture13TextureObject7releaseEv($165);
      $166 = HEAP32[$40>>2]|0;
      $167 = HEAP32[$39>>2]|0;
      $168 = (($166) - ($167))|0;
      $169 = $168 >> 2;
      $170 = ($169>>>0)>($38>>>0);
      L68: do {
       if (!($170)) {
        $171 = (($38) + 1)|0;
        $172 = ($171>>>0)>($169>>>0);
        $173 = $167;
        $174 = $166;
        if ($172) {
         $175 = (($171) - ($169))|0;
         __ZNSt3__26vectorIN3osg7ref_ptrINS1_7Texture13TextureObjectEEENS_9allocatorIS5_EEE8__appendEj($39,$175);
         break;
        }
        $176 = ($171>>>0)<($169>>>0);
        if ($176) {
         $177 = (($173) + ($171<<2)|0);
         $178 = ($174|0)==($177|0);
         if (!($178)) {
          $180 = $174;
          L74: while(1) {
           $179 = ((($180)) + -4|0);
           HEAP32[$40>>2] = $179;
           $181 = HEAP32[$179>>2]|0;
           $182 = ($181|0)==(0|0);
           do {
            if (!($182)) {
             $183 = ((($181)) + 8|0);
             $184 = HEAP32[$183>>2]|0;HEAP32[$183>>2] = (($184-1)|0);
             $185 = ($184|0)==(1);
             if (!($185)) {
              break;
             }
             __THREW__ = 0;
             invoke_viii(3262,($181|0),1,1);
             $186 = __THREW__; __THREW__ = 0;
             $187 = $186&1;
             if ($187) {
              break L74;
             }
            }
           } while(0);
           HEAP32[$179>>2] = 0;
           $188 = HEAP32[$40>>2]|0;
           $189 = ($188|0)==($177|0);
           if ($189) {
            break L68;
           } else {
            $180 = $188;
           }
          }
          $190 = ___cxa_find_matching_catch_2()|0;
          $191 = tempRet0;
          ___cxa_call_unexpected(($190|0));
          // unreachable;
         }
        }
       }
      } while(0);
      $192 = HEAP32[$39>>2]|0;
      $193 = (($192) + ($38<<2)|0);
      $194 = HEAP32[$193>>2]|0;
      $195 = ($194|0)==(0|0);
      if ($195) {
       $$0 = 0;
      } else {
       HEAP32[$193>>2] = 0;
       $196 = ((($194)) + 8|0);
       $197 = HEAP32[$196>>2]|0;HEAP32[$196>>2] = (($197-1)|0);
       $198 = ($197|0)==(1);
       if ($198) {
        __ZNK3osg10Referenced24signalObserversAndDeleteEbb($194,1,1);
        $$0 = 0;
       } else {
        $$0 = 0;
       }
      }
     }
     $$1 = $$0;
    }
    $199 = ($$1|0)==(0|0);
    if ($199) {
     break;
    } else {
     $$181 = $$1;
    }
   }
   __ZN3osg7Texture13TextureObject4bindEv($$181);
   $200 = HEAP32[$37>>2]|0;
   $201 = ((($0)) + 56|0);
   $202 = ((($0)) + 60|0);
   $203 = HEAP32[$202>>2]|0;
   $204 = HEAP32[$201>>2]|0;
   $205 = (($203) - ($204))|0;
   $206 = $205 >> 2;
   $207 = ($206>>>0)>($200>>>0);
   $208 = $204;
   if ($207) {
    $222 = $208;
   } else {
    $209 = (($200) + 1)|0;
    HEAP32[$4>>2] = 0;
    $210 = ($209>>>0)>($206>>>0);
    $211 = $203;
    if ($210) {
     $212 = (($209) - ($206))|0;
     __ZNSt3__26vectorIjNS_9allocatorIjEEE8__appendEjRKj($201,$212,$4);
     $$pre$pre$i$i50 = HEAP32[$201>>2]|0;
     $$pre$i$i54 = $$pre$pre$i$i50;
    } else {
     $213 = ($209>>>0)<($206>>>0);
     if ($213) {
      $214 = (($208) + ($209<<2)|0);
      $215 = ($211|0)==($214|0);
      if ($215) {
       $$pre$i$i54 = $208;
      } else {
       $scevgep$i$i$i$i$i51 = ((($211)) + -4|0);
       $216 = $scevgep$i$i$i$i$i51;
       $217 = $214;
       $218 = (($216) - ($217))|0;
       $219 = $218 >>> 2;
       $220 = $219 ^ -1;
       $scevgep5$i$i$i$i$i52 = (($211) + ($220<<2)|0);
       HEAP32[$202>>2] = $scevgep5$i$i$i$i$i52;
       $$pre$i$i54 = $208;
      }
     } else {
      $$pre$i$i54 = $208;
     }
    }
    $222 = $$pre$i$i54;
   }
   $221 = (($222) + ($200<<2)|0);
   $223 = HEAP32[$221>>2]|0;
   $224 = ($223|0)==(0);
   if (!($224)) {
    __ZNK3osg7Texture18applyTexParametersEjRNS_5StateE($0,34037,$1);
   }
   $225 = ((($0)) + 252|0);
   $226 = HEAP32[$225>>2]|0;
   $227 = ($226|0)==(0|0);
   if (!($227)) {
    $228 = HEAP32[$226>>2]|0;
    $229 = ((($228)) + 16|0);
    $230 = HEAP32[$229>>2]|0;
    FUNCTION_TABLE_viii[$230 & 8191]($226,$0,$1);
    STACKTOP = sp;return;
   }
   $231 = HEAP32[$71>>2]|0;
   $232 = ($231|0)==(0|0);
   if ($232) {
    STACKTOP = sp;return;
   }
   $233 = ((($0)) + 256|0);
   $234 = ((($0)) + 260|0);
   $235 = HEAP32[$234>>2]|0;
   $236 = HEAP32[$233>>2]|0;
   $237 = (($235) - ($236))|0;
   $238 = $237 >> 2;
   $239 = ($238>>>0)>($38>>>0);
   $240 = $236;
   if ($239) {
    $254 = $240;$257 = $231;
   } else {
    $241 = (($38) + 1)|0;
    HEAP32[$3>>2] = 0;
    $242 = ($241>>>0)>($238>>>0);
    $243 = $235;
    if ($242) {
     $244 = (($241) - ($238))|0;
     __ZNSt3__26vectorIjNS_9allocatorIjEEE8__appendEjRKj($233,$244,$3);
     $$pre$pre$i$i57 = HEAP32[$233>>2]|0;
     $$pre82$pre = HEAP32[$71>>2]|0;
     $$pre$i$i61 = $$pre$pre$i$i57;$$pre82 = $$pre82$pre;
    } else {
     $245 = ($241>>>0)<($238>>>0);
     if ($245) {
      $246 = (($240) + ($241<<2)|0);
      $247 = ($243|0)==($246|0);
      if ($247) {
       $$pre$i$i61 = $240;$$pre82 = $231;
      } else {
       $scevgep$i$i$i$i$i58 = ((($243)) + -4|0);
       $248 = $scevgep$i$i$i$i$i58;
       $249 = $246;
       $250 = (($248) - ($249))|0;
       $251 = $250 >>> 2;
       $252 = $251 ^ -1;
       $scevgep5$i$i$i$i$i59 = (($243) + ($252<<2)|0);
       HEAP32[$234>>2] = $scevgep5$i$i$i$i$i59;
       $$pre$i$i61 = $240;$$pre82 = $231;
      }
     } else {
      $$pre$i$i61 = $240;$$pre82 = $231;
     }
    }
    $254 = $$pre$i$i61;$257 = $$pre82;
   }
   $253 = (($254) + ($38<<2)|0);
   $255 = HEAP32[$253>>2]|0;
   $256 = ((($257)) + 32|0);
   $258 = HEAP32[$256>>2]|0;
   $259 = ($255|0)==($258|0);
   if ($259) {
    STACKTOP = sp;return;
   }
   $260 = ((($0)) + 244|0);
   $261 = ((($0)) + 248|0);
   $262 = ((($0)) + 172|0);
   __ZNK3osg16TextureRectangle21applyTexImage_subloadEjPNS_5ImageERNS_5StateERiS5_S5_($0,34037,$257,$1,$260,$261,$262);
   $263 = HEAP32[$71>>2]|0;
   $264 = ((($263)) + 32|0);
   $265 = HEAP32[$264>>2]|0;
   $266 = HEAP32[$234>>2]|0;
   $267 = HEAP32[$233>>2]|0;
   $268 = (($266) - ($267))|0;
   $269 = $268 >> 2;
   $270 = ($269>>>0)>($38>>>0);
   $271 = $267;
   if ($270) {
    $285 = $271;
   } else {
    $272 = (($38) + 1)|0;
    HEAP32[$2>>2] = 0;
    $273 = ($272>>>0)>($269>>>0);
    $274 = $266;
    if ($273) {
     $275 = (($272) - ($269))|0;
     __ZNSt3__26vectorIjNS_9allocatorIjEEE8__appendEjRKj($233,$275,$2);
     $$pre$pre$i$i65 = HEAP32[$233>>2]|0;
     $$pre$i$i69 = $$pre$pre$i$i65;
    } else {
     $276 = ($272>>>0)<($269>>>0);
     if ($276) {
      $277 = (($271) + ($272<<2)|0);
      $278 = ($274|0)==($277|0);
      if ($278) {
       $$pre$i$i69 = $271;
      } else {
       $scevgep$i$i$i$i$i66 = ((($274)) + -4|0);
       $279 = $scevgep$i$i$i$i$i66;
       $280 = $277;
       $281 = (($279) - ($280))|0;
       $282 = $281 >>> 2;
       $283 = $282 ^ -1;
       $scevgep5$i$i$i$i$i67 = (($274) + ($283<<2)|0);
       HEAP32[$234>>2] = $scevgep5$i$i$i$i$i67;
       $$pre$i$i69 = $271;
      }
     } else {
      $$pre$i$i69 = $271;
     }
    }
    $285 = $$pre$i$i69;
   }
   $284 = (($285) + ($38<<2)|0);
   HEAP32[$284>>2] = $265;
   STACKTOP = sp;return;
  }
 } while(0);
 $286 = ((($0)) + 252|0);
 $287 = HEAP32[$286>>2]|0;
 $288 = ($287|0)==(0|0);
 if (!($288)) {
  $289 = (__ZNK3osg7Texture30generateAndAssignTextureObjectEjj($0,$38,34037)|0);
  __ZN3osg7Texture13TextureObject4bindEv($289);
  __ZNK3osg7Texture18applyTexParametersEjRNS_5StateE($0,34037,$1);
  $290 = HEAP32[$286>>2]|0;
  $291 = HEAP32[$290>>2]|0;
  $292 = ((($291)) + 12|0);
  $293 = HEAP32[$292>>2]|0;
  FUNCTION_TABLE_viii[$293 & 8191]($290,$0,$1);
  $294 = ((($0)) + 172|0);
  $295 = HEAP32[$294>>2]|0;
  $296 = ((($0)) + 244|0);
  $297 = HEAP32[$296>>2]|0;
  $298 = ((($0)) + 248|0);
  $299 = HEAP32[$298>>2]|0;
  __ZN3osg7Texture13TextureObject12setAllocatedEijiiii($289,1,$295,$297,$299,1,0);
  STACKTOP = sp;return;
 }
 $300 = ((($0)) + 240|0);
 $301 = HEAP32[$300>>2]|0;
 $302 = ($301|0)==(0|0);
 if (!($302)) {
  $303 = ((($301)) + 112|0);
  $304 = HEAP32[$303>>2]|0;
  $305 = ($304|0)==(0|0);
  if (!($305)) {
   $306 = ((($301)) + 8|0);
   $307 = HEAP32[$306>>2]|0;HEAP32[$306>>2] = (($307+1)|0);
   $308 = HEAP32[$0>>2]|0;
   $309 = ((($308)) + 212|0);
   $310 = HEAP32[$309>>2]|0;
   __THREW__ = 0;
   invoke_vi($310|0,($0|0));
   $311 = __THREW__; __THREW__ = 0;
   $312 = $311&1;
   do {
    if (!($312)) {
     $313 = ((($301)) + 72|0);
     $314 = HEAP32[$313>>2]|0;
     $315 = ((($0)) + 244|0);
     HEAP32[$315>>2] = $314;
     $316 = ((($301)) + 76|0);
     $317 = HEAP32[$316>>2]|0;
     $318 = ((($0)) + 248|0);
     HEAP32[$318>>2] = $317;
     $319 = ((($0)) + 172|0);
     $320 = HEAP32[$319>>2]|0;
     __THREW__ = 0;
     $321 = (invoke_iiiiiiiiii(3969,($0|0),($38|0),34037,1,($320|0),($314|0),($317|0),1,0)|0);
     $322 = __THREW__; __THREW__ = 0;
     $323 = $322&1;
     if (!($323)) {
      __THREW__ = 0;
      invoke_vi(3970,($321|0));
      $324 = __THREW__; __THREW__ = 0;
      $325 = $324&1;
      if (!($325)) {
       __THREW__ = 0;
       invoke_viii(3971,($0|0),34037,($1|0));
       $326 = __THREW__; __THREW__ = 0;
       $327 = $326&1;
       if (!($327)) {
        $328 = ((($321)) + 64|0);
        $329 = HEAP8[$328>>0]|0;
        $330 = ($329<<24>>24)==(0);
        $331 = HEAP32[$300>>2]|0;
        if ($330) {
         __THREW__ = 0;
         invoke_viiiiii(3987,($0|0),34037,($331|0),($1|0),($315|0),($318|0));
         $334 = __THREW__; __THREW__ = 0;
         $335 = $334&1;
         if ($335) {
          break;
         }
         HEAP8[$328>>0] = 1;
        } else {
         __THREW__ = 0;
         invoke_viiiiiii(3986,($0|0),34037,($331|0),($1|0),($315|0),($318|0),($319|0));
         $332 = __THREW__; __THREW__ = 0;
         $333 = $332&1;
         if ($333) {
          break;
         }
        }
        $336 = ((($0)) + 121|0);
        $337 = HEAP8[$336>>0]|0;
        $338 = ($337<<24>>24)==(0);
        if (!($338)) {
         $339 = ((($1)) + 680|0);
         $340 = HEAP32[$339>>2]|0;
         $341 = ($340|0)==(0);
         if ($341) {
          __THREW__ = 0;
          $342 = (invoke_ii(3975,($0|0))|0);
          $343 = __THREW__; __THREW__ = 0;
          $344 = $343&1;
          if ($344) {
           break;
          }
          if ($342) {
           $345 = HEAP32[$300>>2]|0;
           $346 = ((($345)) + 24|0);
           $347 = HEAP32[$346>>2]|0;
           $348 = ($347|0)!=(1);
           $349 = ($345|0)==(0|0);
           $or$cond = $349 | $348;
           if (!($or$cond)) {
            HEAP32[$300>>2] = 0;
            $350 = ((($345)) + 8|0);
            $351 = HEAP32[$350>>2]|0;HEAP32[$350>>2] = (($351-1)|0);
            $352 = ($351|0)==(1);
            if ($352) {
             __THREW__ = 0;
             invoke_viii(3262,($345|0),1,1);
             $353 = __THREW__; __THREW__ = 0;
             $354 = $353&1;
             if ($354) {
              break;
             }
            }
           }
          }
         }
        }
        $355 = HEAP32[$306>>2]|0;HEAP32[$306>>2] = (($355-1)|0);
        $356 = ($355|0)==(1);
        if (!($356)) {
         STACKTOP = sp;return;
        }
        __ZNK3osg10Referenced24signalObserversAndDeleteEbb($301,1,1);
        STACKTOP = sp;return;
       }
      }
     }
    }
   } while(0);
   $357 = ___cxa_find_matching_catch_2()|0;
   $358 = tempRet0;
   $359 = HEAP32[$306>>2]|0;HEAP32[$306>>2] = (($359-1)|0);
   $360 = ($359|0)==(1);
   if (!($360)) {
    ___resumeException($357|0);
    // unreachable;
   }
   __THREW__ = 0;
   invoke_viii(3262,($301|0),1,1);
   $361 = __THREW__; __THREW__ = 0;
   $362 = $361&1;
   if ($362) {
    $391 = ___cxa_find_matching_catch_3(0|0)|0;
    $392 = tempRet0;
    ___clang_call_terminate($391);
    // unreachable;
   } else {
    ___resumeException($357|0);
    // unreachable;
   }
  }
 }
 $363 = ((($0)) + 244|0);
 $364 = HEAP32[$363>>2]|0;
 $365 = ($364|0)==(0);
 if (!($365)) {
  $366 = ((($0)) + 248|0);
  $367 = HEAP32[$366>>2]|0;
  $368 = ($367|0)==(0);
  if (!($368)) {
   $369 = ((($0)) + 172|0);
   $370 = HEAP32[$369>>2]|0;
   $371 = ($370|0)==(0);
   if (!($371)) {
    $372 = (__ZNK3osg7Texture30generateAndAssignTextureObjectEjjijiiii($0,$38,34037,0,$370,$364,$367,1,0)|0);
    __ZN3osg7Texture13TextureObject4bindEv($372);
    __ZNK3osg7Texture18applyTexParametersEjRNS_5StateE($0,34037,$1);
    $373 = HEAP32[$369>>2]|0;
    $374 = HEAP32[$363>>2]|0;
    $375 = HEAP32[$366>>2]|0;
    $376 = ((($0)) + 160|0);
    $377 = HEAP32[$376>>2]|0;
    $378 = ((($0)) + 176|0);
    $379 = HEAP32[$378>>2]|0;
    $380 = ($379|0)==(0);
    $$ = $380 ? $373 : $379;
    $381 = ((($0)) + 180|0);
    $382 = HEAP32[$381>>2]|0;
    $383 = ($382|0)==(0);
    $384 = $383 ? 5121 : $382;
    _glTexImage2D(34037,0,($373|0),($374|0),($375|0),($377|0),($$|0),($384|0),(0|0));
    $385 = ((($0)) + 236|0);
    $386 = HEAP32[$385>>2]|0;
    $387 = ($386|0)==(0|0);
    if ($387) {
     STACKTOP = sp;return;
    }
    $388 = HEAP32[$386>>2]|0;
    $389 = ((($388)) + 176|0);
    $390 = HEAP32[$389>>2]|0;
    FUNCTION_TABLE_vii[$390 & 8191]($386,1028);
    STACKTOP = sp;return;
   }
  }
 }
 _glBindTexture(34037,0);
 STACKTOP = sp;return;
}
function __ZNK3osg16TextureRectangle16getTextureTargetEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 34037;
}
function __ZNK3osg16TextureRectangle15getTextureWidthEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 244|0);
 $2 = HEAP32[$1>>2]|0;
 return ($2|0);
}
function __ZNK3osg16TextureRectangle16getTextureHeightEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 248|0);
 $2 = HEAP32[$1>>2]|0;
 return ($2|0);
}
function __ZNK3osg16TextureRectangle15getTextureDepthEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 1;
}
function __ZN3osg16TextureRectangle8setImageEjPNS_5ImageE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg16TextureRectangle8setImageEPNS_5ImageE($0,$2);
 return;
}
function __ZN3osg16TextureRectangle8getImageEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 240|0);
 $3 = HEAP32[$2>>2]|0;
 return ($3|0);
}
function __ZNK3osg16TextureRectangle8getImageEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 240|0);
 $3 = HEAP32[$2>>2]|0;
 return ($3|0);
}
function __ZNK3osg16TextureRectangle12getNumImagesEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 1;
}
function __ZNK3osg16TextureRectangle21computeInternalFormatEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 240|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  __ZNK3osg7Texture25computeInternalFormatTypeEv($0);
  return;
 } else {
  __ZNK3osg7Texture30computeInternalFormatWithImageERKNS_5ImageE($0,$2);
  return;
 }
}
function __ZNK3osg16TextureRectangle14allocateMipmapERNS_5StateE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $4 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
 $5 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($4,156202,118)|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($6)) + -12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($5) + ($8)|0);
 __ZNKSt3__28ios_base6getlocEv($2,$9);
 __THREW__ = 0;
 $10 = (invoke_iii(3255,($2|0),(215188|0))|0);
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if (!($12)) {
  $13 = HEAP32[$10>>2]|0;
  $14 = ((($13)) + 28|0);
  $15 = HEAP32[$14>>2]|0;
  __THREW__ = 0;
  $16 = (invoke_iii($15|0,($10|0),10)|0);
  $17 = __THREW__; __THREW__ = 0;
  $18 = $17&1;
  if (!($18)) {
   __ZNSt3__26localeD2Ev($2);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($5,$16)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($5)|0);
   STACKTOP = sp;return;
  }
 }
 $19 = ___cxa_find_matching_catch_2()|0;
 $20 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($2|0));
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if ($22) {
  $23 = ___cxa_find_matching_catch_3(0|0)|0;
  $24 = tempRet0;
  ___clang_call_terminate($23);
  // unreachable;
 } else {
  ___resumeException($19|0);
  // unreachable;
 }
}
function __ZN3osg16TextureRectangle8setImageEPNS_5ImageE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$cast$i$i = 0, $$cast$i2$i = 0, $$pr = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 240|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==($1|0);
 if ($4) {
  return;
 }
 $5 = ($3|0)==(0|0);
 if (!($5)) {
  $6 = ((($3)) + 48|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($7) + -1)|0;
  HEAP32[$6>>2] = $8;
  $9 = HEAP32[$3>>2]|0;
  $10 = ((($9)) + 204|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (FUNCTION_TABLE_ii[$11 & 8191]($3)|0);
  if ($12) {
   __ZN3osg14StateAttribute17setUpdateCallbackEPNS_22StateAttributeCallbackE($0,0);
   $13 = ((($0)) + 24|0);
   HEAP32[$13>>2] = 1;
  }
 }
 __ZN3osg7Texture18dirtyTextureObjectEv($0);
 $14 = HEAP32[$2>>2]|0;
 $15 = ($14|0)==($1|0);
 if ($15) {
  $23 = $1;
 } else {
  HEAP32[$2>>2] = $1;
  $16 = ($1|0)==(0|0);
  if (!($16)) {
   $17 = ((($1)) + 8|0);
   $18 = HEAP32[$17>>2]|0;HEAP32[$17>>2] = (($18+1)|0);
  }
  $19 = ($14|0)==(0|0);
  if (!($19)) {
   $20 = ((($14)) + 8|0);
   $21 = HEAP32[$20>>2]|0;HEAP32[$20>>2] = (($21-1)|0);
   $22 = ($21|0)==(1);
   if ($22) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($14,1,1);
   }
  }
  $$pr = HEAP32[$2>>2]|0;
  $23 = $$pr;
 }
 $24 = ($23|0)==(0|0);
 if ($24) {
  return;
 }
 $25 = ((($23)) + 48|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (($26) + 1)|0;
 HEAP32[$25>>2] = $27;
 $28 = HEAP32[$23>>2]|0;
 $29 = ((($28)) + 204|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (FUNCTION_TABLE_ii[$30 & 8191]($23)|0);
 if (!($31)) {
  return;
 }
 $32 = (__Znwj(44)|0);
 dest=$32; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $33 = ((($32)) + 12|0);
 __THREW__ = 0;
 invoke_vi(3282,($33|0));
 $34 = __THREW__; __THREW__ = 0;
 $35 = $34&1;
 if ($35) {
  $57 = ___cxa_find_matching_catch_2()|0;
  $58 = tempRet0;
  __ZdlPv($32);
  ___resumeException($57|0);
  // unreachable;
 }
 HEAP32[$33>>2] = (63412);
 $36 = ((($32)) + 24|0);
 ;HEAP32[$36>>2]=0|0;HEAP32[$36+4>>2]=0|0;HEAP32[$36+8>>2]=0|0;
 $37 = ((($32)) + 36|0);
 HEAP32[$37>>2] = 2;
 $38 = ((($32)) + 40|0);
 HEAP32[$38>>2] = 0;
 $39 = ((($32)) + 4|0);
 $40 = HEAP32[(62180)>>2]|0;
 HEAP32[$39>>2] = $40;
 $41 = HEAP32[(62184)>>2]|0;
 $$cast$i$i = $40;
 $42 = ((($$cast$i$i)) + -12|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = (($39) + ($43)|0);
 HEAP32[$44>>2] = $41;
 $45 = ((($32)) + 8|0);
 HEAP32[$45>>2] = 0;
 $46 = HEAP32[(62160)>>2]|0;
 HEAP32[$32>>2] = $46;
 $47 = HEAP32[(62164)>>2]|0;
 $$cast$i2$i = $46;
 $48 = ((($$cast$i2$i)) + -12|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = (($32) + ($49)|0);
 HEAP32[$50>>2] = $47;
 $51 = HEAP32[(62168)>>2]|0;
 $52 = HEAP32[$32>>2]|0;
 $53 = ((($52)) + -16|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = (($32) + ($54)|0);
 HEAP32[$55>>2] = $51;
 HEAP32[$32>>2] = (61612);
 HEAP32[$39>>2] = (61768);
 HEAP32[$33>>2] = (62016);
 __ZN3osg14StateAttribute17setUpdateCallbackEPNS_22StateAttributeCallbackE($0,$32);
 $56 = ((($0)) + 24|0);
 HEAP32[$56>>2] = 0;
 return;
}
function __ZNK3osg16TextureRectangle21applyTexImage_subloadEjPNS_5ImageERNS_5StateERiS5_S5_($0,$1,$2,$3,$4,$5,$6) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 var $$0 = 0, $$pre$i$i = 0, $$pre$pre$i$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $scevgep$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $7 = sp;
 $8 = ($2|0)==(0|0);
 if ($8) {
  STACKTOP = sp;return;
 }
 $9 = ((($2)) + 112|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  STACKTOP = sp;return;
 }
 $12 = ((($2)) + 72|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = HEAP32[$4>>2]|0;
 $15 = ($13|0)==($14|0);
 if ($15) {
  $16 = ((($2)) + 76|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = HEAP32[$5>>2]|0;
  $19 = ($17|0)==($18|0);
  if ($19) {
   $20 = ((($2)) + 88|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = HEAP32[$6>>2]|0;
   $23 = ($21|0)==($22|0);
   if ($23) {
    $24 = ((($3)) + 124|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = ((($3)) + 784|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = ((($2)) + 32|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = ((($0)) + 256|0);
    $31 = ((($0)) + 260|0);
    $32 = HEAP32[$31>>2]|0;
    $33 = HEAP32[$30>>2]|0;
    $34 = (($32) - ($33))|0;
    $35 = $34 >> 2;
    $36 = ($35>>>0)>($25>>>0);
    $37 = $33;
    if ($36) {
     $51 = $37;
    } else {
     $38 = (($25) + 1)|0;
     HEAP32[$7>>2] = 0;
     $39 = ($38>>>0)>($35>>>0);
     $40 = $32;
     if ($39) {
      $41 = (($38) - ($35))|0;
      __ZNSt3__26vectorIjNS_9allocatorIjEEE8__appendEjRKj($30,$41,$7);
      $$pre$pre$i$i = HEAP32[$30>>2]|0;
      $$pre$i$i = $$pre$pre$i$i;
     } else {
      $42 = ($38>>>0)<($35>>>0);
      if ($42) {
       $43 = (($37) + ($38<<2)|0);
       $44 = ($40|0)==($43|0);
       if ($44) {
        $$pre$i$i = $37;
       } else {
        $scevgep$i$i$i$i$i = ((($40)) + -4|0);
        $45 = $scevgep$i$i$i$i$i;
        $46 = $43;
        $47 = (($45) - ($46))|0;
        $48 = $47 >>> 2;
        $49 = $48 ^ -1;
        $scevgep5$i$i$i$i$i = (($40) + ($49<<2)|0);
        HEAP32[$31>>2] = $scevgep5$i$i$i$i$i;
        $$pre$i$i = $37;
       }
      } else {
       $$pre$i$i = $37;
      }
     }
     $51 = $$pre$i$i;
    }
    $50 = (($51) + ($25<<2)|0);
    HEAP32[$50>>2] = $29;
    $52 = HEAP32[$0>>2]|0;
    $53 = ((($52)) + 212|0);
    $54 = HEAP32[$53>>2]|0;
    FUNCTION_TABLE_vi[$54 & 8191]($0);
    $55 = ((($2)) + 100|0);
    $56 = HEAP32[$55>>2]|0;
    _glPixelStorei(3317,($56|0));
    $57 = HEAP32[$9>>2]|0;
    $58 = ((($2)) + 40|0);
    $59 = HEAP32[$58>>2]|0;
    $60 = ($59|0)==(0|0);
    if ($60) {
     $$0 = $57;$109 = 0;
    } else {
     $61 = (__ZNK3osg12BufferObject25getOrCreateGLBufferObjectEj($59,$25)|0);
     $62 = ($61|0)==(0|0);
     if ($62) {
      $$0 = $57;$109 = 0;
     } else {
      $63 = ((($3)) + 696|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = ($64|0)==($61|0);
      if (!($65)) {
       $66 = ((($61)) + 36|0);
       $67 = HEAP8[$66>>0]|0;
       $68 = ($67<<24>>24)==(0);
       if ($68) {
        $69 = ((($61)) + 72|0);
        $70 = HEAP32[$69>>2]|0;
        $71 = ((($70)) + 724|0);
        $72 = HEAP32[$71>>2]|0;
        $73 = ((($61)) + 20|0);
        $74 = HEAP32[$73>>2]|0;
        $75 = ((($61)) + 16|0);
        $76 = HEAP32[$75>>2]|0;
        FUNCTION_TABLE_vii[$72 & 8191]($74,$76);
        $77 = ((($61)) + 56|0);
        $78 = HEAP32[$77>>2]|0;
        $79 = ($78|0)==(0|0);
        if (!($79)) {
         __ZN3osg17GLBufferObjectSet10moveToBackEPNS_14GLBufferObjectE($78,$61);
        }
       } else {
        __ZN3osg14GLBufferObject13compileBufferEv($61);
       }
       HEAP32[$63>>2] = $61;
      }
      $80 = ((($2)) + 36|0);
      $81 = HEAP32[$80>>2]|0;
      $82 = ((($61)) + 40|0);
      $83 = HEAP32[$82>>2]|0;
      $84 = (((($83) + (($81*20)|0)|0)) + 12|0);
      $85 = HEAP32[$84>>2]|0;
      $$0 = $85;$109 = 1;
     }
    }
    $86 = ((($0)) + 172|0);
    $87 = HEAP32[$86>>2]|0;
    $88 = (__ZN3osg7Texture26isCompressedInternalFormatEi($87)|0);
    if ($88) {
     $89 = ((($27)) + 1080|0);
     $90 = HEAP32[$89>>2]|0;
     $91 = ($90|0)==(0|0);
     if ($91) {
      label = 26;
     } else {
      $92 = HEAP32[$12>>2]|0;
      $93 = HEAP32[$16>>2]|0;
      $94 = ((($2)) + 92|0);
      $95 = HEAP32[$94>>2]|0;
      $96 = ((($2)) + 96|0);
      $97 = HEAP32[$96>>2]|0;
      FUNCTION_TABLE_viiiiiiiii[$90 & 8191]($1,0,0,0,$92,$93,$95,$97,$$0);
     }
    } else {
     label = 26;
    }
    if ((label|0) == 26) {
     $98 = HEAP32[$12>>2]|0;
     $99 = HEAP32[$16>>2]|0;
     $100 = ((($2)) + 92|0);
     $101 = HEAP32[$100>>2]|0;
     $102 = ((($2)) + 96|0);
     $103 = HEAP32[$102>>2]|0;
     _glTexSubImage2D(($1|0),0,0,0,($98|0),($99|0),($101|0),($103|0),($$0|0));
    }
    if (!($109)) {
     STACKTOP = sp;return;
    }
    $104 = ((($3)) + 696|0);
    $105 = HEAP32[$104>>2]|0;
    $106 = ($105|0)==(0|0);
    if ($106) {
     STACKTOP = sp;return;
    }
    $107 = ((($3)) + 772|0);
    $108 = HEAP32[$107>>2]|0;
    FUNCTION_TABLE_vii[$108 & 8191](35052,0);
    HEAP32[$104>>2] = 0;
    STACKTOP = sp;return;
   }
  }
 }
 __ZNK3osg16TextureRectangle18applyTexImage_loadEjPNS_5ImageERNS_5StateERiS5_($0,$1,$2,$3,$4,$5);
 STACKTOP = sp;return;
}
function __ZNK3osg16TextureRectangle18applyTexImage_loadEjPNS_5ImageERNS_5StateERiS5_($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$0 = 0, $$pre$i$i = 0, $$pre$pre$i$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $scevgep$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $6 = sp;
 $7 = ($2|0)==(0|0);
 if ($7) {
  STACKTOP = sp;return;
 }
 $8 = ((($2)) + 112|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if ($10) {
  STACKTOP = sp;return;
 }
 $11 = ((($3)) + 124|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ((($3)) + 784|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ((($2)) + 32|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ((($0)) + 256|0);
 $18 = ((($0)) + 260|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$17>>2]|0;
 $21 = (($19) - ($20))|0;
 $22 = $21 >> 2;
 $23 = ($22>>>0)>($12>>>0);
 $24 = $20;
 if ($23) {
  $38 = $24;
 } else {
  $25 = (($12) + 1)|0;
  HEAP32[$6>>2] = 0;
  $26 = ($25>>>0)>($22>>>0);
  $27 = $19;
  if ($26) {
   $28 = (($25) - ($22))|0;
   __ZNSt3__26vectorIjNS_9allocatorIjEEE8__appendEjRKj($17,$28,$6);
   $$pre$pre$i$i = HEAP32[$17>>2]|0;
   $$pre$i$i = $$pre$pre$i$i;
  } else {
   $29 = ($25>>>0)<($22>>>0);
   if ($29) {
    $30 = (($24) + ($25<<2)|0);
    $31 = ($27|0)==($30|0);
    if ($31) {
     $$pre$i$i = $24;
    } else {
     $scevgep$i$i$i$i$i = ((($27)) + -4|0);
     $32 = $scevgep$i$i$i$i$i;
     $33 = $30;
     $34 = (($32) - ($33))|0;
     $35 = $34 >>> 2;
     $36 = $35 ^ -1;
     $scevgep5$i$i$i$i$i = (($27) + ($36<<2)|0);
     HEAP32[$18>>2] = $scevgep5$i$i$i$i$i;
     $$pre$i$i = $24;
    }
   } else {
    $$pre$i$i = $24;
   }
  }
  $38 = $$pre$i$i;
 }
 $37 = (($38) + ($12<<2)|0);
 HEAP32[$37>>2] = $16;
 $39 = HEAP32[$0>>2]|0;
 $40 = ((($39)) + 212|0);
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_vi[$41 & 8191]($0);
 $42 = ((($2)) + 100|0);
 $43 = HEAP32[$42>>2]|0;
 _glPixelStorei(3317,($43|0));
 $44 = ((($14)) + 1064|0);
 $45 = HEAP8[$44>>0]|0;
 $46 = ($45<<24>>24)==(0);
 if ($46) {
  $116 = 0;
 } else {
  $47 = ((($0)) + 122|0);
  $48 = HEAP8[$47>>0]|0;
  $49 = ($48<<24>>24)==(0);
  if ($49) {
   $116 = 0;
  } else {
   _glPixelStorei(34226,1);
   $116 = 1;
  }
 }
 $50 = HEAP32[$8>>2]|0;
 $51 = ((($2)) + 40|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = ($52|0)==(0|0);
 if ($53) {
  $$0 = $50;$117 = 0;
 } else {
  $54 = (__ZNK3osg12BufferObject25getOrCreateGLBufferObjectEj($52,$12)|0);
  $55 = ($54|0)==(0|0);
  if ($55) {
   $$0 = $50;$117 = 0;
  } else {
   $56 = ((($3)) + 696|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = ($57|0)==($54|0);
   if (!($58)) {
    $59 = ((($54)) + 36|0);
    $60 = HEAP8[$59>>0]|0;
    $61 = ($60<<24>>24)==(0);
    if ($61) {
     $62 = ((($54)) + 72|0);
     $63 = HEAP32[$62>>2]|0;
     $64 = ((($63)) + 724|0);
     $65 = HEAP32[$64>>2]|0;
     $66 = ((($54)) + 20|0);
     $67 = HEAP32[$66>>2]|0;
     $68 = ((($54)) + 16|0);
     $69 = HEAP32[$68>>2]|0;
     FUNCTION_TABLE_vii[$65 & 8191]($67,$69);
     $70 = ((($54)) + 56|0);
     $71 = HEAP32[$70>>2]|0;
     $72 = ($71|0)==(0|0);
     if (!($72)) {
      __ZN3osg17GLBufferObjectSet10moveToBackEPNS_14GLBufferObjectE($71,$54);
     }
    } else {
     __ZN3osg14GLBufferObject13compileBufferEv($54);
    }
    HEAP32[$56>>2] = $54;
   }
   $73 = ((($2)) + 36|0);
   $74 = HEAP32[$73>>2]|0;
   $75 = ((($54)) + 40|0);
   $76 = HEAP32[$75>>2]|0;
   $77 = (((($76) + (($74*20)|0)|0)) + 12|0);
   $78 = HEAP32[$77>>2]|0;
   $$0 = $78;$117 = 1;
  }
 }
 $79 = ((($0)) + 172|0);
 $80 = HEAP32[$79>>2]|0;
 $81 = (__ZN3osg7Texture26isCompressedInternalFormatEi($80)|0);
 if ($81) {
  $82 = ((($14)) + 1076|0);
  $83 = HEAP32[$82>>2]|0;
  $84 = ($83|0)==(0|0);
  if ($84) {
   label = 25;
  } else {
   $85 = HEAP32[$79>>2]|0;
   $86 = ((($2)) + 72|0);
   $87 = HEAP32[$86>>2]|0;
   $88 = ((($2)) + 76|0);
   $89 = HEAP32[$88>>2]|0;
   $90 = ((($2)) + 92|0);
   $91 = HEAP32[$90>>2]|0;
   $92 = ((($2)) + 96|0);
   $93 = HEAP32[$92>>2]|0;
   $94 = HEAP32[$42>>2]|0;
   $95 = (__ZN3osg5Image22computeRowWidthInBytesEijji($87,$91,$93,$94)|0);
   $96 = HEAP32[$88>>2]|0;
   $97 = Math_imul($96, $95)|0;
   FUNCTION_TABLE_viiiiiiii[$83 & 8191]($1,0,$85,$87,$89,0,$97,$$0);
  }
 } else {
  label = 25;
 }
 if ((label|0) == 25) {
  $98 = HEAP32[$79>>2]|0;
  $99 = ((($2)) + 72|0);
  $100 = HEAP32[$99>>2]|0;
  $101 = ((($2)) + 76|0);
  $102 = HEAP32[$101>>2]|0;
  $103 = ((($2)) + 92|0);
  $104 = HEAP32[$103>>2]|0;
  $105 = ((($2)) + 96|0);
  $106 = HEAP32[$105>>2]|0;
  _glTexImage2D(($1|0),0,($98|0),($100|0),($102|0),0,($104|0),($106|0),($$0|0));
 }
 if ($117) {
  $107 = ((($3)) + 696|0);
  $108 = HEAP32[$107>>2]|0;
  $109 = ($108|0)==(0|0);
  if (!($109)) {
   $110 = ((($3)) + 772|0);
   $111 = HEAP32[$110>>2]|0;
   FUNCTION_TABLE_vii[$111 & 8191](35052,0);
   HEAP32[$107>>2] = 0;
  }
 }
 $112 = ((($2)) + 72|0);
 $113 = HEAP32[$112>>2]|0;
 HEAP32[$4>>2] = $113;
 $114 = ((($2)) + 76|0);
 $115 = HEAP32[$114>>2]|0;
 HEAP32[$5>>2] = $115;
 if (!($116)) {
  STACKTOP = sp;return;
 }
 _glPixelStorei(34226,0);
 STACKTOP = sp;return;
}
function __ZN3osg16TextureRectangleC2ERKS0_RKNS_6CopyOpE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$09 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $9 = 0, $eh$lpad$body$index3Z2D = 0, $eh$lpad$body$indexZ2D = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i$i$i$i = 0, $scevgep5$i$i$i$i = 0, $scevgep5$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg7TextureC2ERKS0_RKNS_6CopyOpE($0,$1,$2);
 HEAP32[$0>>2] = (68308);
 $3 = ((($0)) + 240|0);
 HEAP32[$3>>2] = 0;
 $4 = ((($0)) + 244|0);
 $5 = ((($1)) + 244|0);
 $6 = HEAP32[$5>>2]|0;
 HEAP32[$4>>2] = $6;
 $7 = ((($0)) + 248|0);
 $8 = ((($1)) + 248|0);
 $9 = HEAP32[$8>>2]|0;
 HEAP32[$7>>2] = $9;
 $10 = ((($0)) + 252|0);
 $11 = ((($1)) + 252|0);
 $12 = HEAP32[$11>>2]|0;
 HEAP32[$10>>2] = $12;
 $13 = ($12|0)==(0|0);
 if (!($13)) {
  $14 = ((($12)) + 8|0);
  $15 = HEAP32[$14>>2]|0;HEAP32[$14>>2] = (($15+1)|0);
 }
 $16 = ((($0)) + 256|0);
 __THREW__ = 0;
 $17 = (invoke_i(3285)|0);
 $18 = __THREW__; __THREW__ = 0;
 $19 = $18&1;
 L4: do {
  if ($19) {
   label = 17;
  } else {
   $20 = HEAP32[$17>>2]|0;
   __THREW__ = 0;
   $21 = (invoke_ii(3286,($20|0))|0);
   $22 = __THREW__; __THREW__ = 0;
   $23 = $22&1;
   if ($23) {
    label = 17;
   } else {
    HEAP32[$16>>2] = 0;
    $24 = ((($0)) + 260|0);
    HEAP32[$24>>2] = 0;
    $25 = ((($0)) + 264|0);
    HEAP32[$25>>2] = 0;
    $26 = ($21|0)==(0);
    do {
     if (!($26)) {
      $27 = ($21>>>0)>(1073741823);
      if ($27) {
       __THREW__ = 0;
       invoke_vi(3307,($16|0));
       $28 = __THREW__; __THREW__ = 0;
      } else {
       $29 = $21 << 2;
       __THREW__ = 0;
       $30 = (invoke_ii(3276,($29|0))|0);
       $31 = __THREW__; __THREW__ = 0;
       $32 = $31&1;
       if (!($32)) {
        HEAP32[$16>>2] = $30;
        $33 = (($30) + ($21<<2)|0);
        $34 = ((($0)) + 264|0);
        HEAP32[$34>>2] = $33;
        _memset(($30|0),0,($29|0))|0;
        HEAP32[$24>>2] = $33;
        break;
       }
      }
      $35 = ___cxa_find_matching_catch_2()|0;
      $36 = tempRet0;
      $37 = HEAP32[$16>>2]|0;
      $38 = ($37|0)==(0|0);
      if ($38) {
       $eh$lpad$body$index3Z2D = $36;$eh$lpad$body$indexZ2D = $35;
       label = 18;
       break L4;
      }
      $39 = HEAP32[$24>>2]|0;
      $40 = ($39|0)==($37|0);
      if (!($40)) {
       $scevgep$i$i$i$i$i = ((($39)) + -4|0);
       $41 = $scevgep$i$i$i$i$i;
       $42 = $37;
       $43 = (($41) - ($42))|0;
       $44 = $43 >>> 2;
       $45 = $44 ^ -1;
       $scevgep5$i$i$i$i$i = (($39) + ($45<<2)|0);
       HEAP32[$24>>2] = $scevgep5$i$i$i$i$i;
      }
      __ZdlPv($37);
      $eh$lpad$body$index3Z2D = $36;$eh$lpad$body$indexZ2D = $35;
      label = 18;
      break L4;
     }
    } while(0);
    $46 = HEAP32[$2>>2]|0;
    $47 = ((($46)) + 36|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = ((($1)) + 240|0);
    $50 = HEAP32[$49>>2]|0;
    __THREW__ = 0;
    $51 = (invoke_iii($48|0,($2|0),($50|0))|0);
    $52 = __THREW__; __THREW__ = 0;
    $53 = $52&1;
    if (!($53)) {
     __THREW__ = 0;
     invoke_vii(3984,($0|0),($51|0));
     $54 = __THREW__; __THREW__ = 0;
     $55 = $54&1;
     if (!($55)) {
      return;
     }
    }
    $58 = ___cxa_find_matching_catch_2()|0;
    $59 = tempRet0;
    $60 = HEAP32[$16>>2]|0;
    $61 = ($60|0)==(0|0);
    if ($61) {
     $$0 = $59;$$09 = $58;
    } else {
     $62 = HEAP32[$24>>2]|0;
     $63 = ($62|0)==($60|0);
     if (!($63)) {
      $scevgep$i$i$i$i = ((($62)) + -4|0);
      $64 = $scevgep$i$i$i$i;
      $65 = $60;
      $66 = (($64) - ($65))|0;
      $67 = $66 >>> 2;
      $68 = $67 ^ -1;
      $scevgep5$i$i$i$i = (($62) + ($68<<2)|0);
      HEAP32[$24>>2] = $scevgep5$i$i$i$i;
     }
     __ZdlPv($60);
     $$0 = $59;$$09 = $58;
    }
   }
  }
 } while(0);
 if ((label|0) == 17) {
  $56 = ___cxa_find_matching_catch_2()|0;
  $57 = tempRet0;
  $eh$lpad$body$index3Z2D = $57;$eh$lpad$body$indexZ2D = $56;
  label = 18;
 }
 if ((label|0) == 18) {
  $$0 = $eh$lpad$body$index3Z2D;$$09 = $eh$lpad$body$indexZ2D;
 }
 $69 = HEAP32[$10>>2]|0;
 $70 = ($69|0)==(0|0);
 if (!($70)) {
  $71 = ((($69)) + 8|0);
  $72 = HEAP32[$71>>2]|0;HEAP32[$71>>2] = (($72-1)|0);
  $73 = ($72|0)==(1);
  if ($73) {
   __THREW__ = 0;
   invoke_viii(3262,($69|0),1,1);
   $74 = __THREW__; __THREW__ = 0;
   $75 = $74&1;
   if ($75) {
    $85 = ___cxa_find_matching_catch_3(0|0)|0;
    $86 = tempRet0;
    ___clang_call_terminate($85);
    // unreachable;
   }
  }
 }
 HEAP32[$10>>2] = 0;
 $76 = HEAP32[$3>>2]|0;
 $77 = ($76|0)==(0|0);
 if (!($77)) {
  $78 = ((($76)) + 8|0);
  $79 = HEAP32[$78>>2]|0;HEAP32[$78>>2] = (($79-1)|0);
  $80 = ($79|0)==(1);
  if ($80) {
   __THREW__ = 0;
   invoke_viii(3262,($76|0),1,1);
   $81 = __THREW__; __THREW__ = 0;
   $82 = $81&1;
   if ($82) {
    $85 = ___cxa_find_matching_catch_3(0|0)|0;
    $86 = tempRet0;
    ___clang_call_terminate($85);
    // unreachable;
   }
  }
 }
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vi(2335,($0|0));
 $83 = __THREW__; __THREW__ = 0;
 $84 = $83&1;
 if ($84) {
  $85 = ___cxa_find_matching_catch_3(0|0)|0;
  $86 = tempRet0;
  ___clang_call_terminate($85);
  // unreachable;
 } else {
  ___resumeException($$09|0);
  // unreachable;
 }
}
function __ZN3osg16TextureRectangleC2Ev($0) {
 $0 = $0|0;
 var $$0 = 0, $$02 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index3Z2D = 0, $eh$lpad$body$indexZ2D = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i$i$i$i = 0, $scevgep5$i$i$i$i = 0, $scevgep5$i$i$i$i$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 __ZN3osg7TextureC2Ev($0);
 HEAP32[$0>>2] = (68308);
 $1 = ((($0)) + 240|0);
 $2 = ((($0)) + 252|0);
 $3 = ((($0)) + 256|0);
 ;HEAP32[$1>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;HEAP32[$1+12>>2]=0|0;
 __THREW__ = 0;
 $4 = (invoke_i(3285)|0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 L1: do {
  if ($6) {
   label = 17;
  } else {
   $7 = HEAP32[$4>>2]|0;
   __THREW__ = 0;
   $8 = (invoke_ii(3286,($7|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if ($10) {
    label = 17;
   } else {
    HEAP32[$3>>2] = 0;
    $11 = ((($0)) + 260|0);
    HEAP32[$11>>2] = 0;
    $12 = ((($0)) + 264|0);
    HEAP32[$12>>2] = 0;
    $13 = ($8|0)==(0);
    do {
     if (!($13)) {
      $14 = ($8>>>0)>(1073741823);
      if ($14) {
       __THREW__ = 0;
       invoke_vi(3307,($3|0));
       $15 = __THREW__; __THREW__ = 0;
      } else {
       $16 = $8 << 2;
       __THREW__ = 0;
       $17 = (invoke_ii(3276,($16|0))|0);
       $18 = __THREW__; __THREW__ = 0;
       $19 = $18&1;
       if (!($19)) {
        HEAP32[$3>>2] = $17;
        $20 = (($17) + ($8<<2)|0);
        $21 = ((($0)) + 264|0);
        HEAP32[$21>>2] = $20;
        _memset(($17|0),0,($16|0))|0;
        HEAP32[$11>>2] = $20;
        break;
       }
      }
      $22 = ___cxa_find_matching_catch_2()|0;
      $23 = tempRet0;
      $24 = HEAP32[$3>>2]|0;
      $25 = ($24|0)==(0|0);
      if ($25) {
       $eh$lpad$body$index3Z2D = $23;$eh$lpad$body$indexZ2D = $22;
       label = 18;
       break L1;
      }
      $26 = HEAP32[$11>>2]|0;
      $27 = ($26|0)==($24|0);
      if (!($27)) {
       $scevgep$i$i$i$i$i = ((($26)) + -4|0);
       $28 = $scevgep$i$i$i$i$i;
       $29 = $24;
       $30 = (($28) - ($29))|0;
       $31 = $30 >>> 2;
       $32 = $31 ^ -1;
       $scevgep5$i$i$i$i$i = (($26) + ($32<<2)|0);
       HEAP32[$11>>2] = $scevgep5$i$i$i$i$i;
      }
      __ZdlPv($24);
      $eh$lpad$body$index3Z2D = $23;$eh$lpad$body$indexZ2D = $22;
      label = 18;
      break L1;
     }
    } while(0);
    __THREW__ = 0;
    invoke_viii(3334,($0|0),0,10496);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     __THREW__ = 0;
     invoke_viii(3334,($0|0),1,10496);
     $35 = __THREW__; __THREW__ = 0;
     $36 = $35&1;
     if (!($36)) {
      __THREW__ = 0;
      invoke_viii(3333,($0|0),0,9729);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if (!($38)) {
       __THREW__ = 0;
       invoke_viii(3333,($0|0),1,9729);
       $39 = __THREW__; __THREW__ = 0;
       $40 = $39&1;
       if (!($40)) {
        return;
       }
      }
     }
    }
    $43 = ___cxa_find_matching_catch_2()|0;
    $44 = tempRet0;
    $45 = HEAP32[$3>>2]|0;
    $46 = ($45|0)==(0|0);
    if ($46) {
     $$0 = $44;$$02 = $43;
    } else {
     $47 = HEAP32[$11>>2]|0;
     $48 = ($47|0)==($45|0);
     if (!($48)) {
      $scevgep$i$i$i$i = ((($47)) + -4|0);
      $49 = $scevgep$i$i$i$i;
      $50 = $45;
      $51 = (($49) - ($50))|0;
      $52 = $51 >>> 2;
      $53 = $52 ^ -1;
      $scevgep5$i$i$i$i = (($47) + ($53<<2)|0);
      HEAP32[$11>>2] = $scevgep5$i$i$i$i;
     }
     __ZdlPv($45);
     $$0 = $44;$$02 = $43;
    }
   }
  }
 } while(0);
 if ((label|0) == 17) {
  $41 = ___cxa_find_matching_catch_2()|0;
  $42 = tempRet0;
  $eh$lpad$body$index3Z2D = $42;$eh$lpad$body$indexZ2D = $41;
  label = 18;
 }
 if ((label|0) == 18) {
  $$0 = $eh$lpad$body$index3Z2D;$$02 = $eh$lpad$body$indexZ2D;
 }
 $54 = HEAP32[$2>>2]|0;
 $55 = ($54|0)==(0|0);
 if (!($55)) {
  $56 = ((($54)) + 8|0);
  $57 = HEAP32[$56>>2]|0;HEAP32[$56>>2] = (($57-1)|0);
  $58 = ($57|0)==(1);
  if ($58) {
   __THREW__ = 0;
   invoke_viii(3262,($54|0),1,1);
   $59 = __THREW__; __THREW__ = 0;
   $60 = $59&1;
   if ($60) {
    $70 = ___cxa_find_matching_catch_3(0|0)|0;
    $71 = tempRet0;
    ___clang_call_terminate($70);
    // unreachable;
   }
  }
 }
 HEAP32[$2>>2] = 0;
 $61 = HEAP32[$1>>2]|0;
 $62 = ($61|0)==(0|0);
 if (!($62)) {
  $63 = ((($61)) + 8|0);
  $64 = HEAP32[$63>>2]|0;HEAP32[$63>>2] = (($64-1)|0);
  $65 = ($64|0)==(1);
  if ($65) {
   __THREW__ = 0;
   invoke_viii(3262,($61|0),1,1);
   $66 = __THREW__; __THREW__ = 0;
   $67 = $66&1;
   if ($67) {
    $70 = ___cxa_find_matching_catch_3(0|0)|0;
    $71 = tempRet0;
    ___clang_call_terminate($70);
    // unreachable;
   }
  }
 }
 HEAP32[$1>>2] = 0;
 __THREW__ = 0;
 invoke_vi(2335,($0|0));
 $68 = __THREW__; __THREW__ = 0;
 $69 = $68&1;
 if ($69) {
  $70 = ___cxa_find_matching_catch_3(0|0)|0;
  $71 = tempRet0;
  ___clang_call_terminate($70);
  // unreachable;
 } else {
  ___resumeException($$02|0);
  // unreachable;
 }
}
function __ZN3osg16TextureRectangle14copyTexImage2DERNS_5StateEiiii($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $6 = ((($1)) + 124|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($0)) + 172|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0);
 if ($10) {
  HEAP32[$8>>2] = 6408;
 }
 $11 = ((($0)) + 224|0);
 $12 = ((($0)) + 228|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = HEAP32[$11>>2]|0;
 $15 = (($13) - ($14))|0;
 $16 = $15 >> 2;
 $17 = ($16>>>0)>($7>>>0);
 L4: do {
  if (!($17)) {
   $18 = (($7) + 1)|0;
   $19 = ($18>>>0)>($16>>>0);
   $20 = $14;
   $21 = $13;
   if ($19) {
    $22 = (($18) - ($16))|0;
    __ZNSt3__26vectorIN3osg7ref_ptrINS1_7Texture13TextureObjectEEENS_9allocatorIS5_EEE8__appendEj($11,$22);
    break;
   }
   $23 = ($18>>>0)<($16>>>0);
   if ($23) {
    $24 = (($20) + ($18<<2)|0);
    $25 = ($21|0)==($24|0);
    if (!($25)) {
     $27 = $21;
     while(1) {
      $26 = ((($27)) + -4|0);
      HEAP32[$12>>2] = $26;
      $28 = HEAP32[$26>>2]|0;
      $29 = ($28|0)==(0|0);
      if (!($29)) {
       $30 = ((($28)) + 8|0);
       $31 = HEAP32[$30>>2]|0;HEAP32[$30>>2] = (($31-1)|0);
       $32 = ($31|0)==(1);
       if ($32) {
        __THREW__ = 0;
        invoke_viii(3262,($28|0),1,1);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break;
        }
       }
      }
      HEAP32[$26>>2] = 0;
      $35 = HEAP32[$12>>2]|0;
      $36 = ($35|0)==($24|0);
      if ($36) {
       break L4;
      } else {
       $27 = $35;
      }
     }
     $37 = ___cxa_find_matching_catch_2()|0;
     $38 = tempRet0;
     ___cxa_call_unexpected(($37|0));
     // unreachable;
    }
   }
  }
 } while(0);
 $39 = HEAP32[$11>>2]|0;
 $40 = (($39) + ($7<<2)|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = ($41|0)==(0|0);
 if (!($42)) {
  $43 = ((($0)) + 244|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = ($44|0)==($4|0);
  if ($45) {
   $46 = ((($0)) + 248|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = ($47|0)==($5|0);
   if ($48) {
    __ZN3osg16TextureRectangle17copyTexSubImage2DERNS_5StateEiiiiii($0,$1,0,0,$2,$3,$4,$5);
    return;
   }
  }
  __ZN3osg7Texture18dirtyTextureObjectEv($0);
 }
 $49 = ((($0)) + 240|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = ($50|0)==(0|0);
 if (!($51)) {
  HEAP32[$49>>2] = 0;
  $52 = ((($50)) + 8|0);
  $53 = HEAP32[$52>>2]|0;HEAP32[$52>>2] = (($53-1)|0);
  $54 = ($53|0)==(1);
  if ($54) {
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($50,1,1);
  }
 }
 $55 = (__ZNK3osg7Texture30generateAndAssignTextureObjectEjj($0,$7,34037)|0);
 __ZN3osg7Texture13TextureObject4bindEv($55);
 __ZNK3osg7Texture18applyTexParametersEjRNS_5StateE($0,34037,$1);
 $56 = HEAP32[$8>>2]|0;
 _glCopyTexImage2D(34037,0,($56|0),($2|0),($3|0),($4|0),($5|0),0);
 $57 = ((($0)) + 244|0);
 HEAP32[$57>>2] = $4;
 $58 = ((($0)) + 248|0);
 HEAP32[$58>>2] = $5;
 $59 = HEAP32[$8>>2]|0;
 __ZN3osg7Texture13TextureObject12setAllocatedEijiiii($55,1,$59,$4,$5,1,0);
 $60 = ((($1)) + 688|0);
 $61 = HEAP32[$60>>2]|0;
 __ZN3osg5State27haveAppliedTextureAttributeEjPKNS_14StateAttributeE($1,$61,$0);
 return;
}
function __ZN3osg16TextureRectangle17copyTexSubImage2DERNS_5StateEiiiiii($0,$1,$2,$3,$4,$5,$6,$7) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $8 = ((($1)) + 124|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($0)) + 172|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0);
 if ($12) {
  HEAP32[$10>>2] = 6408;
 }
 $13 = ((($0)) + 224|0);
 $14 = ((($0)) + 228|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP32[$13>>2]|0;
 $17 = (($15) - ($16))|0;
 $18 = $17 >> 2;
 $19 = ($18>>>0)>($9>>>0);
 L4: do {
  if (!($19)) {
   $20 = (($9) + 1)|0;
   $21 = ($20>>>0)>($18>>>0);
   $22 = $16;
   $23 = $15;
   if ($21) {
    $24 = (($20) - ($18))|0;
    __ZNSt3__26vectorIN3osg7ref_ptrINS1_7Texture13TextureObjectEEENS_9allocatorIS5_EEE8__appendEj($13,$24);
    break;
   }
   $25 = ($20>>>0)<($18>>>0);
   if ($25) {
    $26 = (($22) + ($20<<2)|0);
    $27 = ($23|0)==($26|0);
    if (!($27)) {
     $29 = $23;
     while(1) {
      $28 = ((($29)) + -4|0);
      HEAP32[$14>>2] = $28;
      $30 = HEAP32[$28>>2]|0;
      $31 = ($30|0)==(0|0);
      if (!($31)) {
       $32 = ((($30)) + 8|0);
       $33 = HEAP32[$32>>2]|0;HEAP32[$32>>2] = (($33-1)|0);
       $34 = ($33|0)==(1);
       if ($34) {
        __THREW__ = 0;
        invoke_viii(3262,($30|0),1,1);
        $35 = __THREW__; __THREW__ = 0;
        $36 = $35&1;
        if ($36) {
         break;
        }
       }
      }
      HEAP32[$28>>2] = 0;
      $37 = HEAP32[$14>>2]|0;
      $38 = ($37|0)==($26|0);
      if ($38) {
       break L4;
      } else {
       $29 = $37;
      }
     }
     $39 = ___cxa_find_matching_catch_2()|0;
     $40 = tempRet0;
     ___cxa_call_unexpected(($39|0));
     // unreachable;
    }
   }
  }
 } while(0);
 $41 = HEAP32[$13>>2]|0;
 $42 = (($41) + ($9<<2)|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = ($43|0)==(0|0);
 if ($44) {
  __ZN3osg16TextureRectangle14copyTexImage2DERNS_5StateEiiii($0,$1,$4,$5,$6,$7);
  return;
 } else {
  __ZN3osg7Texture13TextureObject4bindEv($43);
  __ZNK3osg7Texture18applyTexParametersEjRNS_5StateE($0,34037,$1);
  _glCopyTexSubImage2D(34037,0,($2|0),($3|0),($4|0),($5|0),($6|0),($7|0));
  $45 = ((($1)) + 688|0);
  $46 = HEAP32[$45>>2]|0;
  __ZN3osg5State27haveAppliedTextureAttributeEjPKNS_14StateAttributeE($1,$46,$0);
  return;
 }
}
function __ZN3osg5Timer8instanceEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $0 = sp;
 $1 = HEAP8[206096]|0;
 $2 = ($1<<24>>24)==(0);
 if (!($2)) {
  STACKTOP = sp;return (206104|0);
 }
 $3 = (___cxa_guard_acquire(206096)|0);
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return (206104|0);
 }
 HEAPF64[(206112)>>3] = 9.9999999999999995E-7;
 __THREW__ = 0;
 (invoke_iii(3988,1,($0|0))|0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $24 = ___cxa_find_matching_catch_2()|0;
  $25 = tempRet0;
  ___resumeException($24|0);
  // unreachable;
 }
 $7 = HEAP32[$0>>2]|0;
 $8 = ($7|0)<(0);
 $9 = $8 << 31 >> 31;
 $10 = (___muldi3(($7|0),($9|0),1000000,0)|0);
 $11 = tempRet0;
 $12 = ((($0)) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)<(0);
 $15 = $14 << 31 >> 31;
 $16 = (___udivdi3(($13|0),($15|0),1000,0)|0);
 $17 = tempRet0;
 $18 = (_i64Add(($16|0),($17|0),($10|0),($11|0))|0);
 $19 = tempRet0;
 $20 = 206104;
 $21 = $20;
 HEAP32[$21>>2] = $18;
 $22 = (($20) + 4)|0;
 $23 = $22;
 HEAP32[$23>>2] = $19;
 STACKTOP = sp;return (206104|0);
}
function __ZN3osg5TimerC2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $2 = ((($0)) + 8|0);
 HEAPF64[$2>>3] = 9.9999999999999995E-7;
 (_clock_gettime(1,($1|0))|0);
 $3 = HEAP32[$1>>2]|0;
 $4 = ($3|0)<(0);
 $5 = $4 << 31 >> 31;
 $6 = (___muldi3(($3|0),($5|0),1000000,0)|0);
 $7 = tempRet0;
 $8 = ((($1)) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)<(0);
 $11 = $10 << 31 >> 31;
 $12 = (___udivdi3(($9|0),($11|0),1000,0)|0);
 $13 = tempRet0;
 $14 = (_i64Add(($12|0),($13|0),($6|0),($7|0))|0);
 $15 = tempRet0;
 $16 = $0;
 $17 = $16;
 HEAP32[$17>>2] = $14;
 $18 = (($16) + 4)|0;
 $19 = $18;
 HEAP32[$19>>2] = $15;
 STACKTOP = sp;return;
}
function __ZNK3osg5Timer4tickEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 (_clock_gettime(1,($1|0))|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)<(0);
 $4 = $3 << 31 >> 31;
 $5 = (___muldi3(($2|0),($4|0),1000000,0)|0);
 $6 = tempRet0;
 $7 = ((($1)) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)<(0);
 $10 = $9 << 31 >> 31;
 $11 = (___udivdi3(($8|0),($10|0),1000,0)|0);
 $12 = tempRet0;
 $13 = (_i64Add(($11|0),($12|0),($5|0),($6|0))|0);
 $14 = tempRet0;
 tempRet0 = ($14);
 STACKTOP = sp;return ($13|0);
}
function __ZN3osg9TransformD2Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg5GroupD2Ev($0);
 return;
}
function __ZN3osg9TransformD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1924,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK3osg9Transform9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(140)|0);
 __THREW__ = 0;
 invoke_vi(3763,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $5 = ___cxa_find_matching_catch_2()|0;
  $6 = tempRet0;
  __ZdlPv($1);
  ___resumeException($5|0);
  // unreachable;
 } else {
  HEAP32[$1>>2] = (68536);
  $4 = ((($1)) + 136|0);
  HEAP32[$4>>2] = 0;
  return ($1|0);
 }
 return (0)|0;
}
function __ZNK3osg9Transform5cloneERKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(140)|0);
 __THREW__ = 0;
 invoke_viii(3764,($2|0),($0|0),($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $8 = ___cxa_find_matching_catch_2()|0;
  $9 = tempRet0;
  __ZdlPv($2);
  ___resumeException($8|0);
  // unreachable;
 } else {
  HEAP32[$2>>2] = (68536);
  $5 = ((($2)) + 136|0);
  $6 = ((($0)) + 136|0);
  $7 = HEAP32[$6>>2]|0;
  HEAP32[$5>>2] = $7;
  return ($2|0);
 }
 return (0)|0;
}
function __ZNK3osg9Transform12isSameKindAsEPKNS_6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,26928,0)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK3osg9Transform11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175113|0);
}
function __ZNK3osg9Transform9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (156465|0);
}
function __ZN3osg9Transform6acceptERNS_11NodeVisitorE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$byval_copy = 0, $$pre$i$i = 0, $$sink$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i = 0, $scevgep5$i$i$i$i = 0, $scevgep5$i$i$i$sink$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy = sp + 8|0;
 $2 = sp + 4|0;
 $3 = sp;
 $4 = ((($1)) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($1)) + 24|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($0)) + 116|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $9 | $7;
 $11 = $10 & $5;
 $12 = ($11|0)==(0);
 if ($12) {
  STACKTOP = sp;return;
 }
 HEAP32[$2>>2] = $0;
 $13 = ((($1)) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(1);
 $16 = ((($1)) + 28|0);
 $17 = $0;
 do {
  if ($15) {
   $25 = HEAP32[$16>>2]|0;
   HEAP32[$3>>2] = $25;
   ;HEAP32[$$byval_copy>>2]=HEAP32[$3>>2]|0;
   (__ZNSt3__26vectorIPN3osg4NodeENS_9allocatorIS3_EEE6insertENS_11__wrap_iterIPKS3_EERS8_($16,$$byval_copy,$2)|0);
  } else {
   $18 = ((($1)) + 32|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ((($1)) + 36|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = ($19|0)==($21|0);
   if ($22) {
    __ZNSt3__26vectorIPN3osg4NodeENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_($16,$2);
    break;
   } else {
    HEAP32[$19>>2] = $17;
    $23 = HEAP32[$18>>2]|0;
    $24 = ((($23)) + 4|0);
    HEAP32[$18>>2] = $24;
    break;
   }
  }
 } while(0);
 $26 = HEAP32[$1>>2]|0;
 $27 = ((($26)) + 148|0);
 $28 = HEAP32[$27>>2]|0;
 FUNCTION_TABLE_vii[$28 & 8191]($1,$0);
 $29 = HEAP32[$13>>2]|0;
 $30 = ($29|0)==(1);
 do {
  if ($30) {
   $34 = ((($1)) + 28|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ((($35)) + 4|0);
   $37 = ((($1)) + 32|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = $36;
   $40 = (($38) - ($39))|0;
   $41 = $40 >> 2;
   $42 = ($41|0)==(0);
   $43 = $38;
   if ($42) {
    $45 = $43;
   } else {
    _memmove(($35|0),($36|0),($40|0))|0;
    $$pre$i$i = HEAP32[$37>>2]|0;
    $45 = $$pre$i$i;
   }
   $44 = (($35) + ($41<<2)|0);
   $46 = ($45|0)==($44|0);
   if ($46) {
    STACKTOP = sp;return;
   } else {
    $scevgep$i$i$i$i = ((($45)) + -4|0);
    $47 = $scevgep$i$i$i$i;
    $48 = $44;
    $49 = (($47) - ($48))|0;
    $50 = $49 >>> 2;
    $51 = $50 ^ -1;
    $scevgep5$i$i$i$i = (($45) + ($51<<2)|0);
    $$sink$i = $37;$scevgep5$i$i$i$sink$i = $scevgep5$i$i$i$i;
    break;
   }
  } else {
   $31 = ((($1)) + 32|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ((($32)) + -4|0);
   $$sink$i = $31;$scevgep5$i$i$i$sink$i = $33;
  }
 } while(0);
 HEAP32[$$sink$i>>2] = $scevgep5$i$i$i$sink$i;
 STACKTOP = sp;return;
}
function __ZNK3osg9Transform12computeBoundEv($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$sroa$091$0$copyload = 0.0, $$sroa$11$0$$sroa_idx97 = 0, $$sroa$11$0$copyload = 0.0, $$sroa$16102$0$$sroa_idx103 = 0, $$sroa$16102$0$copyload = 0.0, $10 = 0, $100 = 0.0, $101 = 0.0, $102 = 0.0, $103 = 0.0, $104 = 0.0, $105 = 0.0, $106 = 0.0, $107 = 0.0, $108 = 0.0, $109 = 0.0, $11 = 0.0, $110 = 0.0, $111 = 0.0, $112 = 0.0;
 var $113 = 0.0, $114 = 0.0, $115 = 0.0, $116 = 0.0, $117 = 0.0, $118 = 0.0, $119 = 0.0, $12 = 0.0, $120 = 0.0, $121 = 0.0, $122 = 0.0, $123 = 0.0, $124 = 0.0, $125 = 0.0, $126 = 0.0, $127 = 0.0, $128 = 0.0, $129 = 0.0, $13 = 0, $130 = 0.0;
 var $131 = 0.0, $132 = 0.0, $133 = 0.0, $134 = 0.0, $135 = 0.0, $136 = 0.0, $137 = 0.0, $138 = 0.0, $139 = 0.0, $14 = 0.0, $140 = 0.0, $141 = 0.0, $142 = 0.0, $143 = 0.0, $144 = 0.0, $145 = 0.0, $146 = 0.0, $147 = 0.0, $148 = 0.0, $149 = 0.0;
 var $15 = 0.0, $150 = 0.0, $151 = 0.0, $152 = 0.0, $153 = 0.0, $154 = 0.0, $155 = 0.0, $156 = 0.0, $157 = 0.0, $158 = 0.0, $159 = 0.0, $16 = 0.0, $160 = 0.0, $161 = 0.0, $162 = 0.0, $163 = 0.0, $164 = 0.0, $165 = 0.0, $166 = 0.0, $167 = 0.0;
 var $168 = 0.0, $169 = 0.0, $17 = 0, $170 = 0.0, $171 = 0.0, $172 = 0.0, $173 = 0.0, $174 = 0.0, $175 = 0.0, $176 = 0.0, $177 = 0.0, $178 = 0.0, $179 = 0.0, $18 = 0.0, $180 = 0.0, $181 = 0.0, $182 = 0.0, $183 = 0.0, $184 = 0.0, $185 = 0.0;
 var $186 = 0.0, $187 = 0.0, $188 = 0.0, $189 = 0.0, $19 = 0.0, $190 = 0.0, $191 = 0.0, $192 = 0.0, $193 = 0.0, $194 = 0, $195 = 0, $196 = 0.0, $197 = 0, $198 = 0, $2 = 0, $20 = 0.0, $21 = 0.0, $22 = 0, $23 = 0.0, $24 = 0.0;
 var $25 = 0.0, $26 = 0.0, $27 = 0, $28 = 0.0, $29 = 0.0, $3 = 0, $30 = 0.0, $31 = 0.0, $32 = 0.0, $33 = 0, $34 = 0.0, $35 = 0.0, $36 = 0.0, $37 = 0, $38 = 0.0, $39 = 0.0, $4 = 0.0, $40 = 0.0, $41 = 0, $42 = 0.0;
 var $43 = 0.0, $44 = 0.0, $45 = 0.0, $46 = 0, $47 = 0.0, $48 = 0.0, $49 = 0, $5 = 0, $50 = 0.0, $51 = 0.0, $52 = 0.0, $53 = 0, $54 = 0.0, $55 = 0.0, $56 = 0.0, $57 = 0, $58 = 0.0, $59 = 0.0, $6 = 0, $60 = 0.0;
 var $61 = 0.0, $62 = 0, $63 = 0.0, $64 = 0.0, $65 = 0, $66 = 0.0, $67 = 0.0, $68 = 0.0, $69 = 0, $7 = 0, $70 = 0.0, $71 = 0.0, $72 = 0.0, $73 = 0, $74 = 0.0, $75 = 0.0, $76 = 0.0, $77 = 0.0, $78 = 0.0, $79 = 0.0;
 var $8 = 0, $80 = 0.0, $81 = 0.0, $82 = 0.0, $83 = 0.0, $84 = 0.0, $85 = 0.0, $86 = 0.0, $87 = 0.0, $88 = 0.0, $89 = 0.0, $9 = 0, $90 = 0.0, $91 = 0.0, $92 = 0.0, $93 = 0.0, $94 = 0.0, $95 = 0.0, $96 = 0.0, $97 = 0.0;
 var $98 = 0.0, $99 = 0.0, $storemerge = 0.0, $storemerge16 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(128|0);
 $2 = sp;
 __ZNK3osg5Group12computeBoundEv($0,$1);
 $3 = ((($0)) + 12|0);
 $4 = +HEAPF32[$3>>2];
 $5 = !($4 >= 0.0);
 if ($5) {
  STACKTOP = sp;return;
 }
 __ZN3osg7Matrixd12makeIdentityEv($2);
 $6 = HEAP32[$1>>2]|0;
 $7 = ((($6)) + 264|0);
 $8 = HEAP32[$7>>2]|0;
 __THREW__ = 0;
 (invoke_iiii($8|0,($1|0),($2|0),(0|0))|0);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if ($10) {
  $197 = ___cxa_find_matching_catch_2()|0;
  $198 = tempRet0;
  ___resumeException($197|0);
  // unreachable;
 }
 $$sroa$091$0$copyload = +HEAPF32[$0>>2];
 $$sroa$11$0$$sroa_idx97 = ((($0)) + 4|0);
 $$sroa$11$0$copyload = +HEAPF32[$$sroa$11$0$$sroa_idx97>>2];
 $$sroa$16102$0$$sroa_idx103 = ((($0)) + 8|0);
 $$sroa$16102$0$copyload = +HEAPF32[$$sroa$16102$0$$sroa_idx103>>2];
 $11 = +HEAPF32[$3>>2];
 $12 = $$sroa$091$0$copyload + $11;
 $13 = ((($2)) + 24|0);
 $14 = +HEAPF64[$13>>3];
 $15 = $12;
 $16 = $14 * $15;
 $17 = ((($2)) + 56|0);
 $18 = +HEAPF64[$17>>3];
 $19 = $$sroa$11$0$copyload;
 $20 = $19 * $18;
 $21 = $16 + $20;
 $22 = ((($2)) + 88|0);
 $23 = +HEAPF64[$22>>3];
 $24 = $$sroa$16102$0$copyload;
 $25 = $24 * $23;
 $26 = $21 + $25;
 $27 = ((($2)) + 120|0);
 $28 = +HEAPF64[$27>>3];
 $29 = $28 + $26;
 $30 = 1.0 / $29;
 $31 = +HEAPF64[$2>>3];
 $32 = $15 * $31;
 $33 = ((($2)) + 32|0);
 $34 = +HEAPF64[$33>>3];
 $35 = $19 * $34;
 $36 = $32 + $35;
 $37 = ((($2)) + 64|0);
 $38 = +HEAPF64[$37>>3];
 $39 = $24 * $38;
 $40 = $36 + $39;
 $41 = ((($2)) + 96|0);
 $42 = +HEAPF64[$41>>3];
 $43 = $42 + $40;
 $44 = $30 * $43;
 $45 = $44;
 $46 = ((($2)) + 8|0);
 $47 = +HEAPF64[$46>>3];
 $48 = $15 * $47;
 $49 = ((($2)) + 40|0);
 $50 = +HEAPF64[$49>>3];
 $51 = $19 * $50;
 $52 = $48 + $51;
 $53 = ((($2)) + 72|0);
 $54 = +HEAPF64[$53>>3];
 $55 = $24 * $54;
 $56 = $52 + $55;
 $57 = ((($2)) + 104|0);
 $58 = +HEAPF64[$57>>3];
 $59 = $58 + $56;
 $60 = $30 * $59;
 $61 = $60;
 $62 = ((($2)) + 16|0);
 $63 = +HEAPF64[$62>>3];
 $64 = $15 * $63;
 $65 = ((($2)) + 48|0);
 $66 = +HEAPF64[$65>>3];
 $67 = $19 * $66;
 $68 = $64 + $67;
 $69 = ((($2)) + 80|0);
 $70 = +HEAPF64[$69>>3];
 $71 = $24 * $70;
 $72 = $68 + $71;
 $73 = ((($2)) + 112|0);
 $74 = +HEAPF64[$73>>3];
 $75 = $74 + $72;
 $76 = $30 * $75;
 $77 = $76;
 $78 = $$sroa$11$0$copyload + $11;
 $79 = $$sroa$091$0$copyload;
 $80 = $79 * $14;
 $81 = $78;
 $82 = $18 * $81;
 $83 = $80 + $82;
 $84 = $83 + $25;
 $85 = $28 + $84;
 $86 = 1.0 / $85;
 $87 = $79 * $31;
 $88 = $81 * $34;
 $89 = $87 + $88;
 $90 = $89 + $39;
 $91 = $42 + $90;
 $92 = $86 * $91;
 $93 = $92;
 $94 = $79 * $47;
 $95 = $81 * $50;
 $96 = $94 + $95;
 $97 = $96 + $55;
 $98 = $58 + $97;
 $99 = $86 * $98;
 $100 = $99;
 $101 = $79 * $63;
 $102 = $81 * $66;
 $103 = $101 + $102;
 $104 = $103 + $71;
 $105 = $74 + $104;
 $106 = $86 * $105;
 $107 = $106;
 $108 = $$sroa$16102$0$copyload + $11;
 $109 = $80 + $20;
 $110 = $108;
 $111 = $110 * $23;
 $112 = $109 + $111;
 $113 = $28 + $112;
 $114 = 1.0 / $113;
 $115 = $87 + $35;
 $116 = $110 * $38;
 $117 = $115 + $116;
 $118 = $42 + $117;
 $119 = $114 * $118;
 $120 = $119;
 $121 = $94 + $51;
 $122 = $110 * $54;
 $123 = $121 + $122;
 $124 = $58 + $123;
 $125 = $114 * $124;
 $126 = $125;
 $127 = $101 + $67;
 $128 = $110 * $70;
 $129 = $127 + $128;
 $130 = $74 + $129;
 $131 = $114 * $130;
 $132 = $131;
 $133 = +HEAPF32[$0>>2];
 $134 = $133;
 $135 = $14 * $134;
 $136 = +HEAPF32[$$sroa$11$0$$sroa_idx97>>2];
 $137 = $136;
 $138 = $18 * $137;
 $139 = $135 + $138;
 $140 = +HEAPF32[$$sroa$16102$0$$sroa_idx103>>2];
 $141 = $140;
 $142 = $23 * $141;
 $143 = $139 + $142;
 $144 = $28 + $143;
 $145 = 1.0 / $144;
 $146 = $31 * $134;
 $147 = $34 * $137;
 $148 = $146 + $147;
 $149 = $38 * $141;
 $150 = $148 + $149;
 $151 = $42 + $150;
 $152 = $151 * $145;
 $153 = $152;
 $154 = $47 * $134;
 $155 = $50 * $137;
 $156 = $154 + $155;
 $157 = $54 * $141;
 $158 = $156 + $157;
 $159 = $58 + $158;
 $160 = $159 * $145;
 $161 = $160;
 $162 = $63 * $134;
 $163 = $66 * $137;
 $164 = $162 + $163;
 $165 = $70 * $141;
 $166 = $164 + $165;
 $167 = $74 + $166;
 $168 = $167 * $145;
 $169 = $168;
 HEAPF32[$0>>2] = $153;
 HEAPF32[$$sroa$11$0$$sroa_idx97>>2] = $161;
 HEAPF32[$$sroa$16102$0$$sroa_idx103>>2] = $169;
 $170 = $45 - $153;
 $171 = $61 - $161;
 $172 = $77 - $169;
 $173 = $170 * $170;
 $174 = $171 * $171;
 $175 = $173 + $174;
 $176 = $172 * $172;
 $177 = $176 + $175;
 $178 = $93 - $153;
 $179 = $100 - $161;
 $180 = $107 - $169;
 $181 = $178 * $178;
 $182 = $179 * $179;
 $183 = $181 + $182;
 $184 = $180 * $180;
 $185 = $184 + $183;
 $186 = $120 - $153;
 $187 = $126 - $161;
 $188 = $132 - $169;
 $189 = $186 * $186;
 $190 = $187 * $187;
 $191 = $189 + $190;
 $192 = $188 * $188;
 $193 = $192 + $191;
 $194 = $177 < $185;
 $storemerge = $194 ? $185 : $177;
 $195 = $storemerge < $193;
 $storemerge16 = $195 ? $193 : $storemerge;
 $196 = (+Math_sqrt((+$storemerge16)));
 HEAPF32[$3>>2] = $196;
 STACKTOP = sp;return;
}
function __ZNK3osg9Transform25computeLocalToWorldMatrixERNS_7MatrixdEPNS_11NodeVisitorE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 136|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 if ($5) {
  $$0 = 0;
  return ($$0|0);
 }
 __ZN3osg7Matrixd12makeIdentityEv($1);
 $$0 = 1;
 return ($$0|0);
}
function __ZNK3osg9Transform25computeWorldToLocalMatrixERNS_7MatrixdEPNS_11NodeVisitorE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 136|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 if ($5) {
  $$0 = 0;
  return ($$0|0);
 }
 __ZN3osg7Matrixd12makeIdentityEv($1);
 $$0 = 1;
 return ($$0|0);
}
function __ZN3osg19computeLocalToWorldERKNSt3__26vectorIPNS_4NodeENS0_9allocatorIS3_EEEEb($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$01731$i = 0, $$04 = 0, $$1 = 0, $$1$ph$i = 0, $$1$ph$ph$i = 0, $$129$i = 0, $$15 = 0, $$pre$i = 0, $$pre38$i = 0, $$sroa$326$030$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index4Z2D = 0, $eh$lpad$body$indexZ2D = 0, $eh$lpad$body10$index9Z2D = 0, $eh$lpad$body10$indexZ2D = 0, $eh$lpad$body14$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(112|0);
 $3 = sp;
 __ZN3osg7Matrixd12makeIdentityEv($0);
 $4 = ((($3)) + 68|0);
 __THREW__ = 0;
 invoke_vi(3282,($4|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 do {
  if ($6) {
   $81 = ___cxa_find_matching_catch_2()|0;
   $82 = tempRet0;
   $eh$lpad$body$index4Z2D = $82;$eh$lpad$body$indexZ2D = $81;
  } else {
   HEAP32[$4>>2] = (63412);
   $7 = ((($3)) + 80|0);
   ;HEAP32[$7>>2]=0|0;HEAP32[$7+4>>2]=0|0;HEAP32[$7+8>>2]=0|0;
   $8 = ((($3)) + 92|0);
   HEAP32[$8>>2] = 2;
   $9 = ((($3)) + 96|0);
   HEAP32[$9>>2] = 0;
   __THREW__ = 0;
   invoke_viii(3283,($3|0),((68812)|0),0);
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if ($11) {
    $12 = ___cxa_find_matching_catch_2()|0;
    $13 = tempRet0;
    __THREW__ = 0;
    invoke_vi(388,($4|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if (!($15)) {
     $eh$lpad$body$index4Z2D = $13;$eh$lpad$body$indexZ2D = $12;
     break;
    }
    $16 = ___cxa_find_matching_catch_3(0|0)|0;
    $17 = tempRet0;
    ___clang_call_terminate($16);
    // unreachable;
   }
   $18 = $2&1;
   HEAP32[$3>>2] = (68836);
   HEAP32[$4>>2] = (69180);
   $19 = ((($3)) + 56|0);
   HEAP32[$19>>2] = 1;
   $20 = ((($3)) + 60|0);
   HEAP32[$20>>2] = $0;
   $21 = ((($3)) + 64|0);
   HEAP8[$21>>0] = $18;
   $22 = HEAP32[$1>>2]|0;
   $23 = ((($1)) + 4|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = ($22|0)==($24|0);
   $26 = $24;
   $27 = $22;
   L8: do {
    if ($25) {
     label = 17;
    } else {
     L10: do {
      if ($2) {
       $28 = (($26) - ($27))|0;
       $29 = $28 >> 2;
       $$01731$i = $29;$$sroa$326$030$i = $24;
       while(1) {
        $36 = ((($$sroa$326$030$i)) + -4|0);
        $37 = HEAP32[$36>>2]|0;
        $38 = HEAP32[$37>>2]|0;
        $39 = ((($38)) + 72|0);
        $40 = HEAP32[$39>>2]|0;
        __THREW__ = 0;
        $41 = (invoke_ii($40|0,($37|0))|0);
        $42 = __THREW__; __THREW__ = 0;
        $43 = $42&1;
        if ($43) {
         break L10;
        }
        $44 = ($41|0)==(0|0);
        if (!($44)) {
         $45 = ((($41)) + 136|0);
         $46 = HEAP32[$45>>2]|0;
         $47 = ($46|0)==(0);
         if (!($47)) {
          $$1$ph$ph$i = $$01731$i;
          break;
         }
         $48 = ((($41)) + 72|0);
         $49 = HEAP32[$48>>2]|0;
         $50 = ((($41)) + 76|0);
         $51 = HEAP32[$50>>2]|0;
         $52 = ($49|0)==($51|0);
         if ($52) {
          $$1$ph$ph$i = $$01731$i;
          break;
         }
        }
        $53 = (($$01731$i) + -1)|0;
        $54 = HEAP32[$1>>2]|0;
        $55 = ($36|0)==($54|0);
        if ($55) {
         $$1$ph$ph$i = $53;
         break;
        } else {
         $$01731$i = $53;$$sroa$326$030$i = $36;
        }
       }
       $$pre$i = HEAP32[$23>>2]|0;
       $$pre38$i = HEAP32[$1>>2]|0;
       $30 = $$pre38$i;
       $$1$ph$i = $$1$ph$ph$i;$32 = $$pre38$i;$33 = $$pre$i;$99 = $30;
       label = 9;
      } else {
       $$1$ph$i = 0;$32 = $27;$33 = $26;$99 = $22;
       label = 9;
      }
     } while(0);
     L20: do {
      if ((label|0) == 9) {
       $31 = (($33) - ($32))|0;
       $34 = $31 >> 2;
       $35 = ($$1$ph$i>>>0)<($34>>>0);
       if ($35) {
        $$129$i = $$1$ph$i;$57 = $99;
       } else {
        label = 17;
        break L8;
       }
       while(1) {
        $56 = (($57) + ($$129$i<<2)|0);
        $58 = HEAP32[$56>>2]|0;
        $59 = HEAP32[$58>>2]|0;
        $60 = ((($59)) + 188|0);
        $61 = HEAP32[$60>>2]|0;
        __THREW__ = 0;
        invoke_vii($61|0,($58|0),($3|0));
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         break L20;
        }
        $64 = (($$129$i) + 1)|0;
        $65 = HEAP32[$23>>2]|0;
        $66 = HEAP32[$1>>2]|0;
        $67 = (($65) - ($66))|0;
        $68 = $67 >> 2;
        $69 = ($64>>>0)<($68>>>0);
        $70 = $66;
        if ($69) {
         $$129$i = $64;$57 = $70;
        } else {
         label = 17;
         break L8;
        }
       }
      }
     } while(0);
     $83 = ___cxa_find_matching_catch_2()|0;
     $84 = tempRet0;
     __THREW__ = 0;
     invoke_vii(3284,($3|0),((68812)|0));
     $85 = __THREW__; __THREW__ = 0;
     $86 = $85&1;
     if ($86) {
      $89 = ___cxa_find_matching_catch_3(0|0)|0;
      $90 = tempRet0;
      __THREW__ = 0;
      invoke_vi(388,($4|0));
      $91 = __THREW__; __THREW__ = 0;
      $92 = $91&1;
      if ($92) {
       $93 = ___cxa_find_matching_catch_3(0|0)|0;
       $94 = tempRet0;
       ___clang_call_terminate($93);
       // unreachable;
      } else {
       $eh$lpad$body14$indexZ2D = $89;
       ___clang_call_terminate($eh$lpad$body14$indexZ2D);
       // unreachable;
      }
     } else {
      __THREW__ = 0;
      invoke_vi(388,($4|0));
      $87 = __THREW__; __THREW__ = 0;
      $88 = $87&1;
      if (!($88)) {
       $$0 = $84;$$04 = $83;
       break;
      }
      $97 = ___cxa_find_matching_catch_3(0|0)|0;
      $98 = tempRet0;
      $eh$lpad$body14$indexZ2D = $97;
      ___clang_call_terminate($eh$lpad$body14$indexZ2D);
      // unreachable;
     }
    }
   } while(0);
   if ((label|0) == 17) {
    __THREW__ = 0;
    invoke_vii(3284,($3|0),((68812)|0));
    $71 = __THREW__; __THREW__ = 0;
    $72 = $71&1;
    do {
     if ($72) {
      $75 = ___cxa_find_matching_catch_2()|0;
      $76 = tempRet0;
      __THREW__ = 0;
      invoke_vi(388,($4|0));
      $77 = __THREW__; __THREW__ = 0;
      $78 = $77&1;
      if ($78) {
       $79 = ___cxa_find_matching_catch_3(0|0)|0;
       $80 = tempRet0;
       ___clang_call_terminate($79);
       // unreachable;
      } else {
       $eh$lpad$body10$index9Z2D = $76;$eh$lpad$body10$indexZ2D = $75;
      }
     } else {
      __THREW__ = 0;
      invoke_vi(388,($4|0));
      $73 = __THREW__; __THREW__ = 0;
      $74 = $73&1;
      if ($74) {
       $95 = ___cxa_find_matching_catch_2()|0;
       $96 = tempRet0;
       $eh$lpad$body10$index9Z2D = $96;$eh$lpad$body10$indexZ2D = $95;
       break;
      } else {
       STACKTOP = sp;return;
      }
     }
    } while(0);
    $$0 = $eh$lpad$body10$index9Z2D;$$04 = $eh$lpad$body10$indexZ2D;
   }
   $$1 = $$0;$$15 = $$04;
   ___resumeException($$15|0);
   // unreachable;
  }
 } while(0);
 $$1 = $eh$lpad$body$index4Z2D;$$15 = $eh$lpad$body$indexZ2D;
 ___resumeException($$15|0);
 // unreachable;
}
function __ZN16TransformVisitorD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vii(3284,($0|0),((68812)|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  $3 = ((($0)) + 68|0);
  __ZN3osg6ObjectD2Ev($3);
  return;
 }
 $4 = ___cxa_find_matching_catch_2()|0;
 $5 = tempRet0;
 $6 = ((($0)) + 68|0);
 __THREW__ = 0;
 invoke_vi(388,($6|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch_3(0|0)|0;
  $10 = tempRet0;
  ___clang_call_terminate($9);
  // unreachable;
 } else {
  ___resumeException($4|0);
  // unreachable;
 }
}
function __ZN16TransformVisitorD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vii(3284,($0|0),((68812)|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $6 = ___cxa_find_matching_catch_2()|0;
  $7 = tempRet0;
  $8 = ((($0)) + 68|0);
  __THREW__ = 0;
  invoke_vi(388,($8|0));
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if ($10) {
   $11 = ___cxa_find_matching_catch_3(0|0)|0;
   $12 = tempRet0;
   ___clang_call_terminate($11);
   // unreachable;
  } else {
   $eh$lpad$body$index2Z2D = $7;$eh$lpad$body$indexZ2D = $6;
   __ZdlPv($0);
   ___resumeException($eh$lpad$body$indexZ2D|0);
   // unreachable;
  }
 }
 $3 = ((($0)) + 68|0);
 __THREW__ = 0;
 invoke_vi(388,($3|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  __ZdlPv($0);
  return;
 }
 $13 = ___cxa_find_matching_catch_2()|0;
 $14 = tempRet0;
 $eh$lpad$body$index2Z2D = $14;$eh$lpad$body$indexZ2D = $13;
 __ZdlPv($0);
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
}
function __ZN16TransformVisitor5applyERN3osg9TransformE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 56|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(1);
 $5 = HEAP32[$1>>2]|0;
 $6 = ((($0)) + 60|0);
 $7 = HEAP32[$6>>2]|0;
 if ($4) {
  $8 = ((($5)) + 264|0);
  $9 = HEAP32[$8>>2]|0;
  (FUNCTION_TABLE_iiii[$9 & 8191]($1,$7,$0)|0);
  return;
 } else {
  $10 = ((($5)) + 268|0);
  $11 = HEAP32[$10>>2]|0;
  (FUNCTION_TABLE_iiii[$11 & 8191]($1,$7,$0)|0);
  return;
 }
}
function __ZTv0_n16_N16TransformVisitorD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __THREW__ = 0;
 invoke_vii(3284,($4|0),((68812)|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if (!($6)) {
  $14 = ((($4)) + 68|0);
  __ZN3osg6ObjectD2Ev($14);
  return;
 }
 $7 = ___cxa_find_matching_catch_2()|0;
 $8 = tempRet0;
 $9 = ((($4)) + 68|0);
 __THREW__ = 0;
 invoke_vi(388,($9|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if ($11) {
  $12 = ___cxa_find_matching_catch_3(0|0)|0;
  $13 = tempRet0;
  ___clang_call_terminate($12);
  // unreachable;
 } else {
  ___resumeException($7|0);
  // unreachable;
 }
}
function __ZTv0_n16_N16TransformVisitorD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$i$index2Z2D = 0, $eh$lpad$body$i$indexZ2D = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __THREW__ = 0;
 invoke_vii(3284,($4|0),((68812)|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $10 = ___cxa_find_matching_catch_2()|0;
  $11 = tempRet0;
  $12 = ((($4)) + 68|0);
  __THREW__ = 0;
  invoke_vi(388,($12|0));
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if ($14) {
   $15 = ___cxa_find_matching_catch_3(0|0)|0;
   $16 = tempRet0;
   ___clang_call_terminate($15);
   // unreachable;
  } else {
   $eh$lpad$body$i$index2Z2D = $11;$eh$lpad$body$i$indexZ2D = $10;
   __ZdlPv($4);
   ___resumeException($eh$lpad$body$i$indexZ2D|0);
   // unreachable;
  }
 }
 $7 = ((($4)) + 68|0);
 __THREW__ = 0;
 invoke_vi(388,($7|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if (!($9)) {
  __ZdlPv($4);
  return;
 }
 $17 = ___cxa_find_matching_catch_2()|0;
 $18 = tempRet0;
 $eh$lpad$body$i$index2Z2D = $18;$eh$lpad$body$i$indexZ2D = $17;
 __ZdlPv($4);
 ___resumeException($eh$lpad$body$i$indexZ2D|0);
 // unreachable;
}
function __ZN3osg19computeWorldToLocalERKNSt3__26vectorIPNS_4NodeENS0_9allocatorIS3_EEEEb($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$01731$i = 0, $$04 = 0, $$1 = 0, $$1$ph$i = 0, $$1$ph$ph$i = 0, $$129$i = 0, $$15 = 0, $$pre$i = 0, $$pre38$i = 0, $$sroa$326$030$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index4Z2D = 0, $eh$lpad$body$indexZ2D = 0, $eh$lpad$body10$index9Z2D = 0, $eh$lpad$body10$indexZ2D = 0, $eh$lpad$body14$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(112|0);
 $3 = sp;
 __ZN3osg7Matrixd12makeIdentityEv($0);
 $4 = ((($3)) + 68|0);
 __THREW__ = 0;
 invoke_vi(3282,($4|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 do {
  if ($6) {
   $81 = ___cxa_find_matching_catch_2()|0;
   $82 = tempRet0;
   $eh$lpad$body$index4Z2D = $82;$eh$lpad$body$indexZ2D = $81;
  } else {
   HEAP32[$4>>2] = (63412);
   $7 = ((($3)) + 80|0);
   ;HEAP32[$7>>2]=0|0;HEAP32[$7+4>>2]=0|0;HEAP32[$7+8>>2]=0|0;
   $8 = ((($3)) + 92|0);
   HEAP32[$8>>2] = 2;
   $9 = ((($3)) + 96|0);
   HEAP32[$9>>2] = 0;
   __THREW__ = 0;
   invoke_viii(3283,($3|0),((68812)|0),0);
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if ($11) {
    $12 = ___cxa_find_matching_catch_2()|0;
    $13 = tempRet0;
    __THREW__ = 0;
    invoke_vi(388,($4|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if (!($15)) {
     $eh$lpad$body$index4Z2D = $13;$eh$lpad$body$indexZ2D = $12;
     break;
    }
    $16 = ___cxa_find_matching_catch_3(0|0)|0;
    $17 = tempRet0;
    ___clang_call_terminate($16);
    // unreachable;
   }
   $18 = $2&1;
   HEAP32[$3>>2] = (68836);
   HEAP32[$4>>2] = (69180);
   $19 = ((($3)) + 56|0);
   HEAP32[$19>>2] = 0;
   $20 = ((($3)) + 60|0);
   HEAP32[$20>>2] = $0;
   $21 = ((($3)) + 64|0);
   HEAP8[$21>>0] = $18;
   $22 = HEAP32[$1>>2]|0;
   $23 = ((($1)) + 4|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = ($22|0)==($24|0);
   $26 = $24;
   $27 = $22;
   L8: do {
    if ($25) {
     label = 17;
    } else {
     L10: do {
      if ($2) {
       $28 = (($26) - ($27))|0;
       $29 = $28 >> 2;
       $$01731$i = $29;$$sroa$326$030$i = $24;
       while(1) {
        $36 = ((($$sroa$326$030$i)) + -4|0);
        $37 = HEAP32[$36>>2]|0;
        $38 = HEAP32[$37>>2]|0;
        $39 = ((($38)) + 72|0);
        $40 = HEAP32[$39>>2]|0;
        __THREW__ = 0;
        $41 = (invoke_ii($40|0,($37|0))|0);
        $42 = __THREW__; __THREW__ = 0;
        $43 = $42&1;
        if ($43) {
         break L10;
        }
        $44 = ($41|0)==(0|0);
        if (!($44)) {
         $45 = ((($41)) + 136|0);
         $46 = HEAP32[$45>>2]|0;
         $47 = ($46|0)==(0);
         if (!($47)) {
          $$1$ph$ph$i = $$01731$i;
          break;
         }
         $48 = ((($41)) + 72|0);
         $49 = HEAP32[$48>>2]|0;
         $50 = ((($41)) + 76|0);
         $51 = HEAP32[$50>>2]|0;
         $52 = ($49|0)==($51|0);
         if ($52) {
          $$1$ph$ph$i = $$01731$i;
          break;
         }
        }
        $53 = (($$01731$i) + -1)|0;
        $54 = HEAP32[$1>>2]|0;
        $55 = ($36|0)==($54|0);
        if ($55) {
         $$1$ph$ph$i = $53;
         break;
        } else {
         $$01731$i = $53;$$sroa$326$030$i = $36;
        }
       }
       $$pre$i = HEAP32[$23>>2]|0;
       $$pre38$i = HEAP32[$1>>2]|0;
       $30 = $$pre38$i;
       $$1$ph$i = $$1$ph$ph$i;$32 = $$pre38$i;$33 = $$pre$i;$99 = $30;
       label = 9;
      } else {
       $$1$ph$i = 0;$32 = $27;$33 = $26;$99 = $22;
       label = 9;
      }
     } while(0);
     L20: do {
      if ((label|0) == 9) {
       $31 = (($33) - ($32))|0;
       $34 = $31 >> 2;
       $35 = ($$1$ph$i>>>0)<($34>>>0);
       if ($35) {
        $$129$i = $$1$ph$i;$57 = $99;
       } else {
        label = 17;
        break L8;
       }
       while(1) {
        $56 = (($57) + ($$129$i<<2)|0);
        $58 = HEAP32[$56>>2]|0;
        $59 = HEAP32[$58>>2]|0;
        $60 = ((($59)) + 188|0);
        $61 = HEAP32[$60>>2]|0;
        __THREW__ = 0;
        invoke_vii($61|0,($58|0),($3|0));
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         break L20;
        }
        $64 = (($$129$i) + 1)|0;
        $65 = HEAP32[$23>>2]|0;
        $66 = HEAP32[$1>>2]|0;
        $67 = (($65) - ($66))|0;
        $68 = $67 >> 2;
        $69 = ($64>>>0)<($68>>>0);
        $70 = $66;
        if ($69) {
         $$129$i = $64;$57 = $70;
        } else {
         label = 17;
         break L8;
        }
       }
      }
     } while(0);
     $83 = ___cxa_find_matching_catch_2()|0;
     $84 = tempRet0;
     __THREW__ = 0;
     invoke_vii(3284,($3|0),((68812)|0));
     $85 = __THREW__; __THREW__ = 0;
     $86 = $85&1;
     if ($86) {
      $89 = ___cxa_find_matching_catch_3(0|0)|0;
      $90 = tempRet0;
      __THREW__ = 0;
      invoke_vi(388,($4|0));
      $91 = __THREW__; __THREW__ = 0;
      $92 = $91&1;
      if ($92) {
       $93 = ___cxa_find_matching_catch_3(0|0)|0;
       $94 = tempRet0;
       ___clang_call_terminate($93);
       // unreachable;
      } else {
       $eh$lpad$body14$indexZ2D = $89;
       ___clang_call_terminate($eh$lpad$body14$indexZ2D);
       // unreachable;
      }
     } else {
      __THREW__ = 0;
      invoke_vi(388,($4|0));
      $87 = __THREW__; __THREW__ = 0;
      $88 = $87&1;
      if (!($88)) {
       $$0 = $84;$$04 = $83;
       break;
      }
      $97 = ___cxa_find_matching_catch_3(0|0)|0;
      $98 = tempRet0;
      $eh$lpad$body14$indexZ2D = $97;
      ___clang_call_terminate($eh$lpad$body14$indexZ2D);
      // unreachable;
     }
    }
   } while(0);
   if ((label|0) == 17) {
    __THREW__ = 0;
    invoke_vii(3284,($3|0),((68812)|0));
    $71 = __THREW__; __THREW__ = 0;
    $72 = $71&1;
    do {
     if ($72) {
      $75 = ___cxa_find_matching_catch_2()|0;
      $76 = tempRet0;
      __THREW__ = 0;
      invoke_vi(388,($4|0));
      $77 = __THREW__; __THREW__ = 0;
      $78 = $77&1;
      if ($78) {
       $79 = ___cxa_find_matching_catch_3(0|0)|0;
       $80 = tempRet0;
       ___clang_call_terminate($79);
       // unreachable;
      } else {
       $eh$lpad$body10$index9Z2D = $76;$eh$lpad$body10$indexZ2D = $75;
      }
     } else {
      __THREW__ = 0;
      invoke_vi(388,($4|0));
      $73 = __THREW__; __THREW__ = 0;
      $74 = $73&1;
      if ($74) {
       $95 = ___cxa_find_matching_catch_2()|0;
       $96 = tempRet0;
       $eh$lpad$body10$index9Z2D = $96;$eh$lpad$body10$indexZ2D = $95;
       break;
      } else {
       STACKTOP = sp;return;
      }
     }
    } while(0);
    $$0 = $eh$lpad$body10$index9Z2D;$$04 = $eh$lpad$body10$indexZ2D;
   }
   $$1 = $$0;$$15 = $$04;
   ___resumeException($$15|0);
   // unreachable;
  }
 } while(0);
 $$1 = $eh$lpad$body$index4Z2D;$$15 = $eh$lpad$body$indexZ2D;
 ___resumeException($$15|0);
 // unreachable;
}
function __ZN3osg9TransformC2Ev($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg5GroupC2Ev($0);
 HEAP32[$0>>2] = (68536);
 $1 = ((($0)) + 136|0);
 HEAP32[$1>>2] = 0;
 return;
}
function __ZN3osg9TransformC2ERKS0_RKNS_6CopyOpE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg5GroupC2ERKS0_RKNS_6CopyOpE($0,$1,$2);
 HEAP32[$0>>2] = (68536);
 $3 = ((($0)) + 136|0);
 $4 = ((($1)) + 136|0);
 $5 = HEAP32[$4>>2]|0;
 HEAP32[$3>>2] = $5;
 return;
}
function __ZN3osg9Transform17setReferenceFrameENS0_14ReferenceFrameE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 136|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==($1|0);
 if ($4) {
  return;
 }
 $5 = ($1|0)==(0);
 HEAP32[$2>>2] = $1;
 __ZN3osg4Node16setCullingActiveEb($0,$5);
 return;
}
function __ZN3osg7UniformD2Ev($0) {
 $0 = $0|0;
 var $$0 = 0, $$02 = 0, $$1 = 0, $$13 = 0, $$2 = 0, $$24 = 0, $$3 = 0, $$35 = 0, $$4 = 0, $$46 = 0, $$5 = 0, $$57 = 0, $$6 = 0, $$68 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0;
 var $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0;
 var $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0;
 var $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0;
 var $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i32 = 0, $scevgep5$i$i$i = 0, $scevgep5$i$i$i33 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (69328);
 $1 = ((($0)) + 84|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  label = 4;
 } else {
  $4 = HEAP32[$2>>2]|0;
  $5 = ((($4)) + -16|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($2) + ($6)|0);
  $8 = ((($7)) + 8|0);
  $9 = HEAP32[$8>>2]|0;HEAP32[$8>>2] = (($9-1)|0);
  $10 = ($9|0)==(1);
  if ($10) {
   __THREW__ = 0;
   invoke_viii(3262,($7|0),1,1);
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if ($12) {
    $84 = ___cxa_find_matching_catch_2()|0;
    $85 = tempRet0;
    $86 = ((($0)) + 80|0);
    $87 = HEAP32[$86>>2]|0;
    $88 = ($87|0)==(0|0);
    if (!($88)) {
     $89 = HEAP32[$87>>2]|0;
     $90 = ((($89)) + -16|0);
     $91 = HEAP32[$90>>2]|0;
     $92 = (($87) + ($91)|0);
     $93 = ((($92)) + 8|0);
     $94 = HEAP32[$93>>2]|0;HEAP32[$93>>2] = (($94-1)|0);
     $95 = ($94|0)==(1);
     if ($95) {
      __THREW__ = 0;
      invoke_viii(3262,($92|0),1,1);
      $96 = __THREW__; __THREW__ = 0;
      $97 = $96&1;
      if ($97) {
       $173 = ___cxa_find_matching_catch_3(0|0)|0;
       $174 = tempRet0;
       ___clang_call_terminate($173);
       // unreachable;
      }
     }
    }
    HEAP32[$86>>2] = 0;
    $$0 = $85;$$02 = $84;
    label = 36;
   } else {
    label = 4;
   }
  } else {
   label = 4;
  }
 }
 do {
  if ((label|0) == 4) {
   HEAP32[$1>>2] = 0;
   $13 = ((($0)) + 80|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = ($14|0)==(0|0);
   if (!($15)) {
    $16 = HEAP32[$14>>2]|0;
    $17 = ((($16)) + -16|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = (($14) + ($18)|0);
    $20 = ((($19)) + 8|0);
    $21 = HEAP32[$20>>2]|0;HEAP32[$20>>2] = (($21-1)|0);
    $22 = ($21|0)==(1);
    if ($22) {
     __THREW__ = 0;
     invoke_viii(3262,($19|0),1,1);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      $98 = ___cxa_find_matching_catch_2()|0;
      $99 = tempRet0;
      $$0 = $99;$$02 = $98;
      label = 36;
      break;
     }
    }
   }
   HEAP32[$13>>2] = 0;
   $25 = ((($0)) + 76|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = ($26|0)==(0|0);
   if (!($27)) {
    $28 = ((($26)) + 8|0);
    $29 = HEAP32[$28>>2]|0;HEAP32[$28>>2] = (($29-1)|0);
    $30 = ($29|0)==(1);
    if ($30) {
     __THREW__ = 0;
     invoke_viii(3262,($26|0),1,1);
     $31 = __THREW__; __THREW__ = 0;
     $32 = $31&1;
     if ($32) {
      $100 = ___cxa_find_matching_catch_2()|0;
      $101 = tempRet0;
      $$1 = $101;$$13 = $100;
      label = 41;
      break;
     }
    }
   }
   HEAP32[$25>>2] = 0;
   $33 = ((($0)) + 72|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = ($34|0)==(0|0);
   if (!($35)) {
    $36 = ((($34)) + 8|0);
    $37 = HEAP32[$36>>2]|0;HEAP32[$36>>2] = (($37-1)|0);
    $38 = ($37|0)==(1);
    if ($38) {
     __THREW__ = 0;
     invoke_viii(3262,($34|0),1,1);
     $39 = __THREW__; __THREW__ = 0;
     $40 = $39&1;
     if ($40) {
      $110 = ___cxa_find_matching_catch_2()|0;
      $111 = tempRet0;
      $$2 = $111;$$24 = $110;
      label = 46;
      break;
     }
    }
   }
   HEAP32[$33>>2] = 0;
   $41 = ((($0)) + 68|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = ($42|0)==(0|0);
   if (!($43)) {
    $44 = ((($42)) + 8|0);
    $45 = HEAP32[$44>>2]|0;HEAP32[$44>>2] = (($45-1)|0);
    $46 = ($45|0)==(1);
    if ($46) {
     __THREW__ = 0;
     invoke_viii(3262,($42|0),1,1);
     $47 = __THREW__; __THREW__ = 0;
     $48 = $47&1;
     if ($48) {
      $120 = ___cxa_find_matching_catch_2()|0;
      $121 = tempRet0;
      $$3 = $121;$$35 = $120;
      label = 51;
      break;
     }
    }
   }
   HEAP32[$41>>2] = 0;
   $49 = ((($0)) + 64|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = ($50|0)==(0|0);
   if (!($51)) {
    $52 = ((($50)) + 8|0);
    $53 = HEAP32[$52>>2]|0;HEAP32[$52>>2] = (($53-1)|0);
    $54 = ($53|0)==(1);
    if ($54) {
     __THREW__ = 0;
     invoke_viii(3262,($50|0),1,1);
     $55 = __THREW__; __THREW__ = 0;
     $56 = $55&1;
     if ($56) {
      $130 = ___cxa_find_matching_catch_2()|0;
      $131 = tempRet0;
      $$4 = $131;$$46 = $130;
      label = 56;
      break;
     }
    }
   }
   HEAP32[$49>>2] = 0;
   $57 = ((($0)) + 60|0);
   $58 = HEAP32[$57>>2]|0;
   $59 = ($58|0)==(0|0);
   if (!($59)) {
    $60 = ((($58)) + 8|0);
    $61 = HEAP32[$60>>2]|0;HEAP32[$60>>2] = (($61-1)|0);
    $62 = ($61|0)==(1);
    if ($62) {
     __THREW__ = 0;
     invoke_viii(3262,($58|0),1,1);
     $63 = __THREW__; __THREW__ = 0;
     $64 = $63&1;
     if ($64) {
      $140 = ___cxa_find_matching_catch_2()|0;
      $141 = tempRet0;
      $$5 = $141;$$57 = $140;
      label = 61;
      break;
     }
    }
   }
   HEAP32[$57>>2] = 0;
   $65 = ((($0)) + 56|0);
   $66 = HEAP32[$65>>2]|0;
   $67 = ($66|0)==(0|0);
   if (!($67)) {
    $68 = ((($66)) + 8|0);
    $69 = HEAP32[$68>>2]|0;HEAP32[$68>>2] = (($69-1)|0);
    $70 = ($69|0)==(1);
    if ($70) {
     __THREW__ = 0;
     invoke_viii(3262,($66|0),1,1);
     $71 = __THREW__; __THREW__ = 0;
     $72 = $71&1;
     if ($72) {
      $150 = ___cxa_find_matching_catch_2()|0;
      $151 = tempRet0;
      $$6 = $151;$$68 = $150;
      break;
     }
    }
   }
   HEAP32[$65>>2] = 0;
   $73 = ((($0)) + 32|0);
   $74 = HEAP32[$73>>2]|0;
   $75 = ($74|0)==(0|0);
   if ($75) {
    __ZN3osg6ObjectD2Ev($0);
    return;
   }
   $76 = ((($0)) + 36|0);
   $77 = HEAP32[$76>>2]|0;
   $78 = ($77|0)==($74|0);
   if (!($78)) {
    $scevgep$i$i$i = ((($77)) + -4|0);
    $79 = $scevgep$i$i$i;
    $80 = $74;
    $81 = (($79) - ($80))|0;
    $82 = $81 >>> 2;
    $83 = $82 ^ -1;
    $scevgep5$i$i$i = (($77) + ($83<<2)|0);
    HEAP32[$76>>2] = $scevgep5$i$i$i;
   }
   __ZdlPv($74);
   __ZN3osg6ObjectD2Ev($0);
   return;
  }
 } while(0);
 if ((label|0) == 36) {
  $102 = ((($0)) + 76|0);
  $103 = HEAP32[$102>>2]|0;
  $104 = ($103|0)==(0|0);
  if (!($104)) {
   $105 = ((($103)) + 8|0);
   $106 = HEAP32[$105>>2]|0;HEAP32[$105>>2] = (($106-1)|0);
   $107 = ($106|0)==(1);
   if ($107) {
    __THREW__ = 0;
    invoke_viii(3262,($103|0),1,1);
    $108 = __THREW__; __THREW__ = 0;
    $109 = $108&1;
    if ($109) {
     $173 = ___cxa_find_matching_catch_3(0|0)|0;
     $174 = tempRet0;
     ___clang_call_terminate($173);
     // unreachable;
    }
   }
  }
  HEAP32[$102>>2] = 0;
  $$1 = $$0;$$13 = $$02;
  label = 41;
 }
 if ((label|0) == 41) {
  $112 = ((($0)) + 72|0);
  $113 = HEAP32[$112>>2]|0;
  $114 = ($113|0)==(0|0);
  if (!($114)) {
   $115 = ((($113)) + 8|0);
   $116 = HEAP32[$115>>2]|0;HEAP32[$115>>2] = (($116-1)|0);
   $117 = ($116|0)==(1);
   if ($117) {
    __THREW__ = 0;
    invoke_viii(3262,($113|0),1,1);
    $118 = __THREW__; __THREW__ = 0;
    $119 = $118&1;
    if ($119) {
     $173 = ___cxa_find_matching_catch_3(0|0)|0;
     $174 = tempRet0;
     ___clang_call_terminate($173);
     // unreachable;
    }
   }
  }
  HEAP32[$112>>2] = 0;
  $$2 = $$1;$$24 = $$13;
  label = 46;
 }
 if ((label|0) == 46) {
  $122 = ((($0)) + 68|0);
  $123 = HEAP32[$122>>2]|0;
  $124 = ($123|0)==(0|0);
  if (!($124)) {
   $125 = ((($123)) + 8|0);
   $126 = HEAP32[$125>>2]|0;HEAP32[$125>>2] = (($126-1)|0);
   $127 = ($126|0)==(1);
   if ($127) {
    __THREW__ = 0;
    invoke_viii(3262,($123|0),1,1);
    $128 = __THREW__; __THREW__ = 0;
    $129 = $128&1;
    if ($129) {
     $173 = ___cxa_find_matching_catch_3(0|0)|0;
     $174 = tempRet0;
     ___clang_call_terminate($173);
     // unreachable;
    }
   }
  }
  HEAP32[$122>>2] = 0;
  $$3 = $$2;$$35 = $$24;
  label = 51;
 }
 if ((label|0) == 51) {
  $132 = ((($0)) + 64|0);
  $133 = HEAP32[$132>>2]|0;
  $134 = ($133|0)==(0|0);
  if (!($134)) {
   $135 = ((($133)) + 8|0);
   $136 = HEAP32[$135>>2]|0;HEAP32[$135>>2] = (($136-1)|0);
   $137 = ($136|0)==(1);
   if ($137) {
    __THREW__ = 0;
    invoke_viii(3262,($133|0),1,1);
    $138 = __THREW__; __THREW__ = 0;
    $139 = $138&1;
    if ($139) {
     $173 = ___cxa_find_matching_catch_3(0|0)|0;
     $174 = tempRet0;
     ___clang_call_terminate($173);
     // unreachable;
    }
   }
  }
  HEAP32[$132>>2] = 0;
  $$4 = $$3;$$46 = $$35;
  label = 56;
 }
 if ((label|0) == 56) {
  $142 = ((($0)) + 60|0);
  $143 = HEAP32[$142>>2]|0;
  $144 = ($143|0)==(0|0);
  if (!($144)) {
   $145 = ((($143)) + 8|0);
   $146 = HEAP32[$145>>2]|0;HEAP32[$145>>2] = (($146-1)|0);
   $147 = ($146|0)==(1);
   if ($147) {
    __THREW__ = 0;
    invoke_viii(3262,($143|0),1,1);
    $148 = __THREW__; __THREW__ = 0;
    $149 = $148&1;
    if ($149) {
     $173 = ___cxa_find_matching_catch_3(0|0)|0;
     $174 = tempRet0;
     ___clang_call_terminate($173);
     // unreachable;
    }
   }
  }
  HEAP32[$142>>2] = 0;
  $$5 = $$4;$$57 = $$46;
  label = 61;
 }
 if ((label|0) == 61) {
  $152 = ((($0)) + 56|0);
  $153 = HEAP32[$152>>2]|0;
  $154 = ($153|0)==(0|0);
  if (!($154)) {
   $155 = ((($153)) + 8|0);
   $156 = HEAP32[$155>>2]|0;HEAP32[$155>>2] = (($156-1)|0);
   $157 = ($156|0)==(1);
   if ($157) {
    __THREW__ = 0;
    invoke_viii(3262,($153|0),1,1);
    $158 = __THREW__; __THREW__ = 0;
    $159 = $158&1;
    if ($159) {
     $173 = ___cxa_find_matching_catch_3(0|0)|0;
     $174 = tempRet0;
     ___clang_call_terminate($173);
     // unreachable;
    }
   }
  }
  HEAP32[$152>>2] = 0;
  $$6 = $$5;$$68 = $$57;
 }
 $160 = ((($0)) + 32|0);
 $161 = HEAP32[$160>>2]|0;
 $162 = ($161|0)==(0|0);
 if (!($162)) {
  $163 = ((($0)) + 36|0);
  $164 = HEAP32[$163>>2]|0;
  $165 = ($164|0)==($161|0);
  if (!($165)) {
   $scevgep$i$i$i32 = ((($164)) + -4|0);
   $166 = $scevgep$i$i$i32;
   $167 = $161;
   $168 = (($166) - ($167))|0;
   $169 = $168 >>> 2;
   $170 = $169 ^ -1;
   $scevgep5$i$i$i33 = (($164) + ($170<<2)|0);
   HEAP32[$163>>2] = $scevgep5$i$i$i33;
  }
  __ZdlPv($161);
 }
 __THREW__ = 0;
 invoke_vi(388,($0|0));
 $171 = __THREW__; __THREW__ = 0;
 $172 = $171&1;
 if ($172) {
  $173 = ___cxa_find_matching_catch_3(0|0)|0;
  $174 = tempRet0;
  ___clang_call_terminate($173);
  // unreachable;
 } else {
  ___resumeException($$68|0);
  // unreachable;
 }
}
function __ZN3osg7UniformD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(2381,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK3osg7Uniform9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $1 = (__Znwj(92)|0);
 __THREW__ = 0;
 invoke_vi(3282,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $10 = ___cxa_find_matching_catch_2()|0;
  $11 = tempRet0;
  __ZdlPv($1);
  ___resumeException($10|0);
  // unreachable;
 } else {
  $4 = ((($1)) + 12|0);
  ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;
  $5 = ((($1)) + 24|0);
  HEAP32[$5>>2] = 2;
  $6 = ((($1)) + 28|0);
  HEAP32[$6>>2] = 0;
  HEAP32[$1>>2] = (69328);
  $7 = ((($1)) + 32|0);
  $8 = ((($1)) + 52|0);
  ;HEAP32[$7>>2]=0|0;HEAP32[$7+4>>2]=0|0;HEAP32[$7+8>>2]=0|0;HEAP32[$7+12>>2]=0|0;HEAP32[$7+16>>2]=0|0;
  HEAP32[$8>>2] = -1;
  $9 = ((($1)) + 56|0);
  dest=$9; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
  return ($1|0);
 }
 return (0)|0;
}
function __ZNK3osg7Uniform5cloneERKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(92)|0);
 __THREW__ = 0;
 invoke_viii(3989,($2|0),($0|0),($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch_2()|0;
  $6 = tempRet0;
  __ZdlPv($2);
  ___resumeException($5|0);
  // unreachable;
 } else {
  return ($2|0);
 }
 return (0)|0;
}
function __ZNK3osg7Uniform12isSameKindAsEPKNS_6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,26960,0)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK3osg7Uniform11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175113|0);
}
function __ZNK3osg7Uniform9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (156538|0);
}
function __ZN3osg7Uniform9asUniformEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ($0|0);
}
function __ZNK3osg7Uniform9asUniformEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ($0|0);
}
function __ZN3osg7Uniform7setNameERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = ((($0)) + 12|0);
 $4 = ((($3)) + 11|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)<(0);
 $7 = ((($0)) + 16|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $5&255;
 $10 = $6 ? $8 : $9;
 $11 = ($10|0)==(0);
 if ($11) {
  __THREW__ = 0;
  $12 = (invoke_iiiiii(3253,($3|0),0,-1,(221531|0),0)|0);
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if ($14) {
   $15 = ___cxa_find_matching_catch_2()|0;
   $16 = tempRet0;
   ___cxa_call_unexpected(($15|0));
   // unreachable;
  }
  $phitmp$i = ($12|0)==(0);
  if ($phitmp$i) {
   (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEaSERKS5_($3,$1)|0);
   $39 = (__ZN3osg7Uniform9getNameIDERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE($3)|0);
   $40 = ((($0)) + 52|0);
   HEAP32[$40>>2] = $39;
   STACKTOP = sp;return;
  }
 }
 $17 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
 if (!($17)) {
  STACKTOP = sp;return;
 }
 $18 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
 $19 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($18,156511,26)|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ((($20)) + -12|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($19) + ($22)|0);
 __ZNKSt3__28ios_base6getlocEv($2,$23);
 __THREW__ = 0;
 $24 = (invoke_iii(3255,($2|0),(215188|0))|0);
 $25 = __THREW__; __THREW__ = 0;
 $26 = $25&1;
 if (!($26)) {
  $27 = HEAP32[$24>>2]|0;
  $28 = ((($27)) + 28|0);
  $29 = HEAP32[$28>>2]|0;
  __THREW__ = 0;
  $30 = (invoke_iii($29|0,($24|0),10)|0);
  $31 = __THREW__; __THREW__ = 0;
  $32 = $31&1;
  if (!($32)) {
   __ZNSt3__26localeD2Ev($2);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($19,$30)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($19)|0);
   STACKTOP = sp;return;
  }
 }
 $33 = ___cxa_find_matching_catch_2()|0;
 $34 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($2|0));
 $35 = __THREW__; __THREW__ = 0;
 $36 = $35&1;
 if ($36) {
  $37 = ___cxa_find_matching_catch_3(0|0)|0;
  $38 = tempRet0;
  ___clang_call_terminate($37);
  // unreachable;
 } else {
  ___resumeException($33|0);
  // unreachable;
 }
}
function __ZNK3osg7Uniform7compareERKS0_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$sroa$speculated$i$i$i = 0, $$sroa$speculated$i$i$i9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($0|0)==($1|0);
 if ($2) {
  $$0 = 0;
  return ($$0|0);
 }
 $3 = ((($0)) + 44|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($1)) + 44|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4|0)<($6|0);
 if ($7) {
  $$0 = -1;
  return ($$0|0);
 }
 $8 = ($6|0)<($4|0);
 if ($8) {
  $$0 = 1;
  return ($$0|0);
 }
 $9 = ((($0)) + 48|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ((($1)) + 48|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($10>>>0)<($12>>>0);
 if ($13) {
  $$0 = -1;
  return ($$0|0);
 }
 $14 = ($12>>>0)<($10>>>0);
 if ($14) {
  $$0 = 1;
  return ($$0|0);
 }
 $15 = ((($0)) + 12|0);
 $16 = ((($1)) + 12|0);
 $17 = ((($16)) + 11|0);
 $18 = HEAP8[$17>>0]|0;
 $19 = ($18<<24>>24)<(0);
 $20 = ((($1)) + 16|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = $18&255;
 $23 = $19 ? $21 : $22;
 $24 = ((($15)) + 11|0);
 $25 = HEAP8[$24>>0]|0;
 $26 = ($25<<24>>24)<(0);
 $27 = ((($0)) + 16|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = $25&255;
 $30 = $26 ? $28 : $29;
 $31 = ($23>>>0)<($30>>>0);
 $$sroa$speculated$i$i$i = $31 ? $23 : $30;
 $32 = ($$sroa$speculated$i$i$i|0)==(0);
 if ($32) {
  label = 8;
 } else {
  $33 = HEAP32[$15>>2]|0;
  $34 = $26 ? $33 : $15;
  $35 = HEAP32[$16>>2]|0;
  $36 = $19 ? $35 : $16;
  $37 = (_memcmp($34,$36,$$sroa$speculated$i$i$i)|0);
  $38 = ($37|0)==(0);
  if ($38) {
   label = 8;
  } else {
   $40 = ($37|0)<(0);
   if ($40) {
    $$0 = -1;
    return ($$0|0);
   }
  }
 }
 if ((label|0) == 8) {
  $39 = ($30>>>0)<($23>>>0);
  if ($39) {
   $$0 = -1;
   return ($$0|0);
  }
 }
 $41 = ($30>>>0)<($23>>>0);
 $$sroa$speculated$i$i$i9 = $41 ? $30 : $23;
 $42 = ($$sroa$speculated$i$i$i9|0)==(0);
 if ($42) {
  label = 12;
 } else {
  $43 = HEAP32[$16>>2]|0;
  $44 = $19 ? $43 : $16;
  $45 = HEAP32[$15>>2]|0;
  $46 = $26 ? $45 : $15;
  $47 = (_memcmp($44,$46,$$sroa$speculated$i$i$i9)|0);
  $48 = ($47|0)==(0);
  if ($48) {
   label = 12;
  } else {
   $49 = ($47|0)<(0);
   if ($49) {
    $$0 = 1;
    return ($$0|0);
   }
  }
 }
 if ((label|0) == 12) {
  if ($31) {
   $$0 = 1;
   return ($$0|0);
  }
 }
 $50 = HEAP32[$0>>2]|0;
 $51 = ((($50)) + 144|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = (FUNCTION_TABLE_iii[$52 & 8191]($0,$1)|0);
 $$0 = $53;
 return ($$0|0);
}
function __ZNK3osg7Uniform11compareDataERKS0_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0;
 var $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $14 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 56|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = ((($1)) + 56|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==(0|0);
  if ($7) {
   $$0 = 1;
   return ($$0|0);
  }
  $8 = ($3|0)==($6|0);
  if ($8) {
   $$0 = 0;
   return ($$0|0);
  }
  $9 = HEAP32[$3>>2]|0;
  $10 = ((($9)) + 140|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (FUNCTION_TABLE_ii[$11 & 8191]($3)|0);
  $13 = HEAP32[$5>>2]|0;
  $14 = HEAP32[$13>>2]|0;
  $15 = ((($14)) + 140|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (FUNCTION_TABLE_ii[$16 & 8191]($13)|0);
  $18 = HEAP32[$2>>2]|0;
  $19 = HEAP32[$18>>2]|0;
  $20 = ((($19)) + 144|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = (FUNCTION_TABLE_ii[$21 & 8191]($18)|0);
  $23 = (_memcmp($12,$17,$22)|0);
  $$0 = $23;
  return ($$0|0);
 }
 $24 = ((($0)) + 60|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)==(0|0);
 if (!($26)) {
  $27 = ((($1)) + 60|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = ($28|0)==(0|0);
  if ($29) {
   $$0 = 1;
   return ($$0|0);
  }
  $30 = ($25|0)==($28|0);
  if ($30) {
   $$0 = 0;
   return ($$0|0);
  }
  $31 = HEAP32[$25>>2]|0;
  $32 = ((($31)) + 140|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = (FUNCTION_TABLE_ii[$33 & 8191]($25)|0);
  $35 = HEAP32[$27>>2]|0;
  $36 = HEAP32[$35>>2]|0;
  $37 = ((($36)) + 140|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = (FUNCTION_TABLE_ii[$38 & 8191]($35)|0);
  $40 = HEAP32[$24>>2]|0;
  $41 = HEAP32[$40>>2]|0;
  $42 = ((($41)) + 144|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = (FUNCTION_TABLE_ii[$43 & 8191]($40)|0);
  $45 = (_memcmp($34,$39,$44)|0);
  $$0 = $45;
  return ($$0|0);
 }
 $46 = ((($0)) + 64|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = ($47|0)==(0|0);
 if (!($48)) {
  $49 = ((($1)) + 64|0);
  $50 = HEAP32[$49>>2]|0;
  $51 = ($50|0)==(0|0);
  if ($51) {
   $$0 = 1;
   return ($$0|0);
  }
  $52 = ($47|0)==($50|0);
  if ($52) {
   $$0 = 0;
   return ($$0|0);
  }
  $53 = HEAP32[$47>>2]|0;
  $54 = ((($53)) + 140|0);
  $55 = HEAP32[$54>>2]|0;
  $56 = (FUNCTION_TABLE_ii[$55 & 8191]($47)|0);
  $57 = HEAP32[$49>>2]|0;
  $58 = HEAP32[$57>>2]|0;
  $59 = ((($58)) + 140|0);
  $60 = HEAP32[$59>>2]|0;
  $61 = (FUNCTION_TABLE_ii[$60 & 8191]($57)|0);
  $62 = HEAP32[$46>>2]|0;
  $63 = HEAP32[$62>>2]|0;
  $64 = ((($63)) + 144|0);
  $65 = HEAP32[$64>>2]|0;
  $66 = (FUNCTION_TABLE_ii[$65 & 8191]($62)|0);
  $67 = (_memcmp($56,$61,$66)|0);
  $$0 = $67;
  return ($$0|0);
 }
 $68 = ((($0)) + 68|0);
 $69 = HEAP32[$68>>2]|0;
 $70 = ($69|0)==(0|0);
 if (!($70)) {
  $71 = ((($1)) + 68|0);
  $72 = HEAP32[$71>>2]|0;
  $73 = ($72|0)==(0|0);
  if ($73) {
   $$0 = 1;
   return ($$0|0);
  }
  $74 = ($69|0)==($72|0);
  if ($74) {
   $$0 = 0;
   return ($$0|0);
  }
  $75 = HEAP32[$69>>2]|0;
  $76 = ((($75)) + 140|0);
  $77 = HEAP32[$76>>2]|0;
  $78 = (FUNCTION_TABLE_ii[$77 & 8191]($69)|0);
  $79 = HEAP32[$71>>2]|0;
  $80 = HEAP32[$79>>2]|0;
  $81 = ((($80)) + 140|0);
  $82 = HEAP32[$81>>2]|0;
  $83 = (FUNCTION_TABLE_ii[$82 & 8191]($79)|0);
  $84 = HEAP32[$68>>2]|0;
  $85 = HEAP32[$84>>2]|0;
  $86 = ((($85)) + 144|0);
  $87 = HEAP32[$86>>2]|0;
  $88 = (FUNCTION_TABLE_ii[$87 & 8191]($84)|0);
  $89 = (_memcmp($78,$83,$88)|0);
  $$0 = $89;
  return ($$0|0);
 }
 $90 = ((($0)) + 76|0);
 $91 = HEAP32[$90>>2]|0;
 $92 = ($91|0)==(0|0);
 if (!($92)) {
  $93 = ((($1)) + 76|0);
  $94 = HEAP32[$93>>2]|0;
  $95 = ($94|0)==(0|0);
  if ($95) {
   $$0 = 1;
   return ($$0|0);
  }
  $96 = ($91|0)==($94|0);
  if ($96) {
   $$0 = 0;
   return ($$0|0);
  }
  $97 = HEAP32[$91>>2]|0;
  $98 = ((($97)) + 140|0);
  $99 = HEAP32[$98>>2]|0;
  $100 = (FUNCTION_TABLE_ii[$99 & 8191]($91)|0);
  $101 = HEAP32[$93>>2]|0;
  $102 = HEAP32[$101>>2]|0;
  $103 = ((($102)) + 140|0);
  $104 = HEAP32[$103>>2]|0;
  $105 = (FUNCTION_TABLE_ii[$104 & 8191]($101)|0);
  $106 = HEAP32[$90>>2]|0;
  $107 = HEAP32[$106>>2]|0;
  $108 = ((($107)) + 144|0);
  $109 = HEAP32[$108>>2]|0;
  $110 = (FUNCTION_TABLE_ii[$109 & 8191]($106)|0);
  $111 = (_memcmp($100,$105,$110)|0);
  $$0 = $111;
  return ($$0|0);
 }
 $112 = ((($0)) + 72|0);
 $113 = HEAP32[$112>>2]|0;
 $114 = ($113|0)==(0|0);
 if ($114) {
  $$0 = -1;
  return ($$0|0);
 }
 $115 = ((($1)) + 72|0);
 $116 = HEAP32[$115>>2]|0;
 $117 = ($116|0)==(0|0);
 if ($117) {
  $$0 = 1;
  return ($$0|0);
 }
 $118 = ($113|0)==($116|0);
 if ($118) {
  $$0 = 0;
  return ($$0|0);
 }
 $119 = HEAP32[$113>>2]|0;
 $120 = ((($119)) + 140|0);
 $121 = HEAP32[$120>>2]|0;
 $122 = (FUNCTION_TABLE_ii[$121 & 8191]($113)|0);
 $123 = HEAP32[$115>>2]|0;
 $124 = HEAP32[$123>>2]|0;
 $125 = ((($124)) + 140|0);
 $126 = HEAP32[$125>>2]|0;
 $127 = (FUNCTION_TABLE_ii[$126 & 8191]($123)|0);
 $128 = HEAP32[$112>>2]|0;
 $129 = HEAP32[$128>>2]|0;
 $130 = ((($129)) + 144|0);
 $131 = HEAP32[$130>>2]|0;
 $132 = (FUNCTION_TABLE_ii[$131 & 8191]($128)|0);
 $133 = (_memcmp($122,$127,$132)|0);
 $$0 = $133;
 return ($$0|0);
}
function __ZN3osg7Uniform9getNameIDERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE($0) {
 $0 = $0|0;
 var $$0 = 0, $$04 = 0, $$08 = 0, $$2 = 0, $$26 = 0, $$3 = 0, $$37 = 0, $$pre$i$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $1 = sp + 16|0;
 $2 = sp;
 $3 = HEAP8[206120]|0;
 $4 = ($3<<24>>24)==(0);
 do {
  if ($4) {
   $5 = (___cxa_guard_acquire(206120)|0);
   $6 = ($5|0)==(0);
   if (!($6)) {
    __THREW__ = 0;
    invoke_vii(3507,(208740|0),0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     (___cxa_atexit((707|0),(208740|0),(___dso_handle|0))|0);
     break;
    }
    $22 = ___cxa_find_matching_catch_2()|0;
    $23 = tempRet0;
    $$3 = $23;$$37 = $22;
    ___resumeException($$37|0);
    // unreachable;
   }
  }
 } while(0);
 $9 = HEAP8[206128]|0;
 $10 = ($9<<24>>24)==(0);
 if ($10) {
  $11 = (___cxa_guard_acquire(206128)|0);
  $12 = ($11|0)==(0);
  if (!($12)) {
   HEAP32[(208756)>>2] = 0;
   HEAP32[(208760)>>2] = 0;
   HEAP32[52188] = (208756);
   (___cxa_atexit((3990|0),(208752|0),(___dso_handle|0))|0);
  }
 }
 $13 = HEAP32[52185]|0;
 $14 = ((($13)) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 (FUNCTION_TABLE_ii[$15 & 8191](208740)|0);
 __THREW__ = 0;
 $16 = (invoke_iii(3991,(208752|0),($0|0))|0);
 $17 = __THREW__; __THREW__ = 0;
 $18 = $17&1;
 if ($18) {
  $24 = ___cxa_find_matching_catch_2()|0;
  $25 = tempRet0;
  $$2 = $25;$$26 = $24;
 } else {
  $19 = ($16|0)==((208756)|0);
  if (!($19)) {
   $20 = ((($16)) + 28|0);
   $21 = HEAP32[$20>>2]|0;
   $$08 = $21;
   $68 = HEAP32[52185]|0;
   $69 = ((($68)) + 12|0);
   $70 = HEAP32[$69>>2]|0;
   (FUNCTION_TABLE_ii[$70 & 8191](208740)|0);
   STACKTOP = sp;return ($$08|0);
  }
  $26 = HEAP32[(208760)>>2]|0;
  __THREW__ = 0;
  invoke_vii(3457,($2|0),($0|0));
  $27 = __THREW__; __THREW__ = 0;
  $28 = $27&1;
  if ($28) {
   $60 = ___cxa_find_matching_catch_2()|0;
   $61 = tempRet0;
   $$0 = $61;$$04 = $60;
  } else {
   $29 = ((($2)) + 12|0);
   HEAP32[$29>>2] = $26;
   __THREW__ = 0;
   $30 = (invoke_iiii(3992,(208752|0),($1|0),($2|0))|0);
   $31 = __THREW__; __THREW__ = 0;
   $32 = $31&1;
   do {
    if ($32) {
     label = 26;
    } else {
     $33 = HEAP32[$30>>2]|0;
     $34 = ($33|0)==(0|0);
     if ($34) {
      __THREW__ = 0;
      $35 = (invoke_ii(3276,32)|0);
      $36 = __THREW__; __THREW__ = 0;
      $37 = $36&1;
      if ($37) {
       label = 26;
       break;
      }
      $38 = ((($35)) + 16|0);
      __THREW__ = 0;
      invoke_vii(3457,($38|0),($2|0));
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if ($40) {
       $41 = ___cxa_find_matching_catch_2()|0;
       $42 = tempRet0;
       __ZdlPv($35);
       $eh$lpad$body$index2Z2D = $42;$eh$lpad$body$indexZ2D = $41;
       break;
      }
      $43 = ((($35)) + 28|0);
      $44 = HEAP32[$29>>2]|0;
      HEAP32[$43>>2] = $44;
      $45 = HEAP32[$1>>2]|0;
      HEAP32[$35>>2] = 0;
      $46 = ((($35)) + 4|0);
      HEAP32[$46>>2] = 0;
      $47 = ((($35)) + 8|0);
      HEAP32[$47>>2] = $45;
      HEAP32[$30>>2] = $35;
      $48 = HEAP32[52188]|0;
      $49 = HEAP32[$48>>2]|0;
      $50 = ($49|0)==(0|0);
      if ($50) {
       $53 = $35;
      } else {
       $51 = $49;
       HEAP32[52188] = $51;
       $$pre$i$i$i$i = HEAP32[$30>>2]|0;
       $53 = $$pre$i$i$i$i;
      }
      $52 = HEAP32[(208756)>>2]|0;
      __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($52,$53);
      $54 = HEAP32[(208760)>>2]|0;
      $55 = (($54) + 1)|0;
      HEAP32[(208760)>>2] = $55;
     }
     $56 = ((($2)) + 11|0);
     $57 = HEAP8[$56>>0]|0;
     $58 = ($57<<24>>24)<(0);
     if ($58) {
      $59 = HEAP32[$2>>2]|0;
      __ZdlPv($59);
     }
     $$08 = $26;
     $68 = HEAP32[52185]|0;
     $69 = ((($68)) + 12|0);
     $70 = HEAP32[$69>>2]|0;
     (FUNCTION_TABLE_ii[$70 & 8191](208740)|0);
     STACKTOP = sp;return ($$08|0);
    }
   } while(0);
   if ((label|0) == 26) {
    $62 = ___cxa_find_matching_catch_2()|0;
    $63 = tempRet0;
    $eh$lpad$body$index2Z2D = $63;$eh$lpad$body$indexZ2D = $62;
   }
   $64 = ((($2)) + 11|0);
   $65 = HEAP8[$64>>0]|0;
   $66 = ($65<<24>>24)<(0);
   if ($66) {
    $67 = HEAP32[$2>>2]|0;
    __ZdlPv($67);
    $$0 = $eh$lpad$body$index2Z2D;$$04 = $eh$lpad$body$indexZ2D;
   } else {
    $$0 = $eh$lpad$body$index2Z2D;$$04 = $eh$lpad$body$indexZ2D;
   }
  }
  $$2 = $$0;$$26 = $$04;
 }
 $71 = HEAP32[52185]|0;
 $72 = ((($71)) + 12|0);
 $73 = HEAP32[$72>>2]|0;
 __THREW__ = 0;
 (invoke_ii($73|0,(208740|0))|0);
 $74 = __THREW__; __THREW__ = 0;
 $75 = $74&1;
 if ($75) {
  $76 = ___cxa_find_matching_catch_3(0|0)|0;
  $77 = tempRet0;
  ___clang_call_terminate($76);
  // unreachable;
 } else {
  $$3 = $$2;$$37 = $$26;
  ___resumeException($$37|0);
  // unreachable;
 }
 return (0)|0;
}
function __ZNSt3__23mapINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEjNS_4lessIS6_EENS4_INS_4pairIKS6_jEEEEED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEjEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($0,$2);
 return;
}
function __ZN3osg7UniformC2ERKS0_RKNS_6CopyOpE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$010 = 0, $$1 = 0, $$111 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $scevgep$i$i$i = 0, $scevgep5$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg6ObjectC2ERKS0_RKNS_6CopyOpE($0,$1,$2);
 HEAP32[$0>>2] = (69328);
 $3 = ((($0)) + 32|0);
 HEAP32[$3>>2] = 0;
 $4 = ((($0)) + 36|0);
 HEAP32[$4>>2] = 0;
 $5 = ((($0)) + 40|0);
 HEAP32[$5>>2] = 0;
 $6 = ((($0)) + 44|0);
 $7 = ((($1)) + 44|0);
 $8 = HEAP32[$7>>2]|0;
 HEAP32[$6>>2] = $8;
 $9 = ((($0)) + 56|0);
 $10 = ((($0)) + 60|0);
 $11 = ((($0)) + 64|0);
 $12 = ((($0)) + 68|0);
 $13 = ((($0)) + 72|0);
 $14 = ((($0)) + 76|0);
 ;HEAP32[$9>>2]=0|0;HEAP32[$9+4>>2]=0|0;HEAP32[$9+8>>2]=0|0;HEAP32[$9+12>>2]=0|0;HEAP32[$9+16>>2]=0|0;HEAP32[$9+20>>2]=0|0;
 $15 = HEAP32[$2>>2]|0;
 $16 = ((($15)) + 64|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ((($1)) + 80|0);
 $19 = HEAP32[$18>>2]|0;
 __THREW__ = 0;
 $20 = (invoke_iii($17|0,($2|0),($19|0))|0);
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if ($22) {
  $49 = ___cxa_find_matching_catch_2()|0;
  $50 = tempRet0;
  $$1 = $50;$$111 = $49;
 } else {
  $23 = ((($0)) + 80|0);
  HEAP32[$23>>2] = $20;
  $24 = ($20|0)==(0|0);
  if (!($24)) {
   $25 = HEAP32[$20>>2]|0;
   $26 = ((($25)) + -16|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = (($20) + ($27)|0);
   $29 = ((($28)) + 8|0);
   $30 = HEAP32[$29>>2]|0;HEAP32[$29>>2] = (($30+1)|0);
  }
  $31 = HEAP32[$2>>2]|0;
  $32 = ((($31)) + 64|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = ((($1)) + 84|0);
  $35 = HEAP32[$34>>2]|0;
  __THREW__ = 0;
  $36 = (invoke_iii($33|0,($2|0),($35|0))|0);
  $37 = __THREW__; __THREW__ = 0;
  $38 = $37&1;
  if ($38) {
   $51 = ___cxa_find_matching_catch_2()|0;
   $52 = tempRet0;
   $$0 = $52;$$010 = $51;
  } else {
   $39 = ((($0)) + 84|0);
   HEAP32[$39>>2] = $36;
   $40 = ($36|0)==(0|0);
   if (!($40)) {
    $41 = HEAP32[$36>>2]|0;
    $42 = ((($41)) + -16|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = (($36) + ($43)|0);
    $45 = ((($44)) + 8|0);
    $46 = HEAP32[$45>>2]|0;HEAP32[$45>>2] = (($46+1)|0);
   }
   __THREW__ = 0;
   invoke_vii(3993,($0|0),($1|0));
   $47 = __THREW__; __THREW__ = 0;
   $48 = $47&1;
   if (!($48)) {
    return;
   }
   $53 = ___cxa_find_matching_catch_2()|0;
   $54 = tempRet0;
   $55 = HEAP32[$39>>2]|0;
   $56 = ($55|0)==(0|0);
   if (!($56)) {
    $57 = HEAP32[$55>>2]|0;
    $58 = ((($57)) + -16|0);
    $59 = HEAP32[$58>>2]|0;
    $60 = (($55) + ($59)|0);
    $61 = ((($60)) + 8|0);
    $62 = HEAP32[$61>>2]|0;HEAP32[$61>>2] = (($62-1)|0);
    $63 = ($62|0)==(1);
    if ($63) {
     __THREW__ = 0;
     invoke_viii(3262,($60|0),1,1);
     $64 = __THREW__; __THREW__ = 0;
     $65 = $64&1;
     if ($65) {
      $130 = ___cxa_find_matching_catch_3(0|0)|0;
      $131 = tempRet0;
      ___clang_call_terminate($130);
      // unreachable;
     }
    }
   }
   HEAP32[$39>>2] = 0;
   $$0 = $54;$$010 = $53;
  }
  $66 = HEAP32[$23>>2]|0;
  $67 = ($66|0)==(0|0);
  if (!($67)) {
   $68 = HEAP32[$66>>2]|0;
   $69 = ((($68)) + -16|0);
   $70 = HEAP32[$69>>2]|0;
   $71 = (($66) + ($70)|0);
   $72 = ((($71)) + 8|0);
   $73 = HEAP32[$72>>2]|0;HEAP32[$72>>2] = (($73-1)|0);
   $74 = ($73|0)==(1);
   if ($74) {
    __THREW__ = 0;
    invoke_viii(3262,($71|0),1,1);
    $75 = __THREW__; __THREW__ = 0;
    $76 = $75&1;
    if ($76) {
     $130 = ___cxa_find_matching_catch_3(0|0)|0;
     $131 = tempRet0;
     ___clang_call_terminate($130);
     // unreachable;
    }
   }
  }
  HEAP32[$23>>2] = 0;
  $$1 = $$0;$$111 = $$010;
 }
 $77 = HEAP32[$14>>2]|0;
 $78 = ($77|0)==(0|0);
 if (!($78)) {
  $79 = ((($77)) + 8|0);
  $80 = HEAP32[$79>>2]|0;HEAP32[$79>>2] = (($80-1)|0);
  $81 = ($80|0)==(1);
  if ($81) {
   __THREW__ = 0;
   invoke_viii(3262,($77|0),1,1);
   $82 = __THREW__; __THREW__ = 0;
   $83 = $82&1;
   if ($83) {
    $130 = ___cxa_find_matching_catch_3(0|0)|0;
    $131 = tempRet0;
    ___clang_call_terminate($130);
    // unreachable;
   }
  }
 }
 HEAP32[$14>>2] = 0;
 $84 = HEAP32[$13>>2]|0;
 $85 = ($84|0)==(0|0);
 if (!($85)) {
  $86 = ((($84)) + 8|0);
  $87 = HEAP32[$86>>2]|0;HEAP32[$86>>2] = (($87-1)|0);
  $88 = ($87|0)==(1);
  if ($88) {
   __THREW__ = 0;
   invoke_viii(3262,($84|0),1,1);
   $89 = __THREW__; __THREW__ = 0;
   $90 = $89&1;
   if ($90) {
    $130 = ___cxa_find_matching_catch_3(0|0)|0;
    $131 = tempRet0;
    ___clang_call_terminate($130);
    // unreachable;
   }
  }
 }
 HEAP32[$13>>2] = 0;
 $91 = HEAP32[$12>>2]|0;
 $92 = ($91|0)==(0|0);
 if (!($92)) {
  $93 = ((($91)) + 8|0);
  $94 = HEAP32[$93>>2]|0;HEAP32[$93>>2] = (($94-1)|0);
  $95 = ($94|0)==(1);
  if ($95) {
   __THREW__ = 0;
   invoke_viii(3262,($91|0),1,1);
   $96 = __THREW__; __THREW__ = 0;
   $97 = $96&1;
   if ($97) {
    $130 = ___cxa_find_matching_catch_3(0|0)|0;
    $131 = tempRet0;
    ___clang_call_terminate($130);
    // unreachable;
   }
  }
 }
 HEAP32[$12>>2] = 0;
 $98 = HEAP32[$11>>2]|0;
 $99 = ($98|0)==(0|0);
 if (!($99)) {
  $100 = ((($98)) + 8|0);
  $101 = HEAP32[$100>>2]|0;HEAP32[$100>>2] = (($101-1)|0);
  $102 = ($101|0)==(1);
  if ($102) {
   __THREW__ = 0;
   invoke_viii(3262,($98|0),1,1);
   $103 = __THREW__; __THREW__ = 0;
   $104 = $103&1;
   if ($104) {
    $130 = ___cxa_find_matching_catch_3(0|0)|0;
    $131 = tempRet0;
    ___clang_call_terminate($130);
    // unreachable;
   }
  }
 }
 HEAP32[$11>>2] = 0;
 $105 = HEAP32[$10>>2]|0;
 $106 = ($105|0)==(0|0);
 if (!($106)) {
  $107 = ((($105)) + 8|0);
  $108 = HEAP32[$107>>2]|0;HEAP32[$107>>2] = (($108-1)|0);
  $109 = ($108|0)==(1);
  if ($109) {
   __THREW__ = 0;
   invoke_viii(3262,($105|0),1,1);
   $110 = __THREW__; __THREW__ = 0;
   $111 = $110&1;
   if ($111) {
    $130 = ___cxa_find_matching_catch_3(0|0)|0;
    $131 = tempRet0;
    ___clang_call_terminate($130);
    // unreachable;
   }
  }
 }
 HEAP32[$10>>2] = 0;
 $112 = HEAP32[$9>>2]|0;
 $113 = ($112|0)==(0|0);
 if (!($113)) {
  $114 = ((($112)) + 8|0);
  $115 = HEAP32[$114>>2]|0;HEAP32[$114>>2] = (($115-1)|0);
  $116 = ($115|0)==(1);
  if ($116) {
   __THREW__ = 0;
   invoke_viii(3262,($112|0),1,1);
   $117 = __THREW__; __THREW__ = 0;
   $118 = $117&1;
   if ($118) {
    $130 = ___cxa_find_matching_catch_3(0|0)|0;
    $131 = tempRet0;
    ___clang_call_terminate($130);
    // unreachable;
   }
  }
 }
 HEAP32[$9>>2] = 0;
 $119 = HEAP32[$3>>2]|0;
 $120 = ($119|0)==(0|0);
 if (!($120)) {
  $121 = HEAP32[$4>>2]|0;
  $122 = ($121|0)==($119|0);
  if (!($122)) {
   $scevgep$i$i$i = ((($121)) + -4|0);
   $123 = $scevgep$i$i$i;
   $124 = $119;
   $125 = (($123) - ($124))|0;
   $126 = $125 >>> 2;
   $127 = $126 ^ -1;
   $scevgep5$i$i$i = (($121) + ($127<<2)|0);
   HEAP32[$4>>2] = $scevgep5$i$i$i;
  }
  __ZdlPv($119);
 }
 __THREW__ = 0;
 invoke_vi(388,($0|0));
 $128 = __THREW__; __THREW__ = 0;
 $129 = $128&1;
 if ($129) {
  $130 = ___cxa_find_matching_catch_3(0|0)|0;
  $131 = tempRet0;
  ___clang_call_terminate($130);
  // unreachable;
 } else {
  ___resumeException($$111|0);
  // unreachable;
 }
}
function __ZN3osg7Uniform8copyDataERKS0_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $$byval_copy10 = 0, $$byval_copy11 = 0, $$byval_copy2 = 0, $$byval_copy3 = 0, $$byval_copy4 = 0, $$byval_copy5 = 0, $$byval_copy6 = 0, $$byval_copy7 = 0, $$byval_copy8 = 0, $$byval_copy9 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $11 = 0;
 var $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $or$cond19 = 0, $or$cond20 = 0, $or$cond21 = 0;
 var $or$cond22 = 0, $or$cond23 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(96|0);
 $$byval_copy11 = sp + 92|0;
 $$byval_copy10 = sp + 88|0;
 $$byval_copy9 = sp + 84|0;
 $$byval_copy8 = sp + 80|0;
 $$byval_copy7 = sp + 76|0;
 $$byval_copy6 = sp + 72|0;
 $$byval_copy5 = sp + 68|0;
 $$byval_copy4 = sp + 64|0;
 $$byval_copy3 = sp + 60|0;
 $$byval_copy2 = sp + 56|0;
 $$byval_copy1 = sp + 52|0;
 $$byval_copy = sp + 48|0;
 $2 = sp + 44|0;
 $3 = sp + 40|0;
 $4 = sp + 36|0;
 $5 = sp + 32|0;
 $6 = sp + 28|0;
 $7 = sp + 24|0;
 $8 = sp + 20|0;
 $9 = sp + 16|0;
 $10 = sp + 12|0;
 $11 = sp + 8|0;
 $12 = sp + 4|0;
 $13 = sp;
 $14 = ((($1)) + 48|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ((($0)) + 48|0);
 HEAP32[$16>>2] = $15;
 $17 = ((($1)) + 52|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ((($0)) + 52|0);
 HEAP32[$19>>2] = $18;
 $20 = ((($1)) + 56|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0|0);
 if ($22) {
  $23 = ((($1)) + 60|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = ($24|0)==(0|0);
  if ($25) {
   $26 = ((($1)) + 64|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = ($27|0)==(0|0);
   if ($28) {
    $29 = ((($1)) + 68|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = ($30|0)==(0|0);
    if (!($31)) {
     label = 5;
    }
   } else {
    label = 5;
   }
  } else {
   label = 5;
  }
 } else {
  label = 5;
 }
 if ((label|0) == 5) {
  __ZN3osg7Uniform17allocateDataArrayEv($0);
 }
 $32 = ((($0)) + 56|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ($33|0)==(0|0);
 if (!($34)) {
  $35 = HEAP32[$20>>2]|0;
  $36 = ($35|0)==(0|0);
  $37 = ($33|0)==($35|0);
  $or$cond = $36 | $37;
  if (!($or$cond)) {
   $38 = ((($35)) + 76|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = ((($35)) + 80|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = ((($33)) + 76|0);
   HEAP32[$2>>2] = $39;
   HEAP32[$3>>2] = $41;
   ;HEAP32[$$byval_copy>>2]=HEAP32[$2>>2]|0;
   ;HEAP32[$$byval_copy1>>2]=HEAP32[$3>>2]|0;
   __ZNSt3__26vectorIfNS_9allocatorIfEEE6assignINS_11__wrap_iterIPKfEEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIfNS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_($42,$$byval_copy,$$byval_copy1);
  }
 }
 $43 = ((($0)) + 60|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = ($44|0)==(0|0);
 if (!($45)) {
  $46 = ((($1)) + 60|0);
  $47 = HEAP32[$46>>2]|0;
  $48 = ($47|0)==(0|0);
  $49 = ($44|0)==($47|0);
  $or$cond19 = $48 | $49;
  if (!($or$cond19)) {
   $50 = ((($47)) + 76|0);
   $51 = HEAP32[$50>>2]|0;
   $52 = ((($47)) + 80|0);
   $53 = HEAP32[$52>>2]|0;
   $54 = ((($44)) + 76|0);
   HEAP32[$4>>2] = $51;
   HEAP32[$5>>2] = $53;
   ;HEAP32[$$byval_copy2>>2]=HEAP32[$4>>2]|0;
   ;HEAP32[$$byval_copy3>>2]=HEAP32[$5>>2]|0;
   __ZNSt3__26vectorIdNS_9allocatorIdEEE6assignINS_11__wrap_iterIPKdEEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIdNS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_($54,$$byval_copy2,$$byval_copy3);
  }
 }
 $55 = ((($0)) + 64|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = ($56|0)==(0|0);
 if (!($57)) {
  $58 = ((($1)) + 64|0);
  $59 = HEAP32[$58>>2]|0;
  $60 = ($59|0)==(0|0);
  $61 = ($56|0)==($59|0);
  $or$cond20 = $60 | $61;
  if (!($or$cond20)) {
   $62 = ((($59)) + 76|0);
   $63 = HEAP32[$62>>2]|0;
   $64 = ((($59)) + 80|0);
   $65 = HEAP32[$64>>2]|0;
   $66 = ((($56)) + 76|0);
   HEAP32[$6>>2] = $63;
   HEAP32[$7>>2] = $65;
   ;HEAP32[$$byval_copy4>>2]=HEAP32[$6>>2]|0;
   ;HEAP32[$$byval_copy5>>2]=HEAP32[$7>>2]|0;
   __ZNSt3__26vectorIiNS_9allocatorIiEEE6assignINS_11__wrap_iterIPKiEEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIiNS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_($66,$$byval_copy4,$$byval_copy5);
  }
 }
 $67 = ((($0)) + 68|0);
 $68 = HEAP32[$67>>2]|0;
 $69 = ($68|0)==(0|0);
 if (!($69)) {
  $70 = ((($1)) + 68|0);
  $71 = HEAP32[$70>>2]|0;
  $72 = ($71|0)==(0|0);
  $73 = ($68|0)==($71|0);
  $or$cond21 = $72 | $73;
  if (!($or$cond21)) {
   $74 = ((($71)) + 76|0);
   $75 = HEAP32[$74>>2]|0;
   $76 = ((($71)) + 80|0);
   $77 = HEAP32[$76>>2]|0;
   $78 = ((($68)) + 76|0);
   HEAP32[$8>>2] = $75;
   HEAP32[$9>>2] = $77;
   ;HEAP32[$$byval_copy6>>2]=HEAP32[$8>>2]|0;
   ;HEAP32[$$byval_copy7>>2]=HEAP32[$9>>2]|0;
   __ZNSt3__26vectorIjNS_9allocatorIjEEE6assignINS_11__wrap_iterIPKjEEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIjNS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_($78,$$byval_copy6,$$byval_copy7);
  }
 }
 $79 = ((($0)) + 72|0);
 $80 = HEAP32[$79>>2]|0;
 $81 = ($80|0)==(0|0);
 if (!($81)) {
  $82 = ((($1)) + 72|0);
  $83 = HEAP32[$82>>2]|0;
  $84 = ($83|0)==(0|0);
  $85 = ($80|0)==($83|0);
  $or$cond22 = $84 | $85;
  if (!($or$cond22)) {
   $86 = ((($83)) + 76|0);
   $87 = HEAP32[$86>>2]|0;
   $88 = ((($83)) + 80|0);
   $89 = HEAP32[$88>>2]|0;
   $90 = ((($80)) + 76|0);
   HEAP32[$10>>2] = $87;
   HEAP32[$11>>2] = $89;
   ;HEAP32[$$byval_copy8>>2]=HEAP32[$10>>2]|0;
   ;HEAP32[$$byval_copy9>>2]=HEAP32[$11>>2]|0;
   __ZNSt3__26vectorIxNS_9allocatorIxEEE6assignINS_11__wrap_iterIPKxEEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIxNS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_($90,$$byval_copy8,$$byval_copy9);
  }
 }
 $91 = ((($0)) + 76|0);
 $92 = HEAP32[$91>>2]|0;
 $93 = ($92|0)==(0|0);
 if ($93) {
  $103 = ((($0)) + 88|0);
  $104 = HEAP32[$103>>2]|0;
  $105 = (($104) + 1)|0;
  HEAP32[$103>>2] = $105;
  STACKTOP = sp;return;
 }
 $94 = ((($1)) + 76|0);
 $95 = HEAP32[$94>>2]|0;
 $96 = ($95|0)==(0|0);
 $97 = ($92|0)==($95|0);
 $or$cond23 = $96 | $97;
 if ($or$cond23) {
  $103 = ((($0)) + 88|0);
  $104 = HEAP32[$103>>2]|0;
  $105 = (($104) + 1)|0;
  HEAP32[$103>>2] = $105;
  STACKTOP = sp;return;
 }
 $98 = ((($95)) + 76|0);
 $99 = HEAP32[$98>>2]|0;
 $100 = ((($95)) + 80|0);
 $101 = HEAP32[$100>>2]|0;
 $102 = ((($92)) + 76|0);
 HEAP32[$12>>2] = $99;
 HEAP32[$13>>2] = $101;
 ;HEAP32[$$byval_copy10>>2]=HEAP32[$12>>2]|0;
 ;HEAP32[$$byval_copy11>>2]=HEAP32[$13>>2]|0;
 __ZNSt3__26vectorIyNS_9allocatorIyEEE6assignINS_11__wrap_iterIPKyEEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIyNS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_($102,$$byval_copy10,$$byval_copy11);
 $103 = ((($0)) + 88|0);
 $104 = HEAP32[$103>>2]|0;
 $105 = (($104) + 1)|0;
 HEAP32[$103>>2] = $105;
 STACKTOP = sp;return;
}
function __ZN3osg7Uniform17allocateDataArrayEv($0) {
 $0 = $0|0;
 var $$0 = 0, $$0$i$i = 0, $$09 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index17Z2D = 0, $eh$lpad$body$indexZ2D = 0, $eh$lpad$body15$index2Z2D = 0, $eh$lpad$body15$indexZ2D = 0, $eh$lpad$body18$index7Z2D = 0, $eh$lpad$body18$indexZ2D = 0;
 var $eh$lpad$body21$index12Z2D = 0, $eh$lpad$body21$indexZ2D = 0, $scevgep$i$i = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i24 = 0, $scevgep$i$i$i$i$i31 = 0, $scevgep$i$i$i$i$i38 = 0, $scevgep5$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i25 = 0, $scevgep5$i$i$i$i$i32 = 0, $scevgep5$i$i$i$i$i39 = 0, $switch$split212D = 0, $switch$split242D = 0, $switch$split272D = 0, $switch$split2D = 0, $switch$split302D = 0, $switch$split332D = 0, $switch$split362D = 0, $switch$split392D = 0, $switch$split422D = 0;
 var $switch$split452D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 56|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  return;
 }
 $4 = ((($0)) + 60|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  return;
 }
 $7 = ((($0)) + 64|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if (!($9)) {
  return;
 }
 $10 = ((($0)) + 68|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0|0);
 if (!($12)) {
  return;
 }
 $13 = ((($0)) + 48|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(0);
 if ($15) {
  return;
 }
 $16 = ((($0)) + 44|0);
 $17 = HEAP32[$16>>2]|0;
 $switch$split2D = ($17|0)<(36311);
 L16: do {
  if ($switch$split2D) {
   $switch$split242D = ($17|0)<(35685);
   if (!($switch$split242D)) {
    switch ($17|0) {
    case 36309: case 36310: case 36308: case 36307: case 36306: case 36305: case 36301: case 36304: case 36303: case 36302: case 36300: case 36299: case 36298: case 36297: case 36290: case 36293: case 36292: case 36291: case 36289: case 36288:  {
     $$0$i$i = 1;
     break L16;
     break;
    }
    case 36294:  {
     label = 7;
     break L16;
     break;
    }
    case 36295:  {
     label = 8;
     break L16;
     break;
    }
    case 36296:  {
     label = 9;
     break L16;
     break;
    }
    case 35687: case 35685:  {
     label = 10;
     break L16;
     break;
    }
    case 35689: case 35686:  {
     label = 11;
     break L16;
     break;
    }
    case 35690: case 35688:  {
     label = 13;
     break L16;
     break;
    }
    default: {
     label = 15;
     break L16;
    }
    }
   }
   $switch$split302D = ($17|0)<(35671);
   if (!($switch$split302D)) {
    switch ($17|0) {
    case 35684: case 35683: case 35682: case 35681: case 35680: case 35679: case 35678: case 35677:  {
     $$0$i$i = 1;
     break L16;
     break;
    }
    case 35671:  {
     label = 7;
     break L16;
     break;
    }
    case 35672:  {
     label = 8;
     break L16;
     break;
    }
    case 35673: case 35674:  {
     label = 9;
     break L16;
     break;
    }
    case 35675:  {
     label = 12;
     break L16;
     break;
    }
    case 35676:  {
     label = 14;
     break L16;
     break;
    }
    default: {
     label = 15;
     break L16;
    }
    }
   }
   $switch$split362D = ($17|0)<(35664);
   if (!($switch$split362D)) {
    switch ($17|0) {
    case 35670:  {
     $$0$i$i = 1;
     break L16;
     break;
    }
    case 35667: case 35664:  {
     label = 7;
     break L16;
     break;
    }
    case 35668: case 35665:  {
     label = 8;
     break L16;
     break;
    }
    case 35669: case 35666:  {
     label = 9;
     break L16;
     break;
    }
    default: {
     label = 15;
     break L16;
    }
    }
   }
   switch ($17|0) {
   case 5134: case 5135: case 5125: case 5124: case 5130: case 5126:  {
    $$0$i$i = 1;
    break L16;
    break;
   }
   case 0:  {
    break;
   }
   default: {
    label = 15;
    break L16;
   }
   }
   return;
  } else {
   switch ($17|0) {
   case 36972: case 36971: case 36970: case 36969: case 36968: case 36967: case 36966: case 36965: case 36964: case 36963: case 36962: case 36961: case 36960: case 36959: case 36958: case 36957: case 36956: case 36955: case 36954: case 36953: case 36952: case 36951: case 36950: case 36949: case 36948: case 36947: case 36946: case 36945: case 36944: case 36943: case 36942: case 36941: case 36940: case 36312: case 37133: case 37130: case 36879: case 36311: case 37132: case 37129: case 36878: case 36877: case 37131: case 37128: case 36876:  {
    $$0$i$i = 1;
    break;
   }
   case 36860:  {
    label = 7;
    break;
   }
   case 36861:  {
    label = 8;
    break;
   }
   case 36678: case 36862:  {
    label = 9;
    break;
   }
   case 36683: case 36681:  {
    label = 10;
    break;
   }
   case 36685: case 36682:  {
    label = 11;
    break;
   }
   case 36679:  {
    label = 12;
    break;
   }
   case 36686: case 36684:  {
    label = 13;
    break;
   }
   case 36680:  {
    label = 14;
    break;
   }
   default: {
    label = 15;
   }
   }
  }
 } while(0);
 if ((label|0) == 7) {
  $$0$i$i = 2;
 }
 else if ((label|0) == 8) {
  $$0$i$i = 3;
 }
 else if ((label|0) == 9) {
  $$0$i$i = 4;
 }
 else if ((label|0) == 10) {
  $$0$i$i = 6;
 }
 else if ((label|0) == 11) {
  $$0$i$i = 8;
 }
 else if ((label|0) == 12) {
  $$0$i$i = 9;
 }
 else if ((label|0) == 13) {
  $$0$i$i = 12;
 }
 else if ((label|0) == 14) {
  $$0$i$i = 16;
 }
 else if ((label|0) == 15) {
  $$0$i$i = 0;
 }
 $18 = Math_imul($$0$i$i, $14)|0;
 $19 = ($18|0)==(0);
 if ($19) {
  return;
 }
 $switch$split212D = ($17|0)<(36312);
 L43: do {
  if ($switch$split212D) {
   $switch$split272D = ($17|0)<(35687);
   L45: do {
    if ($switch$split272D) {
     $switch$split332D = ($17|0)<(35673);
     if (!($switch$split332D)) {
      switch ($17|0) {
      case 35684: case 35683: case 35682: case 35681: case 35680: case 35679: case 35678: case 35677: case 35673:  {
       label = 50;
       break L43;
       break;
      }
      case 35686: case 35685: case 35676: case 35675: case 35674:  {
       label = 18;
       break L45;
       break;
      }
      default: {
      }
      }
      return;
     }
     $switch$split392D = ($17|0)<(35666);
     if (!($switch$split392D)) {
      switch ($17|0) {
      case 35672: case 35671: case 35670: case 35669: case 35668: case 35667:  {
       label = 50;
       break L43;
       break;
      }
      case 35666:  {
       label = 18;
       break L45;
       break;
      }
      default: {
      }
      }
      return;
     }
     $switch$split422D = ($17|0)<(5130);
     if ($switch$split422D) {
      switch ($17|0) {
      case 5124:  {
       label = 50;
       break L43;
       break;
      }
      case 5126:  {
       label = 18;
       break L45;
       break;
      }
      case 5125:  {
       label = 66;
       break L45;
       break;
      }
      default: {
      }
      }
      return;
     }
     $switch$split452D = ($17|0)<(35664);
     if ($switch$split452D) {
      switch ($17|0) {
      case 5130:  {
       label = 34;
       break L43;
       break;
      }
      default: {
      }
      }
      return;
     } else {
      switch ($17|0) {
      case 35665: case 35664:  {
       label = 18;
       break L45;
       break;
      }
      default: {
      }
      }
      return;
     }
    } else {
     switch ($17|0) {
     case 36309: case 36311: case 36310: case 36308: case 36307: case 36306: case 36305: case 36301: case 36304: case 36303: case 36302: case 36300: case 36299: case 36298: case 36297: case 36290: case 36293: case 36292: case 36291: case 36289: case 36288:  {
      label = 50;
      break L43;
      break;
     }
     case 35690: case 35689: case 35688: case 35687:  {
      label = 18;
      break L45;
      break;
     }
     case 36296: case 36295: case 36294:  {
      label = 66;
      break L45;
      break;
     }
     default: {
     }
     }
     return;
    }
   } while(0);
   if ((label|0) == 18) {
    $20 = (__Znwj(88)|0);
    __THREW__ = 0;
    invoke_vii(3435,($20|0),1);
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if ($22) {
     $66 = ___cxa_find_matching_catch_2()|0;
     $67 = tempRet0;
     $eh$lpad$body15$index2Z2D = $67;$eh$lpad$body15$indexZ2D = $66;
    } else {
     $23 = ((($20)) + 12|0);
     ;HEAP32[$23>>2]=0|0;HEAP32[$23+4>>2]=0|0;HEAP32[$23+8>>2]=0|0;
     $24 = ((($20)) + 24|0);
     HEAP32[$24>>2] = 2;
     $25 = ((($20)) + 28|0);
     ;HEAP32[$25>>2]=0|0;HEAP32[$25+4>>2]=0|0;HEAP32[$25+8>>2]=0|0;HEAP32[$25+12>>2]=0|0;HEAP32[$25+16>>2]=0|0;HEAP32[$25+20>>2]=0|0;
     HEAP32[$20>>2] = (54500);
     $26 = ((($20)) + 52|0);
     HEAP32[$26>>2] = 7;
     $27 = ((($20)) + 56|0);
     HEAP32[$27>>2] = 1;
     $28 = ((($20)) + 60|0);
     HEAP32[$28>>2] = 5126;
     $29 = ((($20)) + 64|0);
     HEAP32[$29>>2] = -1;
     $30 = ((($20)) + 68|0);
     HEAP8[$30>>0] = 0;
     $31 = ((($20)) + 69|0);
     HEAP8[$31>>0] = 0;
     $32 = ((($20)) + 72|0);
     HEAP32[$32>>2] = (52792);
     $33 = ((($20)) + 76|0);
     HEAP32[$33>>2] = 0;
     $34 = ((($20)) + 80|0);
     HEAP32[$34>>2] = 0;
     $35 = ((($20)) + 84|0);
     HEAP32[$35>>2] = 0;
     $36 = ($18>>>0)>(1073741823);
     if ($36) {
      __THREW__ = 0;
      invoke_vi(3307,($33|0));
      $37 = __THREW__; __THREW__ = 0;
     } else {
      $38 = $18 << 2;
      __THREW__ = 0;
      $39 = (invoke_ii(3276,($38|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if (!($41)) {
       HEAP32[$33>>2] = $39;
       $42 = (($39) + ($18<<2)|0);
       HEAP32[$35>>2] = $42;
       _memset(($39|0),0,($38|0))|0;
       $scevgep$i$i = (($39) + ($18<<2)|0);
       HEAP32[$34>>2] = $scevgep$i$i;
       HEAP32[$20>>2] = (52808);
       HEAP32[$32>>2] = (53032);
       $43 = HEAP32[$1>>2]|0;
       $44 = ($43|0)==($20|0);
       if ($44) {
        return;
       }
       HEAP32[$1>>2] = $20;
       $60 = ((($20)) + 8|0);
       $61 = HEAP32[$60>>2]|0;HEAP32[$60>>2] = (($61+1)|0);
       $62 = ($43|0)==(0|0);
       if ($62) {
        return;
       }
       $63 = ((($43)) + 8|0);
       $64 = HEAP32[$63>>2]|0;HEAP32[$63>>2] = (($64-1)|0);
       $65 = ($64|0)==(1);
       if (!($65)) {
        return;
       }
       __ZNK3osg10Referenced24signalObserversAndDeleteEbb($43,1,1);
       return;
      }
     }
     $45 = ___cxa_find_matching_catch_2()|0;
     $46 = tempRet0;
     $47 = HEAP32[$33>>2]|0;
     $48 = ($47|0)==(0|0);
     if (!($48)) {
      $49 = HEAP32[$34>>2]|0;
      $50 = ($49|0)==($47|0);
      if (!($50)) {
       $scevgep$i$i$i$i$i24 = ((($49)) + -4|0);
       $51 = $scevgep$i$i$i$i$i24;
       $52 = $47;
       $53 = (($51) - ($52))|0;
       $54 = $53 >>> 2;
       $55 = $54 ^ -1;
       $scevgep5$i$i$i$i$i25 = (($49) + ($55<<2)|0);
       HEAP32[$34>>2] = $scevgep5$i$i$i$i$i25;
      }
      __ZdlPv($47);
     }
     __THREW__ = 0;
     invoke_vi(1265,($20|0));
     $56 = __THREW__; __THREW__ = 0;
     $57 = $56&1;
     if ($57) {
      $58 = ___cxa_find_matching_catch_3(0|0)|0;
      $59 = tempRet0;
      ___clang_call_terminate($58);
      // unreachable;
     } else {
      $eh$lpad$body15$index2Z2D = $46;$eh$lpad$body15$indexZ2D = $45;
     }
    }
    __ZdlPv($20);
    $$0 = $eh$lpad$body15$index2Z2D;$$09 = $eh$lpad$body15$indexZ2D;
    ___resumeException($$09|0);
    // unreachable;
   }
   else if ((label|0) == 66) {
    $164 = (__Znwj(88)|0);
    __THREW__ = 0;
    invoke_vii(3435,($164|0),1);
    $165 = __THREW__; __THREW__ = 0;
    $166 = $165&1;
    if ($166) {
     $210 = ___cxa_find_matching_catch_2()|0;
     $211 = tempRet0;
     $eh$lpad$body$index17Z2D = $211;$eh$lpad$body$indexZ2D = $210;
    } else {
     $167 = ((($164)) + 12|0);
     ;HEAP32[$167>>2]=0|0;HEAP32[$167+4>>2]=0|0;HEAP32[$167+8>>2]=0|0;
     $168 = ((($164)) + 24|0);
     HEAP32[$168>>2] = 2;
     $169 = ((($164)) + 28|0);
     ;HEAP32[$169>>2]=0|0;HEAP32[$169+4>>2]=0|0;HEAP32[$169+8>>2]=0|0;HEAP32[$169+12>>2]=0|0;HEAP32[$169+16>>2]=0|0;HEAP32[$169+20>>2]=0|0;
     $170 = ((($164)) + 52|0);
     HEAP32[$170>>2] = 6;
     $171 = ((($164)) + 56|0);
     HEAP32[$171>>2] = 1;
     $172 = ((($164)) + 60|0);
     HEAP32[$172>>2] = 5125;
     $173 = ((($164)) + 64|0);
     HEAP32[$173>>2] = -1;
     $174 = ((($164)) + 68|0);
     HEAP8[$174>>0] = 0;
     $175 = ((($164)) + 69|0);
     HEAP8[$175>>0] = 0;
     HEAP32[$164>>2] = (53048);
     $176 = ((($164)) + 72|0);
     HEAP32[$176>>2] = (52520);
     $177 = ((($164)) + 76|0);
     HEAP32[$177>>2] = 0;
     $178 = ((($164)) + 80|0);
     HEAP32[$178>>2] = 0;
     $179 = ((($164)) + 84|0);
     HEAP32[$179>>2] = 0;
     $180 = ($18>>>0)>(1073741823);
     if ($180) {
      __THREW__ = 0;
      invoke_vi(3307,($177|0));
      $181 = __THREW__; __THREW__ = 0;
     } else {
      $182 = $18 << 2;
      __THREW__ = 0;
      $183 = (invoke_ii(3276,($182|0))|0);
      $184 = __THREW__; __THREW__ = 0;
      $185 = $184&1;
      if (!($185)) {
       HEAP32[$177>>2] = $183;
       $186 = (($183) + ($18<<2)|0);
       HEAP32[$179>>2] = $186;
       _memset(($183|0),0,($182|0))|0;
       HEAP32[$178>>2] = $186;
       HEAP32[$164>>2] = (53276);
       HEAP32[$176>>2] = (53504);
       $187 = HEAP32[$10>>2]|0;
       $188 = ($187|0)==($164|0);
       if ($188) {
        return;
       }
       HEAP32[$10>>2] = $164;
       $204 = ((($164)) + 8|0);
       $205 = HEAP32[$204>>2]|0;HEAP32[$204>>2] = (($205+1)|0);
       $206 = ($187|0)==(0|0);
       if ($206) {
        return;
       }
       $207 = ((($187)) + 8|0);
       $208 = HEAP32[$207>>2]|0;HEAP32[$207>>2] = (($208-1)|0);
       $209 = ($208|0)==(1);
       if (!($209)) {
        return;
       }
       __ZNK3osg10Referenced24signalObserversAndDeleteEbb($187,1,1);
       return;
      }
     }
     $189 = ___cxa_find_matching_catch_2()|0;
     $190 = tempRet0;
     $191 = HEAP32[$177>>2]|0;
     $192 = ($191|0)==(0|0);
     if (!($192)) {
      $193 = HEAP32[$178>>2]|0;
      $194 = ($193|0)==($191|0);
      if (!($194)) {
       $scevgep$i$i$i$i$i = ((($193)) + -4|0);
       $195 = $scevgep$i$i$i$i$i;
       $196 = $191;
       $197 = (($195) - ($196))|0;
       $198 = $197 >>> 2;
       $199 = $198 ^ -1;
       $scevgep5$i$i$i$i$i = (($193) + ($199<<2)|0);
       HEAP32[$178>>2] = $scevgep5$i$i$i$i$i;
      }
      __ZdlPv($191);
     }
     __THREW__ = 0;
     invoke_vi(1265,($164|0));
     $200 = __THREW__; __THREW__ = 0;
     $201 = $200&1;
     if ($201) {
      $202 = ___cxa_find_matching_catch_3(0|0)|0;
      $203 = tempRet0;
      ___clang_call_terminate($202);
      // unreachable;
     } else {
      $eh$lpad$body$index17Z2D = $190;$eh$lpad$body$indexZ2D = $189;
     }
    }
    __ZdlPv($164);
    $$0 = $eh$lpad$body$index17Z2D;$$09 = $eh$lpad$body$indexZ2D;
    ___resumeException($$09|0);
    // unreachable;
   }
  } else {
   switch ($17|0) {
   case 36686: case 36685: case 36684: case 36683: case 36682: case 36681: case 36680: case 36679: case 36678: case 36862: case 36861: case 36860:  {
    label = 34;
    break L43;
    break;
   }
   case 36972: case 36971: case 36970: case 36969: case 36968: case 36967: case 36966: case 36965: case 36964: case 36963: case 36962: case 36961: case 36960: case 36959: case 36958: case 36957: case 36956: case 36955: case 36954: case 36953: case 36952: case 36951: case 36950: case 36949: case 36948: case 36947: case 36946: case 36945: case 36944: case 36943: case 36942: case 36941: case 36940: case 36312: case 37133: case 37130: case 36879: case 37132: case 37129: case 36878: case 36877: case 37131: case 37128: case 36876:  {
    label = 50;
    break L43;
    break;
   }
   default: {
   }
   }
   return;
  }
 } while(0);
 if ((label|0) == 34) {
  $68 = (__Znwj(88)|0);
  __THREW__ = 0;
  invoke_vii(3435,($68|0),1);
  $69 = __THREW__; __THREW__ = 0;
  $70 = $69&1;
  if ($70) {
   $114 = ___cxa_find_matching_catch_2()|0;
   $115 = tempRet0;
   $eh$lpad$body18$index7Z2D = $115;$eh$lpad$body18$indexZ2D = $114;
  } else {
   $71 = ((($68)) + 12|0);
   ;HEAP32[$71>>2]=0|0;HEAP32[$71+4>>2]=0|0;HEAP32[$71+8>>2]=0|0;
   $72 = ((($68)) + 24|0);
   HEAP32[$72>>2] = 2;
   $73 = ((($68)) + 28|0);
   ;HEAP32[$73>>2]=0|0;HEAP32[$73+4>>2]=0|0;HEAP32[$73+8>>2]=0|0;HEAP32[$73+12>>2]=0|0;HEAP32[$73+16>>2]=0|0;HEAP32[$73+20>>2]=0|0;
   HEAP32[$68>>2] = (54500);
   $74 = ((($68)) + 52|0);
   HEAP32[$74>>2] = 8;
   $75 = ((($68)) + 56|0);
   HEAP32[$75>>2] = 1;
   $76 = ((($68)) + 60|0);
   HEAP32[$76>>2] = 5130;
   $77 = ((($68)) + 64|0);
   HEAP32[$77>>2] = -1;
   $78 = ((($68)) + 68|0);
   HEAP8[$78>>0] = 0;
   $79 = ((($68)) + 69|0);
   HEAP8[$79>>0] = 0;
   $80 = ((($68)) + 72|0);
   HEAP32[$80>>2] = (52536);
   $81 = ((($68)) + 76|0);
   HEAP32[$81>>2] = 0;
   $82 = ((($68)) + 80|0);
   HEAP32[$82>>2] = 0;
   $83 = ((($68)) + 84|0);
   HEAP32[$83>>2] = 0;
   $84 = ($18>>>0)>(536870911);
   if ($84) {
    __THREW__ = 0;
    invoke_vi(3307,($81|0));
    $85 = __THREW__; __THREW__ = 0;
   } else {
    $86 = $18 << 3;
    __THREW__ = 0;
    $87 = (invoke_ii(3276,($86|0))|0);
    $88 = __THREW__; __THREW__ = 0;
    $89 = $88&1;
    if (!($89)) {
     HEAP32[$81>>2] = $87;
     $90 = (($87) + ($18<<3)|0);
     HEAP32[$83>>2] = $90;
     _memset(($87|0),0,($86|0))|0;
     HEAP32[$82>>2] = $90;
     HEAP32[$68>>2] = (52552);
     HEAP32[$80>>2] = (52776);
     $91 = HEAP32[$4>>2]|0;
     $92 = ($91|0)==($68|0);
     if ($92) {
      return;
     }
     HEAP32[$4>>2] = $68;
     $108 = ((($68)) + 8|0);
     $109 = HEAP32[$108>>2]|0;HEAP32[$108>>2] = (($109+1)|0);
     $110 = ($91|0)==(0|0);
     if ($110) {
      return;
     }
     $111 = ((($91)) + 8|0);
     $112 = HEAP32[$111>>2]|0;HEAP32[$111>>2] = (($112-1)|0);
     $113 = ($112|0)==(1);
     if (!($113)) {
      return;
     }
     __ZNK3osg10Referenced24signalObserversAndDeleteEbb($91,1,1);
     return;
    }
   }
   $93 = ___cxa_find_matching_catch_2()|0;
   $94 = tempRet0;
   $95 = HEAP32[$81>>2]|0;
   $96 = ($95|0)==(0|0);
   if (!($96)) {
    $97 = HEAP32[$82>>2]|0;
    $98 = ($97|0)==($95|0);
    if (!($98)) {
     $scevgep$i$i$i$i$i31 = ((($97)) + -8|0);
     $99 = $scevgep$i$i$i$i$i31;
     $100 = $95;
     $101 = (($99) - ($100))|0;
     $102 = $101 >>> 3;
     $103 = $102 ^ -1;
     $scevgep5$i$i$i$i$i32 = (($97) + ($103<<3)|0);
     HEAP32[$82>>2] = $scevgep5$i$i$i$i$i32;
    }
    __ZdlPv($95);
   }
   __THREW__ = 0;
   invoke_vi(1265,($68|0));
   $104 = __THREW__; __THREW__ = 0;
   $105 = $104&1;
   if ($105) {
    $106 = ___cxa_find_matching_catch_3(0|0)|0;
    $107 = tempRet0;
    ___clang_call_terminate($106);
    // unreachable;
   } else {
    $eh$lpad$body18$index7Z2D = $94;$eh$lpad$body18$indexZ2D = $93;
   }
  }
  __ZdlPv($68);
  $$0 = $eh$lpad$body18$index7Z2D;$$09 = $eh$lpad$body18$indexZ2D;
  ___resumeException($$09|0);
  // unreachable;
 }
 else if ((label|0) == 50) {
  $116 = (__Znwj(88)|0);
  __THREW__ = 0;
  invoke_vii(3435,($116|0),1);
  $117 = __THREW__; __THREW__ = 0;
  $118 = $117&1;
  if ($118) {
   $162 = ___cxa_find_matching_catch_2()|0;
   $163 = tempRet0;
   $eh$lpad$body21$index12Z2D = $163;$eh$lpad$body21$indexZ2D = $162;
  } else {
   $119 = ((($116)) + 12|0);
   ;HEAP32[$119>>2]=0|0;HEAP32[$119+4>>2]=0|0;HEAP32[$119+8>>2]=0|0;
   $120 = ((($116)) + 24|0);
   HEAP32[$120>>2] = 2;
   $121 = ((($116)) + 28|0);
   ;HEAP32[$121>>2]=0|0;HEAP32[$121+4>>2]=0|0;HEAP32[$121+8>>2]=0|0;HEAP32[$121+12>>2]=0|0;HEAP32[$121+16>>2]=0|0;HEAP32[$121+20>>2]=0|0;
   $122 = ((($116)) + 52|0);
   HEAP32[$122>>2] = 3;
   $123 = ((($116)) + 56|0);
   HEAP32[$123>>2] = 1;
   $124 = ((($116)) + 60|0);
   HEAP32[$124>>2] = 5124;
   $125 = ((($116)) + 64|0);
   HEAP32[$125>>2] = -1;
   $126 = ((($116)) + 68|0);
   HEAP8[$126>>0] = 0;
   $127 = ((($116)) + 69|0);
   HEAP8[$127>>0] = 0;
   HEAP32[$116>>2] = (53048);
   $128 = ((($116)) + 72|0);
   HEAP32[$128>>2] = (53552);
   $129 = ((($116)) + 76|0);
   HEAP32[$129>>2] = 0;
   $130 = ((($116)) + 80|0);
   HEAP32[$130>>2] = 0;
   $131 = ((($116)) + 84|0);
   HEAP32[$131>>2] = 0;
   $132 = ($18>>>0)>(1073741823);
   if ($132) {
    __THREW__ = 0;
    invoke_vi(3307,($129|0));
    $133 = __THREW__; __THREW__ = 0;
   } else {
    $134 = $18 << 2;
    __THREW__ = 0;
    $135 = (invoke_ii(3276,($134|0))|0);
    $136 = __THREW__; __THREW__ = 0;
    $137 = $136&1;
    if (!($137)) {
     HEAP32[$129>>2] = $135;
     $138 = (($135) + ($18<<2)|0);
     HEAP32[$131>>2] = $138;
     _memset(($135|0),0,($134|0))|0;
     HEAP32[$130>>2] = $138;
     HEAP32[$116>>2] = (53568);
     HEAP32[$128>>2] = (53796);
     $139 = HEAP32[$7>>2]|0;
     $140 = ($139|0)==($116|0);
     if ($140) {
      return;
     }
     HEAP32[$7>>2] = $116;
     $156 = ((($116)) + 8|0);
     $157 = HEAP32[$156>>2]|0;HEAP32[$156>>2] = (($157+1)|0);
     $158 = ($139|0)==(0|0);
     if ($158) {
      return;
     }
     $159 = ((($139)) + 8|0);
     $160 = HEAP32[$159>>2]|0;HEAP32[$159>>2] = (($160-1)|0);
     $161 = ($160|0)==(1);
     if (!($161)) {
      return;
     }
     __ZNK3osg10Referenced24signalObserversAndDeleteEbb($139,1,1);
     return;
    }
   }
   $141 = ___cxa_find_matching_catch_2()|0;
   $142 = tempRet0;
   $143 = HEAP32[$129>>2]|0;
   $144 = ($143|0)==(0|0);
   if (!($144)) {
    $145 = HEAP32[$130>>2]|0;
    $146 = ($145|0)==($143|0);
    if (!($146)) {
     $scevgep$i$i$i$i$i38 = ((($145)) + -4|0);
     $147 = $scevgep$i$i$i$i$i38;
     $148 = $143;
     $149 = (($147) - ($148))|0;
     $150 = $149 >>> 2;
     $151 = $150 ^ -1;
     $scevgep5$i$i$i$i$i39 = (($145) + ($151<<2)|0);
     HEAP32[$130>>2] = $scevgep5$i$i$i$i$i39;
    }
    __ZdlPv($143);
   }
   __THREW__ = 0;
   invoke_vi(1265,($116|0));
   $152 = __THREW__; __THREW__ = 0;
   $153 = $152&1;
   if ($153) {
    $154 = ___cxa_find_matching_catch_3(0|0)|0;
    $155 = tempRet0;
    ___clang_call_terminate($154);
    // unreachable;
   } else {
    $eh$lpad$body21$index12Z2D = $142;$eh$lpad$body21$indexZ2D = $141;
   }
  }
  __ZdlPv($116);
  $$0 = $eh$lpad$body21$index12Z2D;$$09 = $eh$lpad$body21$indexZ2D;
  ___resumeException($$09|0);
  // unreachable;
 }
}
function __ZNSt3__26vectorIfNS_9allocatorIfEEE6assignINS_11__wrap_iterIPKfEEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIfNS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$ = 0, $$0$lcssa$i$i = 0, $$03$i$i = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $scevgep$i = 0, $scevgep$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i17 = 0, $scevgep$i11 = 0, $scevgep11$i = 0, $scevgep11$i12 = 0, $scevgep5$i$i = 0, $scevgep5$i$i$i$i = 0, $scevgep9$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = HEAP32[$1>>2]|0;
 $4 = HEAP32[$2>>2]|0;
 $5 = (($4) - ($3))|0;
 $6 = $5 >> 2;
 $7 = ((($0)) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$0>>2]|0;
 $10 = (($8) - ($9))|0;
 $11 = $10 >> 2;
 $12 = ($6>>>0)>($11>>>0);
 $13 = $9;
 $14 = $4;
 if ($12) {
  $54 = ($9|0)==(0);
  $55 = $9;
  if ($54) {
   $65 = $8;
  } else {
   $56 = ((($0)) + 4|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = ($57|0)==($13|0);
   if (!($58)) {
    $scevgep$i$i$i$i = ((($57)) + -4|0);
    $59 = $scevgep$i$i$i$i;
    $60 = (($59) - ($9))|0;
    $61 = $60 >>> 2;
    $62 = $61 ^ -1;
    $scevgep5$i$i$i$i = (($57) + ($62<<2)|0);
    HEAP32[$56>>2] = $scevgep5$i$i$i$i;
   }
   __ZdlPv($55);
   HEAP32[$7>>2] = 0;
   HEAP32[$56>>2] = 0;
   HEAP32[$0>>2] = 0;
   $65 = 0;
  }
  $63 = ($6>>>0)>(1073741823);
  if ($63) {
   __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
   // unreachable;
  }
  $64 = $65 >> 2;
  $66 = ($64>>>0)<(536870911);
  $67 = $65 >> 1;
  $68 = ($67>>>0)<($6>>>0);
  $$sroa$speculated$i = $68 ? $6 : $67;
  $$sroa$speculated$$i = $66 ? $$sroa$speculated$i : 1073741823;
  $69 = ($$sroa$speculated$$i>>>0)>(1073741823);
  if ($69) {
   __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
   // unreachable;
  }
  $70 = $$sroa$speculated$$i << 2;
  $71 = (__Znwj($70)|0);
  $72 = ((($0)) + 4|0);
  HEAP32[$72>>2] = $71;
  HEAP32[$0>>2] = $71;
  $73 = (($71) + ($$sroa$speculated$$i<<2)|0);
  HEAP32[$7>>2] = $73;
  $74 = $3;
  $75 = ($74|0)==($14|0);
  if ($75) {
   return;
  }
  $scevgep$i = ((($14)) + -4|0);
  $76 = $scevgep$i;
  $77 = (($76) - ($3))|0;
  $78 = $77 >>> 2;
  $79 = (($78) + 1)|0;
  $81 = $74;$82 = $71;
  while(1) {
   $80 = HEAP32[$81>>2]|0;
   HEAP32[$82>>2] = $80;
   $83 = ((($81)) + 4|0);
   $84 = ((($82)) + 4|0);
   $85 = ($83|0)==($14|0);
   if ($85) {
    break;
   } else {
    $81 = $83;$82 = $84;
   }
  }
  $scevgep11$i = (($71) + ($79<<2)|0);
  HEAP32[$72>>2] = $scevgep11$i;
  return;
 }
 $15 = ((($0)) + 4|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) - ($9))|0;
 $18 = $17 >> 2;
 $19 = ($6>>>0)>($18>>>0);
 $20 = $3;
 $21 = (($20) + ($18<<2)|0);
 $22 = $21;
 $$ = $19 ? $22 : $4;
 $23 = $$;
 $24 = ($20|0)==($23|0);
 $25 = $16;
 $26 = $16;
 if ($24) {
  $$0$lcssa$i$i = $13;
 } else {
  $scevgep$i$i17 = ((($23)) + -4|0);
  $27 = $scevgep$i$i17;
  $28 = (($27) - ($3))|0;
  $$03$i$i = $13;$30 = $20;
  while(1) {
   $29 = HEAP32[$30>>2]|0;
   HEAP32[$$03$i$i>>2] = $29;
   $31 = ((($30)) + 4|0);
   $32 = ((($$03$i$i)) + 4|0);
   $33 = ($31|0)==($23|0);
   if ($33) {
    break;
   } else {
    $$03$i$i = $32;$30 = $31;
   }
  }
  $34 = $28 >>> 2;
  $35 = (($34) + 1)|0;
  $scevgep9$i$i = (($13) + ($35<<2)|0);
  $$0$lcssa$i$i = $scevgep9$i$i;
 }
 if (!($19)) {
  $48 = ($25|0)==($$0$lcssa$i$i|0);
  if ($48) {
   return;
  }
  $scevgep$i$i = ((($25)) + -4|0);
  $49 = $scevgep$i$i;
  $50 = $$0$lcssa$i$i;
  $51 = (($49) - ($50))|0;
  $52 = $51 >>> 2;
  $53 = $52 ^ -1;
  $scevgep5$i$i = (($25) + ($53<<2)|0);
  HEAP32[$15>>2] = $scevgep5$i$i;
  return;
 }
 $36 = ($23|0)==($14|0);
 if ($36) {
  return;
 }
 $37 = $16;
 $scevgep$i11 = ((($14)) + -4|0);
 $38 = $scevgep$i11;
 $39 = (($38) - ($$))|0;
 $40 = $39 >>> 2;
 $41 = (($40) + 1)|0;
 $43 = $23;$44 = $37;
 while(1) {
  $42 = HEAP32[$43>>2]|0;
  HEAP32[$44>>2] = $42;
  $45 = ((($43)) + 4|0);
  $46 = ((($44)) + 4|0);
  $47 = ($45|0)==($14|0);
  if ($47) {
   break;
  } else {
   $43 = $45;$44 = $46;
  }
 }
 $scevgep11$i12 = (($26) + ($41<<2)|0);
 HEAP32[$15>>2] = $scevgep11$i12;
 return;
}
function __ZNSt3__26vectorIdNS_9allocatorIdEEE6assignINS_11__wrap_iterIPKdEEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIdNS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$ = 0, $$0$lcssa$i$i = 0, $$03$i$i = 0, $$promoted$i$i11 = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0.0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0.0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0.0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $9 = 0, $scevgep$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i10 = 0, $scevgep$i$i12 = 0, $scevgep$i$i17 = 0, $scevgep10$i$i = 0, $scevgep10$i$i14 = 0, $scevgep5$i$i = 0, $scevgep5$i$i$i$i = 0, $scevgep9$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = HEAP32[$1>>2]|0;
 $4 = HEAP32[$2>>2]|0;
 $5 = (($4) - ($3))|0;
 $6 = $5 >> 3;
 $7 = ((($0)) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$0>>2]|0;
 $10 = (($8) - ($9))|0;
 $11 = $10 >> 3;
 $12 = ($6>>>0)>($11>>>0);
 $13 = $9;
 $14 = $4;
 if ($12) {
  $52 = ($9|0)==(0);
  $53 = $9;
  if ($52) {
   $63 = $8;
  } else {
   $54 = ((($0)) + 4|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = ($55|0)==($13|0);
   if (!($56)) {
    $scevgep$i$i$i$i = ((($55)) + -8|0);
    $57 = $scevgep$i$i$i$i;
    $58 = (($57) - ($9))|0;
    $59 = $58 >>> 3;
    $60 = $59 ^ -1;
    $scevgep5$i$i$i$i = (($55) + ($60<<3)|0);
    HEAP32[$54>>2] = $scevgep5$i$i$i$i;
   }
   __ZdlPv($53);
   HEAP32[$7>>2] = 0;
   HEAP32[$54>>2] = 0;
   HEAP32[$0>>2] = 0;
   $63 = 0;
  }
  $61 = ($6>>>0)>(536870911);
  if ($61) {
   __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
   // unreachable;
  }
  $62 = $63 >> 3;
  $64 = ($62>>>0)<(268435455);
  $65 = $63 >> 2;
  $66 = ($65>>>0)<($6>>>0);
  $$sroa$speculated$i = $66 ? $6 : $65;
  $$sroa$speculated$$i = $64 ? $$sroa$speculated$i : 536870911;
  $67 = ($$sroa$speculated$$i>>>0)>(536870911);
  if ($67) {
   __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
   // unreachable;
  }
  $68 = $$sroa$speculated$$i << 3;
  $69 = (__Znwj($68)|0);
  $70 = ((($0)) + 4|0);
  HEAP32[$70>>2] = $69;
  HEAP32[$0>>2] = $69;
  $71 = (($69) + ($$sroa$speculated$$i<<3)|0);
  HEAP32[$7>>2] = $71;
  $72 = $3;
  $73 = ($72|0)==($14|0);
  if ($73) {
   return;
  }
  $scevgep$i$i = ((($14)) + -8|0);
  $74 = $scevgep$i$i;
  $75 = (($74) - ($3))|0;
  $77 = $72;$78 = $69;
  while(1) {
   $76 = +HEAPF64[$77>>3];
   HEAPF64[$78>>3] = $76;
   $79 = ((($77)) + 8|0);
   $80 = ((($78)) + 8|0);
   $81 = ($79|0)==($14|0);
   if ($81) {
    break;
   } else {
    $77 = $79;$78 = $80;
   }
  }
  $82 = $75 >>> 3;
  $83 = (($82) + 1)|0;
  $scevgep10$i$i = (($69) + ($83<<3)|0);
  HEAP32[$70>>2] = $scevgep10$i$i;
  return;
 }
 $15 = ((($0)) + 4|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) - ($9))|0;
 $18 = $17 >> 3;
 $19 = ($6>>>0)>($18>>>0);
 $20 = $3;
 $21 = (($20) + ($18<<3)|0);
 $22 = $21;
 $$ = $19 ? $22 : $4;
 $23 = $$;
 $24 = ($20|0)==($23|0);
 $25 = $16;
 if ($24) {
  $$0$lcssa$i$i = $13;
 } else {
  $scevgep$i$i17 = ((($23)) + -8|0);
  $26 = $scevgep$i$i17;
  $27 = (($26) - ($3))|0;
  $$03$i$i = $13;$29 = $20;
  while(1) {
   $28 = +HEAPF64[$29>>3];
   HEAPF64[$$03$i$i>>3] = $28;
   $30 = ((($29)) + 8|0);
   $31 = ((($$03$i$i)) + 8|0);
   $32 = ($30|0)==($23|0);
   if ($32) {
    break;
   } else {
    $$03$i$i = $31;$29 = $30;
   }
  }
  $33 = $27 >>> 3;
  $34 = (($33) + 1)|0;
  $scevgep9$i$i = (($13) + ($34<<3)|0);
  $$0$lcssa$i$i = $scevgep9$i$i;
 }
 if (!($19)) {
  $46 = ($25|0)==($$0$lcssa$i$i|0);
  if ($46) {
   return;
  }
  $scevgep$i$i10 = ((($25)) + -8|0);
  $47 = $scevgep$i$i10;
  $48 = $$0$lcssa$i$i;
  $49 = (($47) - ($48))|0;
  $50 = $49 >>> 3;
  $51 = $50 ^ -1;
  $scevgep5$i$i = (($25) + ($51<<3)|0);
  HEAP32[$15>>2] = $scevgep5$i$i;
  return;
 }
 $35 = ($23|0)==($14|0);
 if ($35) {
  return;
 }
 $$promoted$i$i11 = HEAP32[$15>>2]|0;
 $scevgep$i$i12 = ((($14)) + -8|0);
 $36 = $scevgep$i$i12;
 $37 = (($36) - ($$))|0;
 $39 = $23;$40 = $$promoted$i$i11;
 while(1) {
  $38 = +HEAPF64[$39>>3];
  HEAPF64[$40>>3] = $38;
  $41 = ((($39)) + 8|0);
  $42 = ((($40)) + 8|0);
  $43 = ($41|0)==($14|0);
  if ($43) {
   break;
  } else {
   $39 = $41;$40 = $42;
  }
 }
 $44 = $37 >>> 3;
 $45 = (($44) + 1)|0;
 $scevgep10$i$i14 = (($$promoted$i$i11) + ($45<<3)|0);
 HEAP32[$15>>2] = $scevgep10$i$i14;
 return;
}
function __ZNSt3__26vectorIiNS_9allocatorIiEEE6assignINS_11__wrap_iterIPKiEEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIiNS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$ = 0, $$0$lcssa$i$i = 0, $$03$i$i = 0, $$promoted$i$i11 = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $9 = 0, $scevgep$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i10 = 0, $scevgep$i$i12 = 0, $scevgep$i$i17 = 0, $scevgep10$i$i = 0, $scevgep10$i$i14 = 0, $scevgep5$i$i = 0, $scevgep5$i$i$i$i = 0, $scevgep9$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = HEAP32[$1>>2]|0;
 $4 = HEAP32[$2>>2]|0;
 $5 = (($4) - ($3))|0;
 $6 = $5 >> 2;
 $7 = ((($0)) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$0>>2]|0;
 $10 = (($8) - ($9))|0;
 $11 = $10 >> 2;
 $12 = ($6>>>0)>($11>>>0);
 $13 = $9;
 $14 = $4;
 if ($12) {
  $52 = ($9|0)==(0);
  $53 = $9;
  if ($52) {
   $63 = $8;
  } else {
   $54 = ((($0)) + 4|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = ($55|0)==($13|0);
   if (!($56)) {
    $scevgep$i$i$i$i = ((($55)) + -4|0);
    $57 = $scevgep$i$i$i$i;
    $58 = (($57) - ($9))|0;
    $59 = $58 >>> 2;
    $60 = $59 ^ -1;
    $scevgep5$i$i$i$i = (($55) + ($60<<2)|0);
    HEAP32[$54>>2] = $scevgep5$i$i$i$i;
   }
   __ZdlPv($53);
   HEAP32[$7>>2] = 0;
   HEAP32[$54>>2] = 0;
   HEAP32[$0>>2] = 0;
   $63 = 0;
  }
  $61 = ($6>>>0)>(1073741823);
  if ($61) {
   __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
   // unreachable;
  }
  $62 = $63 >> 2;
  $64 = ($62>>>0)<(536870911);
  $65 = $63 >> 1;
  $66 = ($65>>>0)<($6>>>0);
  $$sroa$speculated$i = $66 ? $6 : $65;
  $$sroa$speculated$$i = $64 ? $$sroa$speculated$i : 1073741823;
  $67 = ($$sroa$speculated$$i>>>0)>(1073741823);
  if ($67) {
   __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
   // unreachable;
  }
  $68 = $$sroa$speculated$$i << 2;
  $69 = (__Znwj($68)|0);
  $70 = ((($0)) + 4|0);
  HEAP32[$70>>2] = $69;
  HEAP32[$0>>2] = $69;
  $71 = (($69) + ($$sroa$speculated$$i<<2)|0);
  HEAP32[$7>>2] = $71;
  $72 = $3;
  $73 = ($72|0)==($14|0);
  if ($73) {
   return;
  }
  $scevgep$i$i = ((($14)) + -4|0);
  $74 = $scevgep$i$i;
  $75 = (($74) - ($3))|0;
  $77 = $72;$78 = $69;
  while(1) {
   $76 = HEAP32[$77>>2]|0;
   HEAP32[$78>>2] = $76;
   $79 = ((($77)) + 4|0);
   $80 = ((($78)) + 4|0);
   $81 = ($79|0)==($14|0);
   if ($81) {
    break;
   } else {
    $77 = $79;$78 = $80;
   }
  }
  $82 = $75 >>> 2;
  $83 = (($82) + 1)|0;
  $scevgep10$i$i = (($69) + ($83<<2)|0);
  HEAP32[$70>>2] = $scevgep10$i$i;
  return;
 }
 $15 = ((($0)) + 4|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) - ($9))|0;
 $18 = $17 >> 2;
 $19 = ($6>>>0)>($18>>>0);
 $20 = $3;
 $21 = (($20) + ($18<<2)|0);
 $22 = $21;
 $$ = $19 ? $22 : $4;
 $23 = $$;
 $24 = ($20|0)==($23|0);
 $25 = $16;
 if ($24) {
  $$0$lcssa$i$i = $13;
 } else {
  $scevgep$i$i17 = ((($23)) + -4|0);
  $26 = $scevgep$i$i17;
  $27 = (($26) - ($3))|0;
  $$03$i$i = $13;$29 = $20;
  while(1) {
   $28 = HEAP32[$29>>2]|0;
   HEAP32[$$03$i$i>>2] = $28;
   $30 = ((($29)) + 4|0);
   $31 = ((($$03$i$i)) + 4|0);
   $32 = ($30|0)==($23|0);
   if ($32) {
    break;
   } else {
    $$03$i$i = $31;$29 = $30;
   }
  }
  $33 = $27 >>> 2;
  $34 = (($33) + 1)|0;
  $scevgep9$i$i = (($13) + ($34<<2)|0);
  $$0$lcssa$i$i = $scevgep9$i$i;
 }
 if (!($19)) {
  $46 = ($25|0)==($$0$lcssa$i$i|0);
  if ($46) {
   return;
  }
  $scevgep$i$i10 = ((($25)) + -4|0);
  $47 = $scevgep$i$i10;
  $48 = $$0$lcssa$i$i;
  $49 = (($47) - ($48))|0;
  $50 = $49 >>> 2;
  $51 = $50 ^ -1;
  $scevgep5$i$i = (($25) + ($51<<2)|0);
  HEAP32[$15>>2] = $scevgep5$i$i;
  return;
 }
 $35 = ($23|0)==($14|0);
 if ($35) {
  return;
 }
 $$promoted$i$i11 = HEAP32[$15>>2]|0;
 $scevgep$i$i12 = ((($14)) + -4|0);
 $36 = $scevgep$i$i12;
 $37 = (($36) - ($$))|0;
 $39 = $23;$40 = $$promoted$i$i11;
 while(1) {
  $38 = HEAP32[$39>>2]|0;
  HEAP32[$40>>2] = $38;
  $41 = ((($39)) + 4|0);
  $42 = ((($40)) + 4|0);
  $43 = ($41|0)==($14|0);
  if ($43) {
   break;
  } else {
   $39 = $41;$40 = $42;
  }
 }
 $44 = $37 >>> 2;
 $45 = (($44) + 1)|0;
 $scevgep10$i$i14 = (($$promoted$i$i11) + ($45<<2)|0);
 HEAP32[$15>>2] = $scevgep10$i$i14;
 return;
}
function __ZNSt3__26vectorIjNS_9allocatorIjEEE6assignINS_11__wrap_iterIPKjEEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIjNS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$ = 0, $$0$lcssa$i$i = 0, $$03$i$i = 0, $$promoted$i$i11 = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $9 = 0, $scevgep$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i10 = 0, $scevgep$i$i12 = 0, $scevgep$i$i17 = 0, $scevgep10$i$i = 0, $scevgep10$i$i14 = 0, $scevgep5$i$i = 0, $scevgep5$i$i$i$i = 0, $scevgep9$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = HEAP32[$1>>2]|0;
 $4 = HEAP32[$2>>2]|0;
 $5 = (($4) - ($3))|0;
 $6 = $5 >> 2;
 $7 = ((($0)) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$0>>2]|0;
 $10 = (($8) - ($9))|0;
 $11 = $10 >> 2;
 $12 = ($6>>>0)>($11>>>0);
 $13 = $9;
 $14 = $4;
 if ($12) {
  $52 = ($9|0)==(0);
  $53 = $9;
  if ($52) {
   $63 = $8;
  } else {
   $54 = ((($0)) + 4|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = ($55|0)==($13|0);
   if (!($56)) {
    $scevgep$i$i$i$i = ((($55)) + -4|0);
    $57 = $scevgep$i$i$i$i;
    $58 = (($57) - ($9))|0;
    $59 = $58 >>> 2;
    $60 = $59 ^ -1;
    $scevgep5$i$i$i$i = (($55) + ($60<<2)|0);
    HEAP32[$54>>2] = $scevgep5$i$i$i$i;
   }
   __ZdlPv($53);
   HEAP32[$7>>2] = 0;
   HEAP32[$54>>2] = 0;
   HEAP32[$0>>2] = 0;
   $63 = 0;
  }
  $61 = ($6>>>0)>(1073741823);
  if ($61) {
   __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
   // unreachable;
  }
  $62 = $63 >> 2;
  $64 = ($62>>>0)<(536870911);
  $65 = $63 >> 1;
  $66 = ($65>>>0)<($6>>>0);
  $$sroa$speculated$i = $66 ? $6 : $65;
  $$sroa$speculated$$i = $64 ? $$sroa$speculated$i : 1073741823;
  $67 = ($$sroa$speculated$$i>>>0)>(1073741823);
  if ($67) {
   __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
   // unreachable;
  }
  $68 = $$sroa$speculated$$i << 2;
  $69 = (__Znwj($68)|0);
  $70 = ((($0)) + 4|0);
  HEAP32[$70>>2] = $69;
  HEAP32[$0>>2] = $69;
  $71 = (($69) + ($$sroa$speculated$$i<<2)|0);
  HEAP32[$7>>2] = $71;
  $72 = $3;
  $73 = ($72|0)==($14|0);
  if ($73) {
   return;
  }
  $scevgep$i$i = ((($14)) + -4|0);
  $74 = $scevgep$i$i;
  $75 = (($74) - ($3))|0;
  $77 = $72;$78 = $69;
  while(1) {
   $76 = HEAP32[$77>>2]|0;
   HEAP32[$78>>2] = $76;
   $79 = ((($77)) + 4|0);
   $80 = ((($78)) + 4|0);
   $81 = ($79|0)==($14|0);
   if ($81) {
    break;
   } else {
    $77 = $79;$78 = $80;
   }
  }
  $82 = $75 >>> 2;
  $83 = (($82) + 1)|0;
  $scevgep10$i$i = (($69) + ($83<<2)|0);
  HEAP32[$70>>2] = $scevgep10$i$i;
  return;
 }
 $15 = ((($0)) + 4|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) - ($9))|0;
 $18 = $17 >> 2;
 $19 = ($6>>>0)>($18>>>0);
 $20 = $3;
 $21 = (($20) + ($18<<2)|0);
 $22 = $21;
 $$ = $19 ? $22 : $4;
 $23 = $$;
 $24 = ($20|0)==($23|0);
 $25 = $16;
 if ($24) {
  $$0$lcssa$i$i = $13;
 } else {
  $scevgep$i$i17 = ((($23)) + -4|0);
  $26 = $scevgep$i$i17;
  $27 = (($26) - ($3))|0;
  $$03$i$i = $13;$29 = $20;
  while(1) {
   $28 = HEAP32[$29>>2]|0;
   HEAP32[$$03$i$i>>2] = $28;
   $30 = ((($29)) + 4|0);
   $31 = ((($$03$i$i)) + 4|0);
   $32 = ($30|0)==($23|0);
   if ($32) {
    break;
   } else {
    $$03$i$i = $31;$29 = $30;
   }
  }
  $33 = $27 >>> 2;
  $34 = (($33) + 1)|0;
  $scevgep9$i$i = (($13) + ($34<<2)|0);
  $$0$lcssa$i$i = $scevgep9$i$i;
 }
 if (!($19)) {
  $46 = ($25|0)==($$0$lcssa$i$i|0);
  if ($46) {
   return;
  }
  $scevgep$i$i10 = ((($25)) + -4|0);
  $47 = $scevgep$i$i10;
  $48 = $$0$lcssa$i$i;
  $49 = (($47) - ($48))|0;
  $50 = $49 >>> 2;
  $51 = $50 ^ -1;
  $scevgep5$i$i = (($25) + ($51<<2)|0);
  HEAP32[$15>>2] = $scevgep5$i$i;
  return;
 }
 $35 = ($23|0)==($14|0);
 if ($35) {
  return;
 }
 $$promoted$i$i11 = HEAP32[$15>>2]|0;
 $scevgep$i$i12 = ((($14)) + -4|0);
 $36 = $scevgep$i$i12;
 $37 = (($36) - ($$))|0;
 $39 = $23;$40 = $$promoted$i$i11;
 while(1) {
  $38 = HEAP32[$39>>2]|0;
  HEAP32[$40>>2] = $38;
  $41 = ((($39)) + 4|0);
  $42 = ((($40)) + 4|0);
  $43 = ($41|0)==($14|0);
  if ($43) {
   break;
  } else {
   $39 = $41;$40 = $42;
  }
 }
 $44 = $37 >>> 2;
 $45 = (($44) + 1)|0;
 $scevgep10$i$i14 = (($$promoted$i$i11) + ($45<<2)|0);
 HEAP32[$15>>2] = $scevgep10$i$i14;
 return;
}
function __ZNSt3__26vectorIxNS_9allocatorIxEEE6assignINS_11__wrap_iterIPKxEEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIxNS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$ = 0, $$0$lcssa$i$i = 0, $$03$i$i = 0, $$promoted$i$i11 = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $12 = 0;
 var $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $scevgep$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i10 = 0, $scevgep$i$i12 = 0, $scevgep$i$i17 = 0, $scevgep10$i$i = 0;
 var $scevgep10$i$i14 = 0, $scevgep5$i$i = 0, $scevgep5$i$i$i$i = 0, $scevgep9$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = HEAP32[$1>>2]|0;
 $4 = HEAP32[$2>>2]|0;
 $5 = (($4) - ($3))|0;
 $6 = $5 >> 3;
 $7 = ((($0)) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$0>>2]|0;
 $10 = (($8) - ($9))|0;
 $11 = $10 >> 3;
 $12 = ($6>>>0)>($11>>>0);
 $13 = $9;
 $14 = $4;
 if ($12) {
  $70 = ($9|0)==(0);
  $71 = $9;
  if ($70) {
   $81 = $8;
  } else {
   $72 = ((($0)) + 4|0);
   $73 = HEAP32[$72>>2]|0;
   $74 = ($73|0)==($13|0);
   if (!($74)) {
    $scevgep$i$i$i$i = ((($73)) + -8|0);
    $75 = $scevgep$i$i$i$i;
    $76 = (($75) - ($9))|0;
    $77 = $76 >>> 3;
    $78 = $77 ^ -1;
    $scevgep5$i$i$i$i = (($73) + ($78<<3)|0);
    HEAP32[$72>>2] = $scevgep5$i$i$i$i;
   }
   __ZdlPv($71);
   HEAP32[$7>>2] = 0;
   HEAP32[$72>>2] = 0;
   HEAP32[$0>>2] = 0;
   $81 = 0;
  }
  $79 = ($6>>>0)>(536870911);
  if ($79) {
   __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
   // unreachable;
  }
  $80 = $81 >> 3;
  $82 = ($80>>>0)<(268435455);
  $83 = $81 >> 2;
  $84 = ($83>>>0)<($6>>>0);
  $$sroa$speculated$i = $84 ? $6 : $83;
  $$sroa$speculated$$i = $82 ? $$sroa$speculated$i : 536870911;
  $85 = ($$sroa$speculated$$i>>>0)>(536870911);
  if ($85) {
   __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
   // unreachable;
  }
  $86 = $$sroa$speculated$$i << 3;
  $87 = (__Znwj($86)|0);
  $88 = ((($0)) + 4|0);
  HEAP32[$88>>2] = $87;
  HEAP32[$0>>2] = $87;
  $89 = (($87) + ($$sroa$speculated$$i<<3)|0);
  HEAP32[$7>>2] = $89;
  $90 = $3;
  $91 = ($90|0)==($14|0);
  if ($91) {
   return;
  }
  $scevgep$i$i = ((($14)) + -8|0);
  $92 = $scevgep$i$i;
  $93 = (($92) - ($3))|0;
  $101 = $87;$94 = $90;
  while(1) {
   $95 = $94;
   $96 = $95;
   $97 = HEAP32[$96>>2]|0;
   $98 = (($95) + 4)|0;
   $99 = $98;
   $100 = HEAP32[$99>>2]|0;
   $102 = $101;
   $103 = $102;
   HEAP32[$103>>2] = $97;
   $104 = (($102) + 4)|0;
   $105 = $104;
   HEAP32[$105>>2] = $100;
   $106 = ((($94)) + 8|0);
   $107 = ((($101)) + 8|0);
   $108 = ($106|0)==($14|0);
   if ($108) {
    break;
   } else {
    $101 = $107;$94 = $106;
   }
  }
  $109 = $93 >>> 3;
  $110 = (($109) + 1)|0;
  $scevgep10$i$i = (($87) + ($110<<3)|0);
  HEAP32[$88>>2] = $scevgep10$i$i;
  return;
 }
 $15 = ((($0)) + 4|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) - ($9))|0;
 $18 = $17 >> 3;
 $19 = ($6>>>0)>($18>>>0);
 $20 = $3;
 $21 = (($20) + ($18<<3)|0);
 $22 = $21;
 $$ = $19 ? $22 : $4;
 $23 = $$;
 $24 = ($20|0)==($23|0);
 $25 = $16;
 if ($24) {
  $$0$lcssa$i$i = $13;
 } else {
  $scevgep$i$i17 = ((($23)) + -8|0);
  $26 = $scevgep$i$i17;
  $27 = (($26) - ($3))|0;
  $$03$i$i = $13;$28 = $20;
  while(1) {
   $29 = $28;
   $30 = $29;
   $31 = HEAP32[$30>>2]|0;
   $32 = (($29) + 4)|0;
   $33 = $32;
   $34 = HEAP32[$33>>2]|0;
   $35 = $$03$i$i;
   $36 = $35;
   HEAP32[$36>>2] = $31;
   $37 = (($35) + 4)|0;
   $38 = $37;
   HEAP32[$38>>2] = $34;
   $39 = ((($28)) + 8|0);
   $40 = ((($$03$i$i)) + 8|0);
   $41 = ($39|0)==($23|0);
   if ($41) {
    break;
   } else {
    $$03$i$i = $40;$28 = $39;
   }
  }
  $42 = $27 >>> 3;
  $43 = (($42) + 1)|0;
  $scevgep9$i$i = (($13) + ($43<<3)|0);
  $$0$lcssa$i$i = $scevgep9$i$i;
 }
 if (!($19)) {
  $64 = ($25|0)==($$0$lcssa$i$i|0);
  if ($64) {
   return;
  }
  $scevgep$i$i10 = ((($25)) + -8|0);
  $65 = $scevgep$i$i10;
  $66 = $$0$lcssa$i$i;
  $67 = (($65) - ($66))|0;
  $68 = $67 >>> 3;
  $69 = $68 ^ -1;
  $scevgep5$i$i = (($25) + ($69<<3)|0);
  HEAP32[$15>>2] = $scevgep5$i$i;
  return;
 }
 $44 = ($23|0)==($14|0);
 if ($44) {
  return;
 }
 $$promoted$i$i11 = HEAP32[$15>>2]|0;
 $scevgep$i$i12 = ((($14)) + -8|0);
 $45 = $scevgep$i$i12;
 $46 = (($45) - ($$))|0;
 $47 = $23;$54 = $$promoted$i$i11;
 while(1) {
  $48 = $47;
  $49 = $48;
  $50 = HEAP32[$49>>2]|0;
  $51 = (($48) + 4)|0;
  $52 = $51;
  $53 = HEAP32[$52>>2]|0;
  $55 = $54;
  $56 = $55;
  HEAP32[$56>>2] = $50;
  $57 = (($55) + 4)|0;
  $58 = $57;
  HEAP32[$58>>2] = $53;
  $59 = ((($47)) + 8|0);
  $60 = ((($54)) + 8|0);
  $61 = ($59|0)==($14|0);
  if ($61) {
   break;
  } else {
   $47 = $59;$54 = $60;
  }
 }
 $62 = $46 >>> 3;
 $63 = (($62) + 1)|0;
 $scevgep10$i$i14 = (($$promoted$i$i11) + ($63<<3)|0);
 HEAP32[$15>>2] = $scevgep10$i$i14;
 return;
}
function __ZNSt3__26vectorIyNS_9allocatorIyEEE6assignINS_11__wrap_iterIPKyEEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIyNS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$ = 0, $$0$lcssa$i$i = 0, $$03$i$i = 0, $$promoted$i$i11 = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $12 = 0;
 var $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $scevgep$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i10 = 0, $scevgep$i$i12 = 0, $scevgep$i$i17 = 0, $scevgep10$i$i = 0;
 var $scevgep10$i$i14 = 0, $scevgep5$i$i = 0, $scevgep5$i$i$i$i = 0, $scevgep9$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = HEAP32[$1>>2]|0;
 $4 = HEAP32[$2>>2]|0;
 $5 = (($4) - ($3))|0;
 $6 = $5 >> 3;
 $7 = ((($0)) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$0>>2]|0;
 $10 = (($8) - ($9))|0;
 $11 = $10 >> 3;
 $12 = ($6>>>0)>($11>>>0);
 $13 = $9;
 $14 = $4;
 if ($12) {
  $70 = ($9|0)==(0);
  $71 = $9;
  if ($70) {
   $81 = $8;
  } else {
   $72 = ((($0)) + 4|0);
   $73 = HEAP32[$72>>2]|0;
   $74 = ($73|0)==($13|0);
   if (!($74)) {
    $scevgep$i$i$i$i = ((($73)) + -8|0);
    $75 = $scevgep$i$i$i$i;
    $76 = (($75) - ($9))|0;
    $77 = $76 >>> 3;
    $78 = $77 ^ -1;
    $scevgep5$i$i$i$i = (($73) + ($78<<3)|0);
    HEAP32[$72>>2] = $scevgep5$i$i$i$i;
   }
   __ZdlPv($71);
   HEAP32[$7>>2] = 0;
   HEAP32[$72>>2] = 0;
   HEAP32[$0>>2] = 0;
   $81 = 0;
  }
  $79 = ($6>>>0)>(536870911);
  if ($79) {
   __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
   // unreachable;
  }
  $80 = $81 >> 3;
  $82 = ($80>>>0)<(268435455);
  $83 = $81 >> 2;
  $84 = ($83>>>0)<($6>>>0);
  $$sroa$speculated$i = $84 ? $6 : $83;
  $$sroa$speculated$$i = $82 ? $$sroa$speculated$i : 536870911;
  $85 = ($$sroa$speculated$$i>>>0)>(536870911);
  if ($85) {
   __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
   // unreachable;
  }
  $86 = $$sroa$speculated$$i << 3;
  $87 = (__Znwj($86)|0);
  $88 = ((($0)) + 4|0);
  HEAP32[$88>>2] = $87;
  HEAP32[$0>>2] = $87;
  $89 = (($87) + ($$sroa$speculated$$i<<3)|0);
  HEAP32[$7>>2] = $89;
  $90 = $3;
  $91 = ($90|0)==($14|0);
  if ($91) {
   return;
  }
  $scevgep$i$i = ((($14)) + -8|0);
  $92 = $scevgep$i$i;
  $93 = (($92) - ($3))|0;
  $101 = $87;$94 = $90;
  while(1) {
   $95 = $94;
   $96 = $95;
   $97 = HEAP32[$96>>2]|0;
   $98 = (($95) + 4)|0;
   $99 = $98;
   $100 = HEAP32[$99>>2]|0;
   $102 = $101;
   $103 = $102;
   HEAP32[$103>>2] = $97;
   $104 = (($102) + 4)|0;
   $105 = $104;
   HEAP32[$105>>2] = $100;
   $106 = ((($94)) + 8|0);
   $107 = ((($101)) + 8|0);
   $108 = ($106|0)==($14|0);
   if ($108) {
    break;
   } else {
    $101 = $107;$94 = $106;
   }
  }
  $109 = $93 >>> 3;
  $110 = (($109) + 1)|0;
  $scevgep10$i$i = (($87) + ($110<<3)|0);
  HEAP32[$88>>2] = $scevgep10$i$i;
  return;
 }
 $15 = ((($0)) + 4|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) - ($9))|0;
 $18 = $17 >> 3;
 $19 = ($6>>>0)>($18>>>0);
 $20 = $3;
 $21 = (($20) + ($18<<3)|0);
 $22 = $21;
 $$ = $19 ? $22 : $4;
 $23 = $$;
 $24 = ($20|0)==($23|0);
 $25 = $16;
 if ($24) {
  $$0$lcssa$i$i = $13;
 } else {
  $scevgep$i$i17 = ((($23)) + -8|0);
  $26 = $scevgep$i$i17;
  $27 = (($26) - ($3))|0;
  $$03$i$i = $13;$28 = $20;
  while(1) {
   $29 = $28;
   $30 = $29;
   $31 = HEAP32[$30>>2]|0;
   $32 = (($29) + 4)|0;
   $33 = $32;
   $34 = HEAP32[$33>>2]|0;
   $35 = $$03$i$i;
   $36 = $35;
   HEAP32[$36>>2] = $31;
   $37 = (($35) + 4)|0;
   $38 = $37;
   HEAP32[$38>>2] = $34;
   $39 = ((($28)) + 8|0);
   $40 = ((($$03$i$i)) + 8|0);
   $41 = ($39|0)==($23|0);
   if ($41) {
    break;
   } else {
    $$03$i$i = $40;$28 = $39;
   }
  }
  $42 = $27 >>> 3;
  $43 = (($42) + 1)|0;
  $scevgep9$i$i = (($13) + ($43<<3)|0);
  $$0$lcssa$i$i = $scevgep9$i$i;
 }
 if (!($19)) {
  $64 = ($25|0)==($$0$lcssa$i$i|0);
  if ($64) {
   return;
  }
  $scevgep$i$i10 = ((($25)) + -8|0);
  $65 = $scevgep$i$i10;
  $66 = $$0$lcssa$i$i;
  $67 = (($65) - ($66))|0;
  $68 = $67 >>> 3;
  $69 = $68 ^ -1;
  $scevgep5$i$i = (($25) + ($69<<3)|0);
  HEAP32[$15>>2] = $scevgep5$i$i;
  return;
 }
 $44 = ($23|0)==($14|0);
 if ($44) {
  return;
 }
 $$promoted$i$i11 = HEAP32[$15>>2]|0;
 $scevgep$i$i12 = ((($14)) + -8|0);
 $45 = $scevgep$i$i12;
 $46 = (($45) - ($$))|0;
 $47 = $23;$54 = $$promoted$i$i11;
 while(1) {
  $48 = $47;
  $49 = $48;
  $50 = HEAP32[$49>>2]|0;
  $51 = (($48) + 4)|0;
  $52 = $51;
  $53 = HEAP32[$52>>2]|0;
  $55 = $54;
  $56 = $55;
  HEAP32[$56>>2] = $50;
  $57 = (($55) + 4)|0;
  $58 = $57;
  HEAP32[$58>>2] = $53;
  $59 = ((($47)) + 8|0);
  $60 = ((($54)) + 8|0);
  $61 = ($59|0)==($14|0);
  if ($61) {
   break;
  } else {
   $47 = $59;$54 = $60;
  }
 }
 $62 = $46 >>> 3;
 $63 = (($62) + 1)|0;
 $scevgep10$i$i14 = (($$promoted$i$i11) + ($63<<3)|0);
 HEAP32[$15>>2] = $scevgep10$i$i14;
 return;
}
function __GLOBAL__sub_I_Uniform_cpp() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $0 = sp;
 HEAPF32[52191] = 1.0;
 HEAPF32[(208768)>>2] = 0.0;
 HEAPF32[(208772)>>2] = 0.0;
 HEAPF32[52194] = 0.0;
 HEAPF32[(208780)>>2] = 1.0;
 HEAPF32[(208784)>>2] = 0.0;
 HEAPF32[52197] = 0.0;
 HEAPF32[(208792)>>2] = 0.0;
 HEAPF32[(208796)>>2] = 1.0;
 ;HEAP32[$0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;
 __THREW__ = 0;
 (invoke_ii(3862,($0|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $7 = ___cxa_find_matching_catch_2()|0;
  $8 = tempRet0;
  $9 = ((($0)) + 11|0);
  $10 = HEAP8[$9>>0]|0;
  $11 = ($10<<24>>24)<(0);
  if (!($11)) {
   ___resumeException($7|0);
   // unreachable;
  }
  $12 = HEAP32[$0>>2]|0;
  __ZdlPv($12);
  ___resumeException($7|0);
  // unreachable;
 } else {
  $3 = ((($0)) + 11|0);
  $4 = HEAP8[$3>>0]|0;
  $5 = ($4<<24>>24)<(0);
  if (!($5)) {
   STACKTOP = sp;return;
  }
  $6 = HEAP32[$0>>2]|0;
  __ZdlPv($6);
  STACKTOP = sp;return;
 }
}
function __ZN3osg7UniformC2ENS0_4TypeERKNSt3__212basic_stringIcNS2_11char_traitsIcEENS2_9allocatorIcEEEEi($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0;
 var $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, $scevgep$i$i$i = 0, $scevgep5$i$i$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $4 = sp;
 __ZN3osg10ReferencedC2Ev($0);
 $5 = ((($0)) + 12|0);
 ;HEAP32[$5>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;
 $6 = ((($0)) + 24|0);
 HEAP32[$6>>2] = 2;
 $7 = ((($0)) + 28|0);
 HEAP32[$7>>2] = 0;
 HEAP32[$0>>2] = (69328);
 $8 = ((($0)) + 32|0);
 HEAP32[$8>>2] = 0;
 $9 = ((($0)) + 36|0);
 HEAP32[$9>>2] = 0;
 $10 = ((($0)) + 40|0);
 HEAP32[$10>>2] = 0;
 $11 = ((($0)) + 44|0);
 HEAP32[$11>>2] = $1;
 $12 = ((($0)) + 48|0);
 HEAP32[$12>>2] = 0;
 $13 = ((($0)) + 52|0);
 HEAP32[$13>>2] = -1;
 $14 = ((($0)) + 56|0);
 $15 = ((($0)) + 60|0);
 $16 = ((($0)) + 64|0);
 $17 = ((($0)) + 68|0);
 $18 = ((($0)) + 72|0);
 $19 = ((($0)) + 76|0);
 $20 = ((($0)) + 80|0);
 $21 = ((($0)) + 84|0);
 dest=$14; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 __THREW__ = 0;
 $22 = (invoke_iiiiii(3253,($5|0),0,-1,(221531|0),0)|0);
 $23 = __THREW__; __THREW__ = 0;
 $24 = $23&1;
 if ($24) {
  $25 = ___cxa_find_matching_catch_2()|0;
  $26 = tempRet0;
  ___cxa_call_unexpected(($25|0));
  // unreachable;
 }
 $27 = ($22|0)==(0);
 do {
  if ($27) {
   __THREW__ = 0;
   (invoke_iii(3477,($5|0),($2|0))|0);
   $64 = __THREW__; __THREW__ = 0;
   $65 = $64&1;
   if ($65) {
    label = 23;
   } else {
    __THREW__ = 0;
    $66 = (invoke_ii(3862,($5|0))|0);
    $67 = __THREW__; __THREW__ = 0;
    $68 = $67&1;
    if ($68) {
     label = 23;
    } else {
     HEAP32[$13>>2] = $66;
     label = 20;
    }
   }
  } else {
   __THREW__ = 0;
   $28 = (invoke_ii(3265,2)|0);
   $29 = __THREW__; __THREW__ = 0;
   $30 = $29&1;
   if ($30) {
    label = 23;
   } else {
    if ($28) {
     __THREW__ = 0;
     $31 = (invoke_ii(3266,2)|0);
     $32 = __THREW__; __THREW__ = 0;
     $33 = $32&1;
     if ($33) {
      label = 23;
     } else {
      __THREW__ = 0;
      $34 = (invoke_iiii(3267,($31|0),(156511|0),26)|0);
      $35 = __THREW__; __THREW__ = 0;
      $36 = $35&1;
      if ($36) {
       label = 23;
      } else {
       $37 = HEAP32[$34>>2]|0;
       $38 = ((($37)) + -12|0);
       $39 = HEAP32[$38>>2]|0;
       $40 = (($34) + ($39)|0);
       __THREW__ = 0;
       invoke_vii(3257,($4|0),($40|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if ($42) {
        label = 23;
       } else {
        __THREW__ = 0;
        $43 = (invoke_iii(3255,($4|0),(215188|0))|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = HEAP32[$43>>2]|0;
         $47 = ((($46)) + 28|0);
         $48 = HEAP32[$47>>2]|0;
         __THREW__ = 0;
         $49 = (invoke_iii($48|0,($43|0),10)|0);
         $50 = __THREW__; __THREW__ = 0;
         $51 = $50&1;
         if (!($51)) {
          __THREW__ = 0;
          invoke_vi(3263,($4|0));
          $52 = __THREW__; __THREW__ = 0;
          $53 = $52&1;
          if ($53) {
           label = 23;
           break;
          }
          __THREW__ = 0;
          (invoke_iii(3268,($34|0),($49|0))|0);
          $60 = __THREW__; __THREW__ = 0;
          $61 = $60&1;
          if ($61) {
           label = 23;
           break;
          }
          __THREW__ = 0;
          (invoke_ii(3269,($34|0))|0);
          $62 = __THREW__; __THREW__ = 0;
          $63 = $62&1;
          if ($63) {
           label = 23;
           break;
          } else {
           label = 20;
           break;
          }
         }
        }
        $54 = ___cxa_find_matching_catch_2()|0;
        $55 = tempRet0;
        __THREW__ = 0;
        invoke_vi(3263,($4|0));
        $56 = __THREW__; __THREW__ = 0;
        $57 = $56&1;
        if ($57) {
         $58 = ___cxa_find_matching_catch_3(0|0)|0;
         $59 = tempRet0;
         ___clang_call_terminate($58);
         // unreachable;
        } else {
         $eh$lpad$body$index2Z2D = $55;$eh$lpad$body$indexZ2D = $54;
         break;
        }
       }
      }
     }
    } else {
     label = 20;
    }
   }
  }
 } while(0);
 if ((label|0) == 20) {
  __THREW__ = 0;
  invoke_vii(3994,($0|0),($3|0));
  $69 = __THREW__; __THREW__ = 0;
  $70 = $69&1;
  if ($70) {
   label = 23;
  } else {
   __THREW__ = 0;
   invoke_vi(3995,($0|0));
   $71 = __THREW__; __THREW__ = 0;
   $72 = $71&1;
   if ($72) {
    label = 23;
   } else {
    STACKTOP = sp;return;
   }
  }
 }
 if ((label|0) == 23) {
  $73 = ___cxa_find_matching_catch_2()|0;
  $74 = tempRet0;
  $eh$lpad$body$index2Z2D = $74;$eh$lpad$body$indexZ2D = $73;
 }
 $75 = HEAP32[$21>>2]|0;
 $76 = ($75|0)==(0|0);
 if (!($76)) {
  $77 = HEAP32[$75>>2]|0;
  $78 = ((($77)) + -16|0);
  $79 = HEAP32[$78>>2]|0;
  $80 = (($75) + ($79)|0);
  $81 = ((($80)) + 8|0);
  $82 = HEAP32[$81>>2]|0;HEAP32[$81>>2] = (($82-1)|0);
  $83 = ($82|0)==(1);
  if ($83) {
   __THREW__ = 0;
   invoke_viii(3262,($80|0),1,1);
   $84 = __THREW__; __THREW__ = 0;
   $85 = $84&1;
   if ($85) {
    $150 = ___cxa_find_matching_catch_3(0|0)|0;
    $151 = tempRet0;
    ___clang_call_terminate($150);
    // unreachable;
   }
  }
 }
 HEAP32[$21>>2] = 0;
 $86 = HEAP32[$20>>2]|0;
 $87 = ($86|0)==(0|0);
 if (!($87)) {
  $88 = HEAP32[$86>>2]|0;
  $89 = ((($88)) + -16|0);
  $90 = HEAP32[$89>>2]|0;
  $91 = (($86) + ($90)|0);
  $92 = ((($91)) + 8|0);
  $93 = HEAP32[$92>>2]|0;HEAP32[$92>>2] = (($93-1)|0);
  $94 = ($93|0)==(1);
  if ($94) {
   __THREW__ = 0;
   invoke_viii(3262,($91|0),1,1);
   $95 = __THREW__; __THREW__ = 0;
   $96 = $95&1;
   if ($96) {
    $150 = ___cxa_find_matching_catch_3(0|0)|0;
    $151 = tempRet0;
    ___clang_call_terminate($150);
    // unreachable;
   }
  }
 }
 HEAP32[$20>>2] = 0;
 $97 = HEAP32[$19>>2]|0;
 $98 = ($97|0)==(0|0);
 if (!($98)) {
  $99 = ((($97)) + 8|0);
  $100 = HEAP32[$99>>2]|0;HEAP32[$99>>2] = (($100-1)|0);
  $101 = ($100|0)==(1);
  if ($101) {
   __THREW__ = 0;
   invoke_viii(3262,($97|0),1,1);
   $102 = __THREW__; __THREW__ = 0;
   $103 = $102&1;
   if ($103) {
    $150 = ___cxa_find_matching_catch_3(0|0)|0;
    $151 = tempRet0;
    ___clang_call_terminate($150);
    // unreachable;
   }
  }
 }
 HEAP32[$19>>2] = 0;
 $104 = HEAP32[$18>>2]|0;
 $105 = ($104|0)==(0|0);
 if (!($105)) {
  $106 = ((($104)) + 8|0);
  $107 = HEAP32[$106>>2]|0;HEAP32[$106>>2] = (($107-1)|0);
  $108 = ($107|0)==(1);
  if ($108) {
   __THREW__ = 0;
   invoke_viii(3262,($104|0),1,1);
   $109 = __THREW__; __THREW__ = 0;
   $110 = $109&1;
   if ($110) {
    $150 = ___cxa_find_matching_catch_3(0|0)|0;
    $151 = tempRet0;
    ___clang_call_terminate($150);
    // unreachable;
   }
  }
 }
 HEAP32[$18>>2] = 0;
 $111 = HEAP32[$17>>2]|0;
 $112 = ($111|0)==(0|0);
 if (!($112)) {
  $113 = ((($111)) + 8|0);
  $114 = HEAP32[$113>>2]|0;HEAP32[$113>>2] = (($114-1)|0);
  $115 = ($114|0)==(1);
  if ($115) {
   __THREW__ = 0;
   invoke_viii(3262,($111|0),1,1);
   $116 = __THREW__; __THREW__ = 0;
   $117 = $116&1;
   if ($117) {
    $150 = ___cxa_find_matching_catch_3(0|0)|0;
    $151 = tempRet0;
    ___clang_call_terminate($150);
    // unreachable;
   }
  }
 }
 HEAP32[$17>>2] = 0;
 $118 = HEAP32[$16>>2]|0;
 $119 = ($118|0)==(0|0);
 if (!($119)) {
  $120 = ((($118)) + 8|0);
  $121 = HEAP32[$120>>2]|0;HEAP32[$120>>2] = (($121-1)|0);
  $122 = ($121|0)==(1);
  if ($122) {
   __THREW__ = 0;
   invoke_viii(3262,($118|0),1,1);
   $123 = __THREW__; __THREW__ = 0;
   $124 = $123&1;
   if ($124) {
    $150 = ___cxa_find_matching_catch_3(0|0)|0;
    $151 = tempRet0;
    ___clang_call_terminate($150);
    // unreachable;
   }
  }
 }
 HEAP32[$16>>2] = 0;
 $125 = HEAP32[$15>>2]|0;
 $126 = ($125|0)==(0|0);
 if (!($126)) {
  $127 = ((($125)) + 8|0);
  $128 = HEAP32[$127>>2]|0;HEAP32[$127>>2] = (($128-1)|0);
  $129 = ($128|0)==(1);
  if ($129) {
   __THREW__ = 0;
   invoke_viii(3262,($125|0),1,1);
   $130 = __THREW__; __THREW__ = 0;
   $131 = $130&1;
   if ($131) {
    $150 = ___cxa_find_matching_catch_3(0|0)|0;
    $151 = tempRet0;
    ___clang_call_terminate($150);
    // unreachable;
   }
  }
 }
 HEAP32[$15>>2] = 0;
 $132 = HEAP32[$14>>2]|0;
 $133 = ($132|0)==(0|0);
 if (!($133)) {
  $134 = ((($132)) + 8|0);
  $135 = HEAP32[$134>>2]|0;HEAP32[$134>>2] = (($135-1)|0);
  $136 = ($135|0)==(1);
  if ($136) {
   __THREW__ = 0;
   invoke_viii(3262,($132|0),1,1);
   $137 = __THREW__; __THREW__ = 0;
   $138 = $137&1;
   if ($138) {
    $150 = ___cxa_find_matching_catch_3(0|0)|0;
    $151 = tempRet0;
    ___clang_call_terminate($150);
    // unreachable;
   }
  }
 }
 HEAP32[$14>>2] = 0;
 $139 = HEAP32[$8>>2]|0;
 $140 = ($139|0)==(0|0);
 if (!($140)) {
  $141 = HEAP32[$9>>2]|0;
  $142 = ($141|0)==($139|0);
  if (!($142)) {
   $scevgep$i$i$i = ((($141)) + -4|0);
   $143 = $scevgep$i$i$i;
   $144 = $139;
   $145 = (($143) - ($144))|0;
   $146 = $145 >>> 2;
   $147 = $146 ^ -1;
   $scevgep5$i$i$i = (($141) + ($147<<2)|0);
   HEAP32[$9>>2] = $scevgep5$i$i$i;
  }
  __ZdlPv($139);
 }
 __THREW__ = 0;
 invoke_vi(388,($0|0));
 $148 = __THREW__; __THREW__ = 0;
 $149 = $148&1;
 if ($149) {
  $150 = ___cxa_find_matching_catch_3(0|0)|0;
  $151 = tempRet0;
  ___clang_call_terminate($150);
  // unreachable;
 } else {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
}
function __ZN3osg7Uniform14setNumElementsEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp + 4|0;
 $3 = sp;
 $4 = ($1|0)==(0);
 if ($4) {
  $5 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
  if (!($5)) {
   STACKTOP = sp;return;
  }
  $6 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
  $7 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($6,156561,34)|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ((($8)) + -12|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($7) + ($10)|0);
  __ZNKSt3__28ios_base6getlocEv($3,$11);
  __THREW__ = 0;
  $12 = (invoke_iii(3255,($3|0),(215188|0))|0);
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if (!($14)) {
   $15 = HEAP32[$12>>2]|0;
   $16 = ((($15)) + 28|0);
   $17 = HEAP32[$16>>2]|0;
   __THREW__ = 0;
   $18 = (invoke_iii($17|0,($12|0),10)|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZNSt3__26localeD2Ev($3);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($7,$18)|0);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($7)|0);
    STACKTOP = sp;return;
   }
  }
  $21 = ___cxa_find_matching_catch_2()|0;
  $22 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3263,($3|0));
  $23 = __THREW__; __THREW__ = 0;
  $24 = $23&1;
  if ($24) {
   $25 = ___cxa_find_matching_catch_3(0|0)|0;
   $26 = tempRet0;
   ___clang_call_terminate($25);
   // unreachable;
  } else {
   ___resumeException($21|0);
   // unreachable;
  }
 }
 $27 = ((($0)) + 48|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = ($28|0)==($1|0);
 if ($29) {
  STACKTOP = sp;return;
 }
 $30 = ($28|0)==(0);
 if ($30) {
  HEAP32[$27>>2] = $1;
  __ZN3osg7Uniform17allocateDataArrayEv($0);
  STACKTOP = sp;return;
 }
 $31 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
 if (!($31)) {
  STACKTOP = sp;return;
 }
 $32 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
 $33 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($32,156596,89)|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ((($34)) + -12|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = (($33) + ($36)|0);
 __ZNKSt3__28ios_base6getlocEv($2,$37);
 __THREW__ = 0;
 $38 = (invoke_iii(3255,($2|0),(215188|0))|0);
 $39 = __THREW__; __THREW__ = 0;
 $40 = $39&1;
 if (!($40)) {
  $41 = HEAP32[$38>>2]|0;
  $42 = ((($41)) + 28|0);
  $43 = HEAP32[$42>>2]|0;
  __THREW__ = 0;
  $44 = (invoke_iii($43|0,($38|0),10)|0);
  $45 = __THREW__; __THREW__ = 0;
  $46 = $45&1;
  if (!($46)) {
   __ZNSt3__26localeD2Ev($2);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($33,$44)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($33)|0);
   STACKTOP = sp;return;
  }
 }
 $47 = ___cxa_find_matching_catch_2()|0;
 $48 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($2|0));
 $49 = __THREW__; __THREW__ = 0;
 $50 = $49&1;
 if ($50) {
  $51 = ___cxa_find_matching_catch_3(0|0)|0;
  $52 = tempRet0;
  ___clang_call_terminate($51);
  // unreachable;
 } else {
  ___resumeException($47|0);
  // unreachable;
 }
}
function __ZN3osg7Uniform9addParentEPNS_8StateSetE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp + 4|0;
 $3 = sp;
 HEAP32[$3>>2] = $1;
 $4 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(6)|0);
 do {
  if ($4) {
   $5 = (__ZN3osg6notifyENS_14NotifySeverityE(6)|0);
   $6 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($5,156686,21)|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ((($7)) + -12|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($6) + ($9)|0);
   __ZNKSt3__28ios_base6getlocEv($2,$10);
   __THREW__ = 0;
   $11 = (invoke_iii(3255,($2|0),(215188|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[$11>>2]|0;
    $15 = ((($14)) + 28|0);
    $16 = HEAP32[$15>>2]|0;
    __THREW__ = 0;
    $17 = (invoke_iii($16|0,($11|0),10)|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     __ZNSt3__26localeD2Ev($2);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($6,$17)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($6)|0);
     break;
    }
   }
   $20 = ___cxa_find_matching_catch_2()|0;
   $21 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($2|0));
   $22 = __THREW__; __THREW__ = 0;
   $23 = $22&1;
   if ($23) {
    $24 = ___cxa_find_matching_catch_3(0|0)|0;
    $25 = tempRet0;
    ___clang_call_terminate($24);
    // unreachable;
   } else {
    ___resumeException($20|0);
    // unreachable;
   }
  }
 } while(0);
 $26 = (__ZN3osg10Referenced24getGlobalReferencedMutexEv()|0);
 $27 = ($26|0)==(0|0);
 if (!($27)) {
  $28 = HEAP32[$26>>2]|0;
  $29 = ((($28)) + 8|0);
  $30 = HEAP32[$29>>2]|0;
  (FUNCTION_TABLE_ii[$30 & 8191]($26)|0);
 }
 $31 = ((($0)) + 36|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = ((($0)) + 40|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($32|0)==($34|0);
 if ($35) {
  $39 = ((($0)) + 32|0);
  __THREW__ = 0;
  invoke_vii(3914,($39|0),($3|0));
  $40 = __THREW__; __THREW__ = 0;
  $41 = $40&1;
  if ($41) {
   $45 = ___cxa_find_matching_catch_2()|0;
   $46 = tempRet0;
   if ($27) {
    ___resumeException($45|0);
    // unreachable;
   }
   $47 = HEAP32[$26>>2]|0;
   $48 = ((($47)) + 12|0);
   $49 = HEAP32[$48>>2]|0;
   __THREW__ = 0;
   (invoke_ii($49|0,($26|0))|0);
   $50 = __THREW__; __THREW__ = 0;
   $51 = $50&1;
   if ($51) {
    $52 = ___cxa_find_matching_catch_3(0|0)|0;
    $53 = tempRet0;
    ___clang_call_terminate($52);
    // unreachable;
   } else {
    ___resumeException($45|0);
    // unreachable;
   }
  }
 } else {
  $36 = HEAP32[$3>>2]|0;
  HEAP32[$32>>2] = $36;
  $37 = HEAP32[$31>>2]|0;
  $38 = ((($37)) + 4|0);
  HEAP32[$31>>2] = $38;
 }
 if ($27) {
  STACKTOP = sp;return;
 }
 $42 = HEAP32[$26>>2]|0;
 $43 = ((($42)) + 12|0);
 $44 = HEAP32[$43>>2]|0;
 (FUNCTION_TABLE_ii[$44 & 8191]($26)|0);
 STACKTOP = sp;return;
}
function __ZN3osg7Uniform12removeParentEPNS_8StateSetE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$pre$i = 0, $$sroa$0$0$copyload$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i = 0, $scevgep5$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__ZN3osg10Referenced24getGlobalReferencedMutexEv()|0);
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = HEAP32[$2>>2]|0;
  $5 = ((($4)) + 8|0);
  $6 = HEAP32[$5>>2]|0;
  (FUNCTION_TABLE_ii[$6 & 8191]($2)|0);
 }
 $7 = ((($0)) + 32|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($0)) + 36|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8|0)==($10|0);
 $12 = $10;
 L4: do {
  if ($11) {
   $$sroa$0$0$copyload$i = $8;
   label = 6;
  } else {
   $14 = $8;
   while(1) {
    $13 = HEAP32[$14>>2]|0;
    $15 = ($13|0)==($1|0);
    if ($15) {
     $$sroa$0$0$copyload$i = $14;
     label = 6;
     break L4;
    }
    $16 = ((($14)) + 4|0);
    $17 = ($16|0)==($10|0);
    if ($17) {
     break;
    } else {
     $14 = $16;
    }
   }
  }
 } while(0);
 if ((label|0) == 6) {
  $18 = ($$sroa$0$0$copyload$i|0)==($10|0);
  if (!($18)) {
   $19 = ((($$sroa$0$0$copyload$i)) + 4|0);
   $20 = $19;
   $21 = (($12) - ($20))|0;
   $22 = $21 >> 2;
   $23 = ($22|0)==(0);
   if ($23) {
    $25 = $10;
   } else {
    _memmove(($$sroa$0$0$copyload$i|0),($19|0),($21|0))|0;
    $$pre$i = HEAP32[$9>>2]|0;
    $25 = $$pre$i;
   }
   $24 = (($$sroa$0$0$copyload$i) + ($22<<2)|0);
   $26 = ($25|0)==($24|0);
   if (!($26)) {
    $scevgep$i$i$i = ((($25)) + -4|0);
    $27 = $scevgep$i$i$i;
    $28 = $24;
    $29 = (($27) - ($28))|0;
    $30 = $29 >>> 2;
    $31 = $30 ^ -1;
    $scevgep5$i$i$i = (($25) + ($31<<2)|0);
    HEAP32[$9>>2] = $scevgep5$i$i$i;
   }
  }
 }
 if ($3) {
  return;
 }
 $32 = HEAP32[$2>>2]|0;
 $33 = ((($32)) + 12|0);
 $34 = HEAP32[$33>>2]|0;
 (FUNCTION_TABLE_ii[$34 & 8191]($2)|0);
 return;
}
function __ZNK3osg7Uniform16isCompatibleTypeENS0_4TypeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$0$i = 0, $$0$i5 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $switch$split102D = 0, $switch$split12D = 0, $switch$split132D = 0, $switch$split162D = 0, $switch$split192D = 0, $switch$split222D = 0, $switch$split252D = 0, $switch$split2D = 0, $switch$split42D = 0, $switch$split72D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = ($1|0)==(0);
 if ($3) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = ((($0)) + 44|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $7 = ($5|0)==($1|0);
 if ($7) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $switch$split2D = ($1|0)<(36879);
 L10: do {
  if ($switch$split2D) {
   $switch$split42D = ($1|0)<(36293);
   if (!($switch$split42D)) {
    switch ($1|0) {
    case 36309: case 36312: case 36311: case 36310: case 36308: case 36307: case 36306: case 36305: case 36301: case 36304: case 36878: case 36303: case 36302: case 36300: case 36299: case 36298: case 36297: case 36877: case 36293: case 36876:  {
     $$0$i = 5124;
     break L10;
     break;
    }
    default: {
     label = 10;
     break L10;
    }
    }
   }
   $switch$split102D = ($1|0)<(35680);
   if (!($switch$split102D)) {
    switch ($1|0) {
    case 35684: case 35683: case 36290: case 36292: case 36291: case 36289: case 36288: case 35682: case 35681: case 35680:  {
     $$0$i = 5124;
     break L10;
     break;
    }
    default: {
     label = 10;
     break L10;
    }
    }
   }
   $switch$split162D = ($1|0)<(35672);
   if (!($switch$split162D)) {
    switch ($1|0) {
    case 35679: case 35678: case 35677:  {
     $$0$i = 5124;
     break L10;
     break;
    }
    case 35672:  {
     $$0$i = 35668;
     break L10;
     break;
    }
    case 35673:  {
     $$0$i = 35669;
     break L10;
     break;
    }
    default: {
     label = 10;
     break L10;
    }
    }
   }
   $switch$split222D = ($1|0)<(35670);
   if (!($switch$split222D)) {
    switch ($1|0) {
    case 35670:  {
     $$0$i = 5124;
     break L10;
     break;
    }
    case 35671:  {
     break;
    }
    default: {
     label = 10;
     break L10;
    }
    }
    $$0$i = 35667;
    break;
   }
   switch ($1|0) {
   case 5135:  {
    $$0$i = $1;
    break L10;
    break;
   }
   case 5134:  {
    $$0$i = $1;
    break L10;
    break;
   }
   default: {
    label = 10;
    break L10;
   }
   }
  } else {
   switch ($1|0) {
   case 36972: case 36971: case 36970: case 36969: case 36968: case 36967: case 36966: case 36965: case 36964: case 36963: case 36962: case 36961: case 36960: case 36959: case 36958: case 36957: case 36956: case 36955: case 36954: case 36953: case 36952: case 36951: case 36950: case 36949: case 36948: case 36947: case 36946: case 36945: case 36944: case 36943: case 36942: case 36941: case 36940: case 37133: case 37130: case 36879: case 37132: case 37129: case 37131: case 37128:  {
    $$0$i = 5124;
    break;
   }
   default: {
    label = 10;
   }
   }
  }
 } while(0);
 if ((label|0) == 10) {
  $$0$i = $1;
 }
 $switch$split12D = ($5|0)<(36879);
 L35: do {
  if ($switch$split12D) {
   $switch$split72D = ($5|0)<(36293);
   if (!($switch$split72D)) {
    switch ($5|0) {
    case 36309: case 36312: case 36311: case 36310: case 36308: case 36307: case 36306: case 36305: case 36301: case 36304: case 36878: case 36303: case 36302: case 36300: case 36299: case 36298: case 36297: case 36877: case 36293: case 36876:  {
     $$0$i5 = 5124;
     break L35;
     break;
    }
    default: {
     label = 17;
     break L35;
    }
    }
   }
   $switch$split132D = ($5|0)<(35680);
   if (!($switch$split132D)) {
    switch ($5|0) {
    case 35684: case 35683: case 36290: case 36292: case 36291: case 36289: case 36288: case 35682: case 35681: case 35680:  {
     $$0$i5 = 5124;
     break L35;
     break;
    }
    default: {
     label = 17;
     break L35;
    }
    }
   }
   $switch$split192D = ($5|0)<(35672);
   if (!($switch$split192D)) {
    switch ($5|0) {
    case 35679: case 35678: case 35677:  {
     $$0$i5 = 5124;
     break L35;
     break;
    }
    case 35672:  {
     $$0$i5 = 35668;
     break L35;
     break;
    }
    case 35673:  {
     $$0$i5 = 35669;
     break L35;
     break;
    }
    default: {
     label = 17;
     break L35;
    }
    }
   }
   $switch$split252D = ($5|0)<(35670);
   if (!($switch$split252D)) {
    switch ($5|0) {
    case 35670:  {
     $$0$i5 = 5124;
     break L35;
     break;
    }
    case 35671:  {
     break;
    }
    default: {
     label = 17;
     break L35;
    }
    }
    $$0$i5 = 35667;
    break;
   }
   switch ($5|0) {
   case 5135:  {
    $$0$i5 = $5;
    break L35;
    break;
   }
   case 5134:  {
    $$0$i5 = $5;
    break L35;
    break;
   }
   default: {
    label = 17;
    break L35;
   }
   }
  } else {
   switch ($5|0) {
   case 36972: case 36971: case 36970: case 36969: case 36968: case 36967: case 36966: case 36965: case 36964: case 36963: case 36962: case 36961: case 36960: case 36959: case 36958: case 36957: case 36956: case 36955: case 36954: case 36953: case 36952: case 36951: case 36950: case 36949: case 36948: case 36947: case 36946: case 36945: case 36944: case 36943: case 36942: case 36941: case 36940: case 37133: case 37130: case 36879: case 37132: case 37129: case 37131: case 37128:  {
    $$0$i5 = 5124;
    break;
   }
   default: {
    label = 17;
   }
   }
  }
 } while(0);
 if ((label|0) == 17) {
  $$0$i5 = $5;
 }
 $8 = ($$0$i|0)==($$0$i5|0);
 if ($8) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $9 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
 if (!($9)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $10 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
 $11 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($10,156708,36)|0);
 $12 = (__ZN3osg7Uniform11getTypenameENS0_4TypeE($1)|0);
 $13 = (_strlen($12)|0);
 $14 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($11,$12,$13)|0);
 $15 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($14,171881,5)|0);
 $16 = HEAP32[$4>>2]|0;
 $17 = (__ZN3osg7Uniform11getTypenameENS0_4TypeE($16)|0);
 $18 = (_strlen($17)|0);
 $19 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($15,$17,$18)|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ((($20)) + -12|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($19) + ($22)|0);
 __ZNKSt3__28ios_base6getlocEv($2,$23);
 __THREW__ = 0;
 $24 = (invoke_iii(3255,($2|0),(215188|0))|0);
 $25 = __THREW__; __THREW__ = 0;
 $26 = $25&1;
 if (!($26)) {
  $27 = HEAP32[$24>>2]|0;
  $28 = ((($27)) + 28|0);
  $29 = HEAP32[$28>>2]|0;
  __THREW__ = 0;
  $30 = (invoke_iii($29|0,($24|0),10)|0);
  $31 = __THREW__; __THREW__ = 0;
  $32 = $31&1;
  if (!($32)) {
   __ZNSt3__26localeD2Ev($2);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($19,$30)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($19)|0);
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $33 = ___cxa_find_matching_catch_2()|0;
 $34 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($2|0));
 $35 = __THREW__; __THREW__ = 0;
 $36 = $35&1;
 if ($36) {
  $37 = ___cxa_find_matching_catch_3(0|0)|0;
  $38 = tempRet0;
  ___clang_call_terminate($37);
  // unreachable;
 } else {
  ___resumeException($33|0);
  // unreachable;
 }
 return (0)|0;
}
function __ZN3osg7Uniform11getTypenameENS0_4TypeE($0) {
 $0 = $0|0;
 var $$0 = 0, $switch$split102D = 0, $switch$split12D = 0, $switch$split132D = 0, $switch$split162D = 0, $switch$split2D = 0, $switch$split42D = 0, $switch$split72D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $switch$split2D = ($0|0)<(36311);
 L1: do {
  if ($switch$split2D) {
   $switch$split12D = ($0|0)<(35686);
   if (!($switch$split12D)) {
    do {
     switch ($0|0) {
     case 36294:  {
      $$0 = 157933;
      break L1;
      break;
     }
     case 36295:  {
      $$0 = 157926;
      break L1;
      break;
     }
     case 36296:  {
      $$0 = 157919;
      break L1;
      break;
     }
     case 35686:  {
      $$0 = 157850;
      break L1;
      break;
     }
     case 35687:  {
      $$0 = 157843;
      break L1;
      break;
     }
     case 35688:  {
      $$0 = 157836;
      break L1;
      break;
     }
     case 35689:  {
      $$0 = 157829;
      break L1;
      break;
     }
     case 35690:  {
      $$0 = 157822;
      break L1;
      break;
     }
     case 36288:  {
      $$0 = 157667;
      break L1;
      break;
     }
     case 36289:  {
      $$0 = 157652;
      break L1;
      break;
     }
     case 36291:  {
      $$0 = 157611;
      break L1;
      break;
     }
     case 36292:  {
      $$0 = 157590;
      break L1;
      break;
     }
     case 36293:  {
      $$0 = 157543;
      break L1;
      break;
     }
     case 36290:  {
      $$0 = 157503;
      break L1;
      break;
     }
     case 36297:  {
      $$0 = 157458;
      break L1;
      break;
     }
     case 36298:  {
      $$0 = 157447;
      break L1;
      break;
     }
     case 36299:  {
      $$0 = 157436;
      break L1;
      break;
     }
     case 36300:  {
      $$0 = 157423;
      break L1;
      break;
     }
     case 36302:  {
      $$0 = 157407;
      break L1;
      break;
     }
     case 36303:  {
      $$0 = 157391;
      break L1;
      break;
     }
     case 36304:  {
      $$0 = 157324;
      break L1;
      break;
     }
     case 36301:  {
      $$0 = 157309;
      break L1;
      break;
     }
     case 36305:  {
      $$0 = 157298;
      break L1;
      break;
     }
     case 36306:  {
      $$0 = 157287;
      break L1;
      break;
     }
     case 36307:  {
      $$0 = 157276;
      break L1;
      break;
     }
     case 36308:  {
      $$0 = 157263;
      break L1;
      break;
     }
     case 36310:  {
      $$0 = 157247;
      break L1;
      break;
     }
     case 36309:  {
      $$0 = 157149;
      break L1;
      break;
     }
     default: {
      label = 114;
      break L1;
     }
     }
    } while(0);
   }
   $switch$split42D = ($0|0)<(35672);
   if (!($switch$split42D)) {
    do {
     switch ($0|0) {
     case 35672:  {
      $$0 = 157902;
      break L1;
      break;
     }
     case 35673:  {
      $$0 = 157896;
      break L1;
      break;
     }
     case 35674:  {
      $$0 = 157874;
      break L1;
      break;
     }
     case 35675:  {
      $$0 = 157869;
      break L1;
      break;
     }
     case 35676:  {
      $$0 = 157864;
      break L1;
      break;
     }
     case 35685:  {
      $$0 = 157857;
      break L1;
      break;
     }
     case 35677:  {
      $$0 = 157746;
      break L1;
      break;
     }
     case 35678:  {
      $$0 = 157736;
      break L1;
      break;
     }
     case 35679:  {
      $$0 = 157726;
      break L1;
      break;
     }
     case 35680:  {
      $$0 = 157714;
      break L1;
      break;
     }
     case 35681:  {
      $$0 = 157698;
      break L1;
      break;
     }
     case 35682:  {
      $$0 = 157682;
      break L1;
      break;
     }
     case 35683:  {
      $$0 = 157489;
      break L1;
      break;
     }
     case 35684:  {
      $$0 = 157469;
      break L1;
      break;
     }
     default: {
      label = 114;
      break L1;
     }
     }
    } while(0);
   }
   $switch$split72D = ($0|0)<(35665);
   if (!($switch$split72D)) {
    switch ($0|0) {
    case 35665:  {
     $$0 = 157993;
     break L1;
     break;
    }
    case 35666:  {
     $$0 = 157988;
     break L1;
     break;
    }
    case 35667:  {
     $$0 = 157957;
     break L1;
     break;
    }
    case 35668:  {
     $$0 = 157951;
     break L1;
     break;
    }
    case 35669:  {
     $$0 = 157945;
     break L1;
     break;
    }
    case 35670:  {
     $$0 = 157914;
     break L1;
     break;
    }
    case 35671:  {
     $$0 = 157908;
     break L1;
     break;
    }
    default: {
     label = 114;
     break L1;
    }
    }
   }
   $switch$split102D = ($0|0)<(5130);
   if ($switch$split102D) {
    switch ($0|0) {
    case 5126:  {
     $$0 = 158003;
     break L1;
     break;
    }
    case 5124:  {
     $$0 = 167275;
     break L1;
     break;
    }
    case 5125:  {
     $$0 = 157940;
     break L1;
     break;
    }
    default: {
     label = 114;
     break L1;
    }
    }
   }
   $switch$split132D = ($0|0)<(5135);
   if ($switch$split132D) {
    switch ($0|0) {
    case 5130:  {
     $$0 = 157981;
     break L1;
     break;
    }
    case 5134:  {
     $$0 = 157888;
     break L1;
     break;
    }
    default: {
     label = 114;
     break L1;
    }
    }
   }
   $switch$split162D = ($0|0)<(35664);
   if ($switch$split162D) {
    switch ($0|0) {
    case 5135:  {
     break;
    }
    default: {
     label = 114;
     break L1;
    }
    }
    $$0 = 157879;
    break;
   } else {
    switch ($0|0) {
    case 35664:  {
     break;
    }
    default: {
     label = 114;
     break L1;
    }
    }
    $$0 = 157998;
    break;
   }
  } else {
   do {
    switch ($0|0) {
    case 36860:  {
     $$0 = 157975;
     break L1;
     break;
    }
    case 36861:  {
     $$0 = 157969;
     break L1;
     break;
    }
    case 36862:  {
     $$0 = 157963;
     break L1;
     break;
    }
    case 36678:  {
     $$0 = 157816;
     break L1;
     break;
    }
    case 36679:  {
     $$0 = 157810;
     break L1;
     break;
    }
    case 36680:  {
     $$0 = 157804;
     break L1;
     break;
    }
    case 36681:  {
     $$0 = 157796;
     break L1;
     break;
    }
    case 36682:  {
     $$0 = 157788;
     break L1;
     break;
    }
    case 36683:  {
     $$0 = 157780;
     break L1;
     break;
    }
    case 36684:  {
     $$0 = 157772;
     break L1;
     break;
    }
    case 36685:  {
     $$0 = 157764;
     break L1;
     break;
    }
    case 36686:  {
     $$0 = 157756;
     break L1;
     break;
    }
    case 36876:  {
     $$0 = 157632;
     break L1;
     break;
    }
    case 37128:  {
     $$0 = 157578;
     break L1;
     break;
    }
    case 37131:  {
     $$0 = 157561;
     break L1;
     break;
    }
    case 36877:  {
     $$0 = 157517;
     break L1;
     break;
    }
    case 36878:  {
     $$0 = 157370;
     break L1;
     break;
    }
    case 37129:  {
     $$0 = 157357;
     break L1;
     break;
    }
    case 37132:  {
     $$0 = 157339;
     break L1;
     break;
    }
    case 36311:  {
     $$0 = 157231;
     break L1;
     break;
    }
    case 36879:  {
     $$0 = 157210;
     break L1;
     break;
    }
    case 37130:  {
     $$0 = 157197;
     break L1;
     break;
    }
    case 37133:  {
     $$0 = 157179;
     break L1;
     break;
    }
    case 36312:  {
     $$0 = 157164;
     break L1;
     break;
    }
    case 36940:  {
     $$0 = 157141;
     break L1;
     break;
    }
    case 36941:  {
     $$0 = 157133;
     break L1;
     break;
    }
    case 36942:  {
     $$0 = 157125;
     break L1;
     break;
    }
    case 36943:  {
     $$0 = 157113;
     break L1;
     break;
    }
    case 36944:  {
     $$0 = 157103;
     break L1;
     break;
    }
    case 36945:  {
     $$0 = 157091;
     break L1;
     break;
    }
    case 36946:  {
     $$0 = 157078;
     break L1;
     break;
    }
    case 36947:  {
     $$0 = 157065;
     break L1;
     break;
    }
    case 36948:  {
     $$0 = 157050;
     break L1;
     break;
    }
    case 36949:  {
     $$0 = 157040;
     break L1;
     break;
    }
    case 36950:  {
     $$0 = 157025;
     break L1;
     break;
    }
    case 36951:  {
     $$0 = 157016;
     break L1;
     break;
    }
    case 36952:  {
     $$0 = 157007;
     break L1;
     break;
    }
    case 36953:  {
     $$0 = 156998;
     break L1;
     break;
    }
    case 36954:  {
     $$0 = 156985;
     break L1;
     break;
    }
    case 36955:  {
     $$0 = 156974;
     break L1;
     break;
    }
    case 36956:  {
     $$0 = 156961;
     break L1;
     break;
    }
    case 36957:  {
     $$0 = 156947;
     break L1;
     break;
    }
    case 36958:  {
     $$0 = 156933;
     break L1;
     break;
    }
    case 36959:  {
     $$0 = 156917;
     break L1;
     break;
    }
    case 36960:  {
     $$0 = 156906;
     break L1;
     break;
    }
    case 36961:  {
     $$0 = 156890;
     break L1;
     break;
    }
    case 36962:  {
     $$0 = 156881;
     break L1;
     break;
    }
    case 36963:  {
     $$0 = 156872;
     break L1;
     break;
    }
    case 36964:  {
     $$0 = 156863;
     break L1;
     break;
    }
    case 36965:  {
     $$0 = 156850;
     break L1;
     break;
    }
    case 36966:  {
     $$0 = 156839;
     break L1;
     break;
    }
    case 36967:  {
     $$0 = 156826;
     break L1;
     break;
    }
    case 36968:  {
     $$0 = 156812;
     break L1;
     break;
    }
    case 36969:  {
     $$0 = 156798;
     break L1;
     break;
    }
    case 36970:  {
     $$0 = 156782;
     break L1;
     break;
    }
    case 36971:  {
     $$0 = 156771;
     break L1;
     break;
    }
    case 36972:  {
     $$0 = 156755;
     break L1;
     break;
    }
    default: {
     label = 114;
     break L1;
    }
    }
   } while(0);
  }
 } while(0);
 if ((label|0) == 114) {
  $$0 = 156745;
 }
 return ($$0|0);
}
function __ZNK3osg7Uniform16isCompatibleTypeENS0_4TypeES1_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$0$i = 0, $$0$i10 = 0, $$0$i12 = 0, $$0$i14 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond16 = 0, $switch$split102D = 0, $switch$split12D = 0, $switch$split132D = 0, $switch$split162D = 0, $switch$split192D = 0, $switch$split222D = 0, $switch$split252D = 0, $switch$split282D = 0, $switch$split2D = 0;
 var $switch$split312D = 0, $switch$split342D = 0, $switch$split372D = 0, $switch$split402D = 0, $switch$split42D = 0, $switch$split432D = 0, $switch$split462D = 0, $switch$split492D = 0, $switch$split522D = 0, $switch$split552D = 0, $switch$split72D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = ($1|0)==(0);
 $5 = ($2|0)==(0);
 $or$cond = $4 | $5;
 if ($or$cond) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $6 = ((($0)) + 44|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0);
 if ($8) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $9 = ($7|0)==($1|0);
 $10 = ($7|0)==($2|0);
 $or$cond16 = $9 | $10;
 if ($or$cond16) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $switch$split2D = ($1|0)<(36879);
 L10: do {
  if ($switch$split2D) {
   $switch$split102D = ($1|0)<(36293);
   if (!($switch$split102D)) {
    switch ($1|0) {
    case 36309: case 36312: case 36311: case 36310: case 36308: case 36307: case 36306: case 36305: case 36301: case 36304: case 36878: case 36303: case 36302: case 36300: case 36299: case 36298: case 36297: case 36877: case 36293: case 36876:  {
     $$0$i = 5124;
     break L10;
     break;
    }
    default: {
     label = 10;
     break L10;
    }
    }
   }
   $switch$split222D = ($1|0)<(35680);
   if (!($switch$split222D)) {
    switch ($1|0) {
    case 35684: case 35683: case 36290: case 36292: case 36291: case 36289: case 36288: case 35682: case 35681: case 35680:  {
     $$0$i = 5124;
     break L10;
     break;
    }
    default: {
     label = 10;
     break L10;
    }
    }
   }
   $switch$split342D = ($1|0)<(35672);
   if (!($switch$split342D)) {
    switch ($1|0) {
    case 35679: case 35678: case 35677:  {
     $$0$i = 5124;
     break L10;
     break;
    }
    case 35672:  {
     $$0$i = 35668;
     break L10;
     break;
    }
    case 35673:  {
     $$0$i = 35669;
     break L10;
     break;
    }
    default: {
     label = 10;
     break L10;
    }
    }
   }
   $switch$split462D = ($1|0)<(35670);
   if (!($switch$split462D)) {
    switch ($1|0) {
    case 35670:  {
     $$0$i = 5124;
     break L10;
     break;
    }
    case 35671:  {
     break;
    }
    default: {
     label = 10;
     break L10;
    }
    }
    $$0$i = 35667;
    break;
   }
   switch ($1|0) {
   case 5135:  {
    $$0$i = $1;
    break L10;
    break;
   }
   case 5134:  {
    $$0$i = $1;
    break L10;
    break;
   }
   default: {
    label = 10;
    break L10;
   }
   }
  } else {
   switch ($1|0) {
   case 36972: case 36971: case 36970: case 36969: case 36968: case 36967: case 36966: case 36965: case 36964: case 36963: case 36962: case 36961: case 36960: case 36959: case 36958: case 36957: case 36956: case 36955: case 36954: case 36953: case 36952: case 36951: case 36950: case 36949: case 36948: case 36947: case 36946: case 36945: case 36944: case 36943: case 36942: case 36941: case 36940: case 37133: case 37130: case 36879: case 37132: case 37129: case 37131: case 37128:  {
    $$0$i = 5124;
    break;
   }
   default: {
    label = 10;
   }
   }
  }
 } while(0);
 if ((label|0) == 10) {
  $$0$i = $1;
 }
 $switch$split12D = ($7|0)<(36879);
 L35: do {
  if ($switch$split12D) {
   $switch$split132D = ($7|0)<(36293);
   if (!($switch$split132D)) {
    switch ($7|0) {
    case 36309: case 36312: case 36311: case 36310: case 36308: case 36307: case 36306: case 36305: case 36301: case 36304: case 36878: case 36303: case 36302: case 36300: case 36299: case 36298: case 36297: case 36877: case 36293: case 36876:  {
     $$0$i10 = 5124;
     break L35;
     break;
    }
    default: {
     label = 17;
     break L35;
    }
    }
   }
   $switch$split252D = ($7|0)<(35680);
   if (!($switch$split252D)) {
    switch ($7|0) {
    case 35684: case 35683: case 36290: case 36292: case 36291: case 36289: case 36288: case 35682: case 35681: case 35680:  {
     $$0$i10 = 5124;
     break L35;
     break;
    }
    default: {
     label = 17;
     break L35;
    }
    }
   }
   $switch$split372D = ($7|0)<(35672);
   if (!($switch$split372D)) {
    switch ($7|0) {
    case 35679: case 35678: case 35677:  {
     $$0$i10 = 5124;
     break L35;
     break;
    }
    case 35672:  {
     $$0$i10 = 35668;
     break L35;
     break;
    }
    case 35673:  {
     $$0$i10 = 35669;
     break L35;
     break;
    }
    default: {
     label = 17;
     break L35;
    }
    }
   }
   $switch$split492D = ($7|0)<(35670);
   if (!($switch$split492D)) {
    switch ($7|0) {
    case 35670:  {
     $$0$i10 = 5124;
     break L35;
     break;
    }
    case 35671:  {
     break;
    }
    default: {
     label = 17;
     break L35;
    }
    }
    $$0$i10 = 35667;
    break;
   }
   switch ($7|0) {
   case 5135:  {
    $$0$i10 = $7;
    break L35;
    break;
   }
   case 5134:  {
    $$0$i10 = $7;
    break L35;
    break;
   }
   default: {
    label = 17;
    break L35;
   }
   }
  } else {
   switch ($7|0) {
   case 36972: case 36971: case 36970: case 36969: case 36968: case 36967: case 36966: case 36965: case 36964: case 36963: case 36962: case 36961: case 36960: case 36959: case 36958: case 36957: case 36956: case 36955: case 36954: case 36953: case 36952: case 36951: case 36950: case 36949: case 36948: case 36947: case 36946: case 36945: case 36944: case 36943: case 36942: case 36941: case 36940: case 37133: case 37130: case 36879: case 37132: case 37129: case 37131: case 37128:  {
    $$0$i10 = 5124;
    break;
   }
   default: {
    label = 17;
   }
   }
  }
 } while(0);
 if ((label|0) == 17) {
  $$0$i10 = $7;
 }
 $11 = ($$0$i|0)==($$0$i10|0);
 if ($11) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $switch$split42D = ($2|0)<(36879);
 L63: do {
  if ($switch$split42D) {
   $switch$split162D = ($2|0)<(36293);
   if (!($switch$split162D)) {
    switch ($2|0) {
    case 36309: case 36312: case 36311: case 36310: case 36308: case 36307: case 36306: case 36305: case 36301: case 36304: case 36878: case 36303: case 36302: case 36300: case 36299: case 36298: case 36297: case 36877: case 36293: case 36876:  {
     $$0$i12 = 5124;
     break L63;
     break;
    }
    default: {
     label = 25;
     break L63;
    }
    }
   }
   $switch$split282D = ($2|0)<(35680);
   if (!($switch$split282D)) {
    switch ($2|0) {
    case 35684: case 35683: case 36290: case 36292: case 36291: case 36289: case 36288: case 35682: case 35681: case 35680:  {
     $$0$i12 = 5124;
     break L63;
     break;
    }
    default: {
     label = 25;
     break L63;
    }
    }
   }
   $switch$split402D = ($2|0)<(35672);
   if (!($switch$split402D)) {
    switch ($2|0) {
    case 35679: case 35678: case 35677:  {
     $$0$i12 = 5124;
     break L63;
     break;
    }
    case 35672:  {
     $$0$i12 = 35668;
     break L63;
     break;
    }
    case 35673:  {
     $$0$i12 = 35669;
     break L63;
     break;
    }
    default: {
     label = 25;
     break L63;
    }
    }
   }
   $switch$split522D = ($2|0)<(35670);
   if (!($switch$split522D)) {
    switch ($2|0) {
    case 35670:  {
     $$0$i12 = 5124;
     break L63;
     break;
    }
    case 35671:  {
     break;
    }
    default: {
     label = 25;
     break L63;
    }
    }
    $$0$i12 = 35667;
    break;
   }
   switch ($2|0) {
   case 5135:  {
    $$0$i12 = $2;
    break L63;
    break;
   }
   case 5134:  {
    $$0$i12 = $2;
    break L63;
    break;
   }
   default: {
    label = 25;
    break L63;
   }
   }
  } else {
   switch ($2|0) {
   case 36972: case 36971: case 36970: case 36969: case 36968: case 36967: case 36966: case 36965: case 36964: case 36963: case 36962: case 36961: case 36960: case 36959: case 36958: case 36957: case 36956: case 36955: case 36954: case 36953: case 36952: case 36951: case 36950: case 36949: case 36948: case 36947: case 36946: case 36945: case 36944: case 36943: case 36942: case 36941: case 36940: case 37133: case 37130: case 36879: case 37132: case 37129: case 37131: case 37128:  {
    $$0$i12 = 5124;
    break;
   }
   default: {
    label = 25;
   }
   }
  }
 } while(0);
 if ((label|0) == 25) {
  $$0$i12 = $2;
 }
 $switch$split72D = ($7|0)<(36879);
 L88: do {
  if ($switch$split72D) {
   $switch$split192D = ($7|0)<(36293);
   if (!($switch$split192D)) {
    switch ($7|0) {
    case 36309: case 36312: case 36311: case 36310: case 36308: case 36307: case 36306: case 36305: case 36301: case 36304: case 36878: case 36303: case 36302: case 36300: case 36299: case 36298: case 36297: case 36877: case 36293: case 36876:  {
     $$0$i14 = 5124;
     break L88;
     break;
    }
    default: {
     label = 32;
     break L88;
    }
    }
   }
   $switch$split312D = ($7|0)<(35680);
   if (!($switch$split312D)) {
    switch ($7|0) {
    case 35684: case 35683: case 36290: case 36292: case 36291: case 36289: case 36288: case 35682: case 35681: case 35680:  {
     $$0$i14 = 5124;
     break L88;
     break;
    }
    default: {
     label = 32;
     break L88;
    }
    }
   }
   $switch$split432D = ($7|0)<(35672);
   if (!($switch$split432D)) {
    switch ($7|0) {
    case 35679: case 35678: case 35677:  {
     $$0$i14 = 5124;
     break L88;
     break;
    }
    case 35672:  {
     $$0$i14 = 35668;
     break L88;
     break;
    }
    case 35673:  {
     $$0$i14 = 35669;
     break L88;
     break;
    }
    default: {
     label = 32;
     break L88;
    }
    }
   }
   $switch$split552D = ($7|0)<(35670);
   if (!($switch$split552D)) {
    switch ($7|0) {
    case 35670:  {
     $$0$i14 = 5124;
     break L88;
     break;
    }
    case 35671:  {
     break;
    }
    default: {
     label = 32;
     break L88;
    }
    }
    $$0$i14 = 35667;
    break;
   }
   switch ($7|0) {
   case 5135:  {
    $$0$i14 = $7;
    break L88;
    break;
   }
   case 5134:  {
    $$0$i14 = $7;
    break L88;
    break;
   }
   default: {
    label = 32;
    break L88;
   }
   }
  } else {
   switch ($7|0) {
   case 36972: case 36971: case 36970: case 36969: case 36968: case 36967: case 36966: case 36965: case 36964: case 36963: case 36962: case 36961: case 36960: case 36959: case 36958: case 36957: case 36956: case 36955: case 36954: case 36953: case 36952: case 36951: case 36950: case 36949: case 36948: case 36947: case 36946: case 36945: case 36944: case 36943: case 36942: case 36941: case 36940: case 37133: case 37130: case 36879: case 37132: case 37129: case 37131: case 37128:  {
    $$0$i14 = 5124;
    break;
   }
   default: {
    label = 32;
   }
   }
  }
 } while(0);
 if ((label|0) == 32) {
  $$0$i14 = $7;
 }
 $12 = ($$0$i12|0)==($$0$i14|0);
 if ($12) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $13 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
 if (!($13)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $14 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
 $15 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($14,156708,36)|0);
 $16 = (__ZN3osg7Uniform11getTypenameENS0_4TypeE($1)|0);
 $17 = (_strlen($16)|0);
 $18 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($15,$16,$17)|0);
 $19 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($18,158009,4)|0);
 $20 = (__ZN3osg7Uniform11getTypenameENS0_4TypeE($2)|0);
 $21 = (_strlen($20)|0);
 $22 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($19,$20,$21)|0);
 $23 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($22,171881,5)|0);
 $24 = HEAP32[$6>>2]|0;
 $25 = (__ZN3osg7Uniform11getTypenameENS0_4TypeE($24)|0);
 $26 = (_strlen($25)|0);
 $27 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($23,$25,$26)|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = ((($28)) + -12|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($27) + ($30)|0);
 __ZNKSt3__28ios_base6getlocEv($3,$31);
 __THREW__ = 0;
 $32 = (invoke_iii(3255,($3|0),(215188|0))|0);
 $33 = __THREW__; __THREW__ = 0;
 $34 = $33&1;
 if (!($34)) {
  $35 = HEAP32[$32>>2]|0;
  $36 = ((($35)) + 28|0);
  $37 = HEAP32[$36>>2]|0;
  __THREW__ = 0;
  $38 = (invoke_iii($37|0,($32|0),10)|0);
  $39 = __THREW__; __THREW__ = 0;
  $40 = $39&1;
  if (!($40)) {
   __ZNSt3__26localeD2Ev($3);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($27,$38)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($27)|0);
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $41 = ___cxa_find_matching_catch_2()|0;
 $42 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($3|0));
 $43 = __THREW__; __THREW__ = 0;
 $44 = $43&1;
 if ($44) {
  $45 = ___cxa_find_matching_catch_3(0|0)|0;
  $46 = tempRet0;
  ___clang_call_terminate($45);
  // unreachable;
 } else {
  ___resumeException($41|0);
  // unreachable;
 }
 return (0)|0;
}
function __ZN3osg7Uniform3setEf($0,$1) {
 $0 = $0|0;
 $1 = +$1;
 var $$pr = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  __ZN3osg7Uniform14setNumElementsEj($0,1);
  $$pr = HEAP32[$2>>2]|0;
  $5 = $$pr;
 } else {
  $5 = $3;
 }
 $6 = ($5|0)==(1);
 if (!($6)) {
  $15 = 0;
  return ($15|0);
 }
 $7 = (__ZNK3osg7Uniform16isCompatibleTypeENS0_4TypeE($0,5126)|0);
 if (!($7)) {
  $15 = 0;
  return ($15|0);
 }
 $8 = ((($0)) + 56|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($9)) + 76|0);
 $11 = HEAP32[$10>>2]|0;
 HEAPF32[$11>>2] = $1;
 $12 = ((($0)) + 88|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($13) + 1)|0;
 HEAP32[$12>>2] = $14;
 $15 = 1;
 return ($15|0);
}
function __ZN3osg7UniformC2EPKcRKNS_5Vec3fE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$016$i$i = 0, $$017$i$i = 0, $$04 = 0, $$1 = 0, $$15 = 0, $$pr$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $scevgep$i$i$i = 0, $scevgep5$i$i$i = 0, dest = 0;
 var label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 __ZN3osg10ReferencedC2Ev($0);
 $4 = ((($0)) + 12|0);
 ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;
 $5 = ((($0)) + 24|0);
 HEAP32[$5>>2] = 2;
 $6 = ((($0)) + 28|0);
 HEAP32[$6>>2] = 0;
 HEAP32[$0>>2] = (69328);
 $7 = ((($0)) + 32|0);
 HEAP32[$7>>2] = 0;
 $8 = ((($0)) + 36|0);
 HEAP32[$8>>2] = 0;
 $9 = ((($0)) + 40|0);
 HEAP32[$9>>2] = 0;
 $10 = ((($0)) + 44|0);
 HEAP32[$10>>2] = 35665;
 $11 = ((($0)) + 48|0);
 HEAP32[$11>>2] = 1;
 $12 = ((($0)) + 56|0);
 $13 = ((($0)) + 60|0);
 $14 = ((($0)) + 64|0);
 $15 = ((($0)) + 68|0);
 $16 = ((($0)) + 72|0);
 $17 = ((($0)) + 76|0);
 $18 = ((($0)) + 80|0);
 $19 = ((($0)) + 84|0);
 $20 = ((($0)) + 88|0);
 dest=$12; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 ;HEAP32[$3>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;
 $21 = (_strlen($1)|0);
 $22 = ($21>>>0)>(4294967279);
 do {
  if ($22) {
   __THREW__ = 0;
   invoke_vi(3367,($3|0));
   $23 = __THREW__; __THREW__ = 0;
   label = 20;
  } else {
   $24 = ($21>>>0)<(11);
   if ($24) {
    $33 = $21&255;
    $34 = ((($3)) + 11|0);
    HEAP8[$34>>0] = $33;
    $35 = ($21|0)==(0);
    if ($35) {
     $$017$i$i = $3;
    } else {
     $$016$i$i = $3;
     label = 7;
    }
   } else {
    $25 = (($21) + 16)|0;
    $26 = $25 & -16;
    __THREW__ = 0;
    $27 = (invoke_ii(3276,($26|0))|0);
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if ($29) {
     label = 20;
     break;
    }
    HEAP32[$3>>2] = $27;
    $30 = $26 | -2147483648;
    $31 = ((($3)) + 8|0);
    HEAP32[$31>>2] = $30;
    $32 = ((($3)) + 4|0);
    HEAP32[$32>>2] = $21;
    $$016$i$i = $27;
    label = 7;
   }
   if ((label|0) == 7) {
    _memcpy(($$016$i$i|0),($1|0),($21|0))|0;
    $$017$i$i = $$016$i$i;
   }
   $36 = (($$017$i$i) + ($21)|0);
   HEAP8[$36>>0] = 0;
   __THREW__ = 0;
   invoke_vii(2390,($0|0),($3|0));
   $37 = __THREW__; __THREW__ = 0;
   $38 = $37&1;
   if ($38) {
    $68 = ___cxa_find_matching_catch_2()|0;
    $69 = tempRet0;
    $70 = ((($3)) + 11|0);
    $71 = HEAP8[$70>>0]|0;
    $72 = ($71<<24>>24)<(0);
    if (!($72)) {
     $$0 = $69;$$04 = $68;
     label = 23;
     break;
    }
    $73 = HEAP32[$3>>2]|0;
    __ZdlPv($73);
    $$0 = $69;$$04 = $68;
    label = 23;
    break;
   }
   $39 = ((($3)) + 11|0);
   $40 = HEAP8[$39>>0]|0;
   $41 = ($40<<24>>24)<(0);
   if ($41) {
    $42 = HEAP32[$3>>2]|0;
    __ZdlPv($42);
   }
   __THREW__ = 0;
   invoke_vi(3995,($0|0));
   $43 = __THREW__; __THREW__ = 0;
   $44 = $43&1;
   do {
    if (!($44)) {
     $45 = HEAP32[$11>>2]|0;
     $46 = ($45|0)==(0);
     if ($46) {
      __THREW__ = 0;
      invoke_vii(3994,($0|0),1);
      $47 = __THREW__; __THREW__ = 0;
      $48 = $47&1;
      if ($48) {
       break;
      }
      $$pr$i = HEAP32[$11>>2]|0;
      $49 = $$pr$i;
     } else {
      $49 = $45;
     }
     $50 = ($49|0)==(1);
     if (!($50)) {
      STACKTOP = sp;return;
     }
     __THREW__ = 0;
     $51 = (invoke_iii(3996,($0|0),35665)|0);
     $52 = __THREW__; __THREW__ = 0;
     $53 = $52&1;
     if (!($53)) {
      if (!($51)) {
       STACKTOP = sp;return;
      }
      $54 = HEAP32[$2>>2]|0;
      $55 = HEAP32[$12>>2]|0;
      $56 = ((($55)) + 76|0);
      $57 = HEAP32[$56>>2]|0;
      HEAP32[$57>>2] = $54;
      $58 = ((($2)) + 4|0);
      $59 = HEAP32[$58>>2]|0;
      $60 = ((($57)) + 4|0);
      HEAP32[$60>>2] = $59;
      $61 = ((($2)) + 8|0);
      $62 = HEAP32[$61>>2]|0;
      $63 = ((($57)) + 8|0);
      HEAP32[$63>>2] = $62;
      $64 = HEAP32[$20>>2]|0;
      $65 = (($64) + 1)|0;
      HEAP32[$20>>2] = $65;
      STACKTOP = sp;return;
     }
    }
   } while(0);
   $74 = ___cxa_find_matching_catch_2()|0;
   $75 = tempRet0;
   $$1 = $75;$$15 = $74;
  }
 } while(0);
 if ((label|0) == 20) {
  $66 = ___cxa_find_matching_catch_2()|0;
  $67 = tempRet0;
  $$0 = $67;$$04 = $66;
  label = 23;
 }
 if ((label|0) == 23) {
  $$1 = $$0;$$15 = $$04;
 }
 $76 = HEAP32[$19>>2]|0;
 $77 = ($76|0)==(0|0);
 if (!($77)) {
  $78 = HEAP32[$76>>2]|0;
  $79 = ((($78)) + -16|0);
  $80 = HEAP32[$79>>2]|0;
  $81 = (($76) + ($80)|0);
  $82 = ((($81)) + 8|0);
  $83 = HEAP32[$82>>2]|0;HEAP32[$82>>2] = (($83-1)|0);
  $84 = ($83|0)==(1);
  if ($84) {
   __THREW__ = 0;
   invoke_viii(3262,($81|0),1,1);
   $85 = __THREW__; __THREW__ = 0;
   $86 = $85&1;
   if ($86) {
    $151 = ___cxa_find_matching_catch_3(0|0)|0;
    $152 = tempRet0;
    ___clang_call_terminate($151);
    // unreachable;
   }
  }
 }
 HEAP32[$19>>2] = 0;
 $87 = HEAP32[$18>>2]|0;
 $88 = ($87|0)==(0|0);
 if (!($88)) {
  $89 = HEAP32[$87>>2]|0;
  $90 = ((($89)) + -16|0);
  $91 = HEAP32[$90>>2]|0;
  $92 = (($87) + ($91)|0);
  $93 = ((($92)) + 8|0);
  $94 = HEAP32[$93>>2]|0;HEAP32[$93>>2] = (($94-1)|0);
  $95 = ($94|0)==(1);
  if ($95) {
   __THREW__ = 0;
   invoke_viii(3262,($92|0),1,1);
   $96 = __THREW__; __THREW__ = 0;
   $97 = $96&1;
   if ($97) {
    $151 = ___cxa_find_matching_catch_3(0|0)|0;
    $152 = tempRet0;
    ___clang_call_terminate($151);
    // unreachable;
   }
  }
 }
 HEAP32[$18>>2] = 0;
 $98 = HEAP32[$17>>2]|0;
 $99 = ($98|0)==(0|0);
 if (!($99)) {
  $100 = ((($98)) + 8|0);
  $101 = HEAP32[$100>>2]|0;HEAP32[$100>>2] = (($101-1)|0);
  $102 = ($101|0)==(1);
  if ($102) {
   __THREW__ = 0;
   invoke_viii(3262,($98|0),1,1);
   $103 = __THREW__; __THREW__ = 0;
   $104 = $103&1;
   if ($104) {
    $151 = ___cxa_find_matching_catch_3(0|0)|0;
    $152 = tempRet0;
    ___clang_call_terminate($151);
    // unreachable;
   }
  }
 }
 HEAP32[$17>>2] = 0;
 $105 = HEAP32[$16>>2]|0;
 $106 = ($105|0)==(0|0);
 if (!($106)) {
  $107 = ((($105)) + 8|0);
  $108 = HEAP32[$107>>2]|0;HEAP32[$107>>2] = (($108-1)|0);
  $109 = ($108|0)==(1);
  if ($109) {
   __THREW__ = 0;
   invoke_viii(3262,($105|0),1,1);
   $110 = __THREW__; __THREW__ = 0;
   $111 = $110&1;
   if ($111) {
    $151 = ___cxa_find_matching_catch_3(0|0)|0;
    $152 = tempRet0;
    ___clang_call_terminate($151);
    // unreachable;
   }
  }
 }
 HEAP32[$16>>2] = 0;
 $112 = HEAP32[$15>>2]|0;
 $113 = ($112|0)==(0|0);
 if (!($113)) {
  $114 = ((($112)) + 8|0);
  $115 = HEAP32[$114>>2]|0;HEAP32[$114>>2] = (($115-1)|0);
  $116 = ($115|0)==(1);
  if ($116) {
   __THREW__ = 0;
   invoke_viii(3262,($112|0),1,1);
   $117 = __THREW__; __THREW__ = 0;
   $118 = $117&1;
   if ($118) {
    $151 = ___cxa_find_matching_catch_3(0|0)|0;
    $152 = tempRet0;
    ___clang_call_terminate($151);
    // unreachable;
   }
  }
 }
 HEAP32[$15>>2] = 0;
 $119 = HEAP32[$14>>2]|0;
 $120 = ($119|0)==(0|0);
 if (!($120)) {
  $121 = ((($119)) + 8|0);
  $122 = HEAP32[$121>>2]|0;HEAP32[$121>>2] = (($122-1)|0);
  $123 = ($122|0)==(1);
  if ($123) {
   __THREW__ = 0;
   invoke_viii(3262,($119|0),1,1);
   $124 = __THREW__; __THREW__ = 0;
   $125 = $124&1;
   if ($125) {
    $151 = ___cxa_find_matching_catch_3(0|0)|0;
    $152 = tempRet0;
    ___clang_call_terminate($151);
    // unreachable;
   }
  }
 }
 HEAP32[$14>>2] = 0;
 $126 = HEAP32[$13>>2]|0;
 $127 = ($126|0)==(0|0);
 if (!($127)) {
  $128 = ((($126)) + 8|0);
  $129 = HEAP32[$128>>2]|0;HEAP32[$128>>2] = (($129-1)|0);
  $130 = ($129|0)==(1);
  if ($130) {
   __THREW__ = 0;
   invoke_viii(3262,($126|0),1,1);
   $131 = __THREW__; __THREW__ = 0;
   $132 = $131&1;
   if ($132) {
    $151 = ___cxa_find_matching_catch_3(0|0)|0;
    $152 = tempRet0;
    ___clang_call_terminate($151);
    // unreachable;
   }
  }
 }
 HEAP32[$13>>2] = 0;
 $133 = HEAP32[$12>>2]|0;
 $134 = ($133|0)==(0|0);
 if (!($134)) {
  $135 = ((($133)) + 8|0);
  $136 = HEAP32[$135>>2]|0;HEAP32[$135>>2] = (($136-1)|0);
  $137 = ($136|0)==(1);
  if ($137) {
   __THREW__ = 0;
   invoke_viii(3262,($133|0),1,1);
   $138 = __THREW__; __THREW__ = 0;
   $139 = $138&1;
   if ($139) {
    $151 = ___cxa_find_matching_catch_3(0|0)|0;
    $152 = tempRet0;
    ___clang_call_terminate($151);
    // unreachable;
   }
  }
 }
 HEAP32[$12>>2] = 0;
 $140 = HEAP32[$7>>2]|0;
 $141 = ($140|0)==(0|0);
 if (!($141)) {
  $142 = HEAP32[$8>>2]|0;
  $143 = ($142|0)==($140|0);
  if (!($143)) {
   $scevgep$i$i$i = ((($142)) + -4|0);
   $144 = $scevgep$i$i$i;
   $145 = $140;
   $146 = (($144) - ($145))|0;
   $147 = $146 >>> 2;
   $148 = $147 ^ -1;
   $scevgep5$i$i$i = (($142) + ($148<<2)|0);
   HEAP32[$8>>2] = $scevgep5$i$i$i;
  }
  __ZdlPv($140);
 }
 __THREW__ = 0;
 invoke_vi(388,($0|0));
 $149 = __THREW__; __THREW__ = 0;
 $150 = $149&1;
 if ($150) {
  $151 = ___cxa_find_matching_catch_3(0|0)|0;
  $152 = tempRet0;
  ___clang_call_terminate($151);
  // unreachable;
 } else {
  ___resumeException($$15|0);
  // unreachable;
 }
}
function __ZN3osg7Uniform3setERKNS_5Vec3fE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$pr = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  __ZN3osg7Uniform14setNumElementsEj($0,1);
  $$pr = HEAP32[$2>>2]|0;
  $5 = $$pr;
 } else {
  $5 = $3;
 }
 $6 = ($5|0)==(1);
 if (!($6)) {
  $22 = 0;
  return ($22|0);
 }
 $7 = (__ZNK3osg7Uniform16isCompatibleTypeENS0_4TypeE($0,35665)|0);
 if (!($7)) {
  $22 = 0;
  return ($22|0);
 }
 $8 = HEAP32[$1>>2]|0;
 $9 = ((($0)) + 56|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ((($10)) + 76|0);
 $12 = HEAP32[$11>>2]|0;
 HEAP32[$12>>2] = $8;
 $13 = ((($1)) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ((($12)) + 4|0);
 HEAP32[$15>>2] = $14;
 $16 = ((($1)) + 8|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ((($12)) + 8|0);
 HEAP32[$18>>2] = $17;
 $19 = ((($0)) + 88|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($20) + 1)|0;
 HEAP32[$19>>2] = $21;
 $22 = 1;
 return ($22|0);
}
function __ZN3osg7Uniform3setERKNS_15Matrix3TemplateIfEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$pr = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  __ZN3osg7Uniform14setNumElementsEj($0,1);
  $$pr = HEAP32[$2>>2]|0;
  $5 = $$pr;
 } else {
  $5 = $3;
 }
 $6 = ($5|0)==(1);
 if (!($6)) {
  $40 = 0;
  return ($40|0);
 }
 $7 = (__ZNK3osg7Uniform16isCompatibleTypeENS0_4TypeE($0,35675)|0);
 if (!($7)) {
  $40 = 0;
  return ($40|0);
 }
 $8 = ((($0)) + 56|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($9)) + 76|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = HEAP32[$1>>2]|0;
 HEAP32[$11>>2] = $12;
 $13 = ((($1)) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ((($11)) + 4|0);
 HEAP32[$15>>2] = $14;
 $16 = ((($1)) + 8|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ((($11)) + 8|0);
 HEAP32[$18>>2] = $17;
 $19 = ((($1)) + 12|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ((($11)) + 12|0);
 HEAP32[$21>>2] = $20;
 $22 = ((($1)) + 16|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ((($11)) + 16|0);
 HEAP32[$24>>2] = $23;
 $25 = ((($1)) + 20|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ((($11)) + 20|0);
 HEAP32[$27>>2] = $26;
 $28 = ((($1)) + 24|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ((($11)) + 24|0);
 HEAP32[$30>>2] = $29;
 $31 = ((($1)) + 28|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = ((($11)) + 28|0);
 HEAP32[$33>>2] = $32;
 $34 = ((($1)) + 32|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = ((($11)) + 32|0);
 HEAP32[$36>>2] = $35;
 $37 = ((($0)) + 88|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (($38) + 1)|0;
 HEAP32[$37>>2] = $39;
 $40 = 1;
 return ($40|0);
}
function __ZN3osg7Uniform10setElementEjRKNS_7MatrixdE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$i = 0, $$0$i$ph = 0, $$026 = 0, $10 = 0, $100 = 0.0, $101 = 0, $102 = 0, $103 = 0, $104 = 0.0, $105 = 0, $106 = 0, $107 = 0, $108 = 0.0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0.0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0.0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0.0, $121 = 0, $122 = 0, $123 = 0, $124 = 0.0, $125 = 0, $126 = 0, $127 = 0, $128 = 0.0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0.0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0.0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0.0, $141 = 0, $142 = 0, $143 = 0, $144 = 0.0, $145 = 0, $146 = 0, $147 = 0, $148 = 0.0, $149 = 0, $15 = 0.0, $150 = 0;
 var $151 = 0, $152 = 0.0, $153 = 0, $154 = 0, $155 = 0, $156 = 0.0, $157 = 0, $158 = 0, $159 = 0, $16 = 0.0, $160 = 0, $161 = 0, $17 = 0, $18 = 0, $19 = 0.0, $20 = 0.0, $21 = 0, $22 = 0, $23 = 0, $24 = 0.0;
 var $25 = 0.0, $26 = 0, $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0.0, $31 = 0, $32 = 0, $33 = 0, $34 = 0.0, $35 = 0.0, $36 = 0, $37 = 0, $38 = 0, $39 = 0.0, $4 = 0, $40 = 0.0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0.0, $45 = 0.0, $46 = 0, $47 = 0, $48 = 0, $49 = 0.0, $5 = 0, $50 = 0.0, $51 = 0, $52 = 0, $53 = 0, $54 = 0.0, $55 = 0.0, $56 = 0, $57 = 0, $58 = 0, $59 = 0.0, $6 = 0, $60 = 0.0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0.0, $65 = 0.0, $66 = 0, $67 = 0, $68 = 0, $69 = 0.0, $7 = 0, $70 = 0.0, $71 = 0, $72 = 0, $73 = 0, $74 = 0.0, $75 = 0.0, $76 = 0, $77 = 0, $78 = 0, $79 = 0.0;
 var $8 = 0, $80 = 0.0, $81 = 0, $82 = 0, $83 = 0, $84 = 0.0, $85 = 0.0, $86 = 0, $87 = 0, $88 = 0, $89 = 0.0, $9 = 0, $90 = 0.0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0.0;
 var $98 = 0, $99 = 0, $switch$split102D = 0, $switch$split12D = 0, $switch$split132D = 0, $switch$split162D = 0, $switch$split2D = 0, $switch$split42D = 0, $switch$split72D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 48|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4>>>0)>($1>>>0);
 if (!($5)) {
  $$026 = 0;
  return ($$026|0);
 }
 $6 = (__ZNK3osg7Uniform16isCompatibleTypeENS0_4TypeES1_($0,36680,35676)|0);
 if (!($6)) {
  $$026 = 0;
  return ($$026|0);
 }
 $7 = ((($0)) + 44|0);
 $8 = HEAP32[$7>>2]|0;
 $switch$split2D = ($8|0)<(36311);
 L7: do {
  if ($switch$split2D) {
   $switch$split12D = ($8|0)<(35686);
   if (!($switch$split12D)) {
    switch ($8|0) {
    case 36309: case 36310: case 36308: case 36307: case 36306: case 36305: case 36301: case 36304: case 36303: case 36302: case 36300: case 36299: case 36298: case 36297: case 36290: case 36293: case 36292: case 36291: case 36289: case 36288:  {
     $$0$i = 1;
     break L7;
     break;
    }
    case 36294:  {
     $$0$i$ph = 2;
     label = 12;
     break L7;
     break;
    }
    case 36295:  {
     label = 4;
     break L7;
     break;
    }
    case 36296:  {
     label = 5;
     break L7;
     break;
    }
    case 35687:  {
     label = 6;
     break L7;
     break;
    }
    case 35689: case 35686:  {
     label = 7;
     break L7;
     break;
    }
    case 35690: case 35688:  {
     label = 9;
     break L7;
     break;
    }
    default: {
     label = 11;
     break L7;
    }
    }
   }
   $switch$split42D = ($8|0)<(35672);
   if (!($switch$split42D)) {
    switch ($8|0) {
    case 35684: case 35683: case 35682: case 35681: case 35680: case 35679: case 35678: case 35677:  {
     $$0$i = 1;
     break L7;
     break;
    }
    case 35672:  {
     label = 4;
     break L7;
     break;
    }
    case 35673: case 35674:  {
     label = 5;
     break L7;
     break;
    }
    case 35685:  {
     label = 6;
     break L7;
     break;
    }
    case 35675:  {
     label = 8;
     break L7;
     break;
    }
    case 35676:  {
     label = 10;
     break L7;
     break;
    }
    default: {
     label = 11;
     break L7;
    }
    }
   }
   $switch$split72D = ($8|0)<(35665);
   if (!($switch$split72D)) {
    switch ($8|0) {
    case 35670:  {
     $$0$i = 1;
     break L7;
     break;
    }
    case 35671: case 35667:  {
     $$0$i$ph = 2;
     label = 12;
     break L7;
     break;
    }
    case 35668: case 35665:  {
     label = 4;
     break L7;
     break;
    }
    case 35669: case 35666:  {
     label = 5;
     break L7;
     break;
    }
    default: {
     label = 11;
     break L7;
    }
    }
   }
   $switch$split102D = ($8|0)<(5130);
   if ($switch$split102D) {
    switch ($8|0) {
    case 5125: case 5124: case 5126:  {
     $$0$i = 1;
     break L7;
     break;
    }
    default: {
     label = 11;
     break L7;
    }
    }
   }
   $switch$split132D = ($8|0)<(5135);
   if ($switch$split132D) {
    switch ($8|0) {
    case 5134: case 5130:  {
     $$0$i = 1;
     break L7;
     break;
    }
    default: {
     label = 11;
     break L7;
    }
    }
   }
   $switch$split162D = ($8|0)<(35664);
   if ($switch$split162D) {
    switch ($8|0) {
    case 5135:  {
     $$0$i = 1;
     break L7;
     break;
    }
    default: {
     label = 11;
     break L7;
    }
    }
   } else {
    switch ($8|0) {
    case 35664:  {
     $$0$i$ph = 2;
     label = 12;
     break L7;
     break;
    }
    default: {
     label = 11;
     break L7;
    }
    }
   }
  } else {
   switch ($8|0) {
   case 36972: case 36971: case 36970: case 36969: case 36968: case 36967: case 36966: case 36965: case 36964: case 36963: case 36962: case 36961: case 36960: case 36959: case 36958: case 36957: case 36956: case 36955: case 36954: case 36953: case 36952: case 36951: case 36950: case 36949: case 36948: case 36947: case 36946: case 36945: case 36944: case 36943: case 36942: case 36941: case 36940: case 36312: case 37133: case 37130: case 36879: case 36311: case 37132: case 37129: case 36878: case 36877: case 37131: case 37128: case 36876:  {
    $$0$i = 1;
    break;
   }
   case 36860:  {
    $$0$i$ph = 2;
    label = 12;
    break;
   }
   case 36861:  {
    label = 4;
    break;
   }
   case 36678: case 36862:  {
    label = 5;
    break;
   }
   case 36683: case 36681:  {
    label = 6;
    break;
   }
   case 36685: case 36682:  {
    label = 7;
    break;
   }
   case 36679:  {
    label = 8;
    break;
   }
   case 36686: case 36684:  {
    label = 9;
    break;
   }
   case 36680:  {
    label = 10;
    break;
   }
   default: {
    label = 11;
   }
   }
  }
 } while(0);
 if ((label|0) == 4) {
  $$0$i$ph = 3;
  label = 12;
 }
 else if ((label|0) == 5) {
  $$0$i$ph = 4;
  label = 12;
 }
 else if ((label|0) == 6) {
  $$0$i$ph = 6;
  label = 12;
 }
 else if ((label|0) == 7) {
  $$0$i$ph = 8;
  label = 12;
 }
 else if ((label|0) == 8) {
  $$0$i$ph = 9;
  label = 12;
 }
 else if ((label|0) == 9) {
  $$0$i$ph = 12;
  label = 12;
 }
 else if ((label|0) == 10) {
  $$0$i$ph = 16;
  label = 12;
 }
 else if ((label|0) == 11) {
  $$0$i$ph = 0;
  label = 12;
 }
 if ((label|0) == 12) {
  $$0$i = $$0$i$ph;
 }
 $9 = Math_imul($$0$i, $1)|0;
 $10 = ($8|0)==(36680);
 if ($10) {
  $93 = ((($0)) + 60|0);
  $94 = HEAP32[$93>>2]|0;
  $95 = ((($94)) + 76|0);
  $96 = HEAP32[$95>>2]|0;
  $97 = +HEAPF64[$2>>3];
  $98 = (($96) + ($9<<3)|0);
  HEAPF64[$98>>3] = $97;
  $99 = ((($2)) + 8|0);
  $100 = +HEAPF64[$99>>3];
  $101 = (($9) + 1)|0;
  $102 = (($96) + ($101<<3)|0);
  HEAPF64[$102>>3] = $100;
  $103 = ((($2)) + 16|0);
  $104 = +HEAPF64[$103>>3];
  $105 = (($9) + 2)|0;
  $106 = (($96) + ($105<<3)|0);
  HEAPF64[$106>>3] = $104;
  $107 = ((($2)) + 24|0);
  $108 = +HEAPF64[$107>>3];
  $109 = (($9) + 3)|0;
  $110 = (($96) + ($109<<3)|0);
  HEAPF64[$110>>3] = $108;
  $111 = ((($2)) + 32|0);
  $112 = +HEAPF64[$111>>3];
  $113 = (($9) + 4)|0;
  $114 = (($96) + ($113<<3)|0);
  HEAPF64[$114>>3] = $112;
  $115 = ((($2)) + 40|0);
  $116 = +HEAPF64[$115>>3];
  $117 = (($9) + 5)|0;
  $118 = (($96) + ($117<<3)|0);
  HEAPF64[$118>>3] = $116;
  $119 = ((($2)) + 48|0);
  $120 = +HEAPF64[$119>>3];
  $121 = (($9) + 6)|0;
  $122 = (($96) + ($121<<3)|0);
  HEAPF64[$122>>3] = $120;
  $123 = ((($2)) + 56|0);
  $124 = +HEAPF64[$123>>3];
  $125 = (($9) + 7)|0;
  $126 = (($96) + ($125<<3)|0);
  HEAPF64[$126>>3] = $124;
  $127 = ((($2)) + 64|0);
  $128 = +HEAPF64[$127>>3];
  $129 = (($9) + 8)|0;
  $130 = (($96) + ($129<<3)|0);
  HEAPF64[$130>>3] = $128;
  $131 = ((($2)) + 72|0);
  $132 = +HEAPF64[$131>>3];
  $133 = (($9) + 9)|0;
  $134 = (($96) + ($133<<3)|0);
  HEAPF64[$134>>3] = $132;
  $135 = ((($2)) + 80|0);
  $136 = +HEAPF64[$135>>3];
  $137 = (($9) + 10)|0;
  $138 = (($96) + ($137<<3)|0);
  HEAPF64[$138>>3] = $136;
  $139 = ((($2)) + 88|0);
  $140 = +HEAPF64[$139>>3];
  $141 = (($9) + 11)|0;
  $142 = (($96) + ($141<<3)|0);
  HEAPF64[$142>>3] = $140;
  $143 = ((($2)) + 96|0);
  $144 = +HEAPF64[$143>>3];
  $145 = (($9) + 12)|0;
  $146 = (($96) + ($145<<3)|0);
  HEAPF64[$146>>3] = $144;
  $147 = ((($2)) + 104|0);
  $148 = +HEAPF64[$147>>3];
  $149 = (($9) + 13)|0;
  $150 = (($96) + ($149<<3)|0);
  HEAPF64[$150>>3] = $148;
  $151 = ((($2)) + 112|0);
  $152 = +HEAPF64[$151>>3];
  $153 = (($9) + 14)|0;
  $154 = (($96) + ($153<<3)|0);
  HEAPF64[$154>>3] = $152;
  $155 = ((($2)) + 120|0);
  $156 = +HEAPF64[$155>>3];
  $157 = (($9) + 15)|0;
  $158 = (($96) + ($157<<3)|0);
  HEAPF64[$158>>3] = $156;
 } else {
  $11 = ((($0)) + 56|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ((($12)) + 76|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = +HEAPF64[$2>>3];
  $16 = $15;
  $17 = (($14) + ($9<<2)|0);
  HEAPF32[$17>>2] = $16;
  $18 = ((($2)) + 8|0);
  $19 = +HEAPF64[$18>>3];
  $20 = $19;
  $21 = (($9) + 1)|0;
  $22 = (($14) + ($21<<2)|0);
  HEAPF32[$22>>2] = $20;
  $23 = ((($2)) + 16|0);
  $24 = +HEAPF64[$23>>3];
  $25 = $24;
  $26 = (($9) + 2)|0;
  $27 = (($14) + ($26<<2)|0);
  HEAPF32[$27>>2] = $25;
  $28 = ((($2)) + 24|0);
  $29 = +HEAPF64[$28>>3];
  $30 = $29;
  $31 = (($9) + 3)|0;
  $32 = (($14) + ($31<<2)|0);
  HEAPF32[$32>>2] = $30;
  $33 = ((($2)) + 32|0);
  $34 = +HEAPF64[$33>>3];
  $35 = $34;
  $36 = (($9) + 4)|0;
  $37 = (($14) + ($36<<2)|0);
  HEAPF32[$37>>2] = $35;
  $38 = ((($2)) + 40|0);
  $39 = +HEAPF64[$38>>3];
  $40 = $39;
  $41 = (($9) + 5)|0;
  $42 = (($14) + ($41<<2)|0);
  HEAPF32[$42>>2] = $40;
  $43 = ((($2)) + 48|0);
  $44 = +HEAPF64[$43>>3];
  $45 = $44;
  $46 = (($9) + 6)|0;
  $47 = (($14) + ($46<<2)|0);
  HEAPF32[$47>>2] = $45;
  $48 = ((($2)) + 56|0);
  $49 = +HEAPF64[$48>>3];
  $50 = $49;
  $51 = (($9) + 7)|0;
  $52 = (($14) + ($51<<2)|0);
  HEAPF32[$52>>2] = $50;
  $53 = ((($2)) + 64|0);
  $54 = +HEAPF64[$53>>3];
  $55 = $54;
  $56 = (($9) + 8)|0;
  $57 = (($14) + ($56<<2)|0);
  HEAPF32[$57>>2] = $55;
  $58 = ((($2)) + 72|0);
  $59 = +HEAPF64[$58>>3];
  $60 = $59;
  $61 = (($9) + 9)|0;
  $62 = (($14) + ($61<<2)|0);
  HEAPF32[$62>>2] = $60;
  $63 = ((($2)) + 80|0);
  $64 = +HEAPF64[$63>>3];
  $65 = $64;
  $66 = (($9) + 10)|0;
  $67 = (($14) + ($66<<2)|0);
  HEAPF32[$67>>2] = $65;
  $68 = ((($2)) + 88|0);
  $69 = +HEAPF64[$68>>3];
  $70 = $69;
  $71 = (($9) + 11)|0;
  $72 = (($14) + ($71<<2)|0);
  HEAPF32[$72>>2] = $70;
  $73 = ((($2)) + 96|0);
  $74 = +HEAPF64[$73>>3];
  $75 = $74;
  $76 = (($9) + 12)|0;
  $77 = (($14) + ($76<<2)|0);
  HEAPF32[$77>>2] = $75;
  $78 = ((($2)) + 104|0);
  $79 = +HEAPF64[$78>>3];
  $80 = $79;
  $81 = (($9) + 13)|0;
  $82 = (($14) + ($81<<2)|0);
  HEAPF32[$82>>2] = $80;
  $83 = ((($2)) + 112|0);
  $84 = +HEAPF64[$83>>3];
  $85 = $84;
  $86 = (($9) + 14)|0;
  $87 = (($14) + ($86<<2)|0);
  HEAPF32[$87>>2] = $85;
  $88 = ((($2)) + 120|0);
  $89 = +HEAPF64[$88>>3];
  $90 = $89;
  $91 = (($9) + 15)|0;
  $92 = (($14) + ($91<<2)|0);
  HEAPF32[$92>>2] = $90;
 }
 $159 = ((($0)) + 88|0);
 $160 = HEAP32[$159>>2]|0;
 $161 = (($160) + 1)|0;
 HEAP32[$159>>2] = $161;
 $$026 = 1;
 return ($$026|0);
}
function __ZN3osg7Uniform3setERKNS_7MatrixdE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$pr = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  __ZN3osg7Uniform14setNumElementsEj($0,1);
  $$pr = HEAP32[$2>>2]|0;
  $5 = $$pr;
 } else {
  $5 = $3;
 }
 $6 = ($5|0)==(1);
 if (!($6)) {
  $8 = 0;
  return ($8|0);
 }
 $7 = (__ZN3osg7Uniform10setElementEjRKNS_7MatrixdE($0,0,$1)|0);
 $8 = $7;
 return ($8|0);
}
function __ZN3osg7UniformC2EPKci($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$016$i$i = 0, $$017$i$i = 0, $$04 = 0, $$1 = 0, $$15 = 0, $$pr$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $scevgep$i$i$i = 0, $scevgep5$i$i$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 __ZN3osg10ReferencedC2Ev($0);
 $4 = ((($0)) + 12|0);
 ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;
 $5 = ((($0)) + 24|0);
 HEAP32[$5>>2] = 2;
 $6 = ((($0)) + 28|0);
 HEAP32[$6>>2] = 0;
 HEAP32[$0>>2] = (69328);
 $7 = ((($0)) + 32|0);
 HEAP32[$7>>2] = 0;
 $8 = ((($0)) + 36|0);
 HEAP32[$8>>2] = 0;
 $9 = ((($0)) + 40|0);
 HEAP32[$9>>2] = 0;
 $10 = ((($0)) + 44|0);
 HEAP32[$10>>2] = 5124;
 $11 = ((($0)) + 48|0);
 HEAP32[$11>>2] = 1;
 $12 = ((($0)) + 56|0);
 $13 = ((($0)) + 60|0);
 $14 = ((($0)) + 64|0);
 $15 = ((($0)) + 68|0);
 $16 = ((($0)) + 72|0);
 $17 = ((($0)) + 76|0);
 $18 = ((($0)) + 80|0);
 $19 = ((($0)) + 84|0);
 $20 = ((($0)) + 88|0);
 dest=$12; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 ;HEAP32[$3>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;
 $21 = (_strlen($1)|0);
 $22 = ($21>>>0)>(4294967279);
 do {
  if ($22) {
   __THREW__ = 0;
   invoke_vi(3367,($3|0));
   $23 = __THREW__; __THREW__ = 0;
   label = 20;
  } else {
   $24 = ($21>>>0)<(11);
   if ($24) {
    $33 = $21&255;
    $34 = ((($3)) + 11|0);
    HEAP8[$34>>0] = $33;
    $35 = ($21|0)==(0);
    if ($35) {
     $$017$i$i = $3;
    } else {
     $$016$i$i = $3;
     label = 7;
    }
   } else {
    $25 = (($21) + 16)|0;
    $26 = $25 & -16;
    __THREW__ = 0;
    $27 = (invoke_ii(3276,($26|0))|0);
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if ($29) {
     label = 20;
     break;
    }
    HEAP32[$3>>2] = $27;
    $30 = $26 | -2147483648;
    $31 = ((($3)) + 8|0);
    HEAP32[$31>>2] = $30;
    $32 = ((($3)) + 4|0);
    HEAP32[$32>>2] = $21;
    $$016$i$i = $27;
    label = 7;
   }
   if ((label|0) == 7) {
    _memcpy(($$016$i$i|0),($1|0),($21|0))|0;
    $$017$i$i = $$016$i$i;
   }
   $36 = (($$017$i$i) + ($21)|0);
   HEAP8[$36>>0] = 0;
   __THREW__ = 0;
   invoke_vii(2390,($0|0),($3|0));
   $37 = __THREW__; __THREW__ = 0;
   $38 = $37&1;
   if ($38) {
    $61 = ___cxa_find_matching_catch_2()|0;
    $62 = tempRet0;
    $63 = ((($3)) + 11|0);
    $64 = HEAP8[$63>>0]|0;
    $65 = ($64<<24>>24)<(0);
    if (!($65)) {
     $$0 = $62;$$04 = $61;
     label = 23;
     break;
    }
    $66 = HEAP32[$3>>2]|0;
    __ZdlPv($66);
    $$0 = $62;$$04 = $61;
    label = 23;
    break;
   }
   $39 = ((($3)) + 11|0);
   $40 = HEAP8[$39>>0]|0;
   $41 = ($40<<24>>24)<(0);
   if ($41) {
    $42 = HEAP32[$3>>2]|0;
    __ZdlPv($42);
   }
   __THREW__ = 0;
   invoke_vi(3995,($0|0));
   $43 = __THREW__; __THREW__ = 0;
   $44 = $43&1;
   do {
    if (!($44)) {
     $45 = HEAP32[$11>>2]|0;
     $46 = ($45|0)==(0);
     if ($46) {
      __THREW__ = 0;
      invoke_vii(3994,($0|0),1);
      $47 = __THREW__; __THREW__ = 0;
      $48 = $47&1;
      if ($48) {
       break;
      }
      $$pr$i = HEAP32[$11>>2]|0;
      $49 = $$pr$i;
     } else {
      $49 = $45;
     }
     $50 = ($49|0)==(1);
     if (!($50)) {
      STACKTOP = sp;return;
     }
     __THREW__ = 0;
     $51 = (invoke_iii(3996,($0|0),5124)|0);
     $52 = __THREW__; __THREW__ = 0;
     $53 = $52&1;
     if (!($53)) {
      if (!($51)) {
       STACKTOP = sp;return;
      }
      $54 = HEAP32[$14>>2]|0;
      $55 = ((($54)) + 76|0);
      $56 = HEAP32[$55>>2]|0;
      HEAP32[$56>>2] = $2;
      $57 = HEAP32[$20>>2]|0;
      $58 = (($57) + 1)|0;
      HEAP32[$20>>2] = $58;
      STACKTOP = sp;return;
     }
    }
   } while(0);
   $67 = ___cxa_find_matching_catch_2()|0;
   $68 = tempRet0;
   $$1 = $68;$$15 = $67;
  }
 } while(0);
 if ((label|0) == 20) {
  $59 = ___cxa_find_matching_catch_2()|0;
  $60 = tempRet0;
  $$0 = $60;$$04 = $59;
  label = 23;
 }
 if ((label|0) == 23) {
  $$1 = $$0;$$15 = $$04;
 }
 $69 = HEAP32[$19>>2]|0;
 $70 = ($69|0)==(0|0);
 if (!($70)) {
  $71 = HEAP32[$69>>2]|0;
  $72 = ((($71)) + -16|0);
  $73 = HEAP32[$72>>2]|0;
  $74 = (($69) + ($73)|0);
  $75 = ((($74)) + 8|0);
  $76 = HEAP32[$75>>2]|0;HEAP32[$75>>2] = (($76-1)|0);
  $77 = ($76|0)==(1);
  if ($77) {
   __THREW__ = 0;
   invoke_viii(3262,($74|0),1,1);
   $78 = __THREW__; __THREW__ = 0;
   $79 = $78&1;
   if ($79) {
    $144 = ___cxa_find_matching_catch_3(0|0)|0;
    $145 = tempRet0;
    ___clang_call_terminate($144);
    // unreachable;
   }
  }
 }
 HEAP32[$19>>2] = 0;
 $80 = HEAP32[$18>>2]|0;
 $81 = ($80|0)==(0|0);
 if (!($81)) {
  $82 = HEAP32[$80>>2]|0;
  $83 = ((($82)) + -16|0);
  $84 = HEAP32[$83>>2]|0;
  $85 = (($80) + ($84)|0);
  $86 = ((($85)) + 8|0);
  $87 = HEAP32[$86>>2]|0;HEAP32[$86>>2] = (($87-1)|0);
  $88 = ($87|0)==(1);
  if ($88) {
   __THREW__ = 0;
   invoke_viii(3262,($85|0),1,1);
   $89 = __THREW__; __THREW__ = 0;
   $90 = $89&1;
   if ($90) {
    $144 = ___cxa_find_matching_catch_3(0|0)|0;
    $145 = tempRet0;
    ___clang_call_terminate($144);
    // unreachable;
   }
  }
 }
 HEAP32[$18>>2] = 0;
 $91 = HEAP32[$17>>2]|0;
 $92 = ($91|0)==(0|0);
 if (!($92)) {
  $93 = ((($91)) + 8|0);
  $94 = HEAP32[$93>>2]|0;HEAP32[$93>>2] = (($94-1)|0);
  $95 = ($94|0)==(1);
  if ($95) {
   __THREW__ = 0;
   invoke_viii(3262,($91|0),1,1);
   $96 = __THREW__; __THREW__ = 0;
   $97 = $96&1;
   if ($97) {
    $144 = ___cxa_find_matching_catch_3(0|0)|0;
    $145 = tempRet0;
    ___clang_call_terminate($144);
    // unreachable;
   }
  }
 }
 HEAP32[$17>>2] = 0;
 $98 = HEAP32[$16>>2]|0;
 $99 = ($98|0)==(0|0);
 if (!($99)) {
  $100 = ((($98)) + 8|0);
  $101 = HEAP32[$100>>2]|0;HEAP32[$100>>2] = (($101-1)|0);
  $102 = ($101|0)==(1);
  if ($102) {
   __THREW__ = 0;
   invoke_viii(3262,($98|0),1,1);
   $103 = __THREW__; __THREW__ = 0;
   $104 = $103&1;
   if ($104) {
    $144 = ___cxa_find_matching_catch_3(0|0)|0;
    $145 = tempRet0;
    ___clang_call_terminate($144);
    // unreachable;
   }
  }
 }
 HEAP32[$16>>2] = 0;
 $105 = HEAP32[$15>>2]|0;
 $106 = ($105|0)==(0|0);
 if (!($106)) {
  $107 = ((($105)) + 8|0);
  $108 = HEAP32[$107>>2]|0;HEAP32[$107>>2] = (($108-1)|0);
  $109 = ($108|0)==(1);
  if ($109) {
   __THREW__ = 0;
   invoke_viii(3262,($105|0),1,1);
   $110 = __THREW__; __THREW__ = 0;
   $111 = $110&1;
   if ($111) {
    $144 = ___cxa_find_matching_catch_3(0|0)|0;
    $145 = tempRet0;
    ___clang_call_terminate($144);
    // unreachable;
   }
  }
 }
 HEAP32[$15>>2] = 0;
 $112 = HEAP32[$14>>2]|0;
 $113 = ($112|0)==(0|0);
 if (!($113)) {
  $114 = ((($112)) + 8|0);
  $115 = HEAP32[$114>>2]|0;HEAP32[$114>>2] = (($115-1)|0);
  $116 = ($115|0)==(1);
  if ($116) {
   __THREW__ = 0;
   invoke_viii(3262,($112|0),1,1);
   $117 = __THREW__; __THREW__ = 0;
   $118 = $117&1;
   if ($118) {
    $144 = ___cxa_find_matching_catch_3(0|0)|0;
    $145 = tempRet0;
    ___clang_call_terminate($144);
    // unreachable;
   }
  }
 }
 HEAP32[$14>>2] = 0;
 $119 = HEAP32[$13>>2]|0;
 $120 = ($119|0)==(0|0);
 if (!($120)) {
  $121 = ((($119)) + 8|0);
  $122 = HEAP32[$121>>2]|0;HEAP32[$121>>2] = (($122-1)|0);
  $123 = ($122|0)==(1);
  if ($123) {
   __THREW__ = 0;
   invoke_viii(3262,($119|0),1,1);
   $124 = __THREW__; __THREW__ = 0;
   $125 = $124&1;
   if ($125) {
    $144 = ___cxa_find_matching_catch_3(0|0)|0;
    $145 = tempRet0;
    ___clang_call_terminate($144);
    // unreachable;
   }
  }
 }
 HEAP32[$13>>2] = 0;
 $126 = HEAP32[$12>>2]|0;
 $127 = ($126|0)==(0|0);
 if (!($127)) {
  $128 = ((($126)) + 8|0);
  $129 = HEAP32[$128>>2]|0;HEAP32[$128>>2] = (($129-1)|0);
  $130 = ($129|0)==(1);
  if ($130) {
   __THREW__ = 0;
   invoke_viii(3262,($126|0),1,1);
   $131 = __THREW__; __THREW__ = 0;
   $132 = $131&1;
   if ($132) {
    $144 = ___cxa_find_matching_catch_3(0|0)|0;
    $145 = tempRet0;
    ___clang_call_terminate($144);
    // unreachable;
   }
  }
 }
 HEAP32[$12>>2] = 0;
 $133 = HEAP32[$7>>2]|0;
 $134 = ($133|0)==(0|0);
 if (!($134)) {
  $135 = HEAP32[$8>>2]|0;
  $136 = ($135|0)==($133|0);
  if (!($136)) {
   $scevgep$i$i$i = ((($135)) + -4|0);
   $137 = $scevgep$i$i$i;
   $138 = $133;
   $139 = (($137) - ($138))|0;
   $140 = $139 >>> 2;
   $141 = $140 ^ -1;
   $scevgep5$i$i$i = (($135) + ($141<<2)|0);
   HEAP32[$8>>2] = $scevgep5$i$i$i;
  }
  __ZdlPv($133);
 }
 __THREW__ = 0;
 invoke_vi(388,($0|0));
 $142 = __THREW__; __THREW__ = 0;
 $143 = $142&1;
 if ($143) {
  $144 = ___cxa_find_matching_catch_3(0|0)|0;
  $145 = tempRet0;
  ___clang_call_terminate($144);
  // unreachable;
 } else {
  ___resumeException($$15|0);
  // unreachable;
 }
}
function __ZN3osg7Uniform3setEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$pr = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  __ZN3osg7Uniform14setNumElementsEj($0,1);
  $$pr = HEAP32[$2>>2]|0;
  $5 = $$pr;
 } else {
  $5 = $3;
 }
 $6 = ($5|0)==(1);
 if (!($6)) {
  $15 = 0;
  return ($15|0);
 }
 $7 = (__ZNK3osg7Uniform16isCompatibleTypeENS0_4TypeE($0,5125)|0);
 if (!($7)) {
  $15 = 0;
  return ($15|0);
 }
 $8 = ((($0)) + 68|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($9)) + 76|0);
 $11 = HEAP32[$10>>2]|0;
 HEAP32[$11>>2] = $1;
 $12 = ((($0)) + 88|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($13) + 1)|0;
 HEAP32[$12>>2] = $14;
 $15 = 1;
 return ($15|0);
}
function __ZNK3osg7Uniform9getNameIDEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 return ($2|0);
}
function __ZNK3osg7Uniform5applyEPKNS_12GLExtensionsEi($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0;
 var $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0;
 var $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0;
 var $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0;
 var $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0;
 var $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0;
 var $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0;
 var $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0;
 var $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0;
 var $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0;
 var $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $switch$split112D = 0, $switch$split142D = 0, $switch$split172D = 0, $switch$split22D = 0, $switch$split2D = 0, $switch$split52D = 0, $switch$split82D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp + 4|0;
 $4 = sp;
 $5 = ((($0)) + 48|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)<(1);
 if ($7) {
  STACKTOP = sp;return;
 }
 $8 = ((($0)) + 44|0);
 $9 = HEAP32[$8>>2]|0;
 $switch$split2D = ($9|0)<(36311);
 L4: do {
  if ($switch$split2D) {
   $switch$split22D = ($9|0)<(35686);
   if (!($switch$split22D)) {
    switch ($9|0) {
    case 36309: case 36310: case 36308: case 36307: case 36306: case 36305: case 36301: case 36304: case 36303: case 36302: case 36300: case 36299: case 36298: case 36297: case 36290: case 36293: case 36292: case 36291: case 36289: case 36288:  {
     label = 55;
     break L4;
     break;
    }
    case 35686:  {
     $66 = ((($0)) + 56|0);
     $67 = HEAP32[$66>>2]|0;
     $68 = ($67|0)==(0|0);
     if ($68) {
      STACKTOP = sp;return;
     }
     $69 = ((($1)) + 428|0);
     $70 = HEAP32[$69>>2]|0;
     $71 = ((($67)) + 76|0);
     $72 = HEAP32[$71>>2]|0;
     FUNCTION_TABLE_viiii[$70 & 8191]($2,$6,0,$72);
     STACKTOP = sp;return;
     break;
    }
    case 35687:  {
     $73 = ((($0)) + 56|0);
     $74 = HEAP32[$73>>2]|0;
     $75 = ($74|0)==(0|0);
     if ($75) {
      STACKTOP = sp;return;
     }
     $76 = ((($1)) + 424|0);
     $77 = HEAP32[$76>>2]|0;
     $78 = ((($74)) + 76|0);
     $79 = HEAP32[$78>>2]|0;
     FUNCTION_TABLE_viiii[$77 & 8191]($2,$6,0,$79);
     STACKTOP = sp;return;
     break;
    }
    case 35688:  {
     $80 = ((($0)) + 56|0);
     $81 = HEAP32[$80>>2]|0;
     $82 = ($81|0)==(0|0);
     if ($82) {
      STACKTOP = sp;return;
     }
     $83 = ((($1)) + 436|0);
     $84 = HEAP32[$83>>2]|0;
     $85 = ((($81)) + 76|0);
     $86 = HEAP32[$85>>2]|0;
     FUNCTION_TABLE_viiii[$84 & 8191]($2,$6,0,$86);
     STACKTOP = sp;return;
     break;
    }
    case 35689:  {
     $87 = ((($0)) + 56|0);
     $88 = HEAP32[$87>>2]|0;
     $89 = ($88|0)==(0|0);
     if ($89) {
      STACKTOP = sp;return;
     }
     $90 = ((($1)) + 432|0);
     $91 = HEAP32[$90>>2]|0;
     $92 = ((($88)) + 76|0);
     $93 = HEAP32[$92>>2]|0;
     FUNCTION_TABLE_viiii[$91 & 8191]($2,$6,0,$93);
     STACKTOP = sp;return;
     break;
    }
    case 35690:  {
     $94 = ((($0)) + 56|0);
     $95 = HEAP32[$94>>2]|0;
     $96 = ($95|0)==(0|0);
     if ($96) {
      STACKTOP = sp;return;
     }
     $97 = ((($1)) + 440|0);
     $98 = HEAP32[$97>>2]|0;
     $99 = ((($95)) + 76|0);
     $100 = HEAP32[$99>>2]|0;
     FUNCTION_TABLE_viiii[$98 & 8191]($2,$6,0,$100);
     STACKTOP = sp;return;
     break;
    }
    case 36294:  {
     $227 = ((($0)) + 68|0);
     $228 = HEAP32[$227>>2]|0;
     $229 = ($228|0)==(0|0);
     if ($229) {
      STACKTOP = sp;return;
     }
     $230 = ((($1)) + 500|0);
     $231 = HEAP32[$230>>2]|0;
     $232 = ((($228)) + 76|0);
     $233 = HEAP32[$232>>2]|0;
     FUNCTION_TABLE_viii[$231 & 8191]($2,$6,$233);
     STACKTOP = sp;return;
     break;
    }
    case 36295:  {
     $234 = ((($0)) + 68|0);
     $235 = HEAP32[$234>>2]|0;
     $236 = ($235|0)==(0|0);
     if ($236) {
      STACKTOP = sp;return;
     }
     $237 = ((($1)) + 504|0);
     $238 = HEAP32[$237>>2]|0;
     $239 = ((($235)) + 76|0);
     $240 = HEAP32[$239>>2]|0;
     FUNCTION_TABLE_viii[$238 & 8191]($2,$6,$240);
     STACKTOP = sp;return;
     break;
    }
    case 36296:  {
     $241 = ((($0)) + 68|0);
     $242 = HEAP32[$241>>2]|0;
     $243 = ($242|0)==(0|0);
     if ($243) {
      STACKTOP = sp;return;
     }
     $244 = ((($1)) + 508|0);
     $245 = HEAP32[$244>>2]|0;
     $246 = ((($242)) + 76|0);
     $247 = HEAP32[$246>>2]|0;
     FUNCTION_TABLE_viii[$245 & 8191]($2,$6,$247);
     STACKTOP = sp;return;
     break;
    }
    default: {
     break L4;
    }
    }
   }
   $switch$split52D = ($9|0)<(35672);
   L50: do {
    if ($switch$split52D) {
     $switch$split82D = ($9|0)<(35665);
     if (!($switch$split82D)) {
      switch ($9|0) {
      case 35670:  {
       label = 55;
       break L4;
       break;
      }
      case 35668:  {
       label = 59;
       break L50;
       break;
      }
      case 35669:  {
       label = 61;
       break L50;
       break;
      }
      case 35667: case 35671:  {
       $199 = ((($0)) + 64|0);
       $200 = HEAP32[$199>>2]|0;
       $201 = ($200|0)==(0|0);
       if ($201) {
        STACKTOP = sp;return;
       }
       $202 = ((($1)) + 232|0);
       $203 = HEAP32[$202>>2]|0;
       $204 = ((($200)) + 76|0);
       $205 = HEAP32[$204>>2]|0;
       FUNCTION_TABLE_viii[$203 & 8191]($2,$6,$205);
       STACKTOP = sp;return;
       break;
      }
      case 35665:  {
       $24 = ((($0)) + 56|0);
       $25 = HEAP32[$24>>2]|0;
       $26 = ($25|0)==(0|0);
       if ($26) {
        STACKTOP = sp;return;
       }
       $27 = ((($1)) + 220|0);
       $28 = HEAP32[$27>>2]|0;
       $29 = ((($25)) + 76|0);
       $30 = HEAP32[$29>>2]|0;
       FUNCTION_TABLE_viii[$28 & 8191]($2,$6,$30);
       STACKTOP = sp;return;
       break;
      }
      case 35666:  {
       $31 = ((($0)) + 56|0);
       $32 = HEAP32[$31>>2]|0;
       $33 = ($32|0)==(0|0);
       if ($33) {
        STACKTOP = sp;return;
       }
       $34 = ((($1)) + 224|0);
       $35 = HEAP32[$34>>2]|0;
       $36 = ((($32)) + 76|0);
       $37 = HEAP32[$36>>2]|0;
       FUNCTION_TABLE_viii[$35 & 8191]($2,$6,$37);
       STACKTOP = sp;return;
       break;
      }
      default: {
       break L4;
      }
      }
     }
     $switch$split112D = ($9|0)<(5130);
     if ($switch$split112D) {
      switch ($9|0) {
      case 5124:  {
       label = 55;
       break L4;
       break;
      }
      case 5126:  {
       $10 = ((($0)) + 56|0);
       $11 = HEAP32[$10>>2]|0;
       $12 = ($11|0)==(0|0);
       if ($12) {
        STACKTOP = sp;return;
       }
       $13 = ((($1)) + 212|0);
       $14 = HEAP32[$13>>2]|0;
       $15 = ((($11)) + 76|0);
       $16 = HEAP32[$15>>2]|0;
       FUNCTION_TABLE_viii[$14 & 8191]($2,$6,$16);
       STACKTOP = sp;return;
       break;
      }
      case 5125:  {
       $220 = ((($0)) + 68|0);
       $221 = HEAP32[$220>>2]|0;
       $222 = ($221|0)==(0|0);
       if ($222) {
        STACKTOP = sp;return;
       }
       $223 = ((($1)) + 496|0);
       $224 = HEAP32[$223>>2]|0;
       $225 = ((($221)) + 76|0);
       $226 = HEAP32[$225>>2]|0;
       FUNCTION_TABLE_viii[$224 & 8191]($2,$6,$226);
       STACKTOP = sp;return;
       break;
      }
      default: {
       break L4;
      }
      }
     }
     $switch$split142D = ($9|0)<(5135);
     if ($switch$split142D) {
      switch ($9|0) {
      case 5134:  {
       $279 = ((($0)) + 72|0);
       $280 = HEAP32[$279>>2]|0;
       $281 = ($280|0)==(0|0);
       if ($281) {
        STACKTOP = sp;return;
       }
       $282 = ((($1)) + 516|0);
       $283 = HEAP32[$282>>2]|0;
       $284 = ((($280)) + 76|0);
       $285 = HEAP32[$284>>2]|0;
       FUNCTION_TABLE_viii[$283 & 8191]($2,$6,$285);
       STACKTOP = sp;return;
       break;
      }
      case 5130:  {
       $101 = ((($0)) + 60|0);
       $102 = HEAP32[$101>>2]|0;
       $103 = ($102|0)==(0|0);
       if ($103) {
        STACKTOP = sp;return;
       }
       $104 = ((($1)) + 632|0);
       $105 = HEAP32[$104>>2]|0;
       $106 = ((($102)) + 76|0);
       $107 = HEAP32[$106>>2]|0;
       FUNCTION_TABLE_viii[$105 & 8191]($2,$6,$107);
       STACKTOP = sp;return;
       break;
      }
      default: {
       break L4;
      }
      }
     }
     $switch$split172D = ($9|0)<(35664);
     if (!($switch$split172D)) {
      switch ($9|0) {
      case 35664:  {
       break;
      }
      default: {
       break L4;
      }
      }
      $17 = ((($0)) + 56|0);
      $18 = HEAP32[$17>>2]|0;
      $19 = ($18|0)==(0|0);
      if ($19) {
       STACKTOP = sp;return;
      }
      $20 = ((($1)) + 216|0);
      $21 = HEAP32[$20>>2]|0;
      $22 = ((($18)) + 76|0);
      $23 = HEAP32[$22>>2]|0;
      FUNCTION_TABLE_viii[$21 & 8191]($2,$6,$23);
      STACKTOP = sp;return;
     }
     switch ($9|0) {
     case 5135:  {
      break;
     }
     default: {
      break L4;
     }
     }
     $248 = ((($0)) + 76|0);
     $249 = HEAP32[$248>>2]|0;
     $250 = ($249|0)==(0|0);
     if ($250) {
      STACKTOP = sp;return;
     }
     $251 = ((($1)) + 524|0);
     $252 = HEAP32[$251>>2]|0;
     $253 = ($252|0)==(0|0);
     if (!($253)) {
      $254 = ((($249)) + 76|0);
      $255 = HEAP32[$254>>2]|0;
      FUNCTION_TABLE_viii[$252 & 8191]($2,$6,$255);
      STACKTOP = sp;return;
     }
     $256 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
     if (!($256)) {
      STACKTOP = sp;return;
     }
     $257 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
     $258 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($257,158014,77)|0);
     $259 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi($258,2762)|0);
     $260 = HEAP32[$259>>2]|0;
     $261 = ((($260)) + -12|0);
     $262 = HEAP32[$261>>2]|0;
     $263 = (($259) + ($262)|0);
     __ZNKSt3__28ios_base6getlocEv($3,$263);
     __THREW__ = 0;
     $264 = (invoke_iii(3255,($3|0),(215188|0))|0);
     $265 = __THREW__; __THREW__ = 0;
     $266 = $265&1;
     if (!($266)) {
      $267 = HEAP32[$264>>2]|0;
      $268 = ((($267)) + 28|0);
      $269 = HEAP32[$268>>2]|0;
      __THREW__ = 0;
      $270 = (invoke_iii($269|0,($264|0),10)|0);
      $271 = __THREW__; __THREW__ = 0;
      $272 = $271&1;
      if (!($272)) {
       __ZNSt3__26localeD2Ev($3);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($259,$270)|0);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($259)|0);
       STACKTOP = sp;return;
      }
     }
     $273 = ___cxa_find_matching_catch_2()|0;
     $274 = tempRet0;
     __THREW__ = 0;
     invoke_vi(3263,($3|0));
     $275 = __THREW__; __THREW__ = 0;
     $276 = $275&1;
     if ($276) {
      $277 = ___cxa_find_matching_catch_3(0|0)|0;
      $278 = tempRet0;
      ___clang_call_terminate($277);
      // unreachable;
     } else {
      ___resumeException($273|0);
      // unreachable;
     }
    } else {
     switch ($9|0) {
     case 35684: case 35683: case 35682: case 35681: case 35680: case 35679: case 35678: case 35677:  {
      label = 55;
      break L4;
      break;
     }
     case 35672:  {
      label = 59;
      break L50;
      break;
     }
     case 35673:  {
      label = 61;
      break L50;
      break;
     }
     case 35674:  {
      $38 = ((($0)) + 56|0);
      $39 = HEAP32[$38>>2]|0;
      $40 = ($39|0)==(0|0);
      if ($40) {
       STACKTOP = sp;return;
      }
      $41 = ((($1)) + 244|0);
      $42 = HEAP32[$41>>2]|0;
      $43 = ((($39)) + 76|0);
      $44 = HEAP32[$43>>2]|0;
      FUNCTION_TABLE_viiii[$42 & 8191]($2,$6,0,$44);
      STACKTOP = sp;return;
      break;
     }
     case 35675:  {
      $45 = ((($0)) + 56|0);
      $46 = HEAP32[$45>>2]|0;
      $47 = ($46|0)==(0|0);
      if ($47) {
       STACKTOP = sp;return;
      }
      $48 = ((($1)) + 248|0);
      $49 = HEAP32[$48>>2]|0;
      $50 = ((($46)) + 76|0);
      $51 = HEAP32[$50>>2]|0;
      FUNCTION_TABLE_viiii[$49 & 8191]($2,$6,0,$51);
      STACKTOP = sp;return;
      break;
     }
     case 35676:  {
      $52 = ((($0)) + 56|0);
      $53 = HEAP32[$52>>2]|0;
      $54 = ($53|0)==(0|0);
      if ($54) {
       STACKTOP = sp;return;
      }
      $55 = ((($1)) + 252|0);
      $56 = HEAP32[$55>>2]|0;
      $57 = ((($53)) + 76|0);
      $58 = HEAP32[$57>>2]|0;
      FUNCTION_TABLE_viiii[$56 & 8191]($2,$6,0,$58);
      STACKTOP = sp;return;
      break;
     }
     case 35685:  {
      $59 = ((($0)) + 56|0);
      $60 = HEAP32[$59>>2]|0;
      $61 = ($60|0)==(0|0);
      if ($61) {
       STACKTOP = sp;return;
      }
      $62 = ((($1)) + 420|0);
      $63 = HEAP32[$62>>2]|0;
      $64 = ((($60)) + 76|0);
      $65 = HEAP32[$64>>2]|0;
      FUNCTION_TABLE_viiii[$63 & 8191]($2,$6,0,$65);
      STACKTOP = sp;return;
      break;
     }
     default: {
      break L4;
     }
     }
    }
   } while(0);
   if ((label|0) == 59) {
    $206 = ((($0)) + 64|0);
    $207 = HEAP32[$206>>2]|0;
    $208 = ($207|0)==(0|0);
    if ($208) {
     STACKTOP = sp;return;
    }
    $209 = ((($1)) + 236|0);
    $210 = HEAP32[$209>>2]|0;
    $211 = ((($207)) + 76|0);
    $212 = HEAP32[$211>>2]|0;
    FUNCTION_TABLE_viii[$210 & 8191]($2,$6,$212);
    STACKTOP = sp;return;
   }
   else if ((label|0) == 61) {
    $213 = ((($0)) + 64|0);
    $214 = HEAP32[$213>>2]|0;
    $215 = ($214|0)==(0|0);
    if ($215) {
     STACKTOP = sp;return;
    }
    $216 = ((($1)) + 240|0);
    $217 = HEAP32[$216>>2]|0;
    $218 = ((($214)) + 76|0);
    $219 = HEAP32[$218>>2]|0;
    FUNCTION_TABLE_viii[$217 & 8191]($2,$6,$219);
    STACKTOP = sp;return;
   }
  } else {
   do {
    switch ($9|0) {
    case 36972: case 36971: case 36970: case 36969: case 36968: case 36967: case 36966: case 36965: case 36964: case 36963: case 36962: case 36961: case 36960: case 36959: case 36958: case 36957: case 36956: case 36955: case 36954: case 36953: case 36952: case 36951: case 36950: case 36949: case 36948: case 36947: case 36946: case 36945: case 36944: case 36943: case 36942: case 36941: case 36940: case 36312: case 37133: case 37130: case 36879: case 36311: case 37132: case 37129: case 36878: case 36877: case 37131: case 37128: case 36876:  {
     label = 55;
     break L4;
     break;
    }
    case 36860:  {
     $108 = ((($0)) + 60|0);
     $109 = HEAP32[$108>>2]|0;
     $110 = ($109|0)==(0|0);
     if ($110) {
      STACKTOP = sp;return;
     }
     $111 = ((($1)) + 636|0);
     $112 = HEAP32[$111>>2]|0;
     $113 = ((($109)) + 76|0);
     $114 = HEAP32[$113>>2]|0;
     FUNCTION_TABLE_viii[$112 & 8191]($2,$6,$114);
     STACKTOP = sp;return;
     break;
    }
    case 36861:  {
     $115 = ((($0)) + 60|0);
     $116 = HEAP32[$115>>2]|0;
     $117 = ($116|0)==(0|0);
     if ($117) {
      STACKTOP = sp;return;
     }
     $118 = ((($1)) + 640|0);
     $119 = HEAP32[$118>>2]|0;
     $120 = ((($116)) + 76|0);
     $121 = HEAP32[$120>>2]|0;
     FUNCTION_TABLE_viii[$119 & 8191]($2,$6,$121);
     STACKTOP = sp;return;
     break;
    }
    case 36862:  {
     $122 = ((($0)) + 60|0);
     $123 = HEAP32[$122>>2]|0;
     $124 = ($123|0)==(0|0);
     if ($124) {
      STACKTOP = sp;return;
     }
     $125 = ((($1)) + 644|0);
     $126 = HEAP32[$125>>2]|0;
     $127 = ((($123)) + 76|0);
     $128 = HEAP32[$127>>2]|0;
     FUNCTION_TABLE_viii[$126 & 8191]($2,$6,$128);
     STACKTOP = sp;return;
     break;
    }
    case 36678:  {
     $129 = ((($0)) + 60|0);
     $130 = HEAP32[$129>>2]|0;
     $131 = ($130|0)==(0|0);
     if ($131) {
      STACKTOP = sp;return;
     }
     $132 = ((($1)) + 648|0);
     $133 = HEAP32[$132>>2]|0;
     $134 = ((($130)) + 76|0);
     $135 = HEAP32[$134>>2]|0;
     FUNCTION_TABLE_viiii[$133 & 8191]($2,$6,0,$135);
     STACKTOP = sp;return;
     break;
    }
    case 36679:  {
     $136 = ((($0)) + 60|0);
     $137 = HEAP32[$136>>2]|0;
     $138 = ($137|0)==(0|0);
     if ($138) {
      STACKTOP = sp;return;
     }
     $139 = ((($1)) + 652|0);
     $140 = HEAP32[$139>>2]|0;
     $141 = ((($137)) + 76|0);
     $142 = HEAP32[$141>>2]|0;
     FUNCTION_TABLE_viiii[$140 & 8191]($2,$6,0,$142);
     STACKTOP = sp;return;
     break;
    }
    case 36680:  {
     $143 = ((($0)) + 60|0);
     $144 = HEAP32[$143>>2]|0;
     $145 = ($144|0)==(0|0);
     if ($145) {
      STACKTOP = sp;return;
     }
     $146 = ((($1)) + 656|0);
     $147 = HEAP32[$146>>2]|0;
     $148 = ((($144)) + 76|0);
     $149 = HEAP32[$148>>2]|0;
     FUNCTION_TABLE_viiii[$147 & 8191]($2,$6,0,$149);
     STACKTOP = sp;return;
     break;
    }
    case 36681:  {
     $150 = ((($0)) + 60|0);
     $151 = HEAP32[$150>>2]|0;
     $152 = ($151|0)==(0|0);
     if ($152) {
      STACKTOP = sp;return;
     }
     $153 = ((($1)) + 660|0);
     $154 = HEAP32[$153>>2]|0;
     $155 = ((($151)) + 76|0);
     $156 = HEAP32[$155>>2]|0;
     FUNCTION_TABLE_viiii[$154 & 8191]($2,$6,0,$156);
     STACKTOP = sp;return;
     break;
    }
    case 36682:  {
     $157 = ((($0)) + 60|0);
     $158 = HEAP32[$157>>2]|0;
     $159 = ($158|0)==(0|0);
     if ($159) {
      STACKTOP = sp;return;
     }
     $160 = ((($1)) + 668|0);
     $161 = HEAP32[$160>>2]|0;
     $162 = ((($158)) + 76|0);
     $163 = HEAP32[$162>>2]|0;
     FUNCTION_TABLE_viiii[$161 & 8191]($2,$6,0,$163);
     STACKTOP = sp;return;
     break;
    }
    case 36683:  {
     $164 = ((($0)) + 60|0);
     $165 = HEAP32[$164>>2]|0;
     $166 = ($165|0)==(0|0);
     if ($166) {
      STACKTOP = sp;return;
     }
     $167 = ((($1)) + 664|0);
     $168 = HEAP32[$167>>2]|0;
     $169 = ((($165)) + 76|0);
     $170 = HEAP32[$169>>2]|0;
     FUNCTION_TABLE_viiii[$168 & 8191]($2,$6,0,$170);
     STACKTOP = sp;return;
     break;
    }
    case 36684:  {
     $171 = ((($0)) + 60|0);
     $172 = HEAP32[$171>>2]|0;
     $173 = ($172|0)==(0|0);
     if ($173) {
      STACKTOP = sp;return;
     }
     $174 = ((($1)) + 676|0);
     $175 = HEAP32[$174>>2]|0;
     $176 = ((($172)) + 76|0);
     $177 = HEAP32[$176>>2]|0;
     FUNCTION_TABLE_viiii[$175 & 8191]($2,$6,0,$177);
     STACKTOP = sp;return;
     break;
    }
    case 36685:  {
     $178 = ((($0)) + 60|0);
     $179 = HEAP32[$178>>2]|0;
     $180 = ($179|0)==(0|0);
     if ($180) {
      STACKTOP = sp;return;
     }
     $181 = ((($1)) + 672|0);
     $182 = HEAP32[$181>>2]|0;
     $183 = ((($179)) + 76|0);
     $184 = HEAP32[$183>>2]|0;
     FUNCTION_TABLE_viiii[$182 & 8191]($2,$6,0,$184);
     STACKTOP = sp;return;
     break;
    }
    case 36686:  {
     $185 = ((($0)) + 60|0);
     $186 = HEAP32[$185>>2]|0;
     $187 = ($186|0)==(0|0);
     if ($187) {
      STACKTOP = sp;return;
     }
     $188 = ((($1)) + 680|0);
     $189 = HEAP32[$188>>2]|0;
     $190 = ((($186)) + 76|0);
     $191 = HEAP32[$190>>2]|0;
     FUNCTION_TABLE_viiii[$189 & 8191]($2,$6,0,$191);
     STACKTOP = sp;return;
     break;
    }
    default: {
     break L4;
    }
    }
   } while(0);
  }
 } while(0);
 if ((label|0) == 55) {
  $192 = ((($0)) + 64|0);
  $193 = HEAP32[$192>>2]|0;
  $194 = ($193|0)==(0|0);
  if ($194) {
   STACKTOP = sp;return;
  }
  $195 = ((($1)) + 228|0);
  $196 = HEAP32[$195>>2]|0;
  $197 = ((($193)) + 76|0);
  $198 = HEAP32[$197>>2]|0;
  FUNCTION_TABLE_viii[$196 & 8191]($2,$6,$198);
  STACKTOP = sp;return;
 }
 $286 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(1)|0);
 if (!($286)) {
  STACKTOP = sp;return;
 }
 $287 = (__ZN3osg6notifyENS_14NotifySeverityE(1)|0);
 $288 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($287,158014,77)|0);
 $289 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi($288,2771)|0);
 $290 = HEAP32[$289>>2]|0;
 $291 = ((($290)) + -12|0);
 $292 = HEAP32[$291>>2]|0;
 $293 = (($289) + ($292)|0);
 __ZNKSt3__28ios_base6getlocEv($4,$293);
 __THREW__ = 0;
 $294 = (invoke_iii(3255,($4|0),(215188|0))|0);
 $295 = __THREW__; __THREW__ = 0;
 $296 = $295&1;
 if (!($296)) {
  $297 = HEAP32[$294>>2]|0;
  $298 = ((($297)) + 28|0);
  $299 = HEAP32[$298>>2]|0;
  __THREW__ = 0;
  $300 = (invoke_iii($299|0,($294|0),10)|0);
  $301 = __THREW__; __THREW__ = 0;
  $302 = $301&1;
  if (!($302)) {
   __ZNSt3__26localeD2Ev($4);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($289,$300)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($289)|0);
   STACKTOP = sp;return;
  }
 }
 $303 = ___cxa_find_matching_catch_2()|0;
 $304 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($4|0));
 $305 = __THREW__; __THREW__ = 0;
 $306 = $305&1;
 if ($306) {
  $307 = ___cxa_find_matching_catch_3(0|0)|0;
  $308 = tempRet0;
  ___clang_call_terminate($307);
  // unreachable;
 } else {
  ___resumeException($303|0);
  // unreachable;
 }
}
function __ZN3osg17UserDataContainer19asUserDataContainerEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ($0|0);
}
function __ZNK3osg17UserDataContainer19asUserDataContainerEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ($0|0);
}
function __ZN3osg17UserDataContainer13getUserObjectERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEj($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = HEAP32[$0>>2]|0;
 $4 = ((($3)) + 152|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($3)) + 168|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_iiii[$7 & 8191]($0,$1,$2)|0);
 $9 = (FUNCTION_TABLE_iii[$5 & 8191]($0,$8)|0);
 return ($9|0);
}
function __ZNK3osg17UserDataContainer13getUserObjectERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEj($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = HEAP32[$0>>2]|0;
 $4 = ((($3)) + 156|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($3)) + 168|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_iiii[$7 & 8191]($0,$1,$2)|0);
 $9 = (FUNCTION_TABLE_iii[$5 & 8191]($0,$8)|0);
 return ($9|0);
}
function __ZN3osg24DefaultUserDataContainer21setThreadSafeRefUnrefEb($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$sroa$04$08 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg6Object21setThreadSafeRefUnrefEb($0,$1);
 $2 = ((($0)) + 32|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = HEAP32[$3>>2]|0;
  $6 = HEAP32[$5>>2]|0;
  FUNCTION_TABLE_vii[$6 & 8191]($3,$1);
 }
 $7 = ((($0)) + 48|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($0)) + 52|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8|0)==($10|0);
 if ($11) {
  return;
 } else {
  $$sroa$04$08 = $8;
 }
 while(1) {
  $12 = HEAP32[$$sroa$04$08>>2]|0;
  $13 = HEAP32[$12>>2]|0;
  $14 = HEAP32[$13>>2]|0;
  FUNCTION_TABLE_vii[$14 & 8191]($12,$1);
  $15 = ((($$sroa$04$08)) + 4|0);
  $16 = HEAP32[$9>>2]|0;
  $17 = ($15|0)==($16|0);
  if ($17) {
   break;
  } else {
   $$sroa$04$08 = $15;
  }
 }
 return;
}
function __ZN3osg24DefaultUserDataContainerD2Ev($0) {
 $0 = $0|0;
 var $$pre$i = 0, $$pre$i$i$i = 0, $$pre$i6 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (69484);
 $1 = ((($0)) + 48|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = ((($0)) + 52|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==($2|0);
  do {
   if ($6) {
    $20 = $2;
   } else {
    $8 = $5;
    while(1) {
     $7 = ((($8)) + -4|0);
     HEAP32[$4>>2] = $7;
     $9 = HEAP32[$7>>2]|0;
     $10 = ($9|0)==(0|0);
     if (!($10)) {
      $11 = ((($9)) + 8|0);
      $12 = HEAP32[$11>>2]|0;HEAP32[$11>>2] = (($12-1)|0);
      $13 = ($12|0)==(1);
      if ($13) {
       __THREW__ = 0;
       invoke_viii(3262,($9|0),1,1);
       $14 = __THREW__; __THREW__ = 0;
       $15 = $14&1;
       if ($15) {
        label = 7;
        break;
       }
      }
     }
     HEAP32[$7>>2] = 0;
     $16 = HEAP32[$4>>2]|0;
     $17 = ($16|0)==($2|0);
     if ($17) {
      label = 8;
      break;
     } else {
      $8 = $16;
     }
    }
    if ((label|0) == 7) {
     $18 = ___cxa_find_matching_catch_2()|0;
     $19 = tempRet0;
     ___cxa_call_unexpected(($18|0));
     // unreachable;
    }
    else if ((label|0) == 8) {
     $$pre$i = HEAP32[$1>>2]|0;
     $20 = $$pre$i;
     break;
    }
   }
  } while(0);
  __ZdlPv($20);
 }
 $21 = ((($0)) + 36|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0|0);
 if (!($23)) {
  $24 = ((($0)) + 40|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = ($25|0)==($22|0);
  if ($26) {
   $35 = $22;
  } else {
   $28 = $25;
   while(1) {
    $27 = ((($28)) + -12|0);
    HEAP32[$24>>2] = $27;
    $29 = ((($27)) + 11|0);
    $30 = HEAP8[$29>>0]|0;
    $31 = ($30<<24>>24)<(0);
    if ($31) {
     $34 = HEAP32[$27>>2]|0;
     __ZdlPv($34);
     $$pre$i$i$i = HEAP32[$24>>2]|0;
     $32 = $$pre$i$i$i;
    } else {
     $32 = $27;
    }
    $33 = ($32|0)==($22|0);
    if ($33) {
     break;
    } else {
     $28 = $32;
    }
   }
   $$pre$i6 = HEAP32[$21>>2]|0;
   $35 = $$pre$i6;
  }
  __ZdlPv($35);
 }
 $36 = ((($0)) + 32|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = ($37|0)==(0|0);
 if ($38) {
  HEAP32[$36>>2] = 0;
  __ZN3osg6ObjectD2Ev($0);
  return;
 }
 $39 = ((($37)) + 8|0);
 $40 = HEAP32[$39>>2]|0;HEAP32[$39>>2] = (($40-1)|0);
 $41 = ($40|0)==(1);
 if (!($41)) {
  HEAP32[$36>>2] = 0;
  __ZN3osg6ObjectD2Ev($0);
  return;
 }
 __THREW__ = 0;
 invoke_viii(3262,($37|0),1,1);
 $42 = __THREW__; __THREW__ = 0;
 $43 = $42&1;
 if (!($43)) {
  HEAP32[$36>>2] = 0;
  __ZN3osg6ObjectD2Ev($0);
  return;
 }
 $44 = ___cxa_find_matching_catch_2()|0;
 $45 = tempRet0;
 __THREW__ = 0;
 invoke_vi(388,($0|0));
 $46 = __THREW__; __THREW__ = 0;
 $47 = $46&1;
 if ($47) {
  $48 = ___cxa_find_matching_catch_3(0|0)|0;
  $49 = tempRet0;
  ___clang_call_terminate($48);
  // unreachable;
 } else {
  ___resumeException($44|0);
  // unreachable;
 }
}
function __ZN3osg24DefaultUserDataContainerD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(2394,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK3osg24DefaultUserDataContainer9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(60)|0);
 __THREW__ = 0;
 invoke_vii(3435,($1|0),1);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $8 = ___cxa_find_matching_catch_2()|0;
  $9 = tempRet0;
  __ZdlPv($1);
  ___resumeException($8|0);
  // unreachable;
 } else {
  $4 = ((($1)) + 12|0);
  ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;
  $5 = ((($1)) + 24|0);
  HEAP32[$5>>2] = 2;
  $6 = ((($1)) + 28|0);
  HEAP32[$6>>2] = 0;
  HEAP32[$1>>2] = (69484);
  $7 = ((($1)) + 32|0);
  ;HEAP32[$7>>2]=0|0;HEAP32[$7+4>>2]=0|0;HEAP32[$7+8>>2]=0|0;HEAP32[$7+12>>2]=0|0;HEAP32[$7+16>>2]=0|0;HEAP32[$7+20>>2]=0|0;HEAP32[$7+24>>2]=0|0;
  return ($1|0);
 }
 return (0)|0;
}
function __ZNK3osg24DefaultUserDataContainer5cloneERKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(60)|0);
 __THREW__ = 0;
 invoke_viii(3997,($2|0),($0|0),($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch_2()|0;
  $6 = tempRet0;
  __ZdlPv($2);
  ___resumeException($5|0);
  // unreachable;
 } else {
  return ($2|0);
 }
 return (0)|0;
}
function __ZNK3osg24DefaultUserDataContainer12isSameKindAsEPKNS_6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,26992,0)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK3osg24DefaultUserDataContainer11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175113|0);
}
function __ZNK3osg24DefaultUserDataContainer9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (158118|0);
}
function __ZN3osg24DefaultUserDataContainer11setUserDataEPNS_10ReferencedE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 32|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==($1|0);
 if ($4) {
  return;
 }
 HEAP32[$2>>2] = $1;
 $5 = ($1|0)==(0|0);
 if (!($5)) {
  $6 = ((($1)) + 8|0);
  $7 = HEAP32[$6>>2]|0;HEAP32[$6>>2] = (($7+1)|0);
 }
 $8 = ($3|0)==(0|0);
 if ($8) {
  return;
 }
 $9 = ((($3)) + 8|0);
 $10 = HEAP32[$9>>2]|0;HEAP32[$9>>2] = (($10-1)|0);
 $11 = ($10|0)==(1);
 if (!($11)) {
  return;
 }
 __ZNK3osg10Referenced24signalObserversAndDeleteEbb($3,1,1);
 return;
}
function __ZN3osg24DefaultUserDataContainer11getUserDataEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 32|0);
 $2 = HEAP32[$1>>2]|0;
 return ($2|0);
}
function __ZNK3osg24DefaultUserDataContainer11getUserDataEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 32|0);
 $2 = HEAP32[$1>>2]|0;
 return ($2|0);
}
function __ZN3osg24DefaultUserDataContainer13addUserObjectEPNS_6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$pre = 0, $$pre$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = HEAP32[$0>>2]|0;
 $4 = ((($3)) + 164|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_iiii[$5 & 8191]($0,$1,0)|0);
 $7 = ((($0)) + 48|0);
 $8 = ((($0)) + 52|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$7>>2]|0;
 $11 = (($9) - ($10))|0;
 $12 = $11 >> 2;
 $13 = ($6>>>0)<($12>>>0);
 if ($13) {
  $$0 = $6;
  STACKTOP = sp;return ($$0|0);
 }
 $14 = $9;
 HEAP32[$2>>2] = $1;
 $15 = ($1|0)==(0|0);
 if ($15) {
  $20 = $14;
 } else {
  $16 = ((($1)) + 8|0);
  $17 = HEAP32[$16>>2]|0;HEAP32[$16>>2] = (($17+1)|0);
  $$pre = HEAP32[$8>>2]|0;
  $20 = $$pre;
 }
 $18 = ((($0)) + 56|0);
 $19 = HEAP32[$18>>2]|0;
 $21 = ($20|0)==($19|0);
 if ($21) {
  __THREW__ = 0;
  invoke_vii(3475,($7|0),($2|0));
  $28 = __THREW__; __THREW__ = 0;
  $29 = $28&1;
  if ($29) {
   $35 = ___cxa_find_matching_catch_2()|0;
   $36 = tempRet0;
   $37 = HEAP32[$2>>2]|0;
   $38 = ($37|0)==(0|0);
   if ($38) {
    ___resumeException($35|0);
    // unreachable;
   }
   $39 = ((($37)) + 8|0);
   $40 = HEAP32[$39>>2]|0;HEAP32[$39>>2] = (($40-1)|0);
   $41 = ($40|0)==(1);
   if (!($41)) {
    ___resumeException($35|0);
    // unreachable;
   }
   __THREW__ = 0;
   invoke_viii(3262,($37|0),1,1);
   $42 = __THREW__; __THREW__ = 0;
   $43 = $42&1;
   if ($43) {
    $44 = ___cxa_find_matching_catch_3(0|0)|0;
    $45 = tempRet0;
    ___clang_call_terminate($44);
    // unreachable;
   } else {
    ___resumeException($35|0);
    // unreachable;
   }
  }
 } else {
  $22 = HEAP32[$2>>2]|0;
  HEAP32[$20>>2] = $22;
  $23 = ($22|0)==(0|0);
  if ($23) {
   $27 = $20;
  } else {
   $24 = ((($22)) + 8|0);
   $25 = HEAP32[$24>>2]|0;HEAP32[$24>>2] = (($25+1)|0);
   $$pre$i = HEAP32[$8>>2]|0;
   $27 = $$pre$i;
  }
  $26 = ((($27)) + 4|0);
  HEAP32[$8>>2] = $26;
 }
 $30 = HEAP32[$2>>2]|0;
 $31 = ($30|0)==(0|0);
 if (!($31)) {
  $32 = ((($30)) + 8|0);
  $33 = HEAP32[$32>>2]|0;HEAP32[$32>>2] = (($33-1)|0);
  $34 = ($33|0)==(1);
  if ($34) {
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($30,1,1);
  }
 }
 $$0 = $12;
 STACKTOP = sp;return ($$0|0);
}
function __ZN3osg24DefaultUserDataContainer13setUserObjectEjPNS_6ObjectE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 48|0);
 $4 = ((($0)) + 52|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$3>>2]|0;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 2;
 $9 = ($8>>>0)>($1>>>0);
 if (!($9)) {
  return;
 }
 $10 = $6;
 $11 = (($10) + ($1<<2)|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==($2|0);
 if ($13) {
  return;
 }
 HEAP32[$11>>2] = $2;
 $14 = ($2|0)==(0|0);
 if (!($14)) {
  $15 = ((($2)) + 8|0);
  $16 = HEAP32[$15>>2]|0;HEAP32[$15>>2] = (($16+1)|0);
 }
 $17 = ($12|0)==(0|0);
 if ($17) {
  return;
 }
 $18 = ((($12)) + 8|0);
 $19 = HEAP32[$18>>2]|0;HEAP32[$18>>2] = (($19-1)|0);
 $20 = ($19|0)==(1);
 if (!($20)) {
  return;
 }
 __ZNK3osg10Referenced24signalObserversAndDeleteEbb($12,1,1);
 return;
}
function __ZN3osg24DefaultUserDataContainer16removeUserObjectEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$lcssa$i$i10$i = 0, $$078$i$i$i = 0, $$09$i$i$i = 0, $$pre$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 48|0);
 $3 = ((($0)) + 52|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$2>>2]|0;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 2;
 $8 = ($7>>>0)>($1>>>0);
 $9 = $4;
 if (!($8)) {
  return;
 }
 $10 = $5;
 $11 = (($10) + ($1<<2)|0);
 $12 = ((($11)) + 4|0);
 $13 = ($12|0)==($9|0);
 if ($13) {
  $$0$lcssa$i$i10$i = $11;$41 = $9;
 } else {
  $$078$i$i$i = $12;$$09$i$i$i = $11;
  while(1) {
   $14 = HEAP32[$$09$i$i$i>>2]|0;
   $15 = HEAP32[$$078$i$i$i>>2]|0;
   $16 = ($14|0)==($15|0);
   if (!($16)) {
    HEAP32[$$09$i$i$i>>2] = $15;
    $17 = ($15|0)==(0|0);
    if (!($17)) {
     $18 = ((($15)) + 8|0);
     $19 = HEAP32[$18>>2]|0;HEAP32[$18>>2] = (($19+1)|0);
    }
    $20 = ($14|0)==(0|0);
    if (!($20)) {
     $21 = ((($14)) + 8|0);
     $22 = HEAP32[$21>>2]|0;HEAP32[$21>>2] = (($22-1)|0);
     $23 = ($22|0)==(1);
     if ($23) {
      __ZNK3osg10Referenced24signalObserversAndDeleteEbb($14,1,1);
     }
    }
   }
   $24 = ((($$078$i$i$i)) + 4|0);
   $25 = ((($$09$i$i$i)) + 4|0);
   $26 = ($24|0)==($9|0);
   if ($26) {
    break;
   } else {
    $$078$i$i$i = $24;$$09$i$i$i = $25;
   }
  }
  $$pre$i = HEAP32[$3>>2]|0;
  $27 = ($$pre$i|0)==($25|0);
  if ($27) {
   return;
  } else {
   $$0$lcssa$i$i10$i = $25;$41 = $$pre$i;
  }
 }
 $29 = $41;
 while(1) {
  $28 = ((($29)) + -4|0);
  HEAP32[$3>>2] = $28;
  $30 = HEAP32[$28>>2]|0;
  $31 = ($30|0)==(0|0);
  if (!($31)) {
   $32 = ((($30)) + 8|0);
   $33 = HEAP32[$32>>2]|0;HEAP32[$32>>2] = (($33-1)|0);
   $34 = ($33|0)==(1);
   if ($34) {
    __THREW__ = 0;
    invoke_viii(3262,($30|0),1,1);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     label = 16;
     break;
    }
   }
  }
  HEAP32[$28>>2] = 0;
  $37 = HEAP32[$3>>2]|0;
  $38 = ($37|0)==($$0$lcssa$i$i10$i|0);
  if ($38) {
   label = 17;
   break;
  } else {
   $29 = $37;
  }
 }
 if ((label|0) == 16) {
  $39 = ___cxa_find_matching_catch_2()|0;
  $40 = tempRet0;
  ___cxa_call_unexpected(($39|0));
  // unreachable;
 }
 else if ((label|0) == 17) {
  return;
 }
}
function __ZN3osg24DefaultUserDataContainer13getUserObjectEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 48|0);
 $3 = ((($0)) + 52|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$2>>2]|0;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 2;
 $8 = ($7>>>0)>($1>>>0);
 if (!($8)) {
  $$0 = 0;
  return ($$0|0);
 }
 $9 = $5;
 $10 = (($9) + ($1<<2)|0);
 $11 = HEAP32[$10>>2]|0;
 $$0 = $11;
 return ($$0|0);
}
function __ZNK3osg24DefaultUserDataContainer13getUserObjectEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 48|0);
 $3 = ((($0)) + 52|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$2>>2]|0;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 2;
 $8 = ($7>>>0)>($1>>>0);
 if (!($8)) {
  $$0 = 0;
  return ($$0|0);
 }
 $9 = $5;
 $10 = (($9) + ($1<<2)|0);
 $11 = HEAP32[$10>>2]|0;
 $$0 = $11;
 return ($$0|0);
}
function __ZNK3osg24DefaultUserDataContainer17getNumUserObjectsEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 48|0);
 $2 = ((($0)) + 52|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$1>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 return ($6|0);
}
function __ZNK3osg24DefaultUserDataContainer18getUserObjectIndexEPKNS_6ObjectEj($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0810 = 0, $$1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 48|0);
 $4 = ((($0)) + 52|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$3>>2]|0;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 2;
 $9 = ($8>>>0)>($2>>>0);
 $10 = $6;
 if ($9) {
  $$0810 = $2;
 } else {
  $$1 = $8;
  return ($$1|0);
 }
 while(1) {
  $11 = (($10) + ($$0810<<2)|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($12|0)==($1|0);
  if ($13) {
   $$1 = $$0810;
   label = 4;
   break;
  }
  $14 = (($$0810) + 1)|0;
  $15 = ($14>>>0)<($8>>>0);
  if ($15) {
   $$0810 = $14;
  } else {
   $$1 = $8;
   label = 4;
   break;
  }
 }
 if ((label|0) == 4) {
  return ($$1|0);
 }
 return (0)|0;
}
function __ZNK3osg24DefaultUserDataContainer18getUserObjectIndexERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEj($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$01630 = 0, $$02026$i41 = 0, $$02125$i42 = 0, $$027$i40 = 0, $$3 = 0, $$pre = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 48|0);
 $4 = ((($0)) + 52|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$3>>2]|0;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 2;
 $9 = ($8>>>0)>($2>>>0);
 $10 = $6;
 if (!($9)) {
  $$3 = $8;
  return ($$3|0);
 }
 $11 = ((($1)) + 11|0);
 $12 = HEAP8[$11>>0]|0;
 $13 = ($12<<24>>24)<(0);
 $14 = ((($1)) + 4|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = $12&255;
 $17 = $13 ? $15 : $16;
 $18 = HEAP32[$1>>2]|0;
 $19 = $13 ? $18 : $1;
 $20 = ($17|0)==(0);
 $$01630 = $2;
 L4: while(1) {
  $21 = (($10) + ($$01630<<2)|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = ($22|0)==(0|0);
  do {
   if (!($23)) {
    $24 = ((($22)) + 12|0);
    $25 = ((($24)) + 11|0);
    $26 = HEAP8[$25>>0]|0;
    $27 = ($26<<24>>24)<(0);
    $28 = ((($22)) + 16|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = $26&255;
    $31 = $27 ? $29 : $30;
    $32 = ($31|0)==($17|0);
    if ($32) {
     $33 = HEAP32[$24>>2]|0;
     $34 = $27 ? $33 : $24;
     if ($27) {
      if ($20) {
       $$3 = $$01630;
       label = 13;
       break L4;
      }
      $45 = (_memcmp($34,$19,$17)|0);
      $phitmp$i = ($45|0)==(0);
      if ($phitmp$i) {
       $$3 = $$01630;
       label = 13;
       break L4;
      } else {
       break;
      }
     }
     if ($20) {
      $$3 = $$01630;
      label = 13;
      break L4;
     }
     $35 = $33;
     $36 = $35&255;
     $37 = HEAP8[$19>>0]|0;
     $38 = ($36<<24>>24)==($37<<24>>24);
     if ($38) {
      $$02026$i41 = $24;$$02125$i42 = $30;$$027$i40 = $19;
      while(1) {
       $39 = (($$02125$i42) + -1)|0;
       $40 = ((($$02026$i41)) + 1|0);
       $41 = ($39|0)==(0);
       if ($41) {
        $$3 = $$01630;
        label = 13;
        break L4;
       }
       $42 = ((($$027$i40)) + 1|0);
       $$pre = HEAP8[$40>>0]|0;
       $43 = HEAP8[$42>>0]|0;
       $44 = ($$pre<<24>>24)==($43<<24>>24);
       if ($44) {
        $$02026$i41 = $40;$$02125$i42 = $39;$$027$i40 = $42;
       } else {
        break;
       }
      }
     }
    }
   }
  } while(0);
  $46 = (($$01630) + 1)|0;
  $47 = ($46>>>0)<($8>>>0);
  if ($47) {
   $$01630 = $46;
  } else {
   $$3 = $8;
   label = 13;
   break;
  }
 }
 if ((label|0) == 13) {
  return ($$3|0);
 }
 return (0)|0;
}
function __ZN3osg24DefaultUserDataContainer15setDescriptionsERKNSt3__26vectorINS1_12basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEENS6_IS8_EEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 36|0);
 $3 = ($2|0)==($1|0);
 if ($3) {
  return;
 }
 $4 = HEAP32[$1>>2]|0;
 $5 = ((($1)) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 __ZNSt3__26vectorINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS4_IS6_EEE6assignIPS6_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS6_NS_15iterator_traitsISC_E9referenceEEE5valueEvE4typeESC_SC_($2,$4,$6);
 return;
}
function __ZN3osg24DefaultUserDataContainer15getDescriptionsEv($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 36|0);
 return ($1|0);
}
function __ZNK3osg24DefaultUserDataContainer15getDescriptionsEv($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 36|0);
 return ($1|0);
}
function __ZNK3osg24DefaultUserDataContainer18getNumDescriptionsEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 36|0);
 $2 = ((($0)) + 40|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$1>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = (($5|0) / 12)&-1;
 return ($6|0);
}
function __ZN3osg24DefaultUserDataContainer14addDescriptionERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 40|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 44|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if ($6) {
  $9 = ((($0)) + 36|0);
  __ZNSt3__26vectorINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS4_IS6_EEE21__push_back_slow_pathIKS6_EEvRT_($9,$1);
  return;
 } else {
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_($3,$1);
  $7 = HEAP32[$2>>2]|0;
  $8 = ((($7)) + 12|0);
  HEAP32[$2>>2] = $8;
  return;
 }
}
function __ZN3osg24DefaultUserDataContainerC2ERKS0_RKNS_6CopyOpE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$09 = 0, $$1 = 0, $$110 = 0, $$pre$i = 0, $$pre$i$i$i = 0, $$pre$i17 = 0, $$pre$i21 = 0, $$sroa$024$031 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 __ZN3osg6ObjectC2ERKS0_RKNS_6CopyOpE($0,$1,$2);
 HEAP32[$0>>2] = (69484);
 $4 = ((($0)) + 32|0);
 $5 = ((($0)) + 36|0);
 $6 = ((($0)) + 40|0);
 $7 = ((($0)) + 48|0);
 $8 = ((($0)) + 52|0);
 $9 = ((($1)) + 32|0);
 ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;HEAP32[$4+12>>2]=0|0;HEAP32[$4+16>>2]=0|0;HEAP32[$4+20>>2]=0|0;HEAP32[$4+24>>2]=0|0;
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if (!($11)) {
  HEAP32[$4>>2] = $10;
  $12 = ((($10)) + 8|0);
  $13 = HEAP32[$12>>2]|0;HEAP32[$12>>2] = (($13+1)|0);
 }
 $14 = ($0|0)==($1|0);
 if ($14) {
  label = 5;
 } else {
  $15 = ((($1)) + 36|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ((($1)) + 40|0);
  $18 = HEAP32[$17>>2]|0;
  __THREW__ = 0;
  invoke_viii(3872,($5|0),($16|0),($18|0));
  $19 = __THREW__; __THREW__ = 0;
  $20 = $19&1;
  if ($20) {
   $27 = ___cxa_find_matching_catch_2()|0;
   $28 = tempRet0;
   $$1 = $28;$$110 = $27;
  } else {
   label = 5;
  }
 }
 if ((label|0) == 5) {
  $21 = ((($1)) + 48|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = ((($1)) + 52|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = ($22|0)==($24|0);
  if ($25) {
   STACKTOP = sp;return;
  }
  $26 = ((($0)) + 56|0);
  $$sroa$024$031 = $22;
  while(1) {
   $29 = HEAP32[$2>>2]|0;
   $30 = ((($29)) + 12|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = HEAP32[$$sroa$024$031>>2]|0;
   __THREW__ = 0;
   $33 = (invoke_iii($31|0,($2|0),($32|0))|0);
   $34 = __THREW__; __THREW__ = 0;
   $35 = $34&1;
   if ($35) {
    label = 21;
    break;
   }
   HEAP32[$3>>2] = $33;
   $36 = ($33|0)==(0|0);
   if (!($36)) {
    $37 = ((($33)) + 8|0);
    $38 = HEAP32[$37>>2]|0;HEAP32[$37>>2] = (($38+1)|0);
   }
   $39 = HEAP32[$8>>2]|0;
   $40 = HEAP32[$26>>2]|0;
   $41 = ($39|0)==($40|0);
   if ($41) {
    __THREW__ = 0;
    invoke_vii(3475,($7|0),($3|0));
    $48 = __THREW__; __THREW__ = 0;
    $49 = $48&1;
    if ($49) {
     label = 22;
     break;
    }
   } else {
    $42 = HEAP32[$3>>2]|0;
    HEAP32[$39>>2] = $42;
    $43 = ($42|0)==(0|0);
    if ($43) {
     $47 = $39;
    } else {
     $44 = ((($42)) + 8|0);
     $45 = HEAP32[$44>>2]|0;HEAP32[$44>>2] = (($45+1)|0);
     $$pre$i21 = HEAP32[$8>>2]|0;
     $47 = $$pre$i21;
    }
    $46 = ((($47)) + 4|0);
    HEAP32[$8>>2] = $46;
   }
   $50 = HEAP32[$3>>2]|0;
   $51 = ($50|0)==(0|0);
   if (!($51)) {
    $52 = ((($50)) + 8|0);
    $53 = HEAP32[$52>>2]|0;HEAP32[$52>>2] = (($53-1)|0);
    $54 = ($53|0)==(1);
    if ($54) {
     __THREW__ = 0;
     invoke_viii(3262,($50|0),1,1);
     $55 = __THREW__; __THREW__ = 0;
     $56 = $55&1;
     if ($56) {
      label = 21;
      break;
     }
    }
   }
   $57 = ((($$sroa$024$031)) + 4|0);
   $58 = HEAP32[$23>>2]|0;
   $59 = ($57|0)==($58|0);
   if ($59) {
    label = 7;
    break;
   } else {
    $$sroa$024$031 = $57;
   }
  }
  if ((label|0) == 7) {
   STACKTOP = sp;return;
  }
  else if ((label|0) == 21) {
   $60 = ___cxa_find_matching_catch_2()|0;
   $61 = tempRet0;
   $$0 = $61;$$09 = $60;
  }
  else if ((label|0) == 22) {
   $62 = ___cxa_find_matching_catch_2()|0;
   $63 = tempRet0;
   $64 = HEAP32[$3>>2]|0;
   $65 = ($64|0)==(0|0);
   if (!($65)) {
    $66 = ((($64)) + 8|0);
    $67 = HEAP32[$66>>2]|0;HEAP32[$66>>2] = (($67-1)|0);
    $68 = ($67|0)==(1);
    if ($68) {
     __THREW__ = 0;
     invoke_viii(3262,($64|0),1,1);
     $69 = __THREW__; __THREW__ = 0;
     $70 = $69&1;
     if ($70) {
      $111 = ___cxa_find_matching_catch_3(0|0)|0;
      $112 = tempRet0;
      ___clang_call_terminate($111);
      // unreachable;
     }
    }
   }
   HEAP32[$3>>2] = 0;
   $$0 = $63;$$09 = $62;
  }
  $$1 = $$0;$$110 = $$09;
 }
 $71 = HEAP32[$7>>2]|0;
 $72 = ($71|0)==(0|0);
 if (!($72)) {
  $73 = HEAP32[$8>>2]|0;
  $74 = ($73|0)==($71|0);
  do {
   if ($74) {
    $88 = $71;
   } else {
    $76 = $73;
    while(1) {
     $75 = ((($76)) + -4|0);
     HEAP32[$8>>2] = $75;
     $77 = HEAP32[$75>>2]|0;
     $78 = ($77|0)==(0|0);
     if (!($78)) {
      $79 = ((($77)) + 8|0);
      $80 = HEAP32[$79>>2]|0;HEAP32[$79>>2] = (($80-1)|0);
      $81 = ($80|0)==(1);
      if ($81) {
       __THREW__ = 0;
       invoke_viii(3262,($77|0),1,1);
       $82 = __THREW__; __THREW__ = 0;
       $83 = $82&1;
       if ($83) {
        label = 33;
        break;
       }
      }
     }
     HEAP32[$75>>2] = 0;
     $84 = HEAP32[$8>>2]|0;
     $85 = ($84|0)==($71|0);
     if ($85) {
      label = 34;
      break;
     } else {
      $76 = $84;
     }
    }
    if ((label|0) == 33) {
     $86 = ___cxa_find_matching_catch_2()|0;
     $87 = tempRet0;
     ___cxa_call_unexpected(($86|0));
     // unreachable;
    }
    else if ((label|0) == 34) {
     $$pre$i17 = HEAP32[$7>>2]|0;
     $88 = $$pre$i17;
     break;
    }
   }
  } while(0);
  __ZdlPv($88);
 }
 $89 = HEAP32[$5>>2]|0;
 $90 = ($89|0)==(0|0);
 if (!($90)) {
  $91 = HEAP32[$6>>2]|0;
  $92 = ($91|0)==($89|0);
  if ($92) {
   $101 = $89;
  } else {
   $94 = $91;
   while(1) {
    $93 = ((($94)) + -12|0);
    HEAP32[$6>>2] = $93;
    $95 = ((($93)) + 11|0);
    $96 = HEAP8[$95>>0]|0;
    $97 = ($96<<24>>24)<(0);
    if ($97) {
     $100 = HEAP32[$93>>2]|0;
     __ZdlPv($100);
     $$pre$i$i$i = HEAP32[$6>>2]|0;
     $98 = $$pre$i$i$i;
    } else {
     $98 = $93;
    }
    $99 = ($98|0)==($89|0);
    if ($99) {
     break;
    } else {
     $94 = $98;
    }
   }
   $$pre$i = HEAP32[$5>>2]|0;
   $101 = $$pre$i;
  }
  __ZdlPv($101);
 }
 $102 = HEAP32[$4>>2]|0;
 $103 = ($102|0)==(0|0);
 if (!($103)) {
  $104 = ((($102)) + 8|0);
  $105 = HEAP32[$104>>2]|0;HEAP32[$104>>2] = (($105-1)|0);
  $106 = ($105|0)==(1);
  if ($106) {
   __THREW__ = 0;
   invoke_viii(3262,($102|0),1,1);
   $107 = __THREW__; __THREW__ = 0;
   $108 = $107&1;
   if ($108) {
    $111 = ___cxa_find_matching_catch_3(0|0)|0;
    $112 = tempRet0;
    ___clang_call_terminate($111);
    // unreachable;
   }
  }
 }
 HEAP32[$4>>2] = 0;
 __THREW__ = 0;
 invoke_vi(388,($0|0));
 $109 = __THREW__; __THREW__ = 0;
 $110 = $109&1;
 if ($110) {
  $111 = ___cxa_find_matching_catch_3(0|0)|0;
  $112 = tempRet0;
  ___clang_call_terminate($111);
  // unreachable;
 } else {
  ___resumeException($$110|0);
  // unreachable;
 }
}
function __ZN3osg24DefaultUserDataContainerC2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg10ReferencedC2Eb($0,1);
 $1 = ((($0)) + 12|0);
 ;HEAP32[$1>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;
 $2 = ((($0)) + 24|0);
 HEAP32[$2>>2] = 2;
 $3 = ((($0)) + 28|0);
 HEAP32[$3>>2] = 0;
 HEAP32[$0>>2] = (69484);
 $4 = ((($0)) + 32|0);
 ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;HEAP32[$4+12>>2]=0|0;HEAP32[$4+16>>2]=0|0;HEAP32[$4+20>>2]=0|0;HEAP32[$4+24>>2]=0|0;
 return;
}
function __ZN3osg16VertexArrayStateC2EPNS_5StateE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$pre = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 __ZN3osg10ReferencedC2Ev($0);
 HEAP32[$0>>2] = (69692);
 $2 = ((($0)) + 12|0);
 HEAP32[$2>>2] = $1;
 $3 = ((($0)) + 16|0);
 HEAP32[$3>>2] = 0;
 $4 = ((($0)) + 24|0);
 $5 = ((($0)) + 104|0);
 dest=$4; stop=dest+80|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAP8[$5>>0] = 1;
 $6 = ((($1)) + 784|0);
 $7 = HEAP32[$6>>2]|0;
 HEAP32[$3>>2] = $7;
 $8 = ((($7)) + 8|0);
 $9 = HEAP32[$8>>2]|0;HEAP32[$8>>2] = (($9+1)|0);
 $$pre = HEAP32[$3>>2]|0;
 $10 = ((($$pre)) + 712|0);
 $11 = HEAP8[$10>>0]|0;
 $12 = ((($0)) + 20|0);
 HEAP8[$12>>0] = $11;
 return;
}
function __ZN3osg16VertexArrayStateD2Ev($0) {
 $0 = $0|0;
 var $$4 = 0, $$46 = 0, $$5 = 0, $$57 = 0, $$6 = 0, $$68 = 0, $$7 = 0, $$79 = 0, $$8 = 0, $$810 = 0, $$pre$i = 0, $$pre$i19 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0;
 var $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i11 = 0;
 var $scevgep5$i$i$i = 0, $scevgep5$i$i$i12 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (69692);
 $1 = ((($0)) + 84|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = ((($0)) + 88|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==($2|0);
  if (!($6)) {
   $scevgep$i$i$i = ((($5)) + -4|0);
   $7 = $scevgep$i$i$i;
   $8 = $2;
   $9 = (($7) - ($8))|0;
   $10 = $9 >>> 2;
   $11 = $10 ^ -1;
   $scevgep5$i$i$i = (($5) + ($11<<2)|0);
   HEAP32[$4>>2] = $scevgep5$i$i$i;
  }
  __ZdlPv($2);
 }
 $12 = ((($0)) + 72|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0|0);
 if (!($14)) {
  $15 = ((($0)) + 76|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($16|0)==($13|0);
  if (!($17)) {
   $scevgep$i$i$i11 = ((($16)) + -4|0);
   $18 = $scevgep$i$i$i11;
   $19 = $13;
   $20 = (($18) - ($19))|0;
   $21 = $20 >>> 2;
   $22 = $21 ^ -1;
   $scevgep5$i$i$i12 = (($16) + ($22<<2)|0);
   HEAP32[$15>>2] = $scevgep5$i$i$i12;
  }
  __ZdlPv($13);
 }
 $23 = ((($0)) + 60|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)==(0|0);
 if (!($25)) {
  $26 = ((($0)) + 64|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = ($27|0)==($24|0);
  do {
   if ($28) {
    $42 = $24;
   } else {
    $30 = $27;
    while(1) {
     $29 = ((($30)) + -4|0);
     HEAP32[$26>>2] = $29;
     $31 = HEAP32[$29>>2]|0;
     $32 = ($31|0)==(0|0);
     if (!($32)) {
      $33 = ((($31)) + 8|0);
      $34 = HEAP32[$33>>2]|0;HEAP32[$33>>2] = (($34-1)|0);
      $35 = ($34|0)==(1);
      if ($35) {
       __THREW__ = 0;
       invoke_viii(3262,($31|0),1,1);
       $36 = __THREW__; __THREW__ = 0;
       $37 = $36&1;
       if ($37) {
        label = 15;
        break;
       }
      }
     }
     HEAP32[$29>>2] = 0;
     $38 = HEAP32[$26>>2]|0;
     $39 = ($38|0)==($24|0);
     if ($39) {
      label = 16;
      break;
     } else {
      $30 = $38;
     }
    }
    if ((label|0) == 15) {
     $40 = ___cxa_find_matching_catch_2()|0;
     $41 = tempRet0;
     ___cxa_call_unexpected(($40|0));
     // unreachable;
    }
    else if ((label|0) == 16) {
     $$pre$i = HEAP32[$23>>2]|0;
     $42 = $$pre$i;
     break;
    }
   }
  } while(0);
  __ZdlPv($42);
 }
 $43 = ((($0)) + 48|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = ($44|0)==(0|0);
 if (!($45)) {
  $46 = ((($0)) + 52|0);
  $47 = HEAP32[$46>>2]|0;
  $48 = ($47|0)==($44|0);
  do {
   if ($48) {
    $62 = $44;
   } else {
    $50 = $47;
    while(1) {
     $49 = ((($50)) + -4|0);
     HEAP32[$46>>2] = $49;
     $51 = HEAP32[$49>>2]|0;
     $52 = ($51|0)==(0|0);
     if (!($52)) {
      $53 = ((($51)) + 8|0);
      $54 = HEAP32[$53>>2]|0;HEAP32[$53>>2] = (($54-1)|0);
      $55 = ($54|0)==(1);
      if ($55) {
       __THREW__ = 0;
       invoke_viii(3262,($51|0),1,1);
       $56 = __THREW__; __THREW__ = 0;
       $57 = $56&1;
       if ($57) {
        label = 24;
        break;
       }
      }
     }
     HEAP32[$49>>2] = 0;
     $58 = HEAP32[$46>>2]|0;
     $59 = ($58|0)==($44|0);
     if ($59) {
      label = 25;
      break;
     } else {
      $50 = $58;
     }
    }
    if ((label|0) == 24) {
     $60 = ___cxa_find_matching_catch_2()|0;
     $61 = tempRet0;
     ___cxa_call_unexpected(($60|0));
     // unreachable;
    }
    else if ((label|0) == 25) {
     $$pre$i19 = HEAP32[$43>>2]|0;
     $62 = $$pre$i19;
     break;
    }
   }
  } while(0);
  __ZdlPv($62);
 }
 $63 = ((($0)) + 44|0);
 $64 = HEAP32[$63>>2]|0;
 $65 = ($64|0)==(0|0);
 if ($65) {
  label = 30;
 } else {
  $66 = ((($64)) + 8|0);
  $67 = HEAP32[$66>>2]|0;HEAP32[$66>>2] = (($67-1)|0);
  $68 = ($67|0)==(1);
  if ($68) {
   __THREW__ = 0;
   invoke_viii(3262,($64|0),1,1);
   $69 = __THREW__; __THREW__ = 0;
   $70 = $69&1;
   if ($70) {
    $113 = ___cxa_find_matching_catch_2()|0;
    $114 = tempRet0;
    $115 = ((($0)) + 40|0);
    $116 = HEAP32[$115>>2]|0;
    $117 = ($116|0)==(0|0);
    if (!($117)) {
     $118 = ((($116)) + 8|0);
     $119 = HEAP32[$118>>2]|0;HEAP32[$118>>2] = (($119-1)|0);
     $120 = ($119|0)==(1);
     if ($120) {
      __THREW__ = 0;
      invoke_viii(3262,($116|0),1,1);
      $121 = __THREW__; __THREW__ = 0;
      $122 = $121&1;
      if ($122) {
       $165 = ___cxa_find_matching_catch_3(0|0)|0;
       $166 = tempRet0;
       ___clang_call_terminate($165);
       // unreachable;
      }
     }
    }
    HEAP32[$115>>2] = 0;
    $$4 = $114;$$46 = $113;
    label = 52;
   } else {
    label = 30;
   }
  } else {
   label = 30;
  }
 }
 do {
  if ((label|0) == 30) {
   HEAP32[$63>>2] = 0;
   $71 = ((($0)) + 40|0);
   $72 = HEAP32[$71>>2]|0;
   $73 = ($72|0)==(0|0);
   if (!($73)) {
    $74 = ((($72)) + 8|0);
    $75 = HEAP32[$74>>2]|0;HEAP32[$74>>2] = (($75-1)|0);
    $76 = ($75|0)==(1);
    if ($76) {
     __THREW__ = 0;
     invoke_viii(3262,($72|0),1,1);
     $77 = __THREW__; __THREW__ = 0;
     $78 = $77&1;
     if ($78) {
      $111 = ___cxa_find_matching_catch_2()|0;
      $112 = tempRet0;
      $$4 = $112;$$46 = $111;
      label = 52;
      break;
     }
    }
   }
   HEAP32[$71>>2] = 0;
   $79 = ((($0)) + 36|0);
   $80 = HEAP32[$79>>2]|0;
   $81 = ($80|0)==(0|0);
   if (!($81)) {
    $82 = ((($80)) + 8|0);
    $83 = HEAP32[$82>>2]|0;HEAP32[$82>>2] = (($83-1)|0);
    $84 = ($83|0)==(1);
    if ($84) {
     __THREW__ = 0;
     invoke_viii(3262,($80|0),1,1);
     $85 = __THREW__; __THREW__ = 0;
     $86 = $85&1;
     if ($86) {
      $123 = ___cxa_find_matching_catch_2()|0;
      $124 = tempRet0;
      $$5 = $124;$$57 = $123;
      label = 57;
      break;
     }
    }
   }
   HEAP32[$79>>2] = 0;
   $87 = ((($0)) + 32|0);
   $88 = HEAP32[$87>>2]|0;
   $89 = ($88|0)==(0|0);
   if (!($89)) {
    $90 = ((($88)) + 8|0);
    $91 = HEAP32[$90>>2]|0;HEAP32[$90>>2] = (($91-1)|0);
    $92 = ($91|0)==(1);
    if ($92) {
     __THREW__ = 0;
     invoke_viii(3262,($88|0),1,1);
     $93 = __THREW__; __THREW__ = 0;
     $94 = $93&1;
     if ($94) {
      $133 = ___cxa_find_matching_catch_2()|0;
      $134 = tempRet0;
      $$6 = $134;$$68 = $133;
      label = 62;
      break;
     }
    }
   }
   HEAP32[$87>>2] = 0;
   $95 = ((($0)) + 28|0);
   $96 = HEAP32[$95>>2]|0;
   $97 = ($96|0)==(0|0);
   if (!($97)) {
    $98 = ((($96)) + 8|0);
    $99 = HEAP32[$98>>2]|0;HEAP32[$98>>2] = (($99-1)|0);
    $100 = ($99|0)==(1);
    if ($100) {
     __THREW__ = 0;
     invoke_viii(3262,($96|0),1,1);
     $101 = __THREW__; __THREW__ = 0;
     $102 = $101&1;
     if ($102) {
      $143 = ___cxa_find_matching_catch_2()|0;
      $144 = tempRet0;
      $$7 = $144;$$79 = $143;
      label = 67;
      break;
     }
    }
   }
   HEAP32[$95>>2] = 0;
   $103 = ((($0)) + 16|0);
   $104 = HEAP32[$103>>2]|0;
   $105 = ($104|0)==(0|0);
   if ($105) {
    HEAP32[$103>>2] = 0;
    __ZN3osg10ReferencedD2Ev($0);
    return;
   }
   $106 = ((($104)) + 8|0);
   $107 = HEAP32[$106>>2]|0;HEAP32[$106>>2] = (($107-1)|0);
   $108 = ($107|0)==(1);
   if (!($108)) {
    HEAP32[$103>>2] = 0;
    __ZN3osg10ReferencedD2Ev($0);
    return;
   }
   __THREW__ = 0;
   invoke_viii(3262,($104|0),1,1);
   $109 = __THREW__; __THREW__ = 0;
   $110 = $109&1;
   if ($110) {
    $153 = ___cxa_find_matching_catch_2()|0;
    $154 = tempRet0;
    $$8 = $154;$$810 = $153;
    break;
   } else {
    HEAP32[$103>>2] = 0;
    __ZN3osg10ReferencedD2Ev($0);
    return;
   }
  }
 } while(0);
 if ((label|0) == 52) {
  $125 = ((($0)) + 36|0);
  $126 = HEAP32[$125>>2]|0;
  $127 = ($126|0)==(0|0);
  if (!($127)) {
   $128 = ((($126)) + 8|0);
   $129 = HEAP32[$128>>2]|0;HEAP32[$128>>2] = (($129-1)|0);
   $130 = ($129|0)==(1);
   if ($130) {
    __THREW__ = 0;
    invoke_viii(3262,($126|0),1,1);
    $131 = __THREW__; __THREW__ = 0;
    $132 = $131&1;
    if ($132) {
     $165 = ___cxa_find_matching_catch_3(0|0)|0;
     $166 = tempRet0;
     ___clang_call_terminate($165);
     // unreachable;
    }
   }
  }
  HEAP32[$125>>2] = 0;
  $$5 = $$4;$$57 = $$46;
  label = 57;
 }
 if ((label|0) == 57) {
  $135 = ((($0)) + 32|0);
  $136 = HEAP32[$135>>2]|0;
  $137 = ($136|0)==(0|0);
  if (!($137)) {
   $138 = ((($136)) + 8|0);
   $139 = HEAP32[$138>>2]|0;HEAP32[$138>>2] = (($139-1)|0);
   $140 = ($139|0)==(1);
   if ($140) {
    __THREW__ = 0;
    invoke_viii(3262,($136|0),1,1);
    $141 = __THREW__; __THREW__ = 0;
    $142 = $141&1;
    if ($142) {
     $165 = ___cxa_find_matching_catch_3(0|0)|0;
     $166 = tempRet0;
     ___clang_call_terminate($165);
     // unreachable;
    }
   }
  }
  HEAP32[$135>>2] = 0;
  $$6 = $$5;$$68 = $$57;
  label = 62;
 }
 if ((label|0) == 62) {
  $145 = ((($0)) + 28|0);
  $146 = HEAP32[$145>>2]|0;
  $147 = ($146|0)==(0|0);
  if (!($147)) {
   $148 = ((($146)) + 8|0);
   $149 = HEAP32[$148>>2]|0;HEAP32[$148>>2] = (($149-1)|0);
   $150 = ($149|0)==(1);
   if ($150) {
    __THREW__ = 0;
    invoke_viii(3262,($146|0),1,1);
    $151 = __THREW__; __THREW__ = 0;
    $152 = $151&1;
    if ($152) {
     $165 = ___cxa_find_matching_catch_3(0|0)|0;
     $166 = tempRet0;
     ___clang_call_terminate($165);
     // unreachable;
    }
   }
  }
  HEAP32[$145>>2] = 0;
  $$7 = $$6;$$79 = $$68;
  label = 67;
 }
 if ((label|0) == 67) {
  $155 = ((($0)) + 16|0);
  $156 = HEAP32[$155>>2]|0;
  $157 = ($156|0)==(0|0);
  if (!($157)) {
   $158 = ((($156)) + 8|0);
   $159 = HEAP32[$158>>2]|0;HEAP32[$158>>2] = (($159-1)|0);
   $160 = ($159|0)==(1);
   if ($160) {
    __THREW__ = 0;
    invoke_viii(3262,($156|0),1,1);
    $161 = __THREW__; __THREW__ = 0;
    $162 = $161&1;
    if ($162) {
     $165 = ___cxa_find_matching_catch_3(0|0)|0;
     $166 = tempRet0;
     ___clang_call_terminate($165);
     // unreachable;
    }
   }
  }
  HEAP32[$155>>2] = 0;
  $$8 = $$7;$$810 = $$79;
 }
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $163 = __THREW__; __THREW__ = 0;
 $164 = $163&1;
 if ($164) {
  $165 = ___cxa_find_matching_catch_3(0|0)|0;
  $166 = tempRet0;
  ___clang_call_terminate($165);
  // unreachable;
 } else {
  ___resumeException($$810|0);
  // unreachable;
 }
}
function __ZN3osg16VertexArrayStateD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(2421,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZN3osg16VertexArrayState25generateVertexArrayObjectEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 1492|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 24|0);
 FUNCTION_TABLE_vii[$4 & 8191](1,$5);
 return;
}
function __ZN3osg16VertexArrayState23deleteVertexArrayObjectEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $2 = ((($0)) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(5)|0);
 do {
  if ($5) {
   $6 = (__ZN3osg6notifyENS_14NotifySeverityE(5)|0);
   $7 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($6,158201,46)|0);
   $8 = HEAP32[$2>>2]|0;
   $9 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($7,$8)|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ((($10)) + -12|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = (($9) + ($12)|0);
   __ZNKSt3__28ios_base6getlocEv($1,$13);
   __THREW__ = 0;
   $14 = (invoke_iii(3255,($1|0),(215188|0))|0);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    $17 = HEAP32[$14>>2]|0;
    $18 = ((($17)) + 28|0);
    $19 = HEAP32[$18>>2]|0;
    __THREW__ = 0;
    $20 = (invoke_iii($19|0,($14|0),10)|0);
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if (!($22)) {
     __ZNSt3__26localeD2Ev($1);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($9,$20)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($9)|0);
     break;
    }
   }
   $23 = ___cxa_find_matching_catch_2()|0;
   $24 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($1|0));
   $25 = __THREW__; __THREW__ = 0;
   $26 = $25&1;
   if ($26) {
    $27 = ___cxa_find_matching_catch_3(0|0)|0;
    $28 = tempRet0;
    ___clang_call_terminate($27);
    // unreachable;
   } else {
    ___resumeException($23|0);
    // unreachable;
   }
  }
 } while(0);
 $29 = ((($0)) + 16|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ((($30)) + 1488|0);
 $32 = HEAP32[$31>>2]|0;
 FUNCTION_TABLE_vii[$32 & 8191](1,$2);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN3osg16VertexArrayState27assignVertexArrayDispatcherEv($0) {
 $0 = $0|0;
 var $$pre = 0, $$pre$phiZ2D = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $2 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(5)|0);
 do {
  if ($2) {
   $3 = (__ZN3osg6notifyENS_14NotifySeverityE(5)|0);
   $4 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($3,158248,83)|0);
   $5 = ((($0)) + 12|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ((($6)) + 352|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($4,$8)|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ((($10)) + -12|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = (($9) + ($12)|0);
   __ZNKSt3__28ios_base6getlocEv($1,$13);
   __THREW__ = 0;
   $14 = (invoke_iii(3255,($1|0),(215188|0))|0);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    $17 = HEAP32[$14>>2]|0;
    $18 = ((($17)) + 28|0);
    $19 = HEAP32[$18>>2]|0;
    __THREW__ = 0;
    $20 = (invoke_iii($19|0,($14|0),10)|0);
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if (!($22)) {
     __ZNSt3__26localeD2Ev($1);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($9,$20)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($9)|0);
     $$pre$phiZ2D = $5;
     break;
    }
   }
   $23 = ___cxa_find_matching_catch_2()|0;
   $24 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($1|0));
   $25 = __THREW__; __THREW__ = 0;
   $26 = $25&1;
   if ($26) {
    $27 = ___cxa_find_matching_catch_3(0|0)|0;
    $28 = tempRet0;
    ___clang_call_terminate($27);
    // unreachable;
   } else {
    ___resumeException($23|0);
    // unreachable;
   }
  } else {
   $$pre = ((($0)) + 12|0);
   $$pre$phiZ2D = $$pre;
  }
 } while(0);
 $29 = (__Znwj(28)|0);
 $30 = HEAP32[$$pre$phiZ2D>>2]|0;
 $31 = ((($30)) + 352|0);
 $32 = HEAP32[$31>>2]|0;
 __THREW__ = 0;
 invoke_vi(3282,($29|0));
 $33 = __THREW__; __THREW__ = 0;
 $34 = $33&1;
 if ($34) {
  $48 = ___cxa_find_matching_catch_2()|0;
  $49 = tempRet0;
  __ZdlPv($29);
  ___resumeException($48|0);
  // unreachable;
 }
 $35 = ((($29)) + 12|0);
 HEAP32[$35>>2] = 0;
 $36 = ((($29)) + 16|0);
 HEAP32[$36>>2] = -1;
 $37 = ((($29)) + 20|0);
 HEAP8[$37>>0] = 0;
 HEAP32[$29>>2] = (69712);
 $38 = ((($29)) + 24|0);
 HEAP32[$38>>2] = $32;
 $39 = ((($0)) + 28|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ($40|0)==($29|0);
 if ($41) {
  STACKTOP = sp;return;
 }
 HEAP32[$39>>2] = $29;
 $42 = ((($29)) + 8|0);
 $43 = HEAP32[$42>>2]|0;HEAP32[$42>>2] = (($43+1)|0);
 $44 = ($40|0)==(0|0);
 if ($44) {
  STACKTOP = sp;return;
 }
 $45 = ((($40)) + 8|0);
 $46 = HEAP32[$45>>2]|0;HEAP32[$45>>2] = (($46-1)|0);
 $47 = ($46|0)==(1);
 if (!($47)) {
  STACKTOP = sp;return;
 }
 __ZNK3osg10Referenced24signalObserversAndDeleteEbb($40,1,1);
 STACKTOP = sp;return;
}
function __ZN25VertexAttribArrayDispatchD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZN25VertexAttribArrayDispatch19enable_and_dispatchERN3osg5StateEPKNS0_5ArrayE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($1)) + 784|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($4)) + 84|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($0)) + 24|0);
 $8 = HEAP32[$7>>2]|0;
 FUNCTION_TABLE_vi[$6 & 8191]($8);
 $9 = HEAP32[$2>>2]|0;
 $10 = ((($9)) + 140|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (FUNCTION_TABLE_ii[$11 & 8191]($2)|0);
 $13 = ((($2)) + 69|0);
 $14 = HEAP8[$13>>0]|0;
 $15 = ($14<<24>>24)==(0);
 if ($15) {
  $34 = ((($4)) + 404|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = HEAP32[$7>>2]|0;
  $37 = ((($2)) + 56|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = ((($2)) + 60|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = ((($2)) + 68|0);
  $42 = HEAP8[$41>>0]|0;
  FUNCTION_TABLE_viiiiii[$35 & 8191]($36,$38,$40,$42,0,$12);
  return;
 }
 $16 = ((($2)) + 60|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==(5126);
 if ($18) {
  $19 = ((($4)) + 404|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = HEAP32[$7>>2]|0;
  $22 = ((($2)) + 56|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = ((($2)) + 68|0);
  $25 = HEAP8[$24>>0]|0;
  FUNCTION_TABLE_viiiiii[$20 & 8191]($21,$23,5126,$25,0,$12);
  return;
 }
 $26 = ($17|0)==(5130);
 $27 = HEAP32[$7>>2]|0;
 $28 = ((($2)) + 56|0);
 $29 = HEAP32[$28>>2]|0;
 if ($26) {
  $30 = ((($4)) + 412|0);
  $31 = HEAP32[$30>>2]|0;
  FUNCTION_TABLE_viiiii[$31 & 8191]($27,$29,5130,0,$12);
  return;
 } else {
  $32 = ((($4)) + 408|0);
  $33 = HEAP32[$32>>2]|0;
  FUNCTION_TABLE_viiiii[$33 & 8191]($27,$29,$17,0,$12);
  return;
 }
}
function __ZN25VertexAttribArrayDispatch19enable_and_dispatchERN3osg5StateEPKNS0_5ArrayEPKNS0_14GLBufferObjectE($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ((($1)) + 784|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($5)) + 84|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($0)) + 24|0);
 $9 = HEAP32[$8>>2]|0;
 FUNCTION_TABLE_vi[$7 & 8191]($9);
 $10 = ((($2)) + 36|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($3)) + 40|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (((($13) + (($11*20)|0)|0)) + 12|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ((($2)) + 69|0);
 $17 = HEAP8[$16>>0]|0;
 $18 = ($17<<24>>24)==(0);
 if ($18) {
  $37 = ((($5)) + 404|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = HEAP32[$8>>2]|0;
  $40 = ((($2)) + 56|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = ((($2)) + 60|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = ((($2)) + 68|0);
  $45 = HEAP8[$44>>0]|0;
  FUNCTION_TABLE_viiiiii[$38 & 8191]($39,$41,$43,$45,0,$15);
  return;
 }
 $19 = ((($2)) + 60|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)==(5126);
 if ($21) {
  $22 = ((($5)) + 404|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = HEAP32[$8>>2]|0;
  $25 = ((($2)) + 56|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = ((($2)) + 68|0);
  $28 = HEAP8[$27>>0]|0;
  FUNCTION_TABLE_viiiiii[$23 & 8191]($24,$26,5126,$28,0,$15);
  return;
 }
 $29 = ($20|0)==(5130);
 $30 = HEAP32[$8>>2]|0;
 $31 = ((($2)) + 56|0);
 $32 = HEAP32[$31>>2]|0;
 if ($29) {
  $33 = ((($5)) + 412|0);
  $34 = HEAP32[$33>>2]|0;
  FUNCTION_TABLE_viiiii[$34 & 8191]($30,$32,5130,0,$15);
  return;
 } else {
  $35 = ((($5)) + 408|0);
  $36 = HEAP32[$35>>2]|0;
  FUNCTION_TABLE_viiiii[$36 & 8191]($30,$32,$20,0,$15);
  return;
 }
}
function __ZN3osg16VertexArrayState13ArrayDispatch19enable_and_dispatchERNS_5StateEijiPKvh($0,$1,$2,$3,$4,$5,$6) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN25VertexAttribArrayDispatch8dispatchERN3osg5StateEPKNS0_5ArrayE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $3 = ((($1)) + 784|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$2>>2]|0;
 $6 = ((($5)) + 140|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_ii[$7 & 8191]($2)|0);
 $9 = ((($2)) + 69|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = ($10<<24>>24)==(0);
 if ($11) {
  $32 = ((($4)) + 404|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = ((($0)) + 24|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = ((($2)) + 56|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = ((($2)) + 60|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = ((($2)) + 68|0);
  $41 = HEAP8[$40>>0]|0;
  FUNCTION_TABLE_viiiiii[$33 & 8191]($35,$37,$39,$41,0,$8);
  return;
 }
 $12 = ((($2)) + 60|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(5126);
 if ($14) {
  $15 = ((($4)) + 404|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ((($0)) + 24|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = ((($2)) + 56|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = ((($2)) + 68|0);
  $22 = HEAP8[$21>>0]|0;
  FUNCTION_TABLE_viiiiii[$16 & 8191]($18,$20,5126,$22,0,$8);
  return;
 }
 $23 = ($13|0)==(5130);
 $24 = ((($0)) + 24|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ((($2)) + 56|0);
 $27 = HEAP32[$26>>2]|0;
 if ($23) {
  $28 = ((($4)) + 412|0);
  $29 = HEAP32[$28>>2]|0;
  FUNCTION_TABLE_viiiii[$29 & 8191]($25,$27,5130,0,$8);
  return;
 } else {
  $30 = ((($4)) + 408|0);
  $31 = HEAP32[$30>>2]|0;
  FUNCTION_TABLE_viiiii[$31 & 8191]($25,$27,$13,0,$8);
  return;
 }
}
function __ZN25VertexAttribArrayDispatch8dispatchERN3osg5StateEPKNS0_5ArrayEPKNS0_14GLBufferObjectE($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ((($1)) + 784|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($2)) + 36|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($3)) + 40|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (((($9) + (($7*20)|0)|0)) + 12|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($2)) + 69|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = ($13<<24>>24)==(0);
 if ($14) {
  $35 = ((($5)) + 404|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = ((($0)) + 24|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = ((($2)) + 56|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = ((($2)) + 60|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = ((($2)) + 68|0);
  $44 = HEAP8[$43>>0]|0;
  FUNCTION_TABLE_viiiiii[$36 & 8191]($38,$40,$42,$44,0,$11);
  return;
 }
 $15 = ((($2)) + 60|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==(5126);
 if ($17) {
  $18 = ((($5)) + 404|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = ((($0)) + 24|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = ((($2)) + 56|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = ((($2)) + 68|0);
  $25 = HEAP8[$24>>0]|0;
  FUNCTION_TABLE_viiiiii[$19 & 8191]($21,$23,5126,$25,0,$11);
  return;
 }
 $26 = ($16|0)==(5130);
 $27 = ((($0)) + 24|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = ((($2)) + 56|0);
 $30 = HEAP32[$29>>2]|0;
 if ($26) {
  $31 = ((($5)) + 412|0);
  $32 = HEAP32[$31>>2]|0;
  FUNCTION_TABLE_viiiii[$32 & 8191]($28,$30,5130,0,$11);
  return;
 } else {
  $33 = ((($5)) + 408|0);
  $34 = HEAP32[$33>>2]|0;
  FUNCTION_TABLE_viiiii[$34 & 8191]($28,$30,$16,0,$11);
  return;
 }
}
function __ZN3osg16VertexArrayState13ArrayDispatch8dispatchERNS_5StateEijiPKvh($0,$1,$2,$3,$4,$5,$6) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN25VertexAttribArrayDispatch7disableERN3osg5StateE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 784|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + 80|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($0)) + 24|0);
 $7 = HEAP32[$6>>2]|0;
 FUNCTION_TABLE_vi[$5 & 8191]($7);
 return;
}
function __ZN3osg16VertexArrayState27assignNormalArrayDispatcherEv($0) {
 $0 = $0|0;
 var $$pre = 0, $$pre$phiZ2D = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $2 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(5)|0);
 do {
  if ($2) {
   $3 = (__ZN3osg6notifyENS_14NotifySeverityE(5)|0);
   $4 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($3,158400,83)|0);
   $5 = ((($0)) + 12|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ((($6)) + 392|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($4,$8)|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ((($10)) + -12|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = (($9) + ($12)|0);
   __ZNKSt3__28ios_base6getlocEv($1,$13);
   __THREW__ = 0;
   $14 = (invoke_iii(3255,($1|0),(215188|0))|0);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    $17 = HEAP32[$14>>2]|0;
    $18 = ((($17)) + 28|0);
    $19 = HEAP32[$18>>2]|0;
    __THREW__ = 0;
    $20 = (invoke_iii($19|0,($14|0),10)|0);
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if (!($22)) {
     __ZNSt3__26localeD2Ev($1);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($9,$20)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($9)|0);
     $$pre$phiZ2D = $5;
     break;
    }
   }
   $23 = ___cxa_find_matching_catch_2()|0;
   $24 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($1|0));
   $25 = __THREW__; __THREW__ = 0;
   $26 = $25&1;
   if ($26) {
    $27 = ___cxa_find_matching_catch_3(0|0)|0;
    $28 = tempRet0;
    ___clang_call_terminate($27);
    // unreachable;
   } else {
    ___resumeException($23|0);
    // unreachable;
   }
  } else {
   $$pre = ((($0)) + 12|0);
   $$pre$phiZ2D = $$pre;
  }
 } while(0);
 $29 = (__Znwj(28)|0);
 $30 = HEAP32[$$pre$phiZ2D>>2]|0;
 $31 = ((($30)) + 392|0);
 $32 = HEAP32[$31>>2]|0;
 __THREW__ = 0;
 invoke_vi(3282,($29|0));
 $33 = __THREW__; __THREW__ = 0;
 $34 = $33&1;
 if ($34) {
  $48 = ___cxa_find_matching_catch_2()|0;
  $49 = tempRet0;
  __ZdlPv($29);
  ___resumeException($48|0);
  // unreachable;
 }
 $35 = ((($29)) + 12|0);
 HEAP32[$35>>2] = 0;
 $36 = ((($29)) + 16|0);
 HEAP32[$36>>2] = -1;
 $37 = ((($29)) + 20|0);
 HEAP8[$37>>0] = 0;
 HEAP32[$29>>2] = (69712);
 $38 = ((($29)) + 24|0);
 HEAP32[$38>>2] = $32;
 $39 = ((($0)) + 32|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ($40|0)==($29|0);
 if ($41) {
  STACKTOP = sp;return;
 }
 HEAP32[$39>>2] = $29;
 $42 = ((($29)) + 8|0);
 $43 = HEAP32[$42>>2]|0;HEAP32[$42>>2] = (($43+1)|0);
 $44 = ($40|0)==(0|0);
 if ($44) {
  STACKTOP = sp;return;
 }
 $45 = ((($40)) + 8|0);
 $46 = HEAP32[$45>>2]|0;HEAP32[$45>>2] = (($46-1)|0);
 $47 = ($46|0)==(1);
 if (!($47)) {
  STACKTOP = sp;return;
 }
 __ZNK3osg10Referenced24signalObserversAndDeleteEbb($40,1,1);
 STACKTOP = sp;return;
}
function __ZN3osg16VertexArrayState26assignColorArrayDispatcherEv($0) {
 $0 = $0|0;
 var $$pre = 0, $$pre$phiZ2D = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $2 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(5)|0);
 do {
  if ($2) {
   $3 = (__ZN3osg6notifyENS_14NotifySeverityE(5)|0);
   $4 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($3,158484,81)|0);
   $5 = ((($0)) + 12|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ((($6)) + 432|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($4,$8)|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ((($10)) + -12|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = (($9) + ($12)|0);
   __ZNKSt3__28ios_base6getlocEv($1,$13);
   __THREW__ = 0;
   $14 = (invoke_iii(3255,($1|0),(215188|0))|0);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    $17 = HEAP32[$14>>2]|0;
    $18 = ((($17)) + 28|0);
    $19 = HEAP32[$18>>2]|0;
    __THREW__ = 0;
    $20 = (invoke_iii($19|0,($14|0),10)|0);
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if (!($22)) {
     __ZNSt3__26localeD2Ev($1);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($9,$20)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($9)|0);
     $$pre$phiZ2D = $5;
     break;
    }
   }
   $23 = ___cxa_find_matching_catch_2()|0;
   $24 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($1|0));
   $25 = __THREW__; __THREW__ = 0;
   $26 = $25&1;
   if ($26) {
    $27 = ___cxa_find_matching_catch_3(0|0)|0;
    $28 = tempRet0;
    ___clang_call_terminate($27);
    // unreachable;
   } else {
    ___resumeException($23|0);
    // unreachable;
   }
  } else {
   $$pre = ((($0)) + 12|0);
   $$pre$phiZ2D = $$pre;
  }
 } while(0);
 $29 = (__Znwj(28)|0);
 $30 = HEAP32[$$pre$phiZ2D>>2]|0;
 $31 = ((($30)) + 432|0);
 $32 = HEAP32[$31>>2]|0;
 __THREW__ = 0;
 invoke_vi(3282,($29|0));
 $33 = __THREW__; __THREW__ = 0;
 $34 = $33&1;
 if ($34) {
  $48 = ___cxa_find_matching_catch_2()|0;
  $49 = tempRet0;
  __ZdlPv($29);
  ___resumeException($48|0);
  // unreachable;
 }
 $35 = ((($29)) + 12|0);
 HEAP32[$35>>2] = 0;
 $36 = ((($29)) + 16|0);
 HEAP32[$36>>2] = -1;
 $37 = ((($29)) + 20|0);
 HEAP8[$37>>0] = 0;
 HEAP32[$29>>2] = (69712);
 $38 = ((($29)) + 24|0);
 HEAP32[$38>>2] = $32;
 $39 = ((($0)) + 36|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ($40|0)==($29|0);
 if ($41) {
  STACKTOP = sp;return;
 }
 HEAP32[$39>>2] = $29;
 $42 = ((($29)) + 8|0);
 $43 = HEAP32[$42>>2]|0;HEAP32[$42>>2] = (($43+1)|0);
 $44 = ($40|0)==(0|0);
 if ($44) {
  STACKTOP = sp;return;
 }
 $45 = ((($40)) + 8|0);
 $46 = HEAP32[$45>>2]|0;HEAP32[$45>>2] = (($46-1)|0);
 $47 = ($46|0)==(1);
 if (!($47)) {
  STACKTOP = sp;return;
 }
 __ZNK3osg10Referenced24signalObserversAndDeleteEbb($40,1,1);
 STACKTOP = sp;return;
}
function __ZN3osg16VertexArrayState35assignSecondaryColorArrayDispatcherEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(28)|0);
 $2 = ((($0)) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + 472|0);
 $5 = HEAP32[$4>>2]|0;
 __THREW__ = 0;
 invoke_vi(3282,($1|0));
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if ($7) {
  $21 = ___cxa_find_matching_catch_2()|0;
  $22 = tempRet0;
  __ZdlPv($1);
  ___resumeException($21|0);
  // unreachable;
 }
 $8 = ((($1)) + 12|0);
 HEAP32[$8>>2] = 0;
 $9 = ((($1)) + 16|0);
 HEAP32[$9>>2] = -1;
 $10 = ((($1)) + 20|0);
 HEAP8[$10>>0] = 0;
 HEAP32[$1>>2] = (69712);
 $11 = ((($1)) + 24|0);
 HEAP32[$11>>2] = $5;
 $12 = ((($0)) + 40|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==($1|0);
 if ($14) {
  return;
 }
 HEAP32[$12>>2] = $1;
 $15 = ((($1)) + 8|0);
 $16 = HEAP32[$15>>2]|0;HEAP32[$15>>2] = (($16+1)|0);
 $17 = ($13|0)==(0|0);
 if ($17) {
  return;
 }
 $18 = ((($13)) + 8|0);
 $19 = HEAP32[$18>>2]|0;HEAP32[$18>>2] = (($19-1)|0);
 $20 = ($19|0)==(1);
 if (!($20)) {
  return;
 }
 __ZNK3osg10Referenced24signalObserversAndDeleteEbb($13,1,1);
 return;
}
function __ZN3osg16VertexArrayState29assignFogCoordArrayDispatcherEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(28)|0);
 $2 = ((($0)) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + 512|0);
 $5 = HEAP32[$4>>2]|0;
 __THREW__ = 0;
 invoke_vi(3282,($1|0));
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if ($7) {
  $21 = ___cxa_find_matching_catch_2()|0;
  $22 = tempRet0;
  __ZdlPv($1);
  ___resumeException($21|0);
  // unreachable;
 }
 $8 = ((($1)) + 12|0);
 HEAP32[$8>>2] = 0;
 $9 = ((($1)) + 16|0);
 HEAP32[$9>>2] = -1;
 $10 = ((($1)) + 20|0);
 HEAP8[$10>>0] = 0;
 HEAP32[$1>>2] = (69712);
 $11 = ((($1)) + 24|0);
 HEAP32[$11>>2] = $5;
 $12 = ((($0)) + 44|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==($1|0);
 if ($14) {
  return;
 }
 HEAP32[$12>>2] = $1;
 $15 = ((($1)) + 8|0);
 $16 = HEAP32[$15>>2]|0;HEAP32[$15>>2] = (($16+1)|0);
 $17 = ($13|0)==(0|0);
 if ($17) {
  return;
 }
 $18 = ((($13)) + 8|0);
 $19 = HEAP32[$18>>2]|0;HEAP32[$18>>2] = (($19-1)|0);
 $20 = ($19|0)==(1);
 if (!($20)) {
  return;
 }
 __ZNK3osg10Referenced24signalObserversAndDeleteEbb($13,1,1);
 return;
}
function __ZN3osg16VertexArrayState29assignTexCoordArrayDispatcherEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$01018 = 0, $$09 = 0, $$pre$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp + 4|0;
 $3 = sp;
 $4 = ((($0)) + 48|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($0)) + 52|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==($5|0);
 L1: do {
  if (!($8)) {
   $10 = $7;
   while(1) {
    $9 = ((($10)) + -4|0);
    HEAP32[$6>>2] = $9;
    $11 = HEAP32[$9>>2]|0;
    $12 = ($11|0)==(0|0);
    if (!($12)) {
     $13 = ((($11)) + 8|0);
     $14 = HEAP32[$13>>2]|0;HEAP32[$13>>2] = (($14-1)|0);
     $15 = ($14|0)==(1);
     if ($15) {
      __THREW__ = 0;
      invoke_viii(3262,($11|0),1,1);
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if ($17) {
       break;
      }
     }
    }
    HEAP32[$9>>2] = 0;
    $18 = HEAP32[$6>>2]|0;
    $19 = ($18|0)==($5|0);
    if ($19) {
     break L1;
    } else {
     $10 = $18;
    }
   }
   $23 = ___cxa_find_matching_catch_2()|0;
   $24 = tempRet0;
   ___cxa_call_unexpected(($23|0));
   // unreachable;
  }
 } while(0);
 $20 = ($1|0)==(0);
 if ($20) {
  STACKTOP = sp;return;
 }
 $21 = ((($0)) + 12|0);
 $22 = ((($0)) + 56|0);
 $$01018 = 0;
 while(1) {
  $25 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(5)|0);
  if ($25) {
   $26 = (__ZN3osg6notifyENS_14NotifySeverityE(5)|0);
   $27 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($26,158566,112)|0);
   $28 = HEAP32[$21>>2]|0;
   $29 = ((($28)) + 552|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = (($30) + (($$01018*40)|0)|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($27,$32)|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = ((($34)) + -12|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($33) + ($36)|0);
   __ZNKSt3__28ios_base6getlocEv($2,$37);
   __THREW__ = 0;
   $38 = (invoke_iii(3255,($2|0),(215188|0))|0);
   $39 = __THREW__; __THREW__ = 0;
   $40 = $39&1;
   if ($40) {
    label = 13;
    break;
   }
   $41 = HEAP32[$38>>2]|0;
   $42 = ((($41)) + 28|0);
   $43 = HEAP32[$42>>2]|0;
   __THREW__ = 0;
   $44 = (invoke_iii($43|0,($38|0),10)|0);
   $45 = __THREW__; __THREW__ = 0;
   $46 = $45&1;
   if ($46) {
    label = 13;
    break;
   }
   __ZNSt3__26localeD2Ev($2);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($33,$44)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($33)|0);
  }
  $53 = (__Znwj(28)|0);
  $54 = HEAP32[$21>>2]|0;
  $55 = ((($54)) + 552|0);
  $56 = HEAP32[$55>>2]|0;
  $57 = (($56) + (($$01018*40)|0)|0);
  $58 = HEAP32[$57>>2]|0;
  __THREW__ = 0;
  invoke_vi(3282,($53|0));
  $59 = __THREW__; __THREW__ = 0;
  $60 = $59&1;
  if ($60) {
   label = 27;
   break;
  }
  $61 = ((($53)) + 12|0);
  HEAP32[$61>>2] = 0;
  $62 = ((($53)) + 16|0);
  HEAP32[$62>>2] = -1;
  $63 = ((($53)) + 20|0);
  HEAP8[$63>>0] = 0;
  HEAP32[$53>>2] = (69712);
  $64 = ((($53)) + 24|0);
  HEAP32[$64>>2] = $58;
  HEAP32[$3>>2] = $53;
  $65 = ((($53)) + 8|0);
  $66 = HEAP32[$65>>2]|0;HEAP32[$65>>2] = (($66+1)|0);
  $67 = HEAP32[$6>>2]|0;
  $68 = HEAP32[$22>>2]|0;
  $69 = ($67|0)==($68|0);
  if ($69) {
   __THREW__ = 0;
   invoke_vii(3998,($4|0),($3|0));
   $76 = __THREW__; __THREW__ = 0;
   $77 = $76&1;
   if ($77) {
    label = 28;
    break;
   }
  } else {
   $70 = HEAP32[$3>>2]|0;
   HEAP32[$67>>2] = $70;
   $71 = ($70|0)==(0|0);
   if ($71) {
    $75 = $67;
   } else {
    $72 = ((($70)) + 8|0);
    $73 = HEAP32[$72>>2]|0;HEAP32[$72>>2] = (($73+1)|0);
    $$pre$i = HEAP32[$6>>2]|0;
    $75 = $$pre$i;
   }
   $74 = ((($75)) + 4|0);
   HEAP32[$6>>2] = $74;
  }
  $78 = HEAP32[$3>>2]|0;
  $79 = ($78|0)==(0|0);
  if (!($79)) {
   $80 = ((($78)) + 8|0);
   $81 = HEAP32[$80>>2]|0;HEAP32[$80>>2] = (($81-1)|0);
   $82 = ($81|0)==(1);
   if ($82) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($78,1,1);
   }
  }
  $83 = (($$01018) + 1)|0;
  $84 = ($83>>>0)<($1>>>0);
  if ($84) {
   $$01018 = $83;
  } else {
   label = 9;
   break;
  }
 }
 if ((label|0) == 9) {
  STACKTOP = sp;return;
 }
 else if ((label|0) == 13) {
  $47 = ___cxa_find_matching_catch_2()|0;
  $48 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3263,($2|0));
  $49 = __THREW__; __THREW__ = 0;
  $50 = $49&1;
  if ($50) {
   $51 = ___cxa_find_matching_catch_3(0|0)|0;
   $52 = tempRet0;
   ___clang_call_terminate($51);
   // unreachable;
  } else {
   ___resumeException($47|0);
   // unreachable;
  }
 }
 else if ((label|0) == 27) {
  $85 = ___cxa_find_matching_catch_2()|0;
  $86 = tempRet0;
  __ZdlPv($53);
  $$0 = $86;$$09 = $85;
  ___resumeException($$09|0);
  // unreachable;
 }
 else if ((label|0) == 28) {
  $87 = ___cxa_find_matching_catch_2()|0;
  $88 = tempRet0;
  $89 = HEAP32[$3>>2]|0;
  $90 = ($89|0)==(0|0);
  if (!($90)) {
   $91 = ((($89)) + 8|0);
   $92 = HEAP32[$91>>2]|0;HEAP32[$91>>2] = (($92-1)|0);
   $93 = ($92|0)==(1);
   if ($93) {
    __THREW__ = 0;
    invoke_viii(3262,($89|0),1,1);
    $94 = __THREW__; __THREW__ = 0;
    $95 = $94&1;
    if ($95) {
     $96 = ___cxa_find_matching_catch_3(0|0)|0;
     $97 = tempRet0;
     ___clang_call_terminate($96);
     // unreachable;
    }
   }
  }
  HEAP32[$3>>2] = 0;
  $$0 = $88;$$09 = $87;
  ___resumeException($$09|0);
  // unreachable;
 }
}
function __ZNSt3__26vectorIN3osg7ref_ptrINS1_16VertexArrayState13ArrayDispatchEEENS_9allocatorIS5_EEE21__push_back_slow_pathIKS5_EEvRT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$06$i$i = 0, $$pre = 0, $$pre$i = 0, $$pre38 = 0, $$pre39 = 0, $$sroa$7$0 = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(1073741823);
 $9 = $4;
 $10 = $3;
 if ($8) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $11 = ((($0)) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) - ($4))|0;
 $14 = $13 >> 2;
 $15 = ($14>>>0)<(536870911);
 $16 = $13 >> 1;
 $17 = ($16>>>0)<($7>>>0);
 $$sroa$speculated$i = $17 ? $7 : $16;
 $$sroa$speculated$$i = $15 ? $$sroa$speculated$i : 1073741823;
 $18 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($18) {
   $28 = 0;
  } else {
   $19 = ($$sroa$speculated$$i>>>0)>(1073741823);
   if (!($19)) {
    $25 = $$sroa$speculated$$i << 2;
    $26 = (__Znwj($25)|0);
    $28 = $26;
    break;
   }
   $20 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($20|0),(204840|0));
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if ($22) {
    $23 = ___cxa_find_matching_catch_2()|0;
    $24 = tempRet0;
    ___cxa_free_exception(($20|0));
    ___resumeException($23|0);
    // unreachable;
   } else {
    HEAP32[$20>>2] = (99824);
    ___cxa_throw(($20|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $27 = (($28) + ($6<<2)|0);
 $29 = $27;
 $30 = (($28) + ($$sroa$speculated$$i<<2)|0);
 $31 = $30;
 $32 = HEAP32[$1>>2]|0;
 HEAP32[$27>>2] = $32;
 $33 = ($32|0)==(0|0);
 if ($33) {
  $38 = $10;$40 = $9;
 } else {
  $34 = ((($32)) + 8|0);
  $35 = HEAP32[$34>>2]|0;HEAP32[$34>>2] = (($35+1)|0);
  $$pre = HEAP32[$0>>2]|0;
  $$pre38 = HEAP32[$2>>2]|0;
  $38 = $$pre38;$40 = $$pre;
 }
 $36 = ((($27)) + 4|0);
 $37 = $36;
 $39 = ($38|0)==($40|0);
 if ($39) {
  $41 = $38;
  $53 = $29;$54 = $41;$56 = $38;
 } else {
  $$06$i$i = $38;$$sroa$7$0 = $29;$44 = $27;
  while(1) {
   $42 = ((($$06$i$i)) + -4|0);
   $43 = ((($44)) + -4|0);
   $45 = HEAP32[$42>>2]|0;
   HEAP32[$43>>2] = $45;
   $46 = ($45|0)==(0|0);
   if (!($46)) {
    $47 = ((($45)) + 8|0);
    $48 = HEAP32[$47>>2]|0;HEAP32[$47>>2] = (($48+1)|0);
   }
   $49 = $$sroa$7$0;
   $50 = ((($49)) + -4|0);
   $51 = $50;
   $52 = ($42|0)==($40|0);
   if ($52) {
    break;
   } else {
    $$06$i$i = $42;$$sroa$7$0 = $51;$44 = $50;
   }
  }
  $$pre$i = HEAP32[$0>>2]|0;
  $$pre39 = HEAP32[$2>>2]|0;
  $53 = $51;$54 = $$pre$i;$56 = $$pre39;
 }
 HEAP32[$0>>2] = $53;
 HEAP32[$2>>2] = $37;
 HEAP32[$11>>2] = $31;
 $55 = $54;
 $57 = ($56|0)==($55|0);
 L25: do {
  if (!($57)) {
   $59 = $56;
   while(1) {
    $58 = ((($59)) + -4|0);
    $60 = HEAP32[$58>>2]|0;
    $61 = ($60|0)==(0|0);
    if (!($61)) {
     $62 = ((($60)) + 8|0);
     $63 = HEAP32[$62>>2]|0;HEAP32[$62>>2] = (($63-1)|0);
     $64 = ($63|0)==(1);
     if ($64) {
      __THREW__ = 0;
      invoke_viii(3262,($60|0),1,1);
      $65 = __THREW__; __THREW__ = 0;
      $66 = $65&1;
      if ($66) {
       break;
      }
     }
    }
    HEAP32[$58>>2] = 0;
    $67 = ($58|0)==($55|0);
    if ($67) {
     break L25;
    } else {
     $59 = $58;
    }
   }
   $68 = ___cxa_find_matching_catch_2()|0;
   $69 = tempRet0;
   ___cxa_call_unexpected(($68|0));
   // unreachable;
  }
 } while(0);
 $70 = ($54|0)==(0);
 if ($70) {
  return;
 }
 $71 = $54;
 __ZdlPv($71);
 return;
}
function __ZN3osg16VertexArrayState33assignVertexAttribArrayDispatcherEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$08 = 0, $$0916 = 0, $$pre$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = ((($0)) + 60|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 64|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==($4|0);
 L1: do {
  if (!($7)) {
   $9 = $6;
   while(1) {
    $8 = ((($9)) + -4|0);
    HEAP32[$5>>2] = $8;
    $10 = HEAP32[$8>>2]|0;
    $11 = ($10|0)==(0|0);
    if (!($11)) {
     $12 = ((($10)) + 8|0);
     $13 = HEAP32[$12>>2]|0;HEAP32[$12>>2] = (($13-1)|0);
     $14 = ($13|0)==(1);
     if ($14) {
      __THREW__ = 0;
      invoke_viii(3262,($10|0),1,1);
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if ($16) {
       break;
      }
     }
    }
    HEAP32[$8>>2] = 0;
    $17 = HEAP32[$5>>2]|0;
    $18 = ($17|0)==($4|0);
    if ($18) {
     break L1;
    } else {
     $9 = $17;
    }
   }
   $21 = ___cxa_find_matching_catch_2()|0;
   $22 = tempRet0;
   ___cxa_call_unexpected(($21|0));
   // unreachable;
  }
 } while(0);
 $19 = ($1|0)==(0);
 if ($19) {
  STACKTOP = sp;return;
 }
 $20 = ((($0)) + 68|0);
 $$0916 = 0;
 while(1) {
  $23 = (__Znwj(28)|0);
  __THREW__ = 0;
  invoke_vi(3282,($23|0));
  $24 = __THREW__; __THREW__ = 0;
  $25 = $24&1;
  if ($25) {
   label = 20;
   break;
  }
  $26 = ((($23)) + 12|0);
  HEAP32[$26>>2] = 0;
  $27 = ((($23)) + 16|0);
  HEAP32[$27>>2] = -1;
  $28 = ((($23)) + 20|0);
  HEAP8[$28>>0] = 0;
  HEAP32[$23>>2] = (69712);
  $29 = ((($23)) + 24|0);
  HEAP32[$29>>2] = $$0916;
  HEAP32[$2>>2] = $23;
  $30 = ((($23)) + 8|0);
  $31 = HEAP32[$30>>2]|0;HEAP32[$30>>2] = (($31+1)|0);
  $32 = HEAP32[$5>>2]|0;
  $33 = HEAP32[$20>>2]|0;
  $34 = ($32|0)==($33|0);
  if ($34) {
   __THREW__ = 0;
   invoke_vii(3998,($3|0),($2|0));
   $41 = __THREW__; __THREW__ = 0;
   $42 = $41&1;
   if ($42) {
    label = 21;
    break;
   }
  } else {
   $35 = HEAP32[$2>>2]|0;
   HEAP32[$32>>2] = $35;
   $36 = ($35|0)==(0|0);
   if ($36) {
    $40 = $32;
   } else {
    $37 = ((($35)) + 8|0);
    $38 = HEAP32[$37>>2]|0;HEAP32[$37>>2] = (($38+1)|0);
    $$pre$i = HEAP32[$5>>2]|0;
    $40 = $$pre$i;
   }
   $39 = ((($40)) + 4|0);
   HEAP32[$5>>2] = $39;
  }
  $43 = HEAP32[$2>>2]|0;
  $44 = ($43|0)==(0|0);
  if (!($44)) {
   $45 = ((($43)) + 8|0);
   $46 = HEAP32[$45>>2]|0;HEAP32[$45>>2] = (($46-1)|0);
   $47 = ($46|0)==(1);
   if ($47) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($43,1,1);
   }
  }
  $48 = (($$0916) + 1)|0;
  $49 = ($48>>>0)<($1>>>0);
  if ($49) {
   $$0916 = $48;
  } else {
   label = 9;
   break;
  }
 }
 if ((label|0) == 9) {
  STACKTOP = sp;return;
 }
 else if ((label|0) == 20) {
  $50 = ___cxa_find_matching_catch_2()|0;
  $51 = tempRet0;
  __ZdlPv($23);
  $$0 = $51;$$08 = $50;
  ___resumeException($$08|0);
  // unreachable;
 }
 else if ((label|0) == 21) {
  $52 = ___cxa_find_matching_catch_2()|0;
  $53 = tempRet0;
  $54 = HEAP32[$2>>2]|0;
  $55 = ($54|0)==(0|0);
  if (!($55)) {
   $56 = ((($54)) + 8|0);
   $57 = HEAP32[$56>>2]|0;HEAP32[$56>>2] = (($57-1)|0);
   $58 = ($57|0)==(1);
   if ($58) {
    __THREW__ = 0;
    invoke_viii(3262,($54|0),1,1);
    $59 = __THREW__; __THREW__ = 0;
    $60 = $59&1;
    if ($60) {
     $61 = ___cxa_find_matching_catch_3(0|0)|0;
     $62 = tempRet0;
     ___clang_call_terminate($61);
     // unreachable;
    }
   }
  }
  HEAP32[$2>>2] = 0;
  $$0 = $53;$$08 = $52;
  ___resumeException($$08|0);
  // unreachable;
 }
}
function __ZN3osg16VertexArrayState20assignAllDispatchersEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg16VertexArrayState27assignVertexArrayDispatcherEv($0);
 __ZN3osg16VertexArrayState27assignNormalArrayDispatcherEv($0);
 __ZN3osg16VertexArrayState26assignColorArrayDispatcherEv($0);
 $1 = (__Znwj(28)|0);
 $2 = ((($0)) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + 472|0);
 $5 = HEAP32[$4>>2]|0;
 __THREW__ = 0;
 invoke_vi(3282,($1|0));
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if ($7) {
  $21 = ___cxa_find_matching_catch_2()|0;
  $22 = tempRet0;
  __ZdlPv($1);
  ___resumeException($21|0);
  // unreachable;
 }
 $8 = ((($1)) + 12|0);
 HEAP32[$8>>2] = 0;
 $9 = ((($1)) + 16|0);
 HEAP32[$9>>2] = -1;
 $10 = ((($1)) + 20|0);
 HEAP8[$10>>0] = 0;
 HEAP32[$1>>2] = (69712);
 $11 = ((($1)) + 24|0);
 HEAP32[$11>>2] = $5;
 $12 = ((($0)) + 40|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==($1|0);
 if (!($14)) {
  HEAP32[$12>>2] = $1;
  $15 = ((($1)) + 8|0);
  $16 = HEAP32[$15>>2]|0;HEAP32[$15>>2] = (($16+1)|0);
  $17 = ($13|0)==(0|0);
  if (!($17)) {
   $18 = ((($13)) + 8|0);
   $19 = HEAP32[$18>>2]|0;HEAP32[$18>>2] = (($19-1)|0);
   $20 = ($19|0)==(1);
   if ($20) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($13,1,1);
   }
  }
 }
 $23 = (__Znwj(28)|0);
 $24 = HEAP32[$2>>2]|0;
 $25 = ((($24)) + 512|0);
 $26 = HEAP32[$25>>2]|0;
 __THREW__ = 0;
 invoke_vi(3282,($23|0));
 $27 = __THREW__; __THREW__ = 0;
 $28 = $27&1;
 if ($28) {
  $42 = ___cxa_find_matching_catch_2()|0;
  $43 = tempRet0;
  __ZdlPv($23);
  ___resumeException($42|0);
  // unreachable;
 }
 $29 = ((($23)) + 12|0);
 HEAP32[$29>>2] = 0;
 $30 = ((($23)) + 16|0);
 HEAP32[$30>>2] = -1;
 $31 = ((($23)) + 20|0);
 HEAP8[$31>>0] = 0;
 HEAP32[$23>>2] = (69712);
 $32 = ((($23)) + 24|0);
 HEAP32[$32>>2] = $26;
 $33 = ((($0)) + 44|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)==($23|0);
 if (!($35)) {
  HEAP32[$33>>2] = $23;
  $36 = ((($23)) + 8|0);
  $37 = HEAP32[$36>>2]|0;HEAP32[$36>>2] = (($37+1)|0);
  $38 = ($34|0)==(0|0);
  if (!($38)) {
   $39 = ((($34)) + 8|0);
   $40 = HEAP32[$39>>2]|0;HEAP32[$39>>2] = (($40-1)|0);
   $41 = ($40|0)==(1);
   if ($41) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($34,1,1);
   }
  }
 }
 __ZN3osg16VertexArrayState29assignTexCoordArrayDispatcherEj($0,8);
 __ZN3osg16VertexArrayState33assignVertexAttribArrayDispatcherEj($0,16);
 return;
}
function __ZN3osg16VertexArrayState7releaseEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $2 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(5)|0);
 do {
  if ($2) {
   $3 = (__ZN3osg6notifyENS_14NotifySeverityE(5)|0);
   $4 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($3,158679,28)|0);
   $5 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEPKv($4,$0)|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ((($6)) + -12|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($5) + ($8)|0);
   __ZNKSt3__28ios_base6getlocEv($1,$9);
   __THREW__ = 0;
   $10 = (invoke_iii(3255,($1|0),(215188|0))|0);
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if (!($12)) {
    $13 = HEAP32[$10>>2]|0;
    $14 = ((($13)) + 28|0);
    $15 = HEAP32[$14>>2]|0;
    __THREW__ = 0;
    $16 = (invoke_iii($15|0,($10|0),10)|0);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if (!($18)) {
     __ZNSt3__26localeD2Ev($1);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($5,$16)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($5)|0);
     break;
    }
   }
   $19 = ___cxa_find_matching_catch_2()|0;
   $20 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($1|0));
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if ($22) {
    $23 = ___cxa_find_matching_catch_3(0|0)|0;
    $24 = tempRet0;
    ___clang_call_terminate($23);
    // unreachable;
   } else {
    ___resumeException($19|0);
    // unreachable;
   }
  }
 } while(0);
 $25 = ((($0)) + 16|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ((($26)) + 12|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (__ZN3osg22getOrCreateContextDataEj($28)|0);
 $30 = (__ZN3osg11ContextData3getI23VertexArrayStateManagerEEPT_v($29)|0);
 __ZN23VertexArrayStateManager7releaseEPN3osg16VertexArrayStateE($30,$0);
 STACKTOP = sp;return;
}
function __ZN3osg11ContextData3getI23VertexArrayStateManagerEEPT_v($0) {
 $0 = $0|0;
 var $$0$i$i = 0, $$0$ph$i$i = 0, $$014$i = 0, $$024$i$i = 0, $$025$i$i = 0, $$025$i53$i = 0, $$037$i = 0, $$03752$i = 0, $$in$i$i = 0, $$pre$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 36|0);
 $2 = ((($0)) + 40|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 do {
  if ($4) {
   $$025$i$i = $2;$$037$i = $2;$15 = $3;
   label = 12;
  } else {
   $5 = ((($0)) + 40|0);
   $$0$i$i = $5;$$024$i$i = $3;$51 = $3;
   while(1) {
    $6 = ((($$024$i$i)) + 16|0);
    $7 = HEAP32[$6>>2]|0;
    $8 = ($7>>>0)>(27056>>>0);
    if ($8) {
     $9 = HEAP32[$$024$i$i>>2]|0;
     $10 = ($9|0)==(0|0);
     if ($10) {
      label = 6;
      break;
     } else {
      $$0$ph$i$i = $$024$i$i;$$in$i$i = $9;
     }
    } else {
     $11 = ($7>>>0)<(27056>>>0);
     if (!($11)) {
      label = 10;
      break;
     }
     $12 = ((($$024$i$i)) + 4|0);
     $13 = HEAP32[$12>>2]|0;
     $14 = ($13|0)==(0|0);
     if ($14) {
      label = 9;
      break;
     } else {
      $$0$ph$i$i = $12;$$in$i$i = $13;
     }
    }
    $$0$i$i = $$0$ph$i$i;$$024$i$i = $$in$i$i;$51 = $$in$i$i;
   }
   if ((label|0) == 6) {
    $$025$i53$i = $$024$i$i;$$03752$i = $$024$i$i;
    label = 13;
    break;
   }
   else if ((label|0) == 9) {
    $$025$i53$i = $12;$$03752$i = $$024$i$i;
    label = 13;
    break;
   }
   else if ((label|0) == 10) {
    $$025$i$i = $$0$i$i;$$037$i = $$024$i$i;$15 = $51;
    label = 12;
    break;
   }
  }
 } while(0);
 if ((label|0) == 12) {
  $16 = ($15|0)==(0|0);
  if ($16) {
   $$025$i53$i = $$025$i$i;$$03752$i = $$037$i;
   label = 13;
  } else {
   $$014$i = $15;
  }
 }
 if ((label|0) == 13) {
  $17 = (__Znwj(24)|0);
  $18 = ((($17)) + 16|0);
  HEAP32[$18>>2] = (27056);
  $19 = ((($17)) + 20|0);
  HEAP32[$19>>2] = 0;
  HEAP32[$17>>2] = 0;
  $20 = ((($17)) + 4|0);
  HEAP32[$20>>2] = 0;
  $21 = ((($17)) + 8|0);
  HEAP32[$21>>2] = $$03752$i;
  HEAP32[$$025$i53$i>>2] = $17;
  $22 = HEAP32[$1>>2]|0;
  $23 = HEAP32[$22>>2]|0;
  $24 = ($23|0)==(0|0);
  if ($24) {
   $28 = $17;
  } else {
   $25 = $23;
   HEAP32[$1>>2] = $25;
   $$pre$i$i = HEAP32[$$025$i53$i>>2]|0;
   $28 = $$pre$i$i;
  }
  $26 = ((($0)) + 40|0);
  $27 = HEAP32[$26>>2]|0;
  __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($27,$28);
  $29 = ((($0)) + 44|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (($30) + 1)|0;
  HEAP32[$29>>2] = $31;
  $$014$i = $17;
 }
 $32 = ((($$014$i)) + 20|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ($33|0)==(0|0);
 if (!($34)) {
  $50 = HEAP32[$32>>2]|0;
  return ($50|0);
 }
 $35 = (__Znwj(52)|0);
 $36 = ((($0)) + 24|0);
 $37 = HEAP32[$36>>2]|0;
 __THREW__ = 0;
 invoke_vii(3999,($35|0),($37|0));
 $38 = __THREW__; __THREW__ = 0;
 $39 = $38&1;
 if ($39) {
  $48 = ___cxa_find_matching_catch_2()|0;
  $49 = tempRet0;
  __ZdlPv($35);
  ___resumeException($48|0);
  // unreachable;
 }
 $40 = HEAP32[$32>>2]|0;
 $41 = ($40|0)==($35|0);
 if ($41) {
  $50 = HEAP32[$32>>2]|0;
  return ($50|0);
 }
 HEAP32[$32>>2] = $35;
 $42 = ((($35)) + 8|0);
 $43 = HEAP32[$42>>2]|0;HEAP32[$42>>2] = (($43+1)|0);
 $44 = ($40|0)==(0|0);
 if ($44) {
  $50 = HEAP32[$32>>2]|0;
  return ($50|0);
 }
 $45 = ((($40)) + 8|0);
 $46 = HEAP32[$45>>2]|0;HEAP32[$45>>2] = (($46-1)|0);
 $47 = ($46|0)==(1);
 if (!($47)) {
  $50 = HEAP32[$32>>2]|0;
  return ($50|0);
 }
 __ZNK3osg10Referenced24signalObserversAndDeleteEbb($40,1,1);
 $50 = HEAP32[$32>>2]|0;
 return ($50|0);
}
function __ZN23VertexArrayStateManager7releaseEPN3osg16VertexArrayStateE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$03 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(5)|0);
 do {
  if ($3) {
   $4 = (__ZN3osg6notifyENS_14NotifySeverityE(5)|0);
   $5 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($4,158708,33)|0);
   $6 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEPKv($5,$0)|0);
   $7 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($6,174996,1)|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ((($8)) + -12|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (($7) + ($10)|0);
   __ZNKSt3__28ios_base6getlocEv($2,$11);
   __THREW__ = 0;
   $12 = (invoke_iii(3255,($2|0),(215188|0))|0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if (!($14)) {
    $15 = HEAP32[$12>>2]|0;
    $16 = ((($15)) + 28|0);
    $17 = HEAP32[$16>>2]|0;
    __THREW__ = 0;
    $18 = (invoke_iii($17|0,($12|0),10)|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __ZNSt3__26localeD2Ev($2);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($7,$18)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($7)|0);
     break;
    }
   }
   $21 = ___cxa_find_matching_catch_2()|0;
   $22 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($2|0));
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if ($24) {
    $25 = ___cxa_find_matching_catch_3(0|0)|0;
    $26 = tempRet0;
    ___clang_call_terminate($25);
    // unreachable;
   } else {
    ___resumeException($21|0);
    // unreachable;
   }
  }
 } while(0);
 $27 = ((($0)) + 28|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = ((($28)) + 8|0);
 $30 = HEAP32[$29>>2]|0;
 (FUNCTION_TABLE_ii[$30 & 8191]($27)|0);
 $31 = ($1|0)==(0|0);
 if (!($31)) {
  $32 = ((($1)) + 8|0);
  $33 = HEAP32[$32>>2]|0;HEAP32[$32>>2] = (($33+1)|0);
 }
 $34 = ((($0)) + 40|0);
 __THREW__ = 0;
 $35 = (invoke_ii(3276,12)|0);
 $36 = __THREW__; __THREW__ = 0;
 $37 = $36&1;
 do {
  if ($37) {
   $57 = ___cxa_find_matching_catch_2()|0;
   $58 = tempRet0;
   if ($31) {
    $$0 = $58;$$03 = $57;
   } else {
    $59 = ((($1)) + 8|0);
    $60 = HEAP32[$59>>2]|0;HEAP32[$59>>2] = (($60-1)|0);
    $61 = ($60|0)==(1);
    if ($61) {
     __THREW__ = 0;
     invoke_viii(3262,($1|0),1,1);
     $62 = __THREW__; __THREW__ = 0;
     $63 = $62&1;
     if ($63) {
      $69 = ___cxa_find_matching_catch_3(0|0)|0;
      $70 = tempRet0;
      ___clang_call_terminate($69);
      // unreachable;
     } else {
      $$0 = $58;$$03 = $57;
     }
    } else {
     $$0 = $58;$$03 = $57;
    }
   }
  } else {
   $38 = ((($35)) + 8|0);
   HEAP32[$38>>2] = $1;
   if (!($31)) {
    $39 = ((($1)) + 8|0);
    $40 = HEAP32[$39>>2]|0;HEAP32[$39>>2] = (($40+1)|0);
   }
   $41 = ((($35)) + 4|0);
   HEAP32[$41>>2] = $34;
   $42 = HEAP32[$34>>2]|0;
   HEAP32[$35>>2] = $42;
   $43 = ((($42)) + 4|0);
   HEAP32[$43>>2] = $35;
   HEAP32[$34>>2] = $35;
   $44 = ((($0)) + 48|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = (($45) + 1)|0;
   HEAP32[$44>>2] = $46;
   if ($31) {
    $52 = HEAP32[$27>>2]|0;
    $53 = ((($52)) + 12|0);
    $54 = HEAP32[$53>>2]|0;
    (FUNCTION_TABLE_ii[$54 & 8191]($27)|0);
    STACKTOP = sp;return;
   }
   $47 = ((($1)) + 8|0);
   $48 = HEAP32[$47>>2]|0;HEAP32[$47>>2] = (($48-1)|0);
   $49 = ($48|0)==(1);
   if (!($49)) {
    $52 = HEAP32[$27>>2]|0;
    $53 = ((($52)) + 12|0);
    $54 = HEAP32[$53>>2]|0;
    (FUNCTION_TABLE_ii[$54 & 8191]($27)|0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   invoke_viii(3262,($1|0),1,1);
   $50 = __THREW__; __THREW__ = 0;
   $51 = $50&1;
   if ($51) {
    $55 = ___cxa_find_matching_catch_2()|0;
    $56 = tempRet0;
    $$0 = $56;$$03 = $55;
    break;
   } else {
    $52 = HEAP32[$27>>2]|0;
    $53 = ((($52)) + 12|0);
    $54 = HEAP32[$53>>2]|0;
    (FUNCTION_TABLE_ii[$54 & 8191]($27)|0);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $64 = HEAP32[$27>>2]|0;
 $65 = ((($64)) + 12|0);
 $66 = HEAP32[$65>>2]|0;
 __THREW__ = 0;
 (invoke_ii($66|0,($27|0))|0);
 $67 = __THREW__; __THREW__ = 0;
 $68 = $67&1;
 if ($68) {
  $69 = ___cxa_find_matching_catch_3(0|0)|0;
  $70 = tempRet0;
  ___clang_call_terminate($69);
  // unreachable;
 } else {
  ___resumeException($$03|0);
  // unreachable;
 }
}
function __ZN23VertexArrayStateManagerC2Ej($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$1 = 0, $$14 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = (__Znwj(32)|0);
 HEAP32[$2>>2] = $3;
 $4 = ((($2)) + 8|0);
 HEAP32[$4>>2] = -2147483616;
 $5 = ((($2)) + 4|0);
 HEAP32[$5>>2] = 23;
 dest=$3; src=158742; stop=dest+23|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $6 = ((($3)) + 23|0);
 HEAP8[$6>>0] = 0;
 __THREW__ = 0;
 invoke_viii(3719,($0|0),($2|0),($1|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $19 = ___cxa_find_matching_catch_2()|0;
  $20 = tempRet0;
  $21 = ((($2)) + 11|0);
  $22 = HEAP8[$21>>0]|0;
  $23 = ($22<<24>>24)<(0);
  if ($23) {
   $24 = HEAP32[$2>>2]|0;
   __ZdlPv($24);
  }
  $$1 = $20;$$14 = $19;
  ___resumeException($$14|0);
  // unreachable;
 }
 $9 = ((($2)) + 11|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = ($10<<24>>24)<(0);
 if ($11) {
  $12 = HEAP32[$2>>2]|0;
  __ZdlPv($12);
 }
 HEAP32[$0>>2] = (69760);
 $13 = ((($0)) + 28|0);
 __THREW__ = 0;
 invoke_vii(3507,($13|0),0);
 $14 = __THREW__; __THREW__ = 0;
 $15 = $14&1;
 if (!($15)) {
  $16 = ((($0)) + 40|0);
  HEAP32[$16>>2] = $16;
  $17 = ((($0)) + 44|0);
  HEAP32[$17>>2] = $16;
  $18 = ((($0)) + 48|0);
  HEAP32[$18>>2] = 0;
  STACKTOP = sp;return;
 }
 $25 = ___cxa_find_matching_catch_2()|0;
 $26 = tempRet0;
 __THREW__ = 0;
 invoke_vi(1861,($0|0));
 $27 = __THREW__; __THREW__ = 0;
 $28 = $27&1;
 if ($28) {
  $29 = ___cxa_find_matching_catch_3(0|0)|0;
  $30 = tempRet0;
  ___clang_call_terminate($29);
  // unreachable;
 } else {
  $$1 = $26;$$14 = $25;
  ___resumeException($$14|0);
  // unreachable;
 }
}
function __ZN23VertexArrayStateManagerD2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (69760);
 $1 = ((($0)) + 40|0);
 __ZNSt3__210__list_impIN3osg7ref_ptrINS1_16VertexArrayStateEEENS_9allocatorIS4_EEED2Ev($1);
 $2 = ((($0)) + 28|0);
 __THREW__ = 0;
 invoke_vi(707,($2|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if (!($4)) {
  __ZN3osg21GraphicsObjectManagerD2Ev($0);
  return;
 }
 $5 = ___cxa_find_matching_catch_2()|0;
 $6 = tempRet0;
 __THREW__ = 0;
 invoke_vi(1861,($0|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch_3(0|0)|0;
  $10 = tempRet0;
  ___clang_call_terminate($9);
  // unreachable;
 } else {
  ___resumeException($5|0);
  // unreachable;
 }
}
function __ZN23VertexArrayStateManagerD0Ev($0) {
 $0 = $0|0;
 var $$023$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (69760);
 $1 = ((($0)) + 40|0);
 $2 = ((($0)) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 L1: do {
  if (!($4)) {
   $5 = ((($0)) + 44|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = HEAP32[$1>>2]|0;
   $8 = ((($7)) + 4|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = HEAP32[$6>>2]|0;
   $11 = ((($10)) + 4|0);
   HEAP32[$11>>2] = $9;
   $12 = HEAP32[$8>>2]|0;
   HEAP32[$12>>2] = $10;
   HEAP32[$2>>2] = 0;
   $13 = ($6|0)==($1|0);
   if (!($13)) {
    $$023$i$i = $6;
    while(1) {
     $14 = ((($$023$i$i)) + 4|0);
     $15 = HEAP32[$14>>2]|0;
     $16 = ((($$023$i$i)) + 8|0);
     $17 = HEAP32[$16>>2]|0;
     $18 = ($17|0)==(0|0);
     if (!($18)) {
      $19 = ((($17)) + 8|0);
      $20 = HEAP32[$19>>2]|0;HEAP32[$19>>2] = (($20-1)|0);
      $21 = ($20|0)==(1);
      if ($21) {
       __THREW__ = 0;
       invoke_viii(3262,($17|0),1,1);
       $22 = __THREW__; __THREW__ = 0;
       $23 = $22&1;
       if ($23) {
        break;
       }
      }
     }
     __ZdlPv($$023$i$i);
     $24 = ($15|0)==($1|0);
     if ($24) {
      break L1;
     } else {
      $$023$i$i = $15;
     }
    }
    $25 = ___cxa_find_matching_catch_2()|0;
    $26 = tempRet0;
    ___cxa_call_unexpected(($25|0));
    // unreachable;
   }
  }
 } while(0);
 $27 = ((($0)) + 28|0);
 __THREW__ = 0;
 invoke_vi(707,($27|0));
 $28 = __THREW__; __THREW__ = 0;
 $29 = $28&1;
 if ($29) {
  $32 = ___cxa_find_matching_catch_2()|0;
  $33 = tempRet0;
  __THREW__ = 0;
  invoke_vi(1861,($0|0));
  $34 = __THREW__; __THREW__ = 0;
  $35 = $34&1;
  if ($35) {
   $36 = ___cxa_find_matching_catch_3(0|0)|0;
   $37 = tempRet0;
   ___clang_call_terminate($36);
   // unreachable;
  } else {
   $eh$lpad$body$index2Z2D = $33;$eh$lpad$body$indexZ2D = $32;
   __ZdlPv($0);
   ___resumeException($eh$lpad$body$indexZ2D|0);
   // unreachable;
  }
 }
 __THREW__ = 0;
 invoke_vi(1861,($0|0));
 $30 = __THREW__; __THREW__ = 0;
 $31 = $30&1;
 if (!($31)) {
  __ZdlPv($0);
  return;
 }
 $38 = ___cxa_find_matching_catch_2()|0;
 $39 = tempRet0;
 $eh$lpad$body$index2Z2D = $39;$eh$lpad$body$indexZ2D = $38;
 __ZdlPv($0);
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
}
function __ZN23VertexArrayStateManager21flushDeletedGLObjectsEdRd($0,$1,$2) {
 $0 = $0|0;
 $1 = +$1;
 $2 = $2|0;
 var $$pre = 0, $$sink$i = 0.0, $$sink$i28 = 0.0, $$sroa$041$0 = 0, $$sroa$041$061 = 0, $$sroa$041$063 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0.0, $106 = 0, $107 = 0, $108 = 0.0, $109 = 0.0, $11 = 0, $110 = 0, $111 = 0.0;
 var $112 = 0.0, $113 = 0.0, $114 = 0.0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0.0, $4 = 0.0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0.0, $59 = 0, $6 = 0, $60 = 0, $61 = 0.0, $62 = 0.0, $63 = 0.0, $64 = 0.0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0.0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $or$cond62 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = +HEAPF64[$2>>3];
 $5 = !($4 <= 0.0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(5)|0);
 do {
  if ($6) {
   $7 = (__ZN3osg6notifyENS_14NotifySeverityE(5)|0);
   $8 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($7,158892,48)|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = ((($9)) + -12|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (($8) + ($11)|0);
   __ZNKSt3__28ios_base6getlocEv($3,$12);
   __THREW__ = 0;
   $13 = (invoke_iii(3255,($3|0),(215188|0))|0);
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if (!($15)) {
    $16 = HEAP32[$13>>2]|0;
    $17 = ((($16)) + 28|0);
    $18 = HEAP32[$17>>2]|0;
    __THREW__ = 0;
    $19 = (invoke_iii($18|0,($13|0),10)|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if (!($21)) {
     __ZNSt3__26localeD2Ev($3);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($8,$19)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($8)|0);
     break;
    }
   }
   $22 = ___cxa_find_matching_catch_2()|0;
   $23 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($3|0));
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   if ($25) {
    $26 = ___cxa_find_matching_catch_3(0|0)|0;
    $27 = tempRet0;
    ___clang_call_terminate($26);
    // unreachable;
   } else {
    ___resumeException($22|0);
    // unreachable;
   }
  }
 } while(0);
 $28 = (__ZN3osg5Timer8instanceEv()|0);
 $29 = (__ZNK3osg5Timer4tickEv($28)|0);
 $30 = tempRet0;
 $31 = ((($0)) + 28|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = ((($32)) + 8|0);
 $34 = HEAP32[$33>>2]|0;
 (FUNCTION_TABLE_ii[$34 & 8191]($31)|0);
 $35 = ((($0)) + 44|0);
 $$sroa$041$061 = HEAP32[$35>>2]|0;
 $36 = ((($0)) + 40|0);
 $37 = $$sroa$041$061;
 $38 = ($37|0)!=($36|0);
 $39 = +HEAPF64[$2>>3];
 $40 = $39 > 0.0;
 $or$cond62 = $38 & $40;
 L14: do {
  if ($or$cond62) {
   $41 = ((($28)) + 8|0);
   $$sroa$041$063 = $$sroa$041$061;$66 = $37;
   while(1) {
    $42 = $$sroa$041$063;
    $43 = ((($42)) + 8|0);
    $44 = HEAP32[$43>>2]|0;
    __THREW__ = 0;
    invoke_vi(4000,($44|0));
    $45 = __THREW__; __THREW__ = 0;
    $46 = $45&1;
    if ($46) {
     break;
    }
    __THREW__ = 0;
    $47 = (invoke_ii(3385,($28|0))|0);
    $48 = tempRet0;
    $49 = __THREW__; __THREW__ = 0;
    $50 = $49&1;
    if ($50) {
     break;
    }
    $51 = ($48>>>0)>($30>>>0);
    $52 = ($47>>>0)>($29>>>0);
    $53 = ($48|0)==($30|0);
    $54 = $53 & $52;
    $55 = $51 | $54;
    if ($55) {
     $56 = (_i64Subtract(($47|0),($48|0),($29|0),($30|0))|0);
     $57 = tempRet0;
     $58 = (+($56>>>0)) + (4294967296.0*(+($57>>>0)));
     $$sink$i = $58;
    } else {
     $59 = (_i64Subtract(($29|0),($30|0),($47|0),($48|0))|0);
     $60 = tempRet0;
     $61 = (+($59>>>0)) + (4294967296.0*(+($60>>>0)));
     $62 = -$61;
     $$sink$i = $62;
    }
    $63 = +HEAPF64[$41>>3];
    $64 = $$sink$i * $63;
    $65 = ((($66)) + 4|0);
    $$sroa$041$0 = HEAP32[$65>>2]|0;
    $67 = $$sroa$041$0;
    $68 = ($67|0)!=($36|0);
    $69 = +HEAPF64[$2>>3];
    $70 = $64 < $69;
    $or$cond = $68 & $70;
    if ($or$cond) {
     $$sroa$041$063 = $$sroa$041$0;$66 = $67;
    } else {
     label = 17;
     break;
    }
   }
   L24: do {
    if ((label|0) == 17) {
     $$pre = HEAP32[$35>>2]|0;
     $71 = ($67|0)==($$pre|0);
     if ($71) {
      break L14;
     }
     $72 = HEAP32[$67>>2]|0;
     $73 = ((($72)) + 4|0);
     $74 = HEAP32[$73>>2]|0;
     $75 = HEAP32[$$pre>>2]|0;
     $76 = ((($75)) + 4|0);
     HEAP32[$76>>2] = $74;
     $77 = HEAP32[$73>>2]|0;
     HEAP32[$77>>2] = $75;
     $78 = ((($0)) + 48|0);
     $80 = $$pre;
     while(1) {
      $79 = ((($80)) + 4|0);
      $81 = HEAP32[$79>>2]|0;
      $82 = HEAP32[$78>>2]|0;
      $83 = (($82) + -1)|0;
      HEAP32[$78>>2] = $83;
      $84 = ((($80)) + 8|0);
      $85 = HEAP32[$84>>2]|0;
      $86 = ($85|0)==(0|0);
      if (!($86)) {
       $87 = ((($85)) + 8|0);
       $88 = HEAP32[$87>>2]|0;HEAP32[$87>>2] = (($88-1)|0);
       $89 = ($88|0)==(1);
       if ($89) {
        __THREW__ = 0;
        invoke_viii(3262,($85|0),1,1);
        $90 = __THREW__; __THREW__ = 0;
        $91 = $90&1;
        if ($91) {
         break L24;
        }
       }
      }
      __ZdlPv($80);
      $92 = ($81|0)==($67|0);
      if ($92) {
       break L14;
      } else {
       $80 = $81;
      }
     }
    }
   } while(0);
   $115 = ___cxa_find_matching_catch_2()|0;
   $116 = tempRet0;
   $117 = HEAP32[$31>>2]|0;
   $118 = ((($117)) + 12|0);
   $119 = HEAP32[$118>>2]|0;
   __THREW__ = 0;
   (invoke_ii($119|0,($31|0))|0);
   $120 = __THREW__; __THREW__ = 0;
   $121 = $120&1;
   if ($121) {
    $122 = ___cxa_find_matching_catch_3(0|0)|0;
    $123 = tempRet0;
    ___clang_call_terminate($122);
    // unreachable;
   } else {
    ___resumeException($115|0);
    // unreachable;
   }
  }
 } while(0);
 $93 = HEAP32[$31>>2]|0;
 $94 = ((($93)) + 12|0);
 $95 = HEAP32[$94>>2]|0;
 (FUNCTION_TABLE_ii[$95 & 8191]($31)|0);
 $96 = (__ZNK3osg5Timer4tickEv($28)|0);
 $97 = tempRet0;
 $98 = ($97>>>0)>($30>>>0);
 $99 = ($96>>>0)>($29>>>0);
 $100 = ($97|0)==($30|0);
 $101 = $100 & $99;
 $102 = $98 | $101;
 if ($102) {
  $103 = (_i64Subtract(($96|0),($97|0),($29|0),($30|0))|0);
  $104 = tempRet0;
  $105 = (+($103>>>0)) + (4294967296.0*(+($104>>>0)));
  $$sink$i28 = $105;
 } else {
  $106 = (_i64Subtract(($29|0),($30|0),($96|0),($97|0))|0);
  $107 = tempRet0;
  $108 = (+($106>>>0)) + (4294967296.0*(+($107>>>0)));
  $109 = -$108;
  $$sink$i28 = $109;
 }
 $110 = ((($28)) + 8|0);
 $111 = +HEAPF64[$110>>3];
 $112 = $$sink$i28 * $111;
 $113 = +HEAPF64[$2>>3];
 $114 = $113 - $112;
 HEAPF64[$2>>3] = $114;
 STACKTOP = sp;return;
}
function __ZN23VertexArrayStateManager24flushAllDeletedGLObjectsEv($0) {
 $0 = $0|0;
 var $$023$i$i = 0, $$sroa$08$0 = 0, $$sroa$08$019 = 0, $$sroa$08$020 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $2 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(5)|0);
 do {
  if ($2) {
   $3 = (__ZN3osg6notifyENS_14NotifySeverityE(5)|0);
   $4 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($3,158766,51)|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = ((($5)) + -12|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = (($4) + ($7)|0);
   __ZNKSt3__28ios_base6getlocEv($1,$8);
   __THREW__ = 0;
   $9 = (invoke_iii(3255,($1|0),(215188|0))|0);
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    $12 = HEAP32[$9>>2]|0;
    $13 = ((($12)) + 28|0);
    $14 = HEAP32[$13>>2]|0;
    __THREW__ = 0;
    $15 = (invoke_iii($14|0,($9|0),10)|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if (!($17)) {
     __ZNSt3__26localeD2Ev($1);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($4,$15)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($4)|0);
     break;
    }
   }
   $18 = ___cxa_find_matching_catch_2()|0;
   $19 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($1|0));
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if ($21) {
    $22 = ___cxa_find_matching_catch_3(0|0)|0;
    $23 = tempRet0;
    ___clang_call_terminate($22);
    // unreachable;
   } else {
    ___resumeException($18|0);
    // unreachable;
   }
  }
 } while(0);
 $24 = ((($0)) + 28|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ((($25)) + 8|0);
 $27 = HEAP32[$26>>2]|0;
 (FUNCTION_TABLE_ii[$27 & 8191]($24)|0);
 $28 = ((($0)) + 40|0);
 $29 = ((($0)) + 44|0);
 $$sroa$08$019 = HEAP32[$29>>2]|0;
 $30 = $$sroa$08$019;
 $31 = ($30|0)==($28|0);
 L11: do {
  if (!($31)) {
   $$sroa$08$020 = $$sroa$08$019;$65 = $30;
   while(1) {
    $59 = $$sroa$08$020;
    $60 = ((($59)) + 8|0);
    $61 = HEAP32[$60>>2]|0;
    __THREW__ = 0;
    invoke_vi(4000,($61|0));
    $62 = __THREW__; __THREW__ = 0;
    $63 = $62&1;
    if ($63) {
     break;
    }
    $64 = ((($65)) + 4|0);
    $$sroa$08$0 = HEAP32[$64>>2]|0;
    $66 = $$sroa$08$0;
    $67 = ($66|0)==($28|0);
    if ($67) {
     break L11;
    } else {
     $$sroa$08$020 = $$sroa$08$0;$65 = $66;
    }
   }
   $68 = ___cxa_find_matching_catch_2()|0;
   $69 = tempRet0;
   $70 = HEAP32[$24>>2]|0;
   $71 = ((($70)) + 12|0);
   $72 = HEAP32[$71>>2]|0;
   __THREW__ = 0;
   (invoke_ii($72|0,($24|0))|0);
   $73 = __THREW__; __THREW__ = 0;
   $74 = $73&1;
   if ($74) {
    $75 = ___cxa_find_matching_catch_3(0|0)|0;
    $76 = tempRet0;
    ___clang_call_terminate($75);
    // unreachable;
   } else {
    ___resumeException($68|0);
    // unreachable;
   }
  }
 } while(0);
 $32 = ((($0)) + 48|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ($33|0)==(0);
 if ($34) {
  $56 = HEAP32[$24>>2]|0;
  $57 = ((($56)) + 12|0);
  $58 = HEAP32[$57>>2]|0;
  (FUNCTION_TABLE_ii[$58 & 8191]($24)|0);
  STACKTOP = sp;return;
 }
 $35 = HEAP32[$29>>2]|0;
 $36 = HEAP32[$28>>2]|0;
 $37 = ((($36)) + 4|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = HEAP32[$35>>2]|0;
 $40 = ((($39)) + 4|0);
 HEAP32[$40>>2] = $38;
 $41 = HEAP32[$37>>2]|0;
 HEAP32[$41>>2] = $39;
 HEAP32[$32>>2] = 0;
 $42 = ($35|0)==($28|0);
 if ($42) {
  $56 = HEAP32[$24>>2]|0;
  $57 = ((($56)) + 12|0);
  $58 = HEAP32[$57>>2]|0;
  (FUNCTION_TABLE_ii[$58 & 8191]($24)|0);
  STACKTOP = sp;return;
 } else {
  $$023$i$i = $35;
 }
 while(1) {
  $43 = ((($$023$i$i)) + 4|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = ((($$023$i$i)) + 8|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = ($46|0)==(0|0);
  if (!($47)) {
   $48 = ((($46)) + 8|0);
   $49 = HEAP32[$48>>2]|0;HEAP32[$48>>2] = (($49-1)|0);
   $50 = ($49|0)==(1);
   if ($50) {
    __THREW__ = 0;
    invoke_viii(3262,($46|0),1,1);
    $51 = __THREW__; __THREW__ = 0;
    $52 = $51&1;
    if ($52) {
     label = 15;
     break;
    }
   }
  }
  __ZdlPv($$023$i$i);
  $53 = ($44|0)==($28|0);
  if ($53) {
   label = 16;
   break;
  } else {
   $$023$i$i = $44;
  }
 }
 if ((label|0) == 15) {
  $54 = ___cxa_find_matching_catch_2()|0;
  $55 = tempRet0;
  ___cxa_call_unexpected(($54|0));
  // unreachable;
 }
 else if ((label|0) == 16) {
  $56 = HEAP32[$24>>2]|0;
  $57 = ((($56)) + 12|0);
  $58 = HEAP32[$57>>2]|0;
  (FUNCTION_TABLE_ii[$58 & 8191]($24)|0);
  STACKTOP = sp;return;
 }
}
function __ZN23VertexArrayStateManager18deleteAllGLObjectsEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $2 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 $3 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
 $4 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($3,158818,73)|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($5)) + -12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($4) + ($7)|0);
 __ZNKSt3__28ios_base6getlocEv($1,$8);
 __THREW__ = 0;
 $9 = (invoke_iii(3255,($1|0),(215188|0))|0);
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if (!($11)) {
  $12 = HEAP32[$9>>2]|0;
  $13 = ((($12)) + 28|0);
  $14 = HEAP32[$13>>2]|0;
  __THREW__ = 0;
  $15 = (invoke_iii($14|0,($9|0),10)|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __ZNSt3__26localeD2Ev($1);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($4,$15)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($4)|0);
   STACKTOP = sp;return;
  }
 }
 $18 = ___cxa_find_matching_catch_2()|0;
 $19 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($1|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if ($21) {
  $22 = ___cxa_find_matching_catch_3(0|0)|0;
  $23 = tempRet0;
  ___clang_call_terminate($22);
  // unreachable;
 } else {
  ___resumeException($18|0);
  // unreachable;
 }
}
function __ZN23VertexArrayStateManager19discardAllGLObjectsEv($0) {
 $0 = $0|0;
 var $$023$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $2 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(5)|0);
 do {
  if ($2) {
   $3 = (__ZN3osg6notifyENS_14NotifySeverityE(5)|0);
   $4 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($3,158766,51)|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = ((($5)) + -12|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = (($4) + ($7)|0);
   __ZNKSt3__28ios_base6getlocEv($1,$8);
   __THREW__ = 0;
   $9 = (invoke_iii(3255,($1|0),(215188|0))|0);
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    $12 = HEAP32[$9>>2]|0;
    $13 = ((($12)) + 28|0);
    $14 = HEAP32[$13>>2]|0;
    __THREW__ = 0;
    $15 = (invoke_iii($14|0,($9|0),10)|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if (!($17)) {
     __ZNSt3__26localeD2Ev($1);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($4,$15)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($4)|0);
     break;
    }
   }
   $18 = ___cxa_find_matching_catch_2()|0;
   $19 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($1|0));
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if ($21) {
    $22 = ___cxa_find_matching_catch_3(0|0)|0;
    $23 = tempRet0;
    ___clang_call_terminate($22);
    // unreachable;
   } else {
    ___resumeException($18|0);
    // unreachable;
   }
  }
 } while(0);
 $24 = ((($0)) + 28|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ((($25)) + 8|0);
 $27 = HEAP32[$26>>2]|0;
 (FUNCTION_TABLE_ii[$27 & 8191]($24)|0);
 $28 = ((($0)) + 40|0);
 $29 = ((($0)) + 48|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ($30|0)==(0);
 if ($31) {
  $54 = HEAP32[$24>>2]|0;
  $55 = ((($54)) + 12|0);
  $56 = HEAP32[$55>>2]|0;
  (FUNCTION_TABLE_ii[$56 & 8191]($24)|0);
  STACKTOP = sp;return;
 }
 $32 = ((($0)) + 44|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = HEAP32[$28>>2]|0;
 $35 = ((($34)) + 4|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = HEAP32[$33>>2]|0;
 $38 = ((($37)) + 4|0);
 HEAP32[$38>>2] = $36;
 $39 = HEAP32[$35>>2]|0;
 HEAP32[$39>>2] = $37;
 HEAP32[$29>>2] = 0;
 $40 = ($33|0)==($28|0);
 if ($40) {
  $54 = HEAP32[$24>>2]|0;
  $55 = ((($54)) + 12|0);
  $56 = HEAP32[$55>>2]|0;
  (FUNCTION_TABLE_ii[$56 & 8191]($24)|0);
  STACKTOP = sp;return;
 } else {
  $$023$i$i = $33;
 }
 while(1) {
  $41 = ((($$023$i$i)) + 4|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = ((($$023$i$i)) + 8|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = ($44|0)==(0|0);
  if (!($45)) {
   $46 = ((($44)) + 8|0);
   $47 = HEAP32[$46>>2]|0;HEAP32[$46>>2] = (($47-1)|0);
   $48 = ($47|0)==(1);
   if ($48) {
    __THREW__ = 0;
    invoke_viii(3262,($44|0),1,1);
    $49 = __THREW__; __THREW__ = 0;
    $50 = $49&1;
    if ($50) {
     label = 14;
     break;
    }
   }
  }
  __ZdlPv($$023$i$i);
  $51 = ($42|0)==($28|0);
  if ($51) {
   label = 15;
   break;
  } else {
   $$023$i$i = $42;
  }
 }
 if ((label|0) == 14) {
  $52 = ___cxa_find_matching_catch_2()|0;
  $53 = tempRet0;
  ___cxa_call_unexpected(($52|0));
  // unreachable;
 }
 else if ((label|0) == 15) {
  $54 = HEAP32[$24>>2]|0;
  $55 = ((($54)) + 12|0);
  $56 = HEAP32[$55>>2]|0;
  (FUNCTION_TABLE_ii[$56 & 8191]($24)|0);
  STACKTOP = sp;return;
 }
}
function __ZNSt3__210__list_impIN3osg7ref_ptrINS1_16VertexArrayStateEEENS_9allocatorIS4_EEED2Ev($0) {
 $0 = $0|0;
 var $$023$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  return;
 }
 $4 = ((($0)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$0>>2]|0;
 $7 = ((($6)) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$5>>2]|0;
 $10 = ((($9)) + 4|0);
 HEAP32[$10>>2] = $8;
 $11 = HEAP32[$7>>2]|0;
 HEAP32[$11>>2] = $9;
 HEAP32[$1>>2] = 0;
 $12 = ($5|0)==($0|0);
 if ($12) {
  return;
 } else {
  $$023$i = $5;
 }
 while(1) {
  $13 = ((($$023$i)) + 4|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = ((($$023$i)) + 8|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($16|0)==(0|0);
  if (!($17)) {
   $18 = ((($16)) + 8|0);
   $19 = HEAP32[$18>>2]|0;HEAP32[$18>>2] = (($19-1)|0);
   $20 = ($19|0)==(1);
   if ($20) {
    __THREW__ = 0;
    invoke_viii(3262,($16|0),1,1);
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if ($22) {
     label = 7;
     break;
    }
   }
  }
  __ZdlPv($$023$i);
  $23 = ($14|0)==($0|0);
  if ($23) {
   label = 8;
   break;
  } else {
   $$023$i = $14;
  }
 }
 if ((label|0) == 7) {
  $24 = ___cxa_find_matching_catch_2()|0;
  $25 = tempRet0;
  ___cxa_call_unexpected(($24|0));
  // unreachable;
 }
 else if ((label|0) == 8) {
  return;
 }
}
function __ZN3osg16VertexArrayState8setArrayEPNS0_13ArrayDispatchERNS_5StateEPKNS_5ArrayE($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$pre$i = 0, $$pre$i30 = 0, $$pre$phi$i31Z2D = 0, $$pre$phi$iZ2D = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $4 = sp;
 HEAP32[$4>>2] = $1;
 $5 = ($3|0)==(0|0);
 $6 = $1;
 if ($5) {
  $117 = ((($1)) + 12|0);
  $118 = HEAP32[$117>>2]|0;
  $119 = ($118|0)==(0|0);
  if ($119) {
   STACKTOP = sp;return;
  }
  $120 = HEAP32[$1>>2]|0;
  $121 = ((($120)) + 36|0);
  $122 = HEAP32[$121>>2]|0;
  FUNCTION_TABLE_vii[$122 & 8191]($1,$2);
  HEAP32[$117>>2] = 0;
  $123 = ((($1)) + 16|0);
  HEAP32[$123>>2] = -1;
  $124 = ((($1)) + 20|0);
  HEAP8[$124>>0] = 0;
  STACKTOP = sp;return;
 }
 $7 = ((($1)) + 20|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = ($8<<24>>24)==(0);
 do {
  if ($9) {
   HEAP8[$7>>0] = 1;
   $10 = ((($0)) + 76|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = ((($0)) + 80|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = ($11|0)==($13|0);
   if ($14) {
    $17 = ((($0)) + 72|0);
    __ZNSt3__26vectorIPN3osg16VertexArrayState13ArrayDispatchENS_9allocatorIS4_EEE21__push_back_slow_pathIKS4_EEvRT_($17,$4);
    break;
   } else {
    HEAP32[$11>>2] = $6;
    $15 = HEAP32[$10>>2]|0;
    $16 = ((($15)) + 4|0);
    HEAP32[$10>>2] = $16;
    break;
   }
  }
 } while(0);
 $18 = HEAP32[$4>>2]|0;
 $19 = ((($18)) + 12|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)==(0|0);
 do {
  if ($21) {
   $22 = ((($0)) + 20|0);
   $23 = HEAP8[$22>>0]|0;
   $24 = ($23<<24>>24)==(0);
   if (!($24)) {
    $25 = ((($3)) + 40|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = ($26|0)==(0|0);
    if (!($27)) {
     $28 = ((($2)) + 124|0);
     $29 = HEAP32[$28>>2]|0;
     $30 = (__ZNK3osg12BufferObject25getOrCreateGLBufferObjectEj($26,$29)|0);
     $31 = ($30|0)==(0|0);
     if (!($31)) {
      $32 = ((($30)) + 36|0);
      $33 = HEAP8[$32>>0]|0;
      $34 = ($33<<24>>24)==(0);
      if ($34) {
       $35 = ((($0)) + 96|0);
       $36 = HEAP32[$35>>2]|0;
       $37 = ($36|0)==($30|0);
       if (!($37)) {
        $38 = ((($30)) + 72|0);
        $39 = HEAP32[$38>>2]|0;
        $40 = ((($39)) + 724|0);
        $41 = HEAP32[$40>>2]|0;
        $42 = ((($30)) + 20|0);
        $43 = HEAP32[$42>>2]|0;
        $44 = ((($30)) + 16|0);
        $45 = HEAP32[$44>>2]|0;
        FUNCTION_TABLE_vii[$41 & 8191]($43,$45);
        $46 = ((($30)) + 56|0);
        $47 = HEAP32[$46>>2]|0;
        $48 = ($47|0)==(0|0);
        if ($48) {
         $$pre$phi$iZ2D = $35;
         label = 15;
        } else {
         __ZN3osg17GLBufferObjectSet10moveToBackEPNS_14GLBufferObjectE($47,$30);
         $$pre$phi$iZ2D = $35;
         label = 15;
        }
       }
      } else {
       __ZN3osg14GLBufferObject13compileBufferEv($30);
       $$pre$i = ((($0)) + 96|0);
       $$pre$phi$iZ2D = $$pre$i;
       label = 15;
      }
      if ((label|0) == 15) {
       HEAP32[$$pre$phi$iZ2D>>2] = $30;
      }
      $49 = HEAP32[$4>>2]|0;
      $50 = HEAP32[$49>>2]|0;
      $51 = ((($50)) + 16|0);
      $52 = HEAP32[$51>>2]|0;
      FUNCTION_TABLE_viiii[$52 & 8191]($49,$2,$3,$30);
      break;
     }
    }
   }
   $53 = ((($0)) + 96|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = ($54|0)==(0|0);
   if (!($55)) {
    $56 = ((($0)) + 16|0);
    $57 = HEAP32[$56>>2]|0;
    $58 = ((($57)) + 724|0);
    $59 = HEAP32[$58>>2]|0;
    FUNCTION_TABLE_vii[$59 & 8191](34962,0);
    HEAP32[$53>>2] = 0;
   }
   $60 = HEAP32[$4>>2]|0;
   $61 = HEAP32[$60>>2]|0;
   $62 = ((($61)) + 12|0);
   $63 = HEAP32[$62>>2]|0;
   FUNCTION_TABLE_viii[$63 & 8191]($60,$2,$3);
  } else {
   $64 = ($20|0)==($3|0);
   if ($64) {
    $65 = ((($3)) + 32|0);
    $66 = HEAP32[$65>>2]|0;
    $67 = ((($18)) + 16|0);
    $68 = HEAP32[$67>>2]|0;
    $69 = ($66|0)==($68|0);
    if ($69) {
     break;
    }
   }
   $70 = ((($0)) + 20|0);
   $71 = HEAP8[$70>>0]|0;
   $72 = ($71<<24>>24)==(0);
   if (!($72)) {
    $73 = ((($3)) + 40|0);
    $74 = HEAP32[$73>>2]|0;
    $75 = ($74|0)==(0|0);
    if (!($75)) {
     $76 = ((($2)) + 124|0);
     $77 = HEAP32[$76>>2]|0;
     $78 = (__ZNK3osg12BufferObject25getOrCreateGLBufferObjectEj($74,$77)|0);
     $79 = ($78|0)==(0|0);
     if (!($79)) {
      $80 = ((($78)) + 36|0);
      $81 = HEAP8[$80>>0]|0;
      $82 = ($81<<24>>24)==(0);
      if ($82) {
       $83 = ((($0)) + 96|0);
       $84 = HEAP32[$83>>2]|0;
       $85 = ($84|0)==($78|0);
       if (!($85)) {
        $86 = ((($78)) + 72|0);
        $87 = HEAP32[$86>>2]|0;
        $88 = ((($87)) + 724|0);
        $89 = HEAP32[$88>>2]|0;
        $90 = ((($78)) + 20|0);
        $91 = HEAP32[$90>>2]|0;
        $92 = ((($78)) + 16|0);
        $93 = HEAP32[$92>>2]|0;
        FUNCTION_TABLE_vii[$89 & 8191]($91,$93);
        $94 = ((($78)) + 56|0);
        $95 = HEAP32[$94>>2]|0;
        $96 = ($95|0)==(0|0);
        if ($96) {
         $$pre$phi$i31Z2D = $83;
         label = 30;
        } else {
         __ZN3osg17GLBufferObjectSet10moveToBackEPNS_14GLBufferObjectE($95,$78);
         $$pre$phi$i31Z2D = $83;
         label = 30;
        }
       }
      } else {
       __ZN3osg14GLBufferObject13compileBufferEv($78);
       $$pre$i30 = ((($0)) + 96|0);
       $$pre$phi$i31Z2D = $$pre$i30;
       label = 30;
      }
      if ((label|0) == 30) {
       HEAP32[$$pre$phi$i31Z2D>>2] = $78;
      }
      $97 = HEAP32[$4>>2]|0;
      $98 = HEAP32[$97>>2]|0;
      $99 = ((($98)) + 28|0);
      $100 = HEAP32[$99>>2]|0;
      FUNCTION_TABLE_viiii[$100 & 8191]($97,$2,$3,$78);
      break;
     }
    }
   }
   $101 = ((($0)) + 96|0);
   $102 = HEAP32[$101>>2]|0;
   $103 = ($102|0)==(0|0);
   if (!($103)) {
    $104 = ((($0)) + 16|0);
    $105 = HEAP32[$104>>2]|0;
    $106 = ((($105)) + 724|0);
    $107 = HEAP32[$106>>2]|0;
    FUNCTION_TABLE_vii[$107 & 8191](34962,0);
    HEAP32[$101>>2] = 0;
   }
   $108 = HEAP32[$4>>2]|0;
   $109 = HEAP32[$108>>2]|0;
   $110 = ((($109)) + 24|0);
   $111 = HEAP32[$110>>2]|0;
   FUNCTION_TABLE_viii[$111 & 8191]($108,$2,$3);
  }
 } while(0);
 $112 = HEAP32[$4>>2]|0;
 $113 = ((($112)) + 12|0);
 HEAP32[$113>>2] = $3;
 $114 = ((($3)) + 32|0);
 $115 = HEAP32[$114>>2]|0;
 $116 = ((($112)) + 16|0);
 HEAP32[$116>>2] = $115;
 STACKTOP = sp;return;
}
function __ZNSt3__26vectorIPN3osg16VertexArrayState13ArrayDispatchENS_9allocatorIS4_EEE21__push_back_slow_pathIKS4_EEvRT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(1073741823);
 if ($8) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $9 = ((($0)) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) - ($4))|0;
 $12 = $11 >> 2;
 $13 = ($12>>>0)<(536870911);
 $14 = $11 >> 1;
 $15 = ($14>>>0)<($7>>>0);
 $$sroa$speculated$i = $15 ? $7 : $14;
 $$sroa$speculated$$i = $13 ? $$sroa$speculated$i : 1073741823;
 $16 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($16) {
   $26 = 0;
  } else {
   $17 = ($$sroa$speculated$$i>>>0)>(1073741823);
   if (!($17)) {
    $23 = $$sroa$speculated$$i << 2;
    $24 = (__Znwj($23)|0);
    $26 = $24;
    break;
   }
   $18 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($18|0),(204840|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if ($20) {
    $21 = ___cxa_find_matching_catch_2()|0;
    $22 = tempRet0;
    ___cxa_free_exception(($18|0));
    ___resumeException($21|0);
    // unreachable;
   } else {
    HEAP32[$18>>2] = (99824);
    ___cxa_throw(($18|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $25 = (($26) + ($6<<2)|0);
 $27 = (($26) + ($$sroa$speculated$$i<<2)|0);
 $28 = $27;
 $29 = HEAP32[$1>>2]|0;
 HEAP32[$25>>2] = $29;
 $30 = ((($25)) + 4|0);
 $31 = $30;
 $32 = (0 - ($6))|0;
 $33 = (($25) + ($32<<2)|0);
 $34 = $33;
 $35 = ($5|0)>(0);
 if ($35) {
  $36 = $4;
  _memcpy(($33|0),($36|0),($5|0))|0;
 }
 HEAP32[$0>>2] = $34;
 HEAP32[$2>>2] = $31;
 HEAP32[$9>>2] = $28;
 $37 = ($4|0)==(0);
 if ($37) {
  return;
 }
 $38 = $4;
 __ZdlPv($38);
 return;
}
function __ZN3osg16VertexArrayState5dirtyEv($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 104|0);
 HEAP8[$1>>0] = 1;
 return;
}
function __ZN3osg4View4takeERS0_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$012 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 8|0);
 HEAP32[$4>>2] = $3;
 $5 = ((($0)) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($1)) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6|0)==($8|0);
 if (!($9)) {
  HEAP32[$5>>2] = $8;
  $10 = ($8|0)==(0|0);
  if (!($10)) {
   $11 = ((($8)) + 8|0);
   $12 = HEAP32[$11>>2]|0;HEAP32[$11>>2] = (($12+1)|0);
  }
  $13 = ($6|0)==(0|0);
  if (!($13)) {
   $14 = ((($6)) + 8|0);
   $15 = HEAP32[$14>>2]|0;HEAP32[$14>>2] = (($15-1)|0);
   $16 = ($15|0)==(1);
   if ($16) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($6,1,1);
   }
  }
 }
 $17 = ((($0)) + 16|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ((($1)) + 16|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($18|0)==($20|0);
 if (!($21)) {
  HEAP32[$17>>2] = $20;
  $22 = ($20|0)==(0|0);
  if (!($22)) {
   $23 = ((($20)) + 8|0);
   $24 = HEAP32[$23>>2]|0;HEAP32[$23>>2] = (($24+1)|0);
  }
  $25 = ($18|0)==(0|0);
  if (!($25)) {
   $26 = ((($18)) + 8|0);
   $27 = HEAP32[$26>>2]|0;HEAP32[$26>>2] = (($27-1)|0);
   $28 = ($27|0)==(1);
   if ($28) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($18,1,1);
   }
  }
 }
 $29 = ((($1)) + 20|0);
 $30 = ((($0)) + 20|0);
 $31 = ($0|0)==($1|0);
 if (!($31)) {
  $32 = HEAP32[$29>>2]|0;
  $33 = ((($1)) + 24|0);
  $34 = HEAP32[$33>>2]|0;
  __ZNSt3__26vectorIN3osg4View5SlaveENS_9allocatorIS3_EEE6assignIPS3_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS3_NS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_($30,$32,$34);
 }
 $35 = HEAP32[$17>>2]|0;
 $36 = ($35|0)==(0|0);
 if (!($36)) {
  $37 = ((($35)) + 220|0);
  HEAP32[$37>>2] = $0;
 }
 $38 = ((($0)) + 24|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = HEAP32[$30>>2]|0;
 $41 = ($39|0)==($40|0);
 $42 = $40;
 if (!($41)) {
  $43 = (($39) - ($40))|0;
  $44 = (($43|0) / 272)&-1;
  $$012 = 0;
  while(1) {
   $66 = (((($42) + (($$012*272)|0)|0)) + 4|0);
   $67 = HEAP32[$66>>2]|0;
   $68 = ($67|0)==(0|0);
   if (!($68)) {
    $69 = ((($67)) + 220|0);
    HEAP32[$69>>2] = $0;
   }
   $70 = (($$012) + 1)|0;
   $71 = ($70>>>0)<($44>>>0);
   if ($71) {
    $$012 = $70;
   } else {
    break;
   }
  }
 }
 $45 = HEAP32[$7>>2]|0;
 $46 = ($45|0)==(0|0);
 if (!($46)) {
  HEAP32[$7>>2] = 0;
  $47 = ((($45)) + 8|0);
  $48 = HEAP32[$47>>2]|0;HEAP32[$47>>2] = (($48-1)|0);
  $49 = ($48|0)==(1);
  if ($49) {
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($45,1,1);
  }
 }
 $50 = HEAP32[$19>>2]|0;
 $51 = ($50|0)==(0|0);
 if (!($51)) {
  HEAP32[$19>>2] = 0;
  $52 = ((($50)) + 8|0);
  $53 = HEAP32[$52>>2]|0;HEAP32[$52>>2] = (($53-1)|0);
  $54 = ($53|0)==(1);
  if ($54) {
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($50,1,1);
  }
 }
 $55 = HEAP32[$29>>2]|0;
 $56 = ((($1)) + 24|0);
 while(1) {
  $57 = HEAP32[$56>>2]|0;
  $58 = ($57|0)==($55|0);
  if ($58) {
   label = 29;
   break;
  }
  $59 = ((($57)) + -272|0);
  HEAP32[$56>>2] = $59;
  $60 = HEAP32[$59>>2]|0;
  $61 = HEAP32[$60>>2]|0;
  __THREW__ = 0;
  invoke_vi($61|0,($59|0));
  $62 = __THREW__; __THREW__ = 0;
  $63 = $62&1;
  if ($63) {
   label = 28;
   break;
  }
 }
 if ((label|0) == 28) {
  $64 = ___cxa_find_matching_catch_2()|0;
  $65 = tempRet0;
  ___cxa_call_unexpected(($64|0));
  // unreachable;
 }
 else if ((label|0) == 29) {
  return;
 }
}
function __ZN3osg4ViewD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vii(3294,($0|0),(70136|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  $3 = ((($0)) + 36|0);
  __ZN3osg6ObjectD2Ev($3);
  return;
 }
 $4 = ___cxa_find_matching_catch_2()|0;
 $5 = tempRet0;
 $6 = ((($0)) + 36|0);
 __THREW__ = 0;
 invoke_vi(388,($6|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch_3(0|0)|0;
  $10 = tempRet0;
  ___clang_call_terminate($9);
  // unreachable;
 } else {
  ___resumeException($4|0);
  // unreachable;
 }
}
function __ZN3osg4ViewD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vii(3294,($0|0),(70136|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $6 = ___cxa_find_matching_catch_2()|0;
  $7 = tempRet0;
  $8 = ((($0)) + 36|0);
  __THREW__ = 0;
  invoke_vi(388,($8|0));
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if ($10) {
   $11 = ___cxa_find_matching_catch_3(0|0)|0;
   $12 = tempRet0;
   ___clang_call_terminate($11);
   // unreachable;
  } else {
   $eh$lpad$body$index2Z2D = $7;$eh$lpad$body$indexZ2D = $6;
   __ZdlPv($0);
   ___resumeException($eh$lpad$body$indexZ2D|0);
   // unreachable;
  }
 }
 $3 = ((($0)) + 36|0);
 __THREW__ = 0;
 invoke_vi(388,($3|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  __ZdlPv($0);
  return;
 }
 $13 = ___cxa_find_matching_catch_2()|0;
 $14 = tempRet0;
 $eh$lpad$body$index2Z2D = $14;$eh$lpad$body$indexZ2D = $13;
 __ZdlPv($0);
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
}
function __ZTv0_n16_N3osg4ViewD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __THREW__ = 0;
 invoke_vii(3294,($4|0),(70136|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if (!($6)) {
  $14 = ((($4)) + 36|0);
  __ZN3osg6ObjectD2Ev($14);
  return;
 }
 $7 = ___cxa_find_matching_catch_2()|0;
 $8 = tempRet0;
 $9 = ((($4)) + 36|0);
 __THREW__ = 0;
 invoke_vi(388,($9|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if ($11) {
  $12 = ___cxa_find_matching_catch_3(0|0)|0;
  $13 = tempRet0;
  ___clang_call_terminate($12);
  // unreachable;
 } else {
  ___resumeException($7|0);
  // unreachable;
 }
}
function __ZTv0_n16_N3osg4ViewD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$i$index2Z2D = 0, $eh$lpad$body$i$indexZ2D = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __THREW__ = 0;
 invoke_vii(3294,($4|0),(70136|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $10 = ___cxa_find_matching_catch_2()|0;
  $11 = tempRet0;
  $12 = ((($4)) + 36|0);
  __THREW__ = 0;
  invoke_vi(388,($12|0));
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if ($14) {
   $15 = ___cxa_find_matching_catch_3(0|0)|0;
   $16 = tempRet0;
   ___clang_call_terminate($15);
   // unreachable;
  } else {
   $eh$lpad$body$i$index2Z2D = $11;$eh$lpad$body$i$indexZ2D = $10;
   __ZdlPv($4);
   ___resumeException($eh$lpad$body$i$indexZ2D|0);
   // unreachable;
  }
 }
 $7 = ((($4)) + 36|0);
 __THREW__ = 0;
 invoke_vi(388,($7|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if (!($9)) {
  __ZdlPv($4);
  return;
 }
 $17 = ___cxa_find_matching_catch_2()|0;
 $18 = tempRet0;
 $eh$lpad$body$i$index2Z2D = $18;$eh$lpad$body$i$indexZ2D = $17;
 __ZdlPv($4);
 ___resumeException($eh$lpad$body$i$indexZ2D|0);
 // unreachable;
}
function __ZN3osg4ViewD2Ev($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$1 = 0, $$18 = 0, $$3 = 0, $$310 = 0, $$4 = 0, $$411 = 0, $$cast = 0, $$pre = 0, $$pre$phiZ2D = 0, $$sink56$index = 0, $$sink56$index4 = 0, $$sroa$051$058 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0;
 var $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0;
 var $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0;
 var $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0;
 var $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0;
 var $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0;
 var $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp + 4|0;
 $3 = sp;
 $4 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $4;
 $5 = ((($1)) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $$cast = $4;
 $7 = ((($$cast)) + -12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($0) + ($8)|0);
 HEAP32[$9>>2] = $6;
 __THREW__ = 0;
 $10 = (invoke_ii(3265,4)|0);
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 L1: do {
  if ($12) {
   label = 14;
  } else {
   do {
    if ($10) {
     __THREW__ = 0;
     $13 = (invoke_ii(3266,4)|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      label = 14;
      break L1;
     }
     __THREW__ = 0;
     $16 = (invoke_iiii(3267,($13|0),(158967|0),21)|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      label = 14;
      break L1;
     }
     $19 = HEAP32[$16>>2]|0;
     $20 = ((($19)) + -12|0);
     $21 = HEAP32[$20>>2]|0;
     $22 = (($16) + ($21)|0);
     __THREW__ = 0;
     invoke_vii(3257,($3|0),($22|0));
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      label = 14;
      break L1;
     }
     __THREW__ = 0;
     $25 = (invoke_iii(3255,($3|0),(215188|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if (!($27)) {
      $28 = HEAP32[$25>>2]|0;
      $29 = ((($28)) + 28|0);
      $30 = HEAP32[$29>>2]|0;
      __THREW__ = 0;
      $31 = (invoke_iii($30|0,($25|0),10)|0);
      $32 = __THREW__; __THREW__ = 0;
      $33 = $32&1;
      if (!($33)) {
       __THREW__ = 0;
       invoke_vi(3263,($3|0));
       $34 = __THREW__; __THREW__ = 0;
       $35 = $34&1;
       if ($35) {
        label = 14;
        break L1;
       }
       __THREW__ = 0;
       (invoke_iii(3268,($16|0),($31|0))|0);
       $42 = __THREW__; __THREW__ = 0;
       $43 = $42&1;
       if ($43) {
        label = 14;
        break L1;
       }
       __THREW__ = 0;
       (invoke_ii(3269,($16|0))|0);
       $44 = __THREW__; __THREW__ = 0;
       $45 = $44&1;
       if ($45) {
        label = 14;
        break L1;
       } else {
        break;
       }
      }
     }
     $36 = ___cxa_find_matching_catch_2()|0;
     $37 = tempRet0;
     __THREW__ = 0;
     invoke_vi(3263,($3|0));
     $38 = __THREW__; __THREW__ = 0;
     $39 = $38&1;
     if ($39) {
      $40 = ___cxa_find_matching_catch_3(0|0)|0;
      $41 = tempRet0;
      ___clang_call_terminate($40);
      // unreachable;
     } else {
      $$sink56$index = $36;$$sink56$index4 = $37;
      label = 67;
      break L1;
     }
    }
   } while(0);
   $48 = ((($0)) + 16|0);
   $49 = HEAP32[$48>>2]|0;
   $50 = ($49|0)==(0|0);
   if (!($50)) {
    $51 = ((($49)) + 220|0);
    HEAP32[$51>>2] = 0;
    $52 = ((($49)) + 100|0);
    $53 = HEAP32[$52>>2]|0;
    $54 = ($53|0)==(0|0);
    if (!($54)) {
     HEAP32[$52>>2] = 0;
     $55 = HEAP32[$53>>2]|0;
     $56 = ((($55)) + -12|0);
     $57 = HEAP32[$56>>2]|0;
     $58 = (($53) + ($57)|0);
     $59 = ((($58)) + 8|0);
     $60 = HEAP32[$59>>2]|0;HEAP32[$59>>2] = (($60-1)|0);
     $61 = ($60|0)==(1);
     if ($61) {
      __THREW__ = 0;
      invoke_viii(3262,($58|0),1,1);
      $62 = __THREW__; __THREW__ = 0;
      $63 = $62&1;
      if ($63) {
       label = 14;
       break;
      }
     }
    }
   }
   $64 = ((($0)) + 20|0);
   $65 = HEAP32[$64>>2]|0;
   $66 = ((($0)) + 24|0);
   $67 = HEAP32[$66>>2]|0;
   $68 = ($65|0)==($67|0);
   L23: do {
    if (!($68)) {
     $$sroa$051$058 = $65;
     while(1) {
      $76 = ((($$sroa$051$058)) + 4|0);
      $77 = HEAP32[$76>>2]|0;
      $78 = ((($77)) + 220|0);
      HEAP32[$78>>2] = 0;
      $79 = ((($77)) + 100|0);
      $80 = HEAP32[$79>>2]|0;
      $81 = ($80|0)==(0|0);
      if (!($81)) {
       HEAP32[$79>>2] = 0;
       $82 = HEAP32[$80>>2]|0;
       $83 = ((($82)) + -12|0);
       $84 = HEAP32[$83>>2]|0;
       $85 = (($80) + ($84)|0);
       $86 = ((($85)) + 8|0);
       $87 = HEAP32[$86>>2]|0;HEAP32[$86>>2] = (($87-1)|0);
       $88 = ($87|0)==(1);
       if ($88) {
        __THREW__ = 0;
        invoke_viii(3262,($85|0),1,1);
        $89 = __THREW__; __THREW__ = 0;
        $90 = $89&1;
        if ($90) {
         break;
        }
       }
      }
      $91 = ((($$sroa$051$058)) + 272|0);
      $92 = HEAP32[$66>>2]|0;
      $93 = ($91|0)==($92|0);
      if ($93) {
       break L23;
      } else {
       $$sroa$051$058 = $91;
      }
     }
     $94 = ___cxa_find_matching_catch_2()|0;
     $95 = tempRet0;
     $$sink56$index = $94;$$sink56$index4 = $95;
     label = 67;
     break L1;
    }
   } while(0);
   $69 = HEAP32[$48>>2]|0;
   $70 = ($69|0)==(0|0);
   if (!($70)) {
    HEAP32[$48>>2] = 0;
    $71 = ((($69)) + 8|0);
    $72 = HEAP32[$71>>2]|0;HEAP32[$71>>2] = (($72-1)|0);
    $73 = ($72|0)==(1);
    if ($73) {
     __THREW__ = 0;
     invoke_viii(3262,($69|0),1,1);
     $74 = __THREW__; __THREW__ = 0;
     $75 = $74&1;
     if ($75) {
      label = 14;
      break;
     }
    }
   }
   $96 = HEAP32[$64>>2]|0;
   while(1) {
    $97 = HEAP32[$66>>2]|0;
    $98 = ($97|0)==($96|0);
    if ($98) {
     break;
    }
    $99 = ((($97)) + -272|0);
    HEAP32[$66>>2] = $99;
    $100 = HEAP32[$99>>2]|0;
    $101 = HEAP32[$100>>2]|0;
    __THREW__ = 0;
    invoke_vi($101|0,($99|0));
    $102 = __THREW__; __THREW__ = 0;
    $103 = $102&1;
    if ($103) {
     label = 31;
     break;
    }
   }
   if ((label|0) == 31) {
    $104 = ___cxa_find_matching_catch_2()|0;
    $105 = tempRet0;
    ___cxa_call_unexpected(($104|0));
    // unreachable;
   }
   $106 = ((($0)) + 12|0);
   $107 = HEAP32[$106>>2]|0;
   $108 = ($107|0)==(0|0);
   if (!($108)) {
    HEAP32[$106>>2] = 0;
    $109 = ((($107)) + 8|0);
    $110 = HEAP32[$109>>2]|0;HEAP32[$109>>2] = (($110-1)|0);
    $111 = ($110|0)==(1);
    if ($111) {
     __THREW__ = 0;
     invoke_viii(3262,($107|0),1,1);
     $112 = __THREW__; __THREW__ = 0;
     $113 = $112&1;
     if ($113) {
      label = 14;
      break;
     }
    }
   }
   __THREW__ = 0;
   $114 = (invoke_ii(3265,4)|0);
   $115 = __THREW__; __THREW__ = 0;
   $116 = $115&1;
   if ($116) {
    label = 14;
   } else {
    do {
     if ($114) {
      __THREW__ = 0;
      $117 = (invoke_ii(3266,4)|0);
      $118 = __THREW__; __THREW__ = 0;
      $119 = $118&1;
      if ($119) {
       label = 14;
       break L1;
      }
      __THREW__ = 0;
      $120 = (invoke_iiii(3267,($117|0),(158989|0),26)|0);
      $121 = __THREW__; __THREW__ = 0;
      $122 = $121&1;
      if ($122) {
       label = 14;
       break L1;
      }
      $123 = HEAP32[$120>>2]|0;
      $124 = ((($123)) + -12|0);
      $125 = HEAP32[$124>>2]|0;
      $126 = (($120) + ($125)|0);
      __THREW__ = 0;
      invoke_vii(3257,($2|0),($126|0));
      $127 = __THREW__; __THREW__ = 0;
      $128 = $127&1;
      if ($128) {
       label = 14;
       break L1;
      }
      __THREW__ = 0;
      $129 = (invoke_iii(3255,($2|0),(215188|0))|0);
      $130 = __THREW__; __THREW__ = 0;
      $131 = $130&1;
      if (!($131)) {
       $132 = HEAP32[$129>>2]|0;
       $133 = ((($132)) + 28|0);
       $134 = HEAP32[$133>>2]|0;
       __THREW__ = 0;
       $135 = (invoke_iii($134|0,($129|0),10)|0);
       $136 = __THREW__; __THREW__ = 0;
       $137 = $136&1;
       if (!($137)) {
        __THREW__ = 0;
        invoke_vi(3263,($2|0));
        $138 = __THREW__; __THREW__ = 0;
        $139 = $138&1;
        if ($139) {
         label = 14;
         break L1;
        }
        __THREW__ = 0;
        (invoke_iii(3268,($120|0),($135|0))|0);
        $146 = __THREW__; __THREW__ = 0;
        $147 = $146&1;
        if ($147) {
         label = 14;
         break L1;
        }
        __THREW__ = 0;
        (invoke_ii(3269,($120|0))|0);
        $148 = __THREW__; __THREW__ = 0;
        $149 = $148&1;
        if ($149) {
         label = 14;
         break L1;
        } else {
         break;
        }
       }
      }
      $140 = ___cxa_find_matching_catch_2()|0;
      $141 = tempRet0;
      __THREW__ = 0;
      invoke_vi(3263,($2|0));
      $142 = __THREW__; __THREW__ = 0;
      $143 = $142&1;
      if ($143) {
       $144 = ___cxa_find_matching_catch_3(0|0)|0;
       $145 = tempRet0;
       ___clang_call_terminate($144);
       // unreachable;
      } else {
       $$sink56$index = $140;$$sink56$index4 = $141;
       label = 67;
       break L1;
      }
     }
    } while(0);
    $150 = ((($0)) + 32|0);
    $151 = HEAP32[$150>>2]|0;
    $152 = ($151|0)==(0|0);
    if (!($152)) {
     $153 = ((($151)) + 8|0);
     $154 = HEAP32[$153>>2]|0;HEAP32[$153>>2] = (($154-1)|0);
     $155 = ($154|0)==(1);
     if ($155) {
      __THREW__ = 0;
      invoke_viii(3262,($151|0),1,1);
      $156 = __THREW__; __THREW__ = 0;
      $157 = $156&1;
      if ($157) {
       $190 = ___cxa_find_matching_catch_2()|0;
       $191 = tempRet0;
       $$1 = $190;$$18 = $191;
       label = 71;
       break;
      }
     }
    }
    HEAP32[$150>>2] = 0;
    $158 = HEAP32[$64>>2]|0;
    $159 = ($158|0)==(0|0);
    do {
     if (!($159)) {
      while(1) {
       $160 = HEAP32[$66>>2]|0;
       $161 = ($160|0)==($158|0);
       if ($161) {
        label = 55;
        break;
       }
       $162 = ((($160)) + -272|0);
       HEAP32[$66>>2] = $162;
       $163 = HEAP32[$162>>2]|0;
       $164 = HEAP32[$163>>2]|0;
       __THREW__ = 0;
       invoke_vi($164|0,($162|0));
       $165 = __THREW__; __THREW__ = 0;
       $166 = $165&1;
       if ($166) {
        label = 54;
        break;
       }
      }
      if ((label|0) == 54) {
       $167 = ___cxa_find_matching_catch_2()|0;
       $168 = tempRet0;
       ___cxa_call_unexpected(($167|0));
       // unreachable;
      }
      else if ((label|0) == 55) {
       $169 = HEAP32[$64>>2]|0;
       __ZdlPv($169);
       break;
      }
     }
    } while(0);
    $170 = HEAP32[$48>>2]|0;
    $171 = ($170|0)==(0|0);
    if (!($171)) {
     $172 = ((($170)) + 8|0);
     $173 = HEAP32[$172>>2]|0;HEAP32[$172>>2] = (($173-1)|0);
     $174 = ($173|0)==(1);
     if ($174) {
      __THREW__ = 0;
      invoke_viii(3262,($170|0),1,1);
      $175 = __THREW__; __THREW__ = 0;
      $176 = $175&1;
      if ($176) {
       $214 = ___cxa_find_matching_catch_2()|0;
       $215 = tempRet0;
       $$3 = $214;$$310 = $215;$$pre$phiZ2D = $106;
       label = 83;
       break;
      }
     }
    }
    HEAP32[$48>>2] = 0;
    $177 = HEAP32[$106>>2]|0;
    $178 = ($177|0)==(0|0);
    if (!($178)) {
     $179 = ((($177)) + 8|0);
     $180 = HEAP32[$179>>2]|0;HEAP32[$179>>2] = (($180-1)|0);
     $181 = ($180|0)==(1);
     if ($181) {
      __THREW__ = 0;
      invoke_viii(3262,($177|0),1,1);
      $182 = __THREW__; __THREW__ = 0;
      $183 = $182&1;
      if ($183) {
       $224 = ___cxa_find_matching_catch_2()|0;
       $225 = tempRet0;
       $$4 = $224;$$411 = $225;
       break;
      }
     }
    }
    HEAP32[$106>>2] = 0;
    $184 = ((($0)) + 4|0);
    $185 = HEAP32[$184>>2]|0;
    $186 = ($185|0)==(0|0);
    if ($186) {
     HEAP32[$184>>2] = 0;
     STACKTOP = sp;return;
    }
    $187 = ((($185)) + 8|0);
    $188 = HEAP32[$187>>2]|0;HEAP32[$187>>2] = (($188-1)|0);
    $189 = ($188|0)==(1);
    if (!($189)) {
     HEAP32[$184>>2] = 0;
     STACKTOP = sp;return;
    }
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($185,1,1);
    HEAP32[$184>>2] = 0;
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 14) {
  $46 = ___cxa_find_matching_catch_2()|0;
  $47 = tempRet0;
  $$sink56$index = $46;$$sink56$index4 = $47;
  label = 67;
 }
 if ((label|0) == 67) {
  $192 = ((($0)) + 32|0);
  $193 = HEAP32[$192>>2]|0;
  $194 = ($193|0)==(0|0);
  if (!($194)) {
   $195 = ((($193)) + 8|0);
   $196 = HEAP32[$195>>2]|0;HEAP32[$195>>2] = (($196-1)|0);
   $197 = ($196|0)==(1);
   if ($197) {
    __THREW__ = 0;
    invoke_viii(3262,($193|0),1,1);
    $198 = __THREW__; __THREW__ = 0;
    $199 = $198&1;
    if ($199) {
     $241 = ___cxa_find_matching_catch_3(0|0)|0;
     $242 = tempRet0;
     ___clang_call_terminate($241);
     // unreachable;
    }
   }
  }
  HEAP32[$192>>2] = 0;
  $$1 = $$sink56$index;$$18 = $$sink56$index4;
  label = 71;
 }
 if ((label|0) == 71) {
  $200 = ((($0)) + 20|0);
  $201 = HEAP32[$200>>2]|0;
  $202 = ($201|0)==(0|0);
  do {
   if (!($202)) {
    $203 = ((($0)) + 24|0);
    while(1) {
     $204 = HEAP32[$203>>2]|0;
     $205 = ($204|0)==($201|0);
     if ($205) {
      label = 76;
      break;
     }
     $206 = ((($204)) + -272|0);
     HEAP32[$203>>2] = $206;
     $207 = HEAP32[$206>>2]|0;
     $208 = HEAP32[$207>>2]|0;
     __THREW__ = 0;
     invoke_vi($208|0,($206|0));
     $209 = __THREW__; __THREW__ = 0;
     $210 = $209&1;
     if ($210) {
      label = 75;
      break;
     }
    }
    if ((label|0) == 75) {
     $211 = ___cxa_find_matching_catch_2()|0;
     $212 = tempRet0;
     ___cxa_call_unexpected(($211|0));
     // unreachable;
    }
    else if ((label|0) == 76) {
     $213 = HEAP32[$200>>2]|0;
     __ZdlPv($213);
     break;
    }
   }
  } while(0);
  $216 = ((($0)) + 16|0);
  $217 = HEAP32[$216>>2]|0;
  $218 = ($217|0)==(0|0);
  if (!($218)) {
   $219 = ((($217)) + 8|0);
   $220 = HEAP32[$219>>2]|0;HEAP32[$219>>2] = (($220-1)|0);
   $221 = ($220|0)==(1);
   if ($221) {
    __THREW__ = 0;
    invoke_viii(3262,($217|0),1,1);
    $222 = __THREW__; __THREW__ = 0;
    $223 = $222&1;
    if ($223) {
     $241 = ___cxa_find_matching_catch_3(0|0)|0;
     $242 = tempRet0;
     ___clang_call_terminate($241);
     // unreachable;
    }
   }
  }
  HEAP32[$216>>2] = 0;
  $$pre = ((($0)) + 12|0);
  $$3 = $$1;$$310 = $$18;$$pre$phiZ2D = $$pre;
  label = 83;
 }
 if ((label|0) == 83) {
  $226 = HEAP32[$$pre$phiZ2D>>2]|0;
  $227 = ($226|0)==(0|0);
  if (!($227)) {
   $228 = ((($226)) + 8|0);
   $229 = HEAP32[$228>>2]|0;HEAP32[$228>>2] = (($229-1)|0);
   $230 = ($229|0)==(1);
   if ($230) {
    __THREW__ = 0;
    invoke_viii(3262,($226|0),1,1);
    $231 = __THREW__; __THREW__ = 0;
    $232 = $231&1;
    if ($232) {
     $241 = ___cxa_find_matching_catch_3(0|0)|0;
     $242 = tempRet0;
     ___clang_call_terminate($241);
     // unreachable;
    }
   }
  }
  HEAP32[$$pre$phiZ2D>>2] = 0;
  $$4 = $$3;$$411 = $$310;
 }
 $233 = ((($0)) + 4|0);
 $234 = HEAP32[$233>>2]|0;
 $235 = ($234|0)==(0|0);
 if ($235) {
  HEAP32[$233>>2] = 0;
  ___resumeException($$4|0);
  // unreachable;
 }
 $236 = ((($234)) + 8|0);
 $237 = HEAP32[$236>>2]|0;HEAP32[$236>>2] = (($237-1)|0);
 $238 = ($237|0)==(1);
 if (!($238)) {
  HEAP32[$233>>2] = 0;
  ___resumeException($$4|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(3262,($234|0),1,1);
 $239 = __THREW__; __THREW__ = 0;
 $240 = $239&1;
 if ($240) {
  $241 = ___cxa_find_matching_catch_3(0|0)|0;
  $242 = tempRet0;
  ___clang_call_terminate($241);
  // unreachable;
 } else {
  HEAP32[$233>>2] = 0;
  ___resumeException($$4|0);
  // unreachable;
 }
}
function __ZNSt3__26vectorIN3osg4View5SlaveENS_9allocatorIS3_EEE6assignIPS3_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS3_NS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$ = 0, $$0$lcssa$i$i = 0, $$07$i$i = 0, $$07$i$i21 = 0, $$078$i$i = 0, $$09$i$i = 0, $$pre$i$i19 = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = $2;
 $4 = $1;
 $5 = (($3) - ($4))|0;
 $6 = (($5|0) / 272)&-1;
 $7 = ((($0)) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$0>>2]|0;
 $10 = (($8) - ($9))|0;
 $11 = (($10|0) / 272)&-1;
 $12 = ($6>>>0)>($11>>>0);
 $13 = $9;
 if (!($12)) {
  $14 = ((($0)) + 4|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (($15) - ($9))|0;
  $17 = (($16|0) / 272)&-1;
  $18 = ($6>>>0)>($17>>>0);
  $19 = (($1) + (($17*272)|0)|0);
  $$ = $18 ? $19 : $2;
  $20 = ($$|0)==($1|0);
  if ($20) {
   $$0$lcssa$i$i = $13;
  } else {
   $$078$i$i = $1;$$09$i$i = $13;
   while(1) {
    (__ZN3osg4View5SlaveaSERKS1_($$09$i$i,$$078$i$i)|0);
    $21 = ((($$078$i$i)) + 272|0);
    $22 = ((($$09$i$i)) + 272|0);
    $23 = ($21|0)==($$|0);
    if ($23) {
     $$0$lcssa$i$i = $22;
     break;
    } else {
     $$078$i$i = $21;$$09$i$i = $22;
    }
   }
  }
  if (!($18)) {
   while(1) {
    $30 = HEAP32[$14>>2]|0;
    $31 = ($30|0)==($$0$lcssa$i$i|0);
    if ($31) {
     label = 24;
     break;
    }
    $32 = ((($30)) + -272|0);
    HEAP32[$14>>2] = $32;
    $33 = HEAP32[$32>>2]|0;
    $34 = HEAP32[$33>>2]|0;
    __THREW__ = 0;
    invoke_vi($34|0,($32|0));
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     label = 10;
     break;
    }
   }
   if ((label|0) == 10) {
    $37 = ___cxa_find_matching_catch_2()|0;
    $38 = tempRet0;
    ___cxa_call_unexpected(($37|0));
    // unreachable;
   }
   else if ((label|0) == 24) {
    return;
   }
  }
  $24 = ($$|0)==($2|0);
  if ($24) {
   return;
  }
  $$pre$i$i19 = HEAP32[$14>>2]|0;
  $$07$i$i21 = $19;$25 = $$pre$i$i19;
  while(1) {
   __ZN3osg4View5SlaveC2ERKS1_($25,$$07$i$i21);
   $26 = ((($$07$i$i21)) + 272|0);
   $27 = HEAP32[$14>>2]|0;
   $28 = ((($27)) + 272|0);
   HEAP32[$14>>2] = $28;
   $29 = ($26|0)==($2|0);
   if ($29) {
    break;
   } else {
    $$07$i$i21 = $26;$25 = $28;
   }
  }
  return;
 }
 $39 = ($9|0)==(0);
 do {
  if ($39) {
   $53 = $8;
  } else {
   $40 = ((($0)) + 4|0);
   while(1) {
    $41 = HEAP32[$40>>2]|0;
    $42 = ($41|0)==($13|0);
    if ($42) {
     label = 16;
     break;
    }
    $43 = ((($41)) + -272|0);
    HEAP32[$40>>2] = $43;
    $44 = HEAP32[$43>>2]|0;
    $45 = HEAP32[$44>>2]|0;
    __THREW__ = 0;
    invoke_vi($45|0,($43|0));
    $46 = __THREW__; __THREW__ = 0;
    $47 = $46&1;
    if ($47) {
     label = 15;
     break;
    }
   }
   if ((label|0) == 15) {
    $48 = ___cxa_find_matching_catch_2()|0;
    $49 = tempRet0;
    ___cxa_call_unexpected(($48|0));
    // unreachable;
   }
   else if ((label|0) == 16) {
    $50 = HEAP32[$0>>2]|0;
    __ZdlPv($50);
    HEAP32[$7>>2] = 0;
    HEAP32[$40>>2] = 0;
    HEAP32[$0>>2] = 0;
    $53 = 0;
    break;
   }
  }
 } while(0);
 $51 = ($6>>>0)>(15790320);
 if ($51) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $52 = (($53|0) / 272)&-1;
 $54 = ($52>>>0)<(7895160);
 $55 = $52 << 1;
 $56 = ($55>>>0)<($6>>>0);
 $$sroa$speculated$i = $56 ? $6 : $55;
 $$sroa$speculated$$i = $54 ? $$sroa$speculated$i : 15790320;
 $57 = ($$sroa$speculated$$i>>>0)>(15790320);
 if ($57) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $58 = ($$sroa$speculated$$i*272)|0;
 $59 = (__Znwj($58)|0);
 $60 = ((($0)) + 4|0);
 HEAP32[$60>>2] = $59;
 HEAP32[$0>>2] = $59;
 $61 = (($59) + (($$sroa$speculated$$i*272)|0)|0);
 HEAP32[$7>>2] = $61;
 $62 = ($1|0)==($2|0);
 if ($62) {
  return;
 }
 $$07$i$i = $1;$63 = $59;
 while(1) {
  __ZN3osg4View5SlaveC2ERKS1_($63,$$07$i$i);
  $64 = ((($$07$i$i)) + 272|0);
  $65 = HEAP32[$60>>2]|0;
  $66 = ((($65)) + 272|0);
  HEAP32[$60>>2] = $66;
  $67 = ($64|0)==($2|0);
  if ($67) {
   break;
  } else {
   $$07$i$i = $64;$63 = $66;
  }
 }
 return;
}
function __ZN3osg4View5SlaveaSERKS1_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $100 = 0.0, $101 = 0, $102 = 0, $103 = 0.0, $104 = 0, $105 = 0, $106 = 0.0, $107 = 0, $108 = 0, $109 = 0.0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $14 = 0, $15 = 0;
 var $16 = 0.0, $17 = 0, $18 = 0, $19 = 0.0, $2 = 0, $20 = 0, $21 = 0, $22 = 0.0, $23 = 0, $24 = 0, $25 = 0.0, $26 = 0, $27 = 0, $28 = 0.0, $29 = 0, $3 = 0, $30 = 0, $31 = 0.0, $32 = 0, $33 = 0;
 var $34 = 0.0, $35 = 0, $36 = 0, $37 = 0.0, $38 = 0, $39 = 0, $4 = 0, $40 = 0.0, $41 = 0, $42 = 0, $43 = 0.0, $44 = 0, $45 = 0, $46 = 0.0, $47 = 0, $48 = 0, $49 = 0.0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0.0, $53 = 0, $54 = 0, $55 = 0.0, $56 = 0, $57 = 0, $58 = 0.0, $59 = 0, $6 = 0, $60 = 0, $61 = 0.0, $62 = 0, $63 = 0, $64 = 0.0, $65 = 0, $66 = 0, $67 = 0.0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0.0, $71 = 0, $72 = 0, $73 = 0.0, $74 = 0, $75 = 0, $76 = 0.0, $77 = 0, $78 = 0, $79 = 0.0, $8 = 0, $80 = 0, $81 = 0, $82 = 0.0, $83 = 0, $84 = 0, $85 = 0.0, $86 = 0, $87 = 0, $88 = 0.0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0.0, $92 = 0, $93 = 0, $94 = 0.0, $95 = 0, $96 = 0, $97 = 0.0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if (!($6)) {
  HEAP32[$2>>2] = $5;
  $7 = ($5|0)==(0|0);
  if (!($7)) {
   $8 = ((($5)) + 8|0);
   $9 = HEAP32[$8>>2]|0;HEAP32[$8>>2] = (($9+1)|0);
  }
  $10 = ($3|0)==(0|0);
  if (!($10)) {
   $11 = ((($3)) + 8|0);
   $12 = HEAP32[$11>>2]|0;HEAP32[$11>>2] = (($12-1)|0);
   $13 = ($12|0)==(1);
   if ($13) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($3,1,1);
   }
  }
 }
 $14 = ($1|0)==($0|0);
 if (!($14)) {
  $15 = ((($1)) + 8|0);
  $16 = +HEAPF64[$15>>3];
  $17 = ((($0)) + 8|0);
  HEAPF64[$17>>3] = $16;
  $18 = ((($1)) + 16|0);
  $19 = +HEAPF64[$18>>3];
  $20 = ((($0)) + 16|0);
  HEAPF64[$20>>3] = $19;
  $21 = ((($1)) + 24|0);
  $22 = +HEAPF64[$21>>3];
  $23 = ((($0)) + 24|0);
  HEAPF64[$23>>3] = $22;
  $24 = ((($1)) + 32|0);
  $25 = +HEAPF64[$24>>3];
  $26 = ((($0)) + 32|0);
  HEAPF64[$26>>3] = $25;
  $27 = ((($1)) + 40|0);
  $28 = +HEAPF64[$27>>3];
  $29 = ((($0)) + 40|0);
  HEAPF64[$29>>3] = $28;
  $30 = ((($1)) + 48|0);
  $31 = +HEAPF64[$30>>3];
  $32 = ((($0)) + 48|0);
  HEAPF64[$32>>3] = $31;
  $33 = ((($1)) + 56|0);
  $34 = +HEAPF64[$33>>3];
  $35 = ((($0)) + 56|0);
  HEAPF64[$35>>3] = $34;
  $36 = ((($1)) + 64|0);
  $37 = +HEAPF64[$36>>3];
  $38 = ((($0)) + 64|0);
  HEAPF64[$38>>3] = $37;
  $39 = ((($1)) + 72|0);
  $40 = +HEAPF64[$39>>3];
  $41 = ((($0)) + 72|0);
  HEAPF64[$41>>3] = $40;
  $42 = ((($1)) + 80|0);
  $43 = +HEAPF64[$42>>3];
  $44 = ((($0)) + 80|0);
  HEAPF64[$44>>3] = $43;
  $45 = ((($1)) + 88|0);
  $46 = +HEAPF64[$45>>3];
  $47 = ((($0)) + 88|0);
  HEAPF64[$47>>3] = $46;
  $48 = ((($1)) + 96|0);
  $49 = +HEAPF64[$48>>3];
  $50 = ((($0)) + 96|0);
  HEAPF64[$50>>3] = $49;
  $51 = ((($1)) + 104|0);
  $52 = +HEAPF64[$51>>3];
  $53 = ((($0)) + 104|0);
  HEAPF64[$53>>3] = $52;
  $54 = ((($1)) + 112|0);
  $55 = +HEAPF64[$54>>3];
  $56 = ((($0)) + 112|0);
  HEAPF64[$56>>3] = $55;
  $57 = ((($1)) + 120|0);
  $58 = +HEAPF64[$57>>3];
  $59 = ((($0)) + 120|0);
  HEAPF64[$59>>3] = $58;
  $60 = ((($1)) + 128|0);
  $61 = +HEAPF64[$60>>3];
  $62 = ((($0)) + 128|0);
  HEAPF64[$62>>3] = $61;
  $63 = ((($1)) + 136|0);
  $64 = +HEAPF64[$63>>3];
  $65 = ((($0)) + 136|0);
  HEAPF64[$65>>3] = $64;
  $66 = ((($1)) + 144|0);
  $67 = +HEAPF64[$66>>3];
  $68 = ((($0)) + 144|0);
  HEAPF64[$68>>3] = $67;
  $69 = ((($1)) + 152|0);
  $70 = +HEAPF64[$69>>3];
  $71 = ((($0)) + 152|0);
  HEAPF64[$71>>3] = $70;
  $72 = ((($1)) + 160|0);
  $73 = +HEAPF64[$72>>3];
  $74 = ((($0)) + 160|0);
  HEAPF64[$74>>3] = $73;
  $75 = ((($1)) + 168|0);
  $76 = +HEAPF64[$75>>3];
  $77 = ((($0)) + 168|0);
  HEAPF64[$77>>3] = $76;
  $78 = ((($1)) + 176|0);
  $79 = +HEAPF64[$78>>3];
  $80 = ((($0)) + 176|0);
  HEAPF64[$80>>3] = $79;
  $81 = ((($1)) + 184|0);
  $82 = +HEAPF64[$81>>3];
  $83 = ((($0)) + 184|0);
  HEAPF64[$83>>3] = $82;
  $84 = ((($1)) + 192|0);
  $85 = +HEAPF64[$84>>3];
  $86 = ((($0)) + 192|0);
  HEAPF64[$86>>3] = $85;
  $87 = ((($1)) + 200|0);
  $88 = +HEAPF64[$87>>3];
  $89 = ((($0)) + 200|0);
  HEAPF64[$89>>3] = $88;
  $90 = ((($1)) + 208|0);
  $91 = +HEAPF64[$90>>3];
  $92 = ((($0)) + 208|0);
  HEAPF64[$92>>3] = $91;
  $93 = ((($1)) + 216|0);
  $94 = +HEAPF64[$93>>3];
  $95 = ((($0)) + 216|0);
  HEAPF64[$95>>3] = $94;
  $96 = ((($1)) + 224|0);
  $97 = +HEAPF64[$96>>3];
  $98 = ((($0)) + 224|0);
  HEAPF64[$98>>3] = $97;
  $99 = ((($1)) + 232|0);
  $100 = +HEAPF64[$99>>3];
  $101 = ((($0)) + 232|0);
  HEAPF64[$101>>3] = $100;
  $102 = ((($1)) + 240|0);
  $103 = +HEAPF64[$102>>3];
  $104 = ((($0)) + 240|0);
  HEAPF64[$104>>3] = $103;
  $105 = ((($1)) + 248|0);
  $106 = +HEAPF64[$105>>3];
  $107 = ((($0)) + 248|0);
  HEAPF64[$107>>3] = $106;
  $108 = ((($1)) + 256|0);
  $109 = +HEAPF64[$108>>3];
  $110 = ((($0)) + 256|0);
  HEAPF64[$110>>3] = $109;
 }
 $111 = ((($1)) + 264|0);
 $112 = HEAP8[$111>>0]|0;
 $113 = ((($0)) + 264|0);
 HEAP8[$113>>0] = $112;
 $114 = ((($0)) + 268|0);
 $115 = HEAP32[$114>>2]|0;
 $116 = ((($1)) + 268|0);
 $117 = HEAP32[$116>>2]|0;
 $118 = ($115|0)==($117|0);
 if ($118) {
  return ($0|0);
 }
 HEAP32[$114>>2] = $117;
 $119 = ($117|0)==(0|0);
 if (!($119)) {
  $120 = HEAP32[$117>>2]|0;
  $121 = ((($120)) + -12|0);
  $122 = HEAP32[$121>>2]|0;
  $123 = (($117) + ($122)|0);
  $124 = ((($123)) + 8|0);
  $125 = HEAP32[$124>>2]|0;HEAP32[$124>>2] = (($125+1)|0);
 }
 $126 = ($115|0)==(0|0);
 if ($126) {
  return ($0|0);
 }
 $127 = HEAP32[$115>>2]|0;
 $128 = ((($127)) + -12|0);
 $129 = HEAP32[$128>>2]|0;
 $130 = (($115) + ($129)|0);
 $131 = ((($130)) + 8|0);
 $132 = HEAP32[$131>>2]|0;HEAP32[$131>>2] = (($132-1)|0);
 $133 = ($132|0)==(1);
 if (!($133)) {
  return ($0|0);
 }
 __ZNK3osg10Referenced24signalObserversAndDeleteEbb($130,1,1);
 return ($0|0);
}
function __ZN3osg4View5SlaveC2ERKS1_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0.0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $12 = 0.0;
 var $13 = 0, $14 = 0, $15 = 0.0, $16 = 0, $17 = 0, $18 = 0.0, $19 = 0, $2 = 0, $20 = 0, $21 = 0.0, $22 = 0, $23 = 0, $24 = 0.0, $25 = 0, $26 = 0, $27 = 0.0, $28 = 0, $29 = 0, $3 = 0, $30 = 0.0;
 var $31 = 0, $32 = 0, $33 = 0.0, $34 = 0, $35 = 0, $36 = 0.0, $37 = 0, $38 = 0, $39 = 0.0, $4 = 0, $40 = 0, $41 = 0, $42 = 0.0, $43 = 0, $44 = 0, $45 = 0.0, $46 = 0, $47 = 0, $48 = 0.0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0.0, $52 = 0, $53 = 0, $54 = 0.0, $55 = 0, $56 = 0, $57 = 0.0, $58 = 0, $59 = 0, $6 = 0, $60 = 0.0, $61 = 0, $62 = 0, $63 = 0.0, $64 = 0, $65 = 0, $66 = 0.0, $67 = 0;
 var $68 = 0, $69 = 0.0, $7 = 0, $70 = 0, $71 = 0, $72 = 0.0, $73 = 0, $74 = 0, $75 = 0.0, $76 = 0, $77 = 0, $78 = 0.0, $79 = 0, $8 = 0, $80 = 0, $81 = 0.0, $82 = 0, $83 = 0, $84 = 0.0, $85 = 0;
 var $86 = 0, $87 = 0.0, $88 = 0, $89 = 0, $9 = 0.0, $90 = 0.0, $91 = 0, $92 = 0, $93 = 0.0, $94 = 0, $95 = 0, $96 = 0.0, $97 = 0, $98 = 0, $99 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (70152);
 $2 = ((($0)) + 4|0);
 $3 = ((($1)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$2>>2] = $4;
 $5 = ($4|0)==(0|0);
 if (!($5)) {
  $6 = ((($4)) + 8|0);
  $7 = HEAP32[$6>>2]|0;HEAP32[$6>>2] = (($7+1)|0);
 }
 $8 = ((($1)) + 8|0);
 $9 = +HEAPF64[$8>>3];
 $10 = ((($0)) + 8|0);
 HEAPF64[$10>>3] = $9;
 $11 = ((($1)) + 16|0);
 $12 = +HEAPF64[$11>>3];
 $13 = ((($0)) + 16|0);
 HEAPF64[$13>>3] = $12;
 $14 = ((($1)) + 24|0);
 $15 = +HEAPF64[$14>>3];
 $16 = ((($0)) + 24|0);
 HEAPF64[$16>>3] = $15;
 $17 = ((($1)) + 32|0);
 $18 = +HEAPF64[$17>>3];
 $19 = ((($0)) + 32|0);
 HEAPF64[$19>>3] = $18;
 $20 = ((($1)) + 40|0);
 $21 = +HEAPF64[$20>>3];
 $22 = ((($0)) + 40|0);
 HEAPF64[$22>>3] = $21;
 $23 = ((($1)) + 48|0);
 $24 = +HEAPF64[$23>>3];
 $25 = ((($0)) + 48|0);
 HEAPF64[$25>>3] = $24;
 $26 = ((($1)) + 56|0);
 $27 = +HEAPF64[$26>>3];
 $28 = ((($0)) + 56|0);
 HEAPF64[$28>>3] = $27;
 $29 = ((($1)) + 64|0);
 $30 = +HEAPF64[$29>>3];
 $31 = ((($0)) + 64|0);
 HEAPF64[$31>>3] = $30;
 $32 = ((($1)) + 72|0);
 $33 = +HEAPF64[$32>>3];
 $34 = ((($0)) + 72|0);
 HEAPF64[$34>>3] = $33;
 $35 = ((($1)) + 80|0);
 $36 = +HEAPF64[$35>>3];
 $37 = ((($0)) + 80|0);
 HEAPF64[$37>>3] = $36;
 $38 = ((($1)) + 88|0);
 $39 = +HEAPF64[$38>>3];
 $40 = ((($0)) + 88|0);
 HEAPF64[$40>>3] = $39;
 $41 = ((($1)) + 96|0);
 $42 = +HEAPF64[$41>>3];
 $43 = ((($0)) + 96|0);
 HEAPF64[$43>>3] = $42;
 $44 = ((($1)) + 104|0);
 $45 = +HEAPF64[$44>>3];
 $46 = ((($0)) + 104|0);
 HEAPF64[$46>>3] = $45;
 $47 = ((($1)) + 112|0);
 $48 = +HEAPF64[$47>>3];
 $49 = ((($0)) + 112|0);
 HEAPF64[$49>>3] = $48;
 $50 = ((($1)) + 120|0);
 $51 = +HEAPF64[$50>>3];
 $52 = ((($0)) + 120|0);
 HEAPF64[$52>>3] = $51;
 $53 = ((($1)) + 128|0);
 $54 = +HEAPF64[$53>>3];
 $55 = ((($0)) + 128|0);
 HEAPF64[$55>>3] = $54;
 $56 = ((($1)) + 136|0);
 $57 = +HEAPF64[$56>>3];
 $58 = ((($0)) + 136|0);
 HEAPF64[$58>>3] = $57;
 $59 = ((($1)) + 144|0);
 $60 = +HEAPF64[$59>>3];
 $61 = ((($0)) + 144|0);
 HEAPF64[$61>>3] = $60;
 $62 = ((($1)) + 152|0);
 $63 = +HEAPF64[$62>>3];
 $64 = ((($0)) + 152|0);
 HEAPF64[$64>>3] = $63;
 $65 = ((($1)) + 160|0);
 $66 = +HEAPF64[$65>>3];
 $67 = ((($0)) + 160|0);
 HEAPF64[$67>>3] = $66;
 $68 = ((($1)) + 168|0);
 $69 = +HEAPF64[$68>>3];
 $70 = ((($0)) + 168|0);
 HEAPF64[$70>>3] = $69;
 $71 = ((($1)) + 176|0);
 $72 = +HEAPF64[$71>>3];
 $73 = ((($0)) + 176|0);
 HEAPF64[$73>>3] = $72;
 $74 = ((($1)) + 184|0);
 $75 = +HEAPF64[$74>>3];
 $76 = ((($0)) + 184|0);
 HEAPF64[$76>>3] = $75;
 $77 = ((($1)) + 192|0);
 $78 = +HEAPF64[$77>>3];
 $79 = ((($0)) + 192|0);
 HEAPF64[$79>>3] = $78;
 $80 = ((($1)) + 200|0);
 $81 = +HEAPF64[$80>>3];
 $82 = ((($0)) + 200|0);
 HEAPF64[$82>>3] = $81;
 $83 = ((($1)) + 208|0);
 $84 = +HEAPF64[$83>>3];
 $85 = ((($0)) + 208|0);
 HEAPF64[$85>>3] = $84;
 $86 = ((($1)) + 216|0);
 $87 = +HEAPF64[$86>>3];
 $88 = ((($0)) + 216|0);
 HEAPF64[$88>>3] = $87;
 $89 = ((($1)) + 224|0);
 $90 = +HEAPF64[$89>>3];
 $91 = ((($0)) + 224|0);
 HEAPF64[$91>>3] = $90;
 $92 = ((($1)) + 232|0);
 $93 = +HEAPF64[$92>>3];
 $94 = ((($0)) + 232|0);
 HEAPF64[$94>>3] = $93;
 $95 = ((($1)) + 240|0);
 $96 = +HEAPF64[$95>>3];
 $97 = ((($0)) + 240|0);
 HEAPF64[$97>>3] = $96;
 $98 = ((($1)) + 248|0);
 $99 = +HEAPF64[$98>>3];
 $100 = ((($0)) + 248|0);
 HEAPF64[$100>>3] = $99;
 $101 = ((($1)) + 256|0);
 $102 = +HEAPF64[$101>>3];
 $103 = ((($0)) + 256|0);
 HEAPF64[$103>>3] = $102;
 $104 = ((($0)) + 264|0);
 $105 = ((($1)) + 264|0);
 $106 = HEAP8[$105>>0]|0;
 HEAP8[$104>>0] = $106;
 $107 = ((($0)) + 268|0);
 $108 = ((($1)) + 268|0);
 $109 = HEAP32[$108>>2]|0;
 HEAP32[$107>>2] = $109;
 $110 = ($109|0)==(0|0);
 if ($110) {
  return;
 }
 $111 = HEAP32[$109>>2]|0;
 $112 = ((($111)) + -12|0);
 $113 = HEAP32[$112>>2]|0;
 $114 = (($109) + ($113)|0);
 $115 = ((($114)) + 8|0);
 $116 = HEAP32[$115>>2]|0;HEAP32[$115>>2] = (($116+1)|0);
 return;
}
function __ZN3osg4View5SlaveD2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (70152);
 $1 = ((($0)) + 268|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = HEAP32[$2>>2]|0;
  $5 = ((($4)) + -12|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($2) + ($6)|0);
  $8 = ((($7)) + 8|0);
  $9 = HEAP32[$8>>2]|0;HEAP32[$8>>2] = (($9-1)|0);
  $10 = ($9|0)==(1);
  if ($10) {
   __THREW__ = 0;
   invoke_viii(3262,($7|0),1,1);
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if ($12) {
    $19 = ___cxa_find_matching_catch_2()|0;
    $20 = tempRet0;
    $21 = ((($0)) + 4|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = ($22|0)==(0|0);
    if ($23) {
     HEAP32[$21>>2] = 0;
     ___resumeException($19|0);
     // unreachable;
    }
    $24 = ((($22)) + 8|0);
    $25 = HEAP32[$24>>2]|0;HEAP32[$24>>2] = (($25-1)|0);
    $26 = ($25|0)==(1);
    if (!($26)) {
     HEAP32[$21>>2] = 0;
     ___resumeException($19|0);
     // unreachable;
    }
    __THREW__ = 0;
    invoke_viii(3262,($22|0),1,1);
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     $29 = ___cxa_find_matching_catch_3(0|0)|0;
     $30 = tempRet0;
     ___clang_call_terminate($29);
     // unreachable;
    } else {
     HEAP32[$21>>2] = 0;
     ___resumeException($19|0);
     // unreachable;
    }
   }
  }
 }
 HEAP32[$1>>2] = 0;
 $13 = ((($0)) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(0|0);
 if ($15) {
  HEAP32[$13>>2] = 0;
  return;
 }
 $16 = ((($14)) + 8|0);
 $17 = HEAP32[$16>>2]|0;HEAP32[$16>>2] = (($17-1)|0);
 $18 = ($17|0)==(1);
 if (!($18)) {
  HEAP32[$13>>2] = 0;
  return;
 }
 __ZNK3osg10Referenced24signalObserversAndDeleteEbb($14,1,1);
 HEAP32[$13>>2] = 0;
 return;
}
function __ZN3osg4View5SlaveD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(2437,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZN3osg4View5Slave25updateSlaveImplementationERS0_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$pre = 0, $$pre7 = 0, $10 = 0, $100 = 0, $101 = 0.0, $102 = 0, $103 = 0, $104 = 0.0, $105 = 0, $106 = 0, $107 = 0.0, $108 = 0, $109 = 0, $11 = 0, $110 = 0.0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $13 = 0, $14 = 0.0, $15 = 0, $16 = 0, $17 = 0.0, $18 = 0, $19 = 0, $2 = 0, $20 = 0.0, $21 = 0, $22 = 0;
 var $23 = 0.0, $24 = 0, $25 = 0, $26 = 0.0, $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0, $32 = 0.0, $33 = 0, $34 = 0, $35 = 0.0, $36 = 0, $37 = 0, $38 = 0.0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0.0, $42 = 0, $43 = 0, $44 = 0.0, $45 = 0, $46 = 0, $47 = 0.0, $48 = 0, $49 = 0, $5 = 0, $50 = 0.0, $51 = 0, $52 = 0, $53 = 0.0, $54 = 0, $55 = 0, $56 = 0.0, $57 = 0, $58 = 0, $59 = 0.0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0.0, $66 = 0, $67 = 0, $68 = 0.0, $69 = 0, $7 = 0, $70 = 0, $71 = 0.0, $72 = 0, $73 = 0, $74 = 0.0, $75 = 0, $76 = 0, $77 = 0.0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0.0, $81 = 0, $82 = 0, $83 = 0.0, $84 = 0, $85 = 0, $86 = 0.0, $87 = 0, $88 = 0, $89 = 0.0, $9 = 0, $90 = 0, $91 = 0, $92 = 0.0, $93 = 0, $94 = 0, $95 = 0.0;
 var $96 = 0, $97 = 0, $98 = 0.0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 256|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(256|0);
 $2 = sp + 128|0;
 $3 = sp;
 $4 = ((($1)) + 16|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = ((($0)) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($8)) + 136|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0);
 do {
  if ($11) {
   $12 = ((($5)) + 304|0);
   $13 = ((($0)) + 8|0);
   __ZN3osg7Matrixd12makeIdentityEv($2);
   __ZN3osg7Matrixd4multERKS0_S2_($2,$12,$13);
   $14 = +HEAPF64[$2>>3];
   $15 = ((($8)) + 304|0);
   HEAPF64[$15>>3] = $14;
   $16 = ((($2)) + 8|0);
   $17 = +HEAPF64[$16>>3];
   $18 = ((($8)) + 312|0);
   HEAPF64[$18>>3] = $17;
   $19 = ((($2)) + 16|0);
   $20 = +HEAPF64[$19>>3];
   $21 = ((($8)) + 320|0);
   HEAPF64[$21>>3] = $20;
   $22 = ((($2)) + 24|0);
   $23 = +HEAPF64[$22>>3];
   $24 = ((($8)) + 328|0);
   HEAPF64[$24>>3] = $23;
   $25 = ((($2)) + 32|0);
   $26 = +HEAPF64[$25>>3];
   $27 = ((($8)) + 336|0);
   HEAPF64[$27>>3] = $26;
   $28 = ((($2)) + 40|0);
   $29 = +HEAPF64[$28>>3];
   $30 = ((($8)) + 344|0);
   HEAPF64[$30>>3] = $29;
   $31 = ((($2)) + 48|0);
   $32 = +HEAPF64[$31>>3];
   $33 = ((($8)) + 352|0);
   HEAPF64[$33>>3] = $32;
   $34 = ((($2)) + 56|0);
   $35 = +HEAPF64[$34>>3];
   $36 = ((($8)) + 360|0);
   HEAPF64[$36>>3] = $35;
   $37 = ((($2)) + 64|0);
   $38 = +HEAPF64[$37>>3];
   $39 = ((($8)) + 368|0);
   HEAPF64[$39>>3] = $38;
   $40 = ((($2)) + 72|0);
   $41 = +HEAPF64[$40>>3];
   $42 = ((($8)) + 376|0);
   HEAPF64[$42>>3] = $41;
   $43 = ((($2)) + 80|0);
   $44 = +HEAPF64[$43>>3];
   $45 = ((($8)) + 384|0);
   HEAPF64[$45>>3] = $44;
   $46 = ((($2)) + 88|0);
   $47 = +HEAPF64[$46>>3];
   $48 = ((($8)) + 392|0);
   HEAPF64[$48>>3] = $47;
   $49 = ((($2)) + 96|0);
   $50 = +HEAPF64[$49>>3];
   $51 = ((($8)) + 400|0);
   HEAPF64[$51>>3] = $50;
   $52 = ((($2)) + 104|0);
   $53 = +HEAPF64[$52>>3];
   $54 = ((($8)) + 408|0);
   HEAPF64[$54>>3] = $53;
   $55 = ((($2)) + 112|0);
   $56 = +HEAPF64[$55>>3];
   $57 = ((($8)) + 416|0);
   HEAPF64[$57>>3] = $56;
   $58 = ((($2)) + 120|0);
   $59 = +HEAPF64[$58>>3];
   $60 = ((($8)) + 424|0);
   HEAPF64[$60>>3] = $59;
   $61 = HEAP32[$7>>2]|0;
   $62 = HEAP32[$4>>2]|0;
   $63 = ((($62)) + 432|0);
   $64 = ((($0)) + 136|0);
   __ZN3osg7Matrixd12makeIdentityEv($3);
   __ZN3osg7Matrixd4multERKS0_S2_($3,$63,$64);
   $65 = +HEAPF64[$3>>3];
   $66 = ((($61)) + 432|0);
   HEAPF64[$66>>3] = $65;
   $67 = ((($3)) + 8|0);
   $68 = +HEAPF64[$67>>3];
   $69 = ((($61)) + 440|0);
   HEAPF64[$69>>3] = $68;
   $70 = ((($3)) + 16|0);
   $71 = +HEAPF64[$70>>3];
   $72 = ((($61)) + 448|0);
   HEAPF64[$72>>3] = $71;
   $73 = ((($3)) + 24|0);
   $74 = +HEAPF64[$73>>3];
   $75 = ((($61)) + 456|0);
   HEAPF64[$75>>3] = $74;
   $76 = ((($3)) + 32|0);
   $77 = +HEAPF64[$76>>3];
   $78 = ((($61)) + 464|0);
   HEAPF64[$78>>3] = $77;
   $79 = ((($3)) + 40|0);
   $80 = +HEAPF64[$79>>3];
   $81 = ((($61)) + 472|0);
   HEAPF64[$81>>3] = $80;
   $82 = ((($3)) + 48|0);
   $83 = +HEAPF64[$82>>3];
   $84 = ((($61)) + 480|0);
   HEAPF64[$84>>3] = $83;
   $85 = ((($3)) + 56|0);
   $86 = +HEAPF64[$85>>3];
   $87 = ((($61)) + 488|0);
   HEAPF64[$87>>3] = $86;
   $88 = ((($3)) + 64|0);
   $89 = +HEAPF64[$88>>3];
   $90 = ((($61)) + 496|0);
   HEAPF64[$90>>3] = $89;
   $91 = ((($3)) + 72|0);
   $92 = +HEAPF64[$91>>3];
   $93 = ((($61)) + 504|0);
   HEAPF64[$93>>3] = $92;
   $94 = ((($3)) + 80|0);
   $95 = +HEAPF64[$94>>3];
   $96 = ((($61)) + 512|0);
   HEAPF64[$96>>3] = $95;
   $97 = ((($3)) + 88|0);
   $98 = +HEAPF64[$97>>3];
   $99 = ((($61)) + 520|0);
   HEAPF64[$99>>3] = $98;
   $100 = ((($3)) + 96|0);
   $101 = +HEAPF64[$100>>3];
   $102 = ((($61)) + 528|0);
   HEAPF64[$102>>3] = $101;
   $103 = ((($3)) + 104|0);
   $104 = +HEAPF64[$103>>3];
   $105 = ((($61)) + 536|0);
   HEAPF64[$105>>3] = $104;
   $106 = ((($3)) + 112|0);
   $107 = +HEAPF64[$106>>3];
   $108 = ((($61)) + 544|0);
   HEAPF64[$108>>3] = $107;
   $109 = ((($3)) + 120|0);
   $110 = +HEAPF64[$109>>3];
   $111 = ((($61)) + 552|0);
   HEAPF64[$111>>3] = $110;
   __THREW__ = 0;
   invoke_vi(3323,($61|0));
   $112 = __THREW__; __THREW__ = 0;
   $113 = $112&1;
   if ($113) {
    $122 = ___cxa_find_matching_catch_2()|0;
    $123 = tempRet0;
    ___resumeException($122|0);
    // unreachable;
   } else {
    $$pre = HEAP32[$7>>2]|0;
    $$pre7 = HEAP32[$4>>2]|0;
    $115 = $$pre;$119 = $$pre7;
    break;
   }
  } else {
   $115 = $8;$119 = $5;
  }
 } while(0);
 $114 = HEAP32[$115>>2]|0;
 $116 = ((($114)) + 272|0);
 $117 = HEAP32[$116>>2]|0;
 $118 = ((($119)) + 144|0);
 $120 = ((($115)) + 148|0);
 $121 = HEAP32[$120>>2]|0;
 FUNCTION_TABLE_viii[$117 & 8191]($115,$118,$121);
 STACKTOP = sp;return;
}
function __ZN3osg4ViewC2Ev($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$3 = 0, $$326 = 0, $$cast = 0, $$sroa$0$0$$sroa_idx = 0, $$sroa$5$0$$sroa_idx36 = 0, $$sroa$6$0$$sroa_idx39 = 0, $$sroa$7$0$$sroa_idx42 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0.0, $39 = 0.0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0.0, $46 = 0, $47 = 0, $48 = 0, $49 = 0.0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0.0, $53 = 0.0, $54 = 0.0, $55 = 0.0, $56 = 0.0, $57 = 0.0, $58 = 0.0, $59 = 0, $6 = 0, $60 = 0.0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $2;
 $3 = ((($1)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $$cast = $2;
 $5 = ((($$cast)) + -12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($0) + ($6)|0);
 HEAP32[$7>>2] = $4;
 $8 = ((($0)) + 4|0);
 HEAP32[$8>>2] = 0;
 $9 = ((($0)) + 12|0);
 $10 = ((($0)) + 16|0);
 $11 = ((($0)) + 20|0);
 $12 = ((($0)) + 24|0);
 $13 = ((($0)) + 32|0);
 ;HEAP32[$9>>2]=0|0;HEAP32[$9+4>>2]=0|0;HEAP32[$9+8>>2]=0|0;HEAP32[$9+12>>2]=0|0;HEAP32[$9+16>>2]=0|0;HEAP32[$9+20>>2]=0|0;
 __THREW__ = 0;
 invoke_vii(4001,($0|0),1);
 $14 = __THREW__; __THREW__ = 0;
 $15 = $14&1;
 do {
  if ($15) {
   label = 17;
  } else {
   __THREW__ = 0;
   $16 = (invoke_ii(3276,656)|0);
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if ($18) {
    label = 17;
   } else {
    __THREW__ = 0;
    invoke_vi(3336,($16|0));
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     $78 = ___cxa_find_matching_catch_2()|0;
     $79 = tempRet0;
     __ZdlPv($16);
     $$3 = $78;$$326 = $79;
     break;
    }
    $21 = HEAP32[$10>>2]|0;
    $22 = ($21|0)==($16|0);
    if (!($22)) {
     HEAP32[$10>>2] = $16;
     $23 = ((($16)) + 8|0);
     $24 = HEAP32[$23>>2]|0;HEAP32[$23>>2] = (($24+1)|0);
     $25 = ($21|0)==(0|0);
     if (!($25)) {
      $26 = ((($21)) + 8|0);
      $27 = HEAP32[$26>>2]|0;HEAP32[$26>>2] = (($27-1)|0);
      $28 = ($27|0)==(1);
      if ($28) {
       __THREW__ = 0;
       invoke_viii(3262,($21|0),1,1);
       $29 = __THREW__; __THREW__ = 0;
       $30 = $29&1;
       if ($30) {
        label = 17;
        break;
       }
      }
     }
    }
    $31 = HEAP32[$10>>2]|0;
    $32 = ((($31)) + 220|0);
    HEAP32[$32>>2] = $0;
    __THREW__ = 0;
    $33 = (invoke_i(3285)|0);
    $34 = __THREW__; __THREW__ = 0;
    $35 = $34&1;
    if ($35) {
     label = 17;
    } else {
     $36 = HEAP32[$33>>2]|0;
     $37 = ((($36)) + 32|0);
     $38 = +HEAPF32[$37>>2];
     $39 = $38;
     __THREW__ = 0;
     $40 = (invoke_i(3285)|0);
     $41 = __THREW__; __THREW__ = 0;
     $42 = $41&1;
     if ($42) {
      $80 = ___cxa_find_matching_catch_2()|0;
      $81 = tempRet0;
      $$3 = $80;$$326 = $81;
      break;
     }
     $43 = HEAP32[$40>>2]|0;
     $44 = ((($43)) + 28|0);
     $45 = +HEAPF32[$44>>2];
     __THREW__ = 0;
     $46 = (invoke_i(3285)|0);
     $47 = __THREW__; __THREW__ = 0;
     $48 = $47&1;
     if ($48) {
      $82 = ___cxa_find_matching_catch_2()|0;
      $83 = tempRet0;
      $$3 = $82;$$326 = $83;
      break;
     }
     $49 = $45;
     $50 = HEAP32[$46>>2]|0;
     $51 = ((($50)) + 36|0);
     $52 = +HEAPF32[$51>>2];
     $53 = $52;
     $54 = $39 * 0.5;
     $55 = (+Math_atan2((+$54),(+$53)));
     $56 = $55 * 2.0;
     $57 = $56 * 180.0;
     $58 = $57 / 3.1415926535897931;
     $59 = HEAP32[$10>>2]|0;
     $60 = $49 / $39;
     __THREW__ = 0;
     invoke_vidddd(3346,($59|0),(+$58),(+$60),1.0,1.0E+4);
     $61 = __THREW__; __THREW__ = 0;
     $62 = $61&1;
     if (!($62)) {
      $63 = HEAP32[$10>>2]|0;
      $$sroa$0$0$$sroa_idx = ((($63)) + 240|0);
      HEAPF32[$$sroa$0$0$$sroa_idx>>2] = 0.20000000298023224;
      $$sroa$5$0$$sroa_idx36 = ((($63)) + 244|0);
      HEAPF32[$$sroa$5$0$$sroa_idx36>>2] = 0.20000000298023224;
      $$sroa$6$0$$sroa_idx39 = ((($63)) + 248|0);
      HEAPF32[$$sroa$6$0$$sroa_idx39>>2] = 0.40000000596046448;
      $$sroa$7$0$$sroa_idx42 = ((($63)) + 252|0);
      HEAPF32[$$sroa$7$0$$sroa_idx42>>2] = 1.0;
      $64 = ((($63)) + 152|0);
      $65 = HEAP32[$64>>2]|0;
      $66 = ($65|0)==(0);
      $67 = ((($63)) + 148|0);
      if ($66) {
       $68 = HEAP32[$67>>2]|0;
       $69 = $68 & -8193;
       HEAP32[$67>>2] = $69;
      }
      $70 = HEAP32[$10>>2]|0;
      __THREW__ = 0;
      $71 = (invoke_ii(3281,($70|0))|0);
      $72 = __THREW__; __THREW__ = 0;
      $73 = $72&1;
      if (!($73)) {
       __THREW__ = 0;
       invoke_vi(4002,($71|0));
       $74 = __THREW__; __THREW__ = 0;
       $75 = $74&1;
       if ($75) {
        $86 = ___cxa_find_matching_catch_2()|0;
        $87 = tempRet0;
        $$3 = $86;$$326 = $87;
        break;
       } else {
        return;
       }
      }
     }
     $84 = ___cxa_find_matching_catch_2()|0;
     $85 = tempRet0;
     $$3 = $84;$$326 = $85;
    }
   }
  }
 } while(0);
 if ((label|0) == 17) {
  $76 = ___cxa_find_matching_catch_2()|0;
  $77 = tempRet0;
  $$3 = $76;$$326 = $77;
 }
 $88 = HEAP32[$13>>2]|0;
 $89 = ($88|0)==(0|0);
 if (!($89)) {
  $90 = ((($88)) + 8|0);
  $91 = HEAP32[$90>>2]|0;HEAP32[$90>>2] = (($91-1)|0);
  $92 = ($91|0)==(1);
  if ($92) {
   __THREW__ = 0;
   invoke_viii(3262,($88|0),1,1);
   $93 = __THREW__; __THREW__ = 0;
   $94 = $93&1;
   if ($94) {
    $128 = ___cxa_find_matching_catch_3(0|0)|0;
    $129 = tempRet0;
    ___clang_call_terminate($128);
    // unreachable;
   }
  }
 }
 HEAP32[$13>>2] = 0;
 $95 = HEAP32[$11>>2]|0;
 $96 = ($95|0)==(0|0);
 do {
  if (!($96)) {
   while(1) {
    $97 = HEAP32[$12>>2]|0;
    $98 = ($97|0)==($95|0);
    if ($98) {
     label = 30;
     break;
    }
    $99 = ((($97)) + -272|0);
    HEAP32[$12>>2] = $99;
    $100 = HEAP32[$99>>2]|0;
    $101 = HEAP32[$100>>2]|0;
    __THREW__ = 0;
    invoke_vi($101|0,($99|0));
    $102 = __THREW__; __THREW__ = 0;
    $103 = $102&1;
    if ($103) {
     label = 29;
     break;
    }
   }
   if ((label|0) == 29) {
    $104 = ___cxa_find_matching_catch_2()|0;
    $105 = tempRet0;
    ___cxa_call_unexpected(($104|0));
    // unreachable;
   }
   else if ((label|0) == 30) {
    $106 = HEAP32[$11>>2]|0;
    __ZdlPv($106);
    break;
   }
  }
 } while(0);
 $107 = HEAP32[$10>>2]|0;
 $108 = ($107|0)==(0|0);
 if (!($108)) {
  $109 = ((($107)) + 8|0);
  $110 = HEAP32[$109>>2]|0;HEAP32[$109>>2] = (($110-1)|0);
  $111 = ($110|0)==(1);
  if ($111) {
   __THREW__ = 0;
   invoke_viii(3262,($107|0),1,1);
   $112 = __THREW__; __THREW__ = 0;
   $113 = $112&1;
   if ($113) {
    $128 = ___cxa_find_matching_catch_3(0|0)|0;
    $129 = tempRet0;
    ___clang_call_terminate($128);
    // unreachable;
   }
  }
 }
 HEAP32[$10>>2] = 0;
 $114 = HEAP32[$9>>2]|0;
 $115 = ($114|0)==(0|0);
 if (!($115)) {
  $116 = ((($114)) + 8|0);
  $117 = HEAP32[$116>>2]|0;HEAP32[$116>>2] = (($117-1)|0);
  $118 = ($117|0)==(1);
  if ($118) {
   __THREW__ = 0;
   invoke_viii(3262,($114|0),1,1);
   $119 = __THREW__; __THREW__ = 0;
   $120 = $119&1;
   if ($120) {
    $128 = ___cxa_find_matching_catch_3(0|0)|0;
    $129 = tempRet0;
    ___clang_call_terminate($128);
    // unreachable;
   }
  }
 }
 HEAP32[$9>>2] = 0;
 $121 = HEAP32[$8>>2]|0;
 $122 = ($121|0)==(0|0);
 if ($122) {
  HEAP32[$8>>2] = 0;
  ___resumeException($$3|0);
  // unreachable;
 }
 $123 = ((($121)) + 8|0);
 $124 = HEAP32[$123>>2]|0;HEAP32[$123>>2] = (($124-1)|0);
 $125 = ($124|0)==(1);
 if (!($125)) {
  HEAP32[$8>>2] = 0;
  ___resumeException($$3|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(3262,($121|0),1,1);
 $126 = __THREW__; __THREW__ = 0;
 $127 = $126&1;
 if ($127) {
  $128 = ___cxa_find_matching_catch_3(0|0)|0;
  $129 = tempRet0;
  ___clang_call_terminate($128);
  // unreachable;
 } else {
  HEAP32[$8>>2] = 0;
  ___resumeException($$3|0);
  // unreachable;
 }
}
function __ZN3osg4View15setLightingModeENS0_12LightingModeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$sroa$0$0$$sroa_idx = 0, $$sroa$010$0$$sroa_idx = 0, $$sroa$021$0$$sroa_idx = 0, $$sroa$4$0$$sroa_idx5 = 0, $$sroa$412$0$$sroa_idx14 = 0, $$sroa$423$0$$sroa_idx25 = 0, $$sroa$5$0$$sroa_idx7 = 0, $$sroa$515$0$$sroa_idx17 = 0, $$sroa$526$0$$sroa_idx28 = 0, $$sroa$6$0$$sroa_idx9 = 0, $$sroa$618$0$$sroa_idx20 = 0, $$sroa$629$0$$sroa_idx31 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 8|0);
 HEAP32[$2>>2] = $1;
 $3 = ($1|0)==(0);
 if ($3) {
  return;
 }
 $4 = ((($0)) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  return;
 }
 $7 = (__Znwj(156)|0);
 __THREW__ = 0;
 invoke_vi(4003,($7|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $25 = ___cxa_find_matching_catch_2()|0;
  $26 = tempRet0;
  __ZdlPv($7);
  ___resumeException($25|0);
  // unreachable;
 }
 $10 = HEAP32[$4>>2]|0;
 $11 = ($10|0)==($7|0);
 if (!($11)) {
  HEAP32[$4>>2] = $7;
  $12 = ((($7)) + 8|0);
  $13 = HEAP32[$12>>2]|0;HEAP32[$12>>2] = (($13+1)|0);
  $14 = ($10|0)==(0|0);
  if (!($14)) {
   $15 = ((($10)) + 8|0);
   $16 = HEAP32[$15>>2]|0;HEAP32[$15>>2] = (($16-1)|0);
   $17 = ($16|0)==(1);
   if ($17) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($10,1,1);
   }
  }
 }
 $18 = HEAP32[$4>>2]|0;
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$19>>2]|0;
 FUNCTION_TABLE_vii[$20 & 8191]($18,1);
 $21 = HEAP32[$4>>2]|0;
 __ZN3osg5Light11setLightNumEi($21,0);
 $22 = HEAP32[$4>>2]|0;
 $$sroa$021$0$$sroa_idx = ((($22)) + 60|0);
 HEAPF32[$$sroa$021$0$$sroa_idx>>2] = 0.0;
 $$sroa$423$0$$sroa_idx25 = ((($22)) + 64|0);
 HEAPF32[$$sroa$423$0$$sroa_idx25>>2] = 0.0;
 $$sroa$526$0$$sroa_idx28 = ((($22)) + 68|0);
 HEAPF32[$$sroa$526$0$$sroa_idx28>>2] = 0.0;
 $$sroa$629$0$$sroa_idx31 = ((($22)) + 72|0);
 HEAPF32[$$sroa$629$0$$sroa_idx31>>2] = 1.0;
 $23 = HEAP32[$4>>2]|0;
 $$sroa$010$0$$sroa_idx = ((($23)) + 76|0);
 HEAPF32[$$sroa$010$0$$sroa_idx>>2] = 0.80000001192092896;
 $$sroa$412$0$$sroa_idx14 = ((($23)) + 80|0);
 HEAPF32[$$sroa$412$0$$sroa_idx14>>2] = 0.80000001192092896;
 $$sroa$515$0$$sroa_idx17 = ((($23)) + 84|0);
 HEAPF32[$$sroa$515$0$$sroa_idx17>>2] = 0.80000001192092896;
 $$sroa$618$0$$sroa_idx20 = ((($23)) + 88|0);
 HEAPF32[$$sroa$618$0$$sroa_idx20>>2] = 1.0;
 $24 = HEAP32[$4>>2]|0;
 $$sroa$0$0$$sroa_idx = ((($24)) + 92|0);
 HEAPF32[$$sroa$0$0$$sroa_idx>>2] = 1.0;
 $$sroa$4$0$$sroa_idx5 = ((($24)) + 96|0);
 HEAPF32[$$sroa$4$0$$sroa_idx5>>2] = 1.0;
 $$sroa$5$0$$sroa_idx7 = ((($24)) + 100|0);
 HEAPF32[$$sroa$5$0$$sroa_idx7>>2] = 1.0;
 $$sroa$6$0$$sroa_idx9 = ((($24)) + 104|0);
 HEAPF32[$$sroa$6$0$$sroa_idx9>>2] = 1.0;
 return;
}
function __ZN3osg4ViewC1Ev($0) {
 $0 = $0|0;
 var $$3 = 0, $$325 = 0, $$sroa$0$0$$sroa_idx = 0, $$sroa$5$0$$sroa_idx35 = 0, $$sroa$6$0$$sroa_idx38 = 0, $$sroa$7$0$$sroa_idx41 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0.0, $36 = 0.0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0.0, $43 = 0, $44 = 0, $45 = 0, $46 = 0.0, $47 = 0, $48 = 0, $49 = 0.0, $5 = 0;
 var $50 = 0.0, $51 = 0.0, $52 = 0.0, $53 = 0.0, $54 = 0.0, $55 = 0.0, $56 = 0, $57 = 0.0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 36|0);
 __ZN3osg10ReferencedC2Eb($1,1);
 $2 = ((($0)) + 48|0);
 ;HEAP32[$2>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;
 $3 = ((($0)) + 60|0);
 HEAP32[$3>>2] = 2;
 $4 = ((($0)) + 64|0);
 HEAP32[$4>>2] = 0;
 HEAP32[$0>>2] = (69816);
 HEAP32[$1>>2] = (69996);
 $5 = ((($0)) + 4|0);
 HEAP32[$5>>2] = 0;
 $6 = ((($0)) + 12|0);
 $7 = ((($0)) + 16|0);
 $8 = ((($0)) + 20|0);
 $9 = ((($0)) + 24|0);
 $10 = ((($0)) + 32|0);
 ;HEAP32[$6>>2]=0|0;HEAP32[$6+4>>2]=0|0;HEAP32[$6+8>>2]=0|0;HEAP32[$6+12>>2]=0|0;HEAP32[$6+16>>2]=0|0;HEAP32[$6+20>>2]=0|0;
 __THREW__ = 0;
 invoke_vii(4001,($0|0),1);
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 do {
  if ($12) {
   label = 17;
  } else {
   __THREW__ = 0;
   $13 = (invoke_ii(3276,656)|0);
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if ($15) {
    label = 17;
   } else {
    __THREW__ = 0;
    invoke_vi(3336,($13|0));
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     $75 = ___cxa_find_matching_catch_2()|0;
     $76 = tempRet0;
     __ZdlPv($13);
     $$3 = $75;$$325 = $76;
     break;
    }
    $18 = HEAP32[$7>>2]|0;
    $19 = ($18|0)==($13|0);
    if (!($19)) {
     HEAP32[$7>>2] = $13;
     $20 = ((($13)) + 8|0);
     $21 = HEAP32[$20>>2]|0;HEAP32[$20>>2] = (($21+1)|0);
     $22 = ($18|0)==(0|0);
     if (!($22)) {
      $23 = ((($18)) + 8|0);
      $24 = HEAP32[$23>>2]|0;HEAP32[$23>>2] = (($24-1)|0);
      $25 = ($24|0)==(1);
      if ($25) {
       __THREW__ = 0;
       invoke_viii(3262,($18|0),1,1);
       $26 = __THREW__; __THREW__ = 0;
       $27 = $26&1;
       if ($27) {
        label = 17;
        break;
       }
      }
     }
    }
    $28 = HEAP32[$7>>2]|0;
    $29 = ((($28)) + 220|0);
    HEAP32[$29>>2] = $0;
    __THREW__ = 0;
    $30 = (invoke_i(3285)|0);
    $31 = __THREW__; __THREW__ = 0;
    $32 = $31&1;
    if ($32) {
     label = 17;
    } else {
     $33 = HEAP32[$30>>2]|0;
     $34 = ((($33)) + 32|0);
     $35 = +HEAPF32[$34>>2];
     $36 = $35;
     __THREW__ = 0;
     $37 = (invoke_i(3285)|0);
     $38 = __THREW__; __THREW__ = 0;
     $39 = $38&1;
     if ($39) {
      $77 = ___cxa_find_matching_catch_2()|0;
      $78 = tempRet0;
      $$3 = $77;$$325 = $78;
      break;
     }
     $40 = HEAP32[$37>>2]|0;
     $41 = ((($40)) + 28|0);
     $42 = +HEAPF32[$41>>2];
     __THREW__ = 0;
     $43 = (invoke_i(3285)|0);
     $44 = __THREW__; __THREW__ = 0;
     $45 = $44&1;
     if ($45) {
      $79 = ___cxa_find_matching_catch_2()|0;
      $80 = tempRet0;
      $$3 = $79;$$325 = $80;
      break;
     }
     $46 = $42;
     $47 = HEAP32[$43>>2]|0;
     $48 = ((($47)) + 36|0);
     $49 = +HEAPF32[$48>>2];
     $50 = $49;
     $51 = $36 * 0.5;
     $52 = (+Math_atan2((+$51),(+$50)));
     $53 = $52 * 2.0;
     $54 = $53 * 180.0;
     $55 = $54 / 3.1415926535897931;
     $56 = HEAP32[$7>>2]|0;
     $57 = $46 / $36;
     __THREW__ = 0;
     invoke_vidddd(3346,($56|0),(+$55),(+$57),1.0,1.0E+4);
     $58 = __THREW__; __THREW__ = 0;
     $59 = $58&1;
     if (!($59)) {
      $60 = HEAP32[$7>>2]|0;
      $$sroa$0$0$$sroa_idx = ((($60)) + 240|0);
      HEAPF32[$$sroa$0$0$$sroa_idx>>2] = 0.20000000298023224;
      $$sroa$5$0$$sroa_idx35 = ((($60)) + 244|0);
      HEAPF32[$$sroa$5$0$$sroa_idx35>>2] = 0.20000000298023224;
      $$sroa$6$0$$sroa_idx38 = ((($60)) + 248|0);
      HEAPF32[$$sroa$6$0$$sroa_idx38>>2] = 0.40000000596046448;
      $$sroa$7$0$$sroa_idx41 = ((($60)) + 252|0);
      HEAPF32[$$sroa$7$0$$sroa_idx41>>2] = 1.0;
      $61 = ((($60)) + 152|0);
      $62 = HEAP32[$61>>2]|0;
      $63 = ($62|0)==(0);
      $64 = ((($60)) + 148|0);
      if ($63) {
       $65 = HEAP32[$64>>2]|0;
       $66 = $65 & -8193;
       HEAP32[$64>>2] = $66;
      }
      $67 = HEAP32[$7>>2]|0;
      __THREW__ = 0;
      $68 = (invoke_ii(3281,($67|0))|0);
      $69 = __THREW__; __THREW__ = 0;
      $70 = $69&1;
      if (!($70)) {
       __THREW__ = 0;
       invoke_vi(4002,($68|0));
       $71 = __THREW__; __THREW__ = 0;
       $72 = $71&1;
       if ($72) {
        $83 = ___cxa_find_matching_catch_2()|0;
        $84 = tempRet0;
        $$3 = $83;$$325 = $84;
        break;
       } else {
        return;
       }
      }
     }
     $81 = ___cxa_find_matching_catch_2()|0;
     $82 = tempRet0;
     $$3 = $81;$$325 = $82;
    }
   }
  }
 } while(0);
 if ((label|0) == 17) {
  $73 = ___cxa_find_matching_catch_2()|0;
  $74 = tempRet0;
  $$3 = $73;$$325 = $74;
 }
 $85 = HEAP32[$10>>2]|0;
 $86 = ($85|0)==(0|0);
 if (!($86)) {
  $87 = ((($85)) + 8|0);
  $88 = HEAP32[$87>>2]|0;HEAP32[$87>>2] = (($88-1)|0);
  $89 = ($88|0)==(1);
  if ($89) {
   __THREW__ = 0;
   invoke_viii(3262,($85|0),1,1);
   $90 = __THREW__; __THREW__ = 0;
   $91 = $90&1;
   if ($91) {
    $127 = ___cxa_find_matching_catch_3(0|0)|0;
    $128 = tempRet0;
    ___clang_call_terminate($127);
    // unreachable;
   }
  }
 }
 HEAP32[$10>>2] = 0;
 $92 = HEAP32[$8>>2]|0;
 $93 = ($92|0)==(0|0);
 do {
  if (!($93)) {
   while(1) {
    $94 = HEAP32[$9>>2]|0;
    $95 = ($94|0)==($92|0);
    if ($95) {
     label = 30;
     break;
    }
    $96 = ((($94)) + -272|0);
    HEAP32[$9>>2] = $96;
    $97 = HEAP32[$96>>2]|0;
    $98 = HEAP32[$97>>2]|0;
    __THREW__ = 0;
    invoke_vi($98|0,($96|0));
    $99 = __THREW__; __THREW__ = 0;
    $100 = $99&1;
    if ($100) {
     label = 29;
     break;
    }
   }
   if ((label|0) == 29) {
    $101 = ___cxa_find_matching_catch_2()|0;
    $102 = tempRet0;
    ___cxa_call_unexpected(($101|0));
    // unreachable;
   }
   else if ((label|0) == 30) {
    $103 = HEAP32[$8>>2]|0;
    __ZdlPv($103);
    break;
   }
  }
 } while(0);
 $104 = HEAP32[$7>>2]|0;
 $105 = ($104|0)==(0|0);
 if (!($105)) {
  $106 = ((($104)) + 8|0);
  $107 = HEAP32[$106>>2]|0;HEAP32[$106>>2] = (($107-1)|0);
  $108 = ($107|0)==(1);
  if ($108) {
   __THREW__ = 0;
   invoke_viii(3262,($104|0),1,1);
   $109 = __THREW__; __THREW__ = 0;
   $110 = $109&1;
   if ($110) {
    $127 = ___cxa_find_matching_catch_3(0|0)|0;
    $128 = tempRet0;
    ___clang_call_terminate($127);
    // unreachable;
   }
  }
 }
 HEAP32[$7>>2] = 0;
 $111 = HEAP32[$6>>2]|0;
 $112 = ($111|0)==(0|0);
 if (!($112)) {
  $113 = ((($111)) + 8|0);
  $114 = HEAP32[$113>>2]|0;HEAP32[$113>>2] = (($114-1)|0);
  $115 = ($114|0)==(1);
  if ($115) {
   __THREW__ = 0;
   invoke_viii(3262,($111|0),1,1);
   $116 = __THREW__; __THREW__ = 0;
   $117 = $116&1;
   if ($117) {
    $127 = ___cxa_find_matching_catch_3(0|0)|0;
    $128 = tempRet0;
    ___clang_call_terminate($127);
    // unreachable;
   }
  }
 }
 HEAP32[$6>>2] = 0;
 $118 = HEAP32[$5>>2]|0;
 $119 = ($118|0)==(0|0);
 if (!($119)) {
  $120 = ((($118)) + 8|0);
  $121 = HEAP32[$120>>2]|0;HEAP32[$120>>2] = (($121-1)|0);
  $122 = ($121|0)==(1);
  if ($122) {
   __THREW__ = 0;
   invoke_viii(3262,($118|0),1,1);
   $123 = __THREW__; __THREW__ = 0;
   $124 = $123&1;
   if ($124) {
    $127 = ___cxa_find_matching_catch_3(0|0)|0;
    $128 = tempRet0;
    ___clang_call_terminate($127);
    // unreachable;
   }
  }
 }
 HEAP32[$5>>2] = 0;
 __THREW__ = 0;
 invoke_vi(388,($1|0));
 $125 = __THREW__; __THREW__ = 0;
 $126 = $125&1;
 if ($126) {
  $127 = ___cxa_find_matching_catch_3(0|0)|0;
  $128 = tempRet0;
  ___clang_call_terminate($127);
  // unreachable;
 } else {
  ___resumeException($$3|0);
  // unreachable;
 }
}
function __ZN3osg4ViewC2ERKS0_RKNS_6CopyOpE($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$cast = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $4;
 $5 = ((($1)) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $$cast = $4;
 $7 = ((($$cast)) + -12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($0) + ($8)|0);
 HEAP32[$9>>2] = $6;
 $10 = ((($0)) + 4|0);
 HEAP32[$10>>2] = 0;
 $11 = ((($0)) + 8|0);
 $12 = ((($2)) + 8|0);
 $13 = HEAP32[$12>>2]|0;
 HEAP32[$11>>2] = $13;
 $14 = ((($0)) + 12|0);
 $15 = ((($2)) + 12|0);
 $16 = HEAP32[$15>>2]|0;
 HEAP32[$14>>2] = $16;
 $17 = ($16|0)==(0|0);
 if (!($17)) {
  $18 = ((($16)) + 8|0);
  $19 = HEAP32[$18>>2]|0;HEAP32[$18>>2] = (($19+1)|0);
 }
 $20 = ((($0)) + 16|0);
 $21 = ((($2)) + 16|0);
 $22 = HEAP32[$21>>2]|0;
 HEAP32[$20>>2] = $22;
 $23 = ($22|0)==(0|0);
 if (!($23)) {
  $24 = ((($22)) + 8|0);
  $25 = HEAP32[$24>>2]|0;HEAP32[$24>>2] = (($25+1)|0);
 }
 $26 = ((($0)) + 20|0);
 $27 = ((($2)) + 20|0);
 __THREW__ = 0;
 invoke_vii(4004,($26|0),($27|0));
 $28 = __THREW__; __THREW__ = 0;
 $29 = $28&1;
 if (!($29)) {
  $30 = ((($0)) + 32|0);
  HEAP32[$30>>2] = 0;
  return;
 }
 $31 = ___cxa_find_matching_catch_2()|0;
 $32 = tempRet0;
 $33 = HEAP32[$20>>2]|0;
 $34 = ($33|0)==(0|0);
 if (!($34)) {
  $35 = ((($33)) + 8|0);
  $36 = HEAP32[$35>>2]|0;HEAP32[$35>>2] = (($36-1)|0);
  $37 = ($36|0)==(1);
  if ($37) {
   __THREW__ = 0;
   invoke_viii(3262,($33|0),1,1);
   $38 = __THREW__; __THREW__ = 0;
   $39 = $38&1;
   if ($39) {
    $54 = ___cxa_find_matching_catch_3(0|0)|0;
    $55 = tempRet0;
    ___clang_call_terminate($54);
    // unreachable;
   }
  }
 }
 HEAP32[$20>>2] = 0;
 $40 = HEAP32[$14>>2]|0;
 $41 = ($40|0)==(0|0);
 if (!($41)) {
  $42 = ((($40)) + 8|0);
  $43 = HEAP32[$42>>2]|0;HEAP32[$42>>2] = (($43-1)|0);
  $44 = ($43|0)==(1);
  if ($44) {
   __THREW__ = 0;
   invoke_viii(3262,($40|0),1,1);
   $45 = __THREW__; __THREW__ = 0;
   $46 = $45&1;
   if ($46) {
    $54 = ___cxa_find_matching_catch_3(0|0)|0;
    $55 = tempRet0;
    ___clang_call_terminate($54);
    // unreachable;
   }
  }
 }
 HEAP32[$14>>2] = 0;
 $47 = HEAP32[$10>>2]|0;
 $48 = ($47|0)==(0|0);
 if ($48) {
  HEAP32[$10>>2] = 0;
  ___resumeException($31|0);
  // unreachable;
 }
 $49 = ((($47)) + 8|0);
 $50 = HEAP32[$49>>2]|0;HEAP32[$49>>2] = (($50-1)|0);
 $51 = ($50|0)==(1);
 if (!($51)) {
  HEAP32[$10>>2] = 0;
  ___resumeException($31|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(3262,($47|0),1,1);
 $52 = __THREW__; __THREW__ = 0;
 $53 = $52&1;
 if ($53) {
  $54 = ___cxa_find_matching_catch_3(0|0)|0;
  $55 = tempRet0;
  ___clang_call_terminate($54);
  // unreachable;
 } else {
  HEAP32[$10>>2] = 0;
  ___resumeException($31|0);
  // unreachable;
 }
}
function __ZNSt3__26vectorIN3osg4View5SlaveENS_9allocatorIS3_EEEC2ERKS6_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$07$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = 0;
 $2 = ((($0)) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = ((($0)) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$1>>2]|0;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 272)&-1;
 $9 = ($7|0)==(0);
 if ($9) {
  return;
 }
 $10 = ($8>>>0)>(15790320);
 L4: do {
  if ($10) {
   __THREW__ = 0;
   invoke_vi(3307,($0|0));
   $11 = __THREW__; __THREW__ = 0;
  } else {
   __THREW__ = 0;
   $12 = (invoke_ii(3276,($7|0))|0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if (!($14)) {
    HEAP32[$2>>2] = $12;
    HEAP32[$0>>2] = $12;
    $15 = (($12) + (($8*272)|0)|0);
    $16 = ((($0)) + 8|0);
    HEAP32[$16>>2] = $15;
    $17 = HEAP32[$1>>2]|0;
    $18 = HEAP32[$4>>2]|0;
    $19 = ($17|0)==($18|0);
    if ($19) {
     return;
    }
    $$07$i$i = $17;$20 = $12;
    while(1) {
     __THREW__ = 0;
     invoke_vii(4005,($20|0),($$07$i$i|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break L4;
     }
     $23 = ((($$07$i$i)) + 272|0);
     $24 = HEAP32[$2>>2]|0;
     $25 = ((($24)) + 272|0);
     HEAP32[$2>>2] = $25;
     $26 = ($23|0)==($18|0);
     if ($26) {
      break;
     } else {
      $$07$i$i = $23;$20 = $25;
     }
    }
    return;
   }
  }
 } while(0);
 $27 = ___cxa_find_matching_catch_2()|0;
 $28 = tempRet0;
 $29 = HEAP32[$0>>2]|0;
 $30 = ($29|0)==(0|0);
 if ($30) {
  ___resumeException($27|0);
  // unreachable;
 }
 while(1) {
  $31 = HEAP32[$2>>2]|0;
  $32 = ($31|0)==($29|0);
  if ($32) {
   break;
  }
  $33 = ((($31)) + -272|0);
  HEAP32[$2>>2] = $33;
  $34 = HEAP32[$33>>2]|0;
  $35 = HEAP32[$34>>2]|0;
  __THREW__ = 0;
  invoke_vi($35|0,($33|0));
  $36 = __THREW__; __THREW__ = 0;
  $37 = $36&1;
  if ($37) {
   label = 12;
   break;
  }
 }
 if ((label|0) == 12) {
  $38 = ___cxa_find_matching_catch_2()|0;
  $39 = tempRet0;
  ___cxa_call_unexpected(($38|0));
  // unreachable;
 }
 $40 = HEAP32[$0>>2]|0;
 __ZdlPv($40);
 ___resumeException($27|0);
 // unreachable;
}
function __ZN3osg4ViewC1ERKS0_RKNS_6CopyOpE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 36|0);
 $4 = HEAP32[$1>>2]|0;
 $5 = ((($4)) + -12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($1) + ($6)|0);
 __ZN3osg6ObjectC2ERKS0_RKNS_6CopyOpE($3,$7,$2);
 HEAP32[$0>>2] = (69816);
 HEAP32[$3>>2] = (69996);
 $8 = ((($0)) + 4|0);
 HEAP32[$8>>2] = 0;
 $9 = ((($0)) + 8|0);
 $10 = ((($1)) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 HEAP32[$9>>2] = $11;
 $12 = ((($0)) + 12|0);
 $13 = ((($1)) + 12|0);
 $14 = HEAP32[$13>>2]|0;
 HEAP32[$12>>2] = $14;
 $15 = ($14|0)==(0|0);
 if (!($15)) {
  $16 = ((($14)) + 8|0);
  $17 = HEAP32[$16>>2]|0;HEAP32[$16>>2] = (($17+1)|0);
 }
 $18 = ((($0)) + 16|0);
 $19 = ((($1)) + 16|0);
 $20 = HEAP32[$19>>2]|0;
 HEAP32[$18>>2] = $20;
 $21 = ($20|0)==(0|0);
 if (!($21)) {
  $22 = ((($20)) + 8|0);
  $23 = HEAP32[$22>>2]|0;HEAP32[$22>>2] = (($23+1)|0);
 }
 $24 = ((($0)) + 20|0);
 $25 = ((($1)) + 20|0);
 __THREW__ = 0;
 invoke_vii(4004,($24|0),($25|0));
 $26 = __THREW__; __THREW__ = 0;
 $27 = $26&1;
 if (!($27)) {
  $28 = ((($0)) + 32|0);
  HEAP32[$28>>2] = 0;
  return;
 }
 $29 = ___cxa_find_matching_catch_2()|0;
 $30 = tempRet0;
 $31 = HEAP32[$18>>2]|0;
 $32 = ($31|0)==(0|0);
 if (!($32)) {
  $33 = ((($31)) + 8|0);
  $34 = HEAP32[$33>>2]|0;HEAP32[$33>>2] = (($34-1)|0);
  $35 = ($34|0)==(1);
  if ($35) {
   __THREW__ = 0;
   invoke_viii(3262,($31|0),1,1);
   $36 = __THREW__; __THREW__ = 0;
   $37 = $36&1;
   if ($37) {
    $54 = ___cxa_find_matching_catch_3(0|0)|0;
    $55 = tempRet0;
    ___clang_call_terminate($54);
    // unreachable;
   }
  }
 }
 HEAP32[$18>>2] = 0;
 $38 = HEAP32[$12>>2]|0;
 $39 = ($38|0)==(0|0);
 if (!($39)) {
  $40 = ((($38)) + 8|0);
  $41 = HEAP32[$40>>2]|0;HEAP32[$40>>2] = (($41-1)|0);
  $42 = ($41|0)==(1);
  if ($42) {
   __THREW__ = 0;
   invoke_viii(3262,($38|0),1,1);
   $43 = __THREW__; __THREW__ = 0;
   $44 = $43&1;
   if ($44) {
    $54 = ___cxa_find_matching_catch_3(0|0)|0;
    $55 = tempRet0;
    ___clang_call_terminate($54);
    // unreachable;
   }
  }
 }
 HEAP32[$12>>2] = 0;
 $45 = HEAP32[$8>>2]|0;
 $46 = ($45|0)==(0|0);
 if (!($46)) {
  $47 = ((($45)) + 8|0);
  $48 = HEAP32[$47>>2]|0;HEAP32[$47>>2] = (($48-1)|0);
  $49 = ($48|0)==(1);
  if ($49) {
   __THREW__ = 0;
   invoke_viii(3262,($45|0),1,1);
   $50 = __THREW__; __THREW__ = 0;
   $51 = $50&1;
   if ($51) {
    $54 = ___cxa_find_matching_catch_3(0|0)|0;
    $55 = tempRet0;
    ___clang_call_terminate($54);
    // unreachable;
   }
  }
 }
 HEAP32[$8>>2] = 0;
 __THREW__ = 0;
 invoke_vi(388,($3|0));
 $52 = __THREW__; __THREW__ = 0;
 $53 = $52&1;
 if ($53) {
  $54 = ___cxa_find_matching_catch_3(0|0)|0;
  $55 = tempRet0;
  ___clang_call_terminate($54);
  // unreachable;
 } else {
  ___resumeException($29|0);
  // unreachable;
 }
}
function __ZN3osg4View12updateSlavesEv($0) {
 $0 = $0|0;
 var $$07 = 0, $$in = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 20|0);
 $2 = ((($0)) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$1>>2]|0;
 $5 = ($3|0)==($4|0);
 if ($5) {
  return;
 } else {
  $$07 = 0;$$in = $4;
 }
 while(1) {
  $6 = $$in;
  $7 = (($6) + (($$07*272)|0)|0);
  $8 = (((($6) + (($$07*272)|0)|0)) + 268|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($9|0)==(0|0);
  if ($10) {
   $13 = HEAP32[$7>>2]|0;
   $14 = ((($13)) + 8|0);
   $15 = HEAP32[$14>>2]|0;
   FUNCTION_TABLE_vii[$15 & 8191]($7,$0);
  } else {
   $11 = HEAP32[$9>>2]|0;
   $12 = HEAP32[$11>>2]|0;
   FUNCTION_TABLE_viii[$12 & 8191]($9,$0,$7);
  }
  $16 = (($$07) + 1)|0;
  $17 = HEAP32[$2>>2]|0;
  $18 = HEAP32[$1>>2]|0;
  $19 = (($17) - ($18))|0;
  $20 = (($19|0) / 272)&-1;
  $21 = ($16>>>0)<($20>>>0);
  if ($21) {
   $$07 = $16;$$in = $18;
  } else {
   break;
  }
 }
 return;
}
function __ZN3osg4View8addSlaveEPNS_6CameraERKNS_7MatrixdES5_b($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0 = 0, $$02327 = 0, $$pre = 0, $10 = 0, $100 = 0.0, $101 = 0, $102 = 0, $103 = 0.0, $104 = 0, $105 = 0, $106 = 0.0, $107 = 0, $108 = 0, $109 = 0.0, $11 = 0, $110 = 0, $111 = 0, $112 = 0.0, $113 = 0, $114 = 0;
 var $115 = 0.0, $116 = 0, $117 = 0, $118 = 0.0, $119 = 0, $12 = 0, $120 = 0, $121 = 0.0, $122 = 0, $123 = 0, $124 = 0.0, $125 = 0, $126 = 0, $127 = 0.0, $128 = 0, $129 = 0, $13 = 0, $130 = 0.0, $131 = 0, $132 = 0;
 var $133 = 0.0, $134 = 0, $135 = 0, $136 = 0.0, $137 = 0, $138 = 0, $139 = 0.0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0.0, $153 = 0, $154 = 0.0, $155 = 0, $156 = 0.0, $157 = 0, $158 = 0.0, $159 = 0, $16 = 0, $160 = 0.0, $161 = 0, $162 = 0.0, $163 = 0, $164 = 0.0, $165 = 0, $166 = 0.0, $167 = 0, $168 = 0.0, $169 = 0;
 var $17 = 0, $170 = 0.0, $171 = 0, $172 = 0.0, $173 = 0, $174 = 0.0, $175 = 0, $176 = 0.0, $177 = 0, $178 = 0.0, $179 = 0, $18 = 0, $180 = 0.0, $181 = 0, $182 = 0.0, $183 = 0, $184 = 0.0, $185 = 0, $186 = 0.0, $187 = 0;
 var $188 = 0.0, $189 = 0, $19 = 0, $190 = 0.0, $191 = 0, $192 = 0.0, $193 = 0, $194 = 0.0, $195 = 0, $196 = 0.0, $197 = 0, $198 = 0.0, $199 = 0, $20 = 0, $200 = 0.0, $201 = 0, $202 = 0.0, $203 = 0, $204 = 0.0, $205 = 0;
 var $206 = 0.0, $207 = 0, $208 = 0.0, $209 = 0, $21 = 0, $210 = 0.0, $211 = 0, $212 = 0.0, $213 = 0, $214 = 0.0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0;
 var $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0;
 var $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0;
 var $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0;
 var $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0;
 var $297 = 0, $298 = 0, $299 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0;
 var $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0.0, $48 = 0, $49 = 0, $5 = 0, $50 = 0.0, $51 = 0, $52 = 0, $53 = 0.0, $54 = 0, $55 = 0, $56 = 0.0, $57 = 0, $58 = 0, $59 = 0.0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0.0, $63 = 0, $64 = 0, $65 = 0.0, $66 = 0, $67 = 0, $68 = 0.0, $69 = 0, $7 = 0, $70 = 0, $71 = 0.0, $72 = 0, $73 = 0, $74 = 0.0, $75 = 0, $76 = 0, $77 = 0.0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0.0, $81 = 0, $82 = 0, $83 = 0.0, $84 = 0, $85 = 0, $86 = 0.0, $87 = 0, $88 = 0, $89 = 0.0, $9 = 0, $90 = 0, $91 = 0, $92 = 0.0, $93 = 0, $94 = 0.0, $95 = 0, $96 = 0, $97 = 0.0, $98 = 0;
 var $99 = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 272|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(272|0);
 $5 = sp;
 $6 = ($1|0)==(0|0);
 if ($6) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $7 = ((($1)) + 220|0);
 HEAP32[$7>>2] = $0;
 if ($4) {
  $8 = HEAP32[$1>>2]|0;
  $9 = ((($8)) + 216|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ((($8)) + 224|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (FUNCTION_TABLE_ii[$12 & 8191]($1)|0);
  (FUNCTION_TABLE_iiii[$10 & 8191]($1,0,$13)|0);
  $14 = ((($0)) + 16|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = ($15|0)==(0|0);
  if (!($16)) {
   $17 = HEAP32[$15>>2]|0;
   $18 = ((($17)) + 224|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (FUNCTION_TABLE_ii[$19 & 8191]($15)|0);
   $21 = ($20|0)==(0);
   if (!($21)) {
    $$02327 = 0;
    while(1) {
     $22 = HEAP32[$1>>2]|0;
     $23 = ((($22)) + 204|0);
     $24 = HEAP32[$23>>2]|0;
     $25 = HEAP32[$14>>2]|0;
     $26 = ((($25)) + 124|0);
     $27 = HEAP32[$26>>2]|0;
     $28 = (($27) + ($$02327<<2)|0);
     $29 = HEAP32[$28>>2]|0;
     (FUNCTION_TABLE_iii[$24 & 8191]($1,$29)|0);
     $30 = (($$02327) + 1)|0;
     $31 = HEAP32[$14>>2]|0;
     $32 = HEAP32[$31>>2]|0;
     $33 = ((($32)) + 224|0);
     $34 = HEAP32[$33>>2]|0;
     $35 = (FUNCTION_TABLE_ii[$34 & 8191]($31)|0);
     $36 = ($30>>>0)<($35>>>0);
     if ($36) {
      $$02327 = $30;
     } else {
      break;
     }
    }
   }
  }
 }
 $37 = ((($0)) + 20|0);
 $38 = ((($0)) + 24|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = HEAP32[$37>>2]|0;
 $41 = (($39) - ($40))|0;
 $42 = (($41|0) / 272)&-1;
 $43 = $4&1;
 HEAP32[$5>>2] = (70152);
 $44 = ((($5)) + 4|0);
 HEAP32[$44>>2] = $1;
 $45 = ((($1)) + 8|0);
 $46 = HEAP32[$45>>2]|0;HEAP32[$45>>2] = (($46+1)|0);
 $47 = +HEAPF64[$2>>3];
 $48 = ((($5)) + 8|0);
 HEAPF64[$48>>3] = $47;
 $49 = ((($2)) + 8|0);
 $50 = +HEAPF64[$49>>3];
 $51 = ((($5)) + 16|0);
 HEAPF64[$51>>3] = $50;
 $52 = ((($2)) + 16|0);
 $53 = +HEAPF64[$52>>3];
 $54 = ((($5)) + 24|0);
 HEAPF64[$54>>3] = $53;
 $55 = ((($2)) + 24|0);
 $56 = +HEAPF64[$55>>3];
 $57 = ((($5)) + 32|0);
 HEAPF64[$57>>3] = $56;
 $58 = ((($2)) + 32|0);
 $59 = +HEAPF64[$58>>3];
 $60 = ((($5)) + 40|0);
 HEAPF64[$60>>3] = $59;
 $61 = ((($2)) + 40|0);
 $62 = +HEAPF64[$61>>3];
 $63 = ((($5)) + 48|0);
 HEAPF64[$63>>3] = $62;
 $64 = ((($2)) + 48|0);
 $65 = +HEAPF64[$64>>3];
 $66 = ((($5)) + 56|0);
 HEAPF64[$66>>3] = $65;
 $67 = ((($2)) + 56|0);
 $68 = +HEAPF64[$67>>3];
 $69 = ((($5)) + 64|0);
 HEAPF64[$69>>3] = $68;
 $70 = ((($2)) + 64|0);
 $71 = +HEAPF64[$70>>3];
 $72 = ((($5)) + 72|0);
 HEAPF64[$72>>3] = $71;
 $73 = ((($2)) + 72|0);
 $74 = +HEAPF64[$73>>3];
 $75 = ((($5)) + 80|0);
 HEAPF64[$75>>3] = $74;
 $76 = ((($2)) + 80|0);
 $77 = +HEAPF64[$76>>3];
 $78 = ((($5)) + 88|0);
 HEAPF64[$78>>3] = $77;
 $79 = ((($2)) + 88|0);
 $80 = +HEAPF64[$79>>3];
 $81 = ((($5)) + 96|0);
 HEAPF64[$81>>3] = $80;
 $82 = ((($2)) + 96|0);
 $83 = +HEAPF64[$82>>3];
 $84 = ((($5)) + 104|0);
 HEAPF64[$84>>3] = $83;
 $85 = ((($2)) + 104|0);
 $86 = +HEAPF64[$85>>3];
 $87 = ((($5)) + 112|0);
 HEAPF64[$87>>3] = $86;
 $88 = ((($2)) + 112|0);
 $89 = +HEAPF64[$88>>3];
 $90 = ((($5)) + 120|0);
 HEAPF64[$90>>3] = $89;
 $91 = ((($2)) + 120|0);
 $92 = +HEAPF64[$91>>3];
 $93 = ((($5)) + 128|0);
 HEAPF64[$93>>3] = $92;
 $94 = +HEAPF64[$3>>3];
 $95 = ((($5)) + 136|0);
 HEAPF64[$95>>3] = $94;
 $96 = ((($3)) + 8|0);
 $97 = +HEAPF64[$96>>3];
 $98 = ((($5)) + 144|0);
 HEAPF64[$98>>3] = $97;
 $99 = ((($3)) + 16|0);
 $100 = +HEAPF64[$99>>3];
 $101 = ((($5)) + 152|0);
 HEAPF64[$101>>3] = $100;
 $102 = ((($3)) + 24|0);
 $103 = +HEAPF64[$102>>3];
 $104 = ((($5)) + 160|0);
 HEAPF64[$104>>3] = $103;
 $105 = ((($3)) + 32|0);
 $106 = +HEAPF64[$105>>3];
 $107 = ((($5)) + 168|0);
 HEAPF64[$107>>3] = $106;
 $108 = ((($3)) + 40|0);
 $109 = +HEAPF64[$108>>3];
 $110 = ((($5)) + 176|0);
 HEAPF64[$110>>3] = $109;
 $111 = ((($3)) + 48|0);
 $112 = +HEAPF64[$111>>3];
 $113 = ((($5)) + 184|0);
 HEAPF64[$113>>3] = $112;
 $114 = ((($3)) + 56|0);
 $115 = +HEAPF64[$114>>3];
 $116 = ((($5)) + 192|0);
 HEAPF64[$116>>3] = $115;
 $117 = ((($3)) + 64|0);
 $118 = +HEAPF64[$117>>3];
 $119 = ((($5)) + 200|0);
 HEAPF64[$119>>3] = $118;
 $120 = ((($3)) + 72|0);
 $121 = +HEAPF64[$120>>3];
 $122 = ((($5)) + 208|0);
 HEAPF64[$122>>3] = $121;
 $123 = ((($3)) + 80|0);
 $124 = +HEAPF64[$123>>3];
 $125 = ((($5)) + 216|0);
 HEAPF64[$125>>3] = $124;
 $126 = ((($3)) + 88|0);
 $127 = +HEAPF64[$126>>3];
 $128 = ((($5)) + 224|0);
 HEAPF64[$128>>3] = $127;
 $129 = ((($3)) + 96|0);
 $130 = +HEAPF64[$129>>3];
 $131 = ((($5)) + 232|0);
 HEAPF64[$131>>3] = $130;
 $132 = ((($3)) + 104|0);
 $133 = +HEAPF64[$132>>3];
 $134 = ((($5)) + 240|0);
 HEAPF64[$134>>3] = $133;
 $135 = ((($3)) + 112|0);
 $136 = +HEAPF64[$135>>3];
 $137 = ((($5)) + 248|0);
 HEAPF64[$137>>3] = $136;
 $138 = ((($3)) + 120|0);
 $139 = +HEAPF64[$138>>3];
 $140 = ((($5)) + 256|0);
 HEAPF64[$140>>3] = $139;
 $141 = ((($5)) + 264|0);
 HEAP8[$141>>0] = $43;
 $142 = ((($5)) + 268|0);
 HEAP32[$142>>2] = 0;
 $143 = HEAP32[$38>>2]|0;
 $144 = ((($0)) + 28|0);
 $145 = HEAP32[$144>>2]|0;
 $146 = ($143|0)==($145|0);
 if ($146) {
  __THREW__ = 0;
  invoke_vii(4006,($37|0),($5|0));
  $229 = __THREW__; __THREW__ = 0;
  $230 = $229&1;
  if ($230) {
   $290 = ___cxa_find_matching_catch_2()|0;
   $291 = tempRet0;
   HEAP32[$5>>2] = (70152);
   $292 = HEAP32[$142>>2]|0;
   $293 = ($292|0)==(0|0);
   if (!($293)) {
    $294 = HEAP32[$292>>2]|0;
    $295 = ((($294)) + -12|0);
    $296 = HEAP32[$295>>2]|0;
    $297 = (($292) + ($296)|0);
    $298 = ((($297)) + 8|0);
    $299 = HEAP32[$298>>2]|0;HEAP32[$298>>2] = (($299-1)|0);
    $300 = ($299|0)==(1);
    if ($300) {
     __THREW__ = 0;
     invoke_viii(3262,($297|0),1,1);
     $301 = __THREW__; __THREW__ = 0;
     $302 = $301&1;
     if ($302) {
      $310 = ___cxa_find_matching_catch_3(0|0)|0;
      $311 = tempRet0;
      $312 = HEAP32[$44>>2]|0;
      $313 = ($312|0)==(0|0);
      if (!($313)) {
       $314 = ((($312)) + 8|0);
       $315 = HEAP32[$314>>2]|0;HEAP32[$314>>2] = (($315-1)|0);
       $316 = ($315|0)==(1);
       if ($316) {
        __THREW__ = 0;
        invoke_viii(3262,($312|0),1,1);
        $317 = __THREW__; __THREW__ = 0;
        $318 = $317&1;
        if ($318) {
         $319 = ___cxa_find_matching_catch_3(0|0)|0;
         $320 = tempRet0;
         ___clang_call_terminate($319);
         // unreachable;
        }
       }
      }
      HEAP32[$44>>2] = 0;
      $eh$lpad$body$indexZ2D = $310;
      ___clang_call_terminate($eh$lpad$body$indexZ2D);
      // unreachable;
     }
    }
   }
   HEAP32[$142>>2] = 0;
   $303 = HEAP32[$44>>2]|0;
   $304 = ($303|0)==(0|0);
   if ($304) {
    ___resumeException($290|0);
    // unreachable;
   }
   $305 = ((($303)) + 8|0);
   $306 = HEAP32[$305>>2]|0;HEAP32[$305>>2] = (($306-1)|0);
   $307 = ($306|0)==(1);
   if (!($307)) {
    ___resumeException($290|0);
    // unreachable;
   }
   __THREW__ = 0;
   invoke_viii(3262,($303|0),1,1);
   $308 = __THREW__; __THREW__ = 0;
   $309 = $308&1;
   if (!($309)) {
    ___resumeException($290|0);
    // unreachable;
   }
   $321 = ___cxa_find_matching_catch_3(0|0)|0;
   $322 = tempRet0;
   $eh$lpad$body$indexZ2D = $321;
   ___clang_call_terminate($eh$lpad$body$indexZ2D);
   // unreachable;
  }
 } else {
  HEAP32[$143>>2] = (70152);
  $147 = ((($143)) + 4|0);
  $148 = HEAP32[$44>>2]|0;
  HEAP32[$147>>2] = $148;
  $149 = ($148|0)==(0|0);
  if ($149) {
   $217 = $43;
  } else {
   $150 = ((($148)) + 8|0);
   $151 = HEAP32[$150>>2]|0;HEAP32[$150>>2] = (($151+1)|0);
   $$pre = HEAP8[$141>>0]|0;
   $217 = $$pre;
  }
  $152 = +HEAPF64[$48>>3];
  $153 = ((($143)) + 8|0);
  HEAPF64[$153>>3] = $152;
  $154 = +HEAPF64[$51>>3];
  $155 = ((($143)) + 16|0);
  HEAPF64[$155>>3] = $154;
  $156 = +HEAPF64[$54>>3];
  $157 = ((($143)) + 24|0);
  HEAPF64[$157>>3] = $156;
  $158 = +HEAPF64[$57>>3];
  $159 = ((($143)) + 32|0);
  HEAPF64[$159>>3] = $158;
  $160 = +HEAPF64[$60>>3];
  $161 = ((($143)) + 40|0);
  HEAPF64[$161>>3] = $160;
  $162 = +HEAPF64[$63>>3];
  $163 = ((($143)) + 48|0);
  HEAPF64[$163>>3] = $162;
  $164 = +HEAPF64[$66>>3];
  $165 = ((($143)) + 56|0);
  HEAPF64[$165>>3] = $164;
  $166 = +HEAPF64[$69>>3];
  $167 = ((($143)) + 64|0);
  HEAPF64[$167>>3] = $166;
  $168 = +HEAPF64[$72>>3];
  $169 = ((($143)) + 72|0);
  HEAPF64[$169>>3] = $168;
  $170 = +HEAPF64[$75>>3];
  $171 = ((($143)) + 80|0);
  HEAPF64[$171>>3] = $170;
  $172 = +HEAPF64[$78>>3];
  $173 = ((($143)) + 88|0);
  HEAPF64[$173>>3] = $172;
  $174 = +HEAPF64[$81>>3];
  $175 = ((($143)) + 96|0);
  HEAPF64[$175>>3] = $174;
  $176 = +HEAPF64[$84>>3];
  $177 = ((($143)) + 104|0);
  HEAPF64[$177>>3] = $176;
  $178 = +HEAPF64[$87>>3];
  $179 = ((($143)) + 112|0);
  HEAPF64[$179>>3] = $178;
  $180 = +HEAPF64[$90>>3];
  $181 = ((($143)) + 120|0);
  HEAPF64[$181>>3] = $180;
  $182 = +HEAPF64[$93>>3];
  $183 = ((($143)) + 128|0);
  HEAPF64[$183>>3] = $182;
  $184 = +HEAPF64[$95>>3];
  $185 = ((($143)) + 136|0);
  HEAPF64[$185>>3] = $184;
  $186 = +HEAPF64[$98>>3];
  $187 = ((($143)) + 144|0);
  HEAPF64[$187>>3] = $186;
  $188 = +HEAPF64[$101>>3];
  $189 = ((($143)) + 152|0);
  HEAPF64[$189>>3] = $188;
  $190 = +HEAPF64[$104>>3];
  $191 = ((($143)) + 160|0);
  HEAPF64[$191>>3] = $190;
  $192 = +HEAPF64[$107>>3];
  $193 = ((($143)) + 168|0);
  HEAPF64[$193>>3] = $192;
  $194 = +HEAPF64[$110>>3];
  $195 = ((($143)) + 176|0);
  HEAPF64[$195>>3] = $194;
  $196 = +HEAPF64[$113>>3];
  $197 = ((($143)) + 184|0);
  HEAPF64[$197>>3] = $196;
  $198 = +HEAPF64[$116>>3];
  $199 = ((($143)) + 192|0);
  HEAPF64[$199>>3] = $198;
  $200 = +HEAPF64[$119>>3];
  $201 = ((($143)) + 200|0);
  HEAPF64[$201>>3] = $200;
  $202 = +HEAPF64[$122>>3];
  $203 = ((($143)) + 208|0);
  HEAPF64[$203>>3] = $202;
  $204 = +HEAPF64[$125>>3];
  $205 = ((($143)) + 216|0);
  HEAPF64[$205>>3] = $204;
  $206 = +HEAPF64[$128>>3];
  $207 = ((($143)) + 224|0);
  HEAPF64[$207>>3] = $206;
  $208 = +HEAPF64[$131>>3];
  $209 = ((($143)) + 232|0);
  HEAPF64[$209>>3] = $208;
  $210 = +HEAPF64[$134>>3];
  $211 = ((($143)) + 240|0);
  HEAPF64[$211>>3] = $210;
  $212 = +HEAPF64[$137>>3];
  $213 = ((($143)) + 248|0);
  HEAPF64[$213>>3] = $212;
  $214 = +HEAPF64[$140>>3];
  $215 = ((($143)) + 256|0);
  HEAPF64[$215>>3] = $214;
  $216 = ((($143)) + 264|0);
  HEAP8[$216>>0] = $217;
  $218 = ((($143)) + 268|0);
  $219 = HEAP32[$142>>2]|0;
  HEAP32[$218>>2] = $219;
  $220 = ($219|0)==(0|0);
  if (!($220)) {
   $221 = HEAP32[$219>>2]|0;
   $222 = ((($221)) + -12|0);
   $223 = HEAP32[$222>>2]|0;
   $224 = (($219) + ($223)|0);
   $225 = ((($224)) + 8|0);
   $226 = HEAP32[$225>>2]|0;HEAP32[$225>>2] = (($226+1)|0);
  }
  $227 = HEAP32[$38>>2]|0;
  $228 = ((($227)) + 272|0);
  HEAP32[$38>>2] = $228;
 }
 HEAP32[$5>>2] = (70152);
 $231 = HEAP32[$142>>2]|0;
 $232 = ($231|0)==(0|0);
 if (!($232)) {
  $233 = HEAP32[$231>>2]|0;
  $234 = ((($233)) + -12|0);
  $235 = HEAP32[$234>>2]|0;
  $236 = (($231) + ($235)|0);
  $237 = ((($236)) + 8|0);
  $238 = HEAP32[$237>>2]|0;HEAP32[$237>>2] = (($238-1)|0);
  $239 = ($238|0)==(1);
  if ($239) {
   __THREW__ = 0;
   invoke_viii(3262,($236|0),1,1);
   $240 = __THREW__; __THREW__ = 0;
   $241 = $240&1;
   if ($241) {
    $247 = ___cxa_find_matching_catch_2()|0;
    $248 = tempRet0;
    $249 = HEAP32[$44>>2]|0;
    $250 = ($249|0)==(0|0);
    if ($250) {
     ___resumeException($247|0);
     // unreachable;
    }
    $251 = ((($249)) + 8|0);
    $252 = HEAP32[$251>>2]|0;HEAP32[$251>>2] = (($252-1)|0);
    $253 = ($252|0)==(1);
    if (!($253)) {
     ___resumeException($247|0);
     // unreachable;
    }
    __THREW__ = 0;
    invoke_viii(3262,($249|0),1,1);
    $254 = __THREW__; __THREW__ = 0;
    $255 = $254&1;
    if ($255) {
     $256 = ___cxa_find_matching_catch_3(0|0)|0;
     $257 = tempRet0;
     ___clang_call_terminate($256);
     // unreachable;
    } else {
     ___resumeException($247|0);
     // unreachable;
    }
   }
  }
 }
 HEAP32[$142>>2] = 0;
 $242 = HEAP32[$44>>2]|0;
 $243 = ($242|0)==(0|0);
 if (!($243)) {
  $244 = ((($242)) + 8|0);
  $245 = HEAP32[$244>>2]|0;HEAP32[$244>>2] = (($245-1)|0);
  $246 = ($245|0)==(1);
  if ($246) {
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($242,1,1);
  }
 }
 $258 = HEAP32[$37>>2]|0;
 $259 = (($258) + (($42*272)|0)|0);
 $260 = (((($258) + (($42*272)|0)|0)) + 268|0);
 $261 = HEAP32[$260>>2]|0;
 $262 = ($261|0)==(0|0);
 if ($262) {
  $265 = HEAP32[$259>>2]|0;
  $266 = ((($265)) + 8|0);
  $267 = HEAP32[$266>>2]|0;
  FUNCTION_TABLE_vii[$267 & 8191]($259,$0);
 } else {
  $263 = HEAP32[$261>>2]|0;
  $264 = HEAP32[$263>>2]|0;
  FUNCTION_TABLE_viii[$264 & 8191]($261,$0,$259);
 }
 $268 = HEAP32[$0>>2]|0;
 $269 = ((($268)) + 32|0);
 $270 = HEAP32[$269>>2]|0;
 $271 = (FUNCTION_TABLE_iii[$270 & 8191]($0,$1)|0);
 $272 = ((($1)) + 628|0);
 $273 = HEAP32[$272>>2]|0;
 $274 = ($273|0)==($271|0);
 if ($274) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$272>>2] = $271;
 $275 = ($271|0)==(0|0);
 if (!($275)) {
  $276 = HEAP32[$271>>2]|0;
  $277 = ((($276)) + -12|0);
  $278 = HEAP32[$277>>2]|0;
  $279 = (($271) + ($278)|0);
  $280 = ((($279)) + 8|0);
  $281 = HEAP32[$280>>2]|0;HEAP32[$280>>2] = (($281+1)|0);
 }
 $282 = ($273|0)==(0|0);
 if ($282) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $283 = HEAP32[$273>>2]|0;
 $284 = ((($283)) + -12|0);
 $285 = HEAP32[$284>>2]|0;
 $286 = (($273) + ($285)|0);
 $287 = ((($286)) + 8|0);
 $288 = HEAP32[$287>>2]|0;HEAP32[$287>>2] = (($288-1)|0);
 $289 = ($288|0)==(1);
 if (!($289)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 __ZNK3osg10Referenced24signalObserversAndDeleteEbb($286,1,1);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZNSt3__26vectorIN3osg4View5SlaveENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$06$i$i = 0, $$pre = 0, $$pre$i = 0, $$sroa$16$0 = 0, $$sroa$16$1 = 0, $$sroa$16$2 = 0, $$sroa$7$0 = 0, $$sroa$7$1 = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = (($5|0) / 272)&-1;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(15790320);
 if ($8) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $9 = ((($0)) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) - ($4))|0;
 $12 = (($11|0) / 272)&-1;
 $13 = ($12>>>0)<(7895160);
 $14 = $12 << 1;
 $15 = ($14>>>0)<($7>>>0);
 $$sroa$speculated$i = $15 ? $7 : $14;
 $$sroa$speculated$$i = $13 ? $$sroa$speculated$i : 15790320;
 $16 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($16) {
   $26 = 0;$77 = 0;
  } else {
   $17 = ($$sroa$speculated$$i>>>0)>(15790320);
   if (!($17)) {
    $23 = ($$sroa$speculated$$i*272)|0;
    $24 = (__Znwj($23)|0);
    $26 = $24;$77 = $24;
    break;
   }
   $18 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($18|0),(204840|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if ($20) {
    $21 = ___cxa_find_matching_catch_2()|0;
    $22 = tempRet0;
    ___cxa_free_exception(($18|0));
    ___resumeException($21|0);
    // unreachable;
   } else {
    HEAP32[$18>>2] = (99824);
    ___cxa_throw(($18|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $25 = (($26) + (($6*272)|0)|0);
 $27 = $25;
 $28 = (($26) + (($$sroa$speculated$$i*272)|0)|0);
 $29 = $28;
 __THREW__ = 0;
 invoke_vii(4005,($25|0),($1|0));
 $30 = __THREW__; __THREW__ = 0;
 $31 = $30&1;
 L13: do {
  if ($31) {
   $$sroa$16$1 = $27;$$sroa$7$1 = $27;
  } else {
   $32 = ((($25)) + 272|0);
   $33 = $32;
   $34 = HEAP32[$0>>2]|0;
   $35 = HEAP32[$2>>2]|0;
   $36 = ($35|0)==($34|0);
   if ($36) {
    $37 = $35;
    $38 = $34;
    $48 = $27;$49 = $38;$78 = $37;
   } else {
    $$06$i$i = $35;$$sroa$7$0 = $27;$40 = $25;
    while(1) {
     $39 = ((($40)) + -272|0);
     $41 = ((($$06$i$i)) + -272|0);
     __THREW__ = 0;
     invoke_vii(4005,($39|0),($41|0));
     $42 = __THREW__; __THREW__ = 0;
     $43 = $42&1;
     if ($43) {
      $$sroa$16$1 = $33;$$sroa$7$1 = $$sroa$7$0;
      break L13;
     }
     $44 = $$sroa$7$0;
     $45 = ((($44)) + -272|0);
     $46 = $45;
     $47 = ($41|0)==($34|0);
     if ($47) {
      break;
     } else {
      $$06$i$i = $41;$$sroa$7$0 = $46;$40 = $45;
     }
    }
    $$pre$i = HEAP32[$0>>2]|0;
    $$pre = HEAP32[$2>>2]|0;
    $48 = $46;$49 = $$pre$i;$78 = $$pre;
   }
   HEAP32[$0>>2] = $48;
   HEAP32[$2>>2] = $33;
   HEAP32[$9>>2] = $29;
   $50 = $49;
   $$sroa$16$0 = $78;
   while(1) {
    $51 = $$sroa$16$0;
    $52 = ($51|0)==($50|0);
    if ($52) {
     break;
    }
    $53 = ((($51)) + -272|0);
    $54 = $53;
    $55 = HEAP32[$53>>2]|0;
    $56 = HEAP32[$55>>2]|0;
    __THREW__ = 0;
    invoke_vi($56|0,($53|0));
    $57 = __THREW__; __THREW__ = 0;
    $58 = $57&1;
    if ($58) {
     label = 18;
     break;
    } else {
     $$sroa$16$0 = $54;
    }
   }
   if ((label|0) == 18) {
    $59 = ___cxa_find_matching_catch_2()|0;
    $60 = tempRet0;
    ___cxa_call_unexpected(($59|0));
    // unreachable;
   }
   $61 = ($49|0)==(0);
   if ($61) {
    return;
   }
   $62 = $49;
   __ZdlPv($62);
   return;
  }
 } while(0);
 $63 = ___cxa_find_matching_catch_2()|0;
 $64 = tempRet0;
 $65 = $$sroa$7$1;
 $$sroa$16$2 = $$sroa$16$1;
 while(1) {
  $66 = $$sroa$16$2;
  $67 = ($66|0)==($65|0);
  if ($67) {
   break;
  }
  $68 = ((($66)) + -272|0);
  $69 = $68;
  $70 = HEAP32[$68>>2]|0;
  $71 = HEAP32[$70>>2]|0;
  __THREW__ = 0;
  invoke_vi($71|0,($68|0));
  $72 = __THREW__; __THREW__ = 0;
  $73 = $72&1;
  if ($73) {
   label = 25;
   break;
  } else {
   $$sroa$16$2 = $69;
  }
 }
 if ((label|0) == 25) {
  $74 = ___cxa_find_matching_catch_2()|0;
  $75 = tempRet0;
  ___cxa_call_unexpected(($74|0));
  // unreachable;
 }
 $76 = ($26|0)==(0|0);
 if ($76) {
  ___resumeException($63|0);
  // unreachable;
 }
 __ZdlPv($77);
 ___resumeException($63|0);
 // unreachable;
}
function __ZN3osg4View18findSlaveForCameraEPNS_6CameraE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$ = 0, $$0812$i = 0, $$1$i = 0, $$phi$trans$insert$i = 0, $$pre = 0, $$pre$i = 0, $$pre$phi8Z2D = 0, $$pre16$i = 0, $$pre7 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==($1|0);
 $5 = ((($0)) + 20|0);
 $$phi$trans$insert$i = ((($0)) + 24|0);
 $$pre$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $$pre16$i = HEAP32[$5>>2]|0;
 $6 = $$pre16$i;
 L1: do {
  if ($4) {
   $16 = $$pre16$i;
  } else {
   $7 = ($$pre$i|0)==($$pre16$i|0);
   if ($7) {
    $16 = $$pre$i;
   } else {
    $8 = (($$pre$i) - ($$pre16$i))|0;
    $9 = (($8|0) / 272)&-1;
    $$0812$i = 0;
    while(1) {
     $10 = (((($6) + (($$0812$i*272)|0)|0)) + 4|0);
     $11 = HEAP32[$10>>2]|0;
     $12 = ($11|0)==($1|0);
     if ($12) {
      $$1$i = $$0812$i;$$pre$phi8Z2D = $9;
      break;
     }
     $13 = (($$0812$i) + 1)|0;
     $14 = ($13>>>0)<($9>>>0);
     if ($14) {
      $$0812$i = $13;
     } else {
      $16 = $$pre16$i;
      break L1;
     }
    }
    $18 = ($$1$i>>>0)<($$pre$phi8Z2D>>>0);
    $19 = (($6) + (($$1$i*272)|0)|0);
    $$ = $18 ? $19 : 0;
    return ($$|0);
   }
  }
 } while(0);
 $15 = (($$pre$i) - ($16))|0;
 $17 = (($15|0) / 272)&-1;
 $$pre = (($$pre$i) - ($$pre16$i))|0;
 $$pre7 = (($$pre|0) / 272)&-1;
 $$1$i = $17;$$pre$phi8Z2D = $$pre7;
 $18 = ($$1$i>>>0)<($$pre$phi8Z2D>>>0);
 $19 = (($6) + (($$1$i*272)|0)|0);
 $$ = $18 ? $19 : 0;
 return ($$|0);
}
function __ZN3osg8ViewportD2Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg14StateAttributeD2Ev($0);
 return;
}
function __ZN3osg8ViewportD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1573,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK3osg8Viewport9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(88)|0);
 __THREW__ = 0;
 invoke_vi(3339,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $7 = ___cxa_find_matching_catch_2()|0;
  $8 = tempRet0;
  __ZdlPv($1);
  ___resumeException($7|0);
  // unreachable;
 } else {
  HEAP32[$1>>2] = (70172);
  $4 = ((($1)) + 56|0);
  $5 = ((($1)) + 72|0);
  ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;HEAP32[$4+12>>2]=0|0;
  HEAPF64[$5>>3] = 800.0;
  $6 = ((($1)) + 80|0);
  HEAPF64[$6>>3] = 600.0;
  return ($1|0);
 }
 return (0)|0;
}
function __ZNK3osg8Viewport5cloneERKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0.0, $11 = 0, $12 = 0, $13 = 0.0, $14 = 0, $15 = 0, $16 = 0.0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0.0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(88)|0);
 __THREW__ = 0;
 invoke_viii(3729,($2|0),($0|0),($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $17 = ___cxa_find_matching_catch_2()|0;
  $18 = tempRet0;
  __ZdlPv($2);
  ___resumeException($17|0);
  // unreachable;
 } else {
  HEAP32[$2>>2] = (70172);
  $5 = ((($2)) + 56|0);
  $6 = ((($0)) + 56|0);
  $7 = +HEAPF64[$6>>3];
  HEAPF64[$5>>3] = $7;
  $8 = ((($2)) + 64|0);
  $9 = ((($0)) + 64|0);
  $10 = +HEAPF64[$9>>3];
  HEAPF64[$8>>3] = $10;
  $11 = ((($2)) + 72|0);
  $12 = ((($0)) + 72|0);
  $13 = +HEAPF64[$12>>3];
  HEAPF64[$11>>3] = $13;
  $14 = ((($2)) + 80|0);
  $15 = ((($0)) + 80|0);
  $16 = +HEAPF64[$15>>3];
  HEAPF64[$14>>3] = $16;
  return ($2|0);
 }
 return (0)|0;
}
function __ZNK3osg8Viewport12isSameKindAsEPKNS_6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,27104,0)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK3osg8Viewport11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175113|0);
}
function __ZNK3osg8Viewport9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (159046|0);
}
function __ZNK3osg8Viewport7getTypeEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 27;
}
function __ZNK3osg8Viewport7compareERKNS_14StateAttributeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$ = 0, $$2 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0.0, $18 = 0, $19 = 0.0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0.0, $24 = 0, $25 = 0.0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0.0, $32 = 0, $33 = 0, $34 = 0, $35 = 0.0, $36 = 0, $37 = 0.0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($0|0)==($1|0);
 if ($2) {
  $$2 = 0;
  return ($$2|0);
 }
 $3 = ($0|0)==(0|0);
 if ($3) {
  ___cxa_bad_typeid();
  // unreachable;
 }
 $4 = HEAP32[$0>>2]|0;
 $5 = ((($4)) + -4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$1>>2]|0;
 $8 = ((($7)) + -4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($6)) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($9)) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($11>>>0)<($13>>>0);
 if ($14) {
  $$2 = -1;
  return ($$2|0);
 }
 $15 = ($11|0)==($13|0);
 if (!($15)) {
  $$2 = 1;
  return ($$2|0);
 }
 $16 = ((($0)) + 56|0);
 $17 = +HEAPF64[$16>>3];
 $18 = ((($1)) + 56|0);
 $19 = +HEAPF64[$18>>3];
 $20 = $17 < $19;
 if ($20) {
  $$2 = -1;
  return ($$2|0);
 }
 $21 = $19 < $17;
 if ($21) {
  $$2 = 1;
  return ($$2|0);
 }
 $22 = ((($0)) + 64|0);
 $23 = +HEAPF64[$22>>3];
 $24 = ((($1)) + 64|0);
 $25 = +HEAPF64[$24>>3];
 $26 = $23 < $25;
 if ($26) {
  $$2 = -1;
  return ($$2|0);
 }
 $27 = $25 < $23;
 if ($27) {
  $$2 = 1;
  return ($$2|0);
 }
 $28 = ((($0)) + 72|0);
 $29 = +HEAPF64[$28>>3];
 $30 = ((($1)) + 72|0);
 $31 = +HEAPF64[$30>>3];
 $32 = $29 < $31;
 if ($32) {
  $$2 = -1;
  return ($$2|0);
 }
 $33 = $31 < $29;
 if ($33) {
  $$2 = 1;
  return ($$2|0);
 }
 $34 = ((($0)) + 80|0);
 $35 = +HEAPF64[$34>>3];
 $36 = ((($1)) + 80|0);
 $37 = +HEAPF64[$36>>3];
 $38 = $35 < $37;
 if ($38) {
  $$2 = -1;
  return ($$2|0);
 }
 $39 = $37 < $35;
 $$ = $39&1;
 $$2 = $$;
 return ($$2|0);
}
function __ZNK3osg8Viewport5applyERNS_5StateE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0.0, $13 = 0, $2 = 0, $3 = 0.0, $4 = 0, $5 = 0, $6 = 0.0, $7 = 0, $8 = 0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 56|0);
 $3 = +HEAPF64[$2>>3];
 $4 = (~~(($3)));
 $5 = ((($0)) + 64|0);
 $6 = +HEAPF64[$5>>3];
 $7 = (~~(($6)));
 $8 = ((($0)) + 72|0);
 $9 = +HEAPF64[$8>>3];
 $10 = (~~(($9)));
 $11 = ((($0)) + 80|0);
 $12 = +HEAPF64[$11>>3];
 $13 = (~~(($12)));
 _glViewport(($4|0),($7|0),($10|0),($13|0));
 return;
}
function __ZN3osg8ViewportC2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg14StateAttributeC2Ev($0);
 HEAP32[$0>>2] = (70172);
 $1 = ((($0)) + 56|0);
 $2 = ((($0)) + 72|0);
 ;HEAP32[$1>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;HEAP32[$1+12>>2]=0|0;
 HEAPF64[$2>>3] = 800.0;
 $3 = ((($0)) + 80|0);
 HEAPF64[$3>>3] = 600.0;
 return;
}
function __ZN3osg14gluErrorStringEj($0) {
 $0 = $0|0;
 var $$010$lcssa = 0, $$09 = 0, $$off = 0, $$sink = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $switch$split12D = 0, $switch$split2D = 0, $switch$split42D = 0, $switch$split72D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $switch$split2D = ($0|0)<(1286);
 L1: do {
  if ($switch$split2D) {
   switch ($0|0) {
   case 0:  {
    $$010$lcssa = 0;
    label = 16;
    break L1;
    break;
   }
   case 1280:  {
    $$010$lcssa = 1;
    label = 16;
    break L1;
    break;
   }
   case 1281:  {
    $$010$lcssa = 2;
    label = 16;
    break L1;
    break;
   }
   case 1282:  {
    $$010$lcssa = 3;
    label = 16;
    break L1;
    break;
   }
   case 1283:  {
    $$010$lcssa = 4;
    label = 16;
    break L1;
    break;
   }
   case 1284:  {
    $$010$lcssa = 5;
    label = 16;
    break L1;
    break;
   }
   case 1285:  {
    $$010$lcssa = 6;
    label = 16;
    break L1;
    break;
   }
   default: {
    label = 19;
    break L1;
   }
   }
  } else {
   $switch$split12D = ($0|0)<(100901);
   if (!($switch$split12D)) {
    switch ($0|0) {
    case 100901:  {
     $$010$lcssa = 10;
     label = 16;
     break L1;
     break;
    }
    case 100902:  {
     $$010$lcssa = 11;
     label = 16;
     break L1;
     break;
    }
    case 100903:  {
     $$010$lcssa = 12;
     label = 16;
     break L1;
     break;
    }
    case 100904:  {
     $$010$lcssa = 13;
     label = 16;
     break L1;
     break;
    }
    default: {
     label = 19;
     break L1;
    }
    }
   }
   $switch$split42D = ($0|0)<(32817);
   if ($switch$split42D) {
    switch ($0|0) {
    case 1286:  {
     break;
    }
    default: {
     label = 19;
     break L1;
    }
    }
    $$010$lcssa = 8;
    label = 16;
    break;
   }
   $switch$split72D = ($0|0)<(100900);
   if ($switch$split72D) {
    switch ($0|0) {
    case 32817:  {
     break;
    }
    default: {
     label = 19;
     break L1;
    }
    }
    $$010$lcssa = 7;
    label = 16;
    break;
   } else {
    switch ($0|0) {
    case 100900:  {
     break;
    }
    default: {
     label = 19;
     break L1;
    }
    }
    $$010$lcssa = 9;
    label = 16;
    break;
   }
  }
 } while(0);
 do {
  if ((label|0) == 16) {
   $3 = (((70380 + ($$010$lcssa<<3)|0)) + 4|0);
   $$sink = $3;
  }
  else if ((label|0) == 19) {
   $$off = (($0) + -100151)|0;
   $5 = ($$off>>>0)<(6);
   if ($5) {
    $1 = (($0) + -100150)|0;
    $2 = (70352 + ($1<<2)|0);
    $$sink = $2;
    break;
   } else {
    $$09 = 0;
    return ($$09|0);
   }
  }
 } while(0);
 $4 = HEAP32[$$sink>>2]|0;
 $$09 = $4;
 return ($$09|0);
}
function __ZN3osg17PixelStorageModesC2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = 4;
 $1 = ((($0)) + 4|0);
 $2 = ((($0)) + 32|0);
 ;HEAP32[$1>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;HEAP32[$1+12>>2]=0|0;HEAP32[$1+16>>2]=0|0;HEAP32[$1+20>>2]=0|0;HEAP32[$1+24>>2]=0|0;
 HEAP32[$2>>2] = 4;
 $3 = ((($0)) + 36|0);
 ;HEAP32[$3>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;HEAP32[$3+12>>2]=0|0;HEAP32[$3+16>>2]=0|0;HEAP32[$3+20>>2]=0|0;HEAP32[$3+24>>2]=0|0;
 return;
}
function __ZN3osg13gluScaleImageEPNS_17PixelStorageModesEjiijPKviijPv($0,$1,$2,$3,$4,$5,$6,$7,$8,$9) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 $8 = $8|0;
 $9 = $9|0;
 var $$$0291$us$us$i = 0, $$$0291$us717$i$us = 0, $$$i = 0, $$0 = 0, $$0$i$i = 0, $$0$i$i73 = 0, $$0$i$i78 = 0, $$0$i304$i = 0, $$0$i674$i = 0, $$0$i70 = 0, $$0271703$us$us$i = 0, $$0271703$us709$i$us = 0, $$0275702$us$us$i = 0, $$0275702$us710$i$us = 0, $$0277706$us$i = 0, $$0277706$us$i$us = 0, $$0279705$us$i = 0, $$0279705$us$i$us = 0, $$0291700$us$us$i = 0, $$0291700$us712$i$us = 0;
 var $$0294704$us$i = 0, $$0294704$us$i$us = 0, $$0296$i = 0, $$12$i = 0, $$1276749$i = 0, $$1278755$i = 0, $$1280701$us$us$i = 0, $$1280701$us711$i$us = 0, $$1295753$i = 0, $$1297$i = 0, $$17$i = 0, $$18$i = 0, $$2281754$i = 0, $$2293746$i = 0, $$301$us$us$i = 0, $$301$us718$i$us = 0, $$303$i = 0, $$303$sink687$i = 0, $$3282$lcssa$i = 0, $$3282748$i = 0;
 var $$673$i = 0, $$675$i = 0, $$678$i = 0, $$pn299$us$us$i = 0, $$pn299$us713$i$us = 0, $$pre$i = 0, $$pre$i$us = 0, $$sink$i = 0, $$sink13$us$us$i = 0, $$sink13$us716$i$us = 0, $$sink20$in$sroa$speculated$i = 0, $$sink23$i = 0.0, $$sink27$sink$sink$i = 0, $$sink31$i = 0, $$sink9$in$us$us$i = 0, $$sink9$in$us714$i$us = 0, $$sink9$us$us$i = 0, $$sink9$us715$i$us = 0, $$sroa$0$sroa$0$0$extract$trunc519$i = 0, $$sroa$0$sroa$0$0$extract$trunc520$i = 0;
 var $$sroa$0$sroa$0$0$extract$trunc521$i = 0, $$sroa$0$sroa$0$sroa$0$0$extract$trunc$i = 0, $$sroa$0$sroa$0$sroa$0$0$extract$trunc591$i = 0, $$sroa$0$sroa$0$sroa$0$0$extract$trunc592$i = 0, $$sroa$0$sroa$0$sroa$0$0$extract$trunc594$i = 0, $$sroa$0$sroa$0$sroa$0$0$extract$trunc595$i = 0, $$sroa$0$sroa$0$sroa$0$0$extract$trunc596$i = 0, $$sroa$0$sroa$0$sroa$0$0$extract$trunc597$i = 0, $$sroa$0$sroa$0$sroa$0$0$extract$trunc598$i = 0, $$sroa$0$sroa$0$sroa$0$0$extract$trunc599$sink$i = 0, $$sroa$0$sroa$0$sroa$0$0$extract$trunc600$i = 0, $$sroa$0$sroa$0$sroa$0$0$extract$trunc601$i = 0, $$sroa$0$sroa$0$sroa$0$0$extract$trunc602$i = 0, $$sroa$0$sroa$0$sroa$38$0$extract$shift$i = 0, $$sroa$0$sroa$0$sroa$38$0$extract$shift603$i = 0, $$sroa$0$sroa$0$sroa$38$0$extract$shift605$i = 0, $$sroa$0$sroa$0$sroa$38$0$extract$shift611$i = 0, $$sroa$0$sroa$0$sroa$38$0$extract$shift613$i = 0, $$sroa$0$sroa$0$sroa$38$0$extract$shift615$i = 0, $$sroa$0$sroa$0$sroa$38$0$extract$shift621$i = 0;
 var $$sroa$0$sroa$0$sroa$38$0$extract$shift623$i = 0, $$sroa$0$sroa$0$sroa$38$0$extract$shift625$i = 0, $$sroa$0$sroa$0$sroa$38$0$extract$trunc$i = 0, $$sroa$0$sroa$0$sroa$38$0$extract$trunc604$i = 0, $$sroa$0$sroa$0$sroa$38$0$extract$trunc606$i = 0, $$sroa$0$sroa$0$sroa$38$0$extract$trunc610$i = 0, $$sroa$0$sroa$0$sroa$38$0$extract$trunc612$i = 0, $$sroa$0$sroa$0$sroa$38$0$extract$trunc614$i = 0, $$sroa$0$sroa$0$sroa$38$0$extract$trunc616$i = 0, $$sroa$0$sroa$0$sroa$38$0$extract$trunc616$sink$i = 0, $$sroa$0$sroa$0$sroa$38$0$extract$trunc618$i = 0, $$sroa$0$sroa$0$sroa$38$0$extract$trunc622$i = 0, $$sroa$0$sroa$0$sroa$38$0$extract$trunc624$i = 0, $$sroa$0$sroa$0$sroa$38$0$extract$trunc626$i = 0, $$sroa$0$sroa$62$0$extract$shift571$i = 0, $$sroa$0$sroa$62$0$extract$shift573$i = 0, $$sroa$0$sroa$62$0$extract$shift575$i = 0, $$sroa$0$sroa$62$0$extract$trunc$i = 0, $$sroa$0$sroa$62$0$extract$trunc572$i = 0, $$sroa$0$sroa$62$0$extract$trunc572$sink$i = 0;
 var $$sroa$0$sroa$62$0$extract$trunc574$i = 0, $$sroa$0$sroa$62$0$extract$trunc576$i = 0, $$sroa$0$sroa$62$0$extract$trunc578$i = 0, $$sroa$0$sroa$72$0$extract$shift581$i = 0, $$sroa$0$sroa$72$0$extract$shift583$i = 0, $$sroa$0$sroa$72$0$extract$trunc$i = 0, $$sroa$0$sroa$72$0$extract$trunc582$i = 0, $$sroa$0$sroa$72$0$extract$trunc584$i = 0, $$sroa$0$sroa$72$0$extract$trunc586$i = 0, $$sroa$0$sroa$72$0$extract$trunc588$i = 0, $$sroa_raw_idx$i = 0, $$sroa_raw_idx425$i = 0, $$sroa_raw_idx426$i = 0, $$sroa_raw_idx439$i = 0, $$sroa_raw_idx440$i = 0, $$sroa_raw_idx441$i = 0, $$sroa_raw_idx454$i = 0, $$sroa_raw_idx455$i = 0, $$sroa_raw_idx456$i = 0, $$sroa_raw_idx469$i = 0;
 var $$sroa_raw_idx470$i = 0, $$sroa_raw_idx471$i = 0, $$sroa_raw_idx475$i = 0, $$sroa_raw_idx479$i = 0, $$sroa_raw_idx483$i = 0, $$sroa_raw_idx487$i = 0, $$sroa_raw_idx491$i = 0, $$sroa_raw_idx495$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0.0, $158 = 0.0, $159 = 0.0, $16 = 0, $160 = 0, $161 = 0, $162 = 0.0, $163 = 0.0, $164 = 0.0;
 var $165 = 0, $166 = 0, $167 = 0.0, $168 = 0.0, $169 = 0.0, $17 = 0, $170 = 0, $171 = 0.0, $172 = 0.0, $173 = 0.0, $174 = 0.0, $175 = 0.0, $176 = 0.0, $177 = 0, $178 = 0, $179 = 0.0, $18 = 0, $180 = 0.0, $181 = 0.0, $182 = 0;
 var $183 = 0, $184 = 0, $185 = 0, $186 = 0.0, $187 = 0.0, $188 = 0.0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0.0, $194 = 0.0, $195 = 0.0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0;
 var $201 = 0.0, $202 = 0.0, $203 = 0.0, $204 = 0, $205 = 0, $206 = 0.0, $207 = 0.0, $208 = 0.0, $209 = 0, $21 = 0, $210 = 0, $211 = 0.0, $212 = 0.0, $213 = 0.0, $214 = 0, $215 = 0.0, $216 = 0.0, $217 = 0.0, $218 = 0.0, $219 = 0.0;
 var $22 = 0, $220 = 0.0, $221 = 0, $222 = 0, $223 = 0.0, $224 = 0.0, $225 = 0.0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0.0, $231 = 0.0, $232 = 0.0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0.0;
 var $238 = 0.0, $239 = 0.0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0.0, $247 = 0.0, $248 = 0.0, $249 = 0, $25 = 0, $250 = 0, $251 = 0.0, $252 = 0.0, $253 = 0.0, $254 = 0, $255 = 0;
 var $256 = 0.0, $257 = 0.0, $258 = 0.0, $259 = 0, $26 = 0, $260 = 0.0, $261 = 0.0, $262 = 0.0, $263 = 0.0, $264 = 0.0, $265 = 0.0, $266 = 0, $267 = 0.0, $268 = 0.0, $269 = 0.0, $27 = 0, $270 = 0, $271 = 0.0, $272 = 0.0, $273 = 0.0;
 var $274 = 0, $275 = 0.0, $276 = 0.0, $277 = 0.0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0.0, $282 = 0.0, $283 = 0.0, $284 = 0, $285 = 0, $286 = 0.0, $287 = 0.0, $288 = 0.0, $289 = 0, $29 = 0, $290 = 0, $291 = 0.0;
 var $292 = 0.0, $293 = 0.0, $294 = 0, $295 = 0.0, $296 = 0.0, $297 = 0.0, $298 = 0.0, $299 = 0.0, $30 = 0.0, $300 = 0.0, $301 = 0, $302 = 0.0, $303 = 0.0, $304 = 0.0, $305 = 0, $306 = 0.0, $307 = 0.0, $308 = 0.0, $309 = 0, $31 = 0.0;
 var $310 = 0.0, $311 = 0.0, $312 = 0.0, $313 = 0, $314 = 0, $315 = 0, $316 = 0.0, $317 = 0.0, $318 = 0.0, $319 = 0, $32 = 0, $320 = 0, $321 = 0.0, $322 = 0.0, $323 = 0.0, $324 = 0, $325 = 0, $326 = 0.0, $327 = 0.0, $328 = 0.0;
 var $329 = 0, $33 = 0, $330 = 0.0, $331 = 0.0, $332 = 0.0, $333 = 0.0, $334 = 0.0, $335 = 0.0, $336 = 0, $337 = 0, $338 = 0.0, $339 = 0.0, $34 = 0, $340 = 0.0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0;
 var $347 = 0.0, $348 = 0.0, $349 = 0.0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0.0, $355 = 0.0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0.0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0.0;
 var $365 = 0.0, $366 = 0.0, $367 = 0, $368 = 0, $369 = 0.0, $37 = 0.0, $370 = 0.0, $371 = 0.0, $372 = 0, $373 = 0, $374 = 0.0, $375 = 0.0, $376 = 0.0, $377 = 0, $378 = 0.0, $379 = 0.0, $38 = 0, $380 = 0.0, $381 = 0.0, $382 = 0.0;
 var $383 = 0.0, $384 = 0, $385 = 0, $386 = 0, $387 = 0.0, $388 = 0.0, $389 = 0.0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0.0, $396 = 0.0, $397 = 0.0, $398 = 0, $399 = 0, $40 = 0, $400 = 0;
 var $401 = 0, $402 = 0.0, $403 = 0.0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0.0, $413 = 0.0, $414 = 0.0, $415 = 0, $416 = 0, $417 = 0.0, $418 = 0.0, $419 = 0.0;
 var $42 = 0.0, $420 = 0, $421 = 0, $422 = 0.0, $423 = 0.0, $424 = 0.0, $425 = 0, $426 = 0.0, $427 = 0.0, $428 = 0.0, $429 = 0.0, $43 = 0.0, $430 = 0.0, $431 = 0.0, $432 = 0, $433 = 0, $434 = 0.0, $435 = 0.0, $436 = 0.0, $437 = 0;
 var $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0.0, $443 = 0.0, $444 = 0.0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0.0, $45 = 0, $450 = 0.0, $451 = 0.0, $452 = 0, $453 = 0, $454 = 0, $455 = 0;
 var $456 = 0, $457 = 0, $458 = 0, $459 = 0.0, $46 = 0, $460 = 0.0, $461 = 0.0, $462 = 0, $463 = 0, $464 = 0.0, $465 = 0.0, $466 = 0.0, $467 = 0, $468 = 0, $469 = 0.0, $47 = 0, $470 = 0.0, $471 = 0.0, $472 = 0, $473 = 0.0;
 var $474 = 0.0, $475 = 0.0, $476 = 0.0, $477 = 0.0, $478 = 0.0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0.0, $483 = 0.0, $484 = 0.0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0.0, $491 = 0.0;
 var $492 = 0.0, $493 = 0, $494 = 0, $495 = 0, $496 = 0.0, $497 = 0.0, $498 = 0.0, $499 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0.0, $507 = 0.0, $508 = 0.0, $509 = 0, $51 = 0;
 var $510 = 0, $511 = 0.0, $512 = 0.0, $513 = 0.0, $514 = 0, $515 = 0.0, $516 = 0.0, $517 = 0.0, $518 = 0.0, $519 = 0.0, $52 = 0, $520 = 0.0, $521 = 0, $522 = 0, $523 = 0.0, $524 = 0.0, $525 = 0.0, $526 = 0, $527 = 0, $528 = 0;
 var $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0.0, $533 = 0.0, $534 = 0.0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0.0, $543 = 0.0, $544 = 0.0, $545 = 0, $546 = 0;
 var $547 = 0.0, $548 = 0.0, $549 = 0.0, $55 = 0, $550 = 0, $551 = 0.0, $552 = 0.0, $553 = 0.0, $554 = 0.0, $555 = 0.0, $556 = 0.0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0.0, $561 = 0.0, $562 = 0.0, $563 = 0, $564 = 0;
 var $565 = 0, $566 = 0, $567 = 0, $568 = 0.0, $569 = 0.0, $57 = 0, $570 = 0.0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0.0, $579 = 0.0, $58 = 0, $580 = 0.0, $581 = 0, $582 = 0;
 var $583 = 0.0, $584 = 0.0, $585 = 0.0, $586 = 0, $587 = 0.0, $588 = 0.0, $589 = 0.0, $59 = 0, $590 = 0.0, $591 = 0.0, $592 = 0.0, $593 = 0, $594 = 0, $595 = 0.0, $596 = 0.0, $597 = 0.0, $598 = 0, $599 = 0, $60 = 0, $600 = 0;
 var $601 = 0, $602 = 0, $603 = 0, $604 = 0.0, $605 = 0.0, $606 = 0.0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0.0, $615 = 0.0, $616 = 0.0, $617 = 0, $618 = 0, $619 = 0.0;
 var $62 = 0, $620 = 0.0, $621 = 0.0, $622 = 0, $623 = 0.0, $624 = 0.0, $625 = 0.0, $626 = 0.0, $627 = 0.0, $628 = 0.0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0.0, $633 = 0.0, $634 = 0.0, $635 = 0, $636 = 0, $637 = 0;
 var $638 = 0, $639 = 0, $64 = 0, $640 = 0.0, $641 = 0.0, $642 = 0.0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0;
 var $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0;
 var $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0.0, $68 = 0, $680 = 0.0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0;
 var $692 = 0, $693 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i$us = 0, $exitcond773$i = 0, $exitcond774$i = 0, $exitcond774$i$us = 0, $exitcond800$i = 0, $exitcond801$i = 0, $extract$t683$i = 0, $extract$t686$i = 0;
 var $extract685$i = 0, $narrow$i = 0, $not$$i = 0, $or$cond = 0, $or$cond13 = 0, $or$cond3 = 0, $or$cond5 = 0, $or$cond5$i = 0, $or$cond5$i85 = 0, $or$cond7$i = 0, $or$cond7$i86 = 0, $scevgep776$i = 0, $scevgep778$i = 0, $scevgep780$i = 0, $scevgep782$i = 0, $scevgep784$i = 0, $scevgep786$i = 0, $scevgep788$i = 0, $scevgep790$i = 0, $scevgep792$i = 0;
 var $scevgep794$i = 0, $scevgep796$i = 0, $scevgep798$i = 0, $split$us$i = 0, $split$us$i$us = 0, $switch$split102D = 0, $switch$split12D = 0, $switch$split132D = 0, $switch$split162D = 0, $switch$split192D = 0, $switch$split222D = 0, $switch$split252D = 0, $switch$split282D = 0, $switch$split2D = 0, $switch$split312D = 0, $switch$split342D = 0, $switch$split372D = 0, $switch$split402D = 0, $switch$split42D = 0, $switch$split432D = 0;
 var $switch$split462D = 0, $switch$split492D = 0, $switch$split522D = 0, $switch$split552D = 0, $switch$split582D = 0, $switch$split612D = 0, $switch$split642D = 0, $switch$split672D = 0, $switch$split702D = 0, $switch$split72D = 0, $switch$split732D = 0, $switch$split762D = 0, $switch$split792D = 0, $switch$split822D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $10 = ($2|0)==(0);
 $11 = ($3|0)==(0);
 $or$cond = $10 | $11;
 $12 = ($6|0)==(0);
 $or$cond3 = $or$cond | $12;
 $13 = ($7|0)==(0);
 $or$cond5 = $or$cond3 | $13;
 if ($or$cond5) {
  $$0 = 0;
  return ($$0|0);
 }
 $14 = $3 | $2;
 $15 = $14 | $6;
 $16 = $15 | $7;
 $17 = ($16|0)<(0);
 if ($17) {
  $$0 = 100901;
  return ($$0|0);
 }
 $switch$split2D = ($1|0)<(6406);
 L7: do {
  if ($switch$split2D) {
   switch ($1|0) {
   case 6405: case 6404: case 6403: case 6402: case 6401: case 6400:  {
    break L7;
    break;
   }
   default: {
    $$0 = 100900;
   }
   }
   return ($$0|0);
  } else {
   $switch$split312D = ($1|0)<(6409);
   if ($switch$split312D) {
    switch ($1|0) {
    case 6408: case 6407: case 6406:  {
     break L7;
     break;
    }
    default: {
     $$0 = 100900;
    }
    }
    return ($$0|0);
   }
   $switch$split582D = ($1|0)<(32992);
   if ($switch$split582D) {
    switch ($1|0) {
    case 6410: case 6409:  {
     break L7;
     break;
    }
    default: {
     $$0 = 100900;
    }
    }
    return ($$0|0);
   } else {
    switch ($1|0) {
    case 32993: case 32992:  {
     break L7;
     break;
    }
    default: {
     $$0 = 100900;
    }
    }
    return ($$0|0);
   }
  }
 } while(0);
 $switch$split12D = ($4|0)<(32820);
 L21: do {
  if ($switch$split12D) {
   $switch$split342D = ($4|0)<(5125);
   if ($switch$split342D) {
    switch ($4|0) {
    case 5124: case 5123: case 5122: case 5121: case 5120:  {
     break L21;
     break;
    }
    default: {
     $$0 = 100900;
    }
    }
    return ($$0|0);
   }
   $switch$split612D = ($4|0)<(6656);
   if ($switch$split612D) {
    switch ($4|0) {
    case 5126: case 5125:  {
     break L21;
     break;
    }
    default: {
     $$0 = 100900;
    }
    }
    return ($$0|0);
   }
   $switch$split732D = ($4|0)<(32818);
   if ($switch$split732D) {
    switch ($4|0) {
    case 6656:  {
     break L21;
     break;
    }
    default: {
     $$0 = 100900;
    }
    }
    return ($$0|0);
   } else {
    switch ($4|0) {
    case 32819: case 32818:  {
     break L21;
     break;
    }
    default: {
     $$0 = 100900;
    }
    }
    return ($$0|0);
   }
  } else {
   switch ($4|0) {
   case 33640: case 32822: case 33639: case 32821: case 33638: case 32820: case 33637: case 33636: case 33635: case 33634:  {
    break L21;
    break;
   }
   default: {
    $$0 = 100900;
   }
   }
   return ($$0|0);
  }
 } while(0);
 $switch$split42D = ($8|0)<(32820);
 L39: do {
  if ($switch$split42D) {
   $switch$split372D = ($8|0)<(5125);
   if ($switch$split372D) {
    switch ($8|0) {
    case 5124: case 5123: case 5122: case 5121: case 5120:  {
     break L39;
     break;
    }
    default: {
     $$0 = 100900;
    }
    }
    return ($$0|0);
   }
   $switch$split642D = ($8|0)<(6656);
   if ($switch$split642D) {
    switch ($8|0) {
    case 5126: case 5125:  {
     break L39;
     break;
    }
    default: {
     $$0 = 100900;
    }
    }
    return ($$0|0);
   }
   $switch$split762D = ($8|0)<(32818);
   if ($switch$split762D) {
    switch ($8|0) {
    case 6656:  {
     break L39;
     break;
    }
    default: {
     $$0 = 100900;
    }
    }
    return ($$0|0);
   } else {
    switch ($8|0) {
    case 32819: case 32818:  {
     break L39;
     break;
    }
    default: {
     $$0 = 100900;
    }
    }
    return ($$0|0);
   }
  } else {
   switch ($8|0) {
   case 33640: case 32822: case 33639: case 32821: case 33638: case 32820: case 33637: case 33636: case 33635: case 33634:  {
    break L39;
    break;
   }
   default: {
    $$0 = 100900;
   }
   }
   return ($$0|0);
  }
 } while(0);
 L57: do {
  switch ($4|0) {
  case 32818: case 32819: case 32820: case 32821: case 32822: case 33634: case 33635: case 33636: case 33637: case 33638: case 33639: case 33640:  {
   $18 = ($4|0)==(32818);
   $19 = $4 | 1;
   $20 = ($19|0)==(33635);
   $21 = $18 | $20;
   $22 = ($4|0)==(33636);
   $or$cond5$i85 = $22 | $21;
   $23 = ($1|0)!=(6407);
   $or$cond7$i86 = $23 & $or$cond5$i85;
   if ($or$cond7$i86) {
    $$0 = 100904;
    return ($$0|0);
   }
   switch ($4|0) {
   case 32819: case 32820: case 32821: case 32822: case 33637: case 33638: case 33639: case 33640:  {
    break;
   }
   default: {
    break L57;
   }
   }
   $switch$split72D = ($1|0)<(32993);
   if ($switch$split72D) {
    switch ($1|0) {
    case 6408:  {
     break L57;
     break;
    }
    default: {
     $$0 = 100904;
    }
    }
    return ($$0|0);
   } else {
    switch ($1|0) {
    case 32993:  {
     break L57;
     break;
    }
    default: {
     $$0 = 100904;
    }
    }
    return ($$0|0);
   }
   break;
  }
  default: {
  }
  }
 } while(0);
 L69: do {
  switch ($8|0) {
  case 32818: case 32819: case 32820: case 32821: case 32822: case 33634: case 33635: case 33636: case 33637: case 33638: case 33639: case 33640:  {
   $24 = ($8|0)==(32818);
   $25 = $8 | 1;
   $26 = ($25|0)==(33635);
   $27 = $24 | $26;
   $28 = ($8|0)==(33636);
   $or$cond5$i = $28 | $27;
   $29 = ($1|0)!=(6407);
   $or$cond7$i = $29 & $or$cond5$i;
   if ($or$cond7$i) {
    $$0 = 100904;
    return ($$0|0);
   }
   switch ($8|0) {
   case 32819: case 32820: case 32821: case 32822: case 33637: case 33638: case 33639: case 33640:  {
    break;
   }
   default: {
    label = 14;
    break L69;
   }
   }
   $switch$split102D = ($1|0)<(32993);
   if ($switch$split102D) {
    switch ($1|0) {
    case 6408:  {
     label = 16;
     break L69;
     break;
    }
    default: {
     $$0 = 100904;
    }
    }
    return ($$0|0);
   } else {
    switch ($1|0) {
    case 32993:  {
     label = 16;
     break L69;
     break;
    }
    default: {
     $$0 = 100904;
    }
    }
    return ($$0|0);
   }
   break;
  }
  default: {
   label = 14;
  }
  }
 } while(0);
 L80: do {
  if ((label|0) == 14) {
   $switch$split132D = ($1|0)<(6410);
   L82: do {
    if ($switch$split132D) {
     switch ($1|0) {
     case 6407:  {
      $$0$i$i78 = 3;
      label = 18;
      break L80;
      break;
     }
     case 6408:  {
      label = 16;
      break L80;
      break;
     }
     default: {
     }
     }
    } else {
     $switch$split402D = ($1|0)<(32992);
     if (!($switch$split402D)) {
      switch ($1|0) {
      case 32992:  {
       $$0$i$i78 = 3;
       label = 18;
       break L80;
       break;
      }
      case 32993:  {
       label = 16;
       break L80;
       break;
      }
      default: {
       break L82;
      }
      }
     }
     switch ($1|0) {
     case 6410:  {
      break;
     }
     default: {
      break L82;
     }
     }
     $30 = (+($2|0));
     $31 = $30 * 2.0;
     $32 = (~~(($31))>>>0);
     $33 = $3 << 1;
     $34 = Math_imul($33, $32)|0;
     $35 = (_malloc($34)|0);
     $692 = $35;$693 = $35;
     label = 19;
     break L80;
    }
   } while(0);
   $$0$i$i78 = 1;
   label = 18;
  }
 } while(0);
 if ((label|0) == 16) {
  $$0$i$i78 = 4;
  label = 18;
 }
 L92: do {
  if ((label|0) == 18) {
   $36 = (+($2|0));
   $37 = $36 * 2.0;
   $38 = (~~(($37))>>>0);
   $39 = Math_imul($38, $3)|0;
   $40 = Math_imul($39, $$0$i$i78)|0;
   $41 = (_malloc($40)|0);
   $switch$split162D = ($1|0)<(6410);
   L94: do {
    if ($switch$split162D) {
     switch ($1|0) {
     case 6407:  {
      $$0$i$i73 = 3;$48 = $41;$54 = $41;
      break L92;
      break;
     }
     case 6408:  {
      label = 20;
      break;
     }
     default: {
      label = 21;
     }
     }
    } else {
     $switch$split432D = ($1|0)<(32992);
     if ($switch$split432D) {
      switch ($1|0) {
      case 6410:  {
       $692 = $41;$693 = $41;
       label = 19;
       break L92;
       break;
      }
      default: {
       label = 21;
       break L94;
      }
      }
     } else {
      switch ($1|0) {
      case 32992:  {
       $$0$i$i73 = 3;$48 = $41;$54 = $41;
       break L92;
       break;
      }
      case 32993:  {
       label = 20;
       break L94;
       break;
      }
      default: {
       label = 21;
       break L94;
      }
      }
     }
    }
   } while(0);
   if ((label|0) == 20) {
    $$0$i$i73 = 4;$48 = $41;$54 = $41;
    break;
   }
   else if ((label|0) == 21) {
    $$0$i$i73 = 1;$48 = $41;$54 = $41;
    break;
   }
  }
 } while(0);
 if ((label|0) == 19) {
  $$0$i$i73 = 2;$48 = $693;$54 = $692;
 }
 $42 = (+($6|0));
 $43 = $42 * 2.0;
 $44 = (~~(($43))>>>0);
 $45 = Math_imul($44, $7)|0;
 $46 = Math_imul($45, $$0$i$i73)|0;
 $47 = (_malloc($46)|0);
 $49 = ($48|0)==(0|0);
 $50 = ($47|0)==(0|0);
 $or$cond13 = $49 | $50;
 if ($or$cond13) {
  _free($48);
  _free($47);
  $$0 = 100902;
  return ($$0|0);
 }
 $51 = $1 | 1;
 $52 = ($51|0)==(6401);
 $53 = $52&1;
 __ZN3osgL10fill_imageEPKNS_17PixelStorageModesEiijjhPKvPt($0,$2,$3,$1,$4,$53,$5,$54);
 $switch$split192D = ($1|0)<(6410);
 L110: do {
  if ($switch$split192D) {
   switch ($1|0) {
   case 6407:  {
    $$0$i70 = 3;
    break;
   }
   case 6408:  {
    label = 26;
    break;
   }
   default: {
    label = 27;
   }
   }
  } else {
   $switch$split462D = ($1|0)<(32992);
   if (!($switch$split462D)) {
    switch ($1|0) {
    case 32992:  {
     $$0$i70 = 3;
     break L110;
     break;
    }
    case 32993:  {
     label = 26;
     break L110;
     break;
    }
    default: {
     label = 27;
     break L110;
    }
    }
   }
   switch ($1|0) {
   case 6410:  {
    break;
   }
   default: {
    label = 27;
    break L110;
   }
   }
   $$0$i70 = 2;
  }
 } while(0);
 if ((label|0) == 26) {
  $$0$i70 = 4;
 }
 else if ((label|0) == 27) {
  $$0$i70 = 1;
 }
 __ZN3osgL14scale_internalEiiiPKtiiPt($$0$i70,$2,$3,$54,$6,$7,$47);
 $55 = ((($0)) + 20|0);
 $56 = HEAP32[$55>>2]|0;
 L121: do {
  switch ($8|0) {
  case 32818: case 32819: case 32820: case 32821: case 32822: case 33634: case 33635: case 33636: case 33637: case 33638: case 33639: case 33640:  {
   $57 = ((($0)) + 4|0);
   $58 = HEAP32[$57>>2]|0;
   $59 = ($58|0)>(0);
   $$673$i = $59 ? $58 : $6;
   $$0$i674$i = 1;$$675$i = $$673$i;
   label = 52;
   break;
  }
  default: {
   $switch$split222D = ($1|0)<(6410);
   L123: do {
    if ($switch$split222D) {
     switch ($1|0) {
     case 6407:  {
      $$0$i$i = 3;
      break;
     }
     case 6408:  {
      label = 31;
      break;
     }
     default: {
      label = 32;
     }
     }
    } else {
     $switch$split492D = ($1|0)<(32992);
     if (!($switch$split492D)) {
      switch ($1|0) {
      case 32992:  {
       $$0$i$i = 3;
       break L123;
       break;
      }
      case 32993:  {
       label = 31;
       break L123;
       break;
      }
      default: {
       label = 32;
       break L123;
      }
      }
     }
     switch ($1|0) {
     case 6410:  {
      break;
     }
     default: {
      label = 32;
      break L123;
     }
     }
     $$0$i$i = 2;
    }
   } while(0);
   if ((label|0) == 31) {
    $$0$i$i = 4;
   }
   else if ((label|0) == 32) {
    $$0$i$i = 1;
   }
   $60 = ((($0)) + 4|0);
   $61 = HEAP32[$60>>2]|0;
   $62 = ($61|0)>(0);
   $$$i = $62 ? $61 : $6;
   $63 = ($8|0)==(6656);
   if ($63) {
    $64 = Math_imul($$$i, $$0$i$i)|0;
    $65 = (($64) + 7)|0;
    $66 = (($65|0) / 8)&-1;
    $67 = HEAP32[$0>>2]|0;
    $68 = (($66|0) % ($67|0))&-1;
    $69 = ($68|0)==(0);
    $70 = (($67) - ($68))|0;
    $71 = $69 ? 0 : $70;
    $$0296$i = (($71) + ($66))|0;
    $72 = ((($0)) + 12|0);
    $73 = Math_imul($$0$i$i, $6)|0;
    $74 = ($7|0)>(0);
    if ($74) {
     $75 = HEAP32[$72>>2]|0;
     $76 = ($73|0)>(0);
     $77 = ((($0)) + 16|0);
     if ($76) {
      $78 = ((($0)) + 8|0);
      $79 = HEAP32[$78>>2]|0;
      $80 = Math_imul($79, $$0296$i)|0;
      $81 = (($9) + ($80)|0);
      $82 = Math_imul($75, $$0$i$i)|0;
      $83 = (($82|0) / 8)&-1;
      $84 = (($81) + ($83)|0);
      if ($52) {
       $$0277706$us$i$us = 0;$$0279705$us$i$us = $47;$$0294704$us$i$us = $84;$86 = $75;
       while(1) {
        $85 = Math_imul($86, $$0$i$i)|0;
        $87 = (($85|0) % 8)&-1;
        $$0271703$us709$i$us = $87;$$0275702$us710$i$us = 0;$$0291700$us712$i$us = $$0294704$us$i$us;$$1280701$us711$i$us = $$0279705$us$i$us;
        while(1) {
         $88 = HEAP16[$$1280701$us711$i$us>>1]|0;
         $89 = $88 & 1;
         $90 = ($89<<16>>16)==(0);
         $91 = HEAP32[$77>>2]|0;
         $92 = ($91|0)!=(0);
         $93 = (7 - ($$0271703$us709$i$us))|0;
         $$pn299$us713$i$us = $92 ? $$0271703$us709$i$us : $93;
         $$sink9$in$us714$i$us = 1 << $$pn299$us713$i$us;
         if ($90) {
          $$sink9$us715$i$us = $$sink9$in$us714$i$us ^ -1;
          $97 = HEAP8[$$0291700$us712$i$us>>0]|0;
          $98 = $97&255;
          $99 = $98 & $$sink9$us715$i$us;
          $$sink13$us716$i$us = $99;
         } else {
          $94 = HEAP8[$$0291700$us712$i$us>>0]|0;
          $95 = $94&255;
          $96 = $95 | $$sink9$in$us714$i$us;
          $$sink13$us716$i$us = $96;
         }
         $100 = $$sink13$us716$i$us&255;
         HEAP8[$$0291700$us712$i$us>>0] = $100;
         $101 = (($$0271703$us709$i$us) + 1)|0;
         $102 = ($101|0)==(8);
         $103 = ((($$0291700$us712$i$us)) + 1|0);
         $$$0291$us717$i$us = $102 ? $103 : $$0291700$us712$i$us;
         $$301$us718$i$us = $102 ? 0 : $101;
         $104 = ((($$1280701$us711$i$us)) + 2|0);
         $105 = (($$0275702$us710$i$us) + 1)|0;
         $exitcond$i$us = ($105|0)==($73|0);
         if ($exitcond$i$us) {
          break;
         } else {
          $$0271703$us709$i$us = $$301$us718$i$us;$$0275702$us710$i$us = $105;$$0291700$us712$i$us = $$$0291$us717$i$us;$$1280701$us711$i$us = $104;
         }
        }
        $107 = (($$0277706$us$i$us) + 1)|0;
        $exitcond774$i$us = ($107|0)==($7|0);
        if ($exitcond774$i$us) {
         break L121;
        }
        $106 = (($$0294704$us$i$us) + ($$0296$i)|0);
        $split$us$i$us = (($$0279705$us$i$us) + ($73<<1)|0);
        $$pre$i$us = HEAP32[$72>>2]|0;
        $$0277706$us$i$us = $107;$$0279705$us$i$us = $split$us$i$us;$$0294704$us$i$us = $106;$86 = $$pre$i$us;
       }
      } else {
       $$0277706$us$i = 0;$$0279705$us$i = $47;$$0294704$us$i = $84;$109 = $75;
       while(1) {
        $108 = Math_imul($109, $$0$i$i)|0;
        $110 = (($108|0) % 8)&-1;
        $$0271703$us$us$i = $110;$$0275702$us$us$i = 0;$$0291700$us$us$i = $$0294704$us$i;$$1280701$us$us$i = $$0279705$us$i;
        while(1) {
         $113 = HEAP16[$$1280701$us$us$i>>1]|0;
         $114 = ($113<<16>>16)>(-1);
         $115 = HEAP32[$77>>2]|0;
         $116 = ($115|0)!=(0);
         $117 = (7 - ($$0271703$us$us$i))|0;
         $$pn299$us$us$i = $116 ? $$0271703$us$us$i : $117;
         $$sink9$in$us$us$i = 1 << $$pn299$us$us$i;
         if ($114) {
          $$sink9$us$us$i = $$sink9$in$us$us$i ^ -1;
          $121 = HEAP8[$$0291700$us$us$i>>0]|0;
          $122 = $121&255;
          $123 = $122 & $$sink9$us$us$i;
          $$sink13$us$us$i = $123;
         } else {
          $118 = HEAP8[$$0291700$us$us$i>>0]|0;
          $119 = $118&255;
          $120 = $119 | $$sink9$in$us$us$i;
          $$sink13$us$us$i = $120;
         }
         $124 = $$sink13$us$us$i&255;
         HEAP8[$$0291700$us$us$i>>0] = $124;
         $125 = (($$0271703$us$us$i) + 1)|0;
         $126 = ($125|0)==(8);
         $127 = ((($$0291700$us$us$i)) + 1|0);
         $$$0291$us$us$i = $126 ? $127 : $$0291700$us$us$i;
         $$301$us$us$i = $126 ? 0 : $125;
         $128 = ((($$1280701$us$us$i)) + 2|0);
         $129 = (($$0275702$us$us$i) + 1)|0;
         $exitcond773$i = ($129|0)==($73|0);
         if ($exitcond773$i) {
          break;
         } else {
          $$0271703$us$us$i = $$301$us$us$i;$$0275702$us$us$i = $129;$$0291700$us$us$i = $$$0291$us$us$i;$$1280701$us$us$i = $128;
         }
        }
        $111 = (($$0277706$us$i) + 1)|0;
        $exitcond774$i = ($111|0)==($7|0);
        if ($exitcond774$i) {
         break L121;
        }
        $112 = (($$0294704$us$i) + ($$0296$i)|0);
        $split$us$i = (($$0279705$us$i) + ($73<<1)|0);
        $$pre$i = HEAP32[$72>>2]|0;
        $$0277706$us$i = $111;$$0279705$us$i = $split$us$i;$$0294704$us$i = $112;$109 = $$pre$i;
       }
      }
     }
    }
   } else {
    $$0$i674$i = $$0$i$i;$$675$i = $$$i;
    label = 52;
   }
  }
  }
 } while(0);
 if ((label|0) == 52) {
  $switch$split252D = ($8|0)<(32820);
  L161: do {
   if ($switch$split252D) {
    $switch$split522D = ($8|0)<(5125);
    if ($switch$split522D) {
     switch ($8|0) {
     case 5123:  {
      $$0$i304$i = 2;
      break L161;
      break;
     }
     case 5122:  {
      $$0$i304$i = 2;
      break L161;
      break;
     }
     case 5121:  {
      $$0$i304$i = 1;
      break L161;
      break;
     }
     case 5120:  {
      $$0$i304$i = 1;
      break L161;
      break;
     }
     case 5124:  {
      $$0$i304$i = 4;
      break L161;
      break;
     }
     default: {
      label = 63;
      break L161;
     }
     }
    }
    $switch$split672D = ($8|0)<(6656);
    if ($switch$split672D) {
     switch ($8|0) {
     case 5125:  {
      $$0$i304$i = 4;
      break L161;
      break;
     }
     case 5126:  {
      $$0$i304$i = 4;
      break L161;
      break;
     }
     default: {
      label = 63;
      break L161;
     }
     }
    } else {
     $switch$split792D = ($8|0)<(32818);
     if ($switch$split792D) {
      switch ($8|0) {
      case 6656:  {
       $$0$i304$i = 0;
       break L161;
       break;
      }
      default: {
       label = 63;
       break L161;
      }
      }
     } else {
      switch ($8|0) {
      case 32818:  {
       label = 60;
       break L161;
       break;
      }
      case 32819:  {
       label = 61;
       break L161;
       break;
      }
      default: {
       label = 63;
       break L161;
      }
      }
     }
    }
   } else {
    switch ($8|0) {
    case 33634:  {
     label = 60;
     break L161;
     break;
    }
    case 33638: case 32820: case 33637: case 33636: case 33635:  {
     label = 61;
     break L161;
     break;
    }
    case 33640: case 32822: case 33639: case 32821:  {
     break;
    }
    default: {
     label = 63;
     break L161;
    }
    }
    $$0$i304$i = 4;
   }
  } while(0);
  if ((label|0) == 60) {
   $$0$i304$i = 1;
  }
  else if ((label|0) == 61) {
   $$0$i304$i = 2;
  }
  else if ((label|0) == 63) {
   $$0$i304$i = 4;
  }
  $130 = Math_imul($$0$i304$i, $$0$i674$i)|0;
  $131 = Math_imul($130, $$675$i)|0;
  $132 = HEAP32[$0>>2]|0;
  $133 = (($131|0) % ($132|0))&-1;
  $134 = ($133|0)==(0);
  $135 = (($132) - ($133))|0;
  $136 = $134 ? 0 : $135;
  $$1297$i = (($136) + ($131))|0;
  $137 = Math_imul($$0$i674$i, $6)|0;
  $138 = ($7|0)>(0);
  if ($138) {
   $139 = ($$0$i304$i|0)==(1);
   $140 = ((($0)) + 8|0);
   $141 = HEAP32[$140>>2]|0;
   $142 = Math_imul($141, $$1297$i)|0;
   $143 = (($9) + ($142)|0);
   $144 = ((($0)) + 12|0);
   $145 = HEAP32[$144>>2]|0;
   $146 = Math_imul($145, $130)|0;
   $147 = (($143) + ($146)|0);
   $148 = ($137|0)>(0);
   $149 = $52 ^ 1;
   $150 = ($56|0)==(0);
   $151 = $150 | $139;
   $152 = ($8|0)==(5122);
   $153 = ($8|0)==(5126);
   $not$$i = ($8|0)!=(5125);
   $154 = $not$$i&1;
   $narrow$i = $152 & $149;
   $$303$i = $narrow$i&1;
   $$1278755$i = 0;$$1295753$i = $147;$$2281754$i = $47;
   while(1) {
    if ($148) {
     $$1276749$i = 0;$$2293746$i = $$1295753$i;$$3282748$i = $$2281754$i;
     while(1) {
      $switch$split282D = ($8|0)<(32820);
      L194: do {
       if ($switch$split282D) {
        $switch$split552D = ($8|0)<(5124);
        if ($switch$split552D) {
         switch ($8|0) {
         case 5121:  {
          $648 = ((($$3282748$i)) + 2|0);
          $649 = HEAP16[$$3282748$i>>1]|0;
          if ($52) {
           $650 = $649&255;
           HEAP8[$$2293746$i>>0] = $650;
           $$18$i = $648;
           break L194;
          } else {
           $651 = ($649&65535) >>> 8;
           $652 = $651&255;
           HEAP8[$$2293746$i>>0] = $652;
           $$18$i = $648;
           break L194;
          }
          break;
         }
         case 5120:  {
          $653 = ((($$3282748$i)) + 2|0);
          $654 = HEAP16[$$3282748$i>>1]|0;
          if ($52) {
           $655 = $654&255;
           HEAP8[$$2293746$i>>0] = $655;
           $$18$i = $653;
           break L194;
          } else {
           $656 = ($654&65535) >>> 9;
           $657 = $656&255;
           HEAP8[$$2293746$i>>0] = $657;
           $$18$i = $653;
           break L194;
          }
          break;
         }
         case 5122: case 5123:  {
          $664 = HEAP16[$$3282748$i>>1]|0;
          $$303$sink687$i = ($664&65535) >>> $$303$i;
          $extract$t683$i = $$303$sink687$i&255;
          $extract685$i = ($$303$sink687$i&65535) >>> 8;
          $extract$t686$i = $extract685$i&255;
          $$12$i = ((($$3282748$i)) + 2|0);
          $$sroa$0$sroa$0$sroa$0$0$extract$trunc599$sink$i = $151 ? $extract$t683$i : $extract$t686$i;
          $$sink20$in$sroa$speculated$i = $151 ? $extract$t686$i : $extract$t683$i;
          HEAP8[$$2293746$i>>0] = $$sroa$0$sroa$0$sroa$0$0$extract$trunc599$sink$i;
          $665 = ((($$2293746$i)) + 1|0);
          HEAP8[$665>>0] = $$sink20$in$sroa$speculated$i;
          $$18$i = $$12$i;
          break L194;
          break;
         }
         default: {
          $$18$i = $$3282748$i;
          break L194;
         }
         }
        }
        $switch$split702D = ($8|0)<(5126);
        L209: do {
         if ($switch$split702D) {
          switch ($8|0) {
          case 5125: case 5124:  {
           break;
          }
          default: {
           $$18$i = $$3282748$i;
           break L194;
          }
          }
         } else {
          $switch$split822D = ($8|0)<(32818);
          if ($switch$split822D) {
           switch ($8|0) {
           case 5126:  {
            break L209;
            break;
           }
           default: {
            $$18$i = $$3282748$i;
            break L194;
           }
           }
          }
          switch ($8|0) {
          case 32818:  {
           $612 = ((($$3282748$i)) + 2|0);
           $613 = HEAP16[$$3282748$i>>1]|0;
           $614 = (+($613&65535));
           $615 = $614 / 65535.0;
           $616 = $615;
           $617 = ((($$3282748$i)) + 4|0);
           $618 = HEAP16[$612>>1]|0;
           $619 = (+($618&65535));
           $620 = $619 / 65535.0;
           $621 = $620;
           $622 = HEAP16[$617>>1]|0;
           $623 = (+($622&65535));
           $624 = $623 / 65535.0;
           $625 = $624;
           $scevgep798$i = ((($$3282748$i)) + 6|0);
           $626 = $616 * 7.0;
           $627 = $626;
           $628 = $627 + 0.5;
           $629 = (~~(($628))&255);
           $630 = $629&255;
           $631 = $630 << 5;
           $632 = $621 * 7.0;
           $633 = $632;
           $634 = $633 + 0.5;
           $635 = (~~(($634))&255);
           $636 = $635&255;
           $637 = $636 << 2;
           $638 = $637 & 28;
           $639 = $638 | $631;
           $640 = $625 * 3.0;
           $641 = $640;
           $642 = $641 + 0.5;
           $643 = (~~(($642))&255);
           $644 = $643 & 3;
           $645 = $644&255;
           $646 = $639 | $645;
           $647 = $646&255;
           HEAP8[$$2293746$i>>0] = $647;
           $$18$i = $scevgep798$i;
           break L194;
           break;
          }
          case 32819:  {
           break;
          }
          default: {
           $$18$i = $$3282748$i;
           break L194;
          }
          }
          $457 = ((($$3282748$i)) + 2|0);
          $458 = HEAP16[$$3282748$i>>1]|0;
          $459 = (+($458&65535));
          $460 = $459 / 65535.0;
          $461 = $460;
          $462 = ((($$3282748$i)) + 4|0);
          $463 = HEAP16[$457>>1]|0;
          $464 = (+($463&65535));
          $465 = $464 / 65535.0;
          $466 = $465;
          $467 = ((($$3282748$i)) + 6|0);
          $468 = HEAP16[$462>>1]|0;
          $469 = (+($468&65535));
          $470 = $469 / 65535.0;
          $471 = $470;
          $472 = HEAP16[$467>>1]|0;
          $473 = (+($472&65535));
          $474 = $473 / 65535.0;
          $475 = $474;
          $scevgep790$i = ((($$3282748$i)) + 8|0);
          $476 = $461 * 15.0;
          $477 = $476;
          $478 = $477 + 0.5;
          $479 = (~~(($478))&65535);
          $480 = $479&65535;
          $481 = $480 << 12;
          $482 = $466 * 15.0;
          $483 = $482;
          $484 = $483 + 0.5;
          $485 = (~~(($484))&65535);
          $486 = $485&65535;
          $487 = $486 << 8;
          $488 = $487 & 3840;
          $489 = $488 | $481;
          $490 = $471 * 15.0;
          $491 = $490;
          $492 = $491 + 0.5;
          $493 = (~~(($492))&65535);
          $494 = $493&65535;
          $495 = $494 << 4;
          $496 = $475 * 15.0;
          $497 = $496;
          $498 = $497 + 0.5;
          $499 = (~~(($498))&65535);
          $500 = $499 & 15;
          $501 = $500&65535;
          $502 = $501 | $495;
          $503 = $489&65535;
          $$sroa$0$sroa$0$sroa$0$0$extract$trunc601$i = $502&255;
          $$sroa$0$sroa$0$sroa$38$0$extract$shift623$i = ($503&65535) >>> 8;
          $$sroa$0$sroa$0$sroa$38$0$extract$trunc624$i = $$sroa$0$sroa$0$sroa$38$0$extract$shift623$i&255;
          if ($151) {
           HEAP8[$$2293746$i>>0] = $$sroa$0$sroa$0$sroa$0$0$extract$trunc601$i;
           $$sroa_raw_idx491$i = ((($$2293746$i)) + 1|0);
           HEAP8[$$sroa_raw_idx491$i>>0] = $$sroa$0$sroa$0$sroa$38$0$extract$trunc624$i;
           $$18$i = $scevgep790$i;
           break L194;
          } else {
           HEAP8[$$2293746$i>>0] = $$sroa$0$sroa$0$sroa$38$0$extract$trunc624$i;
           $660 = ((($$2293746$i)) + 1|0);
           HEAP8[$660>>0] = $$sroa$0$sroa$0$sroa$0$0$extract$trunc601$i;
           $$18$i = $scevgep790$i;
           break L194;
          }
         }
        } while(0);
        $678 = HEAP16[$$3282748$i>>1]|0;
        if ($153) {
         $679 = (+($678&65535));
         $680 = $679 / 65535.0;
         $$sink23$i = $52 ? $679 : $680;
         $681 = (HEAPF32[tempDoublePtr>>2]=$$sink23$i,HEAP32[tempDoublePtr>>2]|0);
         $$sink27$sink$sink$i = $681;
        } else {
         $682 = $678&65535;
         $683 = ($682*65537)|0;
         $$sink$i = $683 >>> $154;
         $$678$i = $52 ? $682 : $$sink$i;
         $$sink27$sink$sink$i = $$678$i;
        }
        $$sroa$0$sroa$0$0$extract$trunc519$i = $$sink27$sink$sink$i&65535;
        $$sroa$0$sroa$0$sroa$0$0$extract$trunc597$i = $$sink27$sink$sink$i&255;
        $$sroa$0$sroa$0$sroa$38$0$extract$shift615$i = ($$sroa$0$sroa$0$0$extract$trunc519$i&65535) >>> 8;
        $$sroa$0$sroa$0$sroa$38$0$extract$trunc616$i = $$sroa$0$sroa$0$sroa$38$0$extract$shift615$i&255;
        $$sroa$0$sroa$62$0$extract$shift571$i = $$sink27$sink$sink$i >>> 16;
        $$sroa$0$sroa$62$0$extract$trunc572$i = $$sroa$0$sroa$62$0$extract$shift571$i&255;
        $$sroa$0$sroa$72$0$extract$shift581$i = $$sink27$sink$sink$i >>> 24;
        $$sroa$0$sroa$72$0$extract$trunc582$i = $$sroa$0$sroa$72$0$extract$shift581$i&255;
        $$17$i = ((($$3282748$i)) + 2|0);
        if ($151) {
         HEAP8[$$2293746$i>>0] = $$sroa$0$sroa$0$sroa$0$0$extract$trunc597$i;
         $685 = ((($$2293746$i)) + 3|0);
         $$sink31$i = $685;$$sroa$0$sroa$0$sroa$38$0$extract$trunc616$sink$i = $$sroa$0$sroa$62$0$extract$trunc572$i;$$sroa$0$sroa$62$0$extract$trunc572$sink$i = $$sroa$0$sroa$0$sroa$38$0$extract$trunc616$i;
        } else {
         $684 = ((($$2293746$i)) + 3|0);
         HEAP8[$684>>0] = $$sroa$0$sroa$0$sroa$0$0$extract$trunc597$i;
         $$sink31$i = $$2293746$i;$$sroa$0$sroa$0$sroa$38$0$extract$trunc616$sink$i = $$sroa$0$sroa$0$sroa$38$0$extract$trunc616$i;$$sroa$0$sroa$62$0$extract$trunc572$sink$i = $$sroa$0$sroa$62$0$extract$trunc572$i;
        }
        $686 = ((($$2293746$i)) + 1|0);
        HEAP8[$686>>0] = $$sroa$0$sroa$62$0$extract$trunc572$sink$i;
        $687 = ((($$2293746$i)) + 2|0);
        HEAP8[$687>>0] = $$sroa$0$sroa$0$sroa$38$0$extract$trunc616$sink$i;
        HEAP8[$$sink31$i>>0] = $$sroa$0$sroa$72$0$extract$trunc582$i;
        $$18$i = $$17$i;
       } else {
        do {
         switch ($8|0) {
         case 33634:  {
          $576 = ((($$3282748$i)) + 2|0);
          $577 = HEAP16[$$3282748$i>>1]|0;
          $578 = (+($577&65535));
          $579 = $578 / 65535.0;
          $580 = $579;
          $581 = ((($$3282748$i)) + 4|0);
          $582 = HEAP16[$576>>1]|0;
          $583 = (+($582&65535));
          $584 = $583 / 65535.0;
          $585 = $584;
          $586 = HEAP16[$581>>1]|0;
          $587 = (+($586&65535));
          $588 = $587 / 65535.0;
          $589 = $588;
          $scevgep796$i = ((($$3282748$i)) + 6|0);
          $590 = $580;
          $591 = $590 * 7.0;
          $592 = $591 + 0.5;
          $593 = (~~(($592))&255);
          $594 = $593 & 7;
          $595 = $585;
          $596 = $595 * 7.0;
          $597 = $596 + 0.5;
          $598 = (~~(($597))&255);
          $599 = $598&255;
          $600 = $599 << 3;
          $601 = $600 & 56;
          $602 = $594&255;
          $603 = $601 | $602;
          $604 = $589;
          $605 = $604 * 3.0;
          $606 = $605 + 0.5;
          $607 = (~~(($606))&255);
          $608 = $607&255;
          $609 = $608 << 6;
          $610 = $603 | $609;
          $611 = $610&255;
          HEAP8[$$2293746$i>>0] = $611;
          $$18$i = $scevgep796$i;
          break L194;
          break;
         }
         case 33635:  {
          $540 = ((($$3282748$i)) + 2|0);
          $541 = HEAP16[$$3282748$i>>1]|0;
          $542 = (+($541&65535));
          $543 = $542 / 65535.0;
          $544 = $543;
          $545 = ((($$3282748$i)) + 4|0);
          $546 = HEAP16[$540>>1]|0;
          $547 = (+($546&65535));
          $548 = $547 / 65535.0;
          $549 = $548;
          $550 = HEAP16[$545>>1]|0;
          $551 = (+($550&65535));
          $552 = $551 / 65535.0;
          $553 = $552;
          $scevgep794$i = ((($$3282748$i)) + 6|0);
          $554 = $544 * 31.0;
          $555 = $554;
          $556 = $555 + 0.5;
          $557 = (~~(($556))&65535);
          $558 = $557&65535;
          $559 = $558 << 11;
          $560 = $549 * 63.0;
          $561 = $560;
          $562 = $561 + 0.5;
          $563 = (~~(($562))&65535);
          $564 = $563&65535;
          $565 = $564 << 5;
          $566 = $565 & 1792;
          $567 = $566 | $559;
          $568 = $553 * 31.0;
          $569 = $568;
          $570 = $569 + 0.5;
          $571 = (~~(($570))&65535);
          $572 = $571 & 31;
          $573 = $572&65535;
          $574 = $573 | $565;
          $575 = $567&65535;
          $$sroa$0$sroa$0$sroa$0$0$extract$trunc$i = $574&255;
          $$sroa$0$sroa$0$sroa$38$0$extract$shift$i = ($575&65535) >>> 8;
          $$sroa$0$sroa$0$sroa$38$0$extract$trunc$i = $$sroa$0$sroa$0$sroa$38$0$extract$shift$i&255;
          if ($151) {
           HEAP8[$$2293746$i>>0] = $$sroa$0$sroa$0$sroa$0$0$extract$trunc$i;
           $$sroa_raw_idx475$i = ((($$2293746$i)) + 1|0);
           HEAP8[$$sroa_raw_idx475$i>>0] = $$sroa$0$sroa$0$sroa$38$0$extract$trunc$i;
           $$18$i = $scevgep794$i;
           break L194;
          } else {
           HEAP8[$$2293746$i>>0] = $$sroa$0$sroa$0$sroa$38$0$extract$trunc$i;
           $658 = ((($$2293746$i)) + 1|0);
           HEAP8[$658>>0] = $$sroa$0$sroa$0$sroa$0$0$extract$trunc$i;
           $$18$i = $scevgep794$i;
           break L194;
          }
          break;
         }
         case 33636:  {
          $504 = ((($$3282748$i)) + 2|0);
          $505 = HEAP16[$$3282748$i>>1]|0;
          $506 = (+($505&65535));
          $507 = $506 / 65535.0;
          $508 = $507;
          $509 = ((($$3282748$i)) + 4|0);
          $510 = HEAP16[$504>>1]|0;
          $511 = (+($510&65535));
          $512 = $511 / 65535.0;
          $513 = $512;
          $514 = HEAP16[$509>>1]|0;
          $515 = (+($514&65535));
          $516 = $515 / 65535.0;
          $517 = $516;
          $scevgep792$i = ((($$3282748$i)) + 6|0);
          $518 = $508;
          $519 = $518 * 31.0;
          $520 = $519 + 0.5;
          $521 = (~~(($520))&65535);
          $522 = $521 & 31;
          $523 = $513;
          $524 = $523 * 63.0;
          $525 = $524 + 0.5;
          $526 = (~~(($525))&65535);
          $527 = $526&65535;
          $528 = $527 << 5;
          $529 = $528 & 1792;
          $530 = $522&65535;
          $531 = $528 | $530;
          $532 = $517;
          $533 = $532 * 31.0;
          $534 = $533 + 0.5;
          $535 = (~~(($534))&65535);
          $536 = $535&65535;
          $537 = $536 << 11;
          $538 = $529 | $537;
          $539 = $538&65535;
          $$sroa$0$sroa$0$sroa$0$0$extract$trunc600$i = $531&255;
          $$sroa$0$sroa$0$sroa$38$0$extract$shift621$i = ($539&65535) >>> 8;
          $$sroa$0$sroa$0$sroa$38$0$extract$trunc622$i = $$sroa$0$sroa$0$sroa$38$0$extract$shift621$i&255;
          if ($151) {
           HEAP8[$$2293746$i>>0] = $$sroa$0$sroa$0$sroa$0$0$extract$trunc600$i;
           $$sroa_raw_idx479$i = ((($$2293746$i)) + 1|0);
           HEAP8[$$sroa_raw_idx479$i>>0] = $$sroa$0$sroa$0$sroa$38$0$extract$trunc622$i;
           $$18$i = $scevgep792$i;
           break L194;
          } else {
           HEAP8[$$2293746$i>>0] = $$sroa$0$sroa$0$sroa$38$0$extract$trunc622$i;
           $659 = ((($$2293746$i)) + 1|0);
           HEAP8[$659>>0] = $$sroa$0$sroa$0$sroa$0$0$extract$trunc600$i;
           $$18$i = $scevgep792$i;
           break L194;
          }
          break;
         }
         case 33637:  {
          $410 = ((($$3282748$i)) + 2|0);
          $411 = HEAP16[$$3282748$i>>1]|0;
          $412 = (+($411&65535));
          $413 = $412 / 65535.0;
          $414 = $413;
          $415 = ((($$3282748$i)) + 4|0);
          $416 = HEAP16[$410>>1]|0;
          $417 = (+($416&65535));
          $418 = $417 / 65535.0;
          $419 = $418;
          $420 = ((($$3282748$i)) + 6|0);
          $421 = HEAP16[$415>>1]|0;
          $422 = (+($421&65535));
          $423 = $422 / 65535.0;
          $424 = $423;
          $425 = HEAP16[$420>>1]|0;
          $426 = (+($425&65535));
          $427 = $426 / 65535.0;
          $428 = $427;
          $scevgep788$i = ((($$3282748$i)) + 8|0);
          $429 = $414 * 15.0;
          $430 = $429;
          $431 = $430 + 0.5;
          $432 = (~~(($431))&65535);
          $433 = $432 & 15;
          $434 = $419 * 15.0;
          $435 = $434;
          $436 = $435 + 0.5;
          $437 = (~~(($436))&65535);
          $438 = $437&65535;
          $439 = $438 << 4;
          $440 = $433&65535;
          $441 = $439 | $440;
          $442 = $424 * 15.0;
          $443 = $442;
          $444 = $443 + 0.5;
          $445 = (~~(($444))&65535);
          $446 = $445&65535;
          $447 = $446 << 8;
          $448 = $447 & 3840;
          $449 = $428 * 15.0;
          $450 = $449;
          $451 = $450 + 0.5;
          $452 = (~~(($451))&65535);
          $453 = $452&65535;
          $454 = $453 << 12;
          $455 = $448 | $454;
          $456 = $455&65535;
          $$sroa$0$sroa$0$sroa$0$0$extract$trunc602$i = $441&255;
          $$sroa$0$sroa$0$sroa$38$0$extract$shift625$i = ($456&65535) >>> 8;
          $$sroa$0$sroa$0$sroa$38$0$extract$trunc626$i = $$sroa$0$sroa$0$sroa$38$0$extract$shift625$i&255;
          if ($151) {
           HEAP8[$$2293746$i>>0] = $$sroa$0$sroa$0$sroa$0$0$extract$trunc602$i;
           $$sroa_raw_idx483$i = ((($$2293746$i)) + 1|0);
           HEAP8[$$sroa_raw_idx483$i>>0] = $$sroa$0$sroa$0$sroa$38$0$extract$trunc626$i;
           $$18$i = $scevgep788$i;
           break L194;
          } else {
           HEAP8[$$2293746$i>>0] = $$sroa$0$sroa$0$sroa$38$0$extract$trunc626$i;
           $661 = ((($$2293746$i)) + 1|0);
           HEAP8[$661>>0] = $$sroa$0$sroa$0$sroa$0$0$extract$trunc602$i;
           $$18$i = $scevgep788$i;
           break L194;
          }
          break;
         }
         case 32820:  {
          $362 = ((($$3282748$i)) + 2|0);
          $363 = HEAP16[$$3282748$i>>1]|0;
          $364 = (+($363&65535));
          $365 = $364 / 65535.0;
          $366 = $365;
          $367 = ((($$3282748$i)) + 4|0);
          $368 = HEAP16[$362>>1]|0;
          $369 = (+($368&65535));
          $370 = $369 / 65535.0;
          $371 = $370;
          $372 = ((($$3282748$i)) + 6|0);
          $373 = HEAP16[$367>>1]|0;
          $374 = (+($373&65535));
          $375 = $374 / 65535.0;
          $376 = $375;
          $377 = HEAP16[$372>>1]|0;
          $378 = (+($377&65535));
          $379 = $378 / 65535.0;
          $380 = $379;
          $scevgep786$i = ((($$3282748$i)) + 8|0);
          $381 = $366 * 31.0;
          $382 = $381;
          $383 = $382 + 0.5;
          $384 = (~~(($383))&65535);
          $385 = $384&65535;
          $386 = $385 << 11;
          $387 = $371 * 31.0;
          $388 = $387;
          $389 = $388 + 0.5;
          $390 = (~~(($389))&65535);
          $391 = $390&65535;
          $392 = $391 << 6;
          $393 = $392 & 1792;
          $394 = $393 | $386;
          $395 = $376 * 31.0;
          $396 = $395;
          $397 = $396 + 0.5;
          $398 = (~~(($397))&65535);
          $399 = $398&65535;
          $400 = $399 << 1;
          $401 = $400 & 62;
          $402 = $380;
          $403 = $402 + 0.5;
          $404 = (~~(($403))&65535);
          $405 = $404 & 1;
          $406 = $405&65535;
          $407 = $406 | $392;
          $408 = $407 | $401;
          $409 = $394&65535;
          $$sroa$0$sroa$0$sroa$0$0$extract$trunc591$i = $408&255;
          $$sroa$0$sroa$0$sroa$38$0$extract$shift603$i = ($409&65535) >>> 8;
          $$sroa$0$sroa$0$sroa$38$0$extract$trunc604$i = $$sroa$0$sroa$0$sroa$38$0$extract$shift603$i&255;
          if ($151) {
           HEAP8[$$2293746$i>>0] = $$sroa$0$sroa$0$sroa$0$0$extract$trunc591$i;
           $$sroa_raw_idx487$i = ((($$2293746$i)) + 1|0);
           HEAP8[$$sroa_raw_idx487$i>>0] = $$sroa$0$sroa$0$sroa$38$0$extract$trunc604$i;
           $$18$i = $scevgep786$i;
           break L194;
          } else {
           HEAP8[$$2293746$i>>0] = $$sroa$0$sroa$0$sroa$38$0$extract$trunc604$i;
           $662 = ((($$2293746$i)) + 1|0);
           HEAP8[$662>>0] = $$sroa$0$sroa$0$sroa$0$0$extract$trunc591$i;
           $$18$i = $scevgep786$i;
           break L194;
          }
          break;
         }
         case 33638:  {
          $314 = ((($$3282748$i)) + 2|0);
          $315 = HEAP16[$$3282748$i>>1]|0;
          $316 = (+($315&65535));
          $317 = $316 / 65535.0;
          $318 = $317;
          $319 = ((($$3282748$i)) + 4|0);
          $320 = HEAP16[$314>>1]|0;
          $321 = (+($320&65535));
          $322 = $321 / 65535.0;
          $323 = $322;
          $324 = ((($$3282748$i)) + 6|0);
          $325 = HEAP16[$319>>1]|0;
          $326 = (+($325&65535));
          $327 = $326 / 65535.0;
          $328 = $327;
          $329 = HEAP16[$324>>1]|0;
          $330 = (+($329&65535));
          $331 = $330 / 65535.0;
          $332 = $331;
          $scevgep784$i = ((($$3282748$i)) + 8|0);
          $333 = $318 * 31.0;
          $334 = $333;
          $335 = $334 + 0.5;
          $336 = (~~(($335))&65535);
          $337 = $336 & 31;
          $338 = $323 * 31.0;
          $339 = $338;
          $340 = $339 + 0.5;
          $341 = (~~(($340))&65535);
          $342 = $341&65535;
          $343 = $342 << 5;
          $344 = $343 & 992;
          $345 = $337&65535;
          $346 = $344 | $345;
          $347 = $328 * 31.0;
          $348 = $347;
          $349 = $348 + 0.5;
          $350 = (~~(($349))&65535);
          $351 = $350&65535;
          $352 = $351 << 10;
          $353 = $352 & 31744;
          $354 = $332;
          $355 = $354 + 0.5;
          $356 = (~~(($355))&65535);
          $357 = $356&65535;
          $358 = $357 << 15;
          $359 = $346 | $358;
          $360 = $359 | $353;
          $361 = $360&65535;
          $$sroa$0$sroa$0$sroa$0$0$extract$trunc592$i = $346&255;
          $$sroa$0$sroa$0$sroa$38$0$extract$shift605$i = ($361&65535) >>> 8;
          $$sroa$0$sroa$0$sroa$38$0$extract$trunc606$i = $$sroa$0$sroa$0$sroa$38$0$extract$shift605$i&255;
          if ($151) {
           HEAP8[$$2293746$i>>0] = $$sroa$0$sroa$0$sroa$0$0$extract$trunc592$i;
           $$sroa_raw_idx495$i = ((($$2293746$i)) + 1|0);
           HEAP8[$$sroa_raw_idx495$i>>0] = $$sroa$0$sroa$0$sroa$38$0$extract$trunc606$i;
           $$18$i = $scevgep784$i;
           break L194;
          } else {
           HEAP8[$$2293746$i>>0] = $$sroa$0$sroa$0$sroa$38$0$extract$trunc606$i;
           $663 = ((($$2293746$i)) + 1|0);
           HEAP8[$663>>0] = $$sroa$0$sroa$0$sroa$0$0$extract$trunc592$i;
           $$18$i = $scevgep784$i;
           break L194;
          }
          break;
         }
         case 32821:  {
          $279 = ((($$3282748$i)) + 2|0);
          $280 = HEAP16[$$3282748$i>>1]|0;
          $281 = (+($280&65535));
          $282 = $281 / 65535.0;
          $283 = $282;
          $284 = ((($$3282748$i)) + 4|0);
          $285 = HEAP16[$279>>1]|0;
          $286 = (+($285&65535));
          $287 = $286 / 65535.0;
          $288 = $287;
          $289 = ((($$3282748$i)) + 6|0);
          $290 = HEAP16[$284>>1]|0;
          $291 = (+($290&65535));
          $292 = $291 / 65535.0;
          $293 = $292;
          $294 = HEAP16[$289>>1]|0;
          $295 = (+($294&65535));
          $296 = $295 / 65535.0;
          $297 = $296;
          $scevgep782$i = ((($$3282748$i)) + 8|0);
          $298 = $283 * 255.0;
          $299 = $298;
          $300 = $299 + 0.5;
          $301 = (~~(($300))>>>0);
          $302 = $288 * 255.0;
          $303 = $302;
          $304 = $303 + 0.5;
          $305 = (~~(($304))>>>0);
          $306 = $293 * 255.0;
          $307 = $306;
          $308 = $307 + 0.5;
          $309 = (~~(($308))>>>0);
          $310 = $297 * 255.0;
          $311 = $310;
          $312 = $311 + 0.5;
          $313 = (~~(($312))>>>0);
          $$sroa$0$sroa$0$sroa$0$0$extract$trunc598$i = $313&255;
          $$sroa$0$sroa$0$sroa$38$0$extract$trunc618$i = $309&255;
          $$sroa$0$sroa$62$0$extract$trunc$i = $305&255;
          $$sroa$0$sroa$72$0$extract$trunc$i = $301&255;
          if ($151) {
           HEAP8[$$2293746$i>>0] = $$sroa$0$sroa$0$sroa$0$0$extract$trunc598$i;
           $$sroa_raw_idx469$i = ((($$2293746$i)) + 1|0);
           HEAP8[$$sroa_raw_idx469$i>>0] = $$sroa$0$sroa$0$sroa$38$0$extract$trunc618$i;
           $$sroa_raw_idx470$i = ((($$2293746$i)) + 2|0);
           HEAP8[$$sroa_raw_idx470$i>>0] = $$sroa$0$sroa$62$0$extract$trunc$i;
           $$sroa_raw_idx471$i = ((($$2293746$i)) + 3|0);
           HEAP8[$$sroa_raw_idx471$i>>0] = $$sroa$0$sroa$72$0$extract$trunc$i;
           $$18$i = $scevgep782$i;
           break L194;
          } else {
           $666 = ((($$2293746$i)) + 3|0);
           HEAP8[$666>>0] = $$sroa$0$sroa$0$sroa$0$0$extract$trunc598$i;
           $667 = ((($$2293746$i)) + 2|0);
           HEAP8[$667>>0] = $$sroa$0$sroa$0$sroa$38$0$extract$trunc618$i;
           $668 = ((($$2293746$i)) + 1|0);
           HEAP8[$668>>0] = $$sroa$0$sroa$62$0$extract$trunc$i;
           HEAP8[$$2293746$i>>0] = $$sroa$0$sroa$72$0$extract$trunc$i;
           $$18$i = $scevgep782$i;
           break L194;
          }
          break;
         }
         case 33639:  {
          $244 = ((($$3282748$i)) + 2|0);
          $245 = HEAP16[$$3282748$i>>1]|0;
          $246 = (+($245&65535));
          $247 = $246 / 65535.0;
          $248 = $247;
          $249 = ((($$3282748$i)) + 4|0);
          $250 = HEAP16[$244>>1]|0;
          $251 = (+($250&65535));
          $252 = $251 / 65535.0;
          $253 = $252;
          $254 = ((($$3282748$i)) + 6|0);
          $255 = HEAP16[$249>>1]|0;
          $256 = (+($255&65535));
          $257 = $256 / 65535.0;
          $258 = $257;
          $259 = HEAP16[$254>>1]|0;
          $260 = (+($259&65535));
          $261 = $260 / 65535.0;
          $262 = $261;
          $scevgep780$i = ((($$3282748$i)) + 8|0);
          $263 = $248 * 255.0;
          $264 = $263;
          $265 = $264 + 0.5;
          $266 = (~~(($265))>>>0);
          $267 = $253 * 255.0;
          $268 = $267;
          $269 = $268 + 0.5;
          $270 = (~~(($269))>>>0);
          $271 = $258 * 255.0;
          $272 = $271;
          $273 = $272 + 0.5;
          $274 = (~~(($273))>>>0);
          $275 = $262 * 255.0;
          $276 = $275;
          $277 = $276 + 0.5;
          $278 = (~~(($277))>>>0);
          $$sroa$0$sroa$0$sroa$0$0$extract$trunc594$i = $266&255;
          $$sroa$0$sroa$0$sroa$38$0$extract$trunc610$i = $270&255;
          $$sroa$0$sroa$62$0$extract$trunc578$i = $274&255;
          $$sroa$0$sroa$72$0$extract$trunc588$i = $278&255;
          if ($151) {
           HEAP8[$$2293746$i>>0] = $$sroa$0$sroa$0$sroa$0$0$extract$trunc594$i;
           $$sroa_raw_idx454$i = ((($$2293746$i)) + 1|0);
           HEAP8[$$sroa_raw_idx454$i>>0] = $$sroa$0$sroa$0$sroa$38$0$extract$trunc610$i;
           $$sroa_raw_idx455$i = ((($$2293746$i)) + 2|0);
           HEAP8[$$sroa_raw_idx455$i>>0] = $$sroa$0$sroa$62$0$extract$trunc578$i;
           $$sroa_raw_idx456$i = ((($$2293746$i)) + 3|0);
           HEAP8[$$sroa_raw_idx456$i>>0] = $$sroa$0$sroa$72$0$extract$trunc588$i;
           $$18$i = $scevgep780$i;
           break L194;
          } else {
           $669 = ((($$2293746$i)) + 3|0);
           HEAP8[$669>>0] = $$sroa$0$sroa$0$sroa$0$0$extract$trunc594$i;
           $670 = ((($$2293746$i)) + 2|0);
           HEAP8[$670>>0] = $$sroa$0$sroa$0$sroa$38$0$extract$trunc610$i;
           $671 = ((($$2293746$i)) + 1|0);
           HEAP8[$671>>0] = $$sroa$0$sroa$62$0$extract$trunc578$i;
           HEAP8[$$2293746$i>>0] = $$sroa$0$sroa$72$0$extract$trunc588$i;
           $$18$i = $scevgep780$i;
           break L194;
          }
          break;
         }
         case 32822:  {
          $199 = ((($$3282748$i)) + 2|0);
          $200 = HEAP16[$$3282748$i>>1]|0;
          $201 = (+($200&65535));
          $202 = $201 / 65535.0;
          $203 = $202;
          $204 = ((($$3282748$i)) + 4|0);
          $205 = HEAP16[$199>>1]|0;
          $206 = (+($205&65535));
          $207 = $206 / 65535.0;
          $208 = $207;
          $209 = ((($$3282748$i)) + 6|0);
          $210 = HEAP16[$204>>1]|0;
          $211 = (+($210&65535));
          $212 = $211 / 65535.0;
          $213 = $212;
          $214 = HEAP16[$209>>1]|0;
          $215 = (+($214&65535));
          $216 = $215 / 65535.0;
          $217 = $216;
          $scevgep778$i = ((($$3282748$i)) + 8|0);
          $218 = $203 * 1023.0;
          $219 = $218;
          $220 = $219 + 0.5;
          $221 = (~~(($220))>>>0);
          $222 = $221 << 22;
          $223 = $208 * 1023.0;
          $224 = $223;
          $225 = $224 + 0.5;
          $226 = (~~(($225))>>>0);
          $227 = $226 << 12;
          $228 = $227 & 4128768;
          $229 = $228 | $222;
          $230 = $213 * 1023.0;
          $231 = $230;
          $232 = $231 + 0.5;
          $233 = (~~(($232))>>>0);
          $234 = $233 << 2;
          $235 = $234 & 3840;
          $236 = $235 | $227;
          $237 = $217 * 3.0;
          $238 = $237;
          $239 = $238 + 0.5;
          $240 = (~~(($239))>>>0);
          $241 = $240 & 3;
          $242 = $241 | $234;
          $$sroa$0$sroa$0$0$extract$trunc521$i = $236&65535;
          $$sroa$0$sroa$0$sroa$0$0$extract$trunc595$i = $242&255;
          $$sroa$0$sroa$0$sroa$38$0$extract$shift611$i = ($$sroa$0$sroa$0$0$extract$trunc521$i&65535) >>> 8;
          $$sroa$0$sroa$0$sroa$38$0$extract$trunc612$i = $$sroa$0$sroa$0$sroa$38$0$extract$shift611$i&255;
          $$sroa$0$sroa$62$0$extract$shift575$i = $229 >>> 16;
          $$sroa$0$sroa$62$0$extract$trunc576$i = $$sroa$0$sroa$62$0$extract$shift575$i&255;
          $243 = $221 >>> 2;
          $$sroa$0$sroa$72$0$extract$trunc586$i = $243&255;
          if ($151) {
           HEAP8[$$2293746$i>>0] = $$sroa$0$sroa$0$sroa$0$0$extract$trunc595$i;
           $$sroa_raw_idx439$i = ((($$2293746$i)) + 1|0);
           HEAP8[$$sroa_raw_idx439$i>>0] = $$sroa$0$sroa$0$sroa$38$0$extract$trunc612$i;
           $$sroa_raw_idx440$i = ((($$2293746$i)) + 2|0);
           HEAP8[$$sroa_raw_idx440$i>>0] = $$sroa$0$sroa$62$0$extract$trunc576$i;
           $$sroa_raw_idx441$i = ((($$2293746$i)) + 3|0);
           HEAP8[$$sroa_raw_idx441$i>>0] = $$sroa$0$sroa$72$0$extract$trunc586$i;
           $$18$i = $scevgep778$i;
           break L194;
          } else {
           $672 = ((($$2293746$i)) + 3|0);
           HEAP8[$672>>0] = $$sroa$0$sroa$0$sroa$0$0$extract$trunc595$i;
           $673 = ((($$2293746$i)) + 2|0);
           HEAP8[$673>>0] = $$sroa$0$sroa$0$sroa$38$0$extract$trunc612$i;
           $674 = ((($$2293746$i)) + 1|0);
           HEAP8[$674>>0] = $$sroa$0$sroa$62$0$extract$trunc576$i;
           HEAP8[$$2293746$i>>0] = $$sroa$0$sroa$72$0$extract$trunc586$i;
           $$18$i = $scevgep778$i;
           break L194;
          }
          break;
         }
         case 33640:  {
          $155 = ((($$3282748$i)) + 2|0);
          $156 = HEAP16[$$3282748$i>>1]|0;
          $157 = (+($156&65535));
          $158 = $157 / 65535.0;
          $159 = $158;
          $160 = ((($$3282748$i)) + 4|0);
          $161 = HEAP16[$155>>1]|0;
          $162 = (+($161&65535));
          $163 = $162 / 65535.0;
          $164 = $163;
          $165 = ((($$3282748$i)) + 6|0);
          $166 = HEAP16[$160>>1]|0;
          $167 = (+($166&65535));
          $168 = $167 / 65535.0;
          $169 = $168;
          $170 = HEAP16[$165>>1]|0;
          $171 = (+($170&65535));
          $172 = $171 / 65535.0;
          $173 = $172;
          $scevgep776$i = ((($$3282748$i)) + 8|0);
          $174 = $159 * 1023.0;
          $175 = $174;
          $176 = $175 + 0.5;
          $177 = (~~(($176))>>>0);
          $178 = $177 & 768;
          $179 = $164 * 1023.0;
          $180 = $179;
          $181 = $180 + 0.5;
          $182 = (~~(($181))>>>0);
          $183 = $182 << 10;
          $184 = $183 & 983040;
          $185 = $183 | $178;
          $186 = $169 * 1023.0;
          $187 = $186;
          $188 = $187 + 0.5;
          $189 = (~~(($188))>>>0);
          $190 = $189 << 20;
          $191 = $190 & 1056964608;
          $192 = $190 | $184;
          $193 = $173 * 3.0;
          $194 = $193;
          $195 = $194 + 0.5;
          $196 = (~~(($195))>>>0);
          $197 = $196 << 30;
          $198 = $191 | $197;
          $$sroa$0$sroa$0$0$extract$trunc520$i = $185&65535;
          $$sroa$0$sroa$0$sroa$0$0$extract$trunc596$i = $177&255;
          $$sroa$0$sroa$0$sroa$38$0$extract$shift613$i = ($$sroa$0$sroa$0$0$extract$trunc520$i&65535) >>> 8;
          $$sroa$0$sroa$0$sroa$38$0$extract$trunc614$i = $$sroa$0$sroa$0$sroa$38$0$extract$shift613$i&255;
          $$sroa$0$sroa$62$0$extract$shift573$i = $192 >>> 16;
          $$sroa$0$sroa$62$0$extract$trunc574$i = $$sroa$0$sroa$62$0$extract$shift573$i&255;
          $$sroa$0$sroa$72$0$extract$shift583$i = $198 >>> 24;
          $$sroa$0$sroa$72$0$extract$trunc584$i = $$sroa$0$sroa$72$0$extract$shift583$i&255;
          if ($151) {
           HEAP8[$$2293746$i>>0] = $$sroa$0$sroa$0$sroa$0$0$extract$trunc596$i;
           $$sroa_raw_idx$i = ((($$2293746$i)) + 1|0);
           HEAP8[$$sroa_raw_idx$i>>0] = $$sroa$0$sroa$0$sroa$38$0$extract$trunc614$i;
           $$sroa_raw_idx425$i = ((($$2293746$i)) + 2|0);
           HEAP8[$$sroa_raw_idx425$i>>0] = $$sroa$0$sroa$62$0$extract$trunc574$i;
           $$sroa_raw_idx426$i = ((($$2293746$i)) + 3|0);
           HEAP8[$$sroa_raw_idx426$i>>0] = $$sroa$0$sroa$72$0$extract$trunc584$i;
           $$18$i = $scevgep776$i;
           break L194;
          } else {
           $675 = ((($$2293746$i)) + 3|0);
           HEAP8[$675>>0] = $$sroa$0$sroa$0$sroa$0$0$extract$trunc596$i;
           $676 = ((($$2293746$i)) + 2|0);
           HEAP8[$676>>0] = $$sroa$0$sroa$0$sroa$38$0$extract$trunc614$i;
           $677 = ((($$2293746$i)) + 1|0);
           HEAP8[$677>>0] = $$sroa$0$sroa$62$0$extract$trunc574$i;
           HEAP8[$$2293746$i>>0] = $$sroa$0$sroa$72$0$extract$trunc584$i;
           $$18$i = $scevgep776$i;
           break L194;
          }
          break;
         }
         default: {
          $$18$i = $$3282748$i;
          break L194;
         }
         }
        } while(0);
       }
      } while(0);
      $688 = (($$2293746$i) + ($$0$i304$i)|0);
      $689 = (($$1276749$i) + 1)|0;
      $exitcond800$i = ($689|0)==($137|0);
      if ($exitcond800$i) {
       $$3282$lcssa$i = $$18$i;
       break;
      } else {
       $$1276749$i = $689;$$2293746$i = $688;$$3282748$i = $$18$i;
      }
     }
    } else {
     $$3282$lcssa$i = $$2281754$i;
    }
    $690 = (($$1295753$i) + ($$1297$i)|0);
    $691 = (($$1278755$i) + 1)|0;
    $exitcond801$i = ($691|0)==($7|0);
    if ($exitcond801$i) {
     break;
    } else {
     $$1278755$i = $691;$$1295753$i = $690;$$2281754$i = $$3282$lcssa$i;
    }
   }
  }
 }
 _free($48);
 _free($47);
 $$0 = 0;
 return ($$0|0);
}
function __ZN3osgL10fill_imageEPKNS_17PixelStorageModesEiijjhPKvPt($0,$1,$2,$3,$4,$5,$6,$7) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 var $$ = 0, $$$0273$us = 0, $$0$i = 0, $$0$i283 = 0, $$0$i284 = 0, $$0$i285 = 0, $$0$i286 = 0, $$0$i287 = 0, $$0$i288 = 0, $$0$i289 = 0, $$0$i290 = 0, $$0$i291 = 0, $$0$i292 = 0, $$0$i293 = 0, $$0$i295 = 0, $$0$us = 0, $$0253$pn$us = 0, $$0253313$us = 0, $$0257312$us = 0, $$0259316$us = 0;
 var $$0261315$us = 0, $$0273310$us = 0, $$0276314$us = 0, $$0278 = 0, $$1258346 = 0, $$1260354 = 0, $$1262311$us = 0, $$1277352 = 0, $$1279 = 0, $$16 = 0, $$2263353 = 0, $$2275343 = 0, $$281$us = 0, $$294 = 0, $$296 = 0, $$3264$lcssa = 0, $$3264345 = 0, $$pn$us = 0, $$pre$pre = 0, $$sink = 0;
 var $$sink4 = 0, $$sink8 = 0, $$sroa$0$0$extract$trunc = 0, $$sroa$0$0$insert$ext = 0, $$sroa$0$0$insert$ext$pn = 0, $$sroa$0$0$insert$ext12 = 0, $$sroa$0$0$insert$ext16 = 0, $$sroa$0$0$insert$ext20 = 0, $$sroa$0$1$insert$ext = 0, $$sroa$0$1$insert$ext31 = 0, $$sroa$0$1$insert$insert34 = 0, $$sroa$0$1$insert$shift = 0, $$sroa$0$1$insert$shift27 = 0, $$sroa$0$1$insert$shift32 = 0, $$sroa$0$2$insert$ext = 0, $$sroa$0$2$insert$insert = 0, $$sroa$0$2$insert$insert39 = 0, $$sroa$0$2$insert$mask = 0, $$sroa$0$2$insert$mask38 = 0, $$sroa$0$2$insert$shift = 0;
 var $$sroa$0$2$insert$shift37 = 0, $$sroa$0$3 = 0, $$sroa$0$3$insert$ext = 0, $$sroa$0$3$insert$insert = 0, $$sroa$0$3$insert$mask = 0, $$sroa$0$3$insert$shift = 0, $10 = 0, $100 = 0, $101 = 0.0, $102 = 0.0, $103 = 0, $104 = 0, $105 = 0.0, $106 = 0.0, $107 = 0, $108 = 0.0, $109 = 0.0, $11 = 0, $110 = 0.0, $111 = 0;
 var $112 = 0, $113 = 0.0, $114 = 0, $115 = 0, $116 = 0.0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0.0, $144 = 0.0, $145 = 0, $146 = 0, $147 = 0.0, $148 = 0.0;
 var $149 = 0, $15 = 0, $150 = 0.0, $151 = 0.0, $152 = 0.0, $153 = 0, $154 = 0, $155 = 0.0, $156 = 0, $157 = 0, $158 = 0.0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0.0, $172 = 0.0, $173 = 0, $174 = 0, $175 = 0.0, $176 = 0.0, $177 = 0, $178 = 0.0, $179 = 0.0, $18 = 0, $180 = 0.0, $181 = 0, $182 = 0, $183 = 0.0, $184 = 0;
 var $185 = 0, $186 = 0.0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0.0, $20 = 0, $200 = 0.0, $201 = 0, $202 = 0;
 var $203 = 0.0, $204 = 0.0, $205 = 0, $206 = 0, $207 = 0.0, $208 = 0.0, $209 = 0, $21 = 0, $210 = 0.0, $211 = 0.0, $212 = 0.0, $213 = 0, $214 = 0, $215 = 0.0, $216 = 0, $217 = 0, $218 = 0.0, $219 = 0, $22 = 0, $220 = 0;
 var $221 = 0.0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0.0, $235 = 0.0, $236 = 0, $237 = 0, $238 = 0.0, $239 = 0.0;
 var $24 = 0, $240 = 0, $241 = 0, $242 = 0.0, $243 = 0.0, $244 = 0, $245 = 0.0, $246 = 0.0, $247 = 0.0, $248 = 0, $249 = 0, $25 = 0, $250 = 0.0, $251 = 0, $252 = 0, $253 = 0.0, $254 = 0, $255 = 0, $256 = 0.0, $257 = 0;
 var $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0.0, $27 = 0, $270 = 0.0, $271 = 0, $272 = 0, $273 = 0.0, $274 = 0.0, $275 = 0;
 var $276 = 0, $277 = 0.0, $278 = 0.0, $279 = 0, $28 = 0, $280 = 0.0, $281 = 0.0, $282 = 0, $283 = 0, $284 = 0.0, $285 = 0, $286 = 0, $287 = 0.0, $288 = 0, $289 = 0, $29 = 0, $290 = 0.0, $291 = 0, $292 = 0, $293 = 0;
 var $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0.0, $304 = 0.0, $305 = 0, $306 = 0, $307 = 0.0, $308 = 0.0, $309 = 0, $31 = 0, $310 = 0, $311 = 0.0;
 var $312 = 0.0, $313 = 0, $314 = 0.0, $315 = 0.0, $316 = 0, $317 = 0, $318 = 0.0, $319 = 0, $32 = 0, $320 = 0, $321 = 0.0, $322 = 0, $323 = 0, $324 = 0.0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0;
 var $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0;
 var $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0.0, $356 = 0.0, $357 = 0, $358 = 0, $359 = 0.0, $36 = 0, $360 = 0.0, $361 = 0, $362 = 0, $363 = 0.0, $364 = 0.0, $365 = 0, $366 = 0.0;
 var $367 = 0.0, $368 = 0.0, $369 = 0, $37 = 0, $370 = 0, $371 = 0.0, $372 = 0, $373 = 0, $374 = 0.0, $375 = 0, $376 = 0, $377 = 0.0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0;
 var $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0.0, $399 = 0.0, $40 = 0, $400 = 0, $401 = 0, $402 = 0.0;
 var $403 = 0.0, $404 = 0, $405 = 0, $406 = 0.0, $407 = 0.0, $408 = 0, $409 = 0.0, $41 = 0, $410 = 0.0, $411 = 0.0, $412 = 0, $413 = 0, $414 = 0.0, $415 = 0, $416 = 0, $417 = 0.0, $418 = 0, $419 = 0, $42 = 0, $420 = 0.0;
 var $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0;
 var $44 = 0, $440 = 0, $441 = 0.0, $442 = 0.0, $443 = 0, $444 = 0, $445 = 0.0, $446 = 0.0, $447 = 0, $448 = 0, $449 = 0.0, $45 = 0, $450 = 0.0, $451 = 0, $452 = 0.0, $453 = 0.0, $454 = 0.0, $455 = 0, $456 = 0, $457 = 0.0;
 var $458 = 0, $459 = 0, $46 = 0, $460 = 0.0, $461 = 0, $462 = 0, $463 = 0.0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0;
 var $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0.0, $485 = 0.0, $486 = 0, $487 = 0, $488 = 0.0, $489 = 0.0, $49 = 0, $490 = 0, $491 = 0, $492 = 0.0, $493 = 0.0;
 var $494 = 0, $495 = 0.0, $496 = 0.0, $497 = 0.0, $498 = 0, $499 = 0, $50 = 0, $500 = 0.0, $501 = 0, $502 = 0, $503 = 0.0, $504 = 0, $505 = 0, $506 = 0.0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0;
 var $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0.0, $518 = 0, $519 = 0, $52 = 0, $520 = 0.0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0;
 var $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0.0, $82 = 0.0, $83 = 0, $84 = 0, $85 = 0.0;
 var $86 = 0.0, $87 = 0, $88 = 0.0, $89 = 0.0, $9 = 0, $90 = 0.0, $91 = 0, $92 = 0, $93 = 0.0, $94 = 0, $95 = 0, $96 = 0.0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $exitcond381 = 0, $exitcond419 = 0, $exitcond420 = 0, $scevgep = 0;
 var $scevgep383 = 0, $scevgep386 = 0, $scevgep389 = 0, $scevgep392 = 0, $scevgep395 = 0, $scevgep398 = 0, $scevgep401 = 0, $scevgep404 = 0, $scevgep407 = 0, $scevgep410 = 0, $scevgep413 = 0, $scevgep416 = 0, $storemerge$us = 0, $switch$split102D = 0, $switch$split12D = 0, $switch$split132D = 0, $switch$split162D = 0, $switch$split192D = 0, $switch$split222D = 0, $switch$split252D = 0;
 var $switch$split2D = 0, $switch$split42D = 0, $switch$split72D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $8 = ((($0)) + 52|0);
 $9 = HEAP32[$8>>2]|0;
 switch ($4|0) {
 case 32818: case 32819: case 32820: case 32821: case 32822: case 33634: case 33635: case 33636: case 33637: case 33638: case 33639: case 33640:  {
  $10 = ((($0)) + 36|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($11|0)>(0);
  $$294 = $12 ? $11 : $1;
  $$0$i295 = 1;$$296 = $$294;
  break;
 }
 default: {
  $switch$split2D = ($3|0)<(6410);
  L3: do {
   if ($switch$split2D) {
    switch ($3|0) {
    case 6407:  {
     $$0$i = 3;
     break;
    }
    case 6408:  {
     label = 4;
     break;
    }
    default: {
     label = 5;
    }
    }
   } else {
    $switch$split72D = ($3|0)<(32992);
    if (!($switch$split72D)) {
     switch ($3|0) {
     case 32992:  {
      $$0$i = 3;
      break L3;
      break;
     }
     case 32993:  {
      label = 4;
      break L3;
      break;
     }
     default: {
      label = 5;
      break L3;
     }
     }
    }
    switch ($3|0) {
    case 6410:  {
     break;
    }
    default: {
     label = 5;
     break L3;
    }
    }
    $$0$i = 2;
   }
  } while(0);
  if ((label|0) == 4) {
   $$0$i = 4;
  }
  else if ((label|0) == 5) {
   $$0$i = 1;
  }
  $13 = ((($0)) + 36|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = ($14|0)>(0);
  $$ = $15 ? $14 : $1;
  $16 = ($4|0)==(6656);
  if ($16) {
   $17 = Math_imul($$, $$0$i)|0;
   $18 = (($17) + 7)|0;
   $19 = (($18|0) / 8)&-1;
   $20 = ((($0)) + 32|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = (($19|0) % ($21|0))&-1;
   $23 = ($22|0)==(0);
   $24 = (($21) - ($22))|0;
   $25 = $23 ? 0 : $24;
   $$0278 = (($25) + ($19))|0;
   $26 = Math_imul($$0$i, $1)|0;
   $27 = ($2|0)>(0);
   if (!($27)) {
    return;
   }
   $28 = ((($0)) + 44|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = Math_imul($29, $$0$i)|0;
   $31 = ($26|0)>(0);
   $32 = ($5<<24>>24)!=(0);
   $$sink = $32 ? 1 : -1;
   if (!($31)) {
    return;
   }
   $33 = ((($0)) + 48|0);
   $34 = ((($0)) + 40|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = Math_imul($$0278, $35)|0;
   $37 = (($6) + ($36)|0);
   $38 = (($30|0) / 8)&-1;
   $39 = (($37) + ($38)|0);
   $$pre$pre = HEAP32[$33>>2]|0;
   $40 = (($30|0) % 8)&-1;
   $41 = ($$pre$pre|0)==(0);
   $$0259316$us = 0;$$0261315$us = $7;$$0276314$us = $39;
   while(1) {
    $$0253313$us = $40;$$0257312$us = 0;$$0273310$us = $$0276314$us;$$1262311$us = $$0261315$us;
    while(1) {
     $42 = HEAP8[$$0273310$us>>0]|0;
     $43 = $42&255;
     $44 = (7 - ($$0253313$us))|0;
     $$0253$pn$us = $41 ? $44 : $$0253313$us;
     $$pn$us = 1 << $$0253$pn$us;
     $$0$us = $$pn$us & $43;
     $45 = ($$0$us|0)==(0);
     $storemerge$us = $45 ? 0 : $$sink;
     HEAP16[$$1262311$us>>1] = $storemerge$us;
     $46 = (($$0253313$us) + 1)|0;
     $47 = ($46|0)==(8);
     $48 = ((($$0273310$us)) + 1|0);
     $$$0273$us = $47 ? $48 : $$0273310$us;
     $$281$us = $47 ? 0 : $46;
     $49 = ((($$1262311$us)) + 2|0);
     $50 = (($$0257312$us) + 1)|0;
     $exitcond = ($50|0)==($26|0);
     if ($exitcond) {
      break;
     } else {
      $$0253313$us = $$281$us;$$0257312$us = $50;$$0273310$us = $$$0273$us;$$1262311$us = $49;
     }
    }
    $scevgep = (($$0261315$us) + ($26<<1)|0);
    $51 = (($$0276314$us) + ($$0278)|0);
    $52 = (($$0259316$us) + 1)|0;
    $exitcond381 = ($52|0)==($2|0);
    if ($exitcond381) {
     break;
    } else {
     $$0259316$us = $52;$$0261315$us = $scevgep;$$0276314$us = $51;
    }
   }
   return;
  } else {
   $$0$i295 = $$0$i;$$296 = $$;
  }
 }
 }
 $switch$split12D = ($4|0)<(32820);
 L29: do {
  if ($switch$split12D) {
   $switch$split102D = ($4|0)<(5125);
   if ($switch$split102D) {
    switch ($4|0) {
    case 5123:  {
     $$0$i293 = 2;
     break L29;
     break;
    }
    case 5122:  {
     $$0$i293 = 2;
     break L29;
     break;
    }
    case 5121:  {
     $$0$i293 = 1;
     break L29;
     break;
    }
    case 5120:  {
     $$0$i293 = 1;
     break L29;
     break;
    }
    case 5124:  {
     $$0$i293 = 4;
     break L29;
     break;
    }
    default: {
     label = 25;
     break L29;
    }
    }
   }
   $switch$split162D = ($4|0)<(6656);
   if ($switch$split162D) {
    switch ($4|0) {
    case 5125:  {
     $$0$i293 = 4;
     break L29;
     break;
    }
    case 5126:  {
     $$0$i293 = 4;
     break L29;
     break;
    }
    default: {
     label = 25;
     break L29;
    }
    }
   } else {
    $switch$split222D = ($4|0)<(32818);
    if ($switch$split222D) {
     switch ($4|0) {
     case 6656:  {
      $$0$i293 = 0;
      break L29;
      break;
     }
     default: {
      label = 25;
      break L29;
     }
     }
    } else {
     switch ($4|0) {
     case 32818:  {
      label = 22;
      break L29;
      break;
     }
     case 32819:  {
      label = 23;
      break L29;
      break;
     }
     default: {
      label = 25;
      break L29;
     }
     }
    }
   }
  } else {
   switch ($4|0) {
   case 33634:  {
    label = 22;
    break L29;
    break;
   }
   case 33638: case 32820: case 33637: case 33636: case 33635:  {
    label = 23;
    break L29;
    break;
   }
   case 33640: case 32822: case 33639: case 32821:  {
    break;
   }
   default: {
    label = 25;
    break L29;
   }
   }
   $$0$i293 = 4;
  }
 } while(0);
 if ((label|0) == 22) {
  $$0$i293 = 1;
 }
 else if ((label|0) == 23) {
  $$0$i293 = 2;
 }
 else if ((label|0) == 25) {
  $$0$i293 = 4;
 }
 $53 = Math_imul($$0$i293, $$0$i295)|0;
 $54 = Math_imul($53, $$296)|0;
 $55 = ((($0)) + 32|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = (($54|0) % ($56|0))&-1;
 $58 = ($57|0)==(0);
 $59 = (($56) - ($57))|0;
 $60 = $58 ? 0 : $59;
 $$1279 = (($60) + ($54))|0;
 $61 = Math_imul($$0$i295, $1)|0;
 $62 = ($2|0)>(0);
 if (!($62)) {
  return;
 }
 $63 = ($$0$i293|0)==(1);
 $64 = ((($0)) + 40|0);
 $65 = HEAP32[$64>>2]|0;
 $66 = Math_imul($$1279, $65)|0;
 $67 = (($6) + ($66)|0);
 $68 = ((($0)) + 44|0);
 $69 = HEAP32[$68>>2]|0;
 $70 = Math_imul($69, $53)|0;
 $71 = (($67) + ($70)|0);
 $72 = ($61|0)>(0);
 $73 = ($5<<24>>24)==(0);
 $74 = ($9|0)==(0);
 $75 = $63 | $74;
 $76 = ($4|0)==(5122);
 $77 = ($5<<24>>24)!=(0);
 $$1260354 = 0;$$1277352 = $71;$$2263353 = $7;
 while(1) {
  if ($72) {
   $$1258346 = 0;$$2275343 = $$1277352;$$3264345 = $$2263353;
   while(1) {
    $switch$split42D = ($4|0)<(32820);
    L64: do {
     if ($switch$split42D) {
      $switch$split132D = ($4|0)<(5124);
      if ($switch$split132D) {
       switch ($4|0) {
       case 5121:  {
        $118 = HEAP8[$$2275343>>0]|0;
        if ($73) {
         $121 = $118&255;
         $122 = ($121*257)|0;
         $123 = $122&65535;
         $124 = ((($$3264345)) + 2|0);
         HEAP16[$$3264345>>1] = $123;
         $$16 = $124;
         break L64;
        } else {
         $119 = $118&255;
         $120 = ((($$3264345)) + 2|0);
         HEAP16[$$3264345>>1] = $119;
         $$16 = $120;
         break L64;
        }
        break;
       }
       case 5120:  {
        $125 = HEAP8[$$2275343>>0]|0;
        if ($73) {
         $128 = $125 << 24 >> 24;
         $129 = ($128*516)|0;
         $130 = $129&65535;
         $131 = ((($$3264345)) + 2|0);
         HEAP16[$$3264345>>1] = $130;
         $$16 = $131;
         break L64;
        } else {
         $126 = $125 << 24 >> 24;
         $127 = ((($$3264345)) + 2|0);
         HEAP16[$$3264345>>1] = $126;
         $$16 = $127;
         break L64;
        }
        break;
       }
       case 5122: case 5123:  {
        if ($75) {
         $328 = HEAP8[$$2275343>>0]|0;
         $$sroa$0$0$insert$ext12 = $328&255;
         $329 = ((($$2275343)) + 1|0);
         $$sink4 = $329;$$sroa$0$0$insert$ext$pn = $$sroa$0$0$insert$ext12;
        } else {
         $326 = ((($$2275343)) + 1|0);
         $327 = HEAP8[$326>>0]|0;
         $$sroa$0$0$insert$ext = $327&255;
         $$sink4 = $$2275343;$$sroa$0$0$insert$ext$pn = $$sroa$0$0$insert$ext;
        }
        $330 = HEAP8[$$sink4>>0]|0;
        $$sroa$0$1$insert$ext31 = $330&255;
        $$sroa$0$1$insert$shift32 = $$sroa$0$1$insert$ext31 << 8;
        $$sroa$0$1$insert$insert34 = $$sroa$0$0$insert$ext$pn | $$sroa$0$1$insert$shift32;
        $$sroa$0$0$extract$trunc = $$sroa$0$1$insert$insert34&65535;
        if (!($76)) {
         $335 = ((($$3264345)) + 2|0);
         HEAP16[$$3264345>>1] = $$sroa$0$0$extract$trunc;
         $$16 = $335;
         break L64;
        }
        if ($73) {
         $332 = $$sroa$0$1$insert$insert34 << 1;
         $333 = $332&65535;
         $334 = ((($$3264345)) + 2|0);
         HEAP16[$$3264345>>1] = $333;
         $$16 = $334;
         break L64;
        } else {
         $331 = ((($$3264345)) + 2|0);
         HEAP16[$$3264345>>1] = $$sroa$0$0$extract$trunc;
         $$16 = $331;
         break L64;
        }
        break;
       }
       default: {
        $$16 = $$3264345;
        break L64;
       }
       }
      }
      $switch$split192D = ($4|0)<(5126);
      L89: do {
       if ($switch$split192D) {
        switch ($4|0) {
        case 5125: case 5124:  {
         break;
        }
        default: {
         $$16 = $$3264345;
         break L64;
        }
        }
       } else {
        $switch$split252D = ($4|0)<(32818);
        if ($switch$split252D) {
         switch ($4|0) {
         case 5126:  {
          break L89;
          break;
         }
         default: {
          $$16 = $$3264345;
          break L64;
         }
         }
        }
        switch ($4|0) {
        case 32818:  {
         $78 = HEAP8[$$2275343>>0]|0;
         $79 = $78&255;
         $80 = $79 >>> 5;
         $81 = (+($80|0));
         $82 = $81 / 7.0;
         $83 = $79 >>> 2;
         $84 = $83 & 7;
         $85 = (+($84|0));
         $86 = $85 / 7.0;
         $87 = $79 & 3;
         $88 = (+($87|0));
         $89 = $88 / 3.0;
         $90 = $82 * 65535.0;
         $91 = (~~(($90))&65535);
         $92 = ((($$3264345)) + 2|0);
         HEAP16[$$3264345>>1] = $91;
         $93 = $86 * 65535.0;
         $94 = (~~(($93))&65535);
         $95 = ((($$3264345)) + 4|0);
         HEAP16[$92>>1] = $94;
         $96 = $89 * 65535.0;
         $97 = (~~(($96))&65535);
         HEAP16[$95>>1] = $97;
         $scevgep416 = ((($$3264345)) + 6|0);
         $$16 = $scevgep416;
         break L64;
         break;
        }
        case 32819:  {
         break;
        }
        default: {
         $$16 = $$3264345;
         break L64;
        }
        }
        if ($75) {
         $196 = HEAP16[$$2275343>>1]|0;
         $$0$i290 = $196;
        } else {
         $188 = ((($$2275343)) + 1|0);
         $189 = HEAP8[$188>>0]|0;
         $190 = $189&255;
         $191 = $190 << 8;
         $192 = HEAP8[$$2275343>>0]|0;
         $193 = $192&255;
         $194 = $191 | $193;
         $195 = $194&65535;
         $$0$i290 = $195;
        }
        $197 = $$0$i290&65535;
        $198 = $197 >>> 12;
        $199 = (+($198|0));
        $200 = $199 / 15.0;
        $201 = $197 >>> 8;
        $202 = $201 & 15;
        $203 = (+($202|0));
        $204 = $203 / 15.0;
        $205 = $197 >>> 4;
        $206 = $205 & 15;
        $207 = (+($206|0));
        $208 = $207 / 15.0;
        $209 = $197 & 15;
        $210 = (+($209|0));
        $211 = $210 / 15.0;
        $212 = $200 * 65535.0;
        $213 = (~~(($212))&65535);
        $214 = ((($$3264345)) + 2|0);
        HEAP16[$$3264345>>1] = $213;
        $215 = $204 * 65535.0;
        $216 = (~~(($215))&65535);
        $217 = ((($$3264345)) + 4|0);
        HEAP16[$214>>1] = $216;
        $218 = $208 * 65535.0;
        $219 = (~~(($218))&65535);
        $220 = ((($$3264345)) + 6|0);
        HEAP16[$217>>1] = $219;
        $221 = $211 * 65535.0;
        $222 = (~~(($221))&65535);
        HEAP16[$220>>1] = $222;
        $scevgep404 = ((($$3264345)) + 8|0);
        $$16 = $scevgep404;
        break L64;
       }
      } while(0);
      $508 = ((($$2275343)) + 2|0);
      $509 = HEAP8[$508>>0]|0;
      $510 = ((($$2275343)) + 1|0);
      $511 = HEAP8[$510>>0]|0;
      $$sroa$0$1$insert$ext = $509&255;
      $$sroa$0$2$insert$ext = $511&255;
      if ($75) {
       $514 = HEAP8[$$2275343>>0]|0;
       $$sroa$0$0$insert$ext20 = $514&255;
       $$sroa$0$1$insert$shift27 = $$sroa$0$2$insert$ext << 8;
       $$sroa$0$2$insert$shift37 = $$sroa$0$1$insert$ext << 16;
       $$sroa$0$2$insert$mask38 = $$sroa$0$2$insert$shift37 | $$sroa$0$1$insert$shift27;
       $$sroa$0$2$insert$insert39 = $$sroa$0$2$insert$mask38 | $$sroa$0$0$insert$ext20;
       $515 = ((($$2275343)) + 3|0);
       $$sink8 = $515;$$sroa$0$3 = $$sroa$0$2$insert$insert39;
      } else {
       $512 = ((($$2275343)) + 3|0);
       $513 = HEAP8[$512>>0]|0;
       $$sroa$0$0$insert$ext16 = $513&255;
       $$sroa$0$1$insert$shift = $$sroa$0$1$insert$ext << 8;
       $$sroa$0$2$insert$shift = $$sroa$0$2$insert$ext << 16;
       $$sroa$0$2$insert$mask = $$sroa$0$1$insert$shift | $$sroa$0$2$insert$shift;
       $$sroa$0$2$insert$insert = $$sroa$0$2$insert$mask | $$sroa$0$0$insert$ext16;
       $$sink8 = $$2275343;$$sroa$0$3 = $$sroa$0$2$insert$insert;
      }
      $516 = HEAP8[$$sink8>>0]|0;
      $$sroa$0$3$insert$ext = $516&255;
      $$sroa$0$3$insert$shift = $$sroa$0$3$insert$ext << 24;
      $$sroa$0$3$insert$mask = $$sroa$0$3 & 16777215;
      $$sroa$0$3$insert$insert = $$sroa$0$3$insert$shift | $$sroa$0$3$insert$mask;
      switch ($4|0) {
      case 5126:  {
       $517 = (HEAP32[tempDoublePtr>>2]=$$sroa$0$3$insert$insert,+HEAPF32[tempDoublePtr>>2]);
       if ($77) {
        $518 = (~~(($517))&65535);
        $519 = ((($$3264345)) + 2|0);
        HEAP16[$$3264345>>1] = $518;
        $$16 = $519;
        break L64;
       } else {
        $520 = $517 * 65535.0;
        $521 = (~~(($520))&65535);
        $522 = ((($$3264345)) + 2|0);
        HEAP16[$$3264345>>1] = $521;
        $$16 = $522;
        break L64;
       }
       break;
      }
      case 5125:  {
       if ($77) {
        $523 = $$sroa$0$3&65535;
        $524 = ((($$3264345)) + 2|0);
        HEAP16[$$3264345>>1] = $523;
        $$16 = $524;
        break L64;
       } else {
        $525 = $$sroa$0$3$insert$insert >>> 16;
        $526 = $525&65535;
        $527 = ((($$3264345)) + 2|0);
        HEAP16[$$3264345>>1] = $526;
        $$16 = $527;
        break L64;
       }
       break;
      }
      default: {
       if ($77) {
        $528 = $$sroa$0$3&65535;
        $529 = ((($$3264345)) + 2|0);
        HEAP16[$$3264345>>1] = $528;
        $$16 = $529;
        break L64;
       } else {
        $530 = $$sroa$0$3$insert$insert >>> 15;
        $531 = $530&65535;
        $532 = ((($$3264345)) + 2|0);
        HEAP16[$$3264345>>1] = $531;
        $$16 = $532;
        break L64;
       }
      }
      }
     } else {
      do {
       switch ($4|0) {
       case 33634:  {
        $98 = HEAP8[$$2275343>>0]|0;
        $99 = $98&255;
        $100 = $99 & 7;
        $101 = (+($100|0));
        $102 = $101 / 7.0;
        $103 = $99 >>> 3;
        $104 = $103 & 7;
        $105 = (+($104|0));
        $106 = $105 / 7.0;
        $107 = $99 >>> 6;
        $108 = (+($107|0));
        $109 = $108 / 3.0;
        $110 = $102 * 65535.0;
        $111 = (~~(($110))&65535);
        $112 = ((($$3264345)) + 2|0);
        HEAP16[$$3264345>>1] = $111;
        $113 = $106 * 65535.0;
        $114 = (~~(($113))&65535);
        $115 = ((($$3264345)) + 4|0);
        HEAP16[$112>>1] = $114;
        $116 = $109 * 65535.0;
        $117 = (~~(($116))&65535);
        HEAP16[$115>>1] = $117;
        $scevgep413 = ((($$3264345)) + 6|0);
        $$16 = $scevgep413;
        break L64;
        break;
       }
       case 33635:  {
        if ($75) {
         $140 = HEAP16[$$2275343>>1]|0;
         $$0$i292 = $140;
        } else {
         $132 = ((($$2275343)) + 1|0);
         $133 = HEAP8[$132>>0]|0;
         $134 = $133&255;
         $135 = $134 << 8;
         $136 = HEAP8[$$2275343>>0]|0;
         $137 = $136&255;
         $138 = $135 | $137;
         $139 = $138&65535;
         $$0$i292 = $139;
        }
        $141 = $$0$i292&65535;
        $142 = $141 >>> 11;
        $143 = (+($142|0));
        $144 = $143 / 31.0;
        $145 = $141 >>> 5;
        $146 = $145 & 63;
        $147 = (+($146|0));
        $148 = $147 / 63.0;
        $149 = $141 & 31;
        $150 = (+($149|0));
        $151 = $150 / 31.0;
        $152 = $144 * 65535.0;
        $153 = (~~(($152))&65535);
        $154 = ((($$3264345)) + 2|0);
        HEAP16[$$3264345>>1] = $153;
        $155 = $148 * 65535.0;
        $156 = (~~(($155))&65535);
        $157 = ((($$3264345)) + 4|0);
        HEAP16[$154>>1] = $156;
        $158 = $151 * 65535.0;
        $159 = (~~(($158))&65535);
        HEAP16[$157>>1] = $159;
        $scevgep410 = ((($$3264345)) + 6|0);
        $$16 = $scevgep410;
        break L64;
        break;
       }
       case 33636:  {
        if ($75) {
         $168 = HEAP16[$$2275343>>1]|0;
         $$0$i291 = $168;
        } else {
         $160 = ((($$2275343)) + 1|0);
         $161 = HEAP8[$160>>0]|0;
         $162 = $161&255;
         $163 = $162 << 8;
         $164 = HEAP8[$$2275343>>0]|0;
         $165 = $164&255;
         $166 = $163 | $165;
         $167 = $166&65535;
         $$0$i291 = $167;
        }
        $169 = $$0$i291&65535;
        $170 = $169 & 31;
        $171 = (+($170|0));
        $172 = $171 / 31.0;
        $173 = $169 >>> 5;
        $174 = $173 & 63;
        $175 = (+($174|0));
        $176 = $175 / 63.0;
        $177 = $169 >>> 11;
        $178 = (+($177|0));
        $179 = $178 / 31.0;
        $180 = $172 * 65535.0;
        $181 = (~~(($180))&65535);
        $182 = ((($$3264345)) + 2|0);
        HEAP16[$$3264345>>1] = $181;
        $183 = $176 * 65535.0;
        $184 = (~~(($183))&65535);
        $185 = ((($$3264345)) + 4|0);
        HEAP16[$182>>1] = $184;
        $186 = $179 * 65535.0;
        $187 = (~~(($186))&65535);
        HEAP16[$185>>1] = $187;
        $scevgep407 = ((($$3264345)) + 6|0);
        $$16 = $scevgep407;
        break L64;
        break;
       }
       case 33637:  {
        if ($75) {
         $231 = HEAP16[$$2275343>>1]|0;
         $$0$i289 = $231;
        } else {
         $223 = ((($$2275343)) + 1|0);
         $224 = HEAP8[$223>>0]|0;
         $225 = $224&255;
         $226 = $225 << 8;
         $227 = HEAP8[$$2275343>>0]|0;
         $228 = $227&255;
         $229 = $226 | $228;
         $230 = $229&65535;
         $$0$i289 = $230;
        }
        $232 = $$0$i289&65535;
        $233 = $232 & 15;
        $234 = (+($233|0));
        $235 = $234 / 15.0;
        $236 = $232 >>> 4;
        $237 = $236 & 15;
        $238 = (+($237|0));
        $239 = $238 / 15.0;
        $240 = $232 >>> 8;
        $241 = $240 & 15;
        $242 = (+($241|0));
        $243 = $242 / 15.0;
        $244 = $232 >>> 12;
        $245 = (+($244|0));
        $246 = $245 / 15.0;
        $247 = $235 * 65535.0;
        $248 = (~~(($247))&65535);
        $249 = ((($$3264345)) + 2|0);
        HEAP16[$$3264345>>1] = $248;
        $250 = $239 * 65535.0;
        $251 = (~~(($250))&65535);
        $252 = ((($$3264345)) + 4|0);
        HEAP16[$249>>1] = $251;
        $253 = $243 * 65535.0;
        $254 = (~~(($253))&65535);
        $255 = ((($$3264345)) + 6|0);
        HEAP16[$252>>1] = $254;
        $256 = $246 * 65535.0;
        $257 = (~~(($256))&65535);
        HEAP16[$255>>1] = $257;
        $scevgep401 = ((($$3264345)) + 8|0);
        $$16 = $scevgep401;
        break L64;
        break;
       }
       case 32820:  {
        if ($75) {
         $266 = HEAP16[$$2275343>>1]|0;
         $$0$i288 = $266;
        } else {
         $258 = ((($$2275343)) + 1|0);
         $259 = HEAP8[$258>>0]|0;
         $260 = $259&255;
         $261 = $260 << 8;
         $262 = HEAP8[$$2275343>>0]|0;
         $263 = $262&255;
         $264 = $261 | $263;
         $265 = $264&65535;
         $$0$i288 = $265;
        }
        $267 = $$0$i288&65535;
        $268 = $267 >>> 11;
        $269 = (+($268|0));
        $270 = $269 / 31.0;
        $271 = $267 >>> 6;
        $272 = $271 & 31;
        $273 = (+($272|0));
        $274 = $273 / 31.0;
        $275 = $267 >>> 1;
        $276 = $275 & 31;
        $277 = (+($276|0));
        $278 = $277 / 31.0;
        $279 = $267 & 1;
        $280 = (+($279|0));
        $281 = $270 * 65535.0;
        $282 = (~~(($281))&65535);
        $283 = ((($$3264345)) + 2|0);
        HEAP16[$$3264345>>1] = $282;
        $284 = $274 * 65535.0;
        $285 = (~~(($284))&65535);
        $286 = ((($$3264345)) + 4|0);
        HEAP16[$283>>1] = $285;
        $287 = $278 * 65535.0;
        $288 = (~~(($287))&65535);
        $289 = ((($$3264345)) + 6|0);
        HEAP16[$286>>1] = $288;
        $290 = $280 * 65535.0;
        $291 = (~~(($290))&65535);
        HEAP16[$289>>1] = $291;
        $scevgep398 = ((($$3264345)) + 8|0);
        $$16 = $scevgep398;
        break L64;
        break;
       }
       case 33638:  {
        if ($75) {
         $300 = HEAP16[$$2275343>>1]|0;
         $$0$i287 = $300;
        } else {
         $292 = ((($$2275343)) + 1|0);
         $293 = HEAP8[$292>>0]|0;
         $294 = $293&255;
         $295 = $294 << 8;
         $296 = HEAP8[$$2275343>>0]|0;
         $297 = $296&255;
         $298 = $295 | $297;
         $299 = $298&65535;
         $$0$i287 = $299;
        }
        $301 = $$0$i287&65535;
        $302 = $301 & 31;
        $303 = (+($302|0));
        $304 = $303 / 31.0;
        $305 = $301 >>> 5;
        $306 = $305 & 31;
        $307 = (+($306|0));
        $308 = $307 / 31.0;
        $309 = $301 >>> 10;
        $310 = $309 & 31;
        $311 = (+($310|0));
        $312 = $311 / 31.0;
        $313 = $301 >>> 15;
        $314 = (+($313|0));
        $315 = $304 * 65535.0;
        $316 = (~~(($315))&65535);
        $317 = ((($$3264345)) + 2|0);
        HEAP16[$$3264345>>1] = $316;
        $318 = $308 * 65535.0;
        $319 = (~~(($318))&65535);
        $320 = ((($$3264345)) + 4|0);
        HEAP16[$317>>1] = $319;
        $321 = $312 * 65535.0;
        $322 = (~~(($321))&65535);
        $323 = ((($$3264345)) + 6|0);
        HEAP16[$320>>1] = $322;
        $324 = $314 * 65535.0;
        $325 = (~~(($324))&65535);
        HEAP16[$323>>1] = $325;
        $scevgep395 = ((($$3264345)) + 8|0);
        $$16 = $scevgep395;
        break L64;
        break;
       }
       case 32821:  {
        if ($75) {
         $353 = HEAP32[$$2275343>>2]|0;
         $$0$i286 = $353;
        } else {
         $336 = ((($$2275343)) + 3|0);
         $337 = HEAP8[$336>>0]|0;
         $338 = $337&255;
         $339 = $338 << 24;
         $340 = ((($$2275343)) + 2|0);
         $341 = HEAP8[$340>>0]|0;
         $342 = $341&255;
         $343 = $342 << 16;
         $344 = $343 | $339;
         $345 = ((($$2275343)) + 1|0);
         $346 = HEAP8[$345>>0]|0;
         $347 = $346&255;
         $348 = $347 << 8;
         $349 = $344 | $348;
         $350 = HEAP8[$$2275343>>0]|0;
         $351 = $350&255;
         $352 = $349 | $351;
         $$0$i286 = $352;
        }
        $354 = $$0$i286 >>> 24;
        $355 = (+($354>>>0));
        $356 = $355 / 255.0;
        $357 = $$0$i286 >>> 16;
        $358 = $357 & 255;
        $359 = (+($358>>>0));
        $360 = $359 / 255.0;
        $361 = $$0$i286 >>> 8;
        $362 = $361 & 255;
        $363 = (+($362>>>0));
        $364 = $363 / 255.0;
        $365 = $$0$i286 & 255;
        $366 = (+($365>>>0));
        $367 = $366 / 255.0;
        $368 = $356 * 65535.0;
        $369 = (~~(($368))&65535);
        $370 = ((($$3264345)) + 2|0);
        HEAP16[$$3264345>>1] = $369;
        $371 = $360 * 65535.0;
        $372 = (~~(($371))&65535);
        $373 = ((($$3264345)) + 4|0);
        HEAP16[$370>>1] = $372;
        $374 = $364 * 65535.0;
        $375 = (~~(($374))&65535);
        $376 = ((($$3264345)) + 6|0);
        HEAP16[$373>>1] = $375;
        $377 = $367 * 65535.0;
        $378 = (~~(($377))&65535);
        HEAP16[$376>>1] = $378;
        $scevgep392 = ((($$3264345)) + 8|0);
        $$16 = $scevgep392;
        break L64;
        break;
       }
       case 33639:  {
        if ($75) {
         $396 = HEAP32[$$2275343>>2]|0;
         $$0$i285 = $396;
        } else {
         $379 = ((($$2275343)) + 3|0);
         $380 = HEAP8[$379>>0]|0;
         $381 = $380&255;
         $382 = $381 << 24;
         $383 = ((($$2275343)) + 2|0);
         $384 = HEAP8[$383>>0]|0;
         $385 = $384&255;
         $386 = $385 << 16;
         $387 = $386 | $382;
         $388 = ((($$2275343)) + 1|0);
         $389 = HEAP8[$388>>0]|0;
         $390 = $389&255;
         $391 = $390 << 8;
         $392 = $387 | $391;
         $393 = HEAP8[$$2275343>>0]|0;
         $394 = $393&255;
         $395 = $392 | $394;
         $$0$i285 = $395;
        }
        $397 = $$0$i285 & 255;
        $398 = (+($397>>>0));
        $399 = $398 / 255.0;
        $400 = $$0$i285 >>> 8;
        $401 = $400 & 255;
        $402 = (+($401>>>0));
        $403 = $402 / 255.0;
        $404 = $$0$i285 >>> 16;
        $405 = $404 & 255;
        $406 = (+($405>>>0));
        $407 = $406 / 255.0;
        $408 = $$0$i285 >>> 24;
        $409 = (+($408>>>0));
        $410 = $409 / 255.0;
        $411 = $399 * 65535.0;
        $412 = (~~(($411))&65535);
        $413 = ((($$3264345)) + 2|0);
        HEAP16[$$3264345>>1] = $412;
        $414 = $403 * 65535.0;
        $415 = (~~(($414))&65535);
        $416 = ((($$3264345)) + 4|0);
        HEAP16[$413>>1] = $415;
        $417 = $407 * 65535.0;
        $418 = (~~(($417))&65535);
        $419 = ((($$3264345)) + 6|0);
        HEAP16[$416>>1] = $418;
        $420 = $410 * 65535.0;
        $421 = (~~(($420))&65535);
        HEAP16[$419>>1] = $421;
        $scevgep389 = ((($$3264345)) + 8|0);
        $$16 = $scevgep389;
        break L64;
        break;
       }
       case 32822:  {
        if ($75) {
         $439 = HEAP32[$$2275343>>2]|0;
         $$0$i284 = $439;
        } else {
         $422 = ((($$2275343)) + 3|0);
         $423 = HEAP8[$422>>0]|0;
         $424 = $423&255;
         $425 = $424 << 24;
         $426 = ((($$2275343)) + 2|0);
         $427 = HEAP8[$426>>0]|0;
         $428 = $427&255;
         $429 = $428 << 16;
         $430 = $429 | $425;
         $431 = ((($$2275343)) + 1|0);
         $432 = HEAP8[$431>>0]|0;
         $433 = $432&255;
         $434 = $433 << 8;
         $435 = $430 | $434;
         $436 = HEAP8[$$2275343>>0]|0;
         $437 = $436&255;
         $438 = $435 | $437;
         $$0$i284 = $438;
        }
        $440 = $$0$i284 >>> 22;
        $441 = (+($440>>>0));
        $442 = $441 / 1023.0;
        $443 = $$0$i284 >>> 12;
        $444 = $443 & 1023;
        $445 = (+($444>>>0));
        $446 = $445 / 1023.0;
        $447 = $$0$i284 >>> 2;
        $448 = $447 & 1023;
        $449 = (+($448>>>0));
        $450 = $449 / 1023.0;
        $451 = $$0$i284 & 3;
        $452 = (+($451>>>0));
        $453 = $452 / 3.0;
        $454 = $442 * 65535.0;
        $455 = (~~(($454))&65535);
        $456 = ((($$3264345)) + 2|0);
        HEAP16[$$3264345>>1] = $455;
        $457 = $446 * 65535.0;
        $458 = (~~(($457))&65535);
        $459 = ((($$3264345)) + 4|0);
        HEAP16[$456>>1] = $458;
        $460 = $450 * 65535.0;
        $461 = (~~(($460))&65535);
        $462 = ((($$3264345)) + 6|0);
        HEAP16[$459>>1] = $461;
        $463 = $453 * 65535.0;
        $464 = (~~(($463))&65535);
        HEAP16[$462>>1] = $464;
        $scevgep386 = ((($$3264345)) + 8|0);
        $$16 = $scevgep386;
        break L64;
        break;
       }
       case 33640:  {
        if ($75) {
         $482 = HEAP32[$$2275343>>2]|0;
         $$0$i283 = $482;
        } else {
         $465 = ((($$2275343)) + 3|0);
         $466 = HEAP8[$465>>0]|0;
         $467 = $466&255;
         $468 = $467 << 24;
         $469 = ((($$2275343)) + 2|0);
         $470 = HEAP8[$469>>0]|0;
         $471 = $470&255;
         $472 = $471 << 16;
         $473 = $472 | $468;
         $474 = ((($$2275343)) + 1|0);
         $475 = HEAP8[$474>>0]|0;
         $476 = $475&255;
         $477 = $476 << 8;
         $478 = $473 | $477;
         $479 = HEAP8[$$2275343>>0]|0;
         $480 = $479&255;
         $481 = $478 | $480;
         $$0$i283 = $481;
        }
        $483 = $$0$i283 & 1023;
        $484 = (+($483>>>0));
        $485 = $484 / 1023.0;
        $486 = $$0$i283 >>> 10;
        $487 = $486 & 1023;
        $488 = (+($487>>>0));
        $489 = $488 / 1023.0;
        $490 = $$0$i283 >>> 20;
        $491 = $490 & 1023;
        $492 = (+($491>>>0));
        $493 = $492 / 1023.0;
        $494 = $$0$i283 >>> 30;
        $495 = (+($494>>>0));
        $496 = $495 / 3.0;
        $497 = $485 * 65535.0;
        $498 = (~~(($497))&65535);
        $499 = ((($$3264345)) + 2|0);
        HEAP16[$$3264345>>1] = $498;
        $500 = $489 * 65535.0;
        $501 = (~~(($500))&65535);
        $502 = ((($$3264345)) + 4|0);
        HEAP16[$499>>1] = $501;
        $503 = $493 * 65535.0;
        $504 = (~~(($503))&65535);
        $505 = ((($$3264345)) + 6|0);
        HEAP16[$502>>1] = $504;
        $506 = $496 * 65535.0;
        $507 = (~~(($506))&65535);
        HEAP16[$505>>1] = $507;
        $scevgep383 = ((($$3264345)) + 8|0);
        $$16 = $scevgep383;
        break L64;
        break;
       }
       default: {
        $$16 = $$3264345;
        break L64;
       }
       }
      } while(0);
     }
    } while(0);
    $533 = (($$2275343) + ($$0$i293)|0);
    $534 = (($$1258346) + 1)|0;
    $exitcond419 = ($534|0)==($61|0);
    if ($exitcond419) {
     $$3264$lcssa = $$16;
     break;
    } else {
     $$1258346 = $534;$$2275343 = $533;$$3264345 = $$16;
    }
   }
  } else {
   $$3264$lcssa = $$2263353;
  }
  $535 = (($$1277352) + ($$1279)|0);
  $536 = (($$1260354) + 1)|0;
  $exitcond420 = ($536|0)==($2|0);
  if ($exitcond420) {
   break;
  } else {
   $$1260354 = $536;$$1277352 = $535;$$2263353 = $$3264$lcssa;
  }
 }
 return;
}
function __ZN3osgL14scale_internalEiiiPKtiiPt($0,$1,$2,$3,$4,$5,$6) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 var $$0139 = 0.0, $$0139$p = 0.0, $$0140159$us$us = 0, $$0140159$us168 = 0, $$0141164 = 0, $$0141164$us = 0, $$0142157$us$us = 0, $$0143183 = 0, $$0144187 = 0, $$0145$lcssa = 0.0, $$0145163$us = 0.0, $$0147 = 0.0, $$0147$$us$us = 0.0, $$0147$$us170 = 0.0, $$0148$us = 0.0, $$0149$us$us = 0.0, $$0149$us171 = 0.0, $$0150162$us = 0.0, $$0151 = 0.0, $$0151$p = 0.0;
 var $$0152 = 0.0, $$0152$$us = 0.0, $$0160$us$us = 0.0, $$0160$us167 = 0.0, $$04462$us$i$us = 0, $$04761$us$i$us = 0, $$04855$us$us$i$us = 0, $$04951$us$us$i$us = 0, $$063$us$i$us = 0, $$1146158$us$us = 0.0, $$1146158$us169 = 0.0, $$1179 = 0, $$14556$us$us$i$us = 0, $$157$us$us$i$us = 0, $$24652$us$us$i$us = 0, $$253$us$us$i$us = 0, $$pn = 0.0, $$pn153 = 0.0, $10 = 0, $100 = 0;
 var $101 = 0.0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0.0, $107 = 0.0, $108 = 0, $109 = 0.0, $11 = 0, $110 = 0.0, $111 = 0, $112 = 0, $113 = 0.0, $114 = 0, $115 = 0, $116 = 0, $117 = 0.0, $118 = 0, $119 = 0.0;
 var $12 = 0, $120 = 0.0, $121 = 0.0, $122 = 0.0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0.0, $49 = 0.0, $50 = 0.0, $51 = 0.0, $52 = 0.0, $53 = 0.0, $54 = 0.0, $55 = 0.0, $56 = 0, $57 = 0.0, $58 = 0, $59 = 0.0, $60 = 0, $61 = 0.0, $62 = 0;
 var $63 = 0.0, $64 = 0, $65 = 0.0, $66 = 0.0, $67 = 0.0, $68 = 0.0, $69 = 0.0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0.0, $74 = 0.0, $75 = 0.0, $76 = 0.0, $77 = 0.0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0.0, $84 = 0, $85 = 0, $86 = 0, $87 = 0.0, $88 = 0, $89 = 0.0, $9 = 0, $90 = 0.0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0.0, $97 = 0, $98 = 0.0, $99 = 0;
 var $exitcond = 0, $exitcond$i$us = 0, $exitcond195 = 0, $exitcond196 = 0, $exitcond197 = 0, $exitcond90$i$us = 0, $exitcond91$i$us = 0, $or$cond = 0, $scevgep85$i$us = 0, $scevgep86$i$us = 0, $scevgep87$i$us = 0, $split$us = 0.0, $uglygep$i$us = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $7 = sp;
 $8 = $4 << 1;
 $9 = ($8|0)==($1|0);
 $10 = $5 << 1;
 $11 = ($10|0)==($2|0);
 $or$cond = $9 & $11;
 if ($or$cond) {
  $12 = $1 >>> 1;
  $13 = $2 >>> 1;
  $14 = Math_imul($1, $0)|0;
  $15 = ($13|0)==(0);
  if ($15) {
   STACKTOP = sp;return;
  }
  $16 = ($12|0)==(0);
  $17 = (($14) + ($0))|0;
  if ($16) {
   STACKTOP = sp;return;
  }
  $18 = ($0|0)>(0);
  $19 = Math_imul($12, $0)|0;
  $20 = $12 << 2;
  $21 = (($20) + -2)|0;
  $22 = Math_imul($21, $0)|0;
  if ($18) {
   $$04462$us$i$us = $6;$$04761$us$i$us = 0;$$063$us$i$us = $3;
  } else {
   STACKTOP = sp;return;
  }
  while(1) {
   $$04855$us$us$i$us = 0;$$14556$us$us$i$us = $$04462$us$i$us;$$157$us$us$i$us = $$063$us$i$us;
   while(1) {
    $$04951$us$us$i$us = 0;$$24652$us$us$i$us = $$14556$us$us$i$us;$$253$us$us$i$us = $$157$us$us$i$us;
    while(1) {
     $23 = HEAP16[$$253$us$us$i$us>>1]|0;
     $24 = $23&65535;
     $25 = (($$253$us$us$i$us) + ($0<<1)|0);
     $26 = HEAP16[$25>>1]|0;
     $27 = $26&65535;
     $28 = (($$253$us$us$i$us) + ($14<<1)|0);
     $29 = HEAP16[$28>>1]|0;
     $30 = $29&65535;
     $31 = (($$253$us$us$i$us) + ($17<<1)|0);
     $32 = HEAP16[$31>>1]|0;
     $33 = $32&65535;
     $34 = (($24) + 2)|0;
     $35 = (($34) + ($27))|0;
     $36 = (($35) + ($30))|0;
     $37 = (($36) + ($33))|0;
     $38 = $37 >>> 2;
     $39 = $38&65535;
     HEAP16[$$24652$us$us$i$us>>1] = $39;
     $40 = ((($$24652$us$us$i$us)) + 2|0);
     $41 = ((($$253$us$us$i$us)) + 2|0);
     $42 = (($$04951$us$us$i$us) + 1)|0;
     $exitcond$i$us = ($42|0)==($0|0);
     if ($exitcond$i$us) {
      break;
     } else {
      $$04951$us$us$i$us = $42;$$24652$us$us$i$us = $40;$$253$us$us$i$us = $41;
     }
    }
    $scevgep85$i$us = (($$14556$us$us$i$us) + ($0<<1)|0);
    $scevgep86$i$us = (($$157$us$us$i$us) + ($0<<1)|0);
    $43 = (($scevgep86$i$us) + ($0<<1)|0);
    $44 = (($$04855$us$us$i$us) + 1)|0;
    $exitcond90$i$us = ($44|0)==($12|0);
    if ($exitcond90$i$us) {
     break;
    } else {
     $$04855$us$us$i$us = $44;$$14556$us$us$i$us = $scevgep85$i$us;$$157$us$us$i$us = $43;
    }
   }
   $uglygep$i$us = (($$063$us$i$us) + ($22)|0);
   $scevgep87$i$us = (($$04462$us$i$us) + ($19<<1)|0);
   $45 = (($uglygep$i$us) + ($0<<1)|0);
   $46 = (($45) + ($14<<1)|0);
   $47 = (($$04761$us$i$us) + 1)|0;
   $exitcond91$i$us = ($47|0)==($13|0);
   if ($exitcond91$i$us) {
    break;
   } else {
    $$04462$us$i$us = $scevgep87$i$us;$$04761$us$i$us = $47;$$063$us$i$us = $46;
   }
  }
  STACKTOP = sp;return;
 }
 $48 = (+($2|0));
 $49 = (+($5|0));
 $50 = $48 / $49;
 $51 = (+($1|0));
 $52 = (+($4|0));
 $53 = $51 / $52;
 $54 = $53 * 0.5;
 $55 = $50 * 0.5;
 $56 = ($5|0)>(0);
 if (!($56)) {
  STACKTOP = sp;return;
 }
 $57 = $50;
 $58 = ($2|0)>($5|0);
 $$pn = $58 ? $55 : 0.5;
 $59 = -$55;
 $$0151$p = $58 ? $59 : -0.5;
 $60 = ($4|0)>(0);
 $61 = $53;
 $62 = ($1|0)>($4|0);
 $$pn153 = $62 ? $54 : 0.5;
 $63 = -$54;
 $$0139$p = $62 ? $63 : -0.5;
 $64 = ($0|0)>(0);
 $$0144187 = 0;
 while(1) {
  $65 = (+($$0144187|0));
  $66 = $65 + 0.5;
  $67 = $57 * $66;
  $68 = $67;
  $$0151 = $$0151$p + $68;
  $$0152 = $$pn + $68;
  if ($60) {
   $69 = (+Math_floor((+$$0151)));
   $70 = (~~(($69)));
   $71 = $$0151 < $$0152;
   $72 = Math_imul($$0144187, $4)|0;
   $$0143183 = 0;
   while(1) {
    $73 = (+($$0143183|0));
    $74 = $73 + 0.5;
    $75 = $61 * $74;
    $76 = $75;
    $$0139 = $$0139$p + $76;
    $$0147 = $$pn153 + $76;
    ;HEAP32[$7>>2]=0|0;HEAP32[$7+4>>2]=0|0;HEAP32[$7+8>>2]=0|0;HEAP32[$7+12>>2]=0|0;
    L30: do {
     if ($71) {
      $77 = (+Math_floor((+$$0139)));
      $78 = (~~(($77)));
      $79 = $$0139 < $$0147;
      if ($79) {
       $$0141164$us = $70;$$0145163$us = 0.0;$$0150162$us = $$0151;
      } else {
       $$0141164 = $70;
       while(1) {
        $112 = (($$0141164) + 1)|0;
        $113 = (+($112|0));
        $114 = $113 < $$0152;
        if ($114) {
         $$0141164 = $112;
        } else {
         $$0145$lcssa = 0.0;
         break L30;
        }
       }
      }
      while(1) {
       $80 = (($$0141164$us) + ($2))|0;
       $81 = (($80|0) % ($2|0))&-1;
       $82 = (($$0141164$us) + 1)|0;
       $83 = (+($82|0));
       $84 = $$0152 < $83;
       $$0152$$us = $84 ? $$0152 : $83;
       $$0148$us = $$0152$$us - $$0150162$us;
       $85 = Math_imul($81, $1)|0;
       if ($64) {
        $$0140159$us$us = $78;$$0160$us$us = $$0139;$$1146158$us$us = $$0145163$us;
        while(1) {
         $93 = (($$0140159$us$us) + ($1))|0;
         $94 = (($93|0) % ($1|0))&-1;
         $95 = (($$0140159$us$us) + 1)|0;
         $96 = (+($95|0));
         $97 = $$0147 < $96;
         $$0147$$us$us = $97 ? $$0147 : $96;
         $$0149$us$us = $$0147$$us$us - $$0160$us$us;
         $98 = $$0148$us * $$0149$us$us;
         $99 = (($94) + ($85))|0;
         $100 = Math_imul($99, $0)|0;
         $$0142157$us$us = 0;
         while(1) {
          $103 = (($$0142157$us$us) + ($100))|0;
          $104 = (($3) + ($103<<1)|0);
          $105 = HEAP16[$104>>1]|0;
          $106 = (+($105&65535));
          $107 = $98 * $106;
          $108 = (($7) + ($$0142157$us$us<<2)|0);
          $109 = +HEAPF32[$108>>2];
          $110 = $109 + $107;
          HEAPF32[$108>>2] = $110;
          $111 = (($$0142157$us$us) + 1)|0;
          $exitcond = ($111|0)==($0|0);
          if ($exitcond) {
           break;
          } else {
           $$0142157$us$us = $111;
          }
         }
         $101 = $$1146158$us$us + $98;
         $102 = $96 < $$0147;
         if ($102) {
          $$0140159$us$us = $95;$$0160$us$us = $96;$$1146158$us$us = $101;
         } else {
          $split$us = $101;
          break;
         }
        }
       } else {
        $$0140159$us168 = $78;$$0160$us167 = $$0139;$$1146158$us169 = $$0145163$us;
        while(1) {
         $86 = (($$0140159$us168) + 1)|0;
         $87 = (+($86|0));
         $88 = $$0147 < $87;
         $$0147$$us170 = $88 ? $$0147 : $87;
         $$0149$us171 = $$0147$$us170 - $$0160$us167;
         $89 = $$0148$us * $$0149$us171;
         $90 = $$1146158$us169 + $89;
         $91 = $87 < $$0147;
         if ($91) {
          $$0140159$us168 = $86;$$0160$us167 = $87;$$1146158$us169 = $90;
         } else {
          $split$us = $90;
          break;
         }
        }
       }
       $92 = $83 < $$0152;
       if ($92) {
        $$0141164$us = $82;$$0145163$us = $split$us;$$0150162$us = $83;
       } else {
        $$0145$lcssa = $split$us;
        break;
       }
      }
     } else {
      $$0145$lcssa = 0.0;
     }
    } while(0);
    $115 = (($$0143183) + ($72))|0;
    $116 = Math_imul($115, $0)|0;
    if ($64) {
     $117 = $$0145$lcssa;
     $$1179 = 0;
     while(1) {
      $118 = (($7) + ($$1179<<2)|0);
      $119 = +HEAPF32[$118>>2];
      $120 = $119;
      $121 = $120 + 0.5;
      $122 = $121 / $117;
      $123 = (~~(($122))&65535);
      $124 = (($$1179) + ($116))|0;
      $125 = (($6) + ($124<<1)|0);
      HEAP16[$125>>1] = $123;
      $126 = (($$1179) + 1)|0;
      $exitcond195 = ($126|0)==($0|0);
      if ($exitcond195) {
       break;
      } else {
       $$1179 = $126;
      }
     }
    }
    $127 = (($$0143183) + 1)|0;
    $exitcond196 = ($127|0)==($4|0);
    if ($exitcond196) {
     break;
    } else {
     $$0143183 = $127;
    }
   }
  }
  $128 = (($$0144187) + 1)|0;
  $exitcond197 = ($128|0)==($5|0);
  if ($exitcond197) {
   break;
  } else {
   $$0144187 = $128;
  }
 }
 STACKTOP = sp;return;
}
function __ZN3osgL26gluBuild2DMipmapLevelsCoreEjiiiiijjiiiPKv($0,$1,$2,$3,$4,$5,$6,$7,$8,$9,$10,$11) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 $8 = $8|0;
 $9 = $9|0;
 $10 = $10|0;
 $11 = $11|0;
 var $$ = 0, $$$i = 0, $$$i$i = 0, $$0$$i = 0, $$0$$i$i = 0, $$0$$i798 = 0, $$0$$i89$i = 0, $$0$i = 0, $$0$i$i = 0, $$0$i$i$i = 0, $$0$i$i96$i = 0, $$0$i$i97$i = 0, $$0$i12$i = 0.0, $$0$i12$i$ph = 0.0, $$0$i12$i1628 = 0.0, $$0$i12$i1628$ph = 0.0, $$0$i12$i939 = 0.0, $$0$i12$i939$ph = 0.0, $$0$i12$i948 = 0.0, $$0$i12$i948$ph = 0.0;
 var $$0$i14$i = 0, $$0$i14$i1626 = 0, $$0$i14$i937 = 0, $$0$i14$i946 = 0, $$0$i3$i$i = 0, $$0$i805 = 0, $$0$i806 = 0, $$0$i874 = 0, $$0$i875 = 0, $$0$i877 = 0, $$0$i879 = 0, $$0$i881 = 0, $$0$i883 = 0, $$0$i885 = 0, $$0$i887 = 0, $$0$i920 = 0, $$0$i921 = 0, $$0$i923 = 0, $$0$i925 = 0, $$0$i927 = 0;
 var $$0$i929 = 0, $$0$i931 = 0, $$0$i933 = 0, $$0$lcssa$i = 0, $$0$lcssa$i$i = 0, $$0$lcssa$i797 = 0, $$0$lcssa$i88$i = 0, $$010$i = 0, $$010$i$i = 0, $$010$i$i$i = 0, $$010$i5$i$i = 0, $$010$i800 = 0, $$010$i91$i = 0, $$0114131$i = 0, $$0114131$us$i = 0, $$0116130$i = 0, $$0116130$us$i = 0, $$0369475$us$i = 0, $$0369475$us$i1541 = 0, $$0370$us$i = 0;
 var $$0370$us$i1545 = 0, $$0370474$i = 0, $$0370474$i1492 = 0, $$0370477$us$i = 0, $$0370477$us$i1539 = 0, $$0370507$us$i = 0, $$0370507$us$i1024 = 0, $$0371448$us$i = 0, $$0371448$us$i1508 = 0, $$0372$us$i = 0, $$0372$us$i1032 = 0, $$0372506$i = 0, $$0372506$i967 = 0, $$0372509$us$i = 0, $$0372509$us$i1022 = 0, $$0374476$us$i = 0, $$0374476$us$i987 = 0, $$0374510$i = 0, $$0374510$i1486 = 0, $$0375503$i = 0;
 var $$0375503$i1497 = 0, $$0377538$i = 0, $$0377538$i961 = 0, $$0378530$i = 0, $$0378530$i972 = 0, $$0380509$i = 0.0, $$0380509$i1487 = 0.0, $$0382508$i = 0.0, $$0382508$i$phi = 0.0, $$0382508$i1488 = 0.0, $$0382508$i1488$phi = 0.0, $$0383499$i = 0.0, $$0383499$i1498 = 0.0, $$0383537$i = 0.0, $$0383537$i962 = 0.0, $$0385498$i = 0.0, $$0385498$i$phi = 0.0, $$0385498$i1499 = 0.0, $$0385498$i1499$phi = 0.0, $$0385536$i = 0.0;
 var $$0385536$i$phi = 0.0, $$0385536$i963 = 0.0, $$0385536$i963$phi = 0.0, $$0386529$i = 0.0, $$0386529$i973 = 0.0, $$0388528$i = 0.0, $$0388528$i$phi = 0.0, $$0388528$i974 = 0.0, $$0388528$i974$phi = 0.0, $$0391507$i = 0, $$0391507$i1489 = 0, $$0393506$i = 0, $$0393506$i$phi = 0, $$0393506$i1490 = 0, $$0393506$i1490$phi = 0, $$0394$$i = 0, $$0394$$i966 = 0, $$0394496$i = 0, $$0394496$i1500 = 0, $$0394535$i = 0;
 var $$0394535$i964 = 0, $$0396495$i = 0, $$0396495$i$phi = 0, $$0396495$i1501 = 0, $$0396495$i1501$phi = 0, $$0397488$i$us = 0, $$0397488$i1598$us = 0, $$0397534$i = 0, $$0397534$i965 = 0, $$0398527$i = 0, $$0398527$i975 = 0, $$0400526$i = 0, $$0400526$i$phi = 0, $$0400526$i976 = 0, $$0400526$i976$phi = 0, $$0401519$i$us = 0, $$0401519$i1102$us = 0, $$0476$us$i = 0, $$0476$us$i1540 = 0, $$0508$us$i = 0;
 var $$0508$us$i1023 = 0, $$0520672$i = 0, $$0520672$i$us = 0, $$0522$i = 0, $$0522$i$us = 0, $$0522671$i = 0, $$0522674$i = 0, $$0522674$i$us = 0, $$0524641$i = 0, $$0524641$i$us = 0, $$0527703$i = 0, $$0528695$i = 0, $$0533702$i = 0.0, $$0535701$i = 0.0, $$0535701$i$phi = 0.0, $$0536694$i = 0.0, $$0538693$i = 0.0, $$0538693$i$phi = 0.0, $$0539731$i = 0, $$0539731$i$us = 0;
 var $$0541$i = 0, $$0541$i$us = 0, $$0541730$i = 0, $$0541733$i = 0, $$0541733$i$us = 0, $$0543686$us$i = 0, $$0543686$us$i$us = 0, $$0544$$i = 0, $$0544700$i = 0, $$0546768$i = 0, $$0547699$i = 0, $$0547760$i = 0, $$0548692$i = 0, $$0550691$i = 0, $$0550691$i$phi = 0, $$0551684$i = 0, $$0552767$i = 0.0, $$0554766$i = 0.0, $$0554766$i$phi = 0.0, $$0555759$i = 0.0;
 var $$0557758$i = 0.0, $$0557758$i$phi = 0.0, $$0563$$i = 0, $$0563744$i = 0, $$0563744$i$us = 0, $$0563765$i = 0, $$0565$i = 0, $$0565$i$us = 0, $$0565743$i = 0, $$0565746$i = 0, $$0565746$i$us = 0, $$0566764$i = 0, $$0567699$us$i = 0, $$0567699$us$i$us = 0, $$0567757$i = 0, $$0569742$i = 0, $$0569742$i$us = 0, $$0569756$i = 0, $$0569756$i$phi = 0, $$0570749$i$us = 0;
 var $$0570781$i = 0, $$0571$i = 0, $$0571$i$us = 0, $$0571741$i = 0, $$0571744$i = 0, $$0571744$i$us = 0, $$0571748$i = 0, $$0571748$i$us = 0, $$0571773$i = 0, $$0572691$i = 0, $$0573$i = 0, $$0573$i$us = 0, $$0573699$us$i = 0, $$0573699$us$i$us = 0, $$0573747$i = 0, $$0573750$i = 0, $$0573750$i$us = 0, $$0575703$us$i = 0, $$0575703$us$i$us = 0, $$0576778$i = 0;
 var $$0577770$i = 0, $$0578691$i = 0, $$0578785$i = 0, $$0579777$i = 0, $$0580695$i = 0, $$0581780$i = 0.0, $$0582777$i = 0.0, $$0583779$i = 0.0, $$0583779$i$phi = 0.0, $$0584772$i = 0.0, $$0584776$i = 0.0, $$0584776$i$phi = 0.0, $$0584784$i = 0.0, $$0585769$i = 0.0, $$0586771$i = 0.0, $$0586771$i$phi = 0.0, $$0586783$i = 0.0, $$0586783$i$phi = 0.0, $$0587762$i$us = 0, $$0587768$i = 0.0;
 var $$0587768$i$phi = 0.0, $$0587776$i = 0.0, $$0588$$i = 0, $$0588778$i = 0, $$0589775$i = 0.0, $$0589775$i$phi = 0.0, $$0591777$i = 0, $$0592770$i = 0, $$0593$$i = 0, $$0593775$i = 0, $$0594769$i = 0, $$0594769$i$phi = 0, $$0595$$i = 0, $$0595690$i = 0, $$0595782$i = 0, $$0596774$i = 0, $$0597767$i = 0, $$0598781$i = 0, $$0599766$i = 0, $$0599766$i$phi = 0;
 var $$0599774$i = 0, $$0600759$i$us = 0, $$0601690$i = 0, $$0601773$i = 0, $$0601773$i$phi = 0, $$0602766$i$us = 0, $$0603694$i = 0, $$0673$i = 0, $$0673$i$us = 0, $$07$lcssa$i = 0, $$07$lcssa$i$i = 0, $$07$lcssa$i796 = 0, $$07$lcssa$i87$i = 0, $$0732$i = 0, $$0732$i$us = 0, $$0743$i = 0, $$0743$i$us = 0, $$0745$i = 0, $$0745$i$us = 0, $$0749$i = 0;
 var $$0749$i$us = 0, $$07512026 = 0, $$07522025 = 0, $$07532024 = 0, $$076138$i = 0, $$076138$us$i = 0, $$0762 = 0, $$0764 = 0, $$0767 = 0, $$0769 = 0, $$0778 = 0, $$078$lcssa$i = 0, $$078137$i = 0, $$078137$us$i = 0, $$0784 = 0, $$079$i = 0, $$079$i$i = 0, $$079$i801 = 0, $$079$i92$i = 0, $$079136$i = 0;
 var $$079136$us$i = 0, $$07999$us$i = 0, $$07999$us$i1651 = 0, $$07999$us$i1682 = 0, $$07999$us$i1713 = 0, $$07999$us$i1744 = 0, $$07999$us$i1775 = 0, $$07999$us$i1814 = 0, $$07999$us$i830 = 0, $$07999$us$i861 = 0, $$07999$us$i907 = 0, $$08$i = 0, $$08$i$i = 0, $$08$i803 = 0, $$08$i94$i = 0, $$08098$us$i = 0, $$08098$us$i1652 = 0, $$08098$us$i1683 = 0, $$08098$us$i1714 = 0, $$08098$us$i1745 = 0;
 var $$08098$us$i1776 = 0, $$08098$us$i1815 = 0, $$08098$us$i831 = 0, $$08098$us$i862 = 0, $$08098$us$i908 = 0, $$081135$i = 0, $$081135$us$i = 0, $$08197$us$i = 0, $$08197$us$i1653 = 0, $$08197$us$i1684 = 0, $$08197$us$i1715 = 0, $$08197$us$i1746 = 0, $$08197$us$i1777 = 0, $$08197$us$i1816 = 0, $$08197$us$i832 = 0, $$08197$us$i863 = 0, $$08197$us$i909 = 0, $$083134$i = 0, $$083134$us$i = 0, $$08391$us$us$i = 0;
 var $$08391$us$us$i1658 = 0, $$08391$us$us$i1689 = 0, $$08391$us$us$i1720 = 0, $$08391$us$us$i1751 = 0, $$08391$us$us$i1782 = 0, $$08391$us$us$i1821 = 0, $$08391$us$us$i837 = 0, $$08391$us$us$i868 = 0, $$08391$us$us$i914 = 0, $$085110$us$i$i = 0, $$085110$us$i$i1644 = 0, $$085110$us$i$i1675 = 0, $$085110$us$i$i1706 = 0, $$085110$us$i$i1737 = 0, $$085110$us$i$i1768 = 0, $$085110$us$i$i1807 = 0, $$085110$us$i$i823 = 0, $$085110$us$i$i854 = 0, $$085110$us$i$i900 = 0, $$088100$us$i$i = 0;
 var $$088100$us$i$i1636 = 0, $$088100$us$i$i1667 = 0, $$088100$us$i$i1698 = 0, $$088100$us$i$i1729 = 0, $$088100$us$i$i1760 = 0, $$088100$us$i$i1799 = 0, $$088100$us$i$i815 = 0, $$088100$us$i$i846 = 0, $$088100$us$i$i892 = 0, $$09$i$i$i = 0, $$09$i2$i$i = 0, $$09098$us$i$i = 0, $$09098$us$i$i1637 = 0, $$09098$us$i$i1668 = 0, $$09098$us$i$i1699 = 0, $$09098$us$i$i1730 = 0, $$09098$us$i$i1761 = 0, $$09098$us$i$i1800 = 0, $$09098$us$i$i816 = 0, $$09098$us$i$i847 = 0;
 var $$09098$us$i$i893 = 0, $$1$i = 0, $$1$i$i = 0, $$1$us$i = 0, $$1$us$i1470 = 0, $$1$us$i1558 = 0, $$10412440$us$i = 0, $$10412440$us$i1071 = 0, $$10562605$i = 0, $$10562605$us$i$us = 0, $$10581636$us$us$i$us = 0, $$10581636$us642$i = 0, $$10605649$us$us$i$us = 0, $$10605649$us655$i = 0, $$10611651$us$us$i$us = 0, $$10611651$us657$i = 0, $$10613653$us$us$i$us = 0, $$10613653$us659$i = 0, $$10647$i = 0, $$10649$i = 0;
 var $$10651$i = 0, $$1115$i = 0, $$1115$us$i = 0, $$1117$i = 0, $$1117$us$i = 0, $$11413445$i = 0, $$11413445$i1088 = 0, $$11441$us$i = 0, $$11441$us$i1070 = 0, $$11563610$i = 0, $$11563610$us$i = 0, $$11582648$i = 0, $$11582648$us$i = 0, $$11606$i = 0, $$11606$us$i$us = 0, $$11606661$i = 0, $$11606661$us$i = 0, $$11612662$i = 0, $$11612662$us$i = 0, $$11614665$i = 0;
 var $$11614665$us$i = 0, $$11637$us$us$i$us = 0, $$11637$us641$i = 0, $$11650$us$us$i$us = 0, $$11650$us654$i = 0, $$11652$us$us$i$us = 0, $$11652$us656$i = 0, $$11654$us$us$i$us = 0, $$11654$us658$i = 0, $$12446$i = 0, $$12446$i1087 = 0, $$12607644$i = 0, $$12611$i = 0, $$12611$us$i = 0, $$12613646$i = 0, $$12615648$i = 0, $$12649$i = 0, $$12649$us$i = 0, $$12662$i = 0, $$12662$us$i = 0;
 var $$12663$i = 0, $$12663$us$i = 0, $$12666$i = 0, $$12666$us$i = 0, $$13415511$us$i$us = 0, $$13415511$us$i1109$us = 0, $$13565676$i = 0, $$13565676$us$i$us = 0, $$13584735$us$us$i$us$us = 0, $$13584735$us744$i$us2110 = 0, $$13608748$us$us$i$us$us = 0, $$13608748$us757$i$us2147 = 0, $$13614746$us$us$i$us$us = 0, $$13614746$us755$i$us2219 = 0, $$13616752$us$us$i$us$us = 0, $$13616752$us761$i$us2185 = 0, $$13645$i = 0, $$13647$i = 0, $$13649$i = 0, $$1371500$us$i = 0;
 var $$1371500$us$i1028 = 0, $$1372464$us$i = 0, $$1372464$us$i1524 = 0, $$1373$us$i = 0, $$1373$us$i1047 = 0, $$1373459$us$i = 0, $$1373459$us$i1041 = 0, $$1375492$us$i = 0, $$1375492$us$i1005 = 0, $$1380473$us$i = 0, $$1380473$us$i989 = 0, $$1381$i = 0.0, $$1381$i1620 = 0.0, $$1384$i = 0.0, $$1384$i1125 = 0.0, $$1384$i1482 = 0.0, $$1384$i1616 = 0.0, $$1387$i = 0.0, $$1387$i1121 = 0.0, $$1392$i = 0;
 var $$1392$i1619 = 0, $$1395$i = 0, $$1395$i1615 = 0, $$1399$i = 0, $$1399$i1120 = 0, $$1403472$us$i = 0, $$1403472$us$i990 = 0, $$1433$us$i = 0, $$1433$us$i1553 = 0, $$14512$us$i$us = 0, $$14512$us$i1108$us = 0, $$14677$i = 0, $$14677$us$i$us = 0, $$14736$us$us$i$us$us = 0, $$14736$us743$i$us2109 = 0, $$14747$us$us$i$us$us = 0, $$14747$us754$i$us2218 = 0, $$14749$us$us$i$us$us = 0, $$14749$us756$i$us2146 = 0, $$14753$us$us$i$us$us = 0;
 var $$14753$us760$i$us2184 = 0, $$1501$us$i = 0, $$1501$us$i1027 = 0, $$1521665$i = 0, $$1521665$us$i$us = 0, $$1523$i = 0, $$1523$i$us = 0, $$1523624$i = 0, $$1523624$i$us = 0, $$1525657$i = 0, $$1525657$i$us = 0, $$1530638$i = 0, $$1530638$us$i$us = 0, $$1534$i = 0.0, $$1537$i = 0.0, $$1540724$i = 0, $$1540724$us$i$us = 0, $$1542$us$i = 0, $$1542$us$i$us = 0, $$1542662$us$i = 0;
 var $$1542662$us$i$us = 0, $$1544709$us$i = 0, $$1544709$us$i$us = 0, $$1549$i = 0, $$1549683$us$us$i$us = 0, $$1549683$us689$i = 0, $$15522$i = 0, $$15522$i1117 = 0, $$1553$i = 0.0, $$1553637$i = 0, $$1553637$us$i$us = 0, $$1556$i = 0.0, $$1564737$i = 0, $$1564737$us$i$us = 0, $$1566$us$i = 0, $$1566$us$i$us = 0, $$1566675$us$i = 0, $$1566675$us$i$us = 0, $$1568$i = 0, $$15687$i = 0;
 var $$1568722$us$i = 0, $$1568722$us$i$us = 0, $$1570735$i = 0, $$1570735$us$i$us = 0, $$1572$us$i = 0, $$1572$us$i$us = 0, $$1572676$us$i = 0, $$1572676$us$i$us = 0, $$1572682$us$us$i$us = 0, $$1572682$us690$i = 0, $$1572741$i = 0, $$1572741$us$i$us = 0, $$1573696$us$us$i$us = 0, $$1573696$us702$i = 0, $$1574$us$i = 0, $$1574$us$i$us = 0, $$1574679$us$i = 0, $$1574679$us$i$us = 0, $$1574721$us$i = 0, $$1574721$us$i$us = 0;
 var $$15752$i = 0, $$15762$i = 0, $$15765$i = 0, $$1576726$us$i = 0, $$1576726$us$i$us = 0, $$15769$i = 0, $$1579696$us$us$i$us = 0, $$1579696$us702$i = 0, $$1581700$us$us$i$us = 0, $$1581700$us706$i = 0, $$1582$i = 0.0, $$1583$i = 0.0, $$1585$i = 0.0, $$1585$i1353 = 0.0, $$1586$i = 0.0, $$1588$i = 0.0, $$1593$i = 0, $$1596695$us$us$i$us = 0, $$1596695$us703$i = 0, $$1598$i = 0;
 var $$1600$i = 0, $$1602695$us$us$i$us = 0, $$1602695$us703$i = 0, $$1604699$us$us$i$us = 0, $$1604699$us707$i = 0, $$1666$i = 0, $$1666$us$i$us = 0, $$1725$i = 0, $$1725$us$i$us = 0, $$1736$i = 0, $$1736$us$i$us = 0, $$1738$i = 0, $$1738$us$i$us = 0, $$1742$i = 0, $$1742$us$i$us = 0, $$1755 = 0, $$1759 = 0, $$17632034 = 0, $$17632034$in = 0, $$1768$lcssa = 0;
 var $$17682030 = 0, $$17682030$phi = 0, $$1779 = 0, $$180$i = 0, $$180$us$i = 0, $$182$i = 0, $$182$us$i = 0, $$18292$us$us$i = 0, $$18292$us$us$i1657 = 0, $$18292$us$us$i1688 = 0, $$18292$us$us$i1719 = 0, $$18292$us$us$i1750 = 0, $$18292$us$us$i1781 = 0, $$18292$us$us$i1820 = 0, $$18292$us$us$i836 = 0, $$18292$us$us$i867 = 0, $$18292$us$us$i913 = 0, $$184$i = 0, $$184$us$i = 0, $$191108$us$i$i = 0;
 var $$191108$us$i$i1645 = 0, $$191108$us$i$i1676 = 0, $$191108$us$i$i1707 = 0, $$191108$us$i$i1738 = 0, $$191108$us$i$i1769 = 0, $$191108$us$i$i1808 = 0, $$191108$us$i$i824 = 0, $$191108$us$i$i855 = 0, $$191108$us$i$i901 = 0, $$193$us$us$i = 0, $$193$us$us$i1656 = 0, $$193$us$us$i1687 = 0, $$193$us$us$i1718 = 0, $$193$us$us$i1749 = 0, $$193$us$us$i1780 = 0, $$193$us$us$i1819 = 0, $$193$us$us$i835 = 0, $$193$us$us$i866 = 0, $$193$us$us$i912 = 0, $$2$i = 0;
 var $$2$us$i = 0, $$2373$us$i = 0, $$2373$us$i1578 = 0, $$2373419$i = 0, $$2373419$i1571 = 0, $$2373420$us$i = 0, $$2373420$us$i1574 = 0, $$2376$us$i = 0, $$2376$us$i1073 = 0, $$2376443$i = 0, $$2376443$i1065 = 0, $$2376444$us$i = 0, $$2376444$us$i1068 = 0, $$2381480$i = 0, $$2381480$i998 = 0, $$2388$lcssa$i = 0, $$2388$lcssa$i1566 = 0, $$2388432$us$i = 0, $$2388432$us$i1554 = 0, $$2391$lcssa$i = 0;
 var $$2391$lcssa$i1059 = 0, $$2391458$us$i = 0, $$2391458$us$i1042 = 0, $$2396$i = 0, $$2396$i1124 = 0, $$2404479$i = 0, $$2404479$i999 = 0, $$2489$i$us = 0, $$2489$i1597$us = 0, $$2520$i$us = 0, $$2520$i1101$us = 0, $$2526$i = 0, $$2526$i$us = 0, $$2526608$i = 0, $$2526609$i = 0, $$2526609$i$us = 0, $$2531645$i = 0, $$2531645$us$i = 0, $$2541$lcssa$i = 0, $$2541623$i = 0;
 var $$2541623$i$us = 0, $$2545$us$i = 0, $$2545$us$i$us = 0, $$2545639$i = 0, $$2545640$us$i = 0, $$2545640$us$i$us = 0, $$2546$i = 0, $$2550697$i = 0, $$2550697$us$i = 0, $$2554644$i = 0, $$2554644$us$i = 0, $$2560$lcssa$i = 0, $$2560661$us$i = 0, $$2560661$us$i$us = 0, $$2565$i = 0, $$2569$us$i = 0, $$2569$us$i$us = 0, $$2569652$i = 0, $$2569653$us$i = 0, $$2569653$us$i$us = 0;
 var $$2573696$i = 0, $$2573696$us$i = 0, $$2574710$i = 0, $$2574710$us$i = 0, $$2575$us$i = 0, $$2575$us$i$us = 0, $$2575654$i = 0, $$2575655$us$i = 0, $$2575655$us$i$us = 0, $$2577$us$i = 0, $$2577$us$i$us = 0, $$2577656$i = 0, $$2577657$us$i = 0, $$2577657$us$i$us = 0, $$2578$lcssa$i = 0, $$2578674$us$i = 0, $$2578674$us$i$us = 0, $$2580709$i = 0, $$2580709$us$i = 0, $$2582714$i = 0;
 var $$2582714$us$i = 0, $$2590$i = 0, $$2590$lcssa$i = 0, $$2590675$us$i = 0, $$2590675$us$i$us = 0, $$2592$lcssa$i = 0, $$2592678$us$i = 0, $$2592678$us$i$us = 0, $$2595$i = 0, $$2597$i = 0, $$2597709$i = 0, $$2597709$us$i = 0, $$2603708$i = 0, $$2603708$us$i = 0, $$2605713$i = 0, $$2605713$us$i = 0, $$2685$i = 0, $$2750$i$us = 0, $$27562033 = 0, $$2760$i$us = 0;
 var $$27602032 = 0, $$2763$i$us = 0, $$2767$i$us = 0, $$27802028 = 0, $$3$i = 0, $$3$i$us = 0, $$3$us$i$us = 0, $$3$us$i1111$us = 0, $$3$us$i1183$us$us = 0, $$3$us$i1183$us2118 = 0, $$3$us$i1249$us$us = 0, $$3$us$i1249$us2156 = 0, $$3$us$i1348$us$us = 0, $$3$us$i1348$us2194 = 0, $$3$us$i1460$us$us = 0, $$3$us$i1460$us2226 = 0, $$3$us$i1480$us = 0, $$3$us$i1606$us = 0, $$3382485$i = 0, $$3382485$i1012 = 0;
 var $$3405484$i = 0, $$3405484$i1013 = 0, $$3483$i = 0, $$3483$i1595 = 0, $$3485$us$i$us = 0, $$3485$us$i1601$us = 0, $$3515$i = 0, $$3515$i1099 = 0, $$3517$us$i$us = 0, $$3517$us$i1105$us = 0, $$3532650$i = 0, $$3532650$us$i = 0, $$3551702$i = 0, $$3551702$us$i = 0, $$3555649$i = 0, $$3555649$us$i = 0, $$3574701$i = 0, $$3574701$us$i = 0, $$3575715$i = 0, $$3575715$us$i = 0;
 var $$3581714$i = 0, $$3581714$us$i = 0, $$3583719$i = 0, $$3583719$us$i = 0, $$3598714$i = 0, $$3598714$us$i = 0, $$3604713$i = 0, $$3604713$us$i = 0, $$3606718$i = 0, $$3606718$us$i = 0, $$3680$i = 0, $$3682$i = 0, $$3682$i$us = 0, $$3739$i = 0, $$3741$us$i$us$us = 0, $$3741$us$i$us2106 = 0, $$3750$i = 0, $$3752$i = 0, $$3752$us$i$us$us = 0, $$3752$us$i$us2215 = 0;
 var $$3754$us$i$us$us = 0, $$3754$us$i$us2143 = 0, $$3756$i = 0, $$3757 = 0, $$3758$us$i$us$us = 0, $$3758$us$i$us2181 = 0, $$3761 = 0, $$3781 = 0, $$4 = 0, $$4390484$us$i$us = 0, $$4390484$us$i1602$us = 0, $$4393516$us$i$us = 0, $$4393516$us$i1106$us = 0, $$4406488$us$i = 0, $$4406488$us$i1008 = 0, $$4489$us$i = 0, $$4489$us$i1007 = 0, $$4543681$i = 0, $$4543681$i$us = 0, $$4556653$i = 0;
 var $$4556653$us$i$us = 0, $$4562740$us$i$us$us = 0, $$4562740$us$i$us2107 = 0, $$4575705$us$us$i$us = 0, $$4575705$us713$i = 0, $$4580753$us$i$us$us = 0, $$4580753$us$i$us2144 = 0, $$4592751$us$i$us$us = 0, $$4592751$us$i$us2216 = 0, $$4594757$us$i$us$us = 0, $$4594757$us$i$us2182 = 0, $$4599718$us$us$i$us = 0, $$4599718$us726$i = 0, $$4605717$us$us$i$us = 0, $$4605717$us725$i = 0, $$4607722$us$us$i$us = 0, $$4607722$us730$i = 0, $$4654$i = 0, $$4654$us$i$us = 0, $$4706$us$us$i$us = 0;
 var $$4706$us712$i = 0, $$4718$us$us$i$us = 0, $$4718$us724$i = 0, $$4719$us$us$i$us = 0, $$4719$us725$i = 0, $$4723$us$us$i$us = 0, $$4723$us729$i = 0, $$5 = 0, $$5407495$i = 0, $$5407495$i1036 = 0, $$5496$i = 0, $$5496$i1035 = 0, $$5557660$i = 0, $$5557660$us$i = 0, $$5576719$i = 0, $$5576719$us$i = 0, $$5600732$i = 0, $$5600732$us$i = 0, $$5606730$i = 0, $$5606730$us$i = 0;
 var $$5608736$i = 0, $$5608736$us$i = 0, $$5661$i = 0, $$5661$us$i = 0, $$5720$i = 0, $$5720$us$i = 0, $$5731$i = 0, $$5731$us$i = 0, $$5733$i = 0, $$5733$us$i = 0, $$5737$i = 0, $$5737$us$i = 0, $$6$lcssa = 0, $$62029 = 0, $$62029$phi = 0, $$6499$us$i = 0, $$6499$us$i1029 = 0, $$6601665$i = 0, $$6607666$i = 0, $$6609669$i = 0;
 var $$6664$i = 0, $$6664$us$i$us = 0, $$6723$i = 0, $$6723$us$i$us = 0, $$6734$i = 0, $$6734$us$i$us = 0, $$6736$i = 0, $$6736$us$i$us = 0, $$6740$i = 0, $$6740$us$i$us = 0, $$7409453$us$i = 0, $$7409453$us$i1045 = 0, $$7559618$i = 0, $$7559618$us$i$us = 0, $$7578656$us$us$i$us = 0, $$7578656$us667$i = 0, $$7602669$us$us$i$us = 0, $$7602669$us680$i = 0, $$7608670$us$us$i$us = 0, $$7608670$us681$i = 0;
 var $$7610673$us$us$i$us = 0, $$7610673$us684$i = 0, $$7666$i = 0, $$7667$i = 0, $$7670$i = 0, $$785 = 0, $$787 = 0, $$789 = 0, $$8410463$i = 0, $$8410463$i1062 = 0, $$8454$us$i = 0, $$8454$us$i1044 = 0, $$8560628$i = 0, $$8560628$us$i = 0, $$8579673$i = 0, $$8579673$us$i = 0, $$8603686$i = 0, $$8603686$us$i = 0, $$8609686$i = 0, $$8609686$us$i = 0;
 var $$8611690$i = 0, $$8611690$us$i = 0, $$8619$i = 0, $$8619$us$i$us = 0, $$8657$us$us$i$us = 0, $$8657$us666$i = 0, $$8670$us$us$i$us = 0, $$8670$us679$i = 0, $$8671$us$us$i$us = 0, $$8671$us680$i = 0, $$8674$us$us$i$us = 0, $$8674$us683$i = 0, $$9464$i = 0, $$9464$i1061 = 0, $$9604646$i = 0, $$9610648$i = 0, $$9612650$i = 0, $$9629$i = 0, $$9629$us$i = 0, $$9674$i = 0;
 var $$9674$us$i = 0, $$9687$i = 0, $$9687$i1419 = 0, $$9687$us$i = 0, $$9687$us$i1415 = 0, $$9691$i = 0, $$9691$us$i = 0, $$lcssa$i = 0, $$lcssa$i1085 = 0, $$lcssa$i1131 = 0, $$lcssa$i1167 = 0, $$lcssa$i1231 = 0, $$lcssa$i1321 = 0, $$lcssa$i1437 = 0, $$lcssa$i1473 = 0, $$lcssa$i1586 = 0, $$lcssa$i954 = 0, $$lcssa121$i = 0, $$lcssa122$i = 0, $$lcssa412$i = 0;
 var $$lcssa412$i1516 = 0, $$lcssa413$i = 0, $$lcssa413$i1535 = 0, $$lcssa433$i = 0, $$lcssa433$i996 = 0, $$lcssa434$i = 0, $$lcssa434$i1018 = 0, $$lcssa598$i = 0, $$lcssa599$i = 0, $$lcssa629$i = 0, $$lcssa630$i = 0, $$lcssa642$i = 0, $$lcssa643$i = 0, $$lcssa644$i = 0, $$lcssa645$i = 0, $$lcssa646$i = 0, $$lcssa647$i = 0, $$not$i = 0, $$not$i1103 = 0, $$not$i1181 = 0;
 var $$not$i1247 = 0, $$not$i1345 = 0, $$not$i1457 = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert$i$phi$trans$insert = 0, $$phi$trans$insert$i1095 = 0, $$phi$trans$insert$i1095$phi$trans$insert = 0, $$phi$trans$insert$i10952938 = 0, $$phi$trans$insert$i1137 = 0, $$phi$trans$insert$i1137$phi$trans$insert = 0, $$phi$trans$insert$i11372946 = 0, $$phi$trans$insert$i1178 = 0, $$phi$trans$insert$i1178$phi$trans$insert = 0, $$phi$trans$insert$i11782970 = 0, $$phi$trans$insert$i1244 = 0, $$phi$trans$insert$i1341 = 0, $$phi$trans$insert$i1453 = 0, $$phi$trans$insert$i2930 = 0, $$phi$trans$insert607$i = 0, $$phi$trans$insert607$i$phi$trans$insert = 0;
 var $$phi$trans$insert607$i1080 = 0, $$phi$trans$insert607$i1080$phi$trans$insert = 0, $$phi$trans$insert607$i10802940 = 0, $$phi$trans$insert607$i2932 = 0, $$phi$trans$insert609$i = 0, $$phi$trans$insert609$i$phi$trans$insert = 0, $$phi$trans$insert609$i1054 = 0, $$phi$trans$insert609$i1054$phi$trans$insert = 0, $$phi$trans$insert609$i10542942 = 0, $$phi$trans$insert609$i2934 = 0, $$phi$trans$insert611$i = 0, $$phi$trans$insert611$i$phi$trans$insert = 0, $$phi$trans$insert611$i2936 = 0, $$phi$trans$insert611$i982 = 0, $$phi$trans$insert611$i982$phi$trans$insert = 0, $$phi$trans$insert611$i9822944 = 0, $$phi$trans$insert781$i = 0, $$phi$trans$insert781$i$phi$trans$insert = 0, $$phi$trans$insert781$i2949 = 0, $$phi$trans$insert783$i = 0;
 var $$phi$trans$insert783$i$phi$trans$insert = 0, $$phi$trans$insert783$i2952 = 0, $$phi$trans$insert785$i = 0, $$phi$trans$insert785$i$phi$trans$insert = 0, $$phi$trans$insert785$i2955 = 0, $$phi$trans$insert787$i = 0, $$phi$trans$insert787$i$phi$trans$insert = 0, $$phi$trans$insert787$i2958 = 0, $$phi$trans$insert789$i = 0, $$phi$trans$insert789$i$phi$trans$insert = 0, $$phi$trans$insert789$i2961 = 0, $$phi$trans$insert791$i = 0, $$phi$trans$insert791$i$phi$trans$insert = 0, $$phi$trans$insert791$i2964 = 0, $$phi$trans$insert793$i = 0, $$phi$trans$insert793$i$phi$trans$insert = 0, $$phi$trans$insert793$i2967 = 0, $$phi$trans$insert868$i = 0, $$phi$trans$insert868$i$phi$trans$insert = 0, $$phi$trans$insert868$i2974 = 0;
 var $$phi$trans$insert870$i = 0, $$phi$trans$insert870$i$phi$trans$insert = 0, $$phi$trans$insert870$i2977 = 0, $$phi$trans$insert872$i = 0, $$phi$trans$insert872$i$phi$trans$insert = 0, $$phi$trans$insert872$i2981 = 0, $$phi$trans$insert874$i = 0, $$phi$trans$insert874$i$phi$trans$insert = 0, $$phi$trans$insert874$i2984 = 0, $$phi$trans$insert876$i = 0, $$phi$trans$insert876$i$phi$trans$insert = 0, $$phi$trans$insert876$i2988 = 0, $$phi$trans$insert878$i = 0, $$phi$trans$insert878$i$phi$trans$insert = 0, $$phi$trans$insert878$i1447 = 0, $$phi$trans$insert878$i1447$phi$trans$insert = 0, $$phi$trans$insert878$i14473030 = 0, $$phi$trans$insert878$i2991 = 0, $$phi$trans$insert880$i = 0, $$phi$trans$insert880$i$phi$trans$insert = 0;
 var $$phi$trans$insert880$i1434 = 0, $$phi$trans$insert880$i2995 = 0, $$phi$trans$insert881$i = 0, $$phi$trans$insert881$i$phi$trans$insert = 0, $$phi$trans$insert881$i2998 = 0, $$phi$trans$insert882$i = 0, $$phi$trans$insert882$i$phi$trans$insert = 0, $$phi$trans$insert882$i3033 = 0, $$phi$trans$insert883$i = 0, $$phi$trans$insert884$i = 0, $$phi$trans$insert885$i = 0, $$phi$trans$insert885$i$phi$trans$insert = 0, $$phi$trans$insert885$i1334 = 0, $$phi$trans$insert885$i1334$phi$trans$insert = 0, $$phi$trans$insert885$i13343014 = 0, $$phi$trans$insert885$i3002 = 0, $$phi$trans$insert886$i = 0, $$phi$trans$insert886$i$phi$trans$insert = 0, $$phi$trans$insert886$i3036 = 0, $$phi$trans$insert887$i = 0;
 var $$phi$trans$insert887$i1318 = 0, $$phi$trans$insert888$i = 0, $$phi$trans$insert889$i = 0, $$phi$trans$insert889$i$phi$trans$insert = 0, $$phi$trans$insert889$i1309 = 0, $$phi$trans$insert889$i1309$phi$trans$insert = 0, $$phi$trans$insert889$i13093018 = 0, $$phi$trans$insert889$i3006 = 0, $$phi$trans$insert890$i = 0, $$phi$trans$insert890$i$phi$trans$insert = 0, $$phi$trans$insert890$i3039 = 0, $$phi$trans$insert891$i = 0, $$phi$trans$insert891$i1298 = 0, $$phi$trans$insert893$i = 0, $$phi$trans$insert893$i$phi$trans$insert = 0, $$phi$trans$insert893$i1289 = 0, $$phi$trans$insert893$i1289$phi$trans$insert = 0, $$phi$trans$insert893$i12893022 = 0, $$phi$trans$insert893$i3010 = 0, $$phi$trans$insert895$i = 0;
 var $$phi$trans$insert897$i = 0, $$phi$trans$insert897$i$phi$trans$insert = 0, $$phi$trans$insert897$i3026 = 0, $$pn$i = 0.0, $$pn$i1337 = 0.0, $$pn$us$i = 0.0, $$pn$us$i1330 = 0.0, $$pn$us$i13302164 = 0.0, $$pn$us$i13303015 = 0.0, $$pn$us$i2126 = 0.0, $$pn$us$i2999 = 0.0, $$pn609$i = 0.0, $$pn609$us$i = 0.0, $$pn610$us$us$i$us = 0.0, $$pn610$us657$i = 0.0, $$pn611$i = 0.0, $$pn611$us$i = 0.0, $$pn611$us$i2130 = 0.0, $$pn611$us$i3003 = 0.0, $$pn612$i = 0.0;
 var $$pn612$us$i = 0.0, $$pn613$us$us$i$us = 0.0, $$pn613$us682$i = 0.0, $$pn614$i = 0.0, $$pn614$us$i = 0.0, $$pn614$us$i2134 = 0.0, $$pn614$us$i3007 = 0.0, $$pn615$i = 0.0, $$pn615$us$i = 0.0, $$pn616$us$us$i$us = 0.0, $$pn616$us728$i = 0.0, $$pn617$i = 0.0, $$pn617$i1326 = 0.0, $$pn617$us$i = 0.0, $$pn617$us$i1323 = 0.0, $$pn618$i = 0.0, $$pn618$us$i = 0.0, $$pn618$us$us$i$us = 0.0, $$pn618$us661$i = 0.0, $$pn619$i = 0.0;
 var $$pn619$us$i = 0.0, $$pn619$us$i2168 = 0.0, $$pn619$us$i3019 = 0.0, $$pn619$us$us$i$us = 0.0, $$pn619$us705$i = 0.0, $$pn620$i = 0.0, $$pn620$i1304 = 0.0, $$pn620$us$i = 0.0, $$pn620$us$i1301 = 0.0, $$pn620$us$i2138 = 0.0, $$pn620$us$i3011 = 0.0, $$pn621$us$us$i$us = 0.0, $$pn621$us686$i = 0.0, $$pn622$i = 0.0, $$pn622$us$i = 0.0, $$pn622$us$i2172 = 0.0, $$pn622$us$i3023 = 0.0, $$pn623$i = 0.0, $$pn623$us$i = 0.0, $$pn624$us$us$i$us = 0.0;
 var $$pn624$us732$i = 0.0, $$pn625$i = 0.0, $$pn625$us$i = 0.0, $$pn626$i = 0.0, $$pn626$i1266 = 0.0, $$pn626$us$i$us = 0.0, $$pn626$us$i1264 = 0.0, $$pn627$us$us$i$us = 0.0, $$pn627$us709$i = 0.0, $$pn628$i = 0.0, $$pn628$us$i = 0.0, $$pn628$us$i2176 = 0.0, $$pn628$us$i3027 = 0.0, $$pre$i$pre = 0.0, $$pre$i1096$pre = 0.0, $$pre$i1138$pre = 0.0, $$pre$i1179$pre = 0.0, $$pre$i1245 = 0.0, $$pre$i1342 = 0.0, $$pre$i1454 = 0.0;
 var $$pre608$i$pre = 0.0, $$pre608$i1081$pre = 0.0, $$pre610$i$pre = 0.0, $$pre610$i1055$pre = 0.0, $$pre612$i$pre = 0.0, $$pre612$i983$pre = 0.0, $$pre782$i$pre = 0.0, $$pre784$i$pre = 0.0, $$pre786$i$pre = 0.0, $$pre788$i$pre = 0.0, $$pre790$i$pre = 0.0, $$pre792$i$pre = 0.0, $$pre794$i$pre = 0.0, $$pre869$i$pre = 0.0, $$pre871$i$pre = 0.0, $$pre873$i$pre = 0.0, $$pre875$i$pre = 0.0, $$pre877$i$pre = 0.0, $$pre879$i$pre = 0.0, $$pre879$i1448$pre = 0.0;
 var $$pre881$i$pre = 0.0, $$pre881$i1435 = 0.0, $$pre882$i$pre = 0.0, $$pre883$i$pre = 0.0, $$pre884$i = 0.0, $$pre885$i = 0.0, $$pre886$i$pre = 0.0, $$pre886$i1335$pre = 0.0, $$pre887$i$pre = 0.0, $$pre888$i = 0.0, $$pre888$i1319 = 0.0, $$pre889$i = 0.0, $$pre890$i$pre = 0.0, $$pre890$i1310$pre = 0.0, $$pre891$i$pre = 0.0, $$pre892$i = 0.0, $$pre892$i1299 = 0.0, $$pre894$i$pre = 0.0, $$pre894$i1290$pre = 0.0, $$pre896$i = 0.0;
 var $$pre898$i$pre = 0.0, $$sink$i = 0.0, $$sink$i1210 = 0.0, $$sink$us$i$us = 0.0, $$sink$us$i1209$us = 0.0, $$sink12$i = 0.0, $$sink12$i1145 = 0.0, $$sink12$i1194 = 0.0, $$sink12$i1267 = 0.0, $$sink12$i1378 = 0.0, $$sink12$us$i = 0.0, $$sink12$us$i1144 = 0.0, $$sink12$us$i1193 = 0.0, $$sink12$us$i1265 = 0.0, $$sink12$us$i1376 = 0.0, $$sink17$i = 0.0, $$sink17$i1147 = 0.0, $$sink17$i1201 = 0.0, $$sink17$i1275 = 0.0, $$sink17$i1387 = 0.0;
 var $$sink17$us$i = 0.0, $$sink17$us$i1146 = 0.0, $$sink17$us$i1196 = 0.0, $$sink17$us$i1268 = 0.0, $$sink17$us$i1379 = 0.0, $$sink22$i = 0.0, $$sink22$us$i$us = 0.0, $$sink22$us$us$i$us = 0.0, $$sink22$us$us$i1200$us = 0.0, $$sink22$us$us$i1273$us = 0.0, $$sink22$us$us$i1385$us = 0.0, $$sink22$us716$i = 0.0, $$sink22$us727$i = 0.0, $$sink22$us729$i = 0.0, $$sink22$us733$i = 0.0, $$sink27$i = 0.0, $$sink27$i1149 = 0.0, $$sink27$i1204 = 0.0, $$sink27$i1279 = 0.0, $$sink27$i1393 = 0.0;
 var $$sink27$us$i = 0.0, $$sink27$us$i1148 = 0.0, $$sink27$us$i1202 = 0.0, $$sink27$us$i1277 = 0.0, $$sink27$us$i1390 = 0.0, $$sink3$i = 0.0, $$sink3$i1143 = 0.0, $$sink3$i11432099 = 0.0, $$sink3$i11432993 = 0.0, $$sink3$i1187 = 0.0, $$sink3$i1256 = 0.0, $$sink3$i1360 = 0.0, $$sink3$i2071 = 0.0, $$sink3$i2965 = 0.0, $$sink3$us$i = 0.0, $$sink3$us$i1142 = 0.0, $$sink3$us$i11422102 = 0.0, $$sink3$us$i11422996 = 0.0, $$sink3$us$i1186 = 0.0, $$sink3$us$i11862139 = 0.0;
 var $$sink3$us$i11863012 = 0.0, $$sink3$us$i1254 = 0.0, $$sink3$us$i12542177 = 0.0, $$sink3$us$i12543028 = 0.0, $$sink3$us$i1356 = 0.0, $$sink3$us$i13562211 = 0.0, $$sink3$us$i13563040 = 0.0, $$sink3$us$i2074 = 0.0, $$sink3$us$i2968 = 0.0, $$sink37$i = 0.0, $$sink37$i1156 = 0.0, $$sink37$i11562092 = 0.0, $$sink37$i11562986 = 0.0, $$sink37$i1217 = 0.0, $$sink37$i1296 = 0.0, $$sink37$i1412 = 0.0, $$sink37$i2065 = 0.0, $$sink37$i2959 = 0.0, $$sink37$us$i = 0.0, $$sink37$us$i1153 = 0.0;
 var $$sink37$us$i11532095 = 0.0, $$sink37$us$i11532989 = 0.0, $$sink37$us$i1211 = 0.0, $$sink37$us$i12112135 = 0.0, $$sink37$us$i12113008 = 0.0, $$sink37$us$i1287 = 0.0, $$sink37$us$i12872173 = 0.0, $$sink37$us$i12873024 = 0.0, $$sink37$us$i1403 = 0.0, $$sink37$us$i14032208 = 0.0, $$sink37$us$i14033037 = 0.0, $$sink37$us$i2068 = 0.0, $$sink37$us$i2962 = 0.0, $$sink42$i = 0.0, $$sink42$us$i$us = 0.0, $$sink42$us$us$i$us = 0.0, $$sink42$us$us$i1216$us = 0.0, $$sink42$us$us$i1294$us = 0.0, $$sink42$us$us$i1410$us = 0.0, $$sink42$us670$i = 0.0;
 var $$sink42$us683$i = 0.0, $$sink42$us683$i1406 = 0.0, $$sink42$us687$i = 0.0, $$sink47$i = 0.0, $$sink47$i1159 = 0.0, $$sink47$i1223 = 0.0, $$sink47$i1305 = 0.0, $$sink47$i1420 = 0.0, $$sink47$us$i = 0.0, $$sink47$us$i1158 = 0.0, $$sink47$us$i1221 = 0.0, $$sink47$us$i1302 = 0.0, $$sink47$us$i1416 = 0.0, $$sink52$i = 0.0, $$sink52$i1163 = 0.0, $$sink52$i11632085 = 0.0, $$sink52$i11632979 = 0.0, $$sink52$i1229 = 0.0, $$sink52$i1315 = 0.0, $$sink52$i1432 = 0.0;
 var $$sink52$i2059 = 0.0, $$sink52$i2953 = 0.0, $$sink52$us$i = 0.0, $$sink52$us$i1160 = 0.0, $$sink52$us$i11602088 = 0.0, $$sink52$us$i11602982 = 0.0, $$sink52$us$i1225 = 0.0, $$sink52$us$i12252131 = 0.0, $$sink52$us$i12253004 = 0.0, $$sink52$us$i1307 = 0.0, $$sink52$us$i13072169 = 0.0, $$sink52$us$i13073020 = 0.0, $$sink52$us$i1422 = 0.0, $$sink52$us$i14222205 = 0.0, $$sink52$us$i14223034 = 0.0, $$sink52$us$i2062 = 0.0, $$sink52$us$i2956 = 0.0, $$sink57$i = 0.0, $$sink57$us$i$us = 0.0, $$sink57$us$us$i$us = 0.0;
 var $$sink57$us$us$i1228$us = 0.0, $$sink57$us$us$i1313$us = 0.0, $$sink57$us$us$i1430$us = 0.0, $$sink57$us645$i = 0.0, $$sink57$us658$i = 0.0, $$sink57$us659$i = 0.0, $$sink57$us662$i = 0.0, $$sink62$i = 0.0, $$sink62$i1170 = 0.0, $$sink62$i1235 = 0.0, $$sink62$i1327 = 0.0, $$sink62$i1441 = 0.0, $$sink62$us$i = 0.0, $$sink62$us$i1169 = 0.0, $$sink62$us$i1233 = 0.0, $$sink62$us$i1324 = 0.0, $$sink62$us$i1439 = 0.0, $$sink67$i = 0.0, $$sink67$i1175 = 0.0, $$sink67$i11752078 = 0.0;
 var $$sink67$i11752972 = 0.0, $$sink67$i1241 = 0.0, $$sink67$i1338 = 0.0, $$sink67$i1450 = 0.0, $$sink67$i2053 = 0.0, $$sink67$i2947 = 0.0, $$sink67$us$i = 0.0, $$sink67$us$i1172 = 0.0, $$sink67$us$i11722081 = 0.0, $$sink67$us$i11722975 = 0.0, $$sink67$us$i1238 = 0.0, $$sink67$us$i12382127 = 0.0, $$sink67$us$i12383000 = 0.0, $$sink67$us$i1331 = 0.0, $$sink67$us$i13312165 = 0.0, $$sink67$us$i13313016 = 0.0, $$sink67$us$i1444 = 0.0, $$sink67$us$i14442202 = 0.0, $$sink67$us$i14443031 = 0.0, $$sink67$us$i2056 = 0.0;
 var $$sink67$us$i2950 = 0.0, $$sink7$i = 0.0, $$sink7$us$i$us = 0.0, $$sink7$us$us$i$us = 0.0, $$sink7$us$us$i1191$us = 0.0, $$sink7$us$us$i1261$us = 0.0, $$sink7$us$us$i1371$us = 0.0, $$sink7$us693$i = 0.0, $$sink7$us705$i = 0.0, $$sink7$us706$i = 0.0, $$sink7$us710$i = 0.0, $$sink72$us$us$i$us$us = 0.0, $$sink72$us$us$i1350$us$us = 0.0, $$sink72$us759$i$us2148 = 0.0, $$sink72$us763$i$us2186 = 0.0, $$sink74$i = 0, $100 = 0, $1000 = 0, $1001 = 0, $1002 = 0;
 var $1003 = 0, $1004 = 0, $1005 = 0, $1006 = 0, $1007 = 0, $1008 = 0, $1009 = 0, $101 = 0, $1010 = 0, $1011 = 0, $1012 = 0.0, $1013 = 0.0, $1014 = 0, $1015 = 0, $1016 = 0.0, $1017 = 0.0, $1018 = 0, $1019 = 0.0, $102 = 0, $1020 = 0.0;
 var $1021 = 0, $1022 = 0, $1023 = 0, $1024 = 0, $1025 = 0, $1026 = 0, $1027 = 0, $1028 = 0, $1029 = 0, $103 = 0, $1030 = 0, $1031 = 0, $1032 = 0, $1033 = 0.0, $1034 = 0.0, $1035 = 0, $1036 = 0, $1037 = 0.0, $1038 = 0.0, $1039 = 0;
 var $104 = 0, $1040 = 0.0, $1041 = 0.0, $1042 = 0.0, $1043 = 0.0, $1044 = 0.0, $1045 = 0.0, $1046 = 0.0, $1047 = 0.0, $1048 = 0.0, $1049 = 0.0, $105 = 0, $1050 = 0.0, $1051 = 0.0, $1052 = 0.0, $1053 = 0.0, $1054 = 0, $1055 = 0, $1056 = 0, $1057 = 0.0;
 var $1058 = 0.0, $1059 = 0.0, $106 = 0, $1060 = 0, $1061 = 0, $1062 = 0, $1063 = 0, $1064 = 0, $1065 = 0, $1066 = 0.0, $1067 = 0.0, $1068 = 0.0, $1069 = 0, $107 = 0, $1070 = 0, $1071 = 0, $1072 = 0, $1073 = 0, $1074 = 0, $1075 = 0;
 var $1076 = 0, $1077 = 0, $1078 = 0, $1079 = 0, $108 = 0, $1080 = 0, $1081 = 0, $1082 = 0, $1083 = 0, $1084 = 0, $1085 = 0, $1086 = 0, $1087 = 0, $1088 = 0, $1089 = 0, $109 = 0, $1090 = 0, $1091 = 0, $1092 = 0, $1093 = 0;
 var $1094 = 0, $1095 = 0, $1096 = 0, $1097 = 0, $1098 = 0, $1099 = 0.0, $110 = 0, $1100 = 0.0, $1101 = 0, $1102 = 0, $1103 = 0.0, $1104 = 0.0, $1105 = 0, $1106 = 0.0, $1107 = 0.0, $1108 = 0, $1109 = 0, $111 = 0, $1110 = 0, $1111 = 0;
 var $1112 = 0, $1113 = 0, $1114 = 0, $1115 = 0, $1116 = 0, $1117 = 0, $1118 = 0, $1119 = 0, $112 = 0, $1120 = 0.0, $1121 = 0.0, $1122 = 0, $1123 = 0, $1124 = 0.0, $1125 = 0.0, $1126 = 0, $1127 = 0.0, $1128 = 0.0, $1129 = 0, $113 = 0;
 var $1130 = 0, $1131 = 0, $1132 = 0, $1133 = 0, $1134 = 0, $1135 = 0, $1136 = 0, $1137 = 0, $1138 = 0, $1139 = 0, $114 = 0, $1140 = 0, $1141 = 0.0, $1142 = 0.0, $1143 = 0, $1144 = 0, $1145 = 0.0, $1146 = 0.0, $1147 = 0, $1148 = 0.0;
 var $1149 = 0.0, $115 = 0, $1150 = 0, $1151 = 0, $1152 = 0, $1153 = 0, $1154 = 0, $1155 = 0, $1156 = 0, $1157 = 0, $1158 = 0, $1159 = 0, $116 = 0, $1160 = 0, $1161 = 0, $1162 = 0.0, $1163 = 0.0, $1164 = 0, $1165 = 0, $1166 = 0.0;
 var $1167 = 0.0, $1168 = 0, $1169 = 0.0, $117 = 0, $1170 = 0.0, $1171 = 0.0, $1172 = 0.0, $1173 = 0.0, $1174 = 0.0, $1175 = 0.0, $1176 = 0.0, $1177 = 0.0, $1178 = 0.0, $1179 = 0.0, $118 = 0, $1180 = 0.0, $1181 = 0.0, $1182 = 0.0, $1183 = 0.0, $1184 = 0.0;
 var $1185 = 0.0, $1186 = 0.0, $1187 = 0.0, $1188 = 0.0, $1189 = 0, $119 = 0, $1190 = 0, $1191 = 0, $1192 = 0.0, $1193 = 0.0, $1194 = 0.0, $1195 = 0, $1196 = 0, $1197 = 0, $1198 = 0, $1199 = 0, $12 = 0, $120 = 0, $1200 = 0, $1201 = 0.0;
 var $1202 = 0.0, $1203 = 0.0, $1204 = 0, $1205 = 0, $1206 = 0, $1207 = 0, $1208 = 0, $1209 = 0, $121 = 0, $1210 = 0, $1211 = 0, $1212 = 0, $1213 = 0, $1214 = 0, $1215 = 0.0, $1216 = 0.0, $1217 = 0, $1218 = 0, $1219 = 0, $122 = 0;
 var $1220 = 0.0, $1221 = 0.0, $1222 = 0, $1223 = 0, $1224 = 0, $1225 = 0, $1226 = 0, $1227 = 0, $1228 = 0, $1229 = 0, $123 = 0, $1230 = 0.0, $1231 = 0.0, $1232 = 0, $1233 = 0, $1234 = 0, $1235 = 0.0, $1236 = 0.0, $1237 = 0, $1238 = 0;
 var $1239 = 0, $124 = 0, $1240 = 0, $1241 = 0, $1242 = 0, $1243 = 0, $1244 = 0, $1245 = 0, $1246 = 0, $1247 = 0.0, $1248 = 0.0, $1249 = 0.0, $125 = 0, $1250 = 0.0, $1251 = 0.0, $1252 = 0.0, $1253 = 0.0, $1254 = 0, $1255 = 0.0, $1256 = 0.0;
 var $1257 = 0.0, $1258 = 0, $1259 = 0.0, $126 = 0, $1260 = 0.0, $1261 = 0.0, $1262 = 0, $1263 = 0, $1264 = 0, $1265 = 0, $1266 = 0, $1267 = 0, $1268 = 0, $1269 = 0.0, $127 = 0, $1270 = 0, $1271 = 0, $1272 = 0, $1273 = 0, $1274 = 0.0;
 var $1275 = 0, $1276 = 0, $1277 = 0, $1278 = 0, $1279 = 0, $128 = 0, $1280 = 0, $1281 = 0.0, $1282 = 0.0, $1283 = 0, $1284 = 0.0, $1285 = 0.0, $1286 = 0.0, $1287 = 0, $1288 = 0, $1289 = 0.0, $129 = 0, $1290 = 0.0, $1291 = 0.0, $1292 = 0;
 var $1293 = 0, $1294 = 0, $1295 = 0, $1296 = 0.0, $1297 = 0.0, $1298 = 0.0, $1299 = 0, $13 = 0, $130 = 0, $1300 = 0, $1301 = 0, $1302 = 0, $1303 = 0, $1304 = 0.0, $1305 = 0.0, $1306 = 0, $1307 = 0.0, $1308 = 0.0, $1309 = 0, $131 = 0;
 var $1310 = 0, $1311 = 0, $1312 = 0, $1313 = 0, $1314 = 0, $1315 = 0.0, $1316 = 0, $1317 = 0.0, $1318 = 0.0, $1319 = 0, $132 = 0, $1320 = 0.0, $1321 = 0.0, $1322 = 0, $1323 = 0, $1324 = 0.0, $1325 = 0, $1326 = 0, $1327 = 0, $1328 = 0.0;
 var $1329 = 0.0, $133 = 0, $1330 = 0, $1331 = 0.0, $1332 = 0.0, $1333 = 0, $1334 = 0, $1335 = 0, $1336 = 0, $1337 = 0, $1338 = 0, $1339 = 0.0, $134 = 0, $1340 = 0.0, $1341 = 0, $1342 = 0.0, $1343 = 0.0, $1344 = 0, $1345 = 0, $1346 = 0;
 var $1347 = 0.0, $1348 = 0, $1349 = 0, $135 = 0, $1350 = 0, $1351 = 0.0, $1352 = 0.0, $1353 = 0, $1354 = 0.0, $1355 = 0.0, $1356 = 0.0, $1357 = 0, $1358 = 0.0, $1359 = 0.0, $136 = 0, $1360 = 0, $1361 = 0, $1362 = 0, $1363 = 0, $1364 = 0.0;
 var $1365 = 0.0, $1366 = 0, $1367 = 0.0, $1368 = 0.0, $1369 = 0, $137 = 0, $1370 = 0, $1371 = 0.0, $1372 = 0.0, $1373 = 0, $1374 = 0, $1375 = 0, $1376 = 0.0, $1377 = 0.0, $1378 = 0.0, $1379 = 0, $138 = 0, $1380 = 0, $1381 = 0.0, $1382 = 0.0;
 var $1383 = 0.0, $1384 = 0, $1385 = 0, $1386 = 0.0, $1387 = 0.0, $1388 = 0, $1389 = 0.0, $139 = 0, $1390 = 0.0, $1391 = 0, $1392 = 0, $1393 = 0, $1394 = 0, $1395 = 0, $1396 = 0, $1397 = 0.0, $1398 = 0.0, $1399 = 0.0, $14 = 0, $140 = 0;
 var $1400 = 0, $1401 = 0.0, $1402 = 0, $1403 = 0, $1404 = 0.0, $1405 = 0.0, $1406 = 0, $1407 = 0.0, $1408 = 0.0, $1409 = 0, $141 = 0, $1410 = 0, $1411 = 0.0, $1412 = 0.0, $1413 = 0, $1414 = 0, $1415 = 0, $1416 = 0.0, $1417 = 0.0, $1418 = 0.0;
 var $1419 = 0, $142 = 0, $1420 = 0, $1421 = 0.0, $1422 = 0.0, $1423 = 0.0, $1424 = 0, $1425 = 0, $1426 = 0, $1427 = 0.0, $1428 = 0.0, $1429 = 0, $143 = 0, $1430 = 0.0, $1431 = 0.0, $1432 = 0, $1433 = 0, $1434 = 0, $1435 = 0, $1436 = 0;
 var $1437 = 0, $1438 = 0, $1439 = 0, $144 = 0, $1440 = 0.0, $1441 = 0.0, $1442 = 0.0, $1443 = 0, $1444 = 0, $1445 = 0.0, $1446 = 0, $1447 = 0.0, $1448 = 0.0, $1449 = 0, $145 = 0, $1450 = 0.0, $1451 = 0.0, $1452 = 0, $1453 = 0, $1454 = 0.0;
 var $1455 = 0.0, $1456 = 0, $1457 = 0, $1458 = 0, $1459 = 0.0, $146 = 0, $1460 = 0.0, $1461 = 0.0, $1462 = 0, $1463 = 0, $1464 = 0.0, $1465 = 0.0, $1466 = 0.0, $1467 = 0, $1468 = 0, $1469 = 0, $147 = 0, $1470 = 0, $1471 = 0.0, $1472 = 0.0;
 var $1473 = 0.0, $1474 = 0, $1475 = 0, $1476 = 0, $1477 = 0, $1478 = 0, $1479 = 0.0, $148 = 0, $1480 = 0, $1481 = 0.0, $1482 = 0.0, $1483 = 0, $1484 = 0, $1485 = 0, $1486 = 0, $1487 = 0, $1488 = 0, $1489 = 0, $149 = 0, $1490 = 0;
 var $1491 = 0.0, $1492 = 0.0, $1493 = 0, $1494 = 0, $1495 = 0, $1496 = 0, $1497 = 0, $1498 = 0.0, $1499 = 0, $15 = 0, $150 = 0, $1500 = 0.0, $1501 = 0, $1502 = 0, $1503 = 0.0, $1504 = 0, $1505 = 0.0, $1506 = 0, $1507 = 0, $1508 = 0;
 var $1509 = 0, $151 = 0, $1510 = 0, $1511 = 0, $1512 = 0, $1513 = 0.0, $1514 = 0.0, $1515 = 0.0, $1516 = 0.0, $1517 = 0.0, $1518 = 0.0, $1519 = 0.0, $152 = 0.0, $1520 = 0, $1521 = 0.0, $1522 = 0.0, $1523 = 0.0, $1524 = 0, $1525 = 0.0, $1526 = 0.0;
 var $1527 = 0.0, $1528 = 0, $1529 = 0, $153 = 0.0, $1530 = 0, $1531 = 0, $1532 = 0, $1533 = 0, $1534 = 0, $1535 = 0.0, $1536 = 0, $1537 = 0, $1538 = 0, $1539 = 0, $154 = 0, $1540 = 0.0, $1541 = 0, $1542 = 0, $1543 = 0, $1544 = 0;
 var $1545 = 0, $1546 = 0, $1547 = 0.0, $1548 = 0.0, $1549 = 0, $155 = 0, $1550 = 0.0, $1551 = 0.0, $1552 = 0.0, $1553 = 0, $1554 = 0, $1555 = 0.0, $1556 = 0.0, $1557 = 0.0, $1558 = 0, $1559 = 0, $156 = 0, $1560 = 0, $1561 = 0, $1562 = 0.0;
 var $1563 = 0.0, $1564 = 0.0, $1565 = 0, $1566 = 0, $1567 = 0, $1568 = 0, $1569 = 0, $157 = 0.0, $1570 = 0.0, $1571 = 0.0, $1572 = 0, $1573 = 0.0, $1574 = 0.0, $1575 = 0, $1576 = 0, $1577 = 0, $1578 = 0, $1579 = 0, $158 = 0.0, $1580 = 0;
 var $1581 = 0.0, $1582 = 0, $1583 = 0.0, $1584 = 0.0, $1585 = 0, $1586 = 0.0, $1587 = 0.0, $1588 = 0, $1589 = 0, $159 = 0, $1590 = 0.0, $1591 = 0, $1592 = 0, $1593 = 0, $1594 = 0.0, $1595 = 0.0, $1596 = 0, $1597 = 0.0, $1598 = 0.0, $1599 = 0;
 var $16 = 0, $160 = 0, $1600 = 0, $1601 = 0, $1602 = 0, $1603 = 0, $1604 = 0, $1605 = 0.0, $1606 = 0.0, $1607 = 0, $1608 = 0.0, $1609 = 0.0, $161 = 0, $1610 = 0, $1611 = 0, $1612 = 0, $1613 = 0.0, $1614 = 0, $1615 = 0, $1616 = 0;
 var $1617 = 0.0, $1618 = 0.0, $1619 = 0, $162 = 0, $1620 = 0.0, $1621 = 0.0, $1622 = 0.0, $1623 = 0, $1624 = 0.0, $1625 = 0.0, $1626 = 0, $1627 = 0, $1628 = 0, $1629 = 0, $163 = 0, $1630 = 0.0, $1631 = 0.0, $1632 = 0, $1633 = 0.0, $1634 = 0.0;
 var $1635 = 0, $1636 = 0, $1637 = 0.0, $1638 = 0.0, $1639 = 0, $164 = 0, $1640 = 0, $1641 = 0, $1642 = 0.0, $1643 = 0.0, $1644 = 0.0, $1645 = 0, $1646 = 0, $1647 = 0.0, $1648 = 0.0, $1649 = 0.0, $165 = 0, $1650 = 0, $1651 = 0, $1652 = 0.0;
 var $1653 = 0.0, $1654 = 0, $1655 = 0.0, $1656 = 0.0, $1657 = 0, $1658 = 0, $1659 = 0, $166 = 0, $1660 = 0, $1661 = 0, $1662 = 0, $1663 = 0.0, $1664 = 0.0, $1665 = 0.0, $1666 = 0, $1667 = 0.0, $1668 = 0, $1669 = 0, $167 = 0, $1670 = 0.0;
 var $1671 = 0.0, $1672 = 0, $1673 = 0.0, $1674 = 0.0, $1675 = 0, $1676 = 0, $1677 = 0.0, $1678 = 0.0, $1679 = 0, $168 = 0, $1680 = 0, $1681 = 0, $1682 = 0.0, $1683 = 0.0, $1684 = 0.0, $1685 = 0, $1686 = 0, $1687 = 0.0, $1688 = 0.0, $1689 = 0.0;
 var $169 = 0, $1690 = 0, $1691 = 0, $1692 = 0, $1693 = 0.0, $1694 = 0.0, $1695 = 0, $1696 = 0.0, $1697 = 0.0, $1698 = 0, $1699 = 0, $17 = 0, $170 = 0, $1700 = 0, $1701 = 0, $1702 = 0, $1703 = 0, $1704 = 0, $1705 = 0, $1706 = 0.0;
 var $1707 = 0.0, $1708 = 0.0, $1709 = 0, $171 = 0, $1710 = 0, $1711 = 0.0, $1712 = 0, $1713 = 0.0, $1714 = 0.0, $1715 = 0, $1716 = 0.0, $1717 = 0.0, $1718 = 0, $1719 = 0, $172 = 0, $1720 = 0.0, $1721 = 0.0, $1722 = 0, $1723 = 0, $1724 = 0;
 var $1725 = 0.0, $1726 = 0.0, $1727 = 0.0, $1728 = 0, $1729 = 0, $173 = 0.0, $1730 = 0.0, $1731 = 0.0, $1732 = 0.0, $1733 = 0, $1734 = 0, $1735 = 0, $1736 = 0, $1737 = 0.0, $1738 = 0.0, $1739 = 0.0, $174 = 0.0, $1740 = 0, $1741 = 0, $1742 = 0;
 var $1743 = 0, $1744 = 0, $1745 = 0.0, $1746 = 0, $1747 = 0.0, $1748 = 0.0, $1749 = 0, $175 = 0, $1750 = 0, $1751 = 0, $1752 = 0, $1753 = 0, $1754 = 0, $1755 = 0, $1756 = 0, $1757 = 0.0, $1758 = 0.0, $1759 = 0, $176 = 0, $1760 = 0;
 var $1761 = 0, $1762 = 0, $1763 = 0, $1764 = 0.0, $1765 = 0, $1766 = 0.0, $1767 = 0, $1768 = 0, $1769 = 0.0, $177 = 0.0, $1770 = 0, $1771 = 0.0, $1772 = 0, $1773 = 0, $1774 = 0, $1775 = 0, $1776 = 0, $1777 = 0, $1778 = 0, $1779 = 0.0;
 var $178 = 0.0, $1780 = 0.0, $1781 = 0.0, $1782 = 0.0, $1783 = 0.0, $1784 = 0.0, $1785 = 0.0, $1786 = 0, $1787 = 0.0, $1788 = 0.0, $1789 = 0.0, $179 = 0, $1790 = 0, $1791 = 0.0, $1792 = 0.0, $1793 = 0.0, $1794 = 0, $1795 = 0, $1796 = 0, $1797 = 0;
 var $1798 = 0, $1799 = 0, $18 = 0, $180 = 0.0, $1800 = 0, $1801 = 0, $1802 = 0.0, $1803 = 0, $1804 = 0, $1805 = 0, $1806 = 0, $1807 = 0.0, $1808 = 0, $1809 = 0, $181 = 0.0, $1810 = 0, $1811 = 0, $1812 = 0, $1813 = 0, $1814 = 0.0;
 var $1815 = 0.0, $1816 = 0, $1817 = 0, $1818 = 0, $1819 = 0, $182 = 0, $1820 = 0, $1821 = 0, $1822 = 0, $1823 = 0.0, $1824 = 0.0, $1825 = 0, $1826 = 0, $1827 = 0, $1828 = 0, $1829 = 0, $183 = 0, $1830 = 0, $1831 = 0, $1832 = 0;
 var $1833 = 0.0, $1834 = 0.0, $1835 = 0, $1836 = 0.0, $1837 = 0.0, $1838 = 0, $1839 = 0, $184 = 0, $1840 = 0.0, $1841 = 0.0, $1842 = 0, $1843 = 0, $1844 = 0, $1845 = 0, $1846 = 0.0, $1847 = 0.0, $1848 = 0, $1849 = 0, $185 = 0, $1850 = 0;
 var $1851 = 0, $1852 = 0, $1853 = 0, $1854 = 0, $1855 = 0, $1856 = 0, $1857 = 0, $1858 = 0, $1859 = 0.0, $186 = 0.0, $1860 = 0.0, $1861 = 0, $1862 = 0, $1863 = 0, $1864 = 0, $1865 = 0, $1866 = 0, $1867 = 0.0, $1868 = 0, $1869 = 0.0;
 var $187 = 0.0, $1870 = 0.0, $1871 = 0, $1872 = 0, $1873 = 0, $1874 = 0, $1875 = 0, $1876 = 0, $1877 = 0, $1878 = 0, $1879 = 0, $188 = 0, $1880 = 0, $1881 = 0, $1882 = 0, $1883 = 0.0, $1884 = 0, $1885 = 0.0, $1886 = 0.0, $1887 = 0;
 var $1888 = 0, $1889 = 0, $189 = 0, $1890 = 0, $1891 = 0, $1892 = 0.0, $1893 = 0, $1894 = 0.0, $1895 = 0, $1896 = 0.0, $1897 = 0.0, $1898 = 0, $1899 = 0, $19 = 0, $190 = 0.0, $1900 = 0, $1901 = 0, $1902 = 0, $1903 = 0, $1904 = 0;
 var $1905 = 0, $1906 = 0, $1907 = 0.0, $1908 = 0, $1909 = 0.0, $191 = 0.0, $1910 = 0.0, $1911 = 0, $1912 = 0, $1913 = 0.0, $1914 = 0, $1915 = 0, $1916 = 0.0, $1917 = 0, $1918 = 0.0, $1919 = 0.0, $192 = 0, $1920 = 0, $1921 = 0, $1922 = 0;
 var $1923 = 0, $1924 = 0, $1925 = 0.0, $1926 = 0, $1927 = 0.0, $1928 = 0.0, $1929 = 0, $193 = 0.0, $1930 = 0, $1931 = 0, $1932 = 0, $1933 = 0, $1934 = 0, $1935 = 0, $1936 = 0, $1937 = 0, $1938 = 0, $1939 = 0, $194 = 0.0, $1940 = 0;
 var $1941 = 0.0, $1942 = 0, $1943 = 0.0, $1944 = 0.0, $1945 = 0, $1946 = 0, $1947 = 0, $1948 = 0, $1949 = 0, $195 = 0.0, $1950 = 0, $1951 = 0, $1952 = 0, $1953 = 0, $1954 = 0.0, $1955 = 0, $1956 = 0.0, $1957 = 0.0, $1958 = 0, $1959 = 0;
 var $196 = 0.0, $1960 = 0, $1961 = 0, $1962 = 0, $1963 = 0.0, $1964 = 0, $1965 = 0.0, $1966 = 0, $1967 = 0.0, $1968 = 0.0, $1969 = 0, $197 = 0.0, $1970 = 0, $1971 = 0, $1972 = 0, $1973 = 0, $1974 = 0.0, $1975 = 0, $1976 = 0.0, $1977 = 0.0;
 var $1978 = 0.0, $1979 = 0, $198 = 0.0, $1980 = 0.0, $1981 = 0.0, $1982 = 0, $1983 = 0, $1984 = 0, $1985 = 0, $1986 = 0, $1987 = 0, $1988 = 0, $1989 = 0, $199 = 0.0, $1990 = 0, $1991 = 0, $1992 = 0.0, $1993 = 0, $1994 = 0.0, $1995 = 0.0;
 var $1996 = 0, $1997 = 0, $1998 = 0, $1999 = 0, $20 = 0, $200 = 0.0, $2000 = 0, $2001 = 0, $2002 = 0, $2003 = 0, $2004 = 0, $2005 = 0, $2006 = 0, $2007 = 0.0, $2008 = 0, $2009 = 0, $201 = 0.0, $2010 = 0, $2011 = 0, $2012 = 0;
 var $2013 = 0, $2014 = 0, $2015 = 0.0, $2016 = 0.0, $2017 = 0.0, $2018 = 0, $2019 = 0.0, $202 = 0.0, $2020 = 0.0, $2021 = 0, $2022 = 0, $2023 = 0, $2024 = 0.0, $2025 = 0.0, $2026 = 0, $2027 = 0, $2028 = 0, $2029 = 0, $203 = 0.0, $2030 = 0;
 var $2031 = 0, $2032 = 0, $2033 = 0, $2034 = 0, $2035 = 0.0, $2036 = 0.0, $2037 = 0, $2038 = 0, $2039 = 0, $204 = 0.0, $2040 = 0, $2041 = 0, $2042 = 0, $2043 = 0, $2044 = 0, $2045 = 0.0, $2046 = 0.0, $2047 = 0, $2048 = 0.0, $2049 = 0.0;
 var $205 = 0.0, $2050 = 0, $2051 = 0, $2052 = 0.0, $2053 = 0.0, $2054 = 0, $2055 = 0, $2056 = 0, $2057 = 0, $2058 = 0.0, $2059 = 0.0, $206 = 0.0, $2060 = 0, $2061 = 0, $2062 = 0, $2063 = 0.0, $2064 = 0, $2065 = 0.0, $2066 = 0.0, $2067 = 0;
 var $2068 = 0, $2069 = 0, $207 = 0, $2070 = 0, $2071 = 0, $2072 = 0, $2073 = 0, $2074 = 0, $2075 = 0, $2076 = 0, $2077 = 0, $2078 = 0, $2079 = 0.0, $208 = 0, $2080 = 0.0, $2081 = 0, $2082 = 0, $2083 = 0, $2084 = 0, $2085 = 0;
 var $2086 = 0, $2087 = 0, $2088 = 0, $2089 = 0, $209 = 0, $2090 = 0.0, $2091 = 0, $2092 = 0.0, $2093 = 0.0, $2094 = 0, $2095 = 0, $2096 = 0.0, $2097 = 0, $2098 = 0, $2099 = 0.0, $21 = 0, $210 = 0, $2100 = 0, $2101 = 0.0, $2102 = 0.0;
 var $2103 = 0, $2104 = 0, $2105 = 0, $2106 = 0, $2107 = 0, $2108 = 0, $2109 = 0, $211 = 0.0, $2110 = 0, $2111 = 0, $2112 = 0.0, $2113 = 0, $2114 = 0.0, $2115 = 0.0, $2116 = 0, $2117 = 0, $2118 = 0.0, $2119 = 0.0, $212 = 0.0, $2120 = 0;
 var $2121 = 0, $2122 = 0, $2123 = 0, $2124 = 0, $2125 = 0, $2126 = 0, $2127 = 0, $2128 = 0, $2129 = 0.0, $213 = 0.0, $2130 = 0.0, $2131 = 0, $2132 = 0, $2133 = 0, $2134 = 0, $2135 = 0, $2136 = 0, $2137 = 0, $2138 = 0, $2139 = 0.0;
 var $214 = 0, $2140 = 0.0, $2141 = 0, $2142 = 0.0, $2143 = 0.0, $2144 = 0, $2145 = 0, $2146 = 0.0, $2147 = 0.0, $2148 = 0, $2149 = 0, $215 = 0, $2150 = 0, $2151 = 0, $2152 = 0.0, $2153 = 0.0, $2154 = 0, $2155 = 0, $2156 = 0, $2157 = 0;
 var $2158 = 0, $2159 = 0.0, $216 = 0, $2160 = 0, $2161 = 0.0, $2162 = 0.0, $2163 = 0, $2164 = 0, $2165 = 0, $2166 = 0, $2167 = 0, $2168 = 0, $2169 = 0, $217 = 0, $2170 = 0, $2171 = 0, $2172 = 0, $2173 = 0, $2174 = 0, $2175 = 0;
 var $2176 = 0, $2177 = 0.0, $2178 = 0.0, $2179 = 0, $218 = 0, $2180 = 0, $2181 = 0, $2182 = 0, $2183 = 0, $2184 = 0, $2185 = 0, $2186 = 0, $2187 = 0, $2188 = 0, $2189 = 0.0, $219 = 0.0, $2190 = 0, $2191 = 0.0, $2192 = 0.0, $2193 = 0;
 var $2194 = 0, $2195 = 0.0, $2196 = 0, $2197 = 0.0, $2198 = 0, $2199 = 0.0, $22 = 0, $220 = 0.0, $2200 = 0.0, $2201 = 0, $2202 = 0, $2203 = 0, $2204 = 0, $2205 = 0, $2206 = 0, $2207 = 0, $2208 = 0, $2209 = 0, $221 = 0.0, $2210 = 0.0;
 var $2211 = 0, $2212 = 0.0, $2213 = 0.0, $2214 = 0, $2215 = 0, $2216 = 0.0, $2217 = 0.0, $2218 = 0, $2219 = 0, $222 = 0, $2220 = 0, $2221 = 0, $2222 = 0, $2223 = 0, $2224 = 0, $2225 = 0, $2226 = 0, $2227 = 0.0, $2228 = 0.0, $2229 = 0;
 var $223 = 0, $2230 = 0, $2231 = 0, $2232 = 0, $2233 = 0, $2234 = 0, $2235 = 0, $2236 = 0, $2237 = 0.0, $2238 = 0.0, $2239 = 0, $224 = 0, $2240 = 0.0, $2241 = 0.0, $2242 = 0, $2243 = 0, $2244 = 0.0, $2245 = 0.0, $2246 = 0, $2247 = 0;
 var $2248 = 0, $2249 = 0, $225 = 0, $2250 = 0.0, $2251 = 0.0, $2252 = 0, $2253 = 0, $2254 = 0, $2255 = 0, $2256 = 0, $2257 = 0, $2258 = 0, $2259 = 0, $226 = 0, $2260 = 0, $2261 = 0, $2262 = 0, $2263 = 0.0, $2264 = 0.0, $2265 = 0;
 var $2266 = 0, $2267 = 0, $2268 = 0, $2269 = 0, $227 = 0, $2270 = 0, $2271 = 0.0, $2272 = 0, $2273 = 0.0, $2274 = 0.0, $2275 = 0, $2276 = 0, $2277 = 0, $2278 = 0, $2279 = 0, $228 = 0, $2280 = 0, $2281 = 0, $2282 = 0, $2283 = 0;
 var $2284 = 0, $2285 = 0.0, $2286 = 0, $2287 = 0.0, $2288 = 0.0, $2289 = 0, $229 = 0, $2290 = 0, $2291 = 0, $2292 = 0, $2293 = 0, $2294 = 0, $2295 = 0, $2296 = 0, $2297 = 0.0, $2298 = 0.0, $2299 = 0, $23 = 0, $230 = 0, $2300 = 0;
 var $2301 = 0, $2302 = 0, $2303 = 0, $2304 = 0.0, $2305 = 0, $2306 = 0.0, $2307 = 0, $2308 = 0, $2309 = 0.0, $231 = 0, $2310 = 0, $2311 = 0.0, $2312 = 0, $2313 = 0, $2314 = 0, $2315 = 0, $2316 = 0, $2317 = 0, $2318 = 0, $2319 = 0.0;
 var $232 = 0, $2320 = 0.0, $2321 = 0.0, $2322 = 0.0, $2323 = 0.0, $2324 = 0.0, $2325 = 0.0, $2326 = 0, $2327 = 0.0, $2328 = 0.0, $2329 = 0.0, $233 = 0, $2330 = 0, $2331 = 0.0, $2332 = 0.0, $2333 = 0.0, $2334 = 0, $2335 = 0, $2336 = 0, $2337 = 0;
 var $2338 = 0, $2339 = 0, $234 = 0, $2340 = 0, $2341 = 0, $2342 = 0.0, $2343 = 0, $2344 = 0, $2345 = 0, $2346 = 0, $2347 = 0.0, $2348 = 0, $2349 = 0, $235 = 0.0, $2350 = 0, $2351 = 0, $2352 = 0, $2353 = 0, $2354 = 0.0, $2355 = 0.0;
 var $2356 = 0, $2357 = 0, $2358 = 0, $2359 = 0, $236 = 0.0, $2360 = 0, $2361 = 0, $2362 = 0, $2363 = 0, $2364 = 0.0, $2365 = 0.0, $2366 = 0, $2367 = 0, $2368 = 0, $2369 = 0, $237 = 0, $2370 = 0, $2371 = 0, $2372 = 0, $2373 = 0;
 var $2374 = 0, $2375 = 0.0, $2376 = 0.0, $2377 = 0, $2378 = 0.0, $2379 = 0.0, $238 = 0, $2380 = 0, $2381 = 0, $2382 = 0.0, $2383 = 0.0, $2384 = 0, $2385 = 0, $2386 = 0, $2387 = 0, $2388 = 0.0, $2389 = 0.0, $239 = 0.0, $2390 = 0, $2391 = 0;
 var $2392 = 0, $2393 = 0, $2394 = 0, $2395 = 0, $2396 = 0, $2397 = 0, $2398 = 0, $2399 = 0, $24 = 0, $240 = 0.0, $2400 = 0, $2401 = 0, $2402 = 0.0, $2403 = 0.0, $2404 = 0, $2405 = 0, $2406 = 0, $2407 = 0, $2408 = 0, $2409 = 0;
 var $241 = 0, $2410 = 0.0, $2411 = 0, $2412 = 0.0, $2413 = 0.0, $2414 = 0, $2415 = 0, $2416 = 0, $2417 = 0, $2418 = 0, $2419 = 0, $242 = 0.0, $2420 = 0, $2421 = 0, $2422 = 0, $2423 = 0, $2424 = 0, $2425 = 0, $2426 = 0, $2427 = 0.0;
 var $2428 = 0, $2429 = 0.0, $243 = 0.0, $2430 = 0.0, $2431 = 0, $2432 = 0, $2433 = 0, $2434 = 0, $2435 = 0, $2436 = 0.0, $2437 = 0, $2438 = 0.0, $2439 = 0, $244 = 0, $2440 = 0.0, $2441 = 0.0, $2442 = 0, $2443 = 0, $2444 = 0, $2445 = 0;
 var $2446 = 0, $2447 = 0, $2448 = 0, $2449 = 0, $245 = 0, $2450 = 0, $2451 = 0, $2452 = 0.0, $2453 = 0, $2454 = 0.0, $2455 = 0.0, $2456 = 0, $2457 = 0, $2458 = 0.0, $2459 = 0, $246 = 0, $2460 = 0, $2461 = 0.0, $2462 = 0, $2463 = 0.0;
 var $2464 = 0.0, $2465 = 0, $2466 = 0, $2467 = 0, $2468 = 0, $2469 = 0, $247 = 0, $2470 = 0.0, $2471 = 0, $2472 = 0.0, $2473 = 0.0, $2474 = 0, $2475 = 0, $2476 = 0, $2477 = 0, $2478 = 0, $2479 = 0, $248 = 0.0, $2480 = 0, $2481 = 0;
 var $2482 = 0, $2483 = 0, $2484 = 0, $2485 = 0, $2486 = 0, $2487 = 0.0, $2488 = 0, $2489 = 0.0, $249 = 0.0, $2490 = 0.0, $2491 = 0, $2492 = 0, $2493 = 0, $2494 = 0, $2495 = 0, $2496 = 0, $2497 = 0, $2498 = 0, $2499 = 0, $25 = 0;
 var $250 = 0, $2500 = 0, $2501 = 0, $2502 = 0, $2503 = 0, $2504 = 0.0, $2505 = 0, $2506 = 0.0, $2507 = 0.0, $2508 = 0, $2509 = 0, $251 = 0, $2510 = 0.0, $2511 = 0, $2512 = 0.0, $2513 = 0, $2514 = 0.0, $2515 = 0.0, $2516 = 0, $2517 = 0;
 var $2518 = 0, $2519 = 0, $252 = 0.0, $2520 = 0, $2521 = 0.0, $2522 = 0.0, $2523 = 0, $2524 = 0.0, $2525 = 0.0, $2526 = 0.0, $2527 = 0, $2528 = 0.0, $2529 = 0.0, $253 = 0.0, $2530 = 0, $2531 = 0, $2532 = 0, $2533 = 0, $2534 = 0, $2535 = 0;
 var $2536 = 0, $2537 = 0, $2538 = 0, $2539 = 0, $254 = 0, $2540 = 0, $2541 = 0.0, $2542 = 0, $2543 = 0.0, $2544 = 0.0, $2545 = 0, $2546 = 0, $2547 = 0, $2548 = 0, $2549 = 0, $255 = 0.0, $2550 = 0, $2551 = 0, $2552 = 0, $2553 = 0;
 var $2554 = 0, $2555 = 0, $2556 = 0, $2557 = 0.0, $2558 = 0.0, $2559 = 0, $256 = 0.0, $2560 = 0.0, $2561 = 0.0, $2562 = 0, $2563 = 0, $2564 = 0, $2565 = 0, $2566 = 0, $2567 = 0, $2568 = 0, $2569 = 0, $257 = 0.0, $2570 = 0.0, $2571 = 0.0;
 var $2572 = 0.0, $2573 = 0, $2574 = 0, $2575 = 0, $2576 = 0.0, $2577 = 0.0, $2578 = 0, $2579 = 0, $258 = 0.0, $2580 = 0, $2581 = 0, $2582 = 0, $2583 = 0, $2584 = 0, $2585 = 0, $2586 = 0, $2587 = 0, $2588 = 0.0, $2589 = 0.0, $259 = 0.0;
 var $2590 = 0, $2591 = 0, $2592 = 0, $2593 = 0, $2594 = 0, $2595 = 0, $2596 = 0, $2597 = 0, $2598 = 0, $2599 = 0.0, $26 = 0, $260 = 0.0, $2600 = 0.0, $2601 = 0, $2602 = 0.0, $2603 = 0.0, $2604 = 0, $2605 = 0, $2606 = 0.0, $2607 = 0.0;
 var $2608 = 0, $2609 = 0, $261 = 0.0, $2610 = 0, $2611 = 0, $2612 = 0.0, $2613 = 0.0, $2614 = 0, $2615 = 0, $2616 = 0, $2617 = 0.0, $2618 = 0, $2619 = 0.0, $262 = 0.0, $2620 = 0.0, $2621 = 0, $2622 = 0, $2623 = 0, $2624 = 0, $2625 = 0;
 var $2626 = 0, $2627 = 0, $2628 = 0, $2629 = 0, $263 = 0.0, $2630 = 0, $2631 = 0, $2632 = 0.0, $2633 = 0, $2634 = 0.0, $2635 = 0.0, $2636 = 0, $2637 = 0, $2638 = 0, $2639 = 0, $264 = 0.0, $2640 = 0, $2641 = 0, $2642 = 0, $2643 = 0;
 var $2644 = 0, $2645 = 0, $2646 = 0, $2647 = 0, $2648 = 0, $2649 = 0.0, $265 = 0.0, $2650 = 0.0, $2651 = 0, $2652 = 0.0, $2653 = 0, $2654 = 0, $2655 = 0.0, $2656 = 0, $2657 = 0.0, $2658 = 0.0, $2659 = 0, $266 = 0.0, $2660 = 0, $2661 = 0;
 var $2662 = 0, $2663 = 0, $2664 = 0, $2665 = 0, $2666 = 0, $2667 = 0, $2668 = 0, $2669 = 0.0, $267 = 0.0, $2670 = 0, $2671 = 0.0, $2672 = 0.0, $2673 = 0, $2674 = 0, $2675 = 0.0, $2676 = 0.0, $2677 = 0, $2678 = 0, $2679 = 0, $268 = 0.0;
 var $2680 = 0, $2681 = 0, $2682 = 0, $2683 = 0, $2684 = 0, $2685 = 0, $2686 = 0, $2687 = 0.0, $2688 = 0.0, $2689 = 0, $269 = 0, $2690 = 0, $2691 = 0, $2692 = 0, $2693 = 0, $2694 = 0, $2695 = 0, $2696 = 0, $2697 = 0, $2698 = 0.0;
 var $2699 = 0.0, $27 = 0, $270 = 0, $2700 = 0, $2701 = 0.0, $2702 = 0.0, $2703 = 0, $2704 = 0, $2705 = 0.0, $2706 = 0.0, $2707 = 0, $2708 = 0, $2709 = 0, $271 = 0, $2710 = 0, $2711 = 0.0, $2712 = 0.0, $2713 = 0, $2714 = 0, $2715 = 0;
 var $2716 = 0, $2717 = 0, $2718 = 0.0, $2719 = 0, $272 = 0, $2720 = 0.0, $2721 = 0.0, $2722 = 0, $2723 = 0, $2724 = 0, $2725 = 0, $2726 = 0, $2727 = 0, $2728 = 0, $2729 = 0, $273 = 0.0, $2730 = 0, $2731 = 0, $2732 = 0, $2733 = 0;
 var $2734 = 0.0, $2735 = 0, $2736 = 0.0, $2737 = 0.0, $2738 = 0, $2739 = 0, $274 = 0.0, $2740 = 0, $2741 = 0, $2742 = 0, $2743 = 0, $2744 = 0, $2745 = 0, $2746 = 0, $2747 = 0, $2748 = 0, $2749 = 0, $275 = 0.0, $2750 = 0, $2751 = 0;
 var $2752 = 0, $2753 = 0.0, $2754 = 0.0, $2755 = 0, $2756 = 0.0, $2757 = 0, $2758 = 0.0, $2759 = 0, $276 = 0, $2760 = 0.0, $2761 = 0.0, $2762 = 0, $2763 = 0, $2764 = 0, $2765 = 0, $2766 = 0, $2767 = 0, $2768 = 0, $2769 = 0, $277 = 0;
 var $2770 = 0, $2771 = 0, $2772 = 0.0, $2773 = 0, $2774 = 0.0, $2775 = 0.0, $2776 = 0, $2777 = 0, $2778 = 0.0, $2779 = 0.0, $278 = 0, $2780 = 0, $2781 = 0, $2782 = 0, $2783 = 0, $2784 = 0, $2785 = 0, $2786 = 0, $2787 = 0, $2788 = 0;
 var $2789 = 0, $279 = 0, $2790 = 0.0, $2791 = 0.0, $2792 = 0, $2793 = 0, $2794 = 0, $2795 = 0, $2796 = 0, $2797 = 0, $2798 = 0, $2799 = 0, $28 = 0, $280 = 0, $2800 = 0, $2801 = 0.0, $2802 = 0.0, $2803 = 0, $2804 = 0.0, $2805 = 0.0;
 var $2806 = 0, $2807 = 0, $2808 = 0.0, $2809 = 0.0, $281 = 0.0, $2810 = 0, $2811 = 0, $2812 = 0, $2813 = 0, $2814 = 0.0, $2815 = 0.0, $2816 = 0, $2817 = 0, $2818 = 0, $2819 = 0, $282 = 0.0, $2820 = 0, $2821 = 0, $2822 = 0, $2823 = 0;
 var $2824 = 0, $2825 = 0, $2826 = 0, $2827 = 0, $2828 = 0.0, $2829 = 0.0, $283 = 0.0, $2830 = 0, $2831 = 0, $2832 = 0, $2833 = 0, $2834 = 0, $2835 = 0, $2836 = 0, $2837 = 0, $2838 = 0, $2839 = 0, $284 = 0, $2840 = 0, $2841 = 0;
 var $2842 = 0.0, $2843 = 0, $2844 = 0.0, $2845 = 0.0, $2846 = 0, $2847 = 0, $2848 = 0, $2849 = 0, $285 = 0, $2850 = 0, $2851 = 0, $2852 = 0, $2853 = 0.0, $2854 = 0, $2855 = 0.0, $2856 = 0.0, $2857 = 0, $2858 = 0, $2859 = 0, $286 = 0;
 var $2860 = 0, $2861 = 0, $2862 = 0.0, $2863 = 0.0, $2864 = 0, $2865 = 0, $2866 = 0, $2867 = 0, $2868 = 0, $2869 = 0.0, $287 = 0, $2870 = 0, $2871 = 0.0, $2872 = 0, $2873 = 0, $2874 = 0.0, $2875 = 0, $2876 = 0.0, $2877 = 0, $2878 = 0;
 var $2879 = 0, $288 = 0, $2880 = 0, $2881 = 0, $2882 = 0, $2883 = 0, $2884 = 0.0, $2885 = 0.0, $2886 = 0.0, $2887 = 0.0, $2888 = 0.0, $2889 = 0.0, $289 = 0, $2890 = 0.0, $2891 = 0, $2892 = 0.0, $2893 = 0.0, $2894 = 0.0, $2895 = 0, $2896 = 0.0;
 var $2897 = 0.0, $2898 = 0.0, $2899 = 0, $29 = 0, $290 = 0, $2900 = 0, $2901 = 0, $2902 = 0, $2903 = 0, $2904 = 0, $2905 = 0, $2906 = 0, $2907 = 0.0, $2908 = 0, $2909 = 0, $291 = 0, $2910 = 0, $2911 = 0, $2912 = 0.0, $2913 = 0;
 var $2914 = 0, $2915 = 0, $2916 = 0, $2917 = 0, $2918 = 0, $2919 = 0.0, $292 = 0, $2920 = 0.0, $2921 = 0, $2922 = 0.0, $2923 = 0, $2924 = 0, $2925 = 0.0, $2926 = 0, $2927 = 0, $2928 = 0, $2929 = 0, $293 = 0, $2930 = 0.0, $2931 = 0;
 var $2932 = 0, $2933 = 0, $2934 = 0, $2935 = 0, $2936 = 0, $2937 = 0, $2938 = 0, $2939 = 0, $294 = 0, $2940 = 0, $2941 = 0, $2942 = 0, $2943 = 0, $2944 = 0, $2945 = 0, $2946 = 0, $2947 = 0, $2948 = 0, $2949 = 0, $295 = 0;
 var $2950 = 0.0, $2951 = 0.0, $2952 = 0, $2953 = 0, $2954 = 0, $2955 = 0, $2956 = 0, $2957 = 0, $2958 = 0, $2959 = 0, $296 = 0, $2960 = 0.0, $2961 = 0.0, $2962 = 0, $2963 = 0, $2964 = 0, $2965 = 0, $2966 = 0, $2967 = 0, $2968 = 0;
 var $2969 = 0, $297 = 0, $2970 = 0, $2971 = 0, $2972 = 0, $2973 = 0, $2974 = 0, $2975 = 0, $2976 = 0, $2977 = 0, $2978 = 0, $2979 = 0, $298 = 0, $2980 = 0, $2981 = 0, $2982 = 0, $2983 = 0, $2984 = 0, $2985 = 0.0, $2986 = 0.0;
 var $2987 = 0, $2988 = 0, $2989 = 0, $299 = 0, $2990 = 0, $2991 = 0, $2992 = 0.0, $2993 = 0, $2994 = 0, $2995 = 0.0, $2996 = 0.0, $2997 = 0, $2998 = 0, $2999 = 0, $30 = 0, $300 = 0, $3000 = 0, $3001 = 0, $3002 = 0, $3003 = 0;
 var $3004 = 0, $3005 = 0, $3006 = 0, $3007 = 0, $3008 = 0, $3009 = 0, $301 = 0, $3010 = 0, $3011 = 0, $3012 = 0, $3013 = 0, $3014 = 0, $3015 = 0, $3016 = 0, $3017 = 0.0, $3018 = 0.0, $3019 = 0, $302 = 0, $3020 = 0, $3021 = 0.0;
 var $3022 = 0, $3023 = 0, $3024 = 0, $3025 = 0.0, $3026 = 0.0, $3027 = 0, $3028 = 0, $3029 = 0, $303 = 0, $3030 = 0, $3031 = 0, $3032 = 0, $3033 = 0.0, $3034 = 0.0, $3035 = 0, $3036 = 0, $3037 = 0, $3038 = 0, $3039 = 0, $304 = 0;
 var $3040 = 0, $3041 = 0, $3042 = 0, $3043 = 0, $3044 = 0, $3045 = 0, $3046 = 0, $3047 = 0, $3048 = 0, $3049 = 0, $305 = 0.0, $3050 = 0, $3051 = 0, $3052 = 0, $3053 = 0, $3054 = 0, $3055 = 0, $3056 = 0, $3057 = 0, $3058 = 0.0;
 var $3059 = 0.0, $306 = 0.0, $3060 = 0, $3061 = 0, $3062 = 0, $3063 = 0, $3064 = 0, $3065 = 0, $3066 = 0, $3067 = 0, $3068 = 0, $3069 = 0, $307 = 0, $3070 = 0, $3071 = 0, $3072 = 0, $3073 = 0, $3074 = 0, $3075 = 0, $3076 = 0;
 var $3077 = 0, $3078 = 0, $3079 = 0, $308 = 0, $3080 = 0, $3081 = 0, $3082 = 0, $3083 = 0.0, $3084 = 0.0, $3085 = 0, $3086 = 0, $3087 = 0.0, $3088 = 0, $3089 = 0, $309 = 0.0, $3090 = 0.0, $3091 = 0.0, $3092 = 0, $3093 = 0, $3094 = 0;
 var $3095 = 0, $3096 = 0, $3097 = 0, $3098 = 0.0, $3099 = 0.0, $31 = 0, $310 = 0.0, $3100 = 0.0, $3101 = 0, $3102 = 0.0, $3103 = 0.0, $3104 = 0, $3105 = 0, $3106 = 0, $3107 = 0, $3108 = 0, $3109 = 0, $311 = 0, $3110 = 0, $3111 = 0;
 var $3112 = 0, $3113 = 0, $3114 = 0, $3115 = 0, $3116 = 0, $3117 = 0, $3118 = 0, $3119 = 0, $312 = 0.0, $3120 = 0, $3121 = 0, $3122 = 0, $3123 = 0, $3124 = 0, $3125 = 0.0, $3126 = 0.0, $3127 = 0, $3128 = 0, $3129 = 0, $313 = 0.0;
 var $3130 = 0, $3131 = 0, $3132 = 0, $3133 = 0, $3134 = 0, $3135 = 0, $3136 = 0, $3137 = 0, $3138 = 0, $3139 = 0, $314 = 0, $3140 = 0, $3141 = 0, $3142 = 0, $3143 = 0, $3144 = 0, $3145 = 0, $3146 = 0, $3147 = 0, $3148 = 0;
 var $3149 = 0, $315 = 0, $3150 = 0, $3151 = 0, $3152 = 0, $3153 = 0, $3154 = 0, $3155 = 0, $3156 = 0, $3157 = 0, $3158 = 0, $3159 = 0, $316 = 0, $3160 = 0, $3161 = 0, $3162 = 0, $3163 = 0, $3164 = 0, $3165 = 0.0, $3166 = 0.0;
 var $3167 = 0.0, $3168 = 0, $3169 = 0.0, $317 = 0, $3170 = 0.0, $3171 = 0, $3172 = 0, $3173 = 0, $3174 = 0.0, $3175 = 0.0, $3176 = 0, $3177 = 0, $3178 = 0, $3179 = 0.0, $318 = 0.0, $3180 = 0, $3181 = 0, $3182 = 0.0, $3183 = 0, $3184 = 0;
 var $3185 = 0, $3186 = 0, $3187 = 0.0, $3188 = 0, $3189 = 0, $319 = 0.0, $3190 = 0, $3191 = 0, $3192 = 0.0, $3193 = 0.0, $3194 = 0, $3195 = 0, $3196 = 0, $3197 = 0, $3198 = 0, $3199 = 0, $32 = 0, $320 = 0, $3200 = 0, $3201 = 0;
 var $3202 = 0, $3203 = 0, $3204 = 0, $3205 = 0, $3206 = 0, $3207 = 0, $3208 = 0, $3209 = 0, $321 = 0, $3210 = 0, $3211 = 0, $3212 = 0, $3213 = 0, $3214 = 0, $3215 = 0.0, $3216 = 0.0, $3217 = 0, $3218 = 0, $3219 = 0, $322 = 0.0;
 var $3220 = 0, $3221 = 0, $3222 = 0, $3223 = 0, $3224 = 0, $3225 = 0, $3226 = 0, $3227 = 0, $3228 = 0, $3229 = 0, $323 = 0.0, $3230 = 0, $3231 = 0, $3232 = 0, $3233 = 0, $3234 = 0, $3235 = 0, $3236 = 0, $3237 = 0.0, $3238 = 0.0;
 var $3239 = 0, $324 = 0, $3240 = 0, $3241 = 0.0, $3242 = 0, $3243 = 0, $3244 = 0, $3245 = 0.0, $3246 = 0.0, $3247 = 0, $3248 = 0, $3249 = 0, $325 = 0.0, $3250 = 0, $3251 = 0, $3252 = 0, $3253 = 0, $3254 = 0, $3255 = 0, $3256 = 0;
 var $3257 = 0, $3258 = 0, $3259 = 0, $326 = 0.0, $3260 = 0, $3261 = 0, $3262 = 0, $3263 = 0, $3264 = 0, $3265 = 0, $3266 = 0, $3267 = 0.0, $3268 = 0.0, $3269 = 0, $327 = 0, $3270 = 0, $3271 = 0.0, $3272 = 0.0, $3273 = 0, $3274 = 0;
 var $3275 = 0, $3276 = 0.0, $3277 = 0, $3278 = 0, $3279 = 0.0, $328 = 0, $3280 = 0, $3281 = 0, $3282 = 0, $3283 = 0, $3284 = 0.0, $3285 = 0, $3286 = 0, $3287 = 0, $3288 = 0, $3289 = 0, $329 = 0, $3290 = 0, $3291 = 0.0, $3292 = 0.0;
 var $3293 = 0, $3294 = 0, $3295 = 0, $3296 = 0, $3297 = 0, $3298 = 0, $3299 = 0, $33 = 0, $330 = 0, $3300 = 0, $3301 = 0, $3302 = 0, $3303 = 0, $3304 = 0, $3305 = 0, $3306 = 0, $3307 = 0, $3308 = 0, $3309 = 0, $331 = 0.0;
 var $3310 = 0, $3311 = 0, $3312 = 0, $3313 = 0, $3314 = 0, $3315 = 0.0, $3316 = 0.0, $3317 = 0, $3318 = 0, $3319 = 0, $332 = 0.0, $3320 = 0, $3321 = 0, $3322 = 0, $3323 = 0, $3324 = 0, $3325 = 0, $3326 = 0, $3327 = 0, $3328 = 0;
 var $3329 = 0, $333 = 0, $3330 = 0, $3331 = 0, $3332 = 0, $3333 = 0, $3334 = 0, $3335 = 0, $3336 = 0, $3337 = 0, $3338 = 0, $3339 = 0.0, $334 = 0, $3340 = 0.0, $3341 = 0, $3342 = 0, $3343 = 0.0, $3344 = 0, $3345 = 0, $3346 = 0.0;
 var $3347 = 0.0, $3348 = 0, $3349 = 0, $335 = 0.0, $3350 = 0, $3351 = 0, $3352 = 0, $3353 = 0, $3354 = 0, $3355 = 0, $3356 = 0, $3357 = 0, $3358 = 0, $3359 = 0, $336 = 0.0, $3360 = 0, $3361 = 0, $3362 = 0, $3363 = 0, $3364 = 0;
 var $3365 = 0, $3366 = 0, $3367 = 0, $3368 = 0.0, $3369 = 0.0, $337 = 0, $3370 = 0, $3371 = 0, $3372 = 0.0, $3373 = 0.0, $3374 = 0, $3375 = 0, $3376 = 0, $3377 = 0.0, $3378 = 0, $3379 = 0, $338 = 0.0, $3380 = 0.0, $3381 = 0, $3382 = 0;
 var $3383 = 0, $3384 = 0, $3385 = 0.0, $3386 = 0, $3387 = 0, $3388 = 0, $3389 = 0, $339 = 0.0, $3390 = 0, $3391 = 0, $3392 = 0, $3393 = 0, $3394 = 0, $3395 = 0, $3396 = 0, $3397 = 0, $3398 = 0, $3399 = 0, $34 = 0, $340 = 0;
 var $3400 = 0, $3401 = 0, $3402 = 0, $3403 = 0, $3404 = 0, $3405 = 0.0, $3406 = 0.0, $3407 = 0, $3408 = 0, $3409 = 0, $341 = 0, $3410 = 0, $3411 = 0, $3412 = 0, $3413 = 0, $3414 = 0, $3415 = 0, $3416 = 0, $3417 = 0, $3418 = 0;
 var $3419 = 0, $342 = 0, $3420 = 0, $3421 = 0, $3422 = 0, $3423 = 0, $3424 = 0, $3425 = 0, $3426 = 0, $3427 = 0, $3428 = 0, $3429 = 0, $343 = 0, $3430 = 0.0, $3431 = 0.0, $3432 = 0, $3433 = 0, $3434 = 0, $3435 = 0, $3436 = 0;
 var $3437 = 0, $3438 = 0, $3439 = 0, $344 = 0.0, $3440 = 0.0, $3441 = 0.0, $3442 = 0, $3443 = 0, $3444 = 0, $3445 = 0, $3446 = 0, $3447 = 0.0, $3448 = 0.0, $3449 = 0, $345 = 0.0, $3450 = 0, $3451 = 0, $3452 = 0, $3453 = 0, $3454 = 0;
 var $3455 = 0.0, $3456 = 0, $3457 = 0.0, $3458 = 0, $3459 = 0, $346 = 0, $3460 = 0.0, $3461 = 0, $3462 = 0.0, $3463 = 0, $3464 = 0, $3465 = 0, $3466 = 0, $3467 = 0, $3468 = 0, $3469 = 0, $347 = 0, $3470 = 0.0, $3471 = 0.0, $3472 = 0.0;
 var $3473 = 0.0, $3474 = 0.0, $3475 = 0.0, $3476 = 0.0, $3477 = 0, $3478 = 0.0, $3479 = 0.0, $348 = 0.0, $3480 = 0.0, $3481 = 0, $3482 = 0.0, $3483 = 0.0, $3484 = 0.0, $3485 = 0, $3486 = 0, $3487 = 0, $3488 = 0, $3489 = 0, $349 = 0.0, $3490 = 0;
 var $3491 = 0, $3492 = 0, $3493 = 0.0, $3494 = 0, $3495 = 0, $3496 = 0, $3497 = 0, $3498 = 0.0, $3499 = 0, $35 = 0, $350 = 0, $3500 = 0, $3501 = 0, $3502 = 0, $3503 = 0, $3504 = 0, $3505 = 0.0, $3506 = 0.0, $3507 = 0, $3508 = 0.0;
 var $3509 = 0, $351 = 0.0, $3510 = 0, $3511 = 0.0, $3512 = 0, $3513 = 0, $3514 = 0, $3515 = 0, $3516 = 0.0, $3517 = 0, $3518 = 0, $3519 = 0, $352 = 0.0, $3520 = 0, $3521 = 0, $3522 = 0, $3523 = 0, $3524 = 0, $3525 = 0, $3526 = 0;
 var $3527 = 0, $3528 = 0, $3529 = 0, $353 = 0.0, $3530 = 0, $3531 = 0, $3532 = 0, $3533 = 0, $3534 = 0, $3535 = 0, $3536 = 0.0, $3537 = 0.0, $3538 = 0, $3539 = 0, $354 = 0.0, $3540 = 0, $3541 = 0, $3542 = 0, $3543 = 0, $3544 = 0;
 var $3545 = 0, $3546 = 0.0, $3547 = 0.0, $3548 = 0, $3549 = 0, $355 = 0.0, $3550 = 0, $3551 = 0, $3552 = 0, $3553 = 0, $3554 = 0, $3555 = 0, $3556 = 0, $3557 = 0, $3558 = 0, $3559 = 0, $356 = 0.0, $3560 = 0, $3561 = 0, $3562 = 0;
 var $3563 = 0, $3564 = 0, $3565 = 0, $3566 = 0, $3567 = 0, $3568 = 0, $3569 = 0, $357 = 0.0, $3570 = 0, $3571 = 0.0, $3572 = 0.0, $3573 = 0, $3574 = 0, $3575 = 0, $3576 = 0, $3577 = 0, $3578 = 0.0, $3579 = 0, $358 = 0.0, $3580 = 0;
 var $3581 = 0.0, $3582 = 0.0, $3583 = 0, $3584 = 0, $3585 = 0, $3586 = 0, $3587 = 0, $3588 = 0, $3589 = 0, $359 = 0.0, $3590 = 0, $3591 = 0, $3592 = 0, $3593 = 0, $3594 = 0, $3595 = 0, $3596 = 0, $3597 = 0, $3598 = 0, $3599 = 0;
 var $36 = 0, $360 = 0.0, $3600 = 0, $3601 = 0, $3602 = 0, $3603 = 0.0, $3604 = 0.0, $3605 = 0, $3606 = 0, $3607 = 0.0, $3608 = 0, $3609 = 0, $361 = 0.0, $3610 = 0, $3611 = 0.0, $3612 = 0.0, $3613 = 0, $3614 = 0, $3615 = 0, $3616 = 0;
 var $3617 = 0, $3618 = 0, $3619 = 0.0, $362 = 0.0, $3620 = 0.0, $3621 = 0, $3622 = 0, $3623 = 0, $3624 = 0, $3625 = 0, $3626 = 0, $3627 = 0, $3628 = 0, $3629 = 0, $363 = 0.0, $3630 = 0, $3631 = 0, $3632 = 0, $3633 = 0, $3634 = 0;
 var $3635 = 0, $3636 = 0, $3637 = 0, $3638 = 0, $3639 = 0, $364 = 0.0, $3640 = 0, $3641 = 0, $3642 = 0, $3643 = 0, $3644 = 0.0, $3645 = 0.0, $3646 = 0, $3647 = 0, $3648 = 0, $3649 = 0, $365 = 0.0, $3650 = 0, $3651 = 0, $3652 = 0;
 var $3653 = 0, $3654 = 0, $3655 = 0, $3656 = 0, $3657 = 0, $3658 = 0, $3659 = 0, $366 = 0.0, $3660 = 0, $3661 = 0, $3662 = 0, $3663 = 0, $3664 = 0, $3665 = 0, $3666 = 0, $3667 = 0, $3668 = 0, $3669 = 0.0, $367 = 0.0, $3670 = 0.0;
 var $3671 = 0, $3672 = 0, $3673 = 0.0, $3674 = 0, $3675 = 0, $3676 = 0.0, $3677 = 0.0, $3678 = 0, $3679 = 0, $368 = 0.0, $3680 = 0, $3681 = 0, $3682 = 0, $3683 = 0.0, $3684 = 0.0, $3685 = 0, $3686 = 0.0, $3687 = 0.0, $3688 = 0.0, $3689 = 0;
 var $369 = 0.0, $3690 = 0.0, $3691 = 0.0, $3692 = 0, $3693 = 0, $3694 = 0, $3695 = 0, $3696 = 0, $3697 = 0, $3698 = 0, $3699 = 0, $37 = 0, $370 = 0.0, $3700 = 0, $3701 = 0, $3702 = 0, $3703 = 0, $3704 = 0, $3705 = 0, $3706 = 0;
 var $3707 = 0, $3708 = 0, $3709 = 0, $371 = 0, $3710 = 0, $3711 = 0, $3712 = 0, $3713 = 0.0, $3714 = 0.0, $3715 = 0, $3716 = 0, $3717 = 0, $3718 = 0, $3719 = 0, $372 = 0, $3720 = 0, $3721 = 0, $3722 = 0, $3723 = 0, $3724 = 0;
 var $3725 = 0, $3726 = 0, $3727 = 0, $3728 = 0, $3729 = 0, $373 = 0, $3730 = 0, $3731 = 0, $3732 = 0, $3733 = 0, $3734 = 0, $3735 = 0, $3736 = 0.0, $3737 = 0.0, $3738 = 0, $3739 = 0.0, $374 = 0, $3740 = 0.0, $3741 = 0, $3742 = 0;
 var $3743 = 0, $3744 = 0, $3745 = 0, $3746 = 0, $3747 = 0, $3748 = 0, $3749 = 0, $375 = 0.0, $3750 = 0, $3751 = 0, $3752 = 0, $3753 = 0, $3754 = 0, $3755 = 0, $3756 = 0, $3757 = 0, $3758 = 0.0, $3759 = 0.0, $376 = 0.0, $3760 = 0.0;
 var $3761 = 0, $3762 = 0, $3763 = 0, $3764 = 0.0, $3765 = 0.0, $3766 = 0, $3767 = 0, $3768 = 0, $3769 = 0.0, $377 = 0.0, $3770 = 0, $3771 = 0, $3772 = 0.0, $3773 = 0, $3774 = 0, $3775 = 0, $3776 = 0, $3777 = 0.0, $3778 = 0, $3779 = 0;
 var $378 = 0, $3780 = 0, $3781 = 0, $3782 = 0.0, $3783 = 0.0, $3784 = 0, $3785 = 0, $3786 = 0, $3787 = 0, $3788 = 0, $3789 = 0, $379 = 0, $3790 = 0, $3791 = 0, $3792 = 0, $3793 = 0, $3794 = 0, $3795 = 0, $3796 = 0, $3797 = 0;
 var $3798 = 0, $3799 = 0, $38 = 0, $380 = 0, $3800 = 0, $3801 = 0, $3802 = 0, $3803 = 0, $3804 = 0, $3805 = 0.0, $3806 = 0.0, $3807 = 0, $3808 = 0, $3809 = 0, $381 = 0, $3810 = 0, $3811 = 0, $3812 = 0, $3813 = 0, $3814 = 0;
 var $3815 = 0, $3816 = 0, $3817 = 0, $3818 = 0, $3819 = 0, $382 = 0, $3820 = 0, $3821 = 0, $3822 = 0, $3823 = 0, $3824 = 0, $3825 = 0, $3826 = 0, $3827 = 0.0, $3828 = 0.0, $3829 = 0, $383 = 0.0, $3830 = 0, $3831 = 0.0, $3832 = 0;
 var $3833 = 0, $3834 = 0, $3835 = 0.0, $3836 = 0.0, $3837 = 0, $3838 = 0, $3839 = 0, $384 = 0.0, $3840 = 0, $3841 = 0, $3842 = 0, $3843 = 0, $3844 = 0, $3845 = 0, $3846 = 0, $3847 = 0, $3848 = 0, $3849 = 0, $385 = 0.0, $3850 = 0;
 var $3851 = 0, $3852 = 0, $3853 = 0, $3854 = 0, $3855 = 0, $3856 = 0, $3857 = 0.0, $3858 = 0.0, $3859 = 0, $386 = 0, $3860 = 0, $3861 = 0.0, $3862 = 0.0, $3863 = 0, $3864 = 0, $3865 = 0, $3866 = 0.0, $3867 = 0, $3868 = 0, $3869 = 0.0;
 var $387 = 0, $3870 = 0, $3871 = 0, $3872 = 0, $3873 = 0, $3874 = 0.0, $3875 = 0, $3876 = 0, $3877 = 0, $3878 = 0, $3879 = 0, $388 = 0, $3880 = 0, $3881 = 0.0, $3882 = 0.0, $3883 = 0, $3884 = 0, $3885 = 0, $3886 = 0, $3887 = 0;
 var $3888 = 0, $3889 = 0, $389 = 0, $3890 = 0, $3891 = 0, $3892 = 0, $3893 = 0, $3894 = 0, $3895 = 0, $3896 = 0, $3897 = 0, $3898 = 0, $3899 = 0, $39 = 0, $390 = 0, $3900 = 0, $3901 = 0, $3902 = 0, $3903 = 0, $3904 = 0;
 var $3905 = 0.0, $3906 = 0.0, $3907 = 0, $3908 = 0, $3909 = 0, $391 = 0, $3910 = 0, $3911 = 0, $3912 = 0, $3913 = 0, $3914 = 0, $3915 = 0, $3916 = 0, $3917 = 0, $3918 = 0, $3919 = 0, $392 = 0, $3920 = 0, $3921 = 0, $3922 = 0;
 var $3923 = 0, $3924 = 0, $3925 = 0, $3926 = 0, $3927 = 0, $3928 = 0, $3929 = 0.0, $393 = 0, $3930 = 0.0, $3931 = 0, $3932 = 0, $3933 = 0.0, $3934 = 0, $3935 = 0, $3936 = 0.0, $3937 = 0.0, $3938 = 0, $3939 = 0, $394 = 0, $3940 = 0;
 var $3941 = 0, $3942 = 0, $3943 = 0, $3944 = 0, $3945 = 0, $3946 = 0, $3947 = 0, $3948 = 0, $3949 = 0, $395 = 0, $3950 = 0, $3951 = 0, $3952 = 0, $3953 = 0, $3954 = 0, $3955 = 0, $3956 = 0, $3957 = 0, $3958 = 0.0, $3959 = 0.0;
 var $396 = 0, $3960 = 0, $3961 = 0, $3962 = 0.0, $3963 = 0.0, $3964 = 0, $3965 = 0, $3966 = 0, $3967 = 0.0, $3968 = 0, $3969 = 0, $397 = 0, $3970 = 0.0, $3971 = 0, $3972 = 0, $3973 = 0, $3974 = 0, $3975 = 0.0, $3976 = 0, $3977 = 0;
 var $3978 = 0, $3979 = 0, $398 = 0, $3980 = 0, $3981 = 0, $3982 = 0, $3983 = 0, $3984 = 0, $3985 = 0, $3986 = 0, $3987 = 0, $3988 = 0, $3989 = 0, $399 = 0, $3990 = 0, $3991 = 0, $3992 = 0, $3993 = 0, $3994 = 0, $3995 = 0.0;
 var $3996 = 0.0, $3997 = 0, $3998 = 0, $3999 = 0, $40 = 0, $400 = 0, $4000 = 0, $4001 = 0, $4002 = 0, $4003 = 0, $4004 = 0, $4005 = 0, $4006 = 0, $4007 = 0, $4008 = 0, $4009 = 0, $401 = 0.0, $4010 = 0, $4011 = 0, $4012 = 0;
 var $4013 = 0, $4014 = 0, $4015 = 0, $4016 = 0, $4017 = 0, $4018 = 0, $4019 = 0, $402 = 0.0, $4020 = 0.0, $4021 = 0.0, $4022 = 0, $4023 = 0, $4024 = 0, $4025 = 0, $4026 = 0, $4027 = 0, $4028 = 0, $4029 = 0, $403 = 0, $4030 = 0.0;
 var $4031 = 0.0, $4032 = 0, $4033 = 0, $4034 = 0, $4035 = 0, $4036 = 0, $4037 = 0.0, $4038 = 0.0, $4039 = 0, $404 = 0, $4040 = 0, $4041 = 0, $4042 = 0, $4043 = 0, $4044 = 0.0, $4045 = 0, $4046 = 0.0, $4047 = 0, $4048 = 0, $4049 = 0.0;
 var $405 = 0.0, $4050 = 0, $4051 = 0.0, $4052 = 0, $4053 = 0, $4054 = 0, $4055 = 0, $4056 = 0, $4057 = 0, $4058 = 0, $4059 = 0.0, $406 = 0.0, $4060 = 0.0, $4061 = 0.0, $4062 = 0.0, $4063 = 0.0, $4064 = 0.0, $4065 = 0.0, $4066 = 0, $4067 = 0.0;
 var $4068 = 0.0, $4069 = 0.0, $407 = 0, $4070 = 0, $4071 = 0.0, $4072 = 0.0, $4073 = 0.0, $4074 = 0, $4075 = 0, $4076 = 0, $4077 = 0, $4078 = 0, $4079 = 0, $408 = 0.0, $4080 = 0, $4081 = 0, $4082 = 0.0, $4083 = 0, $4084 = 0, $4085 = 0;
 var $4086 = 0, $4087 = 0.0, $4088 = 0, $4089 = 0, $409 = 0.0, $4090 = 0, $4091 = 0, $4092 = 0, $4093 = 0, $4094 = 0.0, $4095 = 0.0, $4096 = 0.0, $4097 = 0.0, $4098 = 0, $4099 = 0.0, $41 = 0, $410 = 0, $4100 = 0.0, $4101 = 0, $4102 = 0;
 var $4103 = 0, $4104 = 0.0, $4105 = 0.0, $4106 = 0, $4107 = 0, $4108 = 0, $4109 = 0, $411 = 0, $4110 = 0, $4111 = 0, $4112 = 0, $4113 = 0, $4114 = 0, $4115 = 0, $4116 = 0, $4117 = 0, $4118 = 0, $4119 = 0, $412 = 0, $4120 = 0;
 var $4121 = 0, $4122 = 0, $4123 = 0, $4124 = 0.0, $4125 = 0, $4126 = 0.0, $4127 = 0.0, $4128 = 0, $4129 = 0, $413 = 0, $4130 = 0, $4131 = 0, $4132 = 0, $4133 = 0, $4134 = 0.0, $4135 = 0, $4136 = 0.0, $4137 = 0.0, $4138 = 0, $4139 = 0;
 var $414 = 0.0, $4140 = 0, $4141 = 0, $4142 = 0, $4143 = 0, $4144 = 0, $4145 = 0, $4146 = 0, $4147 = 0, $4148 = 0, $4149 = 0, $415 = 0.0, $4150 = 0, $4151 = 0, $4152 = 0, $4153 = 0, $4154 = 0, $4155 = 0, $4156 = 0, $4157 = 0;
 var $4158 = 0, $4159 = 0, $416 = 0, $4160 = 0.0, $4161 = 0, $4162 = 0.0, $4163 = 0.0, $4164 = 0, $4165 = 0, $4166 = 0, $4167 = 0, $4168 = 0, $4169 = 0.0, $417 = 0, $4170 = 0.0, $4171 = 0, $4172 = 0.0, $4173 = 0.0, $4174 = 0, $4175 = 0;
 var $4176 = 0, $4177 = 0, $4178 = 0, $4179 = 0, $418 = 0.0, $4180 = 0, $4181 = 0, $4182 = 0, $4183 = 0, $4184 = 0, $4185 = 0, $4186 = 0, $4187 = 0, $4188 = 0, $4189 = 0, $419 = 0.0, $4190 = 0, $4191 = 0, $4192 = 0, $4193 = 0.0;
 var $4194 = 0, $4195 = 0.0, $4196 = 0.0, $4197 = 0, $4198 = 0, $4199 = 0.0, $42 = 0, $420 = 0, $4200 = 0, $4201 = 0.0, $4202 = 0, $4203 = 0.0, $4204 = 0.0, $4205 = 0, $4206 = 0, $4207 = 0, $4208 = 0, $4209 = 0.0, $421 = 0.0, $4210 = 0;
 var $4211 = 0.0, $4212 = 0.0, $4213 = 0, $4214 = 0, $4215 = 0, $4216 = 0, $4217 = 0, $4218 = 0, $4219 = 0, $422 = 0.0, $4220 = 0, $4221 = 0, $4222 = 0, $4223 = 0, $4224 = 0, $4225 = 0, $4226 = 0, $4227 = 0, $4228 = 0, $4229 = 0;
 var $423 = 0.0, $4230 = 0, $4231 = 0, $4232 = 0, $4233 = 0, $4234 = 0, $4235 = 0.0, $4236 = 0, $4237 = 0.0, $4238 = 0.0, $4239 = 0, $424 = 0.0, $4240 = 0, $4241 = 0, $4242 = 0, $4243 = 0, $4244 = 0, $4245 = 0, $4246 = 0, $4247 = 0;
 var $4248 = 0, $4249 = 0, $425 = 0.0, $4250 = 0, $4251 = 0, $4252 = 0, $4253 = 0, $4254 = 0, $4255 = 0, $4256 = 0, $4257 = 0, $4258 = 0, $4259 = 0, $426 = 0.0, $4260 = 0, $4261 = 0.0, $4262 = 0, $4263 = 0.0, $4264 = 0.0, $4265 = 0;
 var $4266 = 0, $4267 = 0.0, $4268 = 0.0, $4269 = 0, $427 = 0.0, $4270 = 0.0, $4271 = 0.0, $4272 = 0, $4273 = 0, $4274 = 0, $4275 = 0, $4276 = 0.0, $4277 = 0.0, $4278 = 0.0, $4279 = 0.0, $428 = 0.0, $4280 = 0.0, $4281 = 0, $4282 = 0.0, $4283 = 0.0;
 var $4284 = 0, $4285 = 0, $4286 = 0, $4287 = 0, $4288 = 0, $4289 = 0, $429 = 0.0, $4290 = 0, $4291 = 0, $4292 = 0, $4293 = 0, $4294 = 0, $4295 = 0, $4296 = 0, $4297 = 0, $4298 = 0, $4299 = 0, $43 = 0, $430 = 0.0, $4300 = 0;
 var $4301 = 0, $4302 = 0, $4303 = 0, $4304 = 0.0, $4305 = 0, $4306 = 0.0, $4307 = 0.0, $4308 = 0, $4309 = 0, $431 = 0.0, $4310 = 0, $4311 = 0, $4312 = 0, $4313 = 0, $4314 = 0, $4315 = 0, $4316 = 0, $4317 = 0, $4318 = 0, $4319 = 0;
 var $432 = 0.0, $4320 = 0, $4321 = 0, $4322 = 0, $4323 = 0, $4324 = 0, $4325 = 0, $4326 = 0, $4327 = 0, $4328 = 0, $4329 = 0.0, $433 = 0.0, $4330 = 0.0, $4331 = 0, $4332 = 0.0, $4333 = 0.0, $4334 = 0, $4335 = 0, $4336 = 0, $4337 = 0;
 var $4338 = 0, $4339 = 0, $434 = 0.0, $4340 = 0, $4341 = 0, $4342 = 0, $4343 = 0, $4344 = 0, $4345 = 0, $4346 = 0, $4347 = 0, $4348 = 0, $4349 = 0, $435 = 0, $4350 = 0, $4351 = 0.0, $4352 = 0.0, $4353 = 0.0, $4354 = 0, $4355 = 0;
 var $4356 = 0, $4357 = 0.0, $4358 = 0.0, $4359 = 0, $436 = 0, $4360 = 0, $4361 = 0.0, $4362 = 0.0, $4363 = 0, $4364 = 0.0, $4365 = 0.0, $4366 = 0, $4367 = 0, $4368 = 0, $4369 = 0.0, $437 = 0, $4370 = 0.0, $4371 = 0, $4372 = 0, $4373 = 0.0;
 var $4374 = 0, $4375 = 0.0, $4376 = 0.0, $4377 = 0, $4378 = 0, $4379 = 0, $438 = 0.0, $4380 = 0, $4381 = 0, $4382 = 0, $4383 = 0, $4384 = 0, $4385 = 0, $4386 = 0, $4387 = 0, $4388 = 0, $4389 = 0, $439 = 0.0, $4390 = 0, $4391 = 0;
 var $4392 = 0, $4393 = 0, $4394 = 0, $4395 = 0, $4396 = 0, $4397 = 0.0, $4398 = 0, $4399 = 0.0, $44 = 0, $440 = 0.0, $4400 = 0.0, $4401 = 0, $4402 = 0, $4403 = 0, $4404 = 0, $4405 = 0, $4406 = 0, $4407 = 0, $4408 = 0, $4409 = 0;
 var $441 = 0, $4410 = 0, $4411 = 0, $4412 = 0, $4413 = 0, $4414 = 0, $4415 = 0, $4416 = 0, $4417 = 0, $4418 = 0, $4419 = 0, $442 = 0, $4420 = 0.0, $4421 = 0, $4422 = 0.0, $4423 = 0.0, $4424 = 0, $4425 = 0, $4426 = 0.0, $4427 = 0;
 var $4428 = 0.0, $4429 = 0, $443 = 0, $4430 = 0.0, $4431 = 0.0, $4432 = 0, $4433 = 0, $4434 = 0, $4435 = 0, $4436 = 0, $4437 = 0, $4438 = 0, $4439 = 0, $444 = 0, $4440 = 0, $4441 = 0, $4442 = 0, $4443 = 0, $4444 = 0, $4445 = 0;
 var $4446 = 0, $4447 = 0, $4448 = 0, $4449 = 0, $445 = 0, $4450 = 0, $4451 = 0.0, $4452 = 0, $4453 = 0.0, $4454 = 0.0, $4455 = 0, $4456 = 0, $4457 = 0.0, $4458 = 0.0, $4459 = 0, $446 = 0, $4460 = 0, $4461 = 0.0, $4462 = 0.0, $4463 = 0;
 var $4464 = 0.0, $4465 = 0.0, $4466 = 0, $4467 = 0, $4468 = 0, $4469 = 0.0, $447 = 0.0, $4470 = 0.0, $4471 = 0, $4472 = 0, $4473 = 0, $4474 = 0, $4475 = 0.0, $4476 = 0, $4477 = 0.0, $4478 = 0.0, $4479 = 0, $448 = 0.0, $4480 = 0, $4481 = 0;
 var $4482 = 0, $4483 = 0, $4484 = 0, $4485 = 0, $4486 = 0, $4487 = 0, $4488 = 0, $4489 = 0, $449 = 0.0, $4490 = 0, $4491 = 0, $4492 = 0, $4493 = 0, $4494 = 0, $4495 = 0, $4496 = 0, $4497 = 0, $4498 = 0, $4499 = 0, $45 = 0;
 var $450 = 0, $4500 = 0.0, $4501 = 0, $4502 = 0.0, $4503 = 0.0, $4504 = 0, $4505 = 0, $4506 = 0, $4507 = 0, $4508 = 0, $4509 = 0, $451 = 0, $4510 = 0, $4511 = 0, $4512 = 0, $4513 = 0, $4514 = 0, $4515 = 0, $4516 = 0, $4517 = 0;
 var $4518 = 0, $4519 = 0, $452 = 0, $4520 = 0, $4521 = 0, $4522 = 0, $4523 = 0, $4524 = 0, $4525 = 0.0, $4526 = 0, $4527 = 0.0, $4528 = 0.0, $4529 = 0, $453 = 0, $4530 = 0, $4531 = 0.0, $4532 = 0.0, $4533 = 0, $4534 = 0.0, $4535 = 0.0;
 var $4536 = 0, $4537 = 0, $4538 = 0, $4539 = 0, $454 = 0, $4540 = 0, $4541 = 0, $4542 = 0, $4543 = 0, $4544 = 0, $4545 = 0, $4546 = 0, $4547 = 0, $4548 = 0, $4549 = 0, $455 = 0, $4550 = 0, $4551 = 0, $4552 = 0, $4553 = 0;
 var $4554 = 0, $4555 = 0.0, $4556 = 0, $4557 = 0.0, $4558 = 0.0, $4559 = 0, $456 = 0, $4560 = 0, $4561 = 0.0, $4562 = 0.0, $4563 = 0, $4564 = 0, $4565 = 0.0, $4566 = 0.0, $4567 = 0, $4568 = 0.0, $4569 = 0.0, $457 = 0, $4570 = 0, $4571 = 0;
 var $4572 = 0, $4573 = 0.0, $4574 = 0.0, $4575 = 0, $4576 = 0, $4577 = 0, $4578 = 0, $4579 = 0, $458 = 0, $4580 = 0, $4581 = 0, $4582 = 0, $4583 = 0, $4584 = 0, $4585 = 0, $4586 = 0, $4587 = 0, $4588 = 0, $4589 = 0, $459 = 0;
 var $4590 = 0, $4591 = 0, $4592 = 0, $4593 = 0.0, $4594 = 0, $4595 = 0.0, $4596 = 0.0, $4597 = 0, $4598 = 0, $4599 = 0, $46 = 0, $460 = 0, $4600 = 0, $4601 = 0, $4602 = 0, $4603 = 0, $4604 = 0, $4605 = 0, $4606 = 0, $4607 = 0;
 var $4608 = 0, $4609 = 0, $461 = 0, $4610 = 0, $4611 = 0, $4612 = 0, $4613 = 0, $4614 = 0, $4615 = 0, $4616 = 0, $4617 = 0, $4618 = 0, $4619 = 0.0, $462 = 0, $4620 = 0, $4621 = 0.0, $4622 = 0.0, $4623 = 0, $4624 = 0, $4625 = 0;
 var $4626 = 0, $4627 = 0, $4628 = 0, $4629 = 0.0, $463 = 0.0, $4630 = 0, $4631 = 0.0, $4632 = 0.0, $4633 = 0, $4634 = 0, $4635 = 0, $4636 = 0, $4637 = 0, $4638 = 0.0, $4639 = 0.0, $464 = 0.0, $4640 = 0, $4641 = 0, $4642 = 0, $4643 = 0;
 var $4644 = 0.0, $4645 = 0, $4646 = 0.0, $4647 = 0, $4648 = 0, $4649 = 0.0, $465 = 0, $4650 = 0, $4651 = 0.0, $4652 = 0, $4653 = 0, $4654 = 0, $4655 = 0, $4656 = 0, $4657 = 0, $4658 = 0, $4659 = 0, $466 = 0, $4660 = 0, $4661 = 0;
 var $4662 = 0, $4663 = 0, $4664 = 0, $4665 = 0, $4666 = 0, $4667 = 0, $4668 = 0.0, $4669 = 0.0, $467 = 0.0, $4670 = 0, $4671 = 0, $4672 = 0.0, $4673 = 0.0, $4674 = 0, $4675 = 0.0, $4676 = 0.0, $4677 = 0, $4678 = 0, $4679 = 0, $468 = 0.0;
 var $4680 = 0, $4681 = 0.0, $4682 = 0.0, $4683 = 0, $4684 = 0, $4685 = 0.0, $4686 = 0.0, $4687 = 0, $4688 = 0.0, $4689 = 0.0, $469 = 0, $4690 = 0.0, $4691 = 0.0, $4692 = 0.0, $4693 = 0.0, $4694 = 0.0, $4695 = 0.0, $4696 = 0.0, $4697 = 0.0, $4698 = 0.0;
 var $4699 = 0.0, $47 = 0, $470 = 0.0, $4700 = 0.0, $4701 = 0.0, $4702 = 0, $4703 = 0, $4704 = 0, $4705 = 0, $4706 = 0.0, $4707 = 0.0, $4708 = 0.0, $4709 = 0, $471 = 0.0, $4710 = 0, $4711 = 0, $4712 = 0, $4713 = 0, $4714 = 0.0, $4715 = 0.0;
 var $4716 = 0.0, $4717 = 0, $4718 = 0, $4719 = 0, $472 = 0, $4720 = 0, $4721 = 0, $4722 = 0, $4723 = 0, $4724 = 0, $4725 = 0, $4726 = 0, $4727 = 0, $4728 = 0, $4729 = 0, $473 = 0, $4730 = 0.0, $4731 = 0.0, $4732 = 0, $4733 = 0;
 var $4734 = 0.0, $4735 = 0.0, $4736 = 0, $4737 = 0.0, $4738 = 0.0, $4739 = 0, $474 = 0, $4740 = 0, $4741 = 0, $4742 = 0, $4743 = 0.0, $4744 = 0.0, $4745 = 0, $4746 = 0, $4747 = 0.0, $4748 = 0.0, $4749 = 0, $475 = 0, $4750 = 0.0, $4751 = 0.0;
 var $4752 = 0.0, $4753 = 0.0, $4754 = 0.0, $4755 = 0.0, $4756 = 0.0, $4757 = 0.0, $4758 = 0.0, $4759 = 0.0, $476 = 0.0, $4760 = 0.0, $4761 = 0.0, $4762 = 0.0, $4763 = 0.0, $4764 = 0, $4765 = 0, $4766 = 0, $4767 = 0, $4768 = 0.0, $4769 = 0.0, $477 = 0.0;
 var $4770 = 0.0, $4771 = 0, $4772 = 0, $4773 = 0, $4774 = 0, $4775 = 0, $4776 = 0.0, $4777 = 0.0, $4778 = 0.0, $4779 = 0, $478 = 0, $4780 = 0, $4781 = 0, $4782 = 0, $4783 = 0, $4784 = 0, $4785 = 0, $4786 = 0, $4787 = 0, $4788 = 0;
 var $4789 = 0, $479 = 0, $4790 = 0, $4791 = 0, $4792 = 0, $4793 = 0, $4794 = 0, $4795 = 0, $4796 = 0, $4797 = 0, $4798 = 0, $4799 = 0, $48 = 0, $480 = 0.0, $4800 = 0.0, $4801 = 0.0, $4802 = 0, $4803 = 0, $4804 = 0.0, $4805 = 0.0;
 var $4806 = 0, $4807 = 0.0, $4808 = 0.0, $4809 = 0, $481 = 0.0, $4810 = 0, $4811 = 0, $4812 = 0, $4813 = 0.0, $4814 = 0.0, $4815 = 0, $4816 = 0, $4817 = 0.0, $4818 = 0.0, $4819 = 0, $482 = 0, $4820 = 0.0, $4821 = 0.0, $4822 = 0, $4823 = 0;
 var $4824 = 0, $4825 = 0, $4826 = 0.0, $4827 = 0.0, $4828 = 0, $4829 = 0, $483 = 0.0, $4830 = 0.0, $4831 = 0.0, $4832 = 0, $4833 = 0.0, $4834 = 0.0, $4835 = 0, $4836 = 0, $4837 = 0, $4838 = 0, $4839 = 0.0, $484 = 0.0, $4840 = 0.0, $4841 = 0;
 var $4842 = 0, $4843 = 0.0, $4844 = 0.0, $4845 = 0, $4846 = 0.0, $4847 = 0.0, $4848 = 0.0, $4849 = 0.0, $485 = 0.0, $4850 = 0.0, $4851 = 0.0, $4852 = 0.0, $4853 = 0.0, $4854 = 0.0, $4855 = 0.0, $4856 = 0.0, $4857 = 0.0, $4858 = 0.0, $4859 = 0.0, $486 = 0.0;
 var $4860 = 0.0, $4861 = 0.0, $4862 = 0.0, $4863 = 0.0, $4864 = 0.0, $4865 = 0.0, $4866 = 0, $4867 = 0, $4868 = 0, $4869 = 0, $487 = 0.0, $4870 = 0.0, $4871 = 0.0, $4872 = 0.0, $4873 = 0, $4874 = 0, $4875 = 0, $4876 = 0, $4877 = 0, $4878 = 0.0;
 var $4879 = 0.0, $488 = 0.0, $4880 = 0.0, $4881 = 0, $4882 = 0, $4883 = 0, $4884 = 0, $4885 = 0, $4886 = 0, $4887 = 0, $4888 = 0, $4889 = 0.0, $489 = 0.0, $4890 = 0.0, $4891 = 0.0, $4892 = 0.0, $4893 = 0.0, $4894 = 0.0, $4895 = 0.0, $4896 = 0;
 var $4897 = 0.0, $4898 = 0.0, $4899 = 0.0, $49 = 0, $490 = 0.0, $4900 = 0, $4901 = 0.0, $4902 = 0.0, $4903 = 0.0, $4904 = 0, $4905 = 0, $4906 = 0, $4907 = 0, $4908 = 0, $4909 = 0, $491 = 0.0, $4910 = 0, $4911 = 0, $4912 = 0, $4913 = 0;
 var $4914 = 0, $4915 = 0, $4916 = 0, $4917 = 0, $4918 = 0, $4919 = 0, $492 = 0.0, $4920 = 0, $4921 = 0, $4922 = 0.0, $4923 = 0, $4924 = 0, $4925 = 0, $4926 = 0, $4927 = 0.0, $4928 = 0, $4929 = 0, $493 = 0.0, $4930 = 0, $4931 = 0;
 var $4932 = 0, $4933 = 0, $4934 = 0.0, $4935 = 0.0, $4936 = 0, $4937 = 0, $4938 = 0, $4939 = 0.0, $494 = 0.0, $4940 = 0.0, $4941 = 0, $4942 = 0, $4943 = 0.0, $4944 = 0.0, $4945 = 0, $4946 = 0.0, $4947 = 0.0, $4948 = 0.0, $4949 = 0.0, $495 = 0.0;
 var $4950 = 0.0, $4951 = 0.0, $4952 = 0.0, $4953 = 0.0, $4954 = 0, $4955 = 0, $4956 = 0, $4957 = 0, $4958 = 0, $4959 = 0, $496 = 0.0, $4960 = 0, $4961 = 0.0, $4962 = 0.0, $4963 = 0, $4964 = 0, $4965 = 0.0, $4966 = 0.0, $4967 = 0, $4968 = 0.0;
 var $4969 = 0.0, $497 = 0, $4970 = 0.0, $4971 = 0.0, $4972 = 0.0, $4973 = 0.0, $4974 = 0.0, $4975 = 0.0, $4976 = 0.0, $4977 = 0.0, $4978 = 0.0, $4979 = 0, $498 = 0, $4980 = 0, $4981 = 0, $4982 = 0.0, $4983 = 0, $4984 = 0, $4985 = 0, $4986 = 0.0;
 var $4987 = 0.0, $4988 = 0, $4989 = 0, $499 = 0, $4990 = 0.0, $4991 = 0.0, $4992 = 0, $4993 = 0.0, $4994 = 0.0, $4995 = 0.0, $4996 = 0.0, $4997 = 0.0, $4998 = 0.0, $4999 = 0.0, $50 = 0, $500 = 0.0, $5000 = 0.0, $5001 = 0.0, $5002 = 0.0, $5003 = 0.0;
 var $5004 = 0.0, $5005 = 0, $5006 = 0, $5007 = 0, $5008 = 0, $5009 = 0.0, $501 = 0.0, $5010 = 0.0, $5011 = 0, $5012 = 0, $5013 = 0.0, $5014 = 0.0, $5015 = 0, $5016 = 0.0, $5017 = 0.0, $5018 = 0.0, $5019 = 0.0, $502 = 0.0, $5020 = 0.0, $5021 = 0.0;
 var $5022 = 0.0, $5023 = 0.0, $5024 = 0, $5025 = 0, $5026 = 0, $5027 = 0, $5028 = 0, $5029 = 0.0, $503 = 0, $5030 = 0.0, $5031 = 0, $5032 = 0, $5033 = 0.0, $5034 = 0.0, $5035 = 0, $5036 = 0.0, $5037 = 0.0, $5038 = 0.0, $5039 = 0.0, $504 = 0;
 var $5040 = 0.0, $5041 = 0.0, $5042 = 0.0, $5043 = 0.0, $5044 = 0.0, $5045 = 0.0, $5046 = 0.0, $5047 = 0, $5048 = 0, $5049 = 0, $505 = 0, $5050 = 0.0, $5051 = 0, $5052 = 0, $5053 = 0, $5054 = 0.0, $5055 = 0.0, $5056 = 0, $5057 = 0, $5058 = 0.0;
 var $5059 = 0.0, $506 = 0, $5060 = 0, $5061 = 0.0, $5062 = 0.0, $5063 = 0.0, $5064 = 0.0, $5065 = 0.0, $5066 = 0.0, $5067 = 0.0, $5068 = 0.0, $5069 = 0.0, $507 = 0, $5070 = 0.0, $5071 = 0.0, $5072 = 0, $5073 = 0, $5074 = 0, $5075 = 0, $5076 = 0;
 var $5077 = 0.0, $5078 = 0.0, $5079 = 0, $508 = 0, $5080 = 0, $5081 = 0.0, $5082 = 0.0, $5083 = 0, $5084 = 0.0, $5085 = 0.0, $5086 = 0, $5087 = 0, $5088 = 0, $5089 = 0.0, $509 = 0.0, $5090 = 0.0, $5091 = 0, $5092 = 0, $5093 = 0.0, $5094 = 0.0;
 var $5095 = 0, $5096 = 0.0, $5097 = 0.0, $5098 = 0.0, $5099 = 0.0, $51 = 0, $510 = 0.0, $5100 = 0.0, $5101 = 0.0, $5102 = 0.0, $5103 = 0.0, $5104 = 0.0, $5105 = 0.0, $5106 = 0.0, $5107 = 0.0, $5108 = 0.0, $5109 = 0.0, $511 = 0.0, $5110 = 0.0, $5111 = 0.0;
 var $5112 = 0.0, $5113 = 0.0, $5114 = 0.0, $5115 = 0, $5116 = 0, $5117 = 0, $5118 = 0, $5119 = 0, $512 = 0, $5120 = 0.0, $5121 = 0.0, $5122 = 0, $5123 = 0, $5124 = 0.0, $5125 = 0.0, $5126 = 0, $5127 = 0.0, $5128 = 0.0, $5129 = 0.0, $513 = 0;
 var $5130 = 0.0, $5131 = 0.0, $5132 = 0.0, $5133 = 0.0, $5134 = 0.0, $5135 = 0, $5136 = 0, $5137 = 0, $5138 = 0, $5139 = 0.0, $514 = 0, $5140 = 0.0, $5141 = 0, $5142 = 0, $5143 = 0.0, $5144 = 0.0, $5145 = 0, $5146 = 0.0, $5147 = 0.0, $5148 = 0.0;
 var $5149 = 0.0, $515 = 0, $5150 = 0.0, $5151 = 0.0, $5152 = 0.0, $5153 = 0.0, $5154 = 0.0, $5155 = 0.0, $5156 = 0.0, $5157 = 0.0, $5158 = 0, $5159 = 0, $516 = 0, $5160 = 0, $5161 = 0, $5162 = 0.0, $5163 = 0.0, $5164 = 0, $5165 = 0, $5166 = 0.0;
 var $5167 = 0.0, $5168 = 0, $5169 = 0.0, $517 = 0, $5170 = 0.0, $5171 = 0.0, $5172 = 0.0, $5173 = 0.0, $5174 = 0.0, $5175 = 0.0, $5176 = 0.0, $5177 = 0.0, $5178 = 0.0, $5179 = 0.0, $518 = 0, $5180 = 0.0, $5181 = 0.0, $5182 = 0, $5183 = 0, $5184 = 0;
 var $5185 = 0, $5186 = 0, $5187 = 0.0, $5188 = 0.0, $5189 = 0, $519 = 0, $5190 = 0, $5191 = 0.0, $5192 = 0.0, $5193 = 0, $5194 = 0.0, $5195 = 0.0, $5196 = 0.0, $5197 = 0.0, $5198 = 0.0, $5199 = 0.0, $52 = 0, $520 = 0, $5200 = 0.0, $5201 = 0.0;
 var $5202 = 0, $5203 = 0, $5204 = 0, $5205 = 0, $5206 = 0, $5207 = 0, $5208 = 0.0, $5209 = 0.0, $521 = 0, $5210 = 0, $5211 = 0, $5212 = 0.0, $5213 = 0.0, $5214 = 0, $5215 = 0.0, $5216 = 0.0, $5217 = 0.0, $5218 = 0.0, $5219 = 0.0, $522 = 0;
 var $5220 = 0.0, $5221 = 0.0, $5222 = 0.0, $5223 = 0.0, $5224 = 0.0, $5225 = 0.0, $5226 = 0, $5227 = 0, $5228 = 0.0, $5229 = 0, $523 = 0, $5230 = 0, $5231 = 0, $5232 = 0.0, $5233 = 0.0, $5234 = 0, $5235 = 0, $5236 = 0.0, $5237 = 0.0, $5238 = 0;
 var $5239 = 0.0, $524 = 0, $5240 = 0.0, $5241 = 0.0, $5242 = 0.0, $5243 = 0.0, $5244 = 0.0, $5245 = 0.0, $5246 = 0.0, $5247 = 0.0, $5248 = 0.0, $5249 = 0.0, $525 = 0, $5250 = 0.0, $5251 = 0.0, $5252 = 0, $5253 = 0, $5254 = 0, $5255 = 0, $5256 = 0;
 var $5257 = 0.0, $5258 = 0.0, $5259 = 0, $526 = 0, $5260 = 0, $5261 = 0.0, $5262 = 0.0, $5263 = 0, $5264 = 0.0, $5265 = 0.0, $5266 = 0.0, $5267 = 0.0, $5268 = 0.0, $5269 = 0.0, $527 = 0, $5270 = 0.0, $5271 = 0.0, $5272 = 0, $5273 = 0, $5274 = 0;
 var $5275 = 0, $5276 = 0, $5277 = 0, $5278 = 0, $5279 = 0.0, $528 = 0, $5280 = 0.0, $5281 = 0, $5282 = 0, $5283 = 0.0, $5284 = 0.0, $5285 = 0, $5286 = 0.0, $5287 = 0.0, $5288 = 0.0, $5289 = 0.0, $529 = 0, $5290 = 0.0, $5291 = 0.0, $5292 = 0.0;
 var $5293 = 0.0, $5294 = 0, $5295 = 0, $5296 = 0, $5297 = 0.0, $5298 = 0.0, $5299 = 0.0, $53 = 0.0, $530 = 0, $5300 = 0.0, $5301 = 0.0, $5302 = 0.0, $5303 = 0, $5304 = 0.0, $5305 = 0.0, $5306 = 0.0, $5307 = 0, $5308 = 0, $5309 = 0, $531 = 0;
 var $5310 = 0, $5311 = 0.0, $5312 = 0.0, $5313 = 0.0, $5314 = 0, $5315 = 0, $5316 = 0, $5317 = 0, $5318 = 0, $5319 = 0.0, $532 = 0, $5320 = 0.0, $5321 = 0.0, $5322 = 0, $5323 = 0, $5324 = 0, $5325 = 0, $5326 = 0, $5327 = 0, $5328 = 0.0;
 var $5329 = 0, $533 = 0.0, $5330 = 0.0, $5331 = 0, $5332 = 0, $5333 = 0, $5334 = 0.0, $5335 = 0, $5336 = 0.0, $5337 = 0, $5338 = 0, $5339 = 0, $534 = 0.0, $5340 = 0, $5341 = 0, $5342 = 0, $5343 = 0, $5344 = 0, $5345 = 0, $5346 = 0;
 var $5347 = 0, $5348 = 0, $5349 = 0, $535 = 0, $5350 = 0, $5351 = 0, $5352 = 0.0, $5353 = 0.0, $5354 = 0, $5355 = 0, $5356 = 0.0, $5357 = 0.0, $5358 = 0, $5359 = 0.0, $536 = 0, $5360 = 0.0, $5361 = 0, $5362 = 0, $5363 = 0, $5364 = 0;
 var $5365 = 0.0, $5366 = 0.0, $5367 = 0, $5368 = 0, $5369 = 0.0, $537 = 0.0, $5370 = 0.0, $5371 = 0, $5372 = 0.0, $5373 = 0.0, $5374 = 0.0, $5375 = 0.0, $5376 = 0.0, $5377 = 0.0, $5378 = 0.0, $5379 = 0.0, $538 = 0.0, $5380 = 0.0, $5381 = 0.0, $5382 = 0.0;
 var $5383 = 0.0, $5384 = 0.0, $5385 = 0.0, $5386 = 0, $5387 = 0, $5388 = 0, $5389 = 0.0, $539 = 0, $5390 = 0.0, $5391 = 0.0, $5392 = 0, $5393 = 0, $5394 = 0, $5395 = 0, $5396 = 0, $5397 = 0, $5398 = 0.0, $5399 = 0.0, $54 = 0.0, $540 = 0.0;
 var $5400 = 0.0, $5401 = 0, $5402 = 0, $5403 = 0, $5404 = 0, $5405 = 0, $5406 = 0, $5407 = 0, $5408 = 0, $5409 = 0, $541 = 0.0, $5410 = 0, $5411 = 0, $5412 = 0, $5413 = 0, $5414 = 0.0, $5415 = 0.0, $5416 = 0, $5417 = 0, $5418 = 0.0;
 var $5419 = 0.0, $542 = 0, $5420 = 0, $5421 = 0.0, $5422 = 0.0, $5423 = 0, $5424 = 0, $5425 = 0, $5426 = 0, $5427 = 0.0, $5428 = 0.0, $5429 = 0, $543 = 0, $5430 = 0, $5431 = 0.0, $5432 = 0.0, $5433 = 0, $5434 = 0.0, $5435 = 0.0, $5436 = 0.0;
 var $5437 = 0.0, $5438 = 0.0, $5439 = 0.0, $544 = 0, $5440 = 0.0, $5441 = 0.0, $5442 = 0.0, $5443 = 0.0, $5444 = 0.0, $5445 = 0.0, $5446 = 0.0, $5447 = 0.0, $5448 = 0, $5449 = 0, $545 = 0, $5450 = 0, $5451 = 0.0, $5452 = 0.0, $5453 = 0.0, $5454 = 0;
 var $5455 = 0, $5456 = 0, $5457 = 0, $5458 = 0, $5459 = 0, $546 = 0.0, $5460 = 0.0, $5461 = 0.0, $5462 = 0.0, $5463 = 0, $5464 = 0, $5465 = 0, $5466 = 0, $5467 = 0, $5468 = 0, $5469 = 0, $547 = 0.0, $5470 = 0, $5471 = 0, $5472 = 0;
 var $5473 = 0, $5474 = 0, $5475 = 0, $5476 = 0, $5477 = 0, $5478 = 0, $5479 = 0, $548 = 0, $5480 = 0, $5481 = 0, $5482 = 0, $5483 = 0, $5484 = 0.0, $5485 = 0.0, $5486 = 0, $5487 = 0, $5488 = 0.0, $5489 = 0.0, $549 = 0, $5490 = 0;
 var $5491 = 0.0, $5492 = 0.0, $5493 = 0, $5494 = 0, $5495 = 0, $5496 = 0, $5497 = 0.0, $5498 = 0.0, $5499 = 0, $55 = 0, $550 = 0.0, $5500 = 0, $5501 = 0.0, $5502 = 0.0, $5503 = 0, $5504 = 0.0, $5505 = 0.0, $5506 = 0, $5507 = 0, $5508 = 0;
 var $5509 = 0, $551 = 0.0, $5510 = 0.0, $5511 = 0.0, $5512 = 0, $5513 = 0, $5514 = 0.0, $5515 = 0.0, $5516 = 0, $5517 = 0.0, $5518 = 0.0, $5519 = 0, $552 = 0, $5520 = 0, $5521 = 0, $5522 = 0, $5523 = 0.0, $5524 = 0.0, $5525 = 0, $5526 = 0;
 var $5527 = 0.0, $5528 = 0.0, $5529 = 0, $553 = 0.0, $5530 = 0.0, $5531 = 0.0, $5532 = 0.0, $5533 = 0.0, $5534 = 0.0, $5535 = 0.0, $5536 = 0.0, $5537 = 0.0, $5538 = 0.0, $5539 = 0.0, $554 = 0.0, $5540 = 0.0, $5541 = 0.0, $5542 = 0.0, $5543 = 0.0, $5544 = 0.0;
 var $5545 = 0.0, $5546 = 0.0, $5547 = 0.0, $5548 = 0.0, $5549 = 0.0, $555 = 0, $5550 = 0, $5551 = 0, $5552 = 0, $5553 = 0.0, $5554 = 0.0, $5555 = 0.0, $5556 = 0, $5557 = 0, $5558 = 0, $5559 = 0, $556 = 0, $5560 = 0, $5561 = 0, $5562 = 0.0;
 var $5563 = 0.0, $5564 = 0.0, $5565 = 0, $5566 = 0, $5567 = 0, $5568 = 0, $5569 = 0, $557 = 0, $5570 = 0, $5571 = 0, $5572 = 0, $5573 = 0.0, $5574 = 0.0, $5575 = 0.0, $5576 = 0.0, $5577 = 0.0, $5578 = 0.0, $5579 = 0.0, $558 = 0, $5580 = 0;
 var $5581 = 0.0, $5582 = 0.0, $5583 = 0.0, $5584 = 0, $5585 = 0.0, $5586 = 0.0, $5587 = 0.0, $5588 = 0, $5589 = 0, $559 = 0.0, $5590 = 0, $5591 = 0, $5592 = 0, $5593 = 0, $5594 = 0, $5595 = 0, $5596 = 0, $5597 = 0, $5598 = 0, $5599 = 0;
 var $56 = 0, $560 = 0.0, $5600 = 0, $5601 = 0, $5602 = 0, $5603 = 0, $5604 = 0, $5605 = 0, $5606 = 0.0, $5607 = 0, $5608 = 0, $5609 = 0, $561 = 0, $5610 = 0, $5611 = 0.0, $5612 = 0, $5613 = 0, $5614 = 0, $5615 = 0, $5616 = 0;
 var $5617 = 0, $5618 = 0.0, $5619 = 0.0, $562 = 0, $5620 = 0, $5621 = 0, $5622 = 0, $5623 = 0.0, $5624 = 0.0, $5625 = 0, $5626 = 0, $5627 = 0.0, $5628 = 0.0, $5629 = 0, $563 = 0.0, $5630 = 0.0, $5631 = 0.0, $5632 = 0.0, $5633 = 0.0, $5634 = 0.0;
 var $5635 = 0.0, $5636 = 0.0, $5637 = 0.0, $5638 = 0, $5639 = 0, $564 = 0.0, $5640 = 0, $5641 = 0, $5642 = 0, $5643 = 0, $5644 = 0, $5645 = 0.0, $5646 = 0.0, $5647 = 0, $5648 = 0, $5649 = 0.0, $565 = 0, $5650 = 0.0, $5651 = 0, $5652 = 0.0;
 var $5653 = 0.0, $5654 = 0.0, $5655 = 0.0, $5656 = 0.0, $5657 = 0.0, $5658 = 0.0, $5659 = 0.0, $566 = 0.0, $5660 = 0.0, $5661 = 0.0, $5662 = 0.0, $5663 = 0, $5664 = 0, $5665 = 0, $5666 = 0.0, $5667 = 0, $5668 = 0, $5669 = 0, $567 = 0.0, $5670 = 0.0;
 var $5671 = 0.0, $5672 = 0, $5673 = 0, $5674 = 0.0, $5675 = 0.0, $5676 = 0, $5677 = 0.0, $5678 = 0.0, $5679 = 0.0, $568 = 0, $5680 = 0.0, $5681 = 0.0, $5682 = 0.0, $5683 = 0.0, $5684 = 0.0, $5685 = 0.0, $5686 = 0.0, $5687 = 0.0, $5688 = 0.0, $5689 = 0;
 var $569 = 0, $5690 = 0, $5691 = 0, $5692 = 0, $5693 = 0.0, $5694 = 0.0, $5695 = 0, $5696 = 0, $5697 = 0.0, $5698 = 0.0, $5699 = 0, $57 = 0, $570 = 0, $5700 = 0.0, $5701 = 0.0, $5702 = 0.0, $5703 = 0.0, $5704 = 0.0, $5705 = 0.0, $5706 = 0.0;
 var $5707 = 0.0, $5708 = 0, $5709 = 0, $571 = 0, $5710 = 0, $5711 = 0, $5712 = 0, $5713 = 0.0, $5714 = 0.0, $5715 = 0, $5716 = 0, $5717 = 0.0, $5718 = 0.0, $5719 = 0, $572 = 0.0, $5720 = 0.0, $5721 = 0.0, $5722 = 0.0, $5723 = 0.0, $5724 = 0.0;
 var $5725 = 0.0, $5726 = 0.0, $5727 = 0.0, $5728 = 0.0, $5729 = 0.0, $573 = 0.0, $5730 = 0.0, $5731 = 0, $5732 = 0, $5733 = 0, $5734 = 0.0, $5735 = 0, $5736 = 0, $5737 = 0, $5738 = 0.0, $5739 = 0.0, $574 = 0, $5740 = 0, $5741 = 0, $5742 = 0.0;
 var $5743 = 0.0, $5744 = 0, $5745 = 0.0, $5746 = 0.0, $5747 = 0.0, $5748 = 0.0, $5749 = 0.0, $575 = 0, $5750 = 0.0, $5751 = 0.0, $5752 = 0.0, $5753 = 0.0, $5754 = 0.0, $5755 = 0.0, $5756 = 0, $5757 = 0, $5758 = 0, $5759 = 0, $576 = 0.0, $5760 = 0;
 var $5761 = 0.0, $5762 = 0.0, $5763 = 0, $5764 = 0, $5765 = 0.0, $5766 = 0.0, $5767 = 0, $5768 = 0.0, $5769 = 0.0, $577 = 0.0, $5770 = 0, $5771 = 0, $5772 = 0, $5773 = 0.0, $5774 = 0.0, $5775 = 0, $5776 = 0, $5777 = 0.0, $5778 = 0.0, $5779 = 0;
 var $578 = 0, $5780 = 0.0, $5781 = 0.0, $5782 = 0.0, $5783 = 0.0, $5784 = 0.0, $5785 = 0.0, $5786 = 0.0, $5787 = 0.0, $5788 = 0.0, $5789 = 0.0, $579 = 0.0, $5790 = 0.0, $5791 = 0.0, $5792 = 0.0, $5793 = 0.0, $5794 = 0.0, $5795 = 0.0, $5796 = 0.0, $5797 = 0.0;
 var $5798 = 0.0, $5799 = 0, $58 = 0, $580 = 0.0, $5800 = 0, $5801 = 0, $5802 = 0, $5803 = 0, $5804 = 0.0, $5805 = 0.0, $5806 = 0, $5807 = 0, $5808 = 0.0, $5809 = 0.0, $581 = 0.0, $5810 = 0, $5811 = 0.0, $5812 = 0.0, $5813 = 0.0, $5814 = 0.0;
 var $5815 = 0.0, $5816 = 0.0, $5817 = 0.0, $5818 = 0.0, $5819 = 0, $582 = 0.0, $5820 = 0, $5821 = 0, $5822 = 0, $5823 = 0.0, $5824 = 0.0, $5825 = 0, $5826 = 0, $5827 = 0.0, $5828 = 0.0, $5829 = 0, $583 = 0.0, $5830 = 0.0, $5831 = 0.0, $5832 = 0.0;
 var $5833 = 0.0, $5834 = 0.0, $5835 = 0.0, $5836 = 0.0, $5837 = 0.0, $5838 = 0.0, $5839 = 0.0, $584 = 0.0, $5840 = 0.0, $5841 = 0.0, $5842 = 0, $5843 = 0, $5844 = 0, $5845 = 0, $5846 = 0.0, $5847 = 0.0, $5848 = 0, $5849 = 0, $585 = 0.0, $5850 = 0.0;
 var $5851 = 0.0, $5852 = 0, $5853 = 0.0, $5854 = 0.0, $5855 = 0.0, $5856 = 0.0, $5857 = 0.0, $5858 = 0.0, $5859 = 0.0, $586 = 0.0, $5860 = 0.0, $5861 = 0.0, $5862 = 0.0, $5863 = 0.0, $5864 = 0.0, $5865 = 0.0, $5866 = 0, $5867 = 0, $5868 = 0, $5869 = 0;
 var $587 = 0.0, $5870 = 0, $5871 = 0.0, $5872 = 0.0, $5873 = 0, $5874 = 0, $5875 = 0.0, $5876 = 0.0, $5877 = 0, $5878 = 0.0, $5879 = 0.0, $588 = 0.0, $5880 = 0.0, $5881 = 0.0, $5882 = 0.0, $5883 = 0.0, $5884 = 0.0, $5885 = 0.0, $5886 = 0, $5887 = 0;
 var $5888 = 0, $5889 = 0, $589 = 0.0, $5890 = 0, $5891 = 0, $5892 = 0.0, $5893 = 0.0, $5894 = 0, $5895 = 0, $5896 = 0.0, $5897 = 0.0, $5898 = 0, $5899 = 0.0, $59 = 0, $590 = 0.0, $5900 = 0.0, $5901 = 0.0, $5902 = 0.0, $5903 = 0.0, $5904 = 0.0;
 var $5905 = 0.0, $5906 = 0.0, $5907 = 0.0, $5908 = 0.0, $5909 = 0.0, $591 = 0.0, $5910 = 0, $5911 = 0, $5912 = 0.0, $5913 = 0, $5914 = 0, $5915 = 0, $5916 = 0.0, $5917 = 0.0, $5918 = 0, $5919 = 0, $592 = 0.0, $5920 = 0.0, $5921 = 0.0, $5922 = 0;
 var $5923 = 0.0, $5924 = 0.0, $5925 = 0.0, $5926 = 0.0, $5927 = 0.0, $5928 = 0.0, $5929 = 0.0, $593 = 0.0, $5930 = 0.0, $5931 = 0.0, $5932 = 0.0, $5933 = 0.0, $5934 = 0.0, $5935 = 0.0, $5936 = 0, $5937 = 0, $5938 = 0, $5939 = 0, $594 = 0.0, $5940 = 0;
 var $5941 = 0.0, $5942 = 0.0, $5943 = 0, $5944 = 0, $5945 = 0.0, $5946 = 0.0, $5947 = 0, $5948 = 0.0, $5949 = 0.0, $595 = 0.0, $5950 = 0.0, $5951 = 0.0, $5952 = 0.0, $5953 = 0.0, $5954 = 0.0, $5955 = 0.0, $5956 = 0, $5957 = 0, $5958 = 0, $5959 = 0;
 var $596 = 0.0, $5960 = 0, $5961 = 0, $5962 = 0, $5963 = 0.0, $5964 = 0.0, $5965 = 0, $5966 = 0, $5967 = 0.0, $5968 = 0.0, $5969 = 0, $597 = 0.0, $5970 = 0.0, $5971 = 0.0, $5972 = 0.0, $5973 = 0.0, $5974 = 0.0, $5975 = 0.0, $5976 = 0.0, $5977 = 0.0;
 var $5978 = 0, $5979 = 0, $598 = 0.0, $5980 = 0, $5981 = 0.0, $5982 = 0.0, $5983 = 0.0, $5984 = 0.0, $5985 = 0.0, $5986 = 0.0, $5987 = 0, $5988 = 0.0, $5989 = 0.0, $599 = 0, $5990 = 0.0, $5991 = 0, $5992 = 0, $5993 = 0, $5994 = 0.0, $5995 = 0.0;
 var $5996 = 0.0, $5997 = 0, $5998 = 0, $5999 = 0, $60 = 0, $600 = 0, $6000 = 0, $6001 = 0, $6002 = 0, $6003 = 0.0, $6004 = 0.0, $6005 = 0.0, $6006 = 0, $6007 = 0, $6008 = 0, $6009 = 0, $601 = 0, $6010 = 0, $6011 = 0, $6012 = 0.0;
 var $6013 = 0, $6014 = 0.0, $6015 = 0, $6016 = 0, $6017 = 0, $6018 = 0.0, $6019 = 0, $602 = 0.0, $6020 = 0.0, $6021 = 0, $6022 = 0, $6023 = 0, $6024 = 0, $6025 = 0, $6026 = 0, $6027 = 0, $6028 = 0, $6029 = 0.0, $603 = 0.0, $6030 = 0.0;
 var $6031 = 0, $6032 = 0, $6033 = 0, $6034 = 0.0, $6035 = 0.0, $6036 = 0, $6037 = 0, $6038 = 0, $6039 = 0, $604 = 0.0, $6040 = 0, $6041 = 0, $6042 = 0, $6043 = 0, $6044 = 0, $6045 = 0, $6046 = 0, $6047 = 0, $6048 = 0, $6049 = 0;
 var $605 = 0, $6050 = 0, $6051 = 0, $6052 = 0, $6053 = 0, $6054 = 0, $6055 = 0, $6056 = 0, $6057 = 0, $6058 = 0, $6059 = 0, $606 = 0, $6060 = 0, $6061 = 0.0, $6062 = 0.0, $6063 = 0, $6064 = 0, $6065 = 0.0, $6066 = 0.0, $6067 = 0;
 var $6068 = 0.0, $6069 = 0.0, $607 = 0, $6070 = 0, $6071 = 0, $6072 = 0, $6073 = 0, $6074 = 0.0, $6075 = 0.0, $6076 = 0, $6077 = 0, $6078 = 0.0, $6079 = 0.0, $608 = 0, $6080 = 0, $6081 = 0.0, $6082 = 0.0, $6083 = 0.0, $6084 = 0.0, $6085 = 0.0;
 var $6086 = 0.0, $6087 = 0.0, $6088 = 0.0, $6089 = 0.0, $609 = 0, $6090 = 0.0, $6091 = 0.0, $6092 = 0.0, $6093 = 0.0, $6094 = 0.0, $6095 = 0, $6096 = 0, $6097 = 0, $6098 = 0, $6099 = 0, $61 = 0, $610 = 0, $6100 = 0.0, $6101 = 0.0, $6102 = 0.0;
 var $6103 = 0.0, $6104 = 0, $6105 = 0, $6106 = 0, $6107 = 0, $6108 = 0, $6109 = 0, $611 = 0.0, $6110 = 0.0, $6111 = 0.0, $6112 = 0.0, $6113 = 0.0, $6114 = 0, $6115 = 0, $6116 = 0, $6117 = 0, $6118 = 0, $6119 = 0, $612 = 0.0, $6120 = 0;
 var $6121 = 0, $6122 = 0, $6123 = 0, $6124 = 0, $6125 = 0, $6126 = 0, $6127 = 0.0, $6128 = 0.0, $6129 = 0, $613 = 0.0, $6130 = 0, $6131 = 0.0, $6132 = 0.0, $6133 = 0, $6134 = 0.0, $6135 = 0.0, $6136 = 0, $6137 = 0, $6138 = 0, $6139 = 0;
 var $614 = 0, $6140 = 0.0, $6141 = 0.0, $6142 = 0, $6143 = 0, $6144 = 0.0, $6145 = 0.0, $6146 = 0, $6147 = 0.0, $6148 = 0.0, $6149 = 0.0, $615 = 0, $6150 = 0.0, $6151 = 0.0, $6152 = 0.0, $6153 = 0.0, $6154 = 0.0, $6155 = 0.0, $6156 = 0.0, $6157 = 0.0;
 var $6158 = 0.0, $6159 = 0.0, $616 = 0, $6160 = 0.0, $6161 = 0, $6162 = 0, $6163 = 0, $6164 = 0, $6165 = 0, $6166 = 0.0, $6167 = 0.0, $6168 = 0.0, $6169 = 0.0, $617 = 0, $6170 = 0, $6171 = 0, $6172 = 0, $6173 = 0, $6174 = 0, $6175 = 0;
 var $6176 = 0.0, $6177 = 0.0, $6178 = 0.0, $6179 = 0.0, $618 = 0, $6180 = 0, $6181 = 0, $6182 = 0, $6183 = 0, $6184 = 0, $6185 = 0, $6186 = 0, $6187 = 0, $6188 = 0, $6189 = 0, $619 = 0, $6190 = 0, $6191 = 0, $6192 = 0, $6193 = 0;
 var $6194 = 0, $6195 = 0, $6196 = 0, $6197 = 0, $6198 = 0, $6199 = 0, $62 = 0, $620 = 0, $6200 = 0.0, $6201 = 0.0, $6202 = 0, $6203 = 0, $6204 = 0.0, $6205 = 0.0, $6206 = 0, $6207 = 0.0, $6208 = 0.0, $6209 = 0, $621 = 0, $6210 = 0;
 var $6211 = 0, $6212 = 0, $6213 = 0.0, $6214 = 0.0, $6215 = 0, $6216 = 0, $6217 = 0.0, $6218 = 0.0, $6219 = 0, $622 = 0, $6220 = 0.0, $6221 = 0.0, $6222 = 0, $6223 = 0, $6224 = 0, $6225 = 0, $6226 = 0.0, $6227 = 0.0, $6228 = 0, $6229 = 0;
 var $623 = 0, $6230 = 0.0, $6231 = 0.0, $6232 = 0, $6233 = 0.0, $6234 = 0.0, $6235 = 0, $6236 = 0, $6237 = 0, $6238 = 0, $6239 = 0.0, $624 = 0, $6240 = 0.0, $6241 = 0, $6242 = 0, $6243 = 0.0, $6244 = 0.0, $6245 = 0, $6246 = 0.0, $6247 = 0.0;
 var $6248 = 0.0, $6249 = 0.0, $625 = 0, $6250 = 0.0, $6251 = 0.0, $6252 = 0.0, $6253 = 0.0, $6254 = 0.0, $6255 = 0.0, $6256 = 0.0, $6257 = 0.0, $6258 = 0.0, $6259 = 0.0, $626 = 0, $6260 = 0.0, $6261 = 0.0, $6262 = 0.0, $6263 = 0.0, $6264 = 0.0, $6265 = 0.0;
 var $6266 = 0, $6267 = 0, $6268 = 0, $6269 = 0, $627 = 0, $6270 = 0, $6271 = 0.0, $6272 = 0.0, $6273 = 0.0, $6274 = 0.0, $6275 = 0, $6276 = 0, $6277 = 0, $6278 = 0, $6279 = 0, $628 = 0, $6280 = 0, $6281 = 0.0, $6282 = 0.0, $6283 = 0.0;
 var $6284 = 0.0, $6285 = 0, $6286 = 0, $6287 = 0, $6288 = 0, $6289 = 0, $629 = 0, $6290 = 0, $6291 = 0, $6292 = 0, $6293 = 0, $6294 = 0, $6295 = 0, $6296 = 0, $6297 = 0, $6298 = 0, $6299 = 0, $63 = 0, $630 = 0, $6300 = 0;
 var $6301 = 0.0, $6302 = 0.0, $6303 = 0, $6304 = 0, $6305 = 0.0, $6306 = 0.0, $6307 = 0, $6308 = 0.0, $6309 = 0.0, $631 = 0, $6310 = 0, $6311 = 0, $6312 = 0, $6313 = 0, $6314 = 0.0, $6315 = 0.0, $6316 = 0, $6317 = 0, $6318 = 0.0, $6319 = 0.0;
 var $632 = 0, $6320 = 0, $6321 = 0.0, $6322 = 0.0, $6323 = 0.0, $6324 = 0.0, $6325 = 0.0, $6326 = 0.0, $6327 = 0.0, $6328 = 0.0, $6329 = 0.0, $633 = 0, $6330 = 0.0, $6331 = 0.0, $6332 = 0.0, $6333 = 0.0, $6334 = 0.0, $6335 = 0, $6336 = 0, $6337 = 0;
 var $6338 = 0.0, $6339 = 0.0, $634 = 0, $6340 = 0.0, $6341 = 0.0, $6342 = 0, $6343 = 0, $6344 = 0, $6345 = 0, $6346 = 0, $6347 = 0, $6348 = 0, $6349 = 0.0, $635 = 0, $6350 = 0.0, $6351 = 0.0, $6352 = 0.0, $6353 = 0, $6354 = 0, $6355 = 0;
 var $6356 = 0, $6357 = 0, $6358 = 0, $6359 = 0, $636 = 0, $6360 = 0, $6361 = 0, $6362 = 0, $6363 = 0, $6364 = 0, $6365 = 0, $6366 = 0.0, $6367 = 0.0, $6368 = 0, $6369 = 0, $637 = 0, $6370 = 0.0, $6371 = 0.0, $6372 = 0, $6373 = 0.0;
 var $6374 = 0.0, $6375 = 0, $6376 = 0, $6377 = 0, $6378 = 0, $6379 = 0.0, $638 = 0.0, $6380 = 0.0, $6381 = 0, $6382 = 0, $6383 = 0.0, $6384 = 0.0, $6385 = 0, $6386 = 0.0, $6387 = 0.0, $6388 = 0.0, $6389 = 0.0, $639 = 0.0, $6390 = 0.0, $6391 = 0.0;
 var $6392 = 0.0, $6393 = 0.0, $6394 = 0.0, $6395 = 0.0, $6396 = 0.0, $6397 = 0.0, $6398 = 0.0, $6399 = 0.0, $64 = 0, $640 = 0, $6400 = 0, $6401 = 0, $6402 = 0, $6403 = 0.0, $6404 = 0.0, $6405 = 0.0, $6406 = 0.0, $6407 = 0, $6408 = 0, $6409 = 0;
 var $641 = 0, $6410 = 0, $6411 = 0, $6412 = 0, $6413 = 0, $6414 = 0.0, $6415 = 0.0, $6416 = 0.0, $6417 = 0.0, $6418 = 0, $6419 = 0, $642 = 0.0, $6420 = 0, $6421 = 0, $6422 = 0, $6423 = 0, $6424 = 0, $6425 = 0, $6426 = 0, $6427 = 0;
 var $6428 = 0, $6429 = 0, $643 = 0.0, $6430 = 0, $6431 = 0, $6432 = 0, $6433 = 0, $6434 = 0, $6435 = 0, $6436 = 0, $6437 = 0, $6438 = 0.0, $6439 = 0.0, $644 = 0, $6440 = 0, $6441 = 0, $6442 = 0.0, $6443 = 0.0, $6444 = 0, $6445 = 0.0;
 var $6446 = 0.0, $6447 = 0, $6448 = 0, $6449 = 0, $645 = 0.0, $6450 = 0, $6451 = 0.0, $6452 = 0.0, $6453 = 0, $6454 = 0, $6455 = 0.0, $6456 = 0.0, $6457 = 0, $6458 = 0.0, $6459 = 0.0, $646 = 0.0, $6460 = 0, $6461 = 0, $6462 = 0, $6463 = 0;
 var $6464 = 0.0, $6465 = 0.0, $6466 = 0, $6467 = 0, $6468 = 0.0, $6469 = 0.0, $647 = 0, $6470 = 0, $6471 = 0.0, $6472 = 0.0, $6473 = 0, $6474 = 0, $6475 = 0, $6476 = 0, $6477 = 0.0, $6478 = 0.0, $6479 = 0, $648 = 0, $6480 = 0, $6481 = 0.0;
 var $6482 = 0.0, $6483 = 0, $6484 = 0.0, $6485 = 0.0, $6486 = 0.0, $6487 = 0.0, $6488 = 0.0, $6489 = 0.0, $649 = 0, $6490 = 0.0, $6491 = 0.0, $6492 = 0.0, $6493 = 0.0, $6494 = 0.0, $6495 = 0.0, $6496 = 0.0, $6497 = 0.0, $6498 = 0.0, $6499 = 0.0, $65 = 0;
 var $650 = 0, $6500 = 0.0, $6501 = 0.0, $6502 = 0.0, $6503 = 0.0, $6504 = 0, $6505 = 0, $6506 = 0, $6507 = 0.0, $6508 = 0.0, $6509 = 0.0, $651 = 0, $6510 = 0.0, $6511 = 0, $6512 = 0, $6513 = 0, $6514 = 0, $6515 = 0, $6516 = 0, $6517 = 0;
 var $6518 = 0.0, $6519 = 0.0, $652 = 0, $6520 = 0.0, $6521 = 0.0, $6522 = 0, $6523 = 0, $6524 = 0, $6525 = 0, $6526 = 0, $6527 = 0, $6528 = 0, $6529 = 0, $653 = 0, $6530 = 0, $6531 = 0, $6532 = 0, $6533 = 0, $6534 = 0, $6535 = 0;
 var $6536 = 0, $6537 = 0, $6538 = 0.0, $6539 = 0.0, $654 = 0, $6540 = 0, $6541 = 0, $6542 = 0.0, $6543 = 0.0, $6544 = 0, $6545 = 0.0, $6546 = 0.0, $6547 = 0, $6548 = 0, $6549 = 0, $655 = 0, $6550 = 0, $6551 = 0.0, $6552 = 0.0, $6553 = 0;
 var $6554 = 0, $6555 = 0.0, $6556 = 0.0, $6557 = 0, $6558 = 0.0, $6559 = 0.0, $656 = 0, $6560 = 0.0, $6561 = 0.0, $6562 = 0.0, $6563 = 0.0, $6564 = 0.0, $6565 = 0.0, $6566 = 0.0, $6567 = 0.0, $6568 = 0.0, $6569 = 0.0, $657 = 0, $6570 = 0.0, $6571 = 0.0;
 var $6572 = 0, $6573 = 0, $6574 = 0, $6575 = 0, $6576 = 0.0, $6577 = 0.0, $6578 = 0.0, $6579 = 0, $658 = 0, $6580 = 0, $6581 = 0, $6582 = 0, $6583 = 0, $6584 = 0.0, $6585 = 0.0, $6586 = 0.0, $6587 = 0, $6588 = 0, $6589 = 0, $659 = 0.0;
 var $6590 = 0, $6591 = 0, $6592 = 0, $6593 = 0, $6594 = 0, $6595 = 0, $6596 = 0, $6597 = 0, $6598 = 0, $6599 = 0, $66 = 0, $660 = 0.0, $6600 = 0.0, $6601 = 0.0, $6602 = 0, $6603 = 0, $6604 = 0.0, $6605 = 0.0, $6606 = 0, $6607 = 0.0;
 var $6608 = 0.0, $6609 = 0, $661 = 0, $6610 = 0, $6611 = 0, $6612 = 0, $6613 = 0.0, $6614 = 0.0, $6615 = 0, $6616 = 0, $6617 = 0.0, $6618 = 0.0, $6619 = 0, $662 = 0, $6620 = 0.0, $6621 = 0.0, $6622 = 0.0, $6623 = 0.0, $6624 = 0.0, $6625 = 0.0;
 var $6626 = 0.0, $6627 = 0.0, $6628 = 0.0, $6629 = 0.0, $663 = 0.0, $6630 = 0.0, $6631 = 0.0, $6632 = 0.0, $6633 = 0.0, $6634 = 0, $6635 = 0, $6636 = 0, $6637 = 0, $6638 = 0.0, $6639 = 0.0, $664 = 0.0, $6640 = 0.0, $6641 = 0, $6642 = 0, $6643 = 0;
 var $6644 = 0, $6645 = 0, $6646 = 0.0, $6647 = 0.0, $6648 = 0.0, $6649 = 0, $665 = 0, $6650 = 0, $6651 = 0, $6652 = 0, $6653 = 0, $6654 = 0, $6655 = 0, $6656 = 0, $6657 = 0, $6658 = 0, $6659 = 0, $666 = 0.0, $6660 = 0, $6661 = 0;
 var $6662 = 0, $6663 = 0, $6664 = 0, $6665 = 0, $6666 = 0, $6667 = 0, $6668 = 0, $6669 = 0.0, $667 = 0.0, $6670 = 0.0, $6671 = 0, $6672 = 0, $6673 = 0.0, $6674 = 0.0, $6675 = 0, $6676 = 0.0, $6677 = 0.0, $6678 = 0, $6679 = 0, $668 = 0.0;
 var $6680 = 0, $6681 = 0, $6682 = 0.0, $6683 = 0.0, $6684 = 0, $6685 = 0, $6686 = 0.0, $6687 = 0.0, $6688 = 0, $6689 = 0.0, $669 = 0.0, $6690 = 0.0, $6691 = 0, $6692 = 0, $6693 = 0, $6694 = 0, $6695 = 0.0, $6696 = 0.0, $6697 = 0, $6698 = 0;
 var $6699 = 0.0, $67 = 0, $670 = 0.0, $6700 = 0.0, $6701 = 0, $6702 = 0.0, $6703 = 0.0, $6704 = 0, $6705 = 0, $6706 = 0, $6707 = 0, $6708 = 0.0, $6709 = 0.0, $671 = 0.0, $6710 = 0, $6711 = 0, $6712 = 0.0, $6713 = 0.0, $6714 = 0, $6715 = 0.0;
 var $6716 = 0.0, $6717 = 0.0, $6718 = 0.0, $6719 = 0.0, $672 = 0.0, $6720 = 0.0, $6721 = 0.0, $6722 = 0.0, $6723 = 0.0, $6724 = 0.0, $6725 = 0.0, $6726 = 0.0, $6727 = 0.0, $6728 = 0.0, $6729 = 0.0, $673 = 0.0, $6730 = 0.0, $6731 = 0.0, $6732 = 0.0, $6733 = 0.0;
 var $6734 = 0.0, $6735 = 0, $6736 = 0, $6737 = 0, $6738 = 0, $6739 = 0.0, $674 = 0.0, $6740 = 0.0, $6741 = 0.0, $6742 = 0, $6743 = 0, $6744 = 0, $6745 = 0, $6746 = 0, $6747 = 0.0, $6748 = 0.0, $6749 = 0.0, $675 = 0.0, $6750 = 0, $6751 = 0;
 var $6752 = 0, $6753 = 0, $6754 = 0, $6755 = 0, $6756 = 0, $6757 = 0, $6758 = 0, $6759 = 0, $676 = 0.0, $6760 = 0, $6761 = 0, $6762 = 0, $6763 = 0, $6764 = 0, $6765 = 0, $6766 = 0.0, $6767 = 0.0, $6768 = 0, $6769 = 0, $677 = 0.0;
 var $6770 = 0.0, $6771 = 0.0, $6772 = 0, $6773 = 0.0, $6774 = 0.0, $6775 = 0, $6776 = 0, $6777 = 0, $6778 = 0, $6779 = 0.0, $678 = 0.0, $6780 = 0.0, $6781 = 0, $6782 = 0, $6783 = 0.0, $6784 = 0.0, $6785 = 0, $6786 = 0.0, $6787 = 0.0, $6788 = 0.0;
 var $6789 = 0.0, $679 = 0.0, $6790 = 0.0, $6791 = 0.0, $6792 = 0.0, $6793 = 0.0, $6794 = 0.0, $6795 = 0.0, $6796 = 0.0, $6797 = 0.0, $6798 = 0.0, $6799 = 0.0, $68 = 0.0, $680 = 0, $6800 = 0, $6801 = 0, $6802 = 0, $6803 = 0.0, $6804 = 0.0, $6805 = 0.0;
 var $6806 = 0, $6807 = 0, $6808 = 0, $6809 = 0, $681 = 0, $6810 = 0, $6811 = 0, $6812 = 0.0, $6813 = 0.0, $6814 = 0.0, $6815 = 0, $6816 = 0, $6817 = 0, $6818 = 0, $6819 = 0, $682 = 0, $6820 = 0, $6821 = 0, $6822 = 0, $6823 = 0;
 var $6824 = 0, $6825 = 0, $6826 = 0, $6827 = 0, $6828 = 0.0, $6829 = 0.0, $683 = 0, $6830 = 0, $6831 = 0, $6832 = 0.0, $6833 = 0.0, $6834 = 0, $6835 = 0.0, $6836 = 0.0, $6837 = 0, $6838 = 0, $6839 = 0, $684 = 0.0, $6840 = 0, $6841 = 0.0;
 var $6842 = 0.0, $6843 = 0, $6844 = 0, $6845 = 0.0, $6846 = 0.0, $6847 = 0, $6848 = 0.0, $6849 = 0.0, $685 = 0.0, $6850 = 0.0, $6851 = 0.0, $6852 = 0.0, $6853 = 0.0, $6854 = 0.0, $6855 = 0.0, $6856 = 0.0, $6857 = 0.0, $6858 = 0.0, $6859 = 0.0, $686 = 0.0;
 var $6860 = 0.0, $6861 = 0.0, $6862 = 0, $6863 = 0, $6864 = 0, $6865 = 0.0, $6866 = 0.0, $6867 = 0.0, $6868 = 0, $6869 = 0, $687 = 0, $6870 = 0, $6871 = 0, $6872 = 0, $6873 = 0, $6874 = 0.0, $6875 = 0.0, $6876 = 0.0, $6877 = 0, $6878 = 0;
 var $6879 = 0, $688 = 0, $6880 = 0, $6881 = 0, $6882 = 0, $6883 = 0, $6884 = 0, $6885 = 0, $6886 = 0, $6887 = 0, $6888 = 0, $6889 = 0, $689 = 0, $6890 = 0, $6891 = 0, $6892 = 0, $6893 = 0, $6894 = 0, $6895 = 0, $6896 = 0;
 var $6897 = 0.0, $6898 = 0.0, $6899 = 0, $69 = 0.0, $690 = 0, $6900 = 0, $6901 = 0.0, $6902 = 0.0, $6903 = 0, $6904 = 0.0, $6905 = 0.0, $6906 = 0, $6907 = 0, $6908 = 0, $6909 = 0, $691 = 0, $6910 = 0.0, $6911 = 0.0, $6912 = 0, $6913 = 0;
 var $6914 = 0.0, $6915 = 0.0, $6916 = 0, $6917 = 0.0, $6918 = 0.0, $6919 = 0, $692 = 0.0, $6920 = 0, $6921 = 0, $6922 = 0, $6923 = 0.0, $6924 = 0.0, $6925 = 0, $6926 = 0, $6927 = 0.0, $6928 = 0.0, $6929 = 0, $693 = 0.0, $6930 = 0.0, $6931 = 0.0;
 var $6932 = 0, $6933 = 0, $6934 = 0, $6935 = 0, $6936 = 0.0, $6937 = 0.0, $6938 = 0, $6939 = 0, $694 = 0.0, $6940 = 0.0, $6941 = 0.0, $6942 = 0, $6943 = 0.0, $6944 = 0.0, $6945 = 0.0, $6946 = 0.0, $6947 = 0.0, $6948 = 0.0, $6949 = 0.0, $695 = 0;
 var $6950 = 0.0, $6951 = 0.0, $6952 = 0.0, $6953 = 0.0, $6954 = 0.0, $6955 = 0.0, $6956 = 0.0, $6957 = 0.0, $6958 = 0.0, $6959 = 0.0, $696 = 0, $6960 = 0.0, $6961 = 0.0, $6962 = 0.0, $6963 = 0, $6964 = 0, $6965 = 0, $6966 = 0.0, $6967 = 0.0, $6968 = 0.0;
 var $6969 = 0, $697 = 0, $6970 = 0, $6971 = 0, $6972 = 0, $6973 = 0, $6974 = 0, $6975 = 0.0, $6976 = 0.0, $6977 = 0.0, $6978 = 0, $6979 = 0, $698 = 0, $6980 = 0, $6981 = 0, $6982 = 0, $6983 = 0, $6984 = 0, $6985 = 0, $6986 = 0;
 var $6987 = 0, $6988 = 0, $6989 = 0, $699 = 0, $6990 = 0, $6991 = 0, $6992 = 0, $6993 = 0, $6994 = 0, $6995 = 0, $6996 = 0, $6997 = 0, $6998 = 0, $6999 = 0, $70 = 0, $700 = 0, $7000 = 0, $7001 = 0, $7002 = 0, $7003 = 0;
 var $7004 = 0, $7005 = 0, $7006 = 0, $7007 = 0, $7008 = 0, $7009 = 0, $701 = 0, $7010 = 0, $7011 = 0, $7012 = 0, $7013 = 0, $7014 = 0, $7015 = 0, $7016 = 0, $7017 = 0, $7018 = 0, $7019 = 0, $702 = 0, $7020 = 0, $7021 = 0;
 var $7022 = 0, $7023 = 0, $7024 = 0, $7025 = 0, $7026 = 0, $7027 = 0, $7028 = 0, $7029 = 0, $703 = 0, $7030 = 0, $7031 = 0, $7032 = 0, $7033 = 0, $7034 = 0, $7035 = 0, $7036 = 0, $7037 = 0, $7038 = 0, $7039 = 0, $704 = 0;
 var $7040 = 0, $7041 = 0, $7042 = 0, $7043 = 0, $7044 = 0, $7045 = 0, $7046 = 0, $7047 = 0, $7048 = 0, $7049 = 0, $705 = 0, $7050 = 0, $7051 = 0, $7052 = 0, $7053 = 0, $7054 = 0, $7055 = 0, $7056 = 0, $7057 = 0, $7058 = 0;
 var $7059 = 0, $706 = 0, $7060 = 0.0, $7061 = 0.0, $7062 = 0.0, $7063 = 0.0, $7064 = 0.0, $7065 = 0.0, $7066 = 0.0, $7067 = 0.0, $7068 = 0.0, $7069 = 0.0, $707 = 0, $7070 = 0.0, $7071 = 0.0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0;
 var $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0.0, $718 = 0.0, $719 = 0, $72 = 0, $720 = 0, $721 = 0.0, $722 = 0.0, $723 = 0, $724 = 0.0, $725 = 0.0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0;
 var $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0.0, $739 = 0.0, $74 = 0, $740 = 0, $741 = 0, $742 = 0.0, $743 = 0.0, $744 = 0, $745 = 0.0, $746 = 0.0, $747 = 0.0, $748 = 0.0;
 var $749 = 0.0, $75 = 0, $750 = 0.0, $751 = 0.0, $752 = 0.0, $753 = 0.0, $754 = 0.0, $755 = 0.0, $756 = 0.0, $757 = 0.0, $758 = 0.0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0.0, $764 = 0.0, $765 = 0.0, $766 = 0;
 var $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0.0, $772 = 0.0, $773 = 0.0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0;
 var $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0;
 var $803 = 0, $804 = 0.0, $805 = 0.0, $806 = 0, $807 = 0, $808 = 0.0, $809 = 0.0, $81 = 0, $810 = 0, $811 = 0.0, $812 = 0.0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0;
 var $821 = 0, $822 = 0, $823 = 0, $824 = 0, $825 = 0.0, $826 = 0.0, $827 = 0, $828 = 0, $829 = 0.0, $83 = 0, $830 = 0.0, $831 = 0, $832 = 0.0, $833 = 0.0, $834 = 0, $835 = 0, $836 = 0, $837 = 0, $838 = 0, $839 = 0;
 var $84 = 0, $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0.0, $847 = 0.0, $848 = 0, $849 = 0, $85 = 0, $850 = 0.0, $851 = 0.0, $852 = 0, $853 = 0.0, $854 = 0.0, $855 = 0, $856 = 0, $857 = 0;
 var $858 = 0, $859 = 0, $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0.0, $868 = 0.0, $869 = 0, $87 = 0.0, $870 = 0, $871 = 0.0, $872 = 0.0, $873 = 0, $874 = 0.0, $875 = 0.0;
 var $876 = 0.0, $877 = 0.0, $878 = 0.0, $879 = 0.0, $88 = 0.0, $880 = 0.0, $881 = 0.0, $882 = 0.0, $883 = 0.0, $884 = 0.0, $885 = 0.0, $886 = 0.0, $887 = 0.0, $888 = 0.0, $889 = 0.0, $89 = 0, $890 = 0.0, $891 = 0.0, $892 = 0.0, $893 = 0.0;
 var $894 = 0, $895 = 0, $896 = 0, $897 = 0, $898 = 0.0, $899 = 0.0, $90 = 0, $900 = 0.0, $901 = 0, $902 = 0, $903 = 0, $904 = 0, $905 = 0, $906 = 0.0, $907 = 0.0, $908 = 0.0, $909 = 0, $91 = 0, $910 = 0, $911 = 0;
 var $912 = 0, $913 = 0, $914 = 0, $915 = 0, $916 = 0, $917 = 0, $918 = 0, $919 = 0, $92 = 0, $920 = 0, $921 = 0, $922 = 0, $923 = 0, $924 = 0, $925 = 0, $926 = 0, $927 = 0, $928 = 0, $929 = 0, $93 = 0;
 var $930 = 0, $931 = 0, $932 = 0, $933 = 0.0, $934 = 0.0, $935 = 0, $936 = 0, $937 = 0.0, $938 = 0.0, $939 = 0, $94 = 0, $940 = 0.0, $941 = 0.0, $942 = 0, $943 = 0, $944 = 0, $945 = 0, $946 = 0, $947 = 0, $948 = 0;
 var $949 = 0, $95 = 0, $950 = 0, $951 = 0, $952 = 0, $953 = 0, $954 = 0.0, $955 = 0.0, $956 = 0, $957 = 0, $958 = 0.0, $959 = 0.0, $96 = 0, $960 = 0, $961 = 0.0, $962 = 0.0, $963 = 0.0, $964 = 0.0, $965 = 0.0, $966 = 0.0;
 var $967 = 0.0, $968 = 0.0, $969 = 0.0, $97 = 0, $970 = 0.0, $971 = 0.0, $972 = 0.0, $973 = 0.0, $974 = 0.0, $975 = 0, $976 = 0, $977 = 0, $978 = 0.0, $979 = 0.0, $98 = 0, $980 = 0.0, $981 = 0, $982 = 0, $983 = 0, $984 = 0;
 var $985 = 0, $986 = 0, $987 = 0.0, $988 = 0.0, $989 = 0.0, $99 = 0, $990 = 0, $991 = 0, $992 = 0, $993 = 0, $994 = 0, $995 = 0, $996 = 0, $997 = 0, $998 = 0, $999 = 0, $exitcond = 0, $exitcond$i1093 = 0, $exitcond$i10932939 = 0, $exitcond$i1135 = 0;
 var $exitcond$i11352948 = 0, $exitcond$i1176 = 0, $exitcond$i11762973 = 0, $exitcond$i1242 = 0, $exitcond$i1339 = 0, $exitcond$i1451 = 0, $exitcond$i956 = 0, $exitcond$i9562931 = 0, $exitcond534$i = 0, $exitcond534$i1579 = 0, $exitcond543$i = 0, $exitcond543$i1559 = 0, $exitcond552$i = 0, $exitcond552$i1512 = 0, $exitcond560$i = 0, $exitcond560$i1078 = 0, $exitcond560$i10782941 = 0, $exitcond560$i2933 = 0, $exitcond561$i = 0, $exitcond561$i1528 = 0;
 var $exitcond563$i = 0, $exitcond563$i1072 = 0, $exitcond565$i = 0, $exitcond565$i1546 = 0, $exitcond566$i = 0, $exitcond566$i1074 = 0, $exitcond567$i = 0, $exitcond567$i1089 = 0, $exitcond568$i = 0, $exitcond568$i1052 = 0, $exitcond568$i10522943 = 0, $exitcond568$i1481$us = 0, $exitcond568$i1607$us = 0, $exitcond568$i2935 = 0, $exitcond569$i$us = 0, $exitcond569$i1609$us = 0, $exitcond571$i = 0, $exitcond571$i1617 = 0, $exitcond572$i = 0, $exitcond572$i1046 = 0;
 var $exitcond572$i1483 = 0, $exitcond572$i1621 = 0, $exitcond575$i = 0, $exitcond575$i1048 = 0, $exitcond576$i = 0, $exitcond576$i1063 = 0, $exitcond577$i = 0, $exitcond577$i2043 = 0, $exitcond577$i2937 = 0, $exitcond577$i980 = 0, $exitcond577$i9802051 = 0, $exitcond577$i9802945 = 0, $exitcond581$i = 0, $exitcond581$i991 = 0, $exitcond584$i = 0, $exitcond584$i992 = 0, $exitcond585$i = 0, $exitcond585$i1000 = 0, $exitcond586$i = 0, $exitcond586$i1014 = 0;
 var $exitcond590$i = 0, $exitcond590$i1009 = 0, $exitcond593$i = 0, $exitcond593$i1010 = 0, $exitcond594$i = 0, $exitcond594$i1037 = 0, $exitcond598$i = 0, $exitcond598$i1030 = 0, $exitcond599$i = 0, $exitcond599$i1033 = 0, $exitcond601$i$us = 0, $exitcond601$i1110$us = 0, $exitcond602$i$us = 0, $exitcond602$i1112$us = 0, $exitcond603$i$us = 0, $exitcond603$i1114$us = 0, $exitcond604$i = 0, $exitcond604$i1118 = 0, $exitcond605$i = 0, $exitcond605$i1122 = 0;
 var $exitcond606$i = 0, $exitcond606$i1126 = 0, $exitcond732$i = 0, $exitcond732$i2951 = 0, $exitcond733$i = 0, $exitcond733$i2954 = 0, $exitcond734$i = 0, $exitcond734$i2957 = 0, $exitcond735$i = 0, $exitcond736$i$us = 0, $exitcond737$i = 0, $exitcond737$i$us = 0, $exitcond738$i = 0, $exitcond739$i = 0, $exitcond740$i = 0, $exitcond740$i2960 = 0, $exitcond741$i = 0, $exitcond741$i2963 = 0, $exitcond742$i = 0, $exitcond743$i$us = 0;
 var $exitcond746$i = 0, $exitcond746$i$us = 0, $exitcond747$i = 0, $exitcond748$i = 0, $exitcond749$i = 0, $exitcond749$i2966 = 0, $exitcond750$i = 0, $exitcond750$i2075 = 0, $exitcond750$i2969 = 0, $exitcond751$i = 0, $exitcond752$i$us = 0, $exitcond755$i = 0, $exitcond755$i$us = 0, $exitcond756$i = 0, $exitcond757$i = 0, $exitcond758$i = 0, $exitcond759$i = 0, $exitcond760$i = 0, $exitcond761$i$us = 0, $exitcond764$i = 0;
 var $exitcond764$i$us = 0, $exitcond765$i = 0, $exitcond766$i = 0, $exitcond769$i = 0, $exitcond772$i$us = 0, $exitcond773$i = 0, $exitcond773$i$us = 0, $exitcond774$i = 0, $exitcond775$i$us = 0, $exitcond776$i = 0, $exitcond776$i$us = 0, $exitcond777$i = 0, $exitcond778$i = 0, $exitcond779$i = 0, $exitcond780$i = 0, $exitcond806$i = 0, $exitcond806$i2976 = 0, $exitcond807$i = 0, $exitcond807$i2980 = 0, $exitcond808$i = 0;
 var $exitcond808$i2983 = 0, $exitcond810$i = 0, $exitcond811$i$us = 0, $exitcond814$i = 0, $exitcond814$i$us = 0, $exitcond815$i = 0, $exitcond816$i = 0, $exitcond816$i1445 = 0, $exitcond816$i14453032 = 0, $exitcond817$i = 0, $exitcond817$i1433 = 0, $exitcond817$i2987 = 0, $exitcond818$i = 0, $exitcond818$i1423 = 0, $exitcond818$i14233035 = 0, $exitcond818$i2990 = 0, $exitcond819$i = 0, $exitcond819$i3001 = 0, $exitcond820$i = 0, $exitcond820$i1427 = 0;
 var $exitcond821$i = 0, $exitcond821$i1431$us = 0, $exitcond821$i3005 = 0, $exitcond822$i = 0, $exitcond823$i$us = 0, $exitcond823$i1226 = 0, $exitcond823$i1332 = 0, $exitcond823$i13323017 = 0, $exitcond824$i$us = 0, $exitcond824$i1316 = 0, $exitcond824$i1428 = 0, $exitcond824$i1428$us = 0, $exitcond825$i = 0, $exitcond825$i1442 = 0, $exitcond825$i3021 = 0, $exitcond826$i = 0, $exitcond826$i$us = 0, $exitcond826$i1440 = 0, $exitcond827$i = 0, $exitcond827$i1227 = 0;
 var $exitcond827$i1227$us = 0, $exitcond827$i1311 = 0, $exitcond827$i1413 = 0, $exitcond828$i = 0, $exitcond828$i1236 = 0, $exitcond828$i1314$us = 0, $exitcond828$i1404 = 0, $exitcond828$i14043038 = 0, $exitcond829$i = 0, $exitcond829$i1234 = 0, $exitcond829$i2994 = 0, $exitcond830$i = 0, $exitcond830$i1218 = 0, $exitcond830$i2103 = 0, $exitcond830$i2997 = 0, $exitcond831$i = 0, $exitcond831$i1312 = 0, $exitcond831$i1312$us = 0, $exitcond831$i3009 = 0, $exitcond832$i = 0;
 var $exitcond832$i1407 = 0, $exitcond833$i = 0, $exitcond833$i1411$us = 0, $exitcond834$i = 0, $exitcond834$i1297 = 0, $exitcond835$i$us = 0, $exitcond835$i1214 = 0, $exitcond835$i1288 = 0, $exitcond835$i12883025 = 0, $exitcond836$i$us = 0, $exitcond836$i1408 = 0, $exitcond836$i1408$us = 0, $exitcond837$i = 0, $exitcond838$i = 0, $exitcond838$i$us = 0, $exitcond838$i1417 = 0, $exitcond839$i = 0, $exitcond839$i1215 = 0, $exitcond839$i1215$us = 0, $exitcond839$i1292 = 0;
 var $exitcond839$i1361 = 0, $exitcond840$i = 0, $exitcond840$i1224 = 0, $exitcond840$i1295$us = 0, $exitcond840$i1357 = 0, $exitcond840$i13572212 = 0, $exitcond840$i13573041 = 0, $exitcond841$i = 0, $exitcond841$i1222 = 0, $exitcond842$i = 0, $exitcond842$i1188 = 0, $exitcond843$i = 0, $exitcond843$i1293 = 0, $exitcond843$i1293$us = 0, $exitcond843$i2140 = 0, $exitcond843$i3013 = 0, $exitcond844$i = 0, $exitcond844$i1367 = 0, $exitcond845$i = 0, $exitcond845$i1372$us = 0;
 var $exitcond846$i = 0, $exitcond846$i1257 = 0, $exitcond847$i$us = 0, $exitcond847$i1189 = 0, $exitcond847$i1255 = 0, $exitcond847$i12552178 = 0, $exitcond847$i12553029 = 0, $exitcond848$i$us = 0, $exitcond848$i1369 = 0, $exitcond848$i1369$us = 0, $exitcond849$i = 0, $exitcond850$i = 0, $exitcond850$i$us = 0, $exitcond850$i1377 = 0, $exitcond851$i = 0, $exitcond851$i1190 = 0, $exitcond851$i1190$us = 0, $exitcond851$i1259 = 0, $exitcond851$i1388 = 0, $exitcond852$i = 0;
 var $exitcond852$i1195 = 0, $exitcond852$i1262$us = 0, $exitcond852$i1380 = 0, $exitcond853$i = 0, $exitcond854$i = 0, $exitcond855$i = 0, $exitcond855$i1197 = 0, $exitcond855$i1260 = 0, $exitcond855$i1260$us = 0, $exitcond856$i = 0, $exitcond856$i1383 = 0, $exitcond857$i = 0, $exitcond857$i1386$us = 0, $exitcond858$i$us = 0, $exitcond858$i1276 = 0, $exitcond859$i = 0, $exitcond859$i$us = 0, $exitcond859$i1198 = 0, $exitcond859$i1269 = 0, $exitcond860$i$us = 0;
 var $exitcond860$i1384 = 0, $exitcond860$i1384$us = 0, $exitcond861$i$us2112 = 0, $exitcond861$i1394 = 0, $exitcond862$i$us$us = 0, $exitcond862$i1391 = 0, $exitcond863$i$us$us = 0, $exitcond863$i$us2119 = 0, $exitcond863$i1199 = 0, $exitcond863$i1199$us = 0, $exitcond863$i1271 = 0, $exitcond864$i$us = 0, $exitcond864$i1205 = 0, $exitcond864$i1274$us = 0, $exitcond865$i = 0, $exitcond865$i1203 = 0, $exitcond865$i1402 = 0, $exitcond866$i = 0, $exitcond867$i = 0, $exitcond867$i1272 = 0;
 var $exitcond867$i1272$us = 0, $exitcond868$i = 0, $exitcond868$i1280 = 0, $exitcond868$i1401$us = 0, $exitcond869$i = 0, $exitcond869$i1398 = 0, $exitcond869$i1398$us = 0, $exitcond871$i$us = 0, $exitcond871$i1459$us2220 = 0, $exitcond872$i = 0, $exitcond872$i$us = 0, $exitcond872$i1286 = 0, $exitcond872$i1461$us$us = 0, $exitcond873$i$us$us = 0, $exitcond873$i$us2227 = 0, $exitcond874$i$us2149 = 0, $exitcond874$i1462$us = 0, $exitcond875$i$us$us = 0, $exitcond875$i1285$us = 0, $exitcond875$i1463 = 0;
 var $exitcond876$i$us$us = 0, $exitcond876$i$us2157 = 0, $exitcond876$i1283 = 0, $exitcond876$i1283$us = 0, $exitcond876$i1464 = 0, $exitcond877$i$us = 0, $exitcond877$i1465 = 0, $exitcond878$i = 0, $exitcond878$i1347$us2187 = 0, $exitcond879$i = 0, $exitcond879$i1351$us$us = 0, $exitcond880$i = 0, $exitcond880$i1349$us$us = 0, $exitcond880$i1349$us2195 = 0, $exitcond881$i$us = 0, $exitcond882$i = 0, $exitcond883$i = 0, $exitcond884$i = 0, $or$cond = 0, $or$cond$i = 0;
 var $or$cond$i$i = 0, $or$cond$i$i1642 = 0, $or$cond$i$i1673 = 0, $or$cond$i$i1704 = 0, $or$cond$i$i1735 = 0, $or$cond$i$i1766 = 0, $or$cond$i$i1805 = 0, $or$cond$i$i821 = 0, $or$cond$i$i852 = 0, $or$cond$i$i898 = 0, $or$cond$i1128 = 0, $or$cond$i1140 = 0, $or$cond$i1184 = 0, $or$cond$i1251 = 0, $or$cond$i1354 = 0, $or$cond$i1466 = 0, $or$cond$i1484 = 0, $or$cond$i1633 = 0, $or$cond$i1664 = 0, $or$cond$i1695 = 0;
 var $or$cond$i1726 = 0, $or$cond$i1757 = 0, $or$cond$i1796 = 0, $or$cond$i810 = 0, $or$cond$i812 = 0, $or$cond$i843 = 0, $or$cond$i889 = 0, $or$cond$i953 = 0, $or$cond$i959 = 0, $or$cond$us$i = 0, $or$cond399$i = 0, $or$cond399$i1502 = 0, $or$cond417$i = 0, $or$cond417$i977 = 0, $or$cond579$i = 0, $or$cond613$i = 0, $or$cond622$i = 0, $or$cond628$i = 0, $or$cond630$i = 0, $or$cond786 = 0;
 var $or$cond790 = 0, $or$cond791 = 0, $or$cond792 = 0, $scevgep$i = 0, $scevgep$i1129 = 0, $scevgep$i1467 = 0, $scevgep$i1493 = 0, $scevgep$i968 = 0, $scevgep533$i = 0, $scevgep533$i1584 = 0, $scevgep537$i = 0, $scevgep537$i1494 = 0, $scevgep542$i = 0, $scevgep542$i1564 = 0, $scevgep551$i = 0, $scevgep551$i1514 = 0, $scevgep555$i = 0, $scevgep555$i1495 = 0, $scevgep560$i = 0, $scevgep560$i1533 = 0;
 var $scevgep565$i = 0, $scevgep565$i1083 = 0, $scevgep569$i = 0, $scevgep569$i969 = 0, $scevgep574$i = 0, $scevgep574$i1057 = 0, $scevgep583$i = 0, $scevgep583$i994 = 0, $scevgep587$i = 0, $scevgep587$i970 = 0, $scevgep592$i = 0, $scevgep592$i1016 = 0, $scevgep596$i = 0, $scevgep596$i1025 = 0, $scevgep597$i = 0, $scevgep597$i1031 = 0, $scevgep745$i = 0, $scevgep754$i = 0, $scevgep763$i = 0, $scevgep768$i = 0;
 var $scevgep768$i$us = 0, $scevgep770$i = 0, $scevgep770$i$us = 0, $scevgep813$i = 0, $scevgep823$i = 0, $scevgep825$i = 0, $scevgep826$i = 0, $scevgep830$i = 0, $scevgep835$i = 0, $scevgep837$i = 0, $scevgep838$i = 0, $scevgep842$i = 0, $scevgep847$i = 0, $scevgep849$i = 0, $scevgep850$i = 0, $scevgep854$i = 0, $scevgep854$i$us = 0, $scevgep854$i1263 = 0, $scevgep856$i = 0, $scevgep856$i$us = 0;
 var $scevgep859$i = 0, $scevgep862$i = 0, $scevgep864$i = 0, $scevgep864$i$us = 0, $scevgep866$i = 0, $scevgep866$i1400 = 0, $scevgep866$i1400$us = 0, $scevgep867$i = 0, $scevgep867$i$us = 0, $scevgep869$i = 0, $scevgep869$i$us = 0, $scevgep871$i = 0, $scevgep871$i$us = 0, $scevgep873$i = 0, $scevgep873$i$us = 0, $sext$us745$i$us2111 = 0, $sext585$i = 0, $sext585$i2077 = 0, $sext585$i2971 = 0, $sext587$i = 0;
 var $sext589$us643$i = 0, $sext591$i = 0, $sext591$i2084 = 0, $sext591$i2978 = 0, $sext593$i = 0, $sext595$us668$i = 0, $sext597$i = 0, $sext597$i2091 = 0, $sext597$i2985 = 0, $sext598$i = 0, $sext599$i = 0, $sext601$i = 0, $sext603$us714$i = 0, $sext605$i = 0, $sext607$i = 0, $sext609$us691$i = 0, $sext611$i = 0, $sext611$i2098 = 0, $sext611$i2992 = 0, $switch$split1022D = 0;
 var $switch$split1052D = 0, $switch$split1082D = 0, $switch$split1112D = 0, $switch$split1142D = 0, $switch$split1172D = 0, $switch$split1202D = 0, $switch$split122D = 0, $switch$split1232D = 0, $switch$split1262D = 0, $switch$split1292D = 0, $switch$split1322D = 0, $switch$split1352D = 0, $switch$split1382D = 0, $switch$split1412D = 0, $switch$split1442D = 0, $switch$split152D = 0, $switch$split182D = 0, $switch$split212D = 0, $switch$split242D = 0, $switch$split272D = 0;
 var $switch$split2D = 0, $switch$split302D = 0, $switch$split332D = 0, $switch$split362D = 0, $switch$split392D = 0, $switch$split422D = 0, $switch$split452D = 0, $switch$split482D = 0, $switch$split512D = 0, $switch$split542D = 0, $switch$split572D = 0, $switch$split602D = 0, $switch$split62D = 0, $switch$split632D = 0, $switch$split662D = 0, $switch$split692D = 0, $switch$split722D = 0, $switch$split752D = 0, $switch$split782D = 0, $switch$split812D = 0;
 var $switch$split842D = 0, $switch$split872D = 0, $switch$split902D = 0, $switch$split92D = 0, $switch$split932D = 0, $switch$split962D = 0, $switch$split992D = 0, $uglygep$i = 0, $uglygep$i1141 = 0, $uglygep$i1185 = 0, $uglygep$i1252 = 0, $uglygep$i1355 = 0, $uglygep744$i = 0, $uglygep762$i = 0, $uglygep819$i = 0, $uglygep829$i = 0, $uglygep832$i = 0, $uglygep836$i = 0, $uglygep843$i = 0, $uglygep853$i = 0;
 var $uglygep856$i = 0, $uglygep860$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 192|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(192|0);
 $12 = sp + 168|0;
 $13 = sp + 152|0;
 $14 = sp + 136|0;
 $15 = sp + 128|0;
 $16 = sp + 64|0;
 $17 = sp;
 HEAP32[$17>>2] = 4;
 $18 = ((($17)) + 4|0);
 $19 = ((($17)) + 32|0);
 ;HEAP32[$18>>2]=0|0;HEAP32[$18+4>>2]=0|0;HEAP32[$18+8>>2]=0|0;HEAP32[$18+12>>2]=0|0;HEAP32[$18+16>>2]=0|0;HEAP32[$18+20>>2]=0|0;HEAP32[$18+24>>2]=0|0;
 HEAP32[$19>>2] = 4;
 $20 = ((($17)) + 36|0);
 ;HEAP32[$20>>2]=0|0;HEAP32[$20+4>>2]=0|0;HEAP32[$20+8>>2]=0|0;HEAP32[$20+12>>2]=0|0;HEAP32[$20+16>>2]=0|0;HEAP32[$20+20>>2]=0|0;HEAP32[$20+24>>2]=0|0;
 $21 = ($7|0)==(6656);
 if ($21) {
  HEAP32[$16>>2] = 4;
  $22 = ((($16)) + 4|0);
  $23 = ((($16)) + 32|0);
  ;HEAP32[$22>>2]=0|0;HEAP32[$22+4>>2]=0|0;HEAP32[$22+8>>2]=0|0;HEAP32[$22+12>>2]=0|0;HEAP32[$22+16>>2]=0|0;HEAP32[$22+20>>2]=0|0;HEAP32[$22+24>>2]=0|0;
  HEAP32[$23>>2] = 4;
  $24 = ((($16)) + 36|0);
  ;HEAP32[$24>>2]=0|0;HEAP32[$24+4>>2]=0|0;HEAP32[$24+8>>2]=0|0;HEAP32[$24+12>>2]=0|0;HEAP32[$24+16>>2]=0|0;HEAP32[$24+20>>2]=0|0;HEAP32[$24+24>>2]=0|0;
  _glGetIntegerv(3317,($23|0));
  _glGetIntegerv(3333,($16|0));
  _glGetIntegerv(3379,($15|0));
  $25 = ($2|0)==(0);
  L3: do {
   if ($25) {
    $$010$i$i$i = -1;
   } else {
    $$0$i$i$i = 1;$$09$i$i$i = $2;
    L4: while(1) {
     switch ($$09$i$i$i|0) {
     case 1:  {
      $$010$i$i$i = $$0$i$i$i;
      break L3;
      break;
     }
     case 3:  {
      break L4;
      break;
     }
     default: {
     }
     }
     $27 = $$09$i$i$i >>> 1;
     $28 = $$0$i$i$i << 1;
     $$0$i$i$i = $28;$$09$i$i$i = $27;
    }
    $26 = $$0$i$i$i << 2;
    $$010$i$i$i = $26;
   }
  } while(0);
  $29 = HEAP32[$15>>2]|0;
  $30 = ($$010$i$i$i|0)>($29|0);
  $$$i$i = $30 ? $29 : $$010$i$i$i;
  $31 = ($3|0)==(0);
  L9: do {
   if ($31) {
    $$010$i5$i$i = -1;
   } else {
    $$0$i3$i$i = 1;$$09$i2$i$i = $3;
    L10: while(1) {
     switch ($$09$i2$i$i|0) {
     case 1:  {
      $$010$i5$i$i = $$0$i3$i$i;
      break L9;
      break;
     }
     case 3:  {
      break L10;
      break;
     }
     default: {
     }
     }
     $33 = $$09$i2$i$i >>> 1;
     $34 = $$0$i3$i$i << 1;
     $$0$i3$i$i = $34;$$09$i2$i$i = $33;
    }
    $32 = $$0$i3$i$i << 2;
    $$010$i5$i$i = $32;
   }
  } while(0);
  $35 = ($$010$i5$i$i|0)>($29|0);
  $$1$i$i = $35 ? $29 : $$010$i5$i$i;
  $36 = ($$$i$i|0)==(0);
  if ($36) {
   $$08$i$i = -1;
  } else {
   $37 = $$$i$i & 1;
   $38 = ($37|0)==(0);
   if ($38) {
    $$010$i$i = 0;$$079$i$i = $$$i$i;
    while(1) {
     $40 = $$079$i$i >>> 1;
     $41 = (($$010$i$i) + 1)|0;
     $42 = $40 & 1;
     $43 = ($42|0)==(0);
     if ($43) {
      $$010$i$i = $41;$$079$i$i = $40;
     } else {
      $$0$lcssa$i$i = $41;$$07$lcssa$i$i = $40;
      break;
     }
    }
   } else {
    $$0$lcssa$i$i = 0;$$07$lcssa$i$i = $$$i$i;
   }
   $39 = ($$07$lcssa$i$i|0)==(1);
   $$0$$i$i = $39 ? $$0$lcssa$i$i : -1;
   $$08$i$i = $$0$$i$i;
  }
  $44 = ($$1$i$i|0)==(0);
  if ($44) {
   $$08$i94$i = -1;
  } else {
   $45 = $$1$i$i & 1;
   $46 = ($45|0)==(0);
   if ($46) {
    $$010$i91$i = 0;$$079$i92$i = $$1$i$i;
    while(1) {
     $48 = $$079$i92$i >>> 1;
     $49 = (($$010$i91$i) + 1)|0;
     $50 = $48 & 1;
     $51 = ($50|0)==(0);
     if ($51) {
      $$010$i91$i = $49;$$079$i92$i = $48;
     } else {
      $$0$lcssa$i88$i = $49;$$07$lcssa$i87$i = $48;
      break;
     }
    }
   } else {
    $$0$lcssa$i88$i = 0;$$07$lcssa$i87$i = $$1$i$i;
   }
   $47 = ($$07$lcssa$i87$i|0)==(1);
   $$0$$i89$i = $47 ? $$0$lcssa$i88$i : -1;
   $$08$i94$i = $$0$$i89$i;
  }
  $52 = ($$08$i94$i|0)>($$08$i$i|0);
  $$$i = $52 ? $$08$i94$i : $$08$i$i;
  $switch$split2D = ($6|0)<(6410);
  L29: do {
   if ($switch$split2D) {
    switch ($6|0) {
    case 6407:  {
     $$0$i$i97$i = 3;
     break;
    }
    case 6408:  {
     label = 20;
     break;
    }
    default: {
     label = 21;
    }
    }
   } else {
    $switch$split512D = ($6|0)<(32992);
    if (!($switch$split512D)) {
     switch ($6|0) {
     case 32992:  {
      $$0$i$i97$i = 3;
      break L29;
      break;
     }
     case 32993:  {
      label = 20;
      break L29;
      break;
     }
     default: {
      label = 21;
      break L29;
     }
     }
    }
    switch ($6|0) {
    case 6410:  {
     break;
    }
    default: {
     label = 21;
     break L29;
    }
    }
    $$0$i$i97$i = 2;
   }
  } while(0);
  if ((label|0) == 20) {
   $$0$i$i97$i = 4;
  }
  else if ((label|0) == 21) {
   $$0$i$i97$i = 1;
  }
  $53 = (+($2|0));
  $54 = $53 * 2.0;
  $55 = (~~(($54))>>>0);
  $56 = Math_imul($55, $3)|0;
  $57 = Math_imul($56, $$0$i$i97$i)|0;
  $58 = (_malloc($57)|0);
  $59 = ($58|0)==(0|0);
  L40: do {
   if ($59) {
    $$0$i = 100902;
   } else {
    $60 = $6 | 1;
    $61 = ($60|0)==(6401);
    $62 = $61&1;
    __ZN3osgL10fill_imageEPKNS_17PixelStorageModesEiijjhPKvPt($16,$2,$3,$6,6656,$62,$11,$58);
    $switch$split62D = ($6|0)<(6410);
    L42: do {
     if ($switch$split62D) {
      switch ($6|0) {
      case 6407:  {
       $$0$i$i = 3;
       break;
      }
      case 6408:  {
       label = 25;
       break;
      }
      default: {
       label = 26;
      }
      }
     } else {
      $switch$split542D = ($6|0)<(32992);
      if (!($switch$split542D)) {
       switch ($6|0) {
       case 32992:  {
        $$0$i$i = 3;
        break L42;
        break;
       }
       case 32993:  {
        label = 25;
        break L42;
        break;
       }
       default: {
        label = 26;
        break L42;
       }
       }
      }
      switch ($6|0) {
      case 6410:  {
       break;
      }
      default: {
       label = 26;
       break L42;
      }
      }
      $$0$i$i = 2;
     }
    } while(0);
    if ((label|0) == 25) {
     $$0$i$i = 4;
    }
    else if ((label|0) == 26) {
     $$0$i$i = 1;
    }
    _glPixelStorei(3317,2);
    $63 = ($$$i|0)<(0);
    L53: do {
     if ($63) {
      $$078$lcssa$i = 0;$$lcssa$i = 0;$$lcssa122$i = $58;
     } else {
      $64 = ($6|0)==(6407);
      L55: do {
       if ($64) {
        $$0114131$us$i = $$1$i$i;$$0116130$us$i = $$$i$i;$$076138$us$i = 0;$$078137$us$i = 0;$$079136$us$i = $3;$$081135$us$i = $2;$$083134$us$i = $58;$7012 = 0;$7013 = 0;$7014 = 0;$7015 = 0;$7016 = 0;$7017 = $58;$7018 = $58;$7019 = $58;$7020 = $58;$76 = $58;
        while(1) {
         $65 = ($$081135$us$i|0)==($$0116130$us$i|0);
         $66 = ($$079136$us$i|0)==($$0114131$us$i|0);
         $or$cond$us$i = $66 & $65;
         if ($or$cond$us$i) {
          _glTexImage2D(($0|0),($$076138$us$i|0),($1|0),($$081135$us$i|0),($$079136$us$i|0),0,6407,5123,($76|0));
          $$180$us$i = $$079136$us$i;$$182$us$i = $$081135$us$i;$$184$us$i = $$083134$us$i;$$2$us$i = $$078137$us$i;$7034 = $7020;$7035 = $7019;$7036 = $7018;$7037 = $7017;$7038 = $76;$7039 = $7016;$7040 = $7015;$7041 = $7014;$7042 = $7013;$7043 = $7012;
         } else {
          $67 = ($$078137$us$i|0)==(0|0);
          if ($67) {
           $68 = (+($$0116130$us$i|0));
           $69 = $68 * 2.0;
           $70 = (~~(($69))>>>0);
           $71 = ($$0114131$us$i*3)|0;
           $72 = Math_imul($71, $70)|0;
           $73 = (_malloc($72)|0);
           $74 = ($73|0)==(0|0);
           if ($74) {
            $$lcssa121$i = $7017;
            break L55;
           } else {
            $$1$us$i = $73;$7030 = $73;$7031 = $73;$7032 = $73;$7033 = $73;$75 = $73;
           }
          } else {
           $$1$us$i = $$078137$us$i;$7030 = $7016;$7031 = $7015;$7032 = $7013;$7033 = $7012;$75 = $7014;
          }
          __ZN3osgL14scale_internalEiiiPKtiiPt($$0$i$i,$$081135$us$i,$$079136$us$i,$$083134$us$i,$$0116130$us$i,$$0114131$us$i,$$1$us$i);
          _glTexImage2D(($0|0),($$076138$us$i|0),($1|0),($$0116130$us$i|0),($$0114131$us$i|0),0,6407,5123,($75|0));
          $$180$us$i = $$0114131$us$i;$$182$us$i = $$0116130$us$i;$$184$us$i = $$1$us$i;$$2$us$i = $$083134$us$i;$7034 = $7030;$7035 = $7031;$7036 = $75;$7037 = $7032;$7038 = $7033;$7039 = $7020;$7040 = $7019;$7041 = $7018;$7042 = $7017;$7043 = $76;
         }
         $77 = ($$0116130$us$i|0)>(1);
         $78 = $77&1;
         $$1117$us$i = $$0116130$us$i >>> $78;
         $79 = ($$0114131$us$i|0)>(1);
         $80 = $79&1;
         $$1115$us$i = $$0114131$us$i >>> $80;
         $81 = (($$076138$us$i) + 1)|0;
         $82 = ($$076138$us$i|0)<($$$i|0);
         if ($82) {
          $$0114131$us$i = $$1115$us$i;$$0116130$us$i = $$1117$us$i;$$076138$us$i = $81;$$078137$us$i = $$2$us$i;$$079136$us$i = $$180$us$i;$$081135$us$i = $$182$us$i;$$083134$us$i = $$184$us$i;$7012 = $7043;$7013 = $7042;$7014 = $7041;$7015 = $7040;$7016 = $7039;$7017 = $7037;$7018 = $7036;$7019 = $7035;$7020 = $7034;$76 = $7038;
         } else {
          $$078$lcssa$i = $$2$us$i;$$lcssa$i = $7040;$$lcssa122$i = $7034;
          break L53;
         }
        }
       } else {
        $$0114131$i = $$1$i$i;$$0116130$i = $$$i$i;$$076138$i = 0;$$078137$i = 0;$$079136$i = $3;$$081135$i = $2;$$083134$i = $58;$7021 = 0;$7022 = 0;$7023 = 0;$7024 = 0;$7025 = 0;$7026 = $58;$7027 = $58;$7028 = $58;$7029 = $58;$85 = $58;
        while(1) {
         $83 = ($$081135$i|0)==($$0116130$i|0);
         $84 = ($$079136$i|0)==($$0114131$i|0);
         $or$cond$i = $84 & $83;
         if ($or$cond$i) {
          _glTexImage2D(($0|0),($$076138$i|0),($1|0),($$081135$i|0),($$079136$i|0),0,($6|0),5123,($85|0));
          $$180$i = $$079136$i;$$182$i = $$081135$i;$$184$i = $$083134$i;$$2$i = $$078137$i;$7044 = $7029;$7045 = $7028;$7046 = $7027;$7047 = $7026;$7048 = $85;$7049 = $7025;$7050 = $7024;$7051 = $7023;$7052 = $7022;$7053 = $7021;
         } else {
          $86 = ($$078137$i|0)==(0|0);
          if ($86) {
           $switch$split92D = ($6|0)<(6410);
           L72: do {
            if ($switch$split92D) {
             switch ($6|0) {
             case 6407:  {
              $$0$i$i96$i = 3;
              break;
             }
             case 6408:  {
              label = 40;
              break;
             }
             default: {
              label = 41;
             }
             }
            } else {
             $switch$split572D = ($6|0)<(32992);
             if (!($switch$split572D)) {
              switch ($6|0) {
              case 32992:  {
               $$0$i$i96$i = 3;
               break L72;
               break;
              }
              case 32993:  {
               label = 40;
               break L72;
               break;
              }
              default: {
               label = 41;
               break L72;
              }
              }
             }
             switch ($6|0) {
             case 6410:  {
              break;
             }
             default: {
              label = 41;
              break L72;
             }
             }
             $$0$i$i96$i = 2;
            }
           } while(0);
           if ((label|0) == 40) {
            label = 0;
            $$0$i$i96$i = 4;
           }
           else if ((label|0) == 41) {
            label = 0;
            $$0$i$i96$i = 1;
           }
           $87 = (+($$0116130$i|0));
           $88 = $87 * 2.0;
           $89 = (~~(($88))>>>0);
           $90 = Math_imul($89, $$0114131$i)|0;
           $91 = Math_imul($90, $$0$i$i96$i)|0;
           $92 = (_malloc($91)|0);
           $93 = ($92|0)==(0|0);
           if ($93) {
            $$lcssa121$i = $7026;
            break L55;
           } else {
            $$1$i = $92;$7054 = $92;$7055 = $92;$7056 = $92;$7057 = $92;$95 = $92;
           }
          } else {
           $$1$i = $$078137$i;$7054 = $7025;$7055 = $7024;$7056 = $7022;$7057 = $7021;$95 = $7023;
          }
          __ZN3osgL14scale_internalEiiiPKtiiPt($$0$i$i,$$081135$i,$$079136$i,$$083134$i,$$0116130$i,$$0114131$i,$$1$i);
          _glTexImage2D(($0|0),($$076138$i|0),($1|0),($$0116130$i|0),($$0114131$i|0),0,($6|0),5123,($95|0));
          $$180$i = $$0114131$i;$$182$i = $$0116130$i;$$184$i = $$1$i;$$2$i = $$083134$i;$7044 = $7054;$7045 = $7055;$7046 = $95;$7047 = $7056;$7048 = $7057;$7049 = $7029;$7050 = $7028;$7051 = $7027;$7052 = $7026;$7053 = $85;
         }
         $96 = ($$0116130$i|0)>(1);
         $97 = $96&1;
         $$1117$i = $$0116130$i >>> $97;
         $98 = ($$0114131$i|0)>(1);
         $99 = $98&1;
         $$1115$i = $$0114131$i >>> $99;
         $100 = (($$076138$i) + 1)|0;
         $101 = ($$076138$i|0)<($$$i|0);
         if ($101) {
          $$0114131$i = $$1115$i;$$0116130$i = $$1117$i;$$076138$i = $100;$$078137$i = $$2$i;$$079136$i = $$180$i;$$081135$i = $$182$i;$$083134$i = $$184$i;$7021 = $7053;$7022 = $7052;$7023 = $7051;$7024 = $7050;$7025 = $7049;$7026 = $7047;$7027 = $7046;$7028 = $7045;$7029 = $7044;$85 = $7048;
         } else {
          $$078$lcssa$i = $$2$i;$$lcssa$i = $7050;$$lcssa122$i = $7044;
          break L53;
         }
        }
       }
      } while(0);
      $94 = HEAP32[$23>>2]|0;
      _glPixelStorei(3317,($94|0));
      _free($$lcssa121$i);
      $$0$i = 100902;
      break L40;
     }
    } while(0);
    $102 = HEAP32[$23>>2]|0;
    _glPixelStorei(3317,($102|0));
    _free($$lcssa122$i);
    $103 = ($$078$lcssa$i|0)==(0|0);
    if ($103) {
     $$0$i = 0;
    } else {
     _free($$lcssa$i);
     $$0$i = 0;
    }
   }
  } while(0);
  $$4 = $$0$i;
  STACKTOP = sp;return ($$4|0);
 }
 $104 = ($4|0)==(0);
 if ($104) {
  $$08$i = -1;
 } else {
  $105 = $4 & 1;
  $106 = ($105|0)==(0);
  if ($106) {
   $$010$i = 0;$$079$i = $4;
   while(1) {
    $108 = $$079$i >>> 1;
    $109 = (($$010$i) + 1)|0;
    $110 = $108 & 1;
    $111 = ($110|0)==(0);
    if ($111) {
     $$010$i = $109;$$079$i = $108;
    } else {
     $$0$lcssa$i = $109;$$07$lcssa$i = $108;
     break;
    }
   }
  } else {
   $$0$lcssa$i = 0;$$07$lcssa$i = $4;
  }
  $107 = ($$07$lcssa$i|0)==(1);
  $$0$$i = $107 ? $$0$lcssa$i : -1;
  $$08$i = $$0$$i;
 }
 $112 = ($5|0)==(0);
 if ($112) {
  $$08$i803 = -1;
 } else {
  $113 = $5 & 1;
  $114 = ($113|0)==(0);
  if ($114) {
   $$010$i800 = 0;$$079$i801 = $5;
   while(1) {
    $116 = $$079$i801 >>> 1;
    $117 = (($$010$i800) + 1)|0;
    $118 = $116 & 1;
    $119 = ($118|0)==(0);
    if ($119) {
     $$010$i800 = $117;$$079$i801 = $116;
    } else {
     $$0$lcssa$i797 = $117;$$07$lcssa$i796 = $116;
     break;
    }
   }
  } else {
   $$0$lcssa$i797 = 0;$$07$lcssa$i796 = $5;
  }
  $115 = ($$07$lcssa$i796|0)==(1);
  $$0$$i798 = $115 ? $$0$lcssa$i797 : -1;
  $$08$i803 = $$0$$i798;
 }
 $120 = ($$08$i803|0)>($$08$i|0);
 $$ = $120 ? $$08$i803 : $$08$i;
 $121 = (($$) + ($8))|0;
 _glGetIntegerv(3317,($19|0));
 _glGetIntegerv(3333,($17|0));
 $122 = ((($17)) + 52|0);
 $123 = HEAP32[$122>>2]|0;
 L105: do {
  switch ($7|0) {
  case 32818: case 32819: case 32820: case 32821: case 32822: case 33634: case 33635: case 33636: case 33637: case 33638: case 33639: case 33640:  {
   $$0$i805 = 1;
   break;
  }
  default: {
   $switch$split122D = ($6|0)<(6410);
   L107: do {
    if ($switch$split122D) {
     switch ($6|0) {
     case 6407:  {
      $$0$i805 = 3;
      break L105;
      break;
     }
     case 6408:  {
      label = 60;
      break;
     }
     default: {
      label = 61;
     }
     }
    } else {
     $switch$split602D = ($6|0)<(32992);
     if (!($switch$split602D)) {
      switch ($6|0) {
      case 32992:  {
       $$0$i805 = 3;
       break L105;
       break;
      }
      case 32993:  {
       label = 60;
       break L107;
       break;
      }
      default: {
       label = 61;
       break L107;
      }
      }
     }
     switch ($6|0) {
     case 6410:  {
      break;
     }
     default: {
      label = 61;
      break L107;
     }
     }
     $$0$i805 = 2;
     break L105;
    }
   } while(0);
   if ((label|0) == 60) {
    $$0$i805 = 4;
    break L105;
   }
   else if ((label|0) == 61) {
    $$0$i805 = 1;
    break L105;
   }
  }
  }
 } while(0);
 $124 = HEAP32[$20>>2]|0;
 $125 = ($124|0)>(0);
 $$0784 = $125 ? $124 : $2;
 $switch$split152D = ($7|0)<(32820);
 L118: do {
  if ($switch$split152D) {
   $switch$split632D = ($7|0)<(5125);
   if ($switch$split632D) {
    switch ($7|0) {
    case 5123:  {
     $$0$i806 = 2;
     break L118;
     break;
    }
    case 5122:  {
     $$0$i806 = 2;
     break L118;
     break;
    }
    case 5121:  {
     $$0$i806 = 1;
     break L118;
     break;
    }
    case 5120:  {
     $$0$i806 = 1;
     break L118;
     break;
    }
    case 5124:  {
     $$0$i806 = 4;
     break L118;
     break;
    }
    default: {
     label = 73;
     break L118;
    }
    }
   }
   $switch$split992D = ($7|0)<(6656);
   if ($switch$split992D) {
    switch ($7|0) {
    case 5125:  {
     $$0$i806 = 4;
     break L118;
     break;
    }
    case 5126:  {
     $$0$i806 = 4;
     break L118;
     break;
    }
    default: {
     label = 73;
     break L118;
    }
    }
   } else {
    $switch$split1232D = ($7|0)<(32818);
    if ($switch$split1232D) {
     switch ($7|0) {
     case 6656:  {
      $$0$i806 = 0;
      break L118;
      break;
     }
     default: {
      label = 73;
      break L118;
     }
     }
    } else {
     switch ($7|0) {
     case 32818:  {
      label = 70;
      break L118;
      break;
     }
     case 32819:  {
      label = 71;
      break L118;
      break;
     }
     default: {
      label = 73;
      break L118;
     }
     }
    }
   }
  } else {
   switch ($7|0) {
   case 33634:  {
    label = 70;
    break L118;
    break;
   }
   case 33638: case 32820: case 33637: case 33636: case 33635:  {
    label = 71;
    break L118;
    break;
   }
   case 33640: case 32822: case 33639: case 32821:  {
    break;
   }
   default: {
    label = 73;
    break L118;
   }
   }
   $$0$i806 = 4;
  }
 } while(0);
 if ((label|0) == 70) {
  $$0$i806 = 1;
 }
 else if ((label|0) == 71) {
  $$0$i806 = 2;
 }
 else if ((label|0) == 73) {
  $$0$i806 = 4;
 }
 $126 = Math_imul($$0$i806, $$0$i805)|0;
 $127 = ($$0$i806|0)==(1);
 $$785 = $127 ? 0 : $123;
 $128 = Math_imul($126, $$0784)|0;
 $129 = HEAP32[$19>>2]|0;
 $130 = (($128|0) % ($129|0))&-1;
 $131 = ($130|0)==(0);
 $132 = (($129) - ($130))|0;
 $133 = $131 ? 0 : $132;
 $$0778 = (($133) + ($128))|0;
 $134 = ((($17)) + 40|0);
 $135 = HEAP32[$134>>2]|0;
 $136 = Math_imul($$0778, $135)|0;
 $137 = (($11) + ($136)|0);
 $138 = ((($17)) + 44|0);
 $139 = HEAP32[$138>>2]|0;
 $140 = Math_imul($139, $126)|0;
 $141 = (($137) + ($140)|0);
 $142 = ($2|0)==($4|0);
 $143 = ($3|0)==($5|0);
 $or$cond = $142 & $143;
 do {
  if ($or$cond) {
   $144 = ($9|0)>($8|0);
   $145 = ($8|0)>($10|0);
   $or$cond786 = $144 | $145;
   if (!($or$cond786)) {
    _glTexImage2D(($0|0),($8|0),($1|0),($4|0),($5|0),0,($6|0),($7|0),($141|0));
   }
   $146 = ($121|0)==(0);
   if ($146) {
    $147 = HEAP32[$19>>2]|0;
    _glPixelStorei(3317,($147|0));
    $$4 = 0;
    STACKTOP = sp;return ($$4|0);
   }
   $148 = (($4|0) / 2)&-1;
   $149 = (($5|0) / 2)&-1;
   $150 = ($4|0)<(2);
   $$787 = $150 ? 1 : $148;
   $151 = ($5|0)<(2);
   $$0769 = $151 ? 1 : $149;
   L154: do {
    switch ($7|0) {
    case 32818: case 32819: case 32820: case 32821: case 32822: case 33634: case 33635: case 33636: case 33637: case 33638: case 33639: case 33640:  {
     $$0$i14$i = 1;
     break;
    }
    default: {
     $switch$split182D = ($6|0)<(6410);
     L156: do {
      if ($switch$split182D) {
       switch ($6|0) {
       case 6407:  {
        $$0$i14$i = 3;
        break L154;
        break;
       }
       case 6408:  {
        label = 82;
        break;
       }
       default: {
        label = 83;
       }
       }
      } else {
       $switch$split662D = ($6|0)<(32992);
       if (!($switch$split662D)) {
        switch ($6|0) {
        case 32992:  {
         $$0$i14$i = 3;
         break L154;
         break;
        }
        case 32993:  {
         label = 82;
         break L156;
         break;
        }
        default: {
         label = 83;
         break L156;
        }
        }
       }
       switch ($6|0) {
       case 6410:  {
        break;
       }
       default: {
        label = 83;
        break L156;
       }
       }
       $$0$i14$i = 2;
       break L154;
      }
     } while(0);
     if ((label|0) == 82) {
      $$0$i14$i = 4;
      break L154;
     }
     else if ((label|0) == 83) {
      $$0$i14$i = 1;
      break L154;
     }
    }
    }
   } while(0);
   $switch$split212D = ($7|0)<(32820);
   L167: do {
    if ($switch$split212D) {
     $switch$split692D = ($7|0)<(5125);
     L169: do {
      if ($switch$split692D) {
       switch ($7|0) {
       case 5122: case 5123:  {
        $$0$i12$i$ph = 2.0;
        break L169;
        break;
       }
       case 5121:  {
        $$0$i12$i$ph = 1.0;
        break L169;
        break;
       }
       case 5120:  {
        $$0$i12$i$ph = 1.0;
        break L169;
        break;
       }
       case 5124:  {
        $$0$i12$i$ph = 4.0;
        break L169;
        break;
       }
       default: {
        label = 92;
        break L167;
       }
       }
      } else {
       $switch$split1022D = ($7|0)<(6656);
       if ($switch$split1022D) {
        switch ($7|0) {
        case 5125:  {
         $$0$i12$i$ph = 4.0;
         break L169;
         break;
        }
        case 5126:  {
         $$0$i12$i$ph = 4.0;
         break L169;
         break;
        }
        default: {
         label = 92;
         break L167;
        }
        }
       }
       $switch$split1262D = ($7|0)<(32818);
       if (!($switch$split1262D)) {
        switch ($7|0) {
        case 32818:  {
         $$0$i12$i = 1.0;
         label = 94;
         break L167;
         break;
        }
        case 32819:  {
         label = 90;
         break L167;
         break;
        }
        default: {
         label = 92;
         break L167;
        }
        }
       }
       switch ($7|0) {
       case 6656:  {
        $$4 = 100900;
        break;
       }
       default: {
        label = 92;
        break L167;
       }
       }
       STACKTOP = sp;return ($$4|0);
      }
     } while(0);
     $152 = (+($$787|0));
     $153 = $152 * $$0$i12$i$ph;
     $154 = (~~(($153))>>>0);
     $155 = Math_imul($$0$i14$i, $$0769)|0;
     $156 = Math_imul($155, $154)|0;
     $162 = $156;
    } else {
     switch ($7|0) {
     case 33634:  {
      $$0$i12$i = 1.0;
      label = 94;
      break L167;
      break;
     }
     case 33638: case 32820: case 33637: case 33636: case 33635:  {
      label = 90;
      break L167;
      break;
     }
     case 33640: case 32822: case 33639: case 32821:  {
      break;
     }
     default: {
      label = 92;
      break L167;
     }
     }
     $$0$i12$i = 4.0;
     label = 94;
    }
   } while(0);
   if ((label|0) == 90) {
    $$0$i12$i = 2.0;
    label = 94;
   }
   else if ((label|0) == 92) {
    $$0$i12$i = 4.0;
    label = 94;
   }
   L192: do {
    if ((label|0) == 94) {
     $157 = (+($$787|0));
     $158 = $157 * $$0$i12$i;
     $159 = (~~(($158))>>>0);
     $160 = Math_imul($$0$i14$i, $$0769)|0;
     $161 = Math_imul($160, $159)|0;
     switch ($7|0) {
     case 32819: case 33636: case 33635: case 33634: case 32818: case 33640: case 32822: case 33639: case 32821: case 33638: case 32820: case 33637:  {
      $162 = $161;
      break L192;
      break;
     }
     default: {
      $$4 = 100900;
     }
     }
     STACKTOP = sp;return ($$4|0);
    }
   } while(0);
   $163 = (_malloc($162)|0);
   $164 = ($163|0)==(0|0);
   if ($164) {
    $165 = HEAP32[$19>>2]|0;
    _glPixelStorei(3317,($165|0));
    $$4 = 100902;
    STACKTOP = sp;return ($$4|0);
   }
   $switch$split242D = ($7|0)<(32820);
   L200: do {
    if ($switch$split242D) {
     $switch$split722D = ($7|0)<(5124);
     L202: do {
      if ($switch$split722D) {
       switch ($7|0) {
       case 5121:  {
        __ZN3osgL16halveImage_ubyteEijjPKhPhiii($$0$i805,$4,$5,$141,$163,$$0$i806,$$0778,$126);
        break L202;
        break;
       }
       case 5120:  {
        __ZN3osgL15halveImage_byteEijjPKaPaiii($$0$i805,$4,$5,$141,$163,$$0$i806,$$0778,$126);
        break L202;
        break;
       }
       case 5123:  {
        __ZN3osgL17halveImage_ushortEijjPKtPtiiii($$0$i805,$4,$5,$141,$163,$$0$i806,$$0778,$126,$$785);
        break L202;
        break;
       }
       case 5122:  {
        __ZN3osgL16halveImage_shortEijjPKsPsiiii($$0$i805,$4,$5,$141,$163,$$0$i806,$$0778,$126,$$785);
        break L202;
        break;
       }
       default: {
        label = 217;
        break L200;
       }
       }
      } else {
       $switch$split1052D = ($7|0)<(5126);
       if ($switch$split1052D) {
        switch ($7|0) {
        case 5125:  {
         __ZN3osgL15halveImage_uintEijjPKjPjiiii($$0$i805,$4,$5,$141,$163,$$0$i806,$$0778,$126,$$785);
         break L202;
         break;
        }
        case 5124:  {
         __ZN3osgL14halveImage_intEijjPKiPiiiii($$0$i805,$4,$5,$141,$163,$$0$i806,$$0778,$126,$$785);
         break L202;
         break;
        }
        default: {
         label = 217;
         break L200;
        }
        }
       }
       $switch$split1292D = ($7|0)<(32818);
       if ($switch$split1292D) {
        switch ($7|0) {
        case 5126:  {
         break;
        }
        default: {
         label = 217;
         break L200;
        }
        }
        __ZN3osgL16halveImage_floatEijjPKfPfiiii($$0$i805,$4,$5,$141,$163,$$0$i806,$$0778,$126,$$785);
        break;
       }
       switch ($7|0) {
       case 32818:  {
        break;
       }
       case 32819:  {
        __ZN3osgL21halveImagePackedPixelEiPFviPKvPfEPFvPKfiPvEiiS1_S7_iii(4,4007,4008,$4,$5,$141,$163,$$0$i806,$$0778,$$785);
        label = 215;
        break L200;
        break;
       }
       default: {
        label = 217;
        break L200;
       }
       }
       $166 = ($4|0)==(1);
       $167 = ($5|0)==(1);
       $or$cond$i810 = $166 | $167;
       if (!($or$cond$i810)) {
        $292 = Math_imul($$0$i806, $4)|0;
        $293 = (($$0778) - ($292))|0;
        $294 = ($5|0)>(1);
        if (!($294)) {
         label = 215;
         break L200;
        }
        $295 = ($4|0)>(1);
        $296 = $$0$i806 << 1;
        if ($295) {
         $$07999$us$i = 0;$$08098$us$i = 0;$$08197$us$i = $141;
        } else {
         label = 215;
         break L200;
        }
        while(1) {
         $$08391$us$us$i = 0;$$18292$us$us$i = $$08197$us$i;$$193$us$us$i = $$07999$us$i;
         while(1) {
          $302 = HEAP8[$$18292$us$us$i>>0]|0;
          $303 = $302&255;
          $304 = $303 >>> 5;
          $305 = (+($304|0));
          $306 = $305 / 7.0;
          $307 = $303 >>> 2;
          $308 = $307 & 7;
          $309 = (+($308|0));
          $310 = $309 / 7.0;
          $311 = $303 & 3;
          $312 = (+($311|0));
          $313 = $312 / 3.0;
          $314 = (($$18292$us$us$i) + ($$0$i806)|0);
          $315 = HEAP8[$314>>0]|0;
          $316 = $315&255;
          $317 = $316 >>> 5;
          $318 = (+($317|0));
          $319 = $318 / 7.0;
          $320 = $316 >>> 2;
          $321 = $320 & 7;
          $322 = (+($321|0));
          $323 = $322 / 7.0;
          $324 = $316 & 3;
          $325 = (+($324|0));
          $326 = $325 / 3.0;
          $327 = (($$18292$us$us$i) + ($$0778)|0);
          $328 = HEAP8[$327>>0]|0;
          $329 = $328&255;
          $330 = $329 >>> 5;
          $331 = (+($330|0));
          $332 = $331 / 7.0;
          $333 = $329 >>> 2;
          $334 = $333 & 7;
          $335 = (+($334|0));
          $336 = $335 / 7.0;
          $337 = $329 & 3;
          $338 = (+($337|0));
          $339 = $338 / 3.0;
          $340 = (($327) + ($$0$i806)|0);
          $341 = HEAP8[$340>>0]|0;
          $342 = $341&255;
          $343 = $342 >>> 5;
          $344 = (+($343|0));
          $345 = $344 / 7.0;
          $346 = $342 >>> 2;
          $347 = $346 & 7;
          $348 = (+($347|0));
          $349 = $348 / 7.0;
          $350 = $342 & 3;
          $351 = (+($350|0));
          $352 = $351 / 3.0;
          $353 = $306 + 0.0;
          $354 = $353 + $319;
          $355 = $354 + $332;
          $356 = $355 + $345;
          $357 = $356 * 0.25;
          $358 = $310 + 0.0;
          $359 = $358 + $323;
          $360 = $359 + $336;
          $361 = $360 + $349;
          $362 = $361 * 0.25;
          $363 = $313 + 0.0;
          $364 = $363 + $326;
          $365 = $364 + $339;
          $366 = $365 + $352;
          $367 = $366 * 0.25;
          $368 = $357 * 7.0;
          $369 = $368;
          $370 = $369 + 0.5;
          $371 = (~~(($370))&255);
          $372 = $371&255;
          $373 = $372 << 5;
          $374 = (($163) + ($$193$us$us$i)|0);
          $375 = $362 * 7.0;
          $376 = $375;
          $377 = $376 + 0.5;
          $378 = (~~(($377))&255);
          $379 = $378&255;
          $380 = $379 << 2;
          $381 = $380 & 28;
          $382 = $381 | $373;
          $383 = $367 * 3.0;
          $384 = $383;
          $385 = $384 + 0.5;
          $386 = (~~(($385))&255);
          $387 = $386 & 3;
          $388 = $387&255;
          $389 = $382 | $388;
          $390 = $389&255;
          HEAP8[$374>>0] = $390;
          $391 = (($$193$us$us$i) + 1)|0;
          $298 = (($$18292$us$us$i) + ($296)|0);
          $392 = (($$08391$us$us$i) + 1)|0;
          $393 = ($392|0)<($148|0);
          if ($393) {
           $$08391$us$us$i = $392;$$18292$us$us$i = $298;$$193$us$us$i = $391;
          } else {
           break;
          }
         }
         $297 = (($298) + ($293)|0);
         $299 = (($297) + ($$0778)|0);
         $300 = (($$08098$us$i) + 1)|0;
         $301 = ($300|0)<($149|0);
         if ($301) {
          $$07999$us$i = $391;$$08098$us$i = $300;$$08197$us$i = $299;
         } else {
          label = 217;
          break L200;
         }
        }
       }
       if ($167) {
        $168 = ($4|0)>(1);
        if (!($168)) {
         label = 215;
         break L200;
        }
        $169 = $$0$i806 << 1;
        $$088100$us$i$i = 0;$$09098$us$i$i = $141;
        while(1) {
         $170 = HEAP8[$$09098$us$i$i>>0]|0;
         $171 = $170&255;
         $172 = $171 >>> 5;
         $173 = (+($172|0));
         $174 = $173 / 7.0;
         $175 = $171 >>> 2;
         $176 = $175 & 7;
         $177 = (+($176|0));
         $178 = $177 / 7.0;
         $179 = $171 & 3;
         $180 = (+($179|0));
         $181 = $180 / 3.0;
         $182 = (($$09098$us$i$i) + ($$0$i806)|0);
         $183 = HEAP8[$182>>0]|0;
         $184 = $183&255;
         $185 = $184 >>> 5;
         $186 = (+($185|0));
         $187 = $186 / 7.0;
         $188 = $184 >>> 2;
         $189 = $188 & 7;
         $190 = (+($189|0));
         $191 = $190 / 7.0;
         $192 = $184 & 3;
         $193 = (+($192|0));
         $194 = $193 / 3.0;
         $195 = $174 + 0.0;
         $196 = $195 + $187;
         $197 = $196 * 0.5;
         $198 = $178 + 0.0;
         $199 = $198 + $191;
         $200 = $199 * 0.5;
         $201 = $181 + 0.0;
         $202 = $201 + $194;
         $203 = $202 * 0.5;
         $204 = $197 * 7.0;
         $205 = $204;
         $206 = $205 + 0.5;
         $207 = (~~(($206))&255);
         $208 = $207&255;
         $209 = $208 << 5;
         $210 = (($163) + ($$088100$us$i$i)|0);
         $211 = $200 * 7.0;
         $212 = $211;
         $213 = $212 + 0.5;
         $214 = (~~(($213))&255);
         $215 = $214&255;
         $216 = $215 << 2;
         $217 = $216 & 28;
         $218 = $217 | $209;
         $219 = $203 * 3.0;
         $220 = $219;
         $221 = $220 + 0.5;
         $222 = (~~(($221))&255);
         $223 = $222 & 3;
         $224 = $223&255;
         $225 = $218 | $224;
         $226 = $225&255;
         HEAP8[$210>>0] = $226;
         $227 = (($$088100$us$i$i) + 1)|0;
         $228 = (($$09098$us$i$i) + ($169)|0);
         $229 = ($227|0)<($148|0);
         if ($229) {
          $$088100$us$i$i = $227;$$09098$us$i$i = $228;
         } else {
          label = 217;
          break L200;
         }
        }
       } else {
        $230 = ($5|0)>(1);
        $or$cond$i$i = $166 & $230;
        if (!($or$cond$i$i)) {
         label = 215;
         break L200;
        }
        $231 = $$0778 << 1;
        $$085110$us$i$i = 0;$$191108$us$i$i = $141;
        while(1) {
         $232 = HEAP8[$$191108$us$i$i>>0]|0;
         $233 = $232&255;
         $234 = $233 >>> 5;
         $235 = (+($234|0));
         $236 = $235 / 7.0;
         $237 = $233 >>> 2;
         $238 = $237 & 7;
         $239 = (+($238|0));
         $240 = $239 / 7.0;
         $241 = $233 & 3;
         $242 = (+($241|0));
         $243 = $242 / 3.0;
         $244 = (($$191108$us$i$i) + ($$0778)|0);
         $245 = HEAP8[$244>>0]|0;
         $246 = $245&255;
         $247 = $246 >>> 5;
         $248 = (+($247|0));
         $249 = $248 / 7.0;
         $250 = $246 >>> 2;
         $251 = $250 & 7;
         $252 = (+($251|0));
         $253 = $252 / 7.0;
         $254 = $246 & 3;
         $255 = (+($254|0));
         $256 = $255 / 3.0;
         $257 = $236 + 0.0;
         $258 = $257 + $249;
         $259 = $258 * 0.5;
         $260 = $240 + 0.0;
         $261 = $260 + $253;
         $262 = $261 * 0.5;
         $263 = $243 + 0.0;
         $264 = $263 + $256;
         $265 = $264 * 0.5;
         $266 = $259 * 7.0;
         $267 = $266;
         $268 = $267 + 0.5;
         $269 = (~~(($268))&255);
         $270 = $269&255;
         $271 = $270 << 5;
         $272 = (($163) + ($$085110$us$i$i)|0);
         $273 = $262 * 7.0;
         $274 = $273;
         $275 = $274 + 0.5;
         $276 = (~~(($275))&255);
         $277 = $276&255;
         $278 = $277 << 2;
         $279 = $278 & 28;
         $280 = $279 | $271;
         $281 = $265 * 3.0;
         $282 = $281;
         $283 = $282 + 0.5;
         $284 = (~~(($283))&255);
         $285 = $284 & 3;
         $286 = $285&255;
         $287 = $280 | $286;
         $288 = $287&255;
         HEAP8[$272>>0] = $288;
         $289 = (($$085110$us$i$i) + 1)|0;
         $290 = (($$191108$us$i$i) + ($231)|0);
         $291 = ($289|0)<($149|0);
         if ($291) {
          $$085110$us$i$i = $289;$$191108$us$i$i = $290;
         } else {
          label = 217;
          break L200;
         }
        }
       }
      }
     } while(0);
     $1213 = Math_imul($126, $$787)|0;
     $7059 = $1213;
     label = 218;
    } else {
     do {
      switch ($7|0) {
      case 33634:  {
       $394 = ($4|0)==(1);
       $395 = ($5|0)==(1);
       $or$cond$i812 = $394 | $395;
       if (!($or$cond$i812)) {
        $520 = Math_imul($$0$i806, $4)|0;
        $521 = (($$0778) - ($520))|0;
        $522 = ($5|0)>(1);
        if (!($522)) {
         label = 215;
         break L200;
        }
        $523 = ($4|0)>(1);
        $524 = $$0$i806 << 1;
        if ($523) {
         $$07999$us$i830 = 0;$$08098$us$i831 = 0;$$08197$us$i832 = $141;
        } else {
         label = 215;
         break L200;
        }
        while(1) {
         $$08391$us$us$i837 = 0;$$18292$us$us$i836 = $$08197$us$i832;$$193$us$us$i835 = $$07999$us$i830;
         while(1) {
          $530 = HEAP8[$$18292$us$us$i836>>0]|0;
          $531 = $530&255;
          $532 = $531 & 7;
          $533 = (+($532|0));
          $534 = $533 / 7.0;
          $535 = $531 >>> 3;
          $536 = $535 & 7;
          $537 = (+($536|0));
          $538 = $537 / 7.0;
          $539 = $531 >>> 6;
          $540 = (+($539|0));
          $541 = $540 / 3.0;
          $542 = (($$18292$us$us$i836) + ($$0$i806)|0);
          $543 = HEAP8[$542>>0]|0;
          $544 = $543&255;
          $545 = $544 & 7;
          $546 = (+($545|0));
          $547 = $546 / 7.0;
          $548 = $544 >>> 3;
          $549 = $548 & 7;
          $550 = (+($549|0));
          $551 = $550 / 7.0;
          $552 = $544 >>> 6;
          $553 = (+($552|0));
          $554 = $553 / 3.0;
          $555 = (($$18292$us$us$i836) + ($$0778)|0);
          $556 = HEAP8[$555>>0]|0;
          $557 = $556&255;
          $558 = $557 & 7;
          $559 = (+($558|0));
          $560 = $559 / 7.0;
          $561 = $557 >>> 3;
          $562 = $561 & 7;
          $563 = (+($562|0));
          $564 = $563 / 7.0;
          $565 = $557 >>> 6;
          $566 = (+($565|0));
          $567 = $566 / 3.0;
          $568 = (($555) + ($$0$i806)|0);
          $569 = HEAP8[$568>>0]|0;
          $570 = $569&255;
          $571 = $570 & 7;
          $572 = (+($571|0));
          $573 = $572 / 7.0;
          $574 = $570 >>> 3;
          $575 = $574 & 7;
          $576 = (+($575|0));
          $577 = $576 / 7.0;
          $578 = $570 >>> 6;
          $579 = (+($578|0));
          $580 = $579 / 3.0;
          $581 = $534 + 0.0;
          $582 = $581 + $547;
          $583 = $582 + $560;
          $584 = $583 + $573;
          $585 = $584 * 0.25;
          $586 = $538 + 0.0;
          $587 = $586 + $551;
          $588 = $587 + $564;
          $589 = $588 + $577;
          $590 = $589 * 0.25;
          $591 = $541 + 0.0;
          $592 = $591 + $554;
          $593 = $592 + $567;
          $594 = $593 + $580;
          $595 = $594 * 0.25;
          $596 = $585;
          $597 = $596 * 7.0;
          $598 = $597 + 0.5;
          $599 = (~~(($598))&255);
          $600 = $599 & 7;
          $601 = (($163) + ($$193$us$us$i835)|0);
          $602 = $590;
          $603 = $602 * 7.0;
          $604 = $603 + 0.5;
          $605 = (~~(($604))&255);
          $606 = $605&255;
          $607 = $606 << 3;
          $608 = $607 & 56;
          $609 = $600&255;
          $610 = $608 | $609;
          $611 = $595;
          $612 = $611 * 3.0;
          $613 = $612 + 0.5;
          $614 = (~~(($613))&255);
          $615 = $614&255;
          $616 = $615 << 6;
          $617 = $610 | $616;
          $618 = $617&255;
          HEAP8[$601>>0] = $618;
          $619 = (($$193$us$us$i835) + 1)|0;
          $526 = (($$18292$us$us$i836) + ($524)|0);
          $620 = (($$08391$us$us$i837) + 1)|0;
          $621 = ($620|0)<($148|0);
          if ($621) {
           $$08391$us$us$i837 = $620;$$18292$us$us$i836 = $526;$$193$us$us$i835 = $619;
          } else {
           break;
          }
         }
         $525 = (($526) + ($521)|0);
         $527 = (($525) + ($$0778)|0);
         $528 = (($$08098$us$i831) + 1)|0;
         $529 = ($528|0)<($149|0);
         if ($529) {
          $$07999$us$i830 = $619;$$08098$us$i831 = $528;$$08197$us$i832 = $527;
         } else {
          label = 217;
          break L200;
         }
        }
       }
       if ($395) {
        $396 = ($4|0)>(1);
        if (!($396)) {
         label = 215;
         break L200;
        }
        $397 = $$0$i806 << 1;
        $$088100$us$i$i815 = 0;$$09098$us$i$i816 = $141;
        while(1) {
         $398 = HEAP8[$$09098$us$i$i816>>0]|0;
         $399 = $398&255;
         $400 = $399 & 7;
         $401 = (+($400|0));
         $402 = $401 / 7.0;
         $403 = $399 >>> 3;
         $404 = $403 & 7;
         $405 = (+($404|0));
         $406 = $405 / 7.0;
         $407 = $399 >>> 6;
         $408 = (+($407|0));
         $409 = $408 / 3.0;
         $410 = (($$09098$us$i$i816) + ($$0$i806)|0);
         $411 = HEAP8[$410>>0]|0;
         $412 = $411&255;
         $413 = $412 & 7;
         $414 = (+($413|0));
         $415 = $414 / 7.0;
         $416 = $412 >>> 3;
         $417 = $416 & 7;
         $418 = (+($417|0));
         $419 = $418 / 7.0;
         $420 = $412 >>> 6;
         $421 = (+($420|0));
         $422 = $421 / 3.0;
         $423 = $402 + 0.0;
         $424 = $423 + $415;
         $425 = $424 * 0.5;
         $426 = $406 + 0.0;
         $427 = $426 + $419;
         $428 = $427 * 0.5;
         $429 = $409 + 0.0;
         $430 = $429 + $422;
         $431 = $430 * 0.5;
         $432 = $425;
         $433 = $432 * 7.0;
         $434 = $433 + 0.5;
         $435 = (~~(($434))&255);
         $436 = $435 & 7;
         $437 = (($163) + ($$088100$us$i$i815)|0);
         $438 = $428;
         $439 = $438 * 7.0;
         $440 = $439 + 0.5;
         $441 = (~~(($440))&255);
         $442 = $441&255;
         $443 = $442 << 3;
         $444 = $443 & 56;
         $445 = $436&255;
         $446 = $444 | $445;
         $447 = $431;
         $448 = $447 * 3.0;
         $449 = $448 + 0.5;
         $450 = (~~(($449))&255);
         $451 = $450&255;
         $452 = $451 << 6;
         $453 = $446 | $452;
         $454 = $453&255;
         HEAP8[$437>>0] = $454;
         $455 = (($$088100$us$i$i815) + 1)|0;
         $456 = (($$09098$us$i$i816) + ($397)|0);
         $457 = ($455|0)<($148|0);
         if ($457) {
          $$088100$us$i$i815 = $455;$$09098$us$i$i816 = $456;
         } else {
          label = 217;
          break;
         }
        }
       } else {
        $458 = ($5|0)>(1);
        $or$cond$i$i821 = $394 & $458;
        if (!($or$cond$i$i821)) {
         label = 215;
         break L200;
        }
        $459 = $$0778 << 1;
        $$085110$us$i$i823 = 0;$$191108$us$i$i824 = $141;
        while(1) {
         $460 = HEAP8[$$191108$us$i$i824>>0]|0;
         $461 = $460&255;
         $462 = $461 & 7;
         $463 = (+($462|0));
         $464 = $463 / 7.0;
         $465 = $461 >>> 3;
         $466 = $465 & 7;
         $467 = (+($466|0));
         $468 = $467 / 7.0;
         $469 = $461 >>> 6;
         $470 = (+($469|0));
         $471 = $470 / 3.0;
         $472 = (($$191108$us$i$i824) + ($$0778)|0);
         $473 = HEAP8[$472>>0]|0;
         $474 = $473&255;
         $475 = $474 & 7;
         $476 = (+($475|0));
         $477 = $476 / 7.0;
         $478 = $474 >>> 3;
         $479 = $478 & 7;
         $480 = (+($479|0));
         $481 = $480 / 7.0;
         $482 = $474 >>> 6;
         $483 = (+($482|0));
         $484 = $483 / 3.0;
         $485 = $464 + 0.0;
         $486 = $485 + $477;
         $487 = $486 * 0.5;
         $488 = $468 + 0.0;
         $489 = $488 + $481;
         $490 = $489 * 0.5;
         $491 = $471 + 0.0;
         $492 = $491 + $484;
         $493 = $492 * 0.5;
         $494 = $487;
         $495 = $494 * 7.0;
         $496 = $495 + 0.5;
         $497 = (~~(($496))&255);
         $498 = $497 & 7;
         $499 = (($163) + ($$085110$us$i$i823)|0);
         $500 = $490;
         $501 = $500 * 7.0;
         $502 = $501 + 0.5;
         $503 = (~~(($502))&255);
         $504 = $503&255;
         $505 = $504 << 3;
         $506 = $505 & 56;
         $507 = $498&255;
         $508 = $506 | $507;
         $509 = $493;
         $510 = $509 * 3.0;
         $511 = $510 + 0.5;
         $512 = (~~(($511))&255);
         $513 = $512&255;
         $514 = $513 << 6;
         $515 = $508 | $514;
         $516 = $515&255;
         HEAP8[$499>>0] = $516;
         $517 = (($$085110$us$i$i823) + 1)|0;
         $518 = (($$191108$us$i$i824) + ($459)|0);
         $519 = ($517|0)<($149|0);
         if ($519) {
          $$085110$us$i$i823 = $517;$$191108$us$i$i824 = $518;
         } else {
          label = 217;
          break;
         }
        }
       }
       break;
      }
      case 33635:  {
       $622 = ($4|0)==(1);
       $623 = ($5|0)==(1);
       $or$cond$i843 = $622 | $623;
       if (!($or$cond$i843)) {
        $782 = Math_imul($$0$i806, $4)|0;
        $783 = (($$0778) - ($782))|0;
        $784 = ($5|0)>(1);
        if (!($784)) {
         label = 215;
         break L200;
        }
        $785 = ($4|0)>(1);
        $786 = $$0$i806 << 1;
        if (!($785)) {
         label = 215;
         break L200;
        }
        $787 = ($$785|0)==(0);
        $$07999$us$i861 = 0;$$08098$us$i862 = 0;$$08197$us$i863 = $141;
        while(1) {
         $$08391$us$us$i868 = 0;$$18292$us$us$i867 = $$08197$us$i863;$$193$us$us$i866 = $$07999$us$i861;
         while(1) {
          if ($787) {
           $801 = HEAP16[$$18292$us$us$i867>>1]|0;
           $$0$i879 = $801;
          } else {
           $793 = ((($$18292$us$us$i867)) + 1|0);
           $794 = HEAP8[$793>>0]|0;
           $795 = $794&255;
           $796 = $795 << 8;
           $797 = HEAP8[$$18292$us$us$i867>>0]|0;
           $798 = $797&255;
           $799 = $796 | $798;
           $800 = $799&65535;
           $$0$i879 = $800;
          }
          $802 = $$0$i879&65535;
          $803 = $802 >>> 11;
          $804 = (+($803|0));
          $805 = $804 / 31.0;
          $806 = $802 >>> 5;
          $807 = $806 & 63;
          $808 = (+($807|0));
          $809 = $808 / 63.0;
          $810 = $802 & 31;
          $811 = (+($810|0));
          $812 = $811 / 31.0;
          $813 = (($$18292$us$us$i867) + ($$0$i806)|0);
          if ($787) {
           $822 = HEAP16[$813>>1]|0;
           $$0$i877 = $822;
          } else {
           $814 = ((($813)) + 1|0);
           $815 = HEAP8[$814>>0]|0;
           $816 = $815&255;
           $817 = $816 << 8;
           $818 = HEAP8[$813>>0]|0;
           $819 = $818&255;
           $820 = $817 | $819;
           $821 = $820&65535;
           $$0$i877 = $821;
          }
          $823 = $$0$i877&65535;
          $824 = $823 >>> 11;
          $825 = (+($824|0));
          $826 = $825 / 31.0;
          $827 = $823 >>> 5;
          $828 = $827 & 63;
          $829 = (+($828|0));
          $830 = $829 / 63.0;
          $831 = $823 & 31;
          $832 = (+($831|0));
          $833 = $832 / 31.0;
          $834 = (($$18292$us$us$i867) + ($$0778)|0);
          if ($787) {
           $843 = HEAP16[$834>>1]|0;
           $$0$i875 = $843;
          } else {
           $835 = ((($834)) + 1|0);
           $836 = HEAP8[$835>>0]|0;
           $837 = $836&255;
           $838 = $837 << 8;
           $839 = HEAP8[$834>>0]|0;
           $840 = $839&255;
           $841 = $838 | $840;
           $842 = $841&65535;
           $$0$i875 = $842;
          }
          $844 = $$0$i875&65535;
          $845 = $844 >>> 11;
          $846 = (+($845|0));
          $847 = $846 / 31.0;
          $848 = $844 >>> 5;
          $849 = $848 & 63;
          $850 = (+($849|0));
          $851 = $850 / 63.0;
          $852 = $844 & 31;
          $853 = (+($852|0));
          $854 = $853 / 31.0;
          $855 = (($834) + ($$0$i806)|0);
          if ($787) {
           $864 = HEAP16[$855>>1]|0;
           $$0$i874 = $864;
          } else {
           $856 = ((($855)) + 1|0);
           $857 = HEAP8[$856>>0]|0;
           $858 = $857&255;
           $859 = $858 << 8;
           $860 = HEAP8[$855>>0]|0;
           $861 = $860&255;
           $862 = $859 | $861;
           $863 = $862&65535;
           $$0$i874 = $863;
          }
          $865 = $$0$i874&65535;
          $866 = $865 >>> 11;
          $867 = (+($866|0));
          $868 = $867 / 31.0;
          $869 = $865 >>> 5;
          $870 = $869 & 63;
          $871 = (+($870|0));
          $872 = $871 / 63.0;
          $873 = $865 & 31;
          $874 = (+($873|0));
          $875 = $874 / 31.0;
          $876 = $805 + 0.0;
          $877 = $876 + $826;
          $878 = $877 + $847;
          $879 = $878 + $868;
          $880 = $879 * 0.25;
          $881 = $809 + 0.0;
          $882 = $881 + $830;
          $883 = $882 + $851;
          $884 = $883 + $872;
          $885 = $884 * 0.25;
          $886 = $812 + 0.0;
          $887 = $886 + $833;
          $888 = $887 + $854;
          $889 = $888 + $875;
          $890 = $889 * 0.25;
          $891 = $880 * 31.0;
          $892 = $891;
          $893 = $892 + 0.5;
          $894 = (~~(($893))&65535);
          $895 = $894&65535;
          $896 = $895 << 11;
          $897 = (($163) + ($$193$us$us$i866<<1)|0);
          $898 = $885 * 63.0;
          $899 = $898;
          $900 = $899 + 0.5;
          $901 = (~~(($900))&65535);
          $902 = $901&65535;
          $903 = $902 << 5;
          $904 = $903 & 2016;
          $905 = $904 | $896;
          $906 = $890 * 31.0;
          $907 = $906;
          $908 = $907 + 0.5;
          $909 = (~~(($908))&65535);
          $910 = $909 & 31;
          $911 = $910&65535;
          $912 = $905 | $911;
          $913 = $912&65535;
          HEAP16[$897>>1] = $913;
          $914 = (($$193$us$us$i866) + 1)|0;
          $789 = (($$18292$us$us$i867) + ($786)|0);
          $915 = (($$08391$us$us$i868) + 1)|0;
          $916 = ($915|0)<($148|0);
          if ($916) {
           $$08391$us$us$i868 = $915;$$18292$us$us$i867 = $789;$$193$us$us$i866 = $914;
          } else {
           break;
          }
         }
         $788 = (($789) + ($783)|0);
         $790 = (($788) + ($$0778)|0);
         $791 = (($$08098$us$i862) + 1)|0;
         $792 = ($791|0)<($149|0);
         if ($792) {
          $$07999$us$i861 = $914;$$08098$us$i862 = $791;$$08197$us$i863 = $790;
         } else {
          label = 217;
          break L200;
         }
        }
       }
       if ($623) {
        $624 = ($4|0)>(1);
        if (!($624)) {
         label = 215;
         break L200;
        }
        $625 = $$0$i806 << 1;
        $626 = ($$785|0)==(0);
        $$088100$us$i$i846 = 0;$$09098$us$i$i847 = $141;
        while(1) {
         if ($626) {
          $635 = HEAP16[$$09098$us$i$i847>>1]|0;
          $$0$i881 = $635;
         } else {
          $627 = ((($$09098$us$i$i847)) + 1|0);
          $628 = HEAP8[$627>>0]|0;
          $629 = $628&255;
          $630 = $629 << 8;
          $631 = HEAP8[$$09098$us$i$i847>>0]|0;
          $632 = $631&255;
          $633 = $630 | $632;
          $634 = $633&65535;
          $$0$i881 = $634;
         }
         $636 = $$0$i881&65535;
         $637 = $636 >>> 11;
         $638 = (+($637|0));
         $639 = $638 / 31.0;
         $640 = $636 >>> 5;
         $641 = $640 & 63;
         $642 = (+($641|0));
         $643 = $642 / 63.0;
         $644 = $636 & 31;
         $645 = (+($644|0));
         $646 = $645 / 31.0;
         $647 = (($$09098$us$i$i847) + ($$0$i806)|0);
         if ($626) {
          $656 = HEAP16[$647>>1]|0;
          $$0$i883 = $656;
         } else {
          $648 = ((($647)) + 1|0);
          $649 = HEAP8[$648>>0]|0;
          $650 = $649&255;
          $651 = $650 << 8;
          $652 = HEAP8[$647>>0]|0;
          $653 = $652&255;
          $654 = $651 | $653;
          $655 = $654&65535;
          $$0$i883 = $655;
         }
         $657 = $$0$i883&65535;
         $658 = $657 >>> 11;
         $659 = (+($658|0));
         $660 = $659 / 31.0;
         $661 = $657 >>> 5;
         $662 = $661 & 63;
         $663 = (+($662|0));
         $664 = $663 / 63.0;
         $665 = $657 & 31;
         $666 = (+($665|0));
         $667 = $666 / 31.0;
         $668 = $639 + 0.0;
         $669 = $668 + $660;
         $670 = $669 * 0.5;
         $671 = $643 + 0.0;
         $672 = $671 + $664;
         $673 = $672 * 0.5;
         $674 = $646 + 0.0;
         $675 = $674 + $667;
         $676 = $675 * 0.5;
         $677 = $670 * 31.0;
         $678 = $677;
         $679 = $678 + 0.5;
         $680 = (~~(($679))&65535);
         $681 = $680&65535;
         $682 = $681 << 11;
         $683 = (($163) + ($$088100$us$i$i846<<1)|0);
         $684 = $673 * 63.0;
         $685 = $684;
         $686 = $685 + 0.5;
         $687 = (~~(($686))&65535);
         $688 = $687&65535;
         $689 = $688 << 5;
         $690 = $689 & 2016;
         $691 = $690 | $682;
         $692 = $676 * 31.0;
         $693 = $692;
         $694 = $693 + 0.5;
         $695 = (~~(($694))&65535);
         $696 = $695 & 31;
         $697 = $696&65535;
         $698 = $691 | $697;
         $699 = $698&65535;
         HEAP16[$683>>1] = $699;
         $700 = (($$088100$us$i$i846) + 1)|0;
         $701 = (($$09098$us$i$i847) + ($625)|0);
         $702 = ($700|0)<($148|0);
         if ($702) {
          $$088100$us$i$i846 = $700;$$09098$us$i$i847 = $701;
         } else {
          label = 217;
          break;
         }
        }
       } else {
        $703 = ($5|0)>(1);
        $or$cond$i$i852 = $622 & $703;
        if (!($or$cond$i$i852)) {
         label = 215;
         break L200;
        }
        $704 = $$0778 << 1;
        $705 = ($$785|0)==(0);
        $$085110$us$i$i854 = 0;$$191108$us$i$i855 = $141;
        while(1) {
         if ($705) {
          $714 = HEAP16[$$191108$us$i$i855>>1]|0;
          $$0$i885 = $714;
         } else {
          $706 = ((($$191108$us$i$i855)) + 1|0);
          $707 = HEAP8[$706>>0]|0;
          $708 = $707&255;
          $709 = $708 << 8;
          $710 = HEAP8[$$191108$us$i$i855>>0]|0;
          $711 = $710&255;
          $712 = $709 | $711;
          $713 = $712&65535;
          $$0$i885 = $713;
         }
         $715 = $$0$i885&65535;
         $716 = $715 >>> 11;
         $717 = (+($716|0));
         $718 = $717 / 31.0;
         $719 = $715 >>> 5;
         $720 = $719 & 63;
         $721 = (+($720|0));
         $722 = $721 / 63.0;
         $723 = $715 & 31;
         $724 = (+($723|0));
         $725 = $724 / 31.0;
         $726 = (($$191108$us$i$i855) + ($$0778)|0);
         if ($705) {
          $735 = HEAP16[$726>>1]|0;
          $$0$i887 = $735;
         } else {
          $727 = ((($726)) + 1|0);
          $728 = HEAP8[$727>>0]|0;
          $729 = $728&255;
          $730 = $729 << 8;
          $731 = HEAP8[$726>>0]|0;
          $732 = $731&255;
          $733 = $730 | $732;
          $734 = $733&65535;
          $$0$i887 = $734;
         }
         $736 = $$0$i887&65535;
         $737 = $736 >>> 11;
         $738 = (+($737|0));
         $739 = $738 / 31.0;
         $740 = $736 >>> 5;
         $741 = $740 & 63;
         $742 = (+($741|0));
         $743 = $742 / 63.0;
         $744 = $736 & 31;
         $745 = (+($744|0));
         $746 = $745 / 31.0;
         $747 = $718 + 0.0;
         $748 = $747 + $739;
         $749 = $748 * 0.5;
         $750 = $722 + 0.0;
         $751 = $750 + $743;
         $752 = $751 * 0.5;
         $753 = $725 + 0.0;
         $754 = $753 + $746;
         $755 = $754 * 0.5;
         $756 = $749 * 31.0;
         $757 = $756;
         $758 = $757 + 0.5;
         $759 = (~~(($758))&65535);
         $760 = $759&65535;
         $761 = $760 << 11;
         $762 = (($163) + ($$085110$us$i$i854<<1)|0);
         $763 = $752 * 63.0;
         $764 = $763;
         $765 = $764 + 0.5;
         $766 = (~~(($765))&65535);
         $767 = $766&65535;
         $768 = $767 << 5;
         $769 = $768 & 2016;
         $770 = $769 | $761;
         $771 = $755 * 31.0;
         $772 = $771;
         $773 = $772 + 0.5;
         $774 = (~~(($773))&65535);
         $775 = $774 & 31;
         $776 = $775&65535;
         $777 = $770 | $776;
         $778 = $777&65535;
         HEAP16[$762>>1] = $778;
         $779 = (($$085110$us$i$i854) + 1)|0;
         $780 = (($$191108$us$i$i855) + ($704)|0);
         $781 = ($779|0)<($149|0);
         if ($781) {
          $$085110$us$i$i854 = $779;$$191108$us$i$i855 = $780;
         } else {
          label = 217;
          break;
         }
        }
       }
       break;
      }
      case 33636:  {
       $917 = ($4|0)==(1);
       $918 = ($5|0)==(1);
       $or$cond$i889 = $917 | $918;
       if (!($or$cond$i889)) {
        $1077 = Math_imul($$0$i806, $4)|0;
        $1078 = (($$0778) - ($1077))|0;
        $1079 = ($5|0)>(1);
        if (!($1079)) {
         label = 215;
         break L200;
        }
        $1080 = ($4|0)>(1);
        $1081 = $$0$i806 << 1;
        if (!($1080)) {
         label = 215;
         break L200;
        }
        $1082 = ($$785|0)==(0);
        $$07999$us$i907 = 0;$$08098$us$i908 = 0;$$08197$us$i909 = $141;
        while(1) {
         $$08391$us$us$i914 = 0;$$18292$us$us$i913 = $$08197$us$i909;$$193$us$us$i912 = $$07999$us$i907;
         while(1) {
          if ($1082) {
           $1096 = HEAP16[$$18292$us$us$i913>>1]|0;
           $$0$i925 = $1096;
          } else {
           $1088 = ((($$18292$us$us$i913)) + 1|0);
           $1089 = HEAP8[$1088>>0]|0;
           $1090 = $1089&255;
           $1091 = $1090 << 8;
           $1092 = HEAP8[$$18292$us$us$i913>>0]|0;
           $1093 = $1092&255;
           $1094 = $1091 | $1093;
           $1095 = $1094&65535;
           $$0$i925 = $1095;
          }
          $1097 = $$0$i925&65535;
          $1098 = $1097 & 31;
          $1099 = (+($1098|0));
          $1100 = $1099 / 31.0;
          $1101 = $1097 >>> 5;
          $1102 = $1101 & 63;
          $1103 = (+($1102|0));
          $1104 = $1103 / 63.0;
          $1105 = $1097 >>> 11;
          $1106 = (+($1105|0));
          $1107 = $1106 / 31.0;
          $1108 = (($$18292$us$us$i913) + ($$0$i806)|0);
          if ($1082) {
           $1117 = HEAP16[$1108>>1]|0;
           $$0$i923 = $1117;
          } else {
           $1109 = ((($1108)) + 1|0);
           $1110 = HEAP8[$1109>>0]|0;
           $1111 = $1110&255;
           $1112 = $1111 << 8;
           $1113 = HEAP8[$1108>>0]|0;
           $1114 = $1113&255;
           $1115 = $1112 | $1114;
           $1116 = $1115&65535;
           $$0$i923 = $1116;
          }
          $1118 = $$0$i923&65535;
          $1119 = $1118 & 31;
          $1120 = (+($1119|0));
          $1121 = $1120 / 31.0;
          $1122 = $1118 >>> 5;
          $1123 = $1122 & 63;
          $1124 = (+($1123|0));
          $1125 = $1124 / 63.0;
          $1126 = $1118 >>> 11;
          $1127 = (+($1126|0));
          $1128 = $1127 / 31.0;
          $1129 = (($$18292$us$us$i913) + ($$0778)|0);
          if ($1082) {
           $1138 = HEAP16[$1129>>1]|0;
           $$0$i921 = $1138;
          } else {
           $1130 = ((($1129)) + 1|0);
           $1131 = HEAP8[$1130>>0]|0;
           $1132 = $1131&255;
           $1133 = $1132 << 8;
           $1134 = HEAP8[$1129>>0]|0;
           $1135 = $1134&255;
           $1136 = $1133 | $1135;
           $1137 = $1136&65535;
           $$0$i921 = $1137;
          }
          $1139 = $$0$i921&65535;
          $1140 = $1139 & 31;
          $1141 = (+($1140|0));
          $1142 = $1141 / 31.0;
          $1143 = $1139 >>> 5;
          $1144 = $1143 & 63;
          $1145 = (+($1144|0));
          $1146 = $1145 / 63.0;
          $1147 = $1139 >>> 11;
          $1148 = (+($1147|0));
          $1149 = $1148 / 31.0;
          $1150 = (($1129) + ($$0$i806)|0);
          if ($1082) {
           $1159 = HEAP16[$1150>>1]|0;
           $$0$i920 = $1159;
          } else {
           $1151 = ((($1150)) + 1|0);
           $1152 = HEAP8[$1151>>0]|0;
           $1153 = $1152&255;
           $1154 = $1153 << 8;
           $1155 = HEAP8[$1150>>0]|0;
           $1156 = $1155&255;
           $1157 = $1154 | $1156;
           $1158 = $1157&65535;
           $$0$i920 = $1158;
          }
          $1160 = $$0$i920&65535;
          $1161 = $1160 & 31;
          $1162 = (+($1161|0));
          $1163 = $1162 / 31.0;
          $1164 = $1160 >>> 5;
          $1165 = $1164 & 63;
          $1166 = (+($1165|0));
          $1167 = $1166 / 63.0;
          $1168 = $1160 >>> 11;
          $1169 = (+($1168|0));
          $1170 = $1169 / 31.0;
          $1171 = $1100 + 0.0;
          $1172 = $1171 + $1121;
          $1173 = $1172 + $1142;
          $1174 = $1173 + $1163;
          $1175 = $1174 * 0.25;
          $1176 = $1104 + 0.0;
          $1177 = $1176 + $1125;
          $1178 = $1177 + $1146;
          $1179 = $1178 + $1167;
          $1180 = $1179 * 0.25;
          $1181 = $1107 + 0.0;
          $1182 = $1181 + $1128;
          $1183 = $1182 + $1149;
          $1184 = $1183 + $1170;
          $1185 = $1184 * 0.25;
          $1186 = $1175;
          $1187 = $1186 * 31.0;
          $1188 = $1187 + 0.5;
          $1189 = (~~(($1188))&65535);
          $1190 = $1189 & 31;
          $1191 = (($163) + ($$193$us$us$i912<<1)|0);
          $1192 = $1180;
          $1193 = $1192 * 63.0;
          $1194 = $1193 + 0.5;
          $1195 = (~~(($1194))&65535);
          $1196 = $1195&65535;
          $1197 = $1196 << 5;
          $1198 = $1197 & 2016;
          $1199 = $1190&65535;
          $1200 = $1198 | $1199;
          $1201 = $1185;
          $1202 = $1201 * 31.0;
          $1203 = $1202 + 0.5;
          $1204 = (~~(($1203))&65535);
          $1205 = $1204&65535;
          $1206 = $1205 << 11;
          $1207 = $1200 | $1206;
          $1208 = $1207&65535;
          HEAP16[$1191>>1] = $1208;
          $1209 = (($$193$us$us$i912) + 1)|0;
          $1084 = (($$18292$us$us$i913) + ($1081)|0);
          $1210 = (($$08391$us$us$i914) + 1)|0;
          $1211 = ($1210|0)<($148|0);
          if ($1211) {
           $$08391$us$us$i914 = $1210;$$18292$us$us$i913 = $1084;$$193$us$us$i912 = $1209;
          } else {
           break;
          }
         }
         $1083 = (($1084) + ($1078)|0);
         $1085 = (($1083) + ($$0778)|0);
         $1086 = (($$08098$us$i908) + 1)|0;
         $1087 = ($1086|0)<($149|0);
         if ($1087) {
          $$07999$us$i907 = $1209;$$08098$us$i908 = $1086;$$08197$us$i909 = $1085;
         } else {
          label = 217;
          break L200;
         }
        }
       }
       if ($918) {
        $919 = ($4|0)>(1);
        if (!($919)) {
         label = 215;
         break L200;
        }
        $920 = $$0$i806 << 1;
        $921 = ($$785|0)==(0);
        $$088100$us$i$i892 = 0;$$09098$us$i$i893 = $141;
        while(1) {
         if ($921) {
          $930 = HEAP16[$$09098$us$i$i893>>1]|0;
          $$0$i927 = $930;
         } else {
          $922 = ((($$09098$us$i$i893)) + 1|0);
          $923 = HEAP8[$922>>0]|0;
          $924 = $923&255;
          $925 = $924 << 8;
          $926 = HEAP8[$$09098$us$i$i893>>0]|0;
          $927 = $926&255;
          $928 = $925 | $927;
          $929 = $928&65535;
          $$0$i927 = $929;
         }
         $931 = $$0$i927&65535;
         $932 = $931 & 31;
         $933 = (+($932|0));
         $934 = $933 / 31.0;
         $935 = $931 >>> 5;
         $936 = $935 & 63;
         $937 = (+($936|0));
         $938 = $937 / 63.0;
         $939 = $931 >>> 11;
         $940 = (+($939|0));
         $941 = $940 / 31.0;
         $942 = (($$09098$us$i$i893) + ($$0$i806)|0);
         if ($921) {
          $951 = HEAP16[$942>>1]|0;
          $$0$i929 = $951;
         } else {
          $943 = ((($942)) + 1|0);
          $944 = HEAP8[$943>>0]|0;
          $945 = $944&255;
          $946 = $945 << 8;
          $947 = HEAP8[$942>>0]|0;
          $948 = $947&255;
          $949 = $946 | $948;
          $950 = $949&65535;
          $$0$i929 = $950;
         }
         $952 = $$0$i929&65535;
         $953 = $952 & 31;
         $954 = (+($953|0));
         $955 = $954 / 31.0;
         $956 = $952 >>> 5;
         $957 = $956 & 63;
         $958 = (+($957|0));
         $959 = $958 / 63.0;
         $960 = $952 >>> 11;
         $961 = (+($960|0));
         $962 = $961 / 31.0;
         $963 = $934 + 0.0;
         $964 = $963 + $955;
         $965 = $964 * 0.5;
         $966 = $938 + 0.0;
         $967 = $966 + $959;
         $968 = $967 * 0.5;
         $969 = $941 + 0.0;
         $970 = $969 + $962;
         $971 = $970 * 0.5;
         $972 = $965;
         $973 = $972 * 31.0;
         $974 = $973 + 0.5;
         $975 = (~~(($974))&65535);
         $976 = $975 & 31;
         $977 = (($163) + ($$088100$us$i$i892<<1)|0);
         $978 = $968;
         $979 = $978 * 63.0;
         $980 = $979 + 0.5;
         $981 = (~~(($980))&65535);
         $982 = $981&65535;
         $983 = $982 << 5;
         $984 = $983 & 2016;
         $985 = $976&65535;
         $986 = $984 | $985;
         $987 = $971;
         $988 = $987 * 31.0;
         $989 = $988 + 0.5;
         $990 = (~~(($989))&65535);
         $991 = $990&65535;
         $992 = $991 << 11;
         $993 = $986 | $992;
         $994 = $993&65535;
         HEAP16[$977>>1] = $994;
         $995 = (($$088100$us$i$i892) + 1)|0;
         $996 = (($$09098$us$i$i893) + ($920)|0);
         $997 = ($995|0)<($148|0);
         if ($997) {
          $$088100$us$i$i892 = $995;$$09098$us$i$i893 = $996;
         } else {
          label = 217;
          break;
         }
        }
       } else {
        $998 = ($5|0)>(1);
        $or$cond$i$i898 = $917 & $998;
        if (!($or$cond$i$i898)) {
         label = 215;
         break L200;
        }
        $999 = $$0778 << 1;
        $1000 = ($$785|0)==(0);
        $$085110$us$i$i900 = 0;$$191108$us$i$i901 = $141;
        while(1) {
         if ($1000) {
          $1009 = HEAP16[$$191108$us$i$i901>>1]|0;
          $$0$i931 = $1009;
         } else {
          $1001 = ((($$191108$us$i$i901)) + 1|0);
          $1002 = HEAP8[$1001>>0]|0;
          $1003 = $1002&255;
          $1004 = $1003 << 8;
          $1005 = HEAP8[$$191108$us$i$i901>>0]|0;
          $1006 = $1005&255;
          $1007 = $1004 | $1006;
          $1008 = $1007&65535;
          $$0$i931 = $1008;
         }
         $1010 = $$0$i931&65535;
         $1011 = $1010 & 31;
         $1012 = (+($1011|0));
         $1013 = $1012 / 31.0;
         $1014 = $1010 >>> 5;
         $1015 = $1014 & 63;
         $1016 = (+($1015|0));
         $1017 = $1016 / 63.0;
         $1018 = $1010 >>> 11;
         $1019 = (+($1018|0));
         $1020 = $1019 / 31.0;
         $1021 = (($$191108$us$i$i901) + ($$0778)|0);
         if ($1000) {
          $1030 = HEAP16[$1021>>1]|0;
          $$0$i933 = $1030;
         } else {
          $1022 = ((($1021)) + 1|0);
          $1023 = HEAP8[$1022>>0]|0;
          $1024 = $1023&255;
          $1025 = $1024 << 8;
          $1026 = HEAP8[$1021>>0]|0;
          $1027 = $1026&255;
          $1028 = $1025 | $1027;
          $1029 = $1028&65535;
          $$0$i933 = $1029;
         }
         $1031 = $$0$i933&65535;
         $1032 = $1031 & 31;
         $1033 = (+($1032|0));
         $1034 = $1033 / 31.0;
         $1035 = $1031 >>> 5;
         $1036 = $1035 & 63;
         $1037 = (+($1036|0));
         $1038 = $1037 / 63.0;
         $1039 = $1031 >>> 11;
         $1040 = (+($1039|0));
         $1041 = $1040 / 31.0;
         $1042 = $1013 + 0.0;
         $1043 = $1042 + $1034;
         $1044 = $1043 * 0.5;
         $1045 = $1017 + 0.0;
         $1046 = $1045 + $1038;
         $1047 = $1046 * 0.5;
         $1048 = $1020 + 0.0;
         $1049 = $1048 + $1041;
         $1050 = $1049 * 0.5;
         $1051 = $1044;
         $1052 = $1051 * 31.0;
         $1053 = $1052 + 0.5;
         $1054 = (~~(($1053))&65535);
         $1055 = $1054 & 31;
         $1056 = (($163) + ($$085110$us$i$i900<<1)|0);
         $1057 = $1047;
         $1058 = $1057 * 63.0;
         $1059 = $1058 + 0.5;
         $1060 = (~~(($1059))&65535);
         $1061 = $1060&65535;
         $1062 = $1061 << 5;
         $1063 = $1062 & 2016;
         $1064 = $1055&65535;
         $1065 = $1063 | $1064;
         $1066 = $1050;
         $1067 = $1066 * 31.0;
         $1068 = $1067 + 0.5;
         $1069 = (~~(($1068))&65535);
         $1070 = $1069&65535;
         $1071 = $1070 << 11;
         $1072 = $1065 | $1071;
         $1073 = $1072&65535;
         HEAP16[$1056>>1] = $1073;
         $1074 = (($$085110$us$i$i900) + 1)|0;
         $1075 = (($$191108$us$i$i901) + ($999)|0);
         $1076 = ($1074|0)<($149|0);
         if ($1076) {
          $$085110$us$i$i900 = $1074;$$191108$us$i$i901 = $1075;
         } else {
          label = 217;
          break;
         }
        }
       }
       break;
      }
      case 33637:  {
       __ZN3osgL21halveImagePackedPixelEiPFviPKvPfEPFvPKfiPvEiiS1_S7_iii(4,4009,4010,$4,$5,$141,$163,$$0$i806,$$0778,$$785);
       label = 215;
       break L200;
       break;
      }
      case 32820:  {
       __ZN3osgL21halveImagePackedPixelEiPFviPKvPfEPFvPKfiPvEiiS1_S7_iii(4,4011,4012,$4,$5,$141,$163,$$0$i806,$$0778,$$785);
       label = 215;
       break L200;
       break;
      }
      case 33638:  {
       __ZN3osgL21halveImagePackedPixelEiPFviPKvPfEPFvPKfiPvEiiS1_S7_iii(4,4013,4014,$4,$5,$141,$163,$$0$i806,$$0778,$$785);
       label = 215;
       break L200;
       break;
      }
      case 32821:  {
       __ZN3osgL21halveImagePackedPixelEiPFviPKvPfEPFvPKfiPvEiiS1_S7_iii(4,4015,4016,$4,$5,$141,$163,$$0$i806,$$0778,$$785);
       label = 215;
       break L200;
       break;
      }
      case 33639:  {
       __ZN3osgL21halveImagePackedPixelEiPFviPKvPfEPFvPKfiPvEiiS1_S7_iii(4,4017,4018,$4,$5,$141,$163,$$0$i806,$$0778,$$785);
       label = 215;
       break L200;
       break;
      }
      case 32822:  {
       __ZN3osgL21halveImagePackedPixelEiPFviPKvPfEPFvPKfiPvEiiS1_S7_iii(4,4019,4020,$4,$5,$141,$163,$$0$i806,$$0778,$$785);
       label = 215;
       break L200;
       break;
      }
      case 33640:  {
       __ZN3osgL21halveImagePackedPixelEiPFviPKvPfEPFvPKfiPvEiiS1_S7_iii(4,4021,4022,$4,$5,$141,$163,$$0$i806,$$0778,$$785);
       label = 215;
       break L200;
       break;
      }
      default: {
       label = 217;
       break L200;
      }
      }
     } while(0);
    }
   } while(0);
   if ((label|0) == 215) {
    $1212 = Math_imul($126, $$787)|0;
    $$0$i14$i937 = 1;$7058 = $1212;
   }
   else if ((label|0) == 217) {
    $1214 = Math_imul($126, $$787)|0;
    switch ($7|0) {
    case 32818: case 32819: case 32820: case 32821: case 32822: case 33634: case 33635: case 33636: case 33637: case 33638: case 33639: case 33640:  {
     $$0$i14$i937 = 1;$7058 = $1214;
     break;
    }
    default: {
     $7059 = $1214;
     label = 218;
    }
    }
   }
   L377: do {
    if ((label|0) == 218) {
     $switch$split272D = ($6|0)<(6410);
     L379: do {
      if ($switch$split272D) {
       switch ($6|0) {
       case 6407:  {
        $$0$i14$i937 = 3;$7058 = $7059;
        break L377;
        break;
       }
       case 6408:  {
        label = 220;
        break;
       }
       default: {
        label = 221;
       }
       }
      } else {
       $switch$split752D = ($6|0)<(32992);
       if (!($switch$split752D)) {
        switch ($6|0) {
        case 32992:  {
         $$0$i14$i937 = 3;$7058 = $7059;
         break L377;
         break;
        }
        case 32993:  {
         label = 220;
         break L379;
         break;
        }
        default: {
         label = 221;
         break L379;
        }
        }
       }
       switch ($6|0) {
       case 6410:  {
        break;
       }
       default: {
        label = 221;
        break L379;
       }
       }
       $$0$i14$i937 = 2;$7058 = $7059;
       break L377;
      }
     } while(0);
     if ((label|0) == 220) {
      $$0$i14$i937 = 4;$7058 = $7059;
      break;
     }
     else if ((label|0) == 221) {
      $$0$i14$i937 = 1;$7058 = $7059;
      break;
     }
    }
   } while(0);
   $switch$split302D = ($7|0)<(32820);
   L390: do {
    if ($switch$split302D) {
     $switch$split782D = ($7|0)<(5125);
     L392: do {
      if ($switch$split782D) {
       switch ($7|0) {
       case 5122: case 5123:  {
        $$0$i12$i939$ph = 2.0;
        break L392;
        break;
       }
       case 5121:  {
        $$0$i12$i939$ph = 1.0;
        break L392;
        break;
       }
       case 5120:  {
        $$0$i12$i939$ph = 1.0;
        break L392;
        break;
       }
       case 5124:  {
        $$0$i12$i939$ph = 4.0;
        break L392;
        break;
       }
       default: {
        label = 230;
        break L390;
       }
       }
      } else {
       $switch$split1082D = ($7|0)<(6656);
       if ($switch$split1082D) {
        switch ($7|0) {
        case 5125:  {
         $$0$i12$i939$ph = 4.0;
         break L392;
         break;
        }
        case 5126:  {
         $$0$i12$i939$ph = 4.0;
         break L392;
         break;
        }
        default: {
         label = 230;
         break L390;
        }
        }
       }
       $switch$split1322D = ($7|0)<(32818);
       if (!($switch$split1322D)) {
        switch ($7|0) {
        case 32818:  {
         $$0$i12$i939 = 1.0;
         label = 232;
         break L390;
         break;
        }
        case 32819:  {
         label = 228;
         break L390;
         break;
        }
        default: {
         label = 230;
         break L390;
        }
        }
       }
       switch ($7|0) {
       case 6656:  {
        $$4 = 100900;
        break;
       }
       default: {
        label = 230;
        break L390;
       }
       }
       STACKTOP = sp;return ($$4|0);
      }
     } while(0);
     $1215 = (+($$787|0));
     $1216 = $1215 * $$0$i12$i939$ph;
     $1217 = (~~(($1216))>>>0);
     $1218 = Math_imul($$0$i14$i937, $$0769)|0;
     $1219 = Math_imul($1218, $1217)|0;
     $1225 = $1219;
    } else {
     switch ($7|0) {
     case 33634:  {
      $$0$i12$i939 = 1.0;
      label = 232;
      break L390;
      break;
     }
     case 33638: case 32820: case 33637: case 33636: case 33635:  {
      label = 228;
      break L390;
      break;
     }
     case 33640: case 32822: case 33639: case 32821:  {
      break;
     }
     default: {
      label = 230;
      break L390;
     }
     }
     $$0$i12$i939 = 4.0;
     label = 232;
    }
   } while(0);
   if ((label|0) == 228) {
    $$0$i12$i939 = 2.0;
    label = 232;
   }
   else if ((label|0) == 230) {
    $$0$i12$i939 = 4.0;
    label = 232;
   }
   L415: do {
    if ((label|0) == 232) {
     $1220 = (+($$787|0));
     $1221 = $1220 * $$0$i12$i939;
     $1222 = (~~(($1221))>>>0);
     $1223 = Math_imul($$0$i14$i937, $$0769)|0;
     $1224 = Math_imul($1223, $1222)|0;
     switch ($7|0) {
     case 32819: case 33636: case 33635: case 33634: case 32818: case 33640: case 32822: case 33639: case 32821: case 33638: case 32820: case 33637:  {
      $1225 = $1224;
      break L415;
      break;
     }
     default: {
      $$4 = 100900;
     }
     }
     STACKTOP = sp;return ($$4|0);
    }
   } while(0);
   $1226 = (_malloc($1225)|0);
   $1227 = ($1226|0)==(0|0);
   if (!($1227)) {
    $1229 = (($8) + 1)|0;
    $$0762 = $1229;$$0767 = $163;$$1755 = $$787;$$1759 = $$0769;$$1779 = $7058;$$5 = $1226;
    break;
   }
   $1228 = HEAP32[$19>>2]|0;
   _glPixelStorei(3317,($1228|0));
   _free($163);
   $$4 = 100902;
   STACKTOP = sp;return ($$4|0);
  } else {
   L424: do {
    switch ($7|0) {
    case 32818: case 32819: case 32820: case 32821: case 32822: case 33634: case 33635: case 33636: case 33637: case 33638: case 33639: case 33640:  {
     $$0$i14$i946 = 1;
     break;
    }
    default: {
     $switch$split332D = ($6|0)<(6410);
     L426: do {
      if ($switch$split332D) {
       switch ($6|0) {
       case 6407:  {
        $$0$i14$i946 = 3;
        break L424;
        break;
       }
       case 6408:  {
        label = 239;
        break;
       }
       default: {
        label = 240;
       }
       }
      } else {
       $switch$split812D = ($6|0)<(32992);
       if (!($switch$split812D)) {
        switch ($6|0) {
        case 32992:  {
         $$0$i14$i946 = 3;
         break L424;
         break;
        }
        case 32993:  {
         label = 239;
         break L426;
         break;
        }
        default: {
         label = 240;
         break L426;
        }
        }
       }
       switch ($6|0) {
       case 6410:  {
        break;
       }
       default: {
        label = 240;
        break L426;
       }
       }
       $$0$i14$i946 = 2;
       break L424;
      }
     } while(0);
     if ((label|0) == 239) {
      $$0$i14$i946 = 4;
      break L424;
     }
     else if ((label|0) == 240) {
      $$0$i14$i946 = 1;
      break L424;
     }
    }
    }
   } while(0);
   $switch$split362D = ($7|0)<(32820);
   L437: do {
    if ($switch$split362D) {
     $switch$split842D = ($7|0)<(5125);
     L439: do {
      if ($switch$split842D) {
       switch ($7|0) {
       case 5122: case 5123:  {
        $$0$i12$i948$ph = 2.0;
        break L439;
        break;
       }
       case 5121:  {
        $$0$i12$i948$ph = 1.0;
        break L439;
        break;
       }
       case 5120:  {
        $$0$i12$i948$ph = 1.0;
        break L439;
        break;
       }
       case 5124:  {
        $$0$i12$i948$ph = 4.0;
        break L439;
        break;
       }
       default: {
        label = 249;
        break L437;
       }
       }
      } else {
       $switch$split1112D = ($7|0)<(6656);
       if ($switch$split1112D) {
        switch ($7|0) {
        case 5125:  {
         $$0$i12$i948$ph = 4.0;
         break L439;
         break;
        }
        case 5126:  {
         $$0$i12$i948$ph = 4.0;
         break L439;
         break;
        }
        default: {
         label = 249;
         break L437;
        }
        }
       }
       $switch$split1352D = ($7|0)<(32818);
       if (!($switch$split1352D)) {
        switch ($7|0) {
        case 32818:  {
         $$0$i12$i948 = 1.0;
         label = 251;
         break L437;
         break;
        }
        case 32819:  {
         label = 247;
         break L437;
         break;
        }
        default: {
         label = 249;
         break L437;
        }
        }
       }
       switch ($7|0) {
       case 6656:  {
        $$4 = 100900;
        break;
       }
       default: {
        label = 249;
        break L437;
       }
       }
       STACKTOP = sp;return ($$4|0);
      }
     } while(0);
     $1230 = (+($4|0));
     $1231 = $1230 * $$0$i12$i948$ph;
     $1232 = (~~(($1231))>>>0);
     $1233 = Math_imul($$0$i14$i946, $5)|0;
     $1234 = Math_imul($1233, $1232)|0;
     $1240 = $1234;
    } else {
     switch ($7|0) {
     case 33634:  {
      $$0$i12$i948 = 1.0;
      label = 251;
      break L437;
      break;
     }
     case 33638: case 32820: case 33637: case 33636: case 33635:  {
      label = 247;
      break L437;
      break;
     }
     case 33640: case 32822: case 33639: case 32821:  {
      break;
     }
     default: {
      label = 249;
      break L437;
     }
     }
     $$0$i12$i948 = 4.0;
     label = 251;
    }
   } while(0);
   if ((label|0) == 247) {
    $$0$i12$i948 = 2.0;
    label = 251;
   }
   else if ((label|0) == 249) {
    $$0$i12$i948 = 4.0;
    label = 251;
   }
   L462: do {
    if ((label|0) == 251) {
     $1235 = (+($4|0));
     $1236 = $1235 * $$0$i12$i948;
     $1237 = (~~(($1236))>>>0);
     $1238 = Math_imul($$0$i14$i946, $5)|0;
     $1239 = Math_imul($1238, $1237)|0;
     switch ($7|0) {
     case 32819: case 33636: case 33635: case 33634: case 32818: case 33640: case 32822: case 33639: case 32821: case 33638: case 32820: case 33637:  {
      $1240 = $1239;
      break L462;
      break;
     }
     default: {
      $$4 = 100900;
     }
     }
     STACKTOP = sp;return ($$4|0);
    }
   } while(0);
   $1241 = (_malloc($1240)|0);
   $1242 = ($1241|0)==(0|0);
   if ($1242) {
    _glPixelStorei(3317,($129|0));
    $$4 = 100902;
    STACKTOP = sp;return ($$4|0);
   }
   $switch$split392D = ($7|0)<(32820);
   L470: do {
    if ($switch$split392D) {
     $switch$split872D = ($7|0)<(5124);
     if ($switch$split872D) {
      switch ($7|0) {
      case 5121:  {
       $1243 = $4 << 1;
       $1244 = ($1243|0)==($2|0);
       $1245 = $5 << 1;
       $1246 = ($1245|0)==($3|0);
       $or$cond$i953 = $1244 & $1246;
       if ($or$cond$i953) {
        __ZN3osgL16halveImage_ubyteEijjPKhPhiii($$0$i805,$2,$3,$141,$1241,$$0$i806,$$0778,$126);
       } else {
        $1247 = (+($3|0));
        $1248 = (+($5|0));
        $1249 = $1247 / $1248;
        $1250 = (+($2|0));
        $1251 = (+($4|0));
        $1252 = $1250 / $1251;
        $1253 = (+Math_floor((+$1249)));
        $1254 = (~~(($1253)));
        $1255 = (+($1254|0));
        $1256 = $1249 - $1255;
        $1257 = (+Math_floor((+$1252)));
        $1258 = (~~(($1257)));
        $1259 = (+($1258|0));
        $1260 = $1252 - $1259;
        $1261 = $1252 * $1249;
        $1262 = ($5|0)>(0);
        if ($1262) {
         $1263 = (($3) + -1)|0;
         $1264 = ($4|0)>(0);
         $1265 = (($$0778) + ($126))|0;
         $exitcond577$i2043 = ($$0$i805|0)==(1);
         $$phi$trans$insert611$i2936 = ((($12)) + 4|0);
         $exitcond577$i2937 = ($$0$i805|0)==(2);
         $$phi$trans$insert609$i2934 = ((($12)) + 4|0);
         $exitcond568$i2935 = ($$0$i805|0)==(2);
         $$phi$trans$insert607$i2932 = ((($12)) + 4|0);
         $exitcond560$i2933 = ($$0$i805|0)==(2);
         $$phi$trans$insert$i2930 = ((($12)) + 4|0);
         $exitcond$i9562931 = ($$0$i805|0)==(2);
         $$0377538$i = 0;$$0383537$i = $1256;$$0385536$i = 0.0;$$0394535$i = $1254;$$0397534$i = 0;
         while(1) {
          $1266 = ($$0394535$i|0)<($3|0);
          $$0394$$i = $1266 ? $$0394535$i : $1263;
          if ($1264) {
           $1267 = ($$0394$$i|0)>($$0397534$i|0);
           $1268 = Math_imul($$0397534$i, $$0778)|0;
           $1269 = 1.0 - $$0385536$i;
           $1270 = Math_imul($$0394$$i, $$0778)|0;
           $$0372506$i = (($$0397534$i) + 1)|0;
           $1271 = ($$0372506$i|0)<($$0394$$i|0);
           $1272 = Math_imul($$0372506$i, $$0778)|0;
           $1273 = Math_imul($$0377538$i, $4)|0;
           $1274 = $$0383537$i - $$0385536$i;
           $scevgep$i = (($141) + ($1268)|0);
           $1275 = (($$0394$$i) + -1)|0;
           $1276 = Math_imul($1275, $$0778)|0;
           $scevgep569$i = (($141) + ($1276)|0);
           $scevgep587$i = (($141) + ($1270)|0);
           $$0378530$i = 0;$$0386529$i = $1260;$$0388528$i = 0.0;$$0398527$i = $1258;$$0400526$i = 0;
           while(1) {
            $1277 = Math_imul($$0400526$i, $126)|0;
            $1278 = ($$0398527$i|0)>($$0400526$i|0);
            $or$cond417$i = $1267 & $1278;
            ;HEAP32[$12>>2]=0|0;HEAP32[$12+4>>2]=0|0;HEAP32[$12+8>>2]=0|0;HEAP32[$12+12>>2]=0|0;
            L486: do {
             if ($or$cond417$i) {
              $1279 = (($141) + ($1277)|0);
              $1280 = (($1279) + ($1268)|0);
              $1281 = 1.0 - $$0388528$i;
              $1282 = $1269 * $1281;
              $1283 = HEAP8[$1280>>0]|0;
              $1284 = (+($1283&255));
              $1285 = $1282 * $1284;
              $1286 = $1285 + 0.0;
              HEAPF32[$12>>2] = $1286;
              do {
               if (!($exitcond577$i2043)) {
                $1287 = (($1280) + ($$0$i806)|0);
                $1288 = HEAP8[$1287>>0]|0;
                $1289 = (+($1288&255));
                $1290 = $1282 * $1289;
                $1291 = $1290 + 0.0;
                HEAPF32[$$phi$trans$insert611$i2936>>2] = $1291;
                if ($exitcond577$i2937) {
                 break;
                } else {
                 $1292 = 2;$1294 = $1287;
                }
                while(1) {
                 $$phi$trans$insert611$i$phi$trans$insert = (($12) + ($1292<<2)|0);
                 $$pre612$i$pre = +HEAPF32[$$phi$trans$insert611$i$phi$trans$insert>>2];
                 $1293 = (($1294) + ($$0$i806)|0);
                 $$phi$trans$insert611$i = (($12) + ($1292<<2)|0);
                 $1295 = HEAP8[$1293>>0]|0;
                 $1296 = (+($1295&255));
                 $1297 = $1282 * $1296;
                 $1298 = $$pre612$i$pre + $1297;
                 HEAPF32[$$phi$trans$insert611$i>>2] = $1298;
                 $1299 = (($1292) + 1)|0;
                 $exitcond577$i = ($1299|0)==($$0$i805|0);
                 if ($exitcond577$i) {
                  break;
                 } else {
                  $1292 = $1299;$1294 = $1293;
                 }
                }
               }
              } while(0);
              $1300 = (($$0400526$i) + 1)|0;
              $1301 = ($1300|0)<($$0398527$i|0);
              $1302 = (($1280) + ($126)|0);
              if ($1301) {
               $$0374476$us$i = $1300;$1313 = $1302;
               while(1) {
                $$1380473$us$i = 0;$$1403472$us$i = $1313;
                while(1) {
                 $1303 = HEAP8[$$1403472$us$i>>0]|0;
                 $1304 = (+($1303&255));
                 $1305 = $1269 * $1304;
                 $1306 = (($12) + ($$1380473$us$i<<2)|0);
                 $1307 = +HEAPF32[$1306>>2];
                 $1308 = $1307 + $1305;
                 HEAPF32[$1306>>2] = $1308;
                 $1309 = (($$1380473$us$i) + 1)|0;
                 $1310 = (($$1403472$us$i) + ($$0$i806)|0);
                 $exitcond581$i = ($1309|0)==($$0$i805|0);
                 if ($exitcond581$i) {
                  break;
                 } else {
                  $$1380473$us$i = $1309;$$1403472$us$i = $1310;
                 }
                }
                $1311 = (($$0374476$us$i) + 1)|0;
                $1312 = (($1313) + ($126)|0);
                $exitcond584$i = ($1311|0)==($$0398527$i|0);
                if ($exitcond584$i) {
                 break;
                } else {
                 $$0374476$us$i = $1311;$1313 = $1312;
                }
               }
               $1314 = Math_imul($$0398527$i, $126)|0;
               $scevgep583$i = (($scevgep$i) + ($1314)|0);
               $$lcssa433$i = $scevgep583$i;
              } else {
               $$lcssa433$i = $1302;
              }
              $1315 = $1269 * $$0386529$i;
              $$2381480$i = 0;$$2404479$i = $$lcssa433$i;
              while(1) {
               $1316 = HEAP8[$$2404479$i>>0]|0;
               $1317 = (+($1316&255));
               $1318 = $1315 * $1317;
               $1319 = (($12) + ($$2381480$i<<2)|0);
               $1320 = +HEAPF32[$1319>>2];
               $1321 = $1320 + $1318;
               HEAPF32[$1319>>2] = $1321;
               $1322 = (($$2381480$i) + 1)|0;
               $1323 = (($$2404479$i) + ($$0$i806)|0);
               $exitcond585$i = ($1322|0)==($$0$i805|0);
               if ($exitcond585$i) {
                break;
               } else {
                $$2381480$i = $1322;$$2404479$i = $1323;
               }
              }
              $1324 = $$0383537$i * $1281;
              $1325 = (($1279) + ($1270)|0);
              $$3382485$i = 0;$$3405484$i = $1325;
              while(1) {
               $1338 = HEAP8[$$3405484$i>>0]|0;
               $1339 = (+($1338&255));
               $1340 = $1324 * $1339;
               $1341 = (($12) + ($$3382485$i<<2)|0);
               $1342 = +HEAPF32[$1341>>2];
               $1343 = $1342 + $1340;
               HEAPF32[$1341>>2] = $1343;
               $1344 = (($$3382485$i) + 1)|0;
               $1345 = (($$3405484$i) + ($$0$i806)|0);
               $exitcond586$i = ($1344|0)==($$0$i805|0);
               if ($exitcond586$i) {
                break;
               } else {
                $$3382485$i = $1344;$$3405484$i = $1345;
               }
              }
              $1326 = (($1325) + ($126)|0);
              if ($1301) {
               $$1375492$us$i = $1300;$1337 = $1326;
               while(1) {
                $$4406488$us$i = $1337;$$4489$us$i = 0;
                while(1) {
                 $1327 = HEAP8[$$4406488$us$i>>0]|0;
                 $1328 = (+($1327&255));
                 $1329 = $$0383537$i * $1328;
                 $1330 = (($12) + ($$4489$us$i<<2)|0);
                 $1331 = +HEAPF32[$1330>>2];
                 $1332 = $1331 + $1329;
                 HEAPF32[$1330>>2] = $1332;
                 $1333 = (($$4489$us$i) + 1)|0;
                 $1334 = (($$4406488$us$i) + ($$0$i806)|0);
                 $exitcond590$i = ($1333|0)==($$0$i805|0);
                 if ($exitcond590$i) {
                  break;
                 } else {
                  $$4406488$us$i = $1334;$$4489$us$i = $1333;
                 }
                }
                $1335 = (($$1375492$us$i) + 1)|0;
                $1336 = (($1337) + ($126)|0);
                $exitcond593$i = ($1335|0)==($$0398527$i|0);
                if ($exitcond593$i) {
                 break;
                } else {
                 $$1375492$us$i = $1335;$1337 = $1336;
                }
               }
               $1346 = Math_imul($$0398527$i, $126)|0;
               $scevgep592$i = (($scevgep587$i) + ($1346)|0);
               $$lcssa434$i = $scevgep592$i;
              } else {
               $$lcssa434$i = $1326;
              }
              $1347 = $$0383537$i * $$0386529$i;
              $$5407495$i = $$lcssa434$i;$$5496$i = 0;
              while(1) {
               $1363 = HEAP8[$$5407495$i>>0]|0;
               $1364 = (+($1363&255));
               $1365 = $1347 * $1364;
               $1366 = (($12) + ($$5496$i<<2)|0);
               $1367 = +HEAPF32[$1366>>2];
               $1368 = $1367 + $1365;
               HEAPF32[$1366>>2] = $1368;
               $1369 = (($$5496$i) + 1)|0;
               $1370 = (($$5407495$i) + ($$0$i806)|0);
               $exitcond594$i = ($1369|0)==($$0$i805|0);
               if ($exitcond594$i) {
                break;
               } else {
                $$5407495$i = $1370;$$5496$i = $1369;
               }
              }
              if ($1271) {
               $$0370507$us$i = $1280;$$0372509$us$i = $$0372506$i;$$0508$us$i = $$lcssa433$i;
              } else {
               break;
              }
              while(1) {
               $1348 = (($$0370507$us$i) + ($$0778)|0);
               $1349 = (($$0508$us$i) + ($$0778)|0);
               $$1371500$us$i = $1348;$$1501$us$i = $1349;$$6499$us$i = 0;
               while(1) {
                $1350 = HEAP8[$$1371500$us$i>>0]|0;
                $1351 = (+($1350&255));
                $1352 = $1281 * $1351;
                $1353 = HEAP8[$$1501$us$i>>0]|0;
                $1354 = (+($1353&255));
                $1355 = $$0386529$i * $1354;
                $1356 = $1352 + $1355;
                $1357 = (($12) + ($$6499$us$i<<2)|0);
                $1358 = +HEAPF32[$1357>>2];
                $1359 = $1358 + $1356;
                HEAPF32[$1357>>2] = $1359;
                $1360 = (($$6499$us$i) + 1)|0;
                $1361 = (($$1371500$us$i) + ($$0$i806)|0);
                $1362 = (($$1501$us$i) + ($$0$i806)|0);
                $exitcond598$i = ($1360|0)==($$0$i805|0);
                if ($exitcond598$i) {
                 break;
                } else {
                 $$1371500$us$i = $1361;$$1501$us$i = $1362;$$6499$us$i = $1360;
                }
               }
               $scevgep596$i = (($$0370507$us$i) + ($1265)|0);
               $scevgep597$i = (($$0508$us$i) + ($1265)|0);
               $$0372$us$i = (($$0372509$us$i) + 1)|0;
               $exitcond599$i = ($$0372$us$i|0)==($$0394$$i|0);
               if ($exitcond599$i) {
                label = 310;
                break;
               } else {
                $$0370507$us$i = $scevgep596$i;$$0372509$us$i = $$0372$us$i;$$0508$us$i = $scevgep597$i;
               }
              }
             } else {
              if ($1267) {
               $1371 = $$0386529$i - $$0388528$i;
               $1372 = $1269 * $1371;
               $1373 = (($141) + ($1277)|0);
               $1374 = (($1373) + ($1268)|0);
               $1375 = HEAP8[$1374>>0]|0;
               $1376 = (+($1375&255));
               $1377 = $1372 * $1376;
               $1378 = $1377 + 0.0;
               HEAPF32[$12>>2] = $1378;
               do {
                if (!($exitcond577$i2043)) {
                 $1379 = (($1374) + ($$0$i806)|0);
                 $1380 = HEAP8[$1379>>0]|0;
                 $1381 = (+($1380&255));
                 $1382 = $1372 * $1381;
                 $1383 = $1382 + 0.0;
                 HEAPF32[$$phi$trans$insert609$i2934>>2] = $1383;
                 if ($exitcond568$i2935) {
                  break;
                 } else {
                  $1393 = 2;$1395 = $1379;
                 }
                 while(1) {
                  $$phi$trans$insert609$i$phi$trans$insert = (($12) + ($1393<<2)|0);
                  $$pre610$i$pre = +HEAPF32[$$phi$trans$insert609$i$phi$trans$insert>>2];
                  $1394 = (($1395) + ($$0$i806)|0);
                  $$phi$trans$insert609$i = (($12) + ($1393<<2)|0);
                  $1396 = HEAP8[$1394>>0]|0;
                  $1397 = (+($1396&255));
                  $1398 = $1372 * $1397;
                  $1399 = $$pre610$i$pre + $1398;
                  HEAPF32[$$phi$trans$insert609$i>>2] = $1399;
                  $1400 = (($1393) + 1)|0;
                  $exitcond568$i = ($1400|0)==($$0$i805|0);
                  if ($exitcond568$i) {
                   break;
                  } else {
                   $1393 = $1400;$1395 = $1394;
                  }
                 }
                }
               } while(0);
               if ($1271) {
                $$1373459$us$i = $$0372506$i;$$2391458$us$i = $1374;
                while(1) {
                 $1384 = (($$2391458$us$i) + ($$0778)|0);
                 $$7409453$us$i = $1384;$$8454$us$i = 0;
                 while(1) {
                  $1385 = HEAP8[$$7409453$us$i>>0]|0;
                  $1386 = (+($1385&255));
                  $1387 = $1371 * $1386;
                  $1388 = (($12) + ($$8454$us$i<<2)|0);
                  $1389 = +HEAPF32[$1388>>2];
                  $1390 = $1389 + $1387;
                  HEAPF32[$1388>>2] = $1390;
                  $1391 = (($$8454$us$i) + 1)|0;
                  $1392 = (($$7409453$us$i) + ($$0$i806)|0);
                  $exitcond572$i = ($1391|0)==($$0$i805|0);
                  if ($exitcond572$i) {
                   break;
                  } else {
                   $$7409453$us$i = $1392;$$8454$us$i = $1391;
                  }
                 }
                 $$1373$us$i = (($$1373459$us$i) + 1)|0;
                 $exitcond575$i = ($$1373$us$i|0)==($$0394$$i|0);
                 if ($exitcond575$i) {
                  break;
                 } else {
                  $$1373459$us$i = $$1373$us$i;$$2391458$us$i = $1384;
                 }
                }
                $scevgep574$i = (($scevgep569$i) + ($1277)|0);
                $$2391$lcssa$i = $scevgep574$i;
               } else {
                $$2391$lcssa$i = $1374;
               }
               $1401 = $$0383537$i * $1371;
               $1402 = (($$2391$lcssa$i) + ($$0778)|0);
               $$8410463$i = $1402;$$9464$i = 0;
               while(1) {
                $1403 = HEAP8[$$8410463$i>>0]|0;
                $1404 = (+($1403&255));
                $1405 = $1401 * $1404;
                $1406 = (($12) + ($$9464$i<<2)|0);
                $1407 = +HEAPF32[$1406>>2];
                $1408 = $1407 + $1405;
                HEAPF32[$1406>>2] = $1408;
                $1409 = (($$9464$i) + 1)|0;
                $1410 = (($$8410463$i) + ($$0$i806)|0);
                $exitcond576$i = ($1409|0)==($$0$i805|0);
                if ($exitcond576$i) {
                 label = 310;
                 break L486;
                } else {
                 $$8410463$i = $1410;$$9464$i = $1409;
                }
               }
              }
              if (!($1278)) {
               $1454 = $$0386529$i - $$0388528$i;
               $1455 = $1274 * $1454;
               $1456 = (($141) + ($1277)|0);
               $1457 = (($1456) + ($1268)|0);
               $1458 = HEAP8[$1457>>0]|0;
               $1459 = (+($1458&255));
               $1460 = $1455 * $1459;
               $1461 = $1460 + 0.0;
               HEAPF32[$12>>2] = $1461;
               if ($exitcond577$i2043) {
                label = 310;
                break;
               }
               $1462 = (($1457) + ($$0$i806)|0);
               $1463 = HEAP8[$1462>>0]|0;
               $1464 = (+($1463&255));
               $1465 = $1455 * $1464;
               $1466 = $1465 + 0.0;
               HEAPF32[$$phi$trans$insert$i2930>>2] = $1466;
               if ($exitcond$i9562931) {
                label = 310;
                break;
               } else {
                $1467 = 2;$1469 = $1462;
               }
               while(1) {
                $$phi$trans$insert$i$phi$trans$insert = (($12) + ($1467<<2)|0);
                $$pre$i$pre = +HEAPF32[$$phi$trans$insert$i$phi$trans$insert>>2];
                $1468 = (($1469) + ($$0$i806)|0);
                $$phi$trans$insert$i = (($12) + ($1467<<2)|0);
                $1470 = HEAP8[$1468>>0]|0;
                $1471 = (+($1470&255));
                $1472 = $1455 * $1471;
                $1473 = $$pre$i$pre + $1472;
                HEAPF32[$$phi$trans$insert$i>>2] = $1473;
                $1474 = (($1467) + 1)|0;
                $exitcond$i956 = ($1474|0)==($$0$i805|0);
                if ($exitcond$i956) {
                 label = 310;
                 break L486;
                } else {
                 $1467 = $1474;$1469 = $1468;
                }
               }
              }
              $1411 = 1.0 - $$0388528$i;
              $1412 = $1274 * $1411;
              $1413 = (($141) + ($1277)|0);
              $1414 = (($1413) + ($1268)|0);
              $1415 = HEAP8[$1414>>0]|0;
              $1416 = (+($1415&255));
              $1417 = $1412 * $1416;
              $1418 = $1417 + 0.0;
              HEAPF32[$12>>2] = $1418;
              do {
               if (!($exitcond577$i2043)) {
                $1419 = (($1414) + ($$0$i806)|0);
                $1420 = HEAP8[$1419>>0]|0;
                $1421 = (+($1420&255));
                $1422 = $1412 * $1421;
                $1423 = $1422 + 0.0;
                HEAPF32[$$phi$trans$insert607$i2932>>2] = $1423;
                if ($exitcond560$i2933) {
                 break;
                } else {
                 $1436 = 2;$1438 = $1419;
                }
                while(1) {
                 $$phi$trans$insert607$i$phi$trans$insert = (($12) + ($1436<<2)|0);
                 $$pre608$i$pre = +HEAPF32[$$phi$trans$insert607$i$phi$trans$insert>>2];
                 $1437 = (($1438) + ($$0$i806)|0);
                 $$phi$trans$insert607$i = (($12) + ($1436<<2)|0);
                 $1439 = HEAP8[$1437>>0]|0;
                 $1440 = (+($1439&255));
                 $1441 = $1412 * $1440;
                 $1442 = $$pre608$i$pre + $1441;
                 HEAPF32[$$phi$trans$insert607$i>>2] = $1442;
                 $1443 = (($1436) + 1)|0;
                 $exitcond560$i = ($1443|0)==($$0$i805|0);
                 if ($exitcond560$i) {
                  break;
                 } else {
                  $1436 = $1443;$1438 = $1437;
                 }
                }
               }
              } while(0);
              $$2376443$i = (($$0400526$i) + 1)|0;
              $1424 = ($$2376443$i|0)<($$0398527$i|0);
              $1425 = (($1414) + ($126)|0);
              if ($1424) {
               $$2376444$us$i = $$2376443$i;$1435 = $1425;
               while(1) {
                $$10412440$us$i = $1435;$$11441$us$i = 0;
                while(1) {
                 $1426 = HEAP8[$$10412440$us$i>>0]|0;
                 $1427 = (+($1426&255));
                 $1428 = $1274 * $1427;
                 $1429 = (($12) + ($$11441$us$i<<2)|0);
                 $1430 = +HEAPF32[$1429>>2];
                 $1431 = $1430 + $1428;
                 HEAPF32[$1429>>2] = $1431;
                 $1432 = (($$11441$us$i) + 1)|0;
                 $1433 = (($$10412440$us$i) + ($$0$i806)|0);
                 $exitcond563$i = ($1432|0)==($$0$i805|0);
                 if ($exitcond563$i) {
                  break;
                 } else {
                  $$10412440$us$i = $1433;$$11441$us$i = $1432;
                 }
                }
                $$2376$us$i = (($$2376444$us$i) + 1)|0;
                $1434 = (($1435) + ($126)|0);
                $exitcond566$i = ($$2376$us$i|0)==($$0398527$i|0);
                if ($exitcond566$i) {
                 break;
                } else {
                 $$2376444$us$i = $$2376$us$i;$1435 = $1434;
                }
               }
               $1444 = Math_imul($$0398527$i, $126)|0;
               $scevgep565$i = (($scevgep$i) + ($1444)|0);
               $$lcssa$i954 = $scevgep565$i;
              } else {
               $$lcssa$i954 = $1425;
              }
              $1445 = $1274 * $$0386529$i;
              $$11413445$i = $$lcssa$i954;$$12446$i = 0;
              while(1) {
               $1446 = HEAP8[$$11413445$i>>0]|0;
               $1447 = (+($1446&255));
               $1448 = $1445 * $1447;
               $1449 = (($12) + ($$12446$i<<2)|0);
               $1450 = +HEAPF32[$1449>>2];
               $1451 = $1450 + $1448;
               HEAPF32[$1449>>2] = $1451;
               $1452 = (($$12446$i) + 1)|0;
               $1453 = (($$11413445$i) + ($$0$i806)|0);
               $exitcond567$i = ($1452|0)==($$0$i805|0);
               if ($exitcond567$i) {
                label = 310;
                break;
               } else {
                $$11413445$i = $1453;$$12446$i = $1452;
               }
              }
             }
            } while(0);
            do {
             if ((label|0) == 310) {
              label = 0;
              if (!($1271)) {
               break;
              }
              $$3515$i = (($$0400526$i) + 1)|0;
              $$not$i = ($$3515$i|0)<($$0398527$i|0);
              if (!($$not$i)) {
               break;
              }
              $1475 = (($141) + ($1277)|0);
              $1476 = (($1475) + ($126)|0);
              $1477 = (($1476) + ($1272)|0);
              $$0401519$i$us = $1477;$$2520$i$us = $$0372506$i;
              while(1) {
               $$3517$us$i$us = $$3515$i;$$4393516$us$i$us = $$0401519$i$us;
               while(1) {
                $$13415511$us$i$us = $$4393516$us$i$us;$$14512$us$i$us = 0;
                while(1) {
                 $1478 = HEAP8[$$13415511$us$i$us>>0]|0;
                 $1479 = (+($1478&255));
                 $1480 = (($12) + ($$14512$us$i$us<<2)|0);
                 $1481 = +HEAPF32[$1480>>2];
                 $1482 = $1481 + $1479;
                 HEAPF32[$1480>>2] = $1482;
                 $1483 = (($$14512$us$i$us) + 1)|0;
                 $1484 = (($$13415511$us$i$us) + ($$0$i806)|0);
                 $exitcond601$i$us = ($1483|0)==($$0$i805|0);
                 if ($exitcond601$i$us) {
                  break;
                 } else {
                  $$13415511$us$i$us = $1484;$$14512$us$i$us = $1483;
                 }
                }
                $1485 = (($$4393516$us$i$us) + ($126)|0);
                $$3$us$i$us = (($$3517$us$i$us) + 1)|0;
                $exitcond602$i$us = ($$3$us$i$us|0)==($$0398527$i|0);
                if ($exitcond602$i$us) {
                 break;
                } else {
                 $$3517$us$i$us = $$3$us$i$us;$$4393516$us$i$us = $1485;
                }
               }
               $1486 = (($$0401519$i$us) + ($$0778)|0);
               $1487 = (($$2520$i$us) + 1)|0;
               $exitcond603$i$us = ($1487|0)==($$0394$$i|0);
               if ($exitcond603$i$us) {
                break;
               } else {
                $$0401519$i$us = $1486;$$2520$i$us = $1487;
               }
              }
             }
            } while(0);
            $1488 = (($$0378530$i) + ($1273))|0;
            $1489 = Math_imul($1488, $$0$i805)|0;
            $$15522$i = 0;
            while(1) {
             $1490 = (($12) + ($$15522$i<<2)|0);
             $1491 = +HEAPF32[$1490>>2];
             $1492 = $1491 / $1261;
             $1493 = (~~(($1492))&255);
             $1494 = (($$15522$i) + ($1489))|0;
             $1495 = (($1241) + ($1494)|0);
             HEAP8[$1495>>0] = $1493;
             $1496 = (($$15522$i) + 1)|0;
             $exitcond604$i = ($1496|0)==($$0$i805|0);
             if ($exitcond604$i) {
              break;
             } else {
              $$15522$i = $1496;
             }
            }
            $1497 = (($$0398527$i) + ($1258))|0;
            $1498 = $1260 + $$0386529$i;
            $1499 = $1498 > 1.0;
            $1500 = $1498 + -1.0;
            $1501 = $1499&1;
            $$1399$i = (($1497) + ($1501))|0;
            $$1387$i = $1499 ? $1500 : $1498;
            $1502 = (($$0378530$i) + 1)|0;
            $exitcond605$i = ($1502|0)==($4|0);
            if ($exitcond605$i) {
             break;
            } else {
             $$0400526$i$phi = $$0398527$i;$$0388528$i$phi = $$0386529$i;$$0378530$i = $1502;$$0386529$i = $$1387$i;$$0398527$i = $$1399$i;$$0400526$i = $$0400526$i$phi;$$0388528$i = $$0388528$i$phi;
            }
           }
          }
          $1503 = $1256 + $$0383537$i;
          $1504 = $1503 > 1.0;
          $1505 = $1503 + -1.0;
          $1506 = $1504&1;
          $1507 = (($1506) + ($1254))|0;
          $$2396$i = (($1507) + ($$0394$$i))|0;
          $$1384$i = $1504 ? $1505 : $1503;
          $1508 = (($$0377538$i) + 1)|0;
          $exitcond606$i = ($1508|0)==($5|0);
          if ($exitcond606$i) {
           break;
          } else {
           $$0385536$i$phi = $$0383537$i;$$0377538$i = $1508;$$0383537$i = $$1384$i;$$0394535$i = $$2396$i;$$0397534$i = $$0394$$i;$$0385536$i = $$0385536$i$phi;
          }
         }
        }
       }
       break L470;
       break;
      }
      case 5120:  {
       $1509 = $4 << 1;
       $1510 = ($1509|0)==($2|0);
       $1511 = $5 << 1;
       $1512 = ($1511|0)==($3|0);
       $or$cond$i959 = $1510 & $1512;
       if ($or$cond$i959) {
        __ZN3osgL15halveImage_byteEijjPKaPaiii($$0$i805,$2,$3,$141,$1241,$$0$i806,$$0778,$126);
       } else {
        $1513 = (+($3|0));
        $1514 = (+($5|0));
        $1515 = $1513 / $1514;
        $1516 = (+($2|0));
        $1517 = (+($4|0));
        $1518 = $1516 / $1517;
        $1519 = (+Math_floor((+$1515)));
        $1520 = (~~(($1519)));
        $1521 = (+($1520|0));
        $1522 = $1515 - $1521;
        $1523 = (+Math_floor((+$1518)));
        $1524 = (~~(($1523)));
        $1525 = (+($1524|0));
        $1526 = $1518 - $1525;
        $1527 = $1518 * $1515;
        $1528 = ($5|0)>(0);
        if ($1528) {
         $1529 = (($3) + -1)|0;
         $1530 = ($4|0)>(0);
         $1531 = (($$0778) + ($126))|0;
         $exitcond577$i9802051 = ($$0$i805|0)==(1);
         $$phi$trans$insert611$i9822944 = ((($12)) + 4|0);
         $exitcond577$i9802945 = ($$0$i805|0)==(2);
         $$phi$trans$insert609$i10542942 = ((($12)) + 4|0);
         $exitcond568$i10522943 = ($$0$i805|0)==(2);
         $$phi$trans$insert607$i10802940 = ((($12)) + 4|0);
         $exitcond560$i10782941 = ($$0$i805|0)==(2);
         $$phi$trans$insert$i10952938 = ((($12)) + 4|0);
         $exitcond$i10932939 = ($$0$i805|0)==(2);
         $$0377538$i961 = 0;$$0383537$i962 = $1522;$$0385536$i963 = 0.0;$$0394535$i964 = $1520;$$0397534$i965 = 0;
         while(1) {
          $1532 = ($$0394535$i964|0)<($3|0);
          $$0394$$i966 = $1532 ? $$0394535$i964 : $1529;
          if ($1530) {
           $1533 = ($$0394$$i966|0)>($$0397534$i965|0);
           $1534 = Math_imul($$0397534$i965, $$0778)|0;
           $1535 = 1.0 - $$0385536$i963;
           $1536 = Math_imul($$0394$$i966, $$0778)|0;
           $$0372506$i967 = (($$0397534$i965) + 1)|0;
           $1537 = ($$0372506$i967|0)<($$0394$$i966|0);
           $1538 = Math_imul($$0372506$i967, $$0778)|0;
           $1539 = Math_imul($$0377538$i961, $4)|0;
           $1540 = $$0383537$i962 - $$0385536$i963;
           $scevgep$i968 = (($141) + ($1534)|0);
           $1541 = (($$0394$$i966) + -1)|0;
           $1542 = Math_imul($1541, $$0778)|0;
           $scevgep569$i969 = (($141) + ($1542)|0);
           $scevgep587$i970 = (($141) + ($1536)|0);
           $$0378530$i972 = 0;$$0386529$i973 = $1526;$$0388528$i974 = 0.0;$$0398527$i975 = $1524;$$0400526$i976 = 0;
           while(1) {
            $1543 = Math_imul($$0400526$i976, $126)|0;
            $1544 = ($$0398527$i975|0)>($$0400526$i976|0);
            $or$cond417$i977 = $1533 & $1544;
            ;HEAP32[$12>>2]=0|0;HEAP32[$12+4>>2]=0|0;HEAP32[$12+8>>2]=0|0;HEAP32[$12+12>>2]=0|0;
            L592: do {
             if ($or$cond417$i977) {
              $1545 = (($141) + ($1543)|0);
              $1546 = (($1545) + ($1534)|0);
              $1547 = 1.0 - $$0388528$i974;
              $1548 = $1535 * $1547;
              $1549 = HEAP8[$1546>>0]|0;
              $1550 = (+($1549<<24>>24));
              $1551 = $1548 * $1550;
              $1552 = $1551 + 0.0;
              HEAPF32[$12>>2] = $1552;
              do {
               if (!($exitcond577$i9802051)) {
                $1553 = (($1546) + ($$0$i806)|0);
                $1554 = HEAP8[$1553>>0]|0;
                $1555 = (+($1554<<24>>24));
                $1556 = $1548 * $1555;
                $1557 = $1556 + 0.0;
                HEAPF32[$$phi$trans$insert611$i9822944>>2] = $1557;
                if ($exitcond577$i9802945) {
                 break;
                } else {
                 $1558 = 2;$1560 = $1553;
                }
                while(1) {
                 $$phi$trans$insert611$i982$phi$trans$insert = (($12) + ($1558<<2)|0);
                 $$pre612$i983$pre = +HEAPF32[$$phi$trans$insert611$i982$phi$trans$insert>>2];
                 $1559 = (($1560) + ($$0$i806)|0);
                 $$phi$trans$insert611$i982 = (($12) + ($1558<<2)|0);
                 $1561 = HEAP8[$1559>>0]|0;
                 $1562 = (+($1561<<24>>24));
                 $1563 = $1548 * $1562;
                 $1564 = $$pre612$i983$pre + $1563;
                 HEAPF32[$$phi$trans$insert611$i982>>2] = $1564;
                 $1565 = (($1558) + 1)|0;
                 $exitcond577$i980 = ($1565|0)==($$0$i805|0);
                 if ($exitcond577$i980) {
                  break;
                 } else {
                  $1558 = $1565;$1560 = $1559;
                 }
                }
               }
              } while(0);
              $1566 = (($$0400526$i976) + 1)|0;
              $1567 = ($1566|0)<($$0398527$i975|0);
              $1568 = (($1546) + ($126)|0);
              if ($1567) {
               $$0374476$us$i987 = $1566;$1579 = $1568;
               while(1) {
                $$1380473$us$i989 = 0;$$1403472$us$i990 = $1579;
                while(1) {
                 $1569 = HEAP8[$$1403472$us$i990>>0]|0;
                 $1570 = (+($1569<<24>>24));
                 $1571 = $1535 * $1570;
                 $1572 = (($12) + ($$1380473$us$i989<<2)|0);
                 $1573 = +HEAPF32[$1572>>2];
                 $1574 = $1573 + $1571;
                 HEAPF32[$1572>>2] = $1574;
                 $1575 = (($$1380473$us$i989) + 1)|0;
                 $1576 = (($$1403472$us$i990) + ($$0$i806)|0);
                 $exitcond581$i991 = ($1575|0)==($$0$i805|0);
                 if ($exitcond581$i991) {
                  break;
                 } else {
                  $$1380473$us$i989 = $1575;$$1403472$us$i990 = $1576;
                 }
                }
                $1577 = (($$0374476$us$i987) + 1)|0;
                $1578 = (($1579) + ($126)|0);
                $exitcond584$i992 = ($1577|0)==($$0398527$i975|0);
                if ($exitcond584$i992) {
                 break;
                } else {
                 $$0374476$us$i987 = $1577;$1579 = $1578;
                }
               }
               $1580 = Math_imul($$0398527$i975, $126)|0;
               $scevgep583$i994 = (($scevgep$i968) + ($1580)|0);
               $$lcssa433$i996 = $scevgep583$i994;
              } else {
               $$lcssa433$i996 = $1568;
              }
              $1581 = $1535 * $$0386529$i973;
              $$2381480$i998 = 0;$$2404479$i999 = $$lcssa433$i996;
              while(1) {
               $1582 = HEAP8[$$2404479$i999>>0]|0;
               $1583 = (+($1582<<24>>24));
               $1584 = $1581 * $1583;
               $1585 = (($12) + ($$2381480$i998<<2)|0);
               $1586 = +HEAPF32[$1585>>2];
               $1587 = $1586 + $1584;
               HEAPF32[$1585>>2] = $1587;
               $1588 = (($$2381480$i998) + 1)|0;
               $1589 = (($$2404479$i999) + ($$0$i806)|0);
               $exitcond585$i1000 = ($1588|0)==($$0$i805|0);
               if ($exitcond585$i1000) {
                break;
               } else {
                $$2381480$i998 = $1588;$$2404479$i999 = $1589;
               }
              }
              $1590 = $$0383537$i962 * $1547;
              $1591 = (($1545) + ($1536)|0);
              $$3382485$i1012 = 0;$$3405484$i1013 = $1591;
              while(1) {
               $1604 = HEAP8[$$3405484$i1013>>0]|0;
               $1605 = (+($1604<<24>>24));
               $1606 = $1590 * $1605;
               $1607 = (($12) + ($$3382485$i1012<<2)|0);
               $1608 = +HEAPF32[$1607>>2];
               $1609 = $1608 + $1606;
               HEAPF32[$1607>>2] = $1609;
               $1610 = (($$3382485$i1012) + 1)|0;
               $1611 = (($$3405484$i1013) + ($$0$i806)|0);
               $exitcond586$i1014 = ($1610|0)==($$0$i805|0);
               if ($exitcond586$i1014) {
                break;
               } else {
                $$3382485$i1012 = $1610;$$3405484$i1013 = $1611;
               }
              }
              $1592 = (($1591) + ($126)|0);
              if ($1567) {
               $$1375492$us$i1005 = $1566;$1603 = $1592;
               while(1) {
                $$4406488$us$i1008 = $1603;$$4489$us$i1007 = 0;
                while(1) {
                 $1593 = HEAP8[$$4406488$us$i1008>>0]|0;
                 $1594 = (+($1593<<24>>24));
                 $1595 = $$0383537$i962 * $1594;
                 $1596 = (($12) + ($$4489$us$i1007<<2)|0);
                 $1597 = +HEAPF32[$1596>>2];
                 $1598 = $1597 + $1595;
                 HEAPF32[$1596>>2] = $1598;
                 $1599 = (($$4489$us$i1007) + 1)|0;
                 $1600 = (($$4406488$us$i1008) + ($$0$i806)|0);
                 $exitcond590$i1009 = ($1599|0)==($$0$i805|0);
                 if ($exitcond590$i1009) {
                  break;
                 } else {
                  $$4406488$us$i1008 = $1600;$$4489$us$i1007 = $1599;
                 }
                }
                $1601 = (($$1375492$us$i1005) + 1)|0;
                $1602 = (($1603) + ($126)|0);
                $exitcond593$i1010 = ($1601|0)==($$0398527$i975|0);
                if ($exitcond593$i1010) {
                 break;
                } else {
                 $$1375492$us$i1005 = $1601;$1603 = $1602;
                }
               }
               $1612 = Math_imul($$0398527$i975, $126)|0;
               $scevgep592$i1016 = (($scevgep587$i970) + ($1612)|0);
               $$lcssa434$i1018 = $scevgep592$i1016;
              } else {
               $$lcssa434$i1018 = $1592;
              }
              $1613 = $$0383537$i962 * $$0386529$i973;
              $$5407495$i1036 = $$lcssa434$i1018;$$5496$i1035 = 0;
              while(1) {
               $1629 = HEAP8[$$5407495$i1036>>0]|0;
               $1630 = (+($1629<<24>>24));
               $1631 = $1613 * $1630;
               $1632 = (($12) + ($$5496$i1035<<2)|0);
               $1633 = +HEAPF32[$1632>>2];
               $1634 = $1633 + $1631;
               HEAPF32[$1632>>2] = $1634;
               $1635 = (($$5496$i1035) + 1)|0;
               $1636 = (($$5407495$i1036) + ($$0$i806)|0);
               $exitcond594$i1037 = ($1635|0)==($$0$i805|0);
               if ($exitcond594$i1037) {
                break;
               } else {
                $$5407495$i1036 = $1636;$$5496$i1035 = $1635;
               }
              }
              if ($1537) {
               $$0370507$us$i1024 = $1546;$$0372509$us$i1022 = $$0372506$i967;$$0508$us$i1023 = $$lcssa433$i996;
              } else {
               break;
              }
              while(1) {
               $1614 = (($$0370507$us$i1024) + ($$0778)|0);
               $1615 = (($$0508$us$i1023) + ($$0778)|0);
               $$1371500$us$i1028 = $1614;$$1501$us$i1027 = $1615;$$6499$us$i1029 = 0;
               while(1) {
                $1616 = HEAP8[$$1371500$us$i1028>>0]|0;
                $1617 = (+($1616<<24>>24));
                $1618 = $1547 * $1617;
                $1619 = HEAP8[$$1501$us$i1027>>0]|0;
                $1620 = (+($1619<<24>>24));
                $1621 = $$0386529$i973 * $1620;
                $1622 = $1618 + $1621;
                $1623 = (($12) + ($$6499$us$i1029<<2)|0);
                $1624 = +HEAPF32[$1623>>2];
                $1625 = $1624 + $1622;
                HEAPF32[$1623>>2] = $1625;
                $1626 = (($$6499$us$i1029) + 1)|0;
                $1627 = (($$1371500$us$i1028) + ($$0$i806)|0);
                $1628 = (($$1501$us$i1027) + ($$0$i806)|0);
                $exitcond598$i1030 = ($1626|0)==($$0$i805|0);
                if ($exitcond598$i1030) {
                 break;
                } else {
                 $$1371500$us$i1028 = $1627;$$1501$us$i1027 = $1628;$$6499$us$i1029 = $1626;
                }
               }
               $scevgep596$i1025 = (($$0370507$us$i1024) + ($1531)|0);
               $scevgep597$i1031 = (($$0508$us$i1023) + ($1531)|0);
               $$0372$us$i1032 = (($$0372509$us$i1022) + 1)|0;
               $exitcond599$i1033 = ($$0372$us$i1032|0)==($$0394$$i966|0);
               if ($exitcond599$i1033) {
                label = 378;
                break;
               } else {
                $$0370507$us$i1024 = $scevgep596$i1025;$$0372509$us$i1022 = $$0372$us$i1032;$$0508$us$i1023 = $scevgep597$i1031;
               }
              }
             } else {
              if ($1533) {
               $1637 = $$0386529$i973 - $$0388528$i974;
               $1638 = $1535 * $1637;
               $1639 = (($141) + ($1543)|0);
               $1640 = (($1639) + ($1534)|0);
               $1641 = HEAP8[$1640>>0]|0;
               $1642 = (+($1641<<24>>24));
               $1643 = $1638 * $1642;
               $1644 = $1643 + 0.0;
               HEAPF32[$12>>2] = $1644;
               do {
                if (!($exitcond577$i9802051)) {
                 $1645 = (($1640) + ($$0$i806)|0);
                 $1646 = HEAP8[$1645>>0]|0;
                 $1647 = (+($1646<<24>>24));
                 $1648 = $1638 * $1647;
                 $1649 = $1648 + 0.0;
                 HEAPF32[$$phi$trans$insert609$i10542942>>2] = $1649;
                 if ($exitcond568$i10522943) {
                  break;
                 } else {
                  $1659 = 2;$1661 = $1645;
                 }
                 while(1) {
                  $$phi$trans$insert609$i1054$phi$trans$insert = (($12) + ($1659<<2)|0);
                  $$pre610$i1055$pre = +HEAPF32[$$phi$trans$insert609$i1054$phi$trans$insert>>2];
                  $1660 = (($1661) + ($$0$i806)|0);
                  $$phi$trans$insert609$i1054 = (($12) + ($1659<<2)|0);
                  $1662 = HEAP8[$1660>>0]|0;
                  $1663 = (+($1662<<24>>24));
                  $1664 = $1638 * $1663;
                  $1665 = $$pre610$i1055$pre + $1664;
                  HEAPF32[$$phi$trans$insert609$i1054>>2] = $1665;
                  $1666 = (($1659) + 1)|0;
                  $exitcond568$i1052 = ($1666|0)==($$0$i805|0);
                  if ($exitcond568$i1052) {
                   break;
                  } else {
                   $1659 = $1666;$1661 = $1660;
                  }
                 }
                }
               } while(0);
               if ($1537) {
                $$1373459$us$i1041 = $$0372506$i967;$$2391458$us$i1042 = $1640;
                while(1) {
                 $1650 = (($$2391458$us$i1042) + ($$0778)|0);
                 $$7409453$us$i1045 = $1650;$$8454$us$i1044 = 0;
                 while(1) {
                  $1651 = HEAP8[$$7409453$us$i1045>>0]|0;
                  $1652 = (+($1651<<24>>24));
                  $1653 = $1637 * $1652;
                  $1654 = (($12) + ($$8454$us$i1044<<2)|0);
                  $1655 = +HEAPF32[$1654>>2];
                  $1656 = $1655 + $1653;
                  HEAPF32[$1654>>2] = $1656;
                  $1657 = (($$8454$us$i1044) + 1)|0;
                  $1658 = (($$7409453$us$i1045) + ($$0$i806)|0);
                  $exitcond572$i1046 = ($1657|0)==($$0$i805|0);
                  if ($exitcond572$i1046) {
                   break;
                  } else {
                   $$7409453$us$i1045 = $1658;$$8454$us$i1044 = $1657;
                  }
                 }
                 $$1373$us$i1047 = (($$1373459$us$i1041) + 1)|0;
                 $exitcond575$i1048 = ($$1373$us$i1047|0)==($$0394$$i966|0);
                 if ($exitcond575$i1048) {
                  break;
                 } else {
                  $$1373459$us$i1041 = $$1373$us$i1047;$$2391458$us$i1042 = $1650;
                 }
                }
                $scevgep574$i1057 = (($scevgep569$i969) + ($1543)|0);
                $$2391$lcssa$i1059 = $scevgep574$i1057;
               } else {
                $$2391$lcssa$i1059 = $1640;
               }
               $1667 = $$0383537$i962 * $1637;
               $1668 = (($$2391$lcssa$i1059) + ($$0778)|0);
               $$8410463$i1062 = $1668;$$9464$i1061 = 0;
               while(1) {
                $1669 = HEAP8[$$8410463$i1062>>0]|0;
                $1670 = (+($1669<<24>>24));
                $1671 = $1667 * $1670;
                $1672 = (($12) + ($$9464$i1061<<2)|0);
                $1673 = +HEAPF32[$1672>>2];
                $1674 = $1673 + $1671;
                HEAPF32[$1672>>2] = $1674;
                $1675 = (($$9464$i1061) + 1)|0;
                $1676 = (($$8410463$i1062) + ($$0$i806)|0);
                $exitcond576$i1063 = ($1675|0)==($$0$i805|0);
                if ($exitcond576$i1063) {
                 label = 378;
                 break L592;
                } else {
                 $$8410463$i1062 = $1676;$$9464$i1061 = $1675;
                }
               }
              }
              if (!($1544)) {
               $1720 = $$0386529$i973 - $$0388528$i974;
               $1721 = $1540 * $1720;
               $1722 = (($141) + ($1543)|0);
               $1723 = (($1722) + ($1534)|0);
               $1724 = HEAP8[$1723>>0]|0;
               $1725 = (+($1724<<24>>24));
               $1726 = $1721 * $1725;
               $1727 = $1726 + 0.0;
               HEAPF32[$12>>2] = $1727;
               if ($exitcond577$i9802051) {
                label = 378;
                break;
               }
               $1728 = (($1723) + ($$0$i806)|0);
               $1729 = HEAP8[$1728>>0]|0;
               $1730 = (+($1729<<24>>24));
               $1731 = $1721 * $1730;
               $1732 = $1731 + 0.0;
               HEAPF32[$$phi$trans$insert$i10952938>>2] = $1732;
               if ($exitcond$i10932939) {
                label = 378;
                break;
               } else {
                $1733 = 2;$1735 = $1728;
               }
               while(1) {
                $$phi$trans$insert$i1095$phi$trans$insert = (($12) + ($1733<<2)|0);
                $$pre$i1096$pre = +HEAPF32[$$phi$trans$insert$i1095$phi$trans$insert>>2];
                $1734 = (($1735) + ($$0$i806)|0);
                $$phi$trans$insert$i1095 = (($12) + ($1733<<2)|0);
                $1736 = HEAP8[$1734>>0]|0;
                $1737 = (+($1736<<24>>24));
                $1738 = $1721 * $1737;
                $1739 = $$pre$i1096$pre + $1738;
                HEAPF32[$$phi$trans$insert$i1095>>2] = $1739;
                $1740 = (($1733) + 1)|0;
                $exitcond$i1093 = ($1740|0)==($$0$i805|0);
                if ($exitcond$i1093) {
                 label = 378;
                 break L592;
                } else {
                 $1733 = $1740;$1735 = $1734;
                }
               }
              }
              $1677 = 1.0 - $$0388528$i974;
              $1678 = $1540 * $1677;
              $1679 = (($141) + ($1543)|0);
              $1680 = (($1679) + ($1534)|0);
              $1681 = HEAP8[$1680>>0]|0;
              $1682 = (+($1681<<24>>24));
              $1683 = $1678 * $1682;
              $1684 = $1683 + 0.0;
              HEAPF32[$12>>2] = $1684;
              do {
               if (!($exitcond577$i9802051)) {
                $1685 = (($1680) + ($$0$i806)|0);
                $1686 = HEAP8[$1685>>0]|0;
                $1687 = (+($1686<<24>>24));
                $1688 = $1678 * $1687;
                $1689 = $1688 + 0.0;
                HEAPF32[$$phi$trans$insert607$i10802940>>2] = $1689;
                if ($exitcond560$i10782941) {
                 break;
                } else {
                 $1702 = 2;$1704 = $1685;
                }
                while(1) {
                 $$phi$trans$insert607$i1080$phi$trans$insert = (($12) + ($1702<<2)|0);
                 $$pre608$i1081$pre = +HEAPF32[$$phi$trans$insert607$i1080$phi$trans$insert>>2];
                 $1703 = (($1704) + ($$0$i806)|0);
                 $$phi$trans$insert607$i1080 = (($12) + ($1702<<2)|0);
                 $1705 = HEAP8[$1703>>0]|0;
                 $1706 = (+($1705<<24>>24));
                 $1707 = $1678 * $1706;
                 $1708 = $$pre608$i1081$pre + $1707;
                 HEAPF32[$$phi$trans$insert607$i1080>>2] = $1708;
                 $1709 = (($1702) + 1)|0;
                 $exitcond560$i1078 = ($1709|0)==($$0$i805|0);
                 if ($exitcond560$i1078) {
                  break;
                 } else {
                  $1702 = $1709;$1704 = $1703;
                 }
                }
               }
              } while(0);
              $$2376443$i1065 = (($$0400526$i976) + 1)|0;
              $1690 = ($$2376443$i1065|0)<($$0398527$i975|0);
              $1691 = (($1680) + ($126)|0);
              if ($1690) {
               $$2376444$us$i1068 = $$2376443$i1065;$1701 = $1691;
               while(1) {
                $$10412440$us$i1071 = $1701;$$11441$us$i1070 = 0;
                while(1) {
                 $1692 = HEAP8[$$10412440$us$i1071>>0]|0;
                 $1693 = (+($1692<<24>>24));
                 $1694 = $1540 * $1693;
                 $1695 = (($12) + ($$11441$us$i1070<<2)|0);
                 $1696 = +HEAPF32[$1695>>2];
                 $1697 = $1696 + $1694;
                 HEAPF32[$1695>>2] = $1697;
                 $1698 = (($$11441$us$i1070) + 1)|0;
                 $1699 = (($$10412440$us$i1071) + ($$0$i806)|0);
                 $exitcond563$i1072 = ($1698|0)==($$0$i805|0);
                 if ($exitcond563$i1072) {
                  break;
                 } else {
                  $$10412440$us$i1071 = $1699;$$11441$us$i1070 = $1698;
                 }
                }
                $$2376$us$i1073 = (($$2376444$us$i1068) + 1)|0;
                $1700 = (($1701) + ($126)|0);
                $exitcond566$i1074 = ($$2376$us$i1073|0)==($$0398527$i975|0);
                if ($exitcond566$i1074) {
                 break;
                } else {
                 $$2376444$us$i1068 = $$2376$us$i1073;$1701 = $1700;
                }
               }
               $1710 = Math_imul($$0398527$i975, $126)|0;
               $scevgep565$i1083 = (($scevgep$i968) + ($1710)|0);
               $$lcssa$i1085 = $scevgep565$i1083;
              } else {
               $$lcssa$i1085 = $1691;
              }
              $1711 = $1540 * $$0386529$i973;
              $$11413445$i1088 = $$lcssa$i1085;$$12446$i1087 = 0;
              while(1) {
               $1712 = HEAP8[$$11413445$i1088>>0]|0;
               $1713 = (+($1712<<24>>24));
               $1714 = $1711 * $1713;
               $1715 = (($12) + ($$12446$i1087<<2)|0);
               $1716 = +HEAPF32[$1715>>2];
               $1717 = $1716 + $1714;
               HEAPF32[$1715>>2] = $1717;
               $1718 = (($$12446$i1087) + 1)|0;
               $1719 = (($$11413445$i1088) + ($$0$i806)|0);
               $exitcond567$i1089 = ($1718|0)==($$0$i805|0);
               if ($exitcond567$i1089) {
                label = 378;
                break;
               } else {
                $$11413445$i1088 = $1719;$$12446$i1087 = $1718;
               }
              }
             }
            } while(0);
            do {
             if ((label|0) == 378) {
              label = 0;
              if (!($1537)) {
               break;
              }
              $$3515$i1099 = (($$0400526$i976) + 1)|0;
              $$not$i1103 = ($$3515$i1099|0)<($$0398527$i975|0);
              if (!($$not$i1103)) {
               break;
              }
              $1741 = (($141) + ($1543)|0);
              $1742 = (($1741) + ($126)|0);
              $1743 = (($1742) + ($1538)|0);
              $$0401519$i1102$us = $1743;$$2520$i1101$us = $$0372506$i967;
              while(1) {
               $$3517$us$i1105$us = $$3515$i1099;$$4393516$us$i1106$us = $$0401519$i1102$us;
               while(1) {
                $$13415511$us$i1109$us = $$4393516$us$i1106$us;$$14512$us$i1108$us = 0;
                while(1) {
                 $1744 = HEAP8[$$13415511$us$i1109$us>>0]|0;
                 $1745 = (+($1744<<24>>24));
                 $1746 = (($12) + ($$14512$us$i1108$us<<2)|0);
                 $1747 = +HEAPF32[$1746>>2];
                 $1748 = $1747 + $1745;
                 HEAPF32[$1746>>2] = $1748;
                 $1749 = (($$14512$us$i1108$us) + 1)|0;
                 $1750 = (($$13415511$us$i1109$us) + ($$0$i806)|0);
                 $exitcond601$i1110$us = ($1749|0)==($$0$i805|0);
                 if ($exitcond601$i1110$us) {
                  break;
                 } else {
                  $$13415511$us$i1109$us = $1750;$$14512$us$i1108$us = $1749;
                 }
                }
                $1751 = (($$4393516$us$i1106$us) + ($126)|0);
                $$3$us$i1111$us = (($$3517$us$i1105$us) + 1)|0;
                $exitcond602$i1112$us = ($$3$us$i1111$us|0)==($$0398527$i975|0);
                if ($exitcond602$i1112$us) {
                 break;
                } else {
                 $$3517$us$i1105$us = $$3$us$i1111$us;$$4393516$us$i1106$us = $1751;
                }
               }
               $1752 = (($$0401519$i1102$us) + ($$0778)|0);
               $1753 = (($$2520$i1101$us) + 1)|0;
               $exitcond603$i1114$us = ($1753|0)==($$0394$$i966|0);
               if ($exitcond603$i1114$us) {
                break;
               } else {
                $$0401519$i1102$us = $1752;$$2520$i1101$us = $1753;
               }
              }
             }
            } while(0);
            $1754 = (($$0378530$i972) + ($1539))|0;
            $1755 = Math_imul($1754, $$0$i805)|0;
            $$15522$i1117 = 0;
            while(1) {
             $1756 = (($12) + ($$15522$i1117<<2)|0);
             $1757 = +HEAPF32[$1756>>2];
             $1758 = $1757 / $1527;
             $1759 = (~~(($1758)));
             $1760 = (($$15522$i1117) + ($1755))|0;
             $1761 = (($1241) + ($1760)|0);
             HEAP8[$1761>>0] = $1759;
             $1762 = (($$15522$i1117) + 1)|0;
             $exitcond604$i1118 = ($1762|0)==($$0$i805|0);
             if ($exitcond604$i1118) {
              break;
             } else {
              $$15522$i1117 = $1762;
             }
            }
            $1763 = (($$0398527$i975) + ($1524))|0;
            $1764 = $1526 + $$0386529$i973;
            $1765 = $1764 > 1.0;
            $1766 = $1764 + -1.0;
            $1767 = $1765&1;
            $$1399$i1120 = (($1763) + ($1767))|0;
            $$1387$i1121 = $1765 ? $1766 : $1764;
            $1768 = (($$0378530$i972) + 1)|0;
            $exitcond605$i1122 = ($1768|0)==($4|0);
            if ($exitcond605$i1122) {
             break;
            } else {
             $$0400526$i976$phi = $$0398527$i975;$$0388528$i974$phi = $$0386529$i973;$$0378530$i972 = $1768;$$0386529$i973 = $$1387$i1121;$$0398527$i975 = $$1399$i1120;$$0400526$i976 = $$0400526$i976$phi;$$0388528$i974 = $$0388528$i974$phi;
            }
           }
          }
          $1769 = $1522 + $$0383537$i962;
          $1770 = $1769 > 1.0;
          $1771 = $1769 + -1.0;
          $1772 = $1770&1;
          $1773 = (($1772) + ($1520))|0;
          $$2396$i1124 = (($1773) + ($$0394$$i966))|0;
          $$1384$i1125 = $1770 ? $1771 : $1769;
          $1774 = (($$0377538$i961) + 1)|0;
          $exitcond606$i1126 = ($1774|0)==($5|0);
          if ($exitcond606$i1126) {
           break;
          } else {
           $$0385536$i963$phi = $$0383537$i962;$$0377538$i961 = $1774;$$0383537$i962 = $$1384$i1125;$$0394535$i964 = $$2396$i1124;$$0397534$i965 = $$0394$$i966;$$0385536$i963 = $$0385536$i963$phi;
          }
         }
        }
       }
       break L470;
       break;
      }
      case 5123:  {
       $1775 = $4 << 1;
       $1776 = ($1775|0)==($2|0);
       $1777 = $5 << 1;
       $1778 = ($1777|0)==($3|0);
       $or$cond$i1128 = $1776 & $1778;
       if ($or$cond$i1128) {
        __ZN3osgL17halveImage_ushortEijjPKtPtiiii($$0$i805,$2,$3,$141,$1241,$$0$i806,$$0778,$126,$$785);
       } else {
        $1779 = (+($3|0));
        $1780 = (+($5|0));
        $1781 = $1779 / $1780;
        $1782 = (+($2|0));
        $1783 = (+($4|0));
        $1784 = $1782 / $1783;
        $1785 = (+Math_floor((+$1781)));
        $1786 = (~~(($1785)));
        $1787 = (+($1786|0));
        $1788 = $1781 - $1787;
        $1789 = (+Math_floor((+$1784)));
        $1790 = (~~(($1789)));
        $1791 = (+($1790|0));
        $1792 = $1784 - $1791;
        $1793 = $1784 * $1781;
        $1794 = ($5|0)>(0);
        if ($1794) {
         $1795 = (($3) + -1)|0;
         $1796 = ($4|0)>(0);
         $1797 = ($$785|0)==(0);
         $1798 = (($$0778) + ($126))|0;
         $exitcond750$i2075 = ($$0$i805|0)==(1);
         $$phi$trans$insert793$i2967 = ((($12)) + 4|0);
         $exitcond750$i2969 = ($$0$i805|0)==(2);
         $$phi$trans$insert791$i2964 = ((($12)) + 4|0);
         $exitcond749$i2966 = ($$0$i805|0)==(2);
         $$phi$trans$insert789$i2961 = ((($12)) + 4|0);
         $exitcond741$i2963 = ($$0$i805|0)==(2);
         $$phi$trans$insert787$i2958 = ((($12)) + 4|0);
         $exitcond740$i2960 = ($$0$i805|0)==(2);
         $$phi$trans$insert785$i2955 = ((($12)) + 4|0);
         $exitcond734$i2957 = ($$0$i805|0)==(2);
         $$phi$trans$insert783$i2952 = ((($12)) + 4|0);
         $exitcond733$i2954 = ($$0$i805|0)==(2);
         $$phi$trans$insert781$i2949 = ((($12)) + 4|0);
         $exitcond732$i2951 = ($$0$i805|0)==(2);
         $$phi$trans$insert$i11372946 = ((($12)) + 4|0);
         $exitcond$i11352948 = ($$0$i805|0)==(2);
         $$0527703$i = 0;$$0533702$i = $1788;$$0535701$i = 0.0;$$0544700$i = $1786;$$0547699$i = 0;
         while(1) {
          $1799 = ($$0544700$i|0)<($3|0);
          $$0544$$i = $1799 ? $$0544700$i : $1795;
          if ($1796) {
           $1800 = ($$0544$$i|0)>($$0547699$i|0);
           $1801 = Math_imul($$0547699$i, $$0778)|0;
           $1802 = 1.0 - $$0535701$i;
           $1803 = Math_imul($$0544$$i, $$0778)|0;
           $$0522671$i = (($$0547699$i) + 1)|0;
           $1804 = ($$0522671$i|0)<($$0544$$i|0);
           $1805 = Math_imul($$0522671$i, $$0778)|0;
           $1806 = Math_imul($$0527703$i, $4)|0;
           $1807 = $$0533702$i - $$0535701$i;
           $uglygep$i = (($141) + ($1801)|0);
           $1808 = (($$0544$$i) + -1)|0;
           $1809 = Math_imul($1808, $$0778)|0;
           $uglygep744$i = (($141) + ($1809)|0);
           $uglygep762$i = (($141) + ($1803)|0);
           $$0528695$i = 0;$$0536694$i = $1792;$$0538693$i = 0.0;$$0548692$i = $1790;$$0550691$i = 0;
           while(1) {
            $1810 = Math_imul($$0550691$i, $126)|0;
            $1811 = ($$0548692$i|0)>($$0550691$i|0);
            $or$cond579$i = $1800 & $1811;
            ;HEAP32[$12>>2]=0|0;HEAP32[$12+4>>2]=0|0;HEAP32[$12+8>>2]=0|0;HEAP32[$12+12>>2]=0|0;
            L698: do {
             if ($or$cond579$i) {
              $1812 = (($141) + ($1810)|0);
              $1813 = (($1812) + ($1801)|0);
              $1814 = 1.0 - $$0538693$i;
              $1815 = $1802 * $1814;
              do {
               if ($1797) {
                $1835 = HEAP16[$1813>>1]|0;
                $1836 = (+($1835&65535));
                $$sink3$us$i2074 = $1815 * $1836;
                $1837 = $$sink3$us$i2074 + 0.0;
                HEAPF32[$12>>2] = $1837;
                if ($exitcond750$i2075) {
                 break;
                }
                $1838 = (($1813) + ($$0$i806)|0);
                $1839 = HEAP16[$1838>>1]|0;
                $1840 = (+($1839&65535));
                $$sink3$us$i2968 = $1815 * $1840;
                $1841 = $$sink3$us$i2968 + 0.0;
                HEAPF32[$$phi$trans$insert793$i2967>>2] = $1841;
                if ($exitcond750$i2969) {
                 break;
                } else {
                 $1842 = 2;$1844 = $1838;
                }
                while(1) {
                 $$phi$trans$insert793$i$phi$trans$insert = (($12) + ($1842<<2)|0);
                 $$pre794$i$pre = +HEAPF32[$$phi$trans$insert793$i$phi$trans$insert>>2];
                 $1843 = (($1844) + ($$0$i806)|0);
                 $$phi$trans$insert793$i = (($12) + ($1842<<2)|0);
                 $1845 = HEAP16[$1843>>1]|0;
                 $1846 = (+($1845&65535));
                 $$sink3$us$i = $1815 * $1846;
                 $1847 = $$pre794$i$pre + $$sink3$us$i;
                 HEAPF32[$$phi$trans$insert793$i>>2] = $1847;
                 $1848 = (($1842) + 1)|0;
                 $exitcond750$i = ($1848|0)==($$0$i805|0);
                 if ($exitcond750$i) {
                  break;
                 } else {
                  $1842 = $1848;$1844 = $1843;
                 }
                }
               } else {
                $1816 = ((($1813)) + 1|0);
                $1817 = HEAP8[$1816>>0]|0;
                $1818 = $1817&255;
                $1819 = $1818 << 8;
                $1820 = HEAP8[$1813>>0]|0;
                $1821 = $1820&255;
                $1822 = $1819 | $1821;
                $1823 = (+($1822|0));
                $$sink3$i2071 = $1815 * $1823;
                $1824 = $$sink3$i2071 + 0.0;
                HEAPF32[$12>>2] = $1824;
                if ($exitcond750$i2075) {
                 break;
                }
                $1825 = (($1813) + ($$0$i806)|0);
                $1826 = ((($1825)) + 1|0);
                $1827 = HEAP8[$1826>>0]|0;
                $1828 = $1827&255;
                $1829 = $1828 << 8;
                $1830 = HEAP8[$1825>>0]|0;
                $1831 = $1830&255;
                $1832 = $1829 | $1831;
                $1833 = (+($1832|0));
                $$sink3$i2965 = $1815 * $1833;
                $1834 = $$sink3$i2965 + 0.0;
                HEAPF32[$$phi$trans$insert791$i2964>>2] = $1834;
                if ($exitcond749$i2966) {
                 break;
                } else {
                 $1849 = 2;$1851 = $1825;
                }
                while(1) {
                 $$phi$trans$insert791$i$phi$trans$insert = (($12) + ($1849<<2)|0);
                 $$pre792$i$pre = +HEAPF32[$$phi$trans$insert791$i$phi$trans$insert>>2];
                 $1850 = (($1851) + ($$0$i806)|0);
                 $$phi$trans$insert791$i = (($12) + ($1849<<2)|0);
                 $1852 = ((($1850)) + 1|0);
                 $1853 = HEAP8[$1852>>0]|0;
                 $1854 = $1853&255;
                 $1855 = $1854 << 8;
                 $1856 = HEAP8[$1850>>0]|0;
                 $1857 = $1856&255;
                 $1858 = $1855 | $1857;
                 $1859 = (+($1858|0));
                 $$sink3$i = $1815 * $1859;
                 $1860 = $$pre792$i$pre + $$sink3$i;
                 HEAPF32[$$phi$trans$insert791$i>>2] = $1860;
                 $1861 = (($1849) + 1)|0;
                 $exitcond749$i = ($1861|0)==($$0$i805|0);
                 if ($exitcond749$i) {
                  break;
                 } else {
                  $1849 = $1861;$1851 = $1850;
                 }
                }
               }
              } while(0);
              $1862 = (($$0550691$i) + 1)|0;
              $1863 = ($1862|0)<($$0548692$i|0);
              $1864 = (($1813) + ($126)|0);
              if ($1863) {
               $1865 = Math_imul($$0548692$i, $126)|0;
               if ($1797) {
                $$0524641$i$us = $1862;$1875 = $1864;
                while(1) {
                 $$1530638$us$i$us = 0;$$1553637$us$i$us = $1875;
                 while(1) {
                  $1866 = HEAP16[$$1553637$us$i$us>>1]|0;
                  $1867 = (+($1866&65535));
                  $$sink7$us$i$us = $1802 * $1867;
                  $1868 = (($12) + ($$1530638$us$i$us<<2)|0);
                  $1869 = +HEAPF32[$1868>>2];
                  $1870 = $1869 + $$sink7$us$i$us;
                  HEAPF32[$1868>>2] = $1870;
                  $1871 = (($$1530638$us$i$us) + 1)|0;
                  $1872 = (($$1553637$us$i$us) + ($$0$i806)|0);
                  $exitcond752$i$us = ($1871|0)==($$0$i805|0);
                  if ($exitcond752$i$us) {
                   break;
                  } else {
                   $$1530638$us$i$us = $1871;$$1553637$us$i$us = $1872;
                  }
                 }
                 $1873 = (($$0524641$i$us) + 1)|0;
                 $1874 = (($1875) + ($126)|0);
                 $exitcond755$i$us = ($1873|0)==($$0548692$i|0);
                 if ($exitcond755$i$us) {
                  break;
                 } else {
                  $$0524641$i$us = $1873;$1875 = $1874;
                 }
                }
               } else {
                $$0524641$i = $1862;$1891 = $1864;
                while(1) {
                 $$1530638$i = 0;$$1553637$i = $1891;
                 while(1) {
                  $1876 = ((($$1553637$i)) + 1|0);
                  $1877 = HEAP8[$1876>>0]|0;
                  $1878 = $1877&255;
                  $1879 = $1878 << 8;
                  $1880 = HEAP8[$$1553637$i>>0]|0;
                  $1881 = $1880&255;
                  $1882 = $1879 | $1881;
                  $1883 = (+($1882|0));
                  $$sink7$i = $1802 * $1883;
                  $1884 = (($12) + ($$1530638$i<<2)|0);
                  $1885 = +HEAPF32[$1884>>2];
                  $1886 = $1885 + $$sink7$i;
                  HEAPF32[$1884>>2] = $1886;
                  $1887 = (($$1530638$i) + 1)|0;
                  $1888 = (($$1553637$i) + ($$0$i806)|0);
                  $exitcond751$i = ($1887|0)==($$0$i805|0);
                  if ($exitcond751$i) {
                   break;
                  } else {
                   $$1530638$i = $1887;$$1553637$i = $1888;
                  }
                 }
                 $1889 = (($$0524641$i) + 1)|0;
                 $1890 = (($1891) + ($126)|0);
                 $exitcond755$i = ($1889|0)==($$0548692$i|0);
                 if ($exitcond755$i) {
                  break;
                 } else {
                  $$0524641$i = $1889;$1891 = $1890;
                 }
                }
               }
               $scevgep754$i = (($uglygep$i) + ($1865)|0);
               $$lcssa598$i = $scevgep754$i;
              } else {
               $$lcssa598$i = $1864;
              }
              $1892 = $1802 * $$0536694$i;
              if ($1797) {
               $$2531645$us$i = 0;$$2554644$us$i = $$lcssa598$i;
               while(1) {
                $1893 = HEAP16[$$2554644$us$i>>1]|0;
                $1894 = (+($1893&65535));
                $$sink12$us$i = $1892 * $1894;
                $1895 = (($12) + ($$2531645$us$i<<2)|0);
                $1896 = +HEAPF32[$1895>>2];
                $1897 = $1896 + $$sink12$us$i;
                HEAPF32[$1895>>2] = $1897;
                $1898 = (($$2531645$us$i) + 1)|0;
                $1899 = (($$2554644$us$i) + ($$0$i806)|0);
                $exitcond757$i = ($1898|0)==($$0$i805|0);
                if ($exitcond757$i) {
                 break;
                } else {
                 $$2531645$us$i = $1898;$$2554644$us$i = $1899;
                }
               }
              } else {
               $$2531645$i = 0;$$2554644$i = $$lcssa598$i;
               while(1) {
                $1900 = ((($$2554644$i)) + 1|0);
                $1901 = HEAP8[$1900>>0]|0;
                $1902 = $1901&255;
                $1903 = $1902 << 8;
                $1904 = HEAP8[$$2554644$i>>0]|0;
                $1905 = $1904&255;
                $1906 = $1903 | $1905;
                $1907 = (+($1906|0));
                $$sink12$i = $1892 * $1907;
                $1908 = (($12) + ($$2531645$i<<2)|0);
                $1909 = +HEAPF32[$1908>>2];
                $1910 = $1909 + $$sink12$i;
                HEAPF32[$1908>>2] = $1910;
                $1911 = (($$2531645$i) + 1)|0;
                $1912 = (($$2554644$i) + ($$0$i806)|0);
                $exitcond756$i = ($1911|0)==($$0$i805|0);
                if ($exitcond756$i) {
                 break;
                } else {
                 $$2531645$i = $1911;$$2554644$i = $1912;
                }
               }
              }
              $1913 = $$0533702$i * $1814;
              $1914 = (($1812) + ($1803)|0);
              if ($1797) {
               $$3532650$us$i = 0;$$3555649$us$i = $1914;
               while(1) {
                $1915 = HEAP16[$$3555649$us$i>>1]|0;
                $1916 = (+($1915&65535));
                $$sink17$us$i = $1913 * $1916;
                $1917 = (($12) + ($$3532650$us$i<<2)|0);
                $1918 = +HEAPF32[$1917>>2];
                $1919 = $1918 + $$sink17$us$i;
                HEAPF32[$1917>>2] = $1919;
                $1920 = (($$3532650$us$i) + 1)|0;
                $1921 = (($$3555649$us$i) + ($$0$i806)|0);
                $exitcond759$i = ($1920|0)==($$0$i805|0);
                if ($exitcond759$i) {
                 break;
                } else {
                 $$3532650$us$i = $1920;$$3555649$us$i = $1921;
                }
               }
              } else {
               $$3532650$i = 0;$$3555649$i = $1914;
               while(1) {
                $1934 = ((($$3555649$i)) + 1|0);
                $1935 = HEAP8[$1934>>0]|0;
                $1936 = $1935&255;
                $1937 = $1936 << 8;
                $1938 = HEAP8[$$3555649$i>>0]|0;
                $1939 = $1938&255;
                $1940 = $1937 | $1939;
                $1941 = (+($1940|0));
                $$sink17$i = $1913 * $1941;
                $1942 = (($12) + ($$3532650$i<<2)|0);
                $1943 = +HEAPF32[$1942>>2];
                $1944 = $1943 + $$sink17$i;
                HEAPF32[$1942>>2] = $1944;
                $1945 = (($$3532650$i) + 1)|0;
                $1946 = (($$3555649$i) + ($$0$i806)|0);
                $exitcond758$i = ($1945|0)==($$0$i805|0);
                if ($exitcond758$i) {
                 break;
                } else {
                 $$3532650$i = $1945;$$3555649$i = $1946;
                }
               }
              }
              $1922 = (($1914) + ($126)|0);
              if ($1863) {
               $1923 = Math_imul($$0548692$i, $126)|0;
               if ($1797) {
                $$1525657$i$us = $1862;$1933 = $1922;
                while(1) {
                 $$4556653$us$i$us = $1933;$$4654$us$i$us = 0;
                 while(1) {
                  $1924 = HEAP16[$$4556653$us$i$us>>1]|0;
                  $1925 = (+($1924&65535));
                  $$sink22$us$i$us = $$0533702$i * $1925;
                  $1926 = (($12) + ($$4654$us$i$us<<2)|0);
                  $1927 = +HEAPF32[$1926>>2];
                  $1928 = $1927 + $$sink22$us$i$us;
                  HEAPF32[$1926>>2] = $1928;
                  $1929 = (($$4654$us$i$us) + 1)|0;
                  $1930 = (($$4556653$us$i$us) + ($$0$i806)|0);
                  $exitcond761$i$us = ($1929|0)==($$0$i805|0);
                  if ($exitcond761$i$us) {
                   break;
                  } else {
                   $$4556653$us$i$us = $1930;$$4654$us$i$us = $1929;
                  }
                 }
                 $1931 = (($$1525657$i$us) + 1)|0;
                 $1932 = (($1933) + ($126)|0);
                 $exitcond764$i$us = ($1931|0)==($$0548692$i|0);
                 if ($exitcond764$i$us) {
                  break;
                 } else {
                  $$1525657$i$us = $1931;$1933 = $1932;
                 }
                }
               } else {
                $$1525657$i = $1862;$1962 = $1922;
                while(1) {
                 $$4556653$i = $1962;$$4654$i = 0;
                 while(1) {
                  $1947 = ((($$4556653$i)) + 1|0);
                  $1948 = HEAP8[$1947>>0]|0;
                  $1949 = $1948&255;
                  $1950 = $1949 << 8;
                  $1951 = HEAP8[$$4556653$i>>0]|0;
                  $1952 = $1951&255;
                  $1953 = $1950 | $1952;
                  $1954 = (+($1953|0));
                  $$sink22$i = $$0533702$i * $1954;
                  $1955 = (($12) + ($$4654$i<<2)|0);
                  $1956 = +HEAPF32[$1955>>2];
                  $1957 = $1956 + $$sink22$i;
                  HEAPF32[$1955>>2] = $1957;
                  $1958 = (($$4654$i) + 1)|0;
                  $1959 = (($$4556653$i) + ($$0$i806)|0);
                  $exitcond760$i = ($1958|0)==($$0$i805|0);
                  if ($exitcond760$i) {
                   break;
                  } else {
                   $$4556653$i = $1959;$$4654$i = $1958;
                  }
                 }
                 $1960 = (($$1525657$i) + 1)|0;
                 $1961 = (($1962) + ($126)|0);
                 $exitcond764$i = ($1960|0)==($$0548692$i|0);
                 if ($exitcond764$i) {
                  break;
                 } else {
                  $$1525657$i = $1960;$1962 = $1961;
                 }
                }
               }
               $scevgep763$i = (($uglygep762$i) + ($1923)|0);
               $$lcssa599$i = $scevgep763$i;
              } else {
               $$lcssa599$i = $1922;
              }
              $1963 = $$0533702$i * $$0536694$i;
              if ($1797) {
               $$5557660$us$i = $$lcssa599$i;$$5661$us$i = 0;
               while(1) {
                $1964 = HEAP16[$$5557660$us$i>>1]|0;
                $1965 = (+($1964&65535));
                $$sink27$us$i = $1963 * $1965;
                $1966 = (($12) + ($$5661$us$i<<2)|0);
                $1967 = +HEAPF32[$1966>>2];
                $1968 = $1967 + $$sink27$us$i;
                HEAPF32[$1966>>2] = $1968;
                $1969 = (($$5661$us$i) + 1)|0;
                $1970 = (($$5557660$us$i) + ($$0$i806)|0);
                $exitcond766$i = ($1969|0)==($$0$i805|0);
                if ($exitcond766$i) {
                 break;
                } else {
                 $$5557660$us$i = $1970;$$5661$us$i = $1969;
                }
               }
              } else {
               $$5557660$i = $$lcssa599$i;$$5661$i = 0;
               while(1) {
                $1985 = ((($$5557660$i)) + 1|0);
                $1986 = HEAP8[$1985>>0]|0;
                $1987 = $1986&255;
                $1988 = $1987 << 8;
                $1989 = HEAP8[$$5557660$i>>0]|0;
                $1990 = $1989&255;
                $1991 = $1988 | $1990;
                $1992 = (+($1991|0));
                $$sink27$i = $1963 * $1992;
                $1993 = (($12) + ($$5661$i<<2)|0);
                $1994 = +HEAPF32[$1993>>2];
                $1995 = $1994 + $$sink27$i;
                HEAPF32[$1993>>2] = $1995;
                $1996 = (($$5661$i) + 1)|0;
                $1997 = (($$5557660$i) + ($$0$i806)|0);
                $exitcond765$i = ($1996|0)==($$0$i805|0);
                if ($exitcond765$i) {
                 break;
                } else {
                 $$5557660$i = $1997;$$5661$i = $1996;
                }
               }
              }
              if (!($1804)) {
               break;
              }
              if ($1797) {
               $$0520672$i$us = $1813;$$0522674$i$us = $$0522671$i;$$0673$i$us = $$lcssa598$i;
               while(1) {
                $1971 = (($$0520672$i$us) + ($$0778)|0);
                $1972 = (($$0673$i$us) + ($$0778)|0);
                $$1521665$us$i$us = $1971;$$1666$us$i$us = $1972;$$6664$us$i$us = 0;
                while(1) {
                 $1973 = HEAP16[$$1521665$us$i$us>>1]|0;
                 $1974 = (+($1973&65535));
                 $1975 = HEAP16[$$1666$us$i$us>>1]|0;
                 $1976 = (+($1975&65535));
                 $$sink$us$i$us = $1814 * $1974;
                 $1977 = $$0536694$i * $1976;
                 $1978 = $$sink$us$i$us + $1977;
                 $1979 = (($12) + ($$6664$us$i$us<<2)|0);
                 $1980 = +HEAPF32[$1979>>2];
                 $1981 = $1980 + $1978;
                 HEAPF32[$1979>>2] = $1981;
                 $1982 = (($$6664$us$i$us) + 1)|0;
                 $1983 = (($$1521665$us$i$us) + ($$0$i806)|0);
                 $1984 = (($$1666$us$i$us) + ($$0$i806)|0);
                 $exitcond772$i$us = ($1982|0)==($$0$i805|0);
                 if ($exitcond772$i$us) {
                  break;
                 } else {
                  $$1521665$us$i$us = $1983;$$1666$us$i$us = $1984;$$6664$us$i$us = $1982;
                 }
                }
                $scevgep770$i$us = (($$0520672$i$us) + ($1798)|0);
                $scevgep768$i$us = (($$0673$i$us) + ($1798)|0);
                $$0522$i$us = (($$0522674$i$us) + 1)|0;
                $exitcond773$i$us = ($$0522$i$us|0)==($$0544$$i|0);
                if ($exitcond773$i$us) {
                 label = 487;
                 break;
                } else {
                 $$0520672$i$us = $scevgep770$i$us;$$0522674$i$us = $$0522$i$us;$$0673$i$us = $scevgep768$i$us;
                }
               }
              } else {
               $$0520672$i = $1813;$$0522674$i = $$0522671$i;$$0673$i = $$lcssa598$i;
               while(1) {
                $1998 = (($$0520672$i) + ($$0778)|0);
                $1999 = (($$0673$i) + ($$0778)|0);
                $$1521665$i = $1998;$$1666$i = $1999;$$6664$i = 0;
                while(1) {
                 $2000 = ((($$1521665$i)) + 1|0);
                 $2001 = HEAP8[$2000>>0]|0;
                 $2002 = $2001&255;
                 $2003 = $2002 << 8;
                 $2004 = HEAP8[$$1521665$i>>0]|0;
                 $2005 = $2004&255;
                 $2006 = $2003 | $2005;
                 $2007 = (+($2006|0));
                 $2008 = ((($$1666$i)) + 1|0);
                 $2009 = HEAP8[$2008>>0]|0;
                 $2010 = $2009&255;
                 $2011 = $2010 << 8;
                 $2012 = HEAP8[$$1666$i>>0]|0;
                 $2013 = $2012&255;
                 $2014 = $2011 | $2013;
                 $2015 = (+($2014|0));
                 $$sink$i = $1814 * $2007;
                 $2016 = $$0536694$i * $2015;
                 $2017 = $$sink$i + $2016;
                 $2018 = (($12) + ($$6664$i<<2)|0);
                 $2019 = +HEAPF32[$2018>>2];
                 $2020 = $2019 + $2017;
                 HEAPF32[$2018>>2] = $2020;
                 $2021 = (($$6664$i) + 1)|0;
                 $2022 = (($$1521665$i) + ($$0$i806)|0);
                 $2023 = (($$1666$i) + ($$0$i806)|0);
                 $exitcond769$i = ($2021|0)==($$0$i805|0);
                 if ($exitcond769$i) {
                  break;
                 } else {
                  $$1521665$i = $2022;$$1666$i = $2023;$$6664$i = $2021;
                 }
                }
                $scevgep770$i = (($$0520672$i) + ($1798)|0);
                $scevgep768$i = (($$0673$i) + ($1798)|0);
                $$0522$i = (($$0522674$i) + 1)|0;
                $exitcond773$i = ($$0522$i|0)==($$0544$$i|0);
                if ($exitcond773$i) {
                 label = 487;
                 break;
                } else {
                 $$0520672$i = $scevgep770$i;$$0522674$i = $$0522$i;$$0673$i = $scevgep768$i;
                }
               }
              }
             } else {
              if ($1800) {
               $2024 = $$0536694$i - $$0538693$i;
               $2025 = $1802 * $2024;
               $2026 = (($141) + ($1810)|0);
               $2027 = (($2026) + ($1801)|0);
               do {
                if ($1797) {
                 $2047 = HEAP16[$2027>>1]|0;
                 $2048 = (+($2047&65535));
                 $$sink37$us$i2068 = $2025 * $2048;
                 $2049 = $$sink37$us$i2068 + 0.0;
                 HEAPF32[$12>>2] = $2049;
                 if ($exitcond750$i2075) {
                  break;
                 }
                 $2050 = (($2027) + ($$0$i806)|0);
                 $2051 = HEAP16[$2050>>1]|0;
                 $2052 = (+($2051&65535));
                 $$sink37$us$i2962 = $2025 * $2052;
                 $2053 = $$sink37$us$i2962 + 0.0;
                 HEAPF32[$$phi$trans$insert789$i2961>>2] = $2053;
                 if ($exitcond741$i2963) {
                  break;
                 } else {
                  $2054 = 2;$2056 = $2050;
                 }
                 while(1) {
                  $$phi$trans$insert789$i$phi$trans$insert = (($12) + ($2054<<2)|0);
                  $$pre790$i$pre = +HEAPF32[$$phi$trans$insert789$i$phi$trans$insert>>2];
                  $2055 = (($2056) + ($$0$i806)|0);
                  $$phi$trans$insert789$i = (($12) + ($2054<<2)|0);
                  $2057 = HEAP16[$2055>>1]|0;
                  $2058 = (+($2057&65535));
                  $$sink37$us$i = $2025 * $2058;
                  $2059 = $$pre790$i$pre + $$sink37$us$i;
                  HEAPF32[$$phi$trans$insert789$i>>2] = $2059;
                  $2060 = (($2054) + 1)|0;
                  $exitcond741$i = ($2060|0)==($$0$i805|0);
                  if ($exitcond741$i) {
                   break;
                  } else {
                   $2054 = $2060;$2056 = $2055;
                  }
                 }
                } else {
                 $2028 = ((($2027)) + 1|0);
                 $2029 = HEAP8[$2028>>0]|0;
                 $2030 = $2029&255;
                 $2031 = $2030 << 8;
                 $2032 = HEAP8[$2027>>0]|0;
                 $2033 = $2032&255;
                 $2034 = $2031 | $2033;
                 $2035 = (+($2034|0));
                 $$sink37$i2065 = $2025 * $2035;
                 $2036 = $$sink37$i2065 + 0.0;
                 HEAPF32[$12>>2] = $2036;
                 if ($exitcond750$i2075) {
                  break;
                 }
                 $2037 = (($2027) + ($$0$i806)|0);
                 $2038 = ((($2037)) + 1|0);
                 $2039 = HEAP8[$2038>>0]|0;
                 $2040 = $2039&255;
                 $2041 = $2040 << 8;
                 $2042 = HEAP8[$2037>>0]|0;
                 $2043 = $2042&255;
                 $2044 = $2041 | $2043;
                 $2045 = (+($2044|0));
                 $$sink37$i2959 = $2025 * $2045;
                 $2046 = $$sink37$i2959 + 0.0;
                 HEAPF32[$$phi$trans$insert787$i2958>>2] = $2046;
                 if ($exitcond740$i2960) {
                  break;
                 } else {
                  $2069 = 2;$2071 = $2037;
                 }
                 while(1) {
                  $$phi$trans$insert787$i$phi$trans$insert = (($12) + ($2069<<2)|0);
                  $$pre788$i$pre = +HEAPF32[$$phi$trans$insert787$i$phi$trans$insert>>2];
                  $2070 = (($2071) + ($$0$i806)|0);
                  $$phi$trans$insert787$i = (($12) + ($2069<<2)|0);
                  $2072 = ((($2070)) + 1|0);
                  $2073 = HEAP8[$2072>>0]|0;
                  $2074 = $2073&255;
                  $2075 = $2074 << 8;
                  $2076 = HEAP8[$2070>>0]|0;
                  $2077 = $2076&255;
                  $2078 = $2075 | $2077;
                  $2079 = (+($2078|0));
                  $$sink37$i = $2025 * $2079;
                  $2080 = $$pre788$i$pre + $$sink37$i;
                  HEAPF32[$$phi$trans$insert787$i>>2] = $2080;
                  $2081 = (($2069) + 1)|0;
                  $exitcond740$i = ($2081|0)==($$0$i805|0);
                  if ($exitcond740$i) {
                   break;
                  } else {
                   $2069 = $2081;$2071 = $2070;
                  }
                 }
                }
               } while(0);
               if ($1804) {
                if ($1797) {
                 $$1523624$i$us = $$0522671$i;$$2541623$i$us = $2027;
                 while(1) {
                  $2061 = (($$2541623$i$us) + ($$0778)|0);
                  $$7559618$us$i$us = $2061;$$8619$us$i$us = 0;
                  while(1) {
                   $2062 = HEAP16[$$7559618$us$i$us>>1]|0;
                   $2063 = (+($2062&65535));
                   $$sink42$us$i$us = $2024 * $2063;
                   $2064 = (($12) + ($$8619$us$i$us<<2)|0);
                   $2065 = +HEAPF32[$2064>>2];
                   $2066 = $2065 + $$sink42$us$i$us;
                   HEAPF32[$2064>>2] = $2066;
                   $2067 = (($$8619$us$i$us) + 1)|0;
                   $2068 = (($$7559618$us$i$us) + ($$0$i806)|0);
                   $exitcond743$i$us = ($2067|0)==($$0$i805|0);
                   if ($exitcond743$i$us) {
                    break;
                   } else {
                    $$7559618$us$i$us = $2068;$$8619$us$i$us = $2067;
                   }
                  }
                  $$1523$i$us = (($$1523624$i$us) + 1)|0;
                  $exitcond746$i$us = ($$1523$i$us|0)==($$0544$$i|0);
                  if ($exitcond746$i$us) {
                   break;
                  } else {
                   $$1523624$i$us = $$1523$i$us;$$2541623$i$us = $2061;
                  }
                 }
                } else {
                 $$1523624$i = $$0522671$i;$$2541623$i = $2027;
                 while(1) {
                  $2082 = (($$2541623$i) + ($$0778)|0);
                  $$7559618$i = $2082;$$8619$i = 0;
                  while(1) {
                   $2083 = ((($$7559618$i)) + 1|0);
                   $2084 = HEAP8[$2083>>0]|0;
                   $2085 = $2084&255;
                   $2086 = $2085 << 8;
                   $2087 = HEAP8[$$7559618$i>>0]|0;
                   $2088 = $2087&255;
                   $2089 = $2086 | $2088;
                   $2090 = (+($2089|0));
                   $$sink42$i = $2024 * $2090;
                   $2091 = (($12) + ($$8619$i<<2)|0);
                   $2092 = +HEAPF32[$2091>>2];
                   $2093 = $2092 + $$sink42$i;
                   HEAPF32[$2091>>2] = $2093;
                   $2094 = (($$8619$i) + 1)|0;
                   $2095 = (($$7559618$i) + ($$0$i806)|0);
                   $exitcond742$i = ($2094|0)==($$0$i805|0);
                   if ($exitcond742$i) {
                    break;
                   } else {
                    $$7559618$i = $2095;$$8619$i = $2094;
                   }
                  }
                  $$1523$i = (($$1523624$i) + 1)|0;
                  $exitcond746$i = ($$1523$i|0)==($$0544$$i|0);
                  if ($exitcond746$i) {
                   break;
                  } else {
                   $$1523624$i = $$1523$i;$$2541623$i = $2082;
                  }
                 }
                }
                $scevgep745$i = (($uglygep744$i) + ($1810)|0);
                $$2541$lcssa$i = $scevgep745$i;
               } else {
                $$2541$lcssa$i = $2027;
               }
               $2096 = $$0533702$i * $2024;
               $2097 = (($$2541$lcssa$i) + ($$0778)|0);
               if ($1797) {
                $$8560628$us$i = $2097;$$9629$us$i = 0;
                while(1) {
                 $2098 = HEAP16[$$8560628$us$i>>1]|0;
                 $2099 = (+($2098&65535));
                 $$sink47$us$i = $2096 * $2099;
                 $2100 = (($12) + ($$9629$us$i<<2)|0);
                 $2101 = +HEAPF32[$2100>>2];
                 $2102 = $2101 + $$sink47$us$i;
                 HEAPF32[$2100>>2] = $2102;
                 $2103 = (($$9629$us$i) + 1)|0;
                 $2104 = (($$8560628$us$i) + ($$0$i806)|0);
                 $exitcond748$i = ($2103|0)==($$0$i805|0);
                 if ($exitcond748$i) {
                  label = 487;
                  break L698;
                 } else {
                  $$8560628$us$i = $2104;$$9629$us$i = $2103;
                 }
                }
               } else {
                $$8560628$i = $2097;$$9629$i = 0;
                while(1) {
                 $2105 = ((($$8560628$i)) + 1|0);
                 $2106 = HEAP8[$2105>>0]|0;
                 $2107 = $2106&255;
                 $2108 = $2107 << 8;
                 $2109 = HEAP8[$$8560628$i>>0]|0;
                 $2110 = $2109&255;
                 $2111 = $2108 | $2110;
                 $2112 = (+($2111|0));
                 $$sink47$i = $2096 * $2112;
                 $2113 = (($12) + ($$9629$i<<2)|0);
                 $2114 = +HEAPF32[$2113>>2];
                 $2115 = $2114 + $$sink47$i;
                 HEAPF32[$2113>>2] = $2115;
                 $2116 = (($$9629$i) + 1)|0;
                 $2117 = (($$8560628$i) + ($$0$i806)|0);
                 $exitcond747$i = ($2116|0)==($$0$i805|0);
                 if ($exitcond747$i) {
                  label = 487;
                  break L698;
                 } else {
                  $$8560628$i = $2117;$$9629$i = $2116;
                 }
                }
               }
              }
              if (!($1811)) {
               $2216 = $$0536694$i - $$0538693$i;
               $2217 = $1807 * $2216;
               $2218 = (($141) + ($1810)|0);
               $2219 = (($2218) + ($1801)|0);
               if ($1797) {
                $2239 = HEAP16[$2219>>1]|0;
                $2240 = (+($2239&65535));
                $$sink67$us$i2056 = $2217 * $2240;
                $2241 = $$sink67$us$i2056 + 0.0;
                HEAPF32[$12>>2] = $2241;
                if ($exitcond750$i2075) {
                 label = 487;
                 break;
                }
                $2242 = (($2219) + ($$0$i806)|0);
                $2243 = HEAP16[$2242>>1]|0;
                $2244 = (+($2243&65535));
                $$sink67$us$i2950 = $2217 * $2244;
                $2245 = $$sink67$us$i2950 + 0.0;
                HEAPF32[$$phi$trans$insert781$i2949>>2] = $2245;
                if ($exitcond732$i2951) {
                 label = 487;
                 break;
                } else {
                 $2246 = 2;$2248 = $2242;
                }
                while(1) {
                 $$phi$trans$insert781$i$phi$trans$insert = (($12) + ($2246<<2)|0);
                 $$pre782$i$pre = +HEAPF32[$$phi$trans$insert781$i$phi$trans$insert>>2];
                 $2247 = (($2248) + ($$0$i806)|0);
                 $$phi$trans$insert781$i = (($12) + ($2246<<2)|0);
                 $2249 = HEAP16[$2247>>1]|0;
                 $2250 = (+($2249&65535));
                 $$sink67$us$i = $2217 * $2250;
                 $2251 = $$pre782$i$pre + $$sink67$us$i;
                 HEAPF32[$$phi$trans$insert781$i>>2] = $2251;
                 $2252 = (($2246) + 1)|0;
                 $exitcond732$i = ($2252|0)==($$0$i805|0);
                 if ($exitcond732$i) {
                  label = 487;
                  break L698;
                 } else {
                  $2246 = $2252;$2248 = $2247;
                 }
                }
               } else {
                $2220 = ((($2219)) + 1|0);
                $2221 = HEAP8[$2220>>0]|0;
                $2222 = $2221&255;
                $2223 = $2222 << 8;
                $2224 = HEAP8[$2219>>0]|0;
                $2225 = $2224&255;
                $2226 = $2223 | $2225;
                $2227 = (+($2226|0));
                $$sink67$i2053 = $2217 * $2227;
                $2228 = $$sink67$i2053 + 0.0;
                HEAPF32[$12>>2] = $2228;
                if ($exitcond750$i2075) {
                 label = 487;
                 break;
                }
                $2229 = (($2219) + ($$0$i806)|0);
                $2230 = ((($2229)) + 1|0);
                $2231 = HEAP8[$2230>>0]|0;
                $2232 = $2231&255;
                $2233 = $2232 << 8;
                $2234 = HEAP8[$2229>>0]|0;
                $2235 = $2234&255;
                $2236 = $2233 | $2235;
                $2237 = (+($2236|0));
                $$sink67$i2947 = $2217 * $2237;
                $2238 = $$sink67$i2947 + 0.0;
                HEAPF32[$$phi$trans$insert$i11372946>>2] = $2238;
                if ($exitcond$i11352948) {
                 label = 487;
                 break;
                } else {
                 $2253 = 2;$2255 = $2229;
                }
                while(1) {
                 $$phi$trans$insert$i1137$phi$trans$insert = (($12) + ($2253<<2)|0);
                 $$pre$i1138$pre = +HEAPF32[$$phi$trans$insert$i1137$phi$trans$insert>>2];
                 $2254 = (($2255) + ($$0$i806)|0);
                 $$phi$trans$insert$i1137 = (($12) + ($2253<<2)|0);
                 $2256 = ((($2254)) + 1|0);
                 $2257 = HEAP8[$2256>>0]|0;
                 $2258 = $2257&255;
                 $2259 = $2258 << 8;
                 $2260 = HEAP8[$2254>>0]|0;
                 $2261 = $2260&255;
                 $2262 = $2259 | $2261;
                 $2263 = (+($2262|0));
                 $$sink67$i = $2217 * $2263;
                 $2264 = $$pre$i1138$pre + $$sink67$i;
                 HEAPF32[$$phi$trans$insert$i1137>>2] = $2264;
                 $2265 = (($2253) + 1)|0;
                 $exitcond$i1135 = ($2265|0)==($$0$i805|0);
                 if ($exitcond$i1135) {
                  label = 487;
                  break L698;
                 } else {
                  $2253 = $2265;$2255 = $2254;
                 }
                }
               }
              }
              $2118 = 1.0 - $$0538693$i;
              $2119 = $1807 * $2118;
              $2120 = (($141) + ($1810)|0);
              $2121 = (($2120) + ($1801)|0);
              do {
               if ($1797) {
                $2141 = HEAP16[$2121>>1]|0;
                $2142 = (+($2141&65535));
                $$sink52$us$i2062 = $2119 * $2142;
                $2143 = $$sink52$us$i2062 + 0.0;
                HEAPF32[$12>>2] = $2143;
                if ($exitcond750$i2075) {
                 break;
                }
                $2144 = (($2121) + ($$0$i806)|0);
                $2145 = HEAP16[$2144>>1]|0;
                $2146 = (+($2145&65535));
                $$sink52$us$i2956 = $2119 * $2146;
                $2147 = $$sink52$us$i2956 + 0.0;
                HEAPF32[$$phi$trans$insert785$i2955>>2] = $2147;
                if ($exitcond734$i2957) {
                 break;
                } else {
                 $2148 = 2;$2150 = $2144;
                }
                while(1) {
                 $$phi$trans$insert785$i$phi$trans$insert = (($12) + ($2148<<2)|0);
                 $$pre786$i$pre = +HEAPF32[$$phi$trans$insert785$i$phi$trans$insert>>2];
                 $2149 = (($2150) + ($$0$i806)|0);
                 $$phi$trans$insert785$i = (($12) + ($2148<<2)|0);
                 $2151 = HEAP16[$2149>>1]|0;
                 $2152 = (+($2151&65535));
                 $$sink52$us$i = $2119 * $2152;
                 $2153 = $$pre786$i$pre + $$sink52$us$i;
                 HEAPF32[$$phi$trans$insert785$i>>2] = $2153;
                 $2154 = (($2148) + 1)|0;
                 $exitcond734$i = ($2154|0)==($$0$i805|0);
                 if ($exitcond734$i) {
                  break;
                 } else {
                  $2148 = $2154;$2150 = $2149;
                 }
                }
               } else {
                $2122 = ((($2121)) + 1|0);
                $2123 = HEAP8[$2122>>0]|0;
                $2124 = $2123&255;
                $2125 = $2124 << 8;
                $2126 = HEAP8[$2121>>0]|0;
                $2127 = $2126&255;
                $2128 = $2125 | $2127;
                $2129 = (+($2128|0));
                $$sink52$i2059 = $2119 * $2129;
                $2130 = $$sink52$i2059 + 0.0;
                HEAPF32[$12>>2] = $2130;
                if ($exitcond750$i2075) {
                 break;
                }
                $2131 = (($2121) + ($$0$i806)|0);
                $2132 = ((($2131)) + 1|0);
                $2133 = HEAP8[$2132>>0]|0;
                $2134 = $2133&255;
                $2135 = $2134 << 8;
                $2136 = HEAP8[$2131>>0]|0;
                $2137 = $2136&255;
                $2138 = $2135 | $2137;
                $2139 = (+($2138|0));
                $$sink52$i2953 = $2119 * $2139;
                $2140 = $$sink52$i2953 + 0.0;
                HEAPF32[$$phi$trans$insert783$i2952>>2] = $2140;
                if ($exitcond733$i2954) {
                 break;
                } else {
                 $2167 = 2;$2169 = $2131;
                }
                while(1) {
                 $$phi$trans$insert783$i$phi$trans$insert = (($12) + ($2167<<2)|0);
                 $$pre784$i$pre = +HEAPF32[$$phi$trans$insert783$i$phi$trans$insert>>2];
                 $2168 = (($2169) + ($$0$i806)|0);
                 $$phi$trans$insert783$i = (($12) + ($2167<<2)|0);
                 $2170 = ((($2168)) + 1|0);
                 $2171 = HEAP8[$2170>>0]|0;
                 $2172 = $2171&255;
                 $2173 = $2172 << 8;
                 $2174 = HEAP8[$2168>>0]|0;
                 $2175 = $2174&255;
                 $2176 = $2173 | $2175;
                 $2177 = (+($2176|0));
                 $$sink52$i = $2119 * $2177;
                 $2178 = $$pre784$i$pre + $$sink52$i;
                 HEAPF32[$$phi$trans$insert783$i>>2] = $2178;
                 $2179 = (($2167) + 1)|0;
                 $exitcond733$i = ($2179|0)==($$0$i805|0);
                 if ($exitcond733$i) {
                  break;
                 } else {
                  $2167 = $2179;$2169 = $2168;
                 }
                }
               }
              } while(0);
              $$2526608$i = (($$0550691$i) + 1)|0;
              $2155 = ($$2526608$i|0)<($$0548692$i|0);
              $2156 = (($2121) + ($126)|0);
              if ($2155) {
               $2157 = Math_imul($$0548692$i, $126)|0;
               if ($1797) {
                $$2526609$i$us = $$2526608$i;$2166 = $2156;
                while(1) {
                 $$10562605$us$i$us = $2166;$$11606$us$i$us = 0;
                 while(1) {
                  $2158 = HEAP16[$$10562605$us$i$us>>1]|0;
                  $2159 = (+($2158&65535));
                  $$sink57$us$i$us = $1807 * $2159;
                  $2160 = (($12) + ($$11606$us$i$us<<2)|0);
                  $2161 = +HEAPF32[$2160>>2];
                  $2162 = $2161 + $$sink57$us$i$us;
                  HEAPF32[$2160>>2] = $2162;
                  $2163 = (($$11606$us$i$us) + 1)|0;
                  $2164 = (($$10562605$us$i$us) + ($$0$i806)|0);
                  $exitcond736$i$us = ($2163|0)==($$0$i805|0);
                  if ($exitcond736$i$us) {
                   break;
                  } else {
                   $$10562605$us$i$us = $2164;$$11606$us$i$us = $2163;
                  }
                 }
                 $$2526$i$us = (($$2526609$i$us) + 1)|0;
                 $2165 = (($2166) + ($126)|0);
                 $exitcond737$i$us = ($$2526$i$us|0)==($$0548692$i|0);
                 if ($exitcond737$i$us) {
                  break;
                 } else {
                  $$2526609$i$us = $$2526$i$us;$2166 = $2165;
                 }
                }
               } else {
                $$2526609$i = $$2526608$i;$2181 = $2156;
                while(1) {
                 $$10562605$i = $2181;$$11606$i = 0;
                 while(1) {
                  $2182 = ((($$10562605$i)) + 1|0);
                  $2183 = HEAP8[$2182>>0]|0;
                  $2184 = $2183&255;
                  $2185 = $2184 << 8;
                  $2186 = HEAP8[$$10562605$i>>0]|0;
                  $2187 = $2186&255;
                  $2188 = $2185 | $2187;
                  $2189 = (+($2188|0));
                  $$sink57$i = $1807 * $2189;
                  $2190 = (($12) + ($$11606$i<<2)|0);
                  $2191 = +HEAPF32[$2190>>2];
                  $2192 = $2191 + $$sink57$i;
                  HEAPF32[$2190>>2] = $2192;
                  $2193 = (($$11606$i) + 1)|0;
                  $2194 = (($$10562605$i) + ($$0$i806)|0);
                  $exitcond735$i = ($2193|0)==($$0$i805|0);
                  if ($exitcond735$i) {
                   break;
                  } else {
                   $$10562605$i = $2194;$$11606$i = $2193;
                  }
                 }
                 $$2526$i = (($$2526609$i) + 1)|0;
                 $2180 = (($2181) + ($126)|0);
                 $exitcond737$i = ($$2526$i|0)==($$0548692$i|0);
                 if ($exitcond737$i) {
                  break;
                 } else {
                  $$2526609$i = $$2526$i;$2181 = $2180;
                 }
                }
               }
               $scevgep$i1129 = (($uglygep$i) + ($2157)|0);
               $$lcssa$i1131 = $scevgep$i1129;
              } else {
               $$lcssa$i1131 = $2156;
              }
              $2195 = $1807 * $$0536694$i;
              if ($1797) {
               $$11563610$us$i = $$lcssa$i1131;$$12611$us$i = 0;
               while(1) {
                $2196 = HEAP16[$$11563610$us$i>>1]|0;
                $2197 = (+($2196&65535));
                $$sink62$us$i = $2195 * $2197;
                $2198 = (($12) + ($$12611$us$i<<2)|0);
                $2199 = +HEAPF32[$2198>>2];
                $2200 = $2199 + $$sink62$us$i;
                HEAPF32[$2198>>2] = $2200;
                $2201 = (($$12611$us$i) + 1)|0;
                $2202 = (($$11563610$us$i) + ($$0$i806)|0);
                $exitcond739$i = ($2201|0)==($$0$i805|0);
                if ($exitcond739$i) {
                 label = 487;
                 break;
                } else {
                 $$11563610$us$i = $2202;$$12611$us$i = $2201;
                }
               }
              } else {
               $$11563610$i = $$lcssa$i1131;$$12611$i = 0;
               while(1) {
                $2203 = ((($$11563610$i)) + 1|0);
                $2204 = HEAP8[$2203>>0]|0;
                $2205 = $2204&255;
                $2206 = $2205 << 8;
                $2207 = HEAP8[$$11563610$i>>0]|0;
                $2208 = $2207&255;
                $2209 = $2206 | $2208;
                $2210 = (+($2209|0));
                $$sink62$i = $2195 * $2210;
                $2211 = (($12) + ($$12611$i<<2)|0);
                $2212 = +HEAPF32[$2211>>2];
                $2213 = $2212 + $$sink62$i;
                HEAPF32[$2211>>2] = $2213;
                $2214 = (($$12611$i) + 1)|0;
                $2215 = (($$11563610$i) + ($$0$i806)|0);
                $exitcond738$i = ($2214|0)==($$0$i805|0);
                if ($exitcond738$i) {
                 label = 487;
                 break;
                } else {
                 $$11563610$i = $2215;$$12611$i = $2214;
                }
               }
              }
             }
            } while(0);
            do {
             if ((label|0) == 487) {
              label = 0;
              if (!($1804)) {
               break;
              }
              $2266 = (($141) + ($1810)|0);
              $2267 = (($2266) + ($126)|0);
              $2268 = (($2267) + ($1805)|0);
              $$3680$i = (($$0550691$i) + 1)|0;
              $2269 = ($$3680$i|0)<($$0548692$i|0);
              $$0551684$i = $2268;$$2685$i = $$0522671$i;
              while(1) {
               if ($2269) {
                if ($1797) {
                 $$3682$i$us = $$3680$i;$$4543681$i$us = $$0551684$i;
                 while(1) {
                  $$13565676$us$i$us = $$4543681$i$us;$$14677$us$i$us = 0;
                  while(1) {
                   $2270 = HEAP16[$$13565676$us$i$us>>1]|0;
                   $2271 = (+($2270&65535));
                   $2272 = (($12) + ($$14677$us$i$us<<2)|0);
                   $2273 = +HEAPF32[$2272>>2];
                   $2274 = $2271 + $2273;
                   HEAPF32[$2272>>2] = $2274;
                   $2275 = (($$14677$us$i$us) + 1)|0;
                   $2276 = (($$13565676$us$i$us) + ($$0$i806)|0);
                   $exitcond775$i$us = ($2275|0)==($$0$i805|0);
                   if ($exitcond775$i$us) {
                    break;
                   } else {
                    $$13565676$us$i$us = $2276;$$14677$us$i$us = $2275;
                   }
                  }
                  $2277 = (($$4543681$i$us) + ($126)|0);
                  $$3$i$us = (($$3682$i$us) + 1)|0;
                  $exitcond776$i$us = ($$3$i$us|0)==($$0548692$i|0);
                  if ($exitcond776$i$us) {
                   break;
                  } else {
                   $$3682$i$us = $$3$i$us;$$4543681$i$us = $2277;
                  }
                 }
                } else {
                 $$3682$i = $$3680$i;$$4543681$i = $$0551684$i;
                 while(1) {
                  $$13565676$i = $$4543681$i;$$14677$i = 0;
                  while(1) {
                   $2278 = ((($$13565676$i)) + 1|0);
                   $2279 = HEAP8[$2278>>0]|0;
                   $2280 = $2279&255;
                   $2281 = $2280 << 8;
                   $2282 = HEAP8[$$13565676$i>>0]|0;
                   $2283 = $2282&255;
                   $2284 = $2281 | $2283;
                   $2285 = (+($2284|0));
                   $2286 = (($12) + ($$14677$i<<2)|0);
                   $2287 = +HEAPF32[$2286>>2];
                   $2288 = $2287 + $2285;
                   HEAPF32[$2286>>2] = $2288;
                   $2289 = (($$14677$i) + 1)|0;
                   $2290 = (($$13565676$i) + ($$0$i806)|0);
                   $exitcond774$i = ($2289|0)==($$0$i805|0);
                   if ($exitcond774$i) {
                    break;
                   } else {
                    $$13565676$i = $2290;$$14677$i = $2289;
                   }
                  }
                  $2291 = (($$4543681$i) + ($126)|0);
                  $$3$i = (($$3682$i) + 1)|0;
                  $exitcond776$i = ($$3$i|0)==($$0548692$i|0);
                  if ($exitcond776$i) {
                   break;
                  } else {
                   $$3682$i = $$3$i;$$4543681$i = $2291;
                  }
                 }
                }
               }
               $2292 = (($$0551684$i) + ($$0778)|0);
               $2293 = (($$2685$i) + 1)|0;
               $exitcond777$i = ($2293|0)==($$0544$$i|0);
               if ($exitcond777$i) {
                break;
               } else {
                $$0551684$i = $2292;$$2685$i = $2293;
               }
              }
             }
            } while(0);
            $2294 = (($$0528695$i) + ($1806))|0;
            $2295 = Math_imul($2294, $$0$i805)|0;
            $$15687$i = 0;
            while(1) {
             $2296 = (($12) + ($$15687$i<<2)|0);
             $2297 = +HEAPF32[$2296>>2];
             $2298 = $2297 / $1793;
             $2299 = (~~(($2298))&65535);
             $2300 = (($$15687$i) + ($2295))|0;
             $2301 = (($1241) + ($2300<<1)|0);
             HEAP16[$2301>>1] = $2299;
             $2302 = (($$15687$i) + 1)|0;
             $exitcond778$i = ($2302|0)==($$0$i805|0);
             if ($exitcond778$i) {
              break;
             } else {
              $$15687$i = $2302;
             }
            }
            $2303 = (($$0548692$i) + ($1790))|0;
            $2304 = $1792 + $$0536694$i;
            $2305 = $2304 > 1.0;
            $2306 = $2304 + -1.0;
            $2307 = $2305&1;
            $$1549$i = (($2303) + ($2307))|0;
            $$1537$i = $2305 ? $2306 : $2304;
            $2308 = (($$0528695$i) + 1)|0;
            $exitcond779$i = ($2308|0)==($4|0);
            if ($exitcond779$i) {
             break;
            } else {
             $$0550691$i$phi = $$0548692$i;$$0538693$i$phi = $$0536694$i;$$0528695$i = $2308;$$0536694$i = $$1537$i;$$0548692$i = $$1549$i;$$0550691$i = $$0550691$i$phi;$$0538693$i = $$0538693$i$phi;
            }
           }
          }
          $2309 = $1788 + $$0533702$i;
          $2310 = $2309 > 1.0;
          $2311 = $2309 + -1.0;
          $2312 = $2310&1;
          $2313 = (($2312) + ($1786))|0;
          $$2546$i = (($2313) + ($$0544$$i))|0;
          $$1534$i = $2310 ? $2311 : $2309;
          $2314 = (($$0527703$i) + 1)|0;
          $exitcond780$i = ($2314|0)==($5|0);
          if ($exitcond780$i) {
           break;
          } else {
           $$0535701$i$phi = $$0533702$i;$$0527703$i = $2314;$$0533702$i = $$1534$i;$$0544700$i = $$2546$i;$$0547699$i = $$0544$$i;$$0535701$i = $$0535701$i$phi;
          }
         }
        }
       }
       break L470;
       break;
      }
      case 5122:  {
       $2315 = $4 << 1;
       $2316 = ($2315|0)==($2|0);
       $2317 = $5 << 1;
       $2318 = ($2317|0)==($3|0);
       $or$cond$i1140 = $2316 & $2318;
       if ($or$cond$i1140) {
        __ZN3osgL16halveImage_shortEijjPKsPsiiii($$0$i805,$2,$3,$141,$1241,$$0$i806,$$0778,$126,$$785);
       } else {
        $2319 = (+($3|0));
        $2320 = (+($5|0));
        $2321 = $2319 / $2320;
        $2322 = (+($2|0));
        $2323 = (+($4|0));
        $2324 = $2322 / $2323;
        $2325 = (+Math_floor((+$2321)));
        $2326 = (~~(($2325)));
        $2327 = (+($2326|0));
        $2328 = $2321 - $2327;
        $2329 = (+Math_floor((+$2324)));
        $2330 = (~~(($2329)));
        $2331 = (+($2330|0));
        $2332 = $2324 - $2331;
        $2333 = $2324 * $2321;
        $2334 = ($5|0)>(0);
        if ($2334) {
         $2335 = (($3) + -1)|0;
         $2336 = ($4|0)>(0);
         $2337 = ($$785|0)==(0);
         $2338 = (($$0778) + ($126))|0;
         $exitcond830$i2103 = ($$0$i805|0)==(1);
         $$phi$trans$insert880$i2995 = ((($12)) + 4|0);
         $exitcond830$i2997 = ($$0$i805|0)==(2);
         $$phi$trans$insert878$i2991 = ((($12)) + 4|0);
         $exitcond829$i2994 = ($$0$i805|0)==(2);
         $$phi$trans$insert876$i2988 = ((($12)) + 4|0);
         $exitcond818$i2990 = ($$0$i805|0)==(2);
         $$phi$trans$insert874$i2984 = ((($12)) + 4|0);
         $exitcond817$i2987 = ($$0$i805|0)==(2);
         $$phi$trans$insert872$i2981 = ((($12)) + 4|0);
         $exitcond808$i2983 = ($$0$i805|0)==(2);
         $$phi$trans$insert870$i2977 = ((($12)) + 4|0);
         $exitcond807$i2980 = ($$0$i805|0)==(2);
         $$phi$trans$insert868$i2974 = ((($12)) + 4|0);
         $exitcond806$i2976 = ($$0$i805|0)==(2);
         $$phi$trans$insert$i11782970 = ((($12)) + 4|0);
         $exitcond$i11762973 = ($$0$i805|0)==(2);
         $$0546768$i = 0;$$0552767$i = $2328;$$0554766$i = 0.0;$$0563765$i = $2326;$$0566764$i = 0;
         while(1) {
          $2339 = ($$0563765$i|0)<($3|0);
          $$0563$$i = $2339 ? $$0563765$i : $2335;
          if ($2336) {
           $2340 = ($$0563$$i|0)>($$0566764$i|0);
           $2341 = Math_imul($$0566764$i, $$0778)|0;
           $2342 = 1.0 - $$0554766$i;
           $2343 = Math_imul($$0563$$i, $$0778)|0;
           $$0541730$i = (($$0566764$i) + 1)|0;
           $2344 = ($$0541730$i|0)<($$0563$$i|0);
           $2345 = Math_imul($$0541730$i, $$0778)|0;
           $2346 = Math_imul($$0546768$i, $4)|0;
           $2347 = $$0552767$i - $$0554766$i;
           $uglygep$i1141 = (($141) + ($2341)|0);
           $2348 = (($$0563$$i) + -1)|0;
           $2349 = Math_imul($2348, $$0778)|0;
           $uglygep819$i = (($141) + ($2349)|0);
           $uglygep843$i = (($141) + ($2343)|0);
           $$0547760$i = 0;$$0555759$i = $2332;$$0557758$i = 0.0;$$0567757$i = $2330;$$0569756$i = 0;
           while(1) {
            $2350 = Math_imul($$0569756$i, $126)|0;
            $2351 = ($$0567757$i|0)>($$0569756$i|0);
            $or$cond613$i = $2340 & $2351;
            ;HEAP32[$12>>2]=0|0;HEAP32[$12+4>>2]=0|0;HEAP32[$12+8>>2]=0|0;HEAP32[$12+12>>2]=0|0;
            L882: do {
             if ($or$cond613$i) {
              $2352 = (($141) + ($2350)|0);
              $2353 = (($2352) + ($2341)|0);
              $2354 = 1.0 - $$0557758$i;
              $2355 = $2342 * $2354;
              do {
               if ($2337) {
                $2377 = HEAP16[$2353>>1]|0;
                $2378 = (+($2377<<16>>16));
                $$sink3$us$i11422102 = $2355 * $2378;
                $2379 = $$sink3$us$i11422102 + 0.0;
                HEAPF32[$12>>2] = $2379;
                if ($exitcond830$i2103) {
                 break;
                }
                $2380 = (($2353) + ($$0$i806)|0);
                $2381 = HEAP16[$2380>>1]|0;
                $2382 = (+($2381<<16>>16));
                $$sink3$us$i11422996 = $2355 * $2382;
                $2383 = $$sink3$us$i11422996 + 0.0;
                HEAPF32[$$phi$trans$insert880$i2995>>2] = $2383;
                if ($exitcond830$i2997) {
                 break;
                } else {
                 $2384 = 2;$2386 = $2380;
                }
                while(1) {
                 $$phi$trans$insert880$i$phi$trans$insert = (($12) + ($2384<<2)|0);
                 $$pre881$i$pre = +HEAPF32[$$phi$trans$insert880$i$phi$trans$insert>>2];
                 $2385 = (($2386) + ($$0$i806)|0);
                 $$phi$trans$insert880$i = (($12) + ($2384<<2)|0);
                 $2387 = HEAP16[$2385>>1]|0;
                 $2388 = (+($2387<<16>>16));
                 $$sink3$us$i1142 = $2355 * $2388;
                 $2389 = $$pre881$i$pre + $$sink3$us$i1142;
                 HEAPF32[$$phi$trans$insert880$i>>2] = $2389;
                 $2390 = (($2384) + 1)|0;
                 $exitcond830$i = ($2390|0)==($$0$i805|0);
                 if ($exitcond830$i) {
                  break;
                 } else {
                  $2384 = $2390;$2386 = $2385;
                 }
                }
               } else {
                $2356 = ((($2353)) + 1|0);
                $2357 = HEAP8[$2356>>0]|0;
                $2358 = $2357&255;
                $2359 = $2358 << 8;
                $2360 = HEAP8[$2353>>0]|0;
                $2361 = $2360&255;
                $2362 = $2359 | $2361;
                $sext611$i2098 = $2362 << 16;
                $2363 = $sext611$i2098 >> 16;
                $2364 = (+($2363|0));
                $$sink3$i11432099 = $2355 * $2364;
                $2365 = $$sink3$i11432099 + 0.0;
                HEAPF32[$12>>2] = $2365;
                if ($exitcond830$i2103) {
                 break;
                }
                $2366 = (($2353) + ($$0$i806)|0);
                $2367 = ((($2366)) + 1|0);
                $2368 = HEAP8[$2367>>0]|0;
                $2369 = $2368&255;
                $2370 = $2369 << 8;
                $2371 = HEAP8[$2366>>0]|0;
                $2372 = $2371&255;
                $2373 = $2370 | $2372;
                $sext611$i2992 = $2373 << 16;
                $2374 = $sext611$i2992 >> 16;
                $2375 = (+($2374|0));
                $$sink3$i11432993 = $2355 * $2375;
                $2376 = $$sink3$i11432993 + 0.0;
                HEAPF32[$$phi$trans$insert878$i2991>>2] = $2376;
                if ($exitcond829$i2994) {
                 break;
                } else {
                 $2391 = 2;$2393 = $2366;
                }
                while(1) {
                 $$phi$trans$insert878$i$phi$trans$insert = (($12) + ($2391<<2)|0);
                 $$pre879$i$pre = +HEAPF32[$$phi$trans$insert878$i$phi$trans$insert>>2];
                 $2392 = (($2393) + ($$0$i806)|0);
                 $$phi$trans$insert878$i = (($12) + ($2391<<2)|0);
                 $2394 = ((($2392)) + 1|0);
                 $2395 = HEAP8[$2394>>0]|0;
                 $2396 = $2395&255;
                 $2397 = $2396 << 8;
                 $2398 = HEAP8[$2392>>0]|0;
                 $2399 = $2398&255;
                 $2400 = $2397 | $2399;
                 $sext611$i = $2400 << 16;
                 $2401 = $sext611$i >> 16;
                 $2402 = (+($2401|0));
                 $$sink3$i1143 = $2355 * $2402;
                 $2403 = $$pre879$i$pre + $$sink3$i1143;
                 HEAPF32[$$phi$trans$insert878$i>>2] = $2403;
                 $2404 = (($2391) + 1)|0;
                 $exitcond829$i = ($2404|0)==($$0$i805|0);
                 if ($exitcond829$i) {
                  break;
                 } else {
                  $2391 = $2404;$2393 = $2392;
                 }
                }
               }
              } while(0);
              $2405 = (($$0569756$i) + 1)|0;
              $2406 = ($2405|0)<($$0567757$i|0);
              $2407 = (($2353) + ($126)|0);
              if ($2406) {
               $2408 = Math_imul($$0567757$i, $126)|0;
               if ($2337) {
                $$0543686$us$i$us = $2405;$2418 = $2407;
                while(1) {
                 $$1549683$us$us$i$us = 0;$$1572682$us$us$i$us = $2418;
                 while(1) {
                  $2409 = HEAP16[$$1572682$us$us$i$us>>1]|0;
                  $2410 = (+($2409<<16>>16));
                  $$sink7$us$us$i$us = $2342 * $2410;
                  $2411 = (($12) + ($$1549683$us$us$i$us<<2)|0);
                  $2412 = +HEAPF32[$2411>>2];
                  $2413 = $2412 + $$sink7$us$us$i$us;
                  HEAPF32[$2411>>2] = $2413;
                  $2414 = (($$1549683$us$us$i$us) + 1)|0;
                  $2415 = (($$1572682$us$us$i$us) + ($$0$i806)|0);
                  $exitcond835$i$us = ($2414|0)==($$0$i805|0);
                  if ($exitcond835$i$us) {
                   break;
                  } else {
                   $$1549683$us$us$i$us = $2414;$$1572682$us$us$i$us = $2415;
                  }
                 }
                 $2416 = (($$0543686$us$i$us) + 1)|0;
                 $2417 = (($2418) + ($126)|0);
                 $exitcond838$i$us = ($2416|0)==($$0567757$i|0);
                 if ($exitcond838$i$us) {
                  break;
                 } else {
                  $$0543686$us$i$us = $2416;$2418 = $2417;
                 }
                }
               } else {
                $$0543686$us$i = $2405;$2435 = $2407;
                while(1) {
                 $$1549683$us689$i = 0;$$1572682$us690$i = $2435;
                 while(1) {
                  $2419 = ((($$1572682$us690$i)) + 1|0);
                  $2420 = HEAP8[$2419>>0]|0;
                  $2421 = $2420&255;
                  $2422 = $2421 << 8;
                  $2423 = HEAP8[$$1572682$us690$i>>0]|0;
                  $2424 = $2423&255;
                  $2425 = $2422 | $2424;
                  $sext609$us691$i = $2425 << 16;
                  $2426 = $sext609$us691$i >> 16;
                  $2427 = (+($2426|0));
                  $$sink7$us693$i = $2342 * $2427;
                  $2428 = (($12) + ($$1549683$us689$i<<2)|0);
                  $2429 = +HEAPF32[$2428>>2];
                  $2430 = $2429 + $$sink7$us693$i;
                  HEAPF32[$2428>>2] = $2430;
                  $2431 = (($$1549683$us689$i) + 1)|0;
                  $2432 = (($$1572682$us690$i) + ($$0$i806)|0);
                  $exitcond834$i = ($2431|0)==($$0$i805|0);
                  if ($exitcond834$i) {
                   break;
                  } else {
                   $$1549683$us689$i = $2431;$$1572682$us690$i = $2432;
                  }
                 }
                 $2433 = (($$0543686$us$i) + 1)|0;
                 $2434 = (($2435) + ($126)|0);
                 $exitcond838$i = ($2433|0)==($$0567757$i|0);
                 if ($exitcond838$i) {
                  break;
                 } else {
                  $$0543686$us$i = $2433;$2435 = $2434;
                 }
                }
               }
               $scevgep837$i = (($uglygep$i1141) + ($2408)|0);
               $$lcssa629$i = $scevgep837$i;
              } else {
               $$lcssa629$i = $2407;
              }
              $2436 = $2342 * $$0555759$i;
              if ($2337) {
               $$2550697$us$i = 0;$$2573696$us$i = $$lcssa629$i;
               while(1) {
                $2437 = HEAP16[$$2573696$us$i>>1]|0;
                $2438 = (+($2437<<16>>16));
                $$sink12$us$i1144 = $2436 * $2438;
                $2439 = (($12) + ($$2550697$us$i<<2)|0);
                $2440 = +HEAPF32[$2439>>2];
                $2441 = $2440 + $$sink12$us$i1144;
                HEAPF32[$2439>>2] = $2441;
                $2442 = (($$2550697$us$i) + 1)|0;
                $2443 = (($$2573696$us$i) + ($$0$i806)|0);
                $exitcond840$i = ($2442|0)==($$0$i805|0);
                if ($exitcond840$i) {
                 break;
                } else {
                 $$2550697$us$i = $2442;$$2573696$us$i = $2443;
                }
               }
              } else {
               $$2550697$i = 0;$$2573696$i = $$lcssa629$i;
               while(1) {
                $2444 = ((($$2573696$i)) + 1|0);
                $2445 = HEAP8[$2444>>0]|0;
                $2446 = $2445&255;
                $2447 = $2446 << 8;
                $2448 = HEAP8[$$2573696$i>>0]|0;
                $2449 = $2448&255;
                $2450 = $2447 | $2449;
                $sext607$i = $2450 << 16;
                $2451 = $sext607$i >> 16;
                $2452 = (+($2451|0));
                $$sink12$i1145 = $2436 * $2452;
                $2453 = (($12) + ($$2550697$i<<2)|0);
                $2454 = +HEAPF32[$2453>>2];
                $2455 = $2454 + $$sink12$i1145;
                HEAPF32[$2453>>2] = $2455;
                $2456 = (($$2550697$i) + 1)|0;
                $2457 = (($$2573696$i) + ($$0$i806)|0);
                $exitcond839$i = ($2456|0)==($$0$i805|0);
                if ($exitcond839$i) {
                 break;
                } else {
                 $$2550697$i = $2456;$$2573696$i = $2457;
                }
               }
              }
              $2458 = $$0552767$i * $2354;
              $2459 = (($2352) + ($2343)|0);
              if ($2337) {
               $$3551702$us$i = 0;$$3574701$us$i = $2459;
               while(1) {
                $2460 = HEAP16[$$3574701$us$i>>1]|0;
                $2461 = (+($2460<<16>>16));
                $$sink17$us$i1146 = $2458 * $2461;
                $2462 = (($12) + ($$3551702$us$i<<2)|0);
                $2463 = +HEAPF32[$2462>>2];
                $2464 = $2463 + $$sink17$us$i1146;
                HEAPF32[$2462>>2] = $2464;
                $2465 = (($$3551702$us$i) + 1)|0;
                $2466 = (($$3574701$us$i) + ($$0$i806)|0);
                $exitcond842$i = ($2465|0)==($$0$i805|0);
                if ($exitcond842$i) {
                 break;
                } else {
                 $$3551702$us$i = $2465;$$3574701$us$i = $2466;
                }
               }
              } else {
               $$3551702$i = 0;$$3574701$i = $2459;
               while(1) {
                $2496 = ((($$3574701$i)) + 1|0);
                $2497 = HEAP8[$2496>>0]|0;
                $2498 = $2497&255;
                $2499 = $2498 << 8;
                $2500 = HEAP8[$$3574701$i>>0]|0;
                $2501 = $2500&255;
                $2502 = $2499 | $2501;
                $sext605$i = $2502 << 16;
                $2503 = $sext605$i >> 16;
                $2504 = (+($2503|0));
                $$sink17$i1147 = $2458 * $2504;
                $2505 = (($12) + ($$3551702$i<<2)|0);
                $2506 = +HEAPF32[$2505>>2];
                $2507 = $2506 + $$sink17$i1147;
                HEAPF32[$2505>>2] = $2507;
                $2508 = (($$3551702$i) + 1)|0;
                $2509 = (($$3574701$i) + ($$0$i806)|0);
                $exitcond841$i = ($2508|0)==($$0$i805|0);
                if ($exitcond841$i) {
                 break;
                } else {
                 $$3551702$i = $2508;$$3574701$i = $2509;
                }
               }
              }
              $2467 = (($2459) + ($126)|0);
              if ($2406) {
               $2468 = Math_imul($$0567757$i, $126)|0;
               if ($2337) {
                $$1544709$us$i$us = $2405;$2478 = $2467;
                while(1) {
                 $$4575705$us$us$i$us = $2478;$$4706$us$us$i$us = 0;
                 while(1) {
                  $2469 = HEAP16[$$4575705$us$us$i$us>>1]|0;
                  $2470 = (+($2469<<16>>16));
                  $$sink22$us$us$i$us = $$0552767$i * $2470;
                  $2471 = (($12) + ($$4706$us$us$i$us<<2)|0);
                  $2472 = +HEAPF32[$2471>>2];
                  $2473 = $2472 + $$sink22$us$us$i$us;
                  HEAPF32[$2471>>2] = $2473;
                  $2474 = (($$4706$us$us$i$us) + 1)|0;
                  $2475 = (($$4575705$us$us$i$us) + ($$0$i806)|0);
                  $exitcond847$i$us = ($2474|0)==($$0$i805|0);
                  if ($exitcond847$i$us) {
                   break;
                  } else {
                   $$4575705$us$us$i$us = $2475;$$4706$us$us$i$us = $2474;
                  }
                 }
                 $2476 = (($$1544709$us$i$us) + 1)|0;
                 $2477 = (($2478) + ($126)|0);
                 $exitcond850$i$us = ($2476|0)==($$0567757$i|0);
                 if ($exitcond850$i$us) {
                  break;
                 } else {
                  $$1544709$us$i$us = $2476;$2478 = $2477;
                 }
                }
               } else {
                $$1544709$us$i = $2405;$2495 = $2467;
                while(1) {
                 $$4575705$us713$i = $2495;$$4706$us712$i = 0;
                 while(1) {
                  $2479 = ((($$4575705$us713$i)) + 1|0);
                  $2480 = HEAP8[$2479>>0]|0;
                  $2481 = $2480&255;
                  $2482 = $2481 << 8;
                  $2483 = HEAP8[$$4575705$us713$i>>0]|0;
                  $2484 = $2483&255;
                  $2485 = $2482 | $2484;
                  $sext603$us714$i = $2485 << 16;
                  $2486 = $sext603$us714$i >> 16;
                  $2487 = (+($2486|0));
                  $$sink22$us716$i = $$0552767$i * $2487;
                  $2488 = (($12) + ($$4706$us712$i<<2)|0);
                  $2489 = +HEAPF32[$2488>>2];
                  $2490 = $2489 + $$sink22$us716$i;
                  HEAPF32[$2488>>2] = $2490;
                  $2491 = (($$4706$us712$i) + 1)|0;
                  $2492 = (($$4575705$us713$i) + ($$0$i806)|0);
                  $exitcond846$i = ($2491|0)==($$0$i805|0);
                  if ($exitcond846$i) {
                   break;
                  } else {
                   $$4575705$us713$i = $2492;$$4706$us712$i = $2491;
                  }
                 }
                 $2493 = (($$1544709$us$i) + 1)|0;
                 $2494 = (($2495) + ($126)|0);
                 $exitcond850$i = ($2493|0)==($$0567757$i|0);
                 if ($exitcond850$i) {
                  break;
                 } else {
                  $$1544709$us$i = $2493;$2495 = $2494;
                 }
                }
               }
               $scevgep849$i = (($uglygep843$i) + ($2468)|0);
               $$lcssa630$i = $scevgep849$i;
              } else {
               $$lcssa630$i = $2467;
              }
              $2510 = $$0552767$i * $$0555759$i;
              if ($2337) {
               $$5576719$us$i = $$lcssa630$i;$$5720$us$i = 0;
               while(1) {
                $2511 = HEAP16[$$5576719$us$i>>1]|0;
                $2512 = (+($2511<<16>>16));
                $$sink27$us$i1148 = $2510 * $2512;
                $2513 = (($12) + ($$5720$us$i<<2)|0);
                $2514 = +HEAPF32[$2513>>2];
                $2515 = $2514 + $$sink27$us$i1148;
                HEAPF32[$2513>>2] = $2515;
                $2516 = (($$5720$us$i) + 1)|0;
                $2517 = (($$5576719$us$i) + ($$0$i806)|0);
                $exitcond852$i = ($2516|0)==($$0$i805|0);
                if ($exitcond852$i) {
                 break;
                } else {
                 $$5576719$us$i = $2517;$$5720$us$i = $2516;
                }
               }
              } else {
               $$5576719$i = $$lcssa630$i;$$5720$i = 0;
               while(1) {
                $2533 = ((($$5576719$i)) + 1|0);
                $2534 = HEAP8[$2533>>0]|0;
                $2535 = $2534&255;
                $2536 = $2535 << 8;
                $2537 = HEAP8[$$5576719$i>>0]|0;
                $2538 = $2537&255;
                $2539 = $2536 | $2538;
                $sext601$i = $2539 << 16;
                $2540 = $sext601$i >> 16;
                $2541 = (+($2540|0));
                $$sink27$i1149 = $2510 * $2541;
                $2542 = (($12) + ($$5720$i<<2)|0);
                $2543 = +HEAPF32[$2542>>2];
                $2544 = $2543 + $$sink27$i1149;
                HEAPF32[$2542>>2] = $2544;
                $2545 = (($$5720$i) + 1)|0;
                $2546 = (($$5576719$i) + ($$0$i806)|0);
                $exitcond851$i = ($2545|0)==($$0$i805|0);
                if ($exitcond851$i) {
                 break;
                } else {
                 $$5576719$i = $2546;$$5720$i = $2545;
                }
               }
              }
              if (!($2344)) {
               break;
              }
              if ($2337) {
               $$0539731$i$us = $2353;$$0541733$i$us = $$0541730$i;$$0732$i$us = $$lcssa629$i;
               while(1) {
                $2518 = (($$0539731$i$us) + ($$0778)|0);
                $2519 = (($$0732$i$us) + ($$0778)|0);
                $$1540724$us$i$us = $2518;$$1725$us$i$us = $2519;$$6723$us$i$us = 0;
                while(1) {
                 $2520 = HEAP16[$$1540724$us$i$us>>1]|0;
                 $2521 = (+($2520<<16>>16));
                 $2522 = $2354 * $2521;
                 $2523 = HEAP16[$$1725$us$i$us>>1]|0;
                 $2524 = (+($2523<<16>>16));
                 $2525 = $$0555759$i * $2524;
                 $2526 = $2522 + $2525;
                 $2527 = (($12) + ($$6723$us$i$us<<2)|0);
                 $2528 = +HEAPF32[$2527>>2];
                 $2529 = $2528 + $2526;
                 HEAPF32[$2527>>2] = $2529;
                 $2530 = (($$6723$us$i$us) + 1)|0;
                 $2531 = (($$1540724$us$i$us) + ($$0$i806)|0);
                 $2532 = (($$1725$us$i$us) + ($$0$i806)|0);
                 $exitcond858$i$us = ($2530|0)==($$0$i805|0);
                 if ($exitcond858$i$us) {
                  break;
                 } else {
                  $$1540724$us$i$us = $2531;$$1725$us$i$us = $2532;$$6723$us$i$us = $2530;
                 }
                }
                $scevgep856$i$us = (($$0539731$i$us) + ($2338)|0);
                $scevgep854$i$us = (($$0732$i$us) + ($2338)|0);
                $$0541$i$us = (($$0541733$i$us) + 1)|0;
                $exitcond859$i$us = ($$0541$i$us|0)==($$0563$$i|0);
                if ($exitcond859$i$us) {
                 label = 599;
                 break;
                } else {
                 $$0539731$i$us = $scevgep856$i$us;$$0541733$i$us = $$0541$i$us;$$0732$i$us = $scevgep854$i$us;
                }
               }
              } else {
               $$0539731$i = $2353;$$0541733$i = $$0541730$i;$$0732$i = $$lcssa629$i;
               while(1) {
                $2547 = (($$0539731$i) + ($$0778)|0);
                $2548 = (($$0732$i) + ($$0778)|0);
                $$1540724$i = $2547;$$1725$i = $2548;$$6723$i = 0;
                while(1) {
                 $2549 = ((($$1540724$i)) + 1|0);
                 $2550 = HEAP8[$2549>>0]|0;
                 $2551 = $2550&255;
                 $2552 = $2551 << 8;
                 $2553 = HEAP8[$$1540724$i>>0]|0;
                 $2554 = $2553&255;
                 $2555 = $2552 | $2554;
                 $sext598$i = $2555 << 16;
                 $2556 = $sext598$i >> 16;
                 $2557 = (+($2556|0));
                 $2558 = $2354 * $2557;
                 $2559 = (($12) + ($$6723$i<<2)|0);
                 $2560 = +HEAPF32[$2559>>2];
                 $2561 = $2560 + $2558;
                 HEAPF32[$2559>>2] = $2561;
                 $2562 = ((($$1725$i)) + 1|0);
                 $2563 = HEAP8[$2562>>0]|0;
                 $2564 = $2563&255;
                 $2565 = $2564 << 8;
                 $2566 = HEAP8[$$1725$i>>0]|0;
                 $2567 = $2566&255;
                 $2568 = $2565 | $2567;
                 $sext599$i = $2568 << 16;
                 $2569 = $sext599$i >> 16;
                 $2570 = (+($2569|0));
                 $2571 = $$0555759$i * $2570;
                 $2572 = $2561 + $2571;
                 HEAPF32[$2559>>2] = $2572;
                 $2573 = (($$6723$i) + 1)|0;
                 $2574 = (($$1540724$i) + ($$0$i806)|0);
                 $2575 = (($$1725$i) + ($$0$i806)|0);
                 $exitcond855$i = ($2573|0)==($$0$i805|0);
                 if ($exitcond855$i) {
                  break;
                 } else {
                  $$1540724$i = $2574;$$1725$i = $2575;$$6723$i = $2573;
                 }
                }
                $scevgep856$i = (($$0539731$i) + ($2338)|0);
                $scevgep854$i = (($$0732$i) + ($2338)|0);
                $$0541$i = (($$0541733$i) + 1)|0;
                $exitcond859$i = ($$0541$i|0)==($$0563$$i|0);
                if ($exitcond859$i) {
                 label = 599;
                 break;
                } else {
                 $$0539731$i = $scevgep856$i;$$0541733$i = $$0541$i;$$0732$i = $scevgep854$i;
                }
               }
              }
             } else {
              if ($2340) {
               $2576 = $$0555759$i - $$0557758$i;
               $2577 = $2342 * $2576;
               $2578 = (($141) + ($2350)|0);
               $2579 = (($2578) + ($2341)|0);
               do {
                if ($2337) {
                 $2601 = HEAP16[$2579>>1]|0;
                 $2602 = (+($2601<<16>>16));
                 $$sink37$us$i11532095 = $2577 * $2602;
                 $2603 = $$sink37$us$i11532095 + 0.0;
                 HEAPF32[$12>>2] = $2603;
                 if ($exitcond830$i2103) {
                  break;
                 }
                 $2604 = (($2579) + ($$0$i806)|0);
                 $2605 = HEAP16[$2604>>1]|0;
                 $2606 = (+($2605<<16>>16));
                 $$sink37$us$i11532989 = $2577 * $2606;
                 $2607 = $$sink37$us$i11532989 + 0.0;
                 HEAPF32[$$phi$trans$insert876$i2988>>2] = $2607;
                 if ($exitcond818$i2990) {
                  break;
                 } else {
                  $2608 = 2;$2610 = $2604;
                 }
                 while(1) {
                  $$phi$trans$insert876$i$phi$trans$insert = (($12) + ($2608<<2)|0);
                  $$pre877$i$pre = +HEAPF32[$$phi$trans$insert876$i$phi$trans$insert>>2];
                  $2609 = (($2610) + ($$0$i806)|0);
                  $$phi$trans$insert876$i = (($12) + ($2608<<2)|0);
                  $2611 = HEAP16[$2609>>1]|0;
                  $2612 = (+($2611<<16>>16));
                  $$sink37$us$i1153 = $2577 * $2612;
                  $2613 = $$pre877$i$pre + $$sink37$us$i1153;
                  HEAPF32[$$phi$trans$insert876$i>>2] = $2613;
                  $2614 = (($2608) + 1)|0;
                  $exitcond818$i = ($2614|0)==($$0$i805|0);
                  if ($exitcond818$i) {
                   break;
                  } else {
                   $2608 = $2614;$2610 = $2609;
                  }
                 }
                } else {
                 $2580 = ((($2579)) + 1|0);
                 $2581 = HEAP8[$2580>>0]|0;
                 $2582 = $2581&255;
                 $2583 = $2582 << 8;
                 $2584 = HEAP8[$2579>>0]|0;
                 $2585 = $2584&255;
                 $2586 = $2583 | $2585;
                 $sext597$i2091 = $2586 << 16;
                 $2587 = $sext597$i2091 >> 16;
                 $2588 = (+($2587|0));
                 $$sink37$i11562092 = $2577 * $2588;
                 $2589 = $$sink37$i11562092 + 0.0;
                 HEAPF32[$12>>2] = $2589;
                 if ($exitcond830$i2103) {
                  break;
                 }
                 $2590 = (($2579) + ($$0$i806)|0);
                 $2591 = ((($2590)) + 1|0);
                 $2592 = HEAP8[$2591>>0]|0;
                 $2593 = $2592&255;
                 $2594 = $2593 << 8;
                 $2595 = HEAP8[$2590>>0]|0;
                 $2596 = $2595&255;
                 $2597 = $2594 | $2596;
                 $sext597$i2985 = $2597 << 16;
                 $2598 = $sext597$i2985 >> 16;
                 $2599 = (+($2598|0));
                 $$sink37$i11562986 = $2577 * $2599;
                 $2600 = $$sink37$i11562986 + 0.0;
                 HEAPF32[$$phi$trans$insert874$i2984>>2] = $2600;
                 if ($exitcond817$i2987) {
                  break;
                 } else {
                  $2638 = 2;$2640 = $2590;
                 }
                 while(1) {
                  $$phi$trans$insert874$i$phi$trans$insert = (($12) + ($2638<<2)|0);
                  $$pre875$i$pre = +HEAPF32[$$phi$trans$insert874$i$phi$trans$insert>>2];
                  $2639 = (($2640) + ($$0$i806)|0);
                  $$phi$trans$insert874$i = (($12) + ($2638<<2)|0);
                  $2641 = ((($2639)) + 1|0);
                  $2642 = HEAP8[$2641>>0]|0;
                  $2643 = $2642&255;
                  $2644 = $2643 << 8;
                  $2645 = HEAP8[$2639>>0]|0;
                  $2646 = $2645&255;
                  $2647 = $2644 | $2646;
                  $sext597$i = $2647 << 16;
                  $2648 = $sext597$i >> 16;
                  $2649 = (+($2648|0));
                  $$sink37$i1156 = $2577 * $2649;
                  $2650 = $$pre875$i$pre + $$sink37$i1156;
                  HEAPF32[$$phi$trans$insert874$i>>2] = $2650;
                  $2651 = (($2638) + 1)|0;
                  $exitcond817$i = ($2651|0)==($$0$i805|0);
                  if ($exitcond817$i) {
                   break;
                  } else {
                   $2638 = $2651;$2640 = $2639;
                  }
                 }
                }
               } while(0);
               if ($2344) {
                if ($2337) {
                 $$1542662$us$i$us = $$0541730$i;$$2560661$us$i$us = $2579;
                 while(1) {
                  $2615 = (($$2560661$us$i$us) + ($$0778)|0);
                  $$7578656$us$us$i$us = $2615;$$8657$us$us$i$us = 0;
                  while(1) {
                   $2616 = HEAP16[$$7578656$us$us$i$us>>1]|0;
                   $2617 = (+($2616<<16>>16));
                   $$sink42$us$us$i$us = $2576 * $2617;
                   $2618 = (($12) + ($$8657$us$us$i$us<<2)|0);
                   $2619 = +HEAPF32[$2618>>2];
                   $2620 = $2619 + $$sink42$us$us$i$us;
                   HEAPF32[$2618>>2] = $2620;
                   $2621 = (($$8657$us$us$i$us) + 1)|0;
                   $2622 = (($$7578656$us$us$i$us) + ($$0$i806)|0);
                   $exitcond823$i$us = ($2621|0)==($$0$i805|0);
                   if ($exitcond823$i$us) {
                    break;
                   } else {
                    $$7578656$us$us$i$us = $2622;$$8657$us$us$i$us = $2621;
                   }
                  }
                  $$1542$us$i$us = (($$1542662$us$i$us) + 1)|0;
                  $exitcond826$i$us = ($$1542$us$i$us|0)==($$0563$$i|0);
                  if ($exitcond826$i$us) {
                   break;
                  } else {
                   $$1542662$us$i$us = $$1542$us$i$us;$$2560661$us$i$us = $2615;
                  }
                 }
                } else {
                 $$1542662$us$i = $$0541730$i;$$2560661$us$i = $2579;
                 while(1) {
                  $2623 = (($$2560661$us$i) + ($$0778)|0);
                  $$7578656$us667$i = $2623;$$8657$us666$i = 0;
                  while(1) {
                   $2624 = ((($$7578656$us667$i)) + 1|0);
                   $2625 = HEAP8[$2624>>0]|0;
                   $2626 = $2625&255;
                   $2627 = $2626 << 8;
                   $2628 = HEAP8[$$7578656$us667$i>>0]|0;
                   $2629 = $2628&255;
                   $2630 = $2627 | $2629;
                   $sext595$us668$i = $2630 << 16;
                   $2631 = $sext595$us668$i >> 16;
                   $2632 = (+($2631|0));
                   $$sink42$us670$i = $2576 * $2632;
                   $2633 = (($12) + ($$8657$us666$i<<2)|0);
                   $2634 = +HEAPF32[$2633>>2];
                   $2635 = $2634 + $$sink42$us670$i;
                   HEAPF32[$2633>>2] = $2635;
                   $2636 = (($$8657$us666$i) + 1)|0;
                   $2637 = (($$7578656$us667$i) + ($$0$i806)|0);
                   $exitcond822$i = ($2636|0)==($$0$i805|0);
                   if ($exitcond822$i) {
                    break;
                   } else {
                    $$7578656$us667$i = $2637;$$8657$us666$i = $2636;
                   }
                  }
                  $$1542$us$i = (($$1542662$us$i) + 1)|0;
                  $exitcond826$i = ($$1542$us$i|0)==($$0563$$i|0);
                  if ($exitcond826$i) {
                   break;
                  } else {
                   $$1542662$us$i = $$1542$us$i;$$2560661$us$i = $2623;
                  }
                 }
                }
                $scevgep825$i = (($uglygep819$i) + ($2350)|0);
                $$2560$lcssa$i = $scevgep825$i;
               } else {
                $$2560$lcssa$i = $2579;
               }
               $2652 = $$0552767$i * $2576;
               $2653 = (($$2560$lcssa$i) + ($$0778)|0);
               if ($2337) {
                $$8579673$us$i = $2653;$$9674$us$i = 0;
                while(1) {
                 $2654 = HEAP16[$$8579673$us$i>>1]|0;
                 $2655 = (+($2654<<16>>16));
                 $$sink47$us$i1158 = $2652 * $2655;
                 $2656 = (($12) + ($$9674$us$i<<2)|0);
                 $2657 = +HEAPF32[$2656>>2];
                 $2658 = $2657 + $$sink47$us$i1158;
                 HEAPF32[$2656>>2] = $2658;
                 $2659 = (($$9674$us$i) + 1)|0;
                 $2660 = (($$8579673$us$i) + ($$0$i806)|0);
                 $exitcond828$i = ($2659|0)==($$0$i805|0);
                 if ($exitcond828$i) {
                  label = 599;
                  break L882;
                 } else {
                  $$8579673$us$i = $2660;$$9674$us$i = $2659;
                 }
                }
               } else {
                $$8579673$i = $2653;$$9674$i = 0;
                while(1) {
                 $2661 = ((($$8579673$i)) + 1|0);
                 $2662 = HEAP8[$2661>>0]|0;
                 $2663 = $2662&255;
                 $2664 = $2663 << 8;
                 $2665 = HEAP8[$$8579673$i>>0]|0;
                 $2666 = $2665&255;
                 $2667 = $2664 | $2666;
                 $sext593$i = $2667 << 16;
                 $2668 = $sext593$i >> 16;
                 $2669 = (+($2668|0));
                 $$sink47$i1159 = $2652 * $2669;
                 $2670 = (($12) + ($$9674$i<<2)|0);
                 $2671 = +HEAPF32[$2670>>2];
                 $2672 = $2671 + $$sink47$i1159;
                 HEAPF32[$2670>>2] = $2672;
                 $2673 = (($$9674$i) + 1)|0;
                 $2674 = (($$8579673$i) + ($$0$i806)|0);
                 $exitcond827$i = ($2673|0)==($$0$i805|0);
                 if ($exitcond827$i) {
                  label = 599;
                  break L882;
                 } else {
                  $$8579673$i = $2674;$$9674$i = $2673;
                 }
                }
               }
              }
              if (!($2351)) {
               $2778 = $$0555759$i - $$0557758$i;
               $2779 = $2347 * $2778;
               $2780 = (($141) + ($2350)|0);
               $2781 = (($2780) + ($2341)|0);
               if ($2337) {
                $2803 = HEAP16[$2781>>1]|0;
                $2804 = (+($2803<<16>>16));
                $$sink67$us$i11722081 = $2779 * $2804;
                $2805 = $$sink67$us$i11722081 + 0.0;
                HEAPF32[$12>>2] = $2805;
                if ($exitcond830$i2103) {
                 label = 599;
                 break;
                }
                $2806 = (($2781) + ($$0$i806)|0);
                $2807 = HEAP16[$2806>>1]|0;
                $2808 = (+($2807<<16>>16));
                $$sink67$us$i11722975 = $2779 * $2808;
                $2809 = $$sink67$us$i11722975 + 0.0;
                HEAPF32[$$phi$trans$insert868$i2974>>2] = $2809;
                if ($exitcond806$i2976) {
                 label = 599;
                 break;
                } else {
                 $2810 = 2;$2812 = $2806;
                }
                while(1) {
                 $$phi$trans$insert868$i$phi$trans$insert = (($12) + ($2810<<2)|0);
                 $$pre869$i$pre = +HEAPF32[$$phi$trans$insert868$i$phi$trans$insert>>2];
                 $2811 = (($2812) + ($$0$i806)|0);
                 $$phi$trans$insert868$i = (($12) + ($2810<<2)|0);
                 $2813 = HEAP16[$2811>>1]|0;
                 $2814 = (+($2813<<16>>16));
                 $$sink67$us$i1172 = $2779 * $2814;
                 $2815 = $$pre869$i$pre + $$sink67$us$i1172;
                 HEAPF32[$$phi$trans$insert868$i>>2] = $2815;
                 $2816 = (($2810) + 1)|0;
                 $exitcond806$i = ($2816|0)==($$0$i805|0);
                 if ($exitcond806$i) {
                  label = 599;
                  break L882;
                 } else {
                  $2810 = $2816;$2812 = $2811;
                 }
                }
               } else {
                $2782 = ((($2781)) + 1|0);
                $2783 = HEAP8[$2782>>0]|0;
                $2784 = $2783&255;
                $2785 = $2784 << 8;
                $2786 = HEAP8[$2781>>0]|0;
                $2787 = $2786&255;
                $2788 = $2785 | $2787;
                $sext585$i2077 = $2788 << 16;
                $2789 = $sext585$i2077 >> 16;
                $2790 = (+($2789|0));
                $$sink67$i11752078 = $2779 * $2790;
                $2791 = $$sink67$i11752078 + 0.0;
                HEAPF32[$12>>2] = $2791;
                if ($exitcond830$i2103) {
                 label = 599;
                 break;
                }
                $2792 = (($2781) + ($$0$i806)|0);
                $2793 = ((($2792)) + 1|0);
                $2794 = HEAP8[$2793>>0]|0;
                $2795 = $2794&255;
                $2796 = $2795 << 8;
                $2797 = HEAP8[$2792>>0]|0;
                $2798 = $2797&255;
                $2799 = $2796 | $2798;
                $sext585$i2971 = $2799 << 16;
                $2800 = $sext585$i2971 >> 16;
                $2801 = (+($2800|0));
                $$sink67$i11752972 = $2779 * $2801;
                $2802 = $$sink67$i11752972 + 0.0;
                HEAPF32[$$phi$trans$insert$i11782970>>2] = $2802;
                if ($exitcond$i11762973) {
                 label = 599;
                 break;
                } else {
                 $2817 = 2;$2819 = $2792;
                }
                while(1) {
                 $$phi$trans$insert$i1178$phi$trans$insert = (($12) + ($2817<<2)|0);
                 $$pre$i1179$pre = +HEAPF32[$$phi$trans$insert$i1178$phi$trans$insert>>2];
                 $2818 = (($2819) + ($$0$i806)|0);
                 $$phi$trans$insert$i1178 = (($12) + ($2817<<2)|0);
                 $2820 = ((($2818)) + 1|0);
                 $2821 = HEAP8[$2820>>0]|0;
                 $2822 = $2821&255;
                 $2823 = $2822 << 8;
                 $2824 = HEAP8[$2818>>0]|0;
                 $2825 = $2824&255;
                 $2826 = $2823 | $2825;
                 $sext585$i = $2826 << 16;
                 $2827 = $sext585$i >> 16;
                 $2828 = (+($2827|0));
                 $$sink67$i1175 = $2779 * $2828;
                 $2829 = $$pre$i1179$pre + $$sink67$i1175;
                 HEAPF32[$$phi$trans$insert$i1178>>2] = $2829;
                 $2830 = (($2817) + 1)|0;
                 $exitcond$i1176 = ($2830|0)==($$0$i805|0);
                 if ($exitcond$i1176) {
                  label = 599;
                  break L882;
                 } else {
                  $2817 = $2830;$2819 = $2818;
                 }
                }
               }
              }
              $2675 = 1.0 - $$0557758$i;
              $2676 = $2347 * $2675;
              $2677 = (($141) + ($2350)|0);
              $2678 = (($2677) + ($2341)|0);
              do {
               if ($2337) {
                $2700 = HEAP16[$2678>>1]|0;
                $2701 = (+($2700<<16>>16));
                $$sink52$us$i11602088 = $2676 * $2701;
                $2702 = $$sink52$us$i11602088 + 0.0;
                HEAPF32[$12>>2] = $2702;
                if ($exitcond830$i2103) {
                 break;
                }
                $2703 = (($2678) + ($$0$i806)|0);
                $2704 = HEAP16[$2703>>1]|0;
                $2705 = (+($2704<<16>>16));
                $$sink52$us$i11602982 = $2676 * $2705;
                $2706 = $$sink52$us$i11602982 + 0.0;
                HEAPF32[$$phi$trans$insert872$i2981>>2] = $2706;
                if ($exitcond808$i2983) {
                 break;
                } else {
                 $2707 = 2;$2709 = $2703;
                }
                while(1) {
                 $$phi$trans$insert872$i$phi$trans$insert = (($12) + ($2707<<2)|0);
                 $$pre873$i$pre = +HEAPF32[$$phi$trans$insert872$i$phi$trans$insert>>2];
                 $2708 = (($2709) + ($$0$i806)|0);
                 $$phi$trans$insert872$i = (($12) + ($2707<<2)|0);
                 $2710 = HEAP16[$2708>>1]|0;
                 $2711 = (+($2710<<16>>16));
                 $$sink52$us$i1160 = $2676 * $2711;
                 $2712 = $$pre873$i$pre + $$sink52$us$i1160;
                 HEAPF32[$$phi$trans$insert872$i>>2] = $2712;
                 $2713 = (($2707) + 1)|0;
                 $exitcond808$i = ($2713|0)==($$0$i805|0);
                 if ($exitcond808$i) {
                  break;
                 } else {
                  $2707 = $2713;$2709 = $2708;
                 }
                }
               } else {
                $2679 = ((($2678)) + 1|0);
                $2680 = HEAP8[$2679>>0]|0;
                $2681 = $2680&255;
                $2682 = $2681 << 8;
                $2683 = HEAP8[$2678>>0]|0;
                $2684 = $2683&255;
                $2685 = $2682 | $2684;
                $sext591$i2084 = $2685 << 16;
                $2686 = $sext591$i2084 >> 16;
                $2687 = (+($2686|0));
                $$sink52$i11632085 = $2676 * $2687;
                $2688 = $$sink52$i11632085 + 0.0;
                HEAPF32[$12>>2] = $2688;
                if ($exitcond830$i2103) {
                 break;
                }
                $2689 = (($2678) + ($$0$i806)|0);
                $2690 = ((($2689)) + 1|0);
                $2691 = HEAP8[$2690>>0]|0;
                $2692 = $2691&255;
                $2693 = $2692 << 8;
                $2694 = HEAP8[$2689>>0]|0;
                $2695 = $2694&255;
                $2696 = $2693 | $2695;
                $sext591$i2978 = $2696 << 16;
                $2697 = $sext591$i2978 >> 16;
                $2698 = (+($2697|0));
                $$sink52$i11632979 = $2676 * $2698;
                $2699 = $$sink52$i11632979 + 0.0;
                HEAPF32[$$phi$trans$insert870$i2977>>2] = $2699;
                if ($exitcond807$i2980) {
                 break;
                } else {
                 $2742 = 2;$2744 = $2689;
                }
                while(1) {
                 $$phi$trans$insert870$i$phi$trans$insert = (($12) + ($2742<<2)|0);
                 $$pre871$i$pre = +HEAPF32[$$phi$trans$insert870$i$phi$trans$insert>>2];
                 $2743 = (($2744) + ($$0$i806)|0);
                 $$phi$trans$insert870$i = (($12) + ($2742<<2)|0);
                 $2745 = ((($2743)) + 1|0);
                 $2746 = HEAP8[$2745>>0]|0;
                 $2747 = $2746&255;
                 $2748 = $2747 << 8;
                 $2749 = HEAP8[$2743>>0]|0;
                 $2750 = $2749&255;
                 $2751 = $2748 | $2750;
                 $sext591$i = $2751 << 16;
                 $2752 = $sext591$i >> 16;
                 $2753 = (+($2752|0));
                 $$sink52$i1163 = $2676 * $2753;
                 $2754 = $$pre871$i$pre + $$sink52$i1163;
                 HEAPF32[$$phi$trans$insert870$i>>2] = $2754;
                 $2755 = (($2742) + 1)|0;
                 $exitcond807$i = ($2755|0)==($$0$i805|0);
                 if ($exitcond807$i) {
                  break;
                 } else {
                  $2742 = $2755;$2744 = $2743;
                 }
                }
               }
              } while(0);
              $$2545639$i = (($$0569756$i) + 1)|0;
              $2714 = ($$2545639$i|0)<($$0567757$i|0);
              $2715 = (($2678) + ($126)|0);
              if ($2714) {
               $2716 = Math_imul($$0567757$i, $126)|0;
               if ($2337) {
                $$2545640$us$i$us = $$2545639$i;$2725 = $2715;
                while(1) {
                 $$10581636$us$us$i$us = $2725;$$11637$us$us$i$us = 0;
                 while(1) {
                  $2717 = HEAP16[$$10581636$us$us$i$us>>1]|0;
                  $2718 = (+($2717<<16>>16));
                  $$sink57$us$us$i$us = $2347 * $2718;
                  $2719 = (($12) + ($$11637$us$us$i$us<<2)|0);
                  $2720 = +HEAPF32[$2719>>2];
                  $2721 = $2720 + $$sink57$us$us$i$us;
                  HEAPF32[$2719>>2] = $2721;
                  $2722 = (($$11637$us$us$i$us) + 1)|0;
                  $2723 = (($$10581636$us$us$i$us) + ($$0$i806)|0);
                  $exitcond811$i$us = ($2722|0)==($$0$i805|0);
                  if ($exitcond811$i$us) {
                   break;
                  } else {
                   $$10581636$us$us$i$us = $2723;$$11637$us$us$i$us = $2722;
                  }
                 }
                 $$2545$us$i$us = (($$2545640$us$i$us) + 1)|0;
                 $2724 = (($2725) + ($126)|0);
                 $exitcond814$i$us = ($$2545$us$i$us|0)==($$0567757$i|0);
                 if ($exitcond814$i$us) {
                  break;
                 } else {
                  $$2545640$us$i$us = $$2545$us$i$us;$2725 = $2724;
                 }
                }
               } else {
                $$2545640$us$i = $$2545639$i;$2741 = $2715;
                while(1) {
                 $$10581636$us642$i = $2741;$$11637$us641$i = 0;
                 while(1) {
                  $2726 = ((($$10581636$us642$i)) + 1|0);
                  $2727 = HEAP8[$2726>>0]|0;
                  $2728 = $2727&255;
                  $2729 = $2728 << 8;
                  $2730 = HEAP8[$$10581636$us642$i>>0]|0;
                  $2731 = $2730&255;
                  $2732 = $2729 | $2731;
                  $sext589$us643$i = $2732 << 16;
                  $2733 = $sext589$us643$i >> 16;
                  $2734 = (+($2733|0));
                  $$sink57$us645$i = $2347 * $2734;
                  $2735 = (($12) + ($$11637$us641$i<<2)|0);
                  $2736 = +HEAPF32[$2735>>2];
                  $2737 = $2736 + $$sink57$us645$i;
                  HEAPF32[$2735>>2] = $2737;
                  $2738 = (($$11637$us641$i) + 1)|0;
                  $2739 = (($$10581636$us642$i) + ($$0$i806)|0);
                  $exitcond810$i = ($2738|0)==($$0$i805|0);
                  if ($exitcond810$i) {
                   break;
                  } else {
                   $$10581636$us642$i = $2739;$$11637$us641$i = $2738;
                  }
                 }
                 $$2545$us$i = (($$2545640$us$i) + 1)|0;
                 $2740 = (($2741) + ($126)|0);
                 $exitcond814$i = ($$2545$us$i|0)==($$0567757$i|0);
                 if ($exitcond814$i) {
                  break;
                 } else {
                  $$2545640$us$i = $$2545$us$i;$2741 = $2740;
                 }
                }
               }
               $scevgep813$i = (($uglygep$i1141) + ($2716)|0);
               $$lcssa$i1167 = $scevgep813$i;
              } else {
               $$lcssa$i1167 = $2715;
              }
              $2756 = $2347 * $$0555759$i;
              if ($2337) {
               $$11582648$us$i = $$lcssa$i1167;$$12649$us$i = 0;
               while(1) {
                $2757 = HEAP16[$$11582648$us$i>>1]|0;
                $2758 = (+($2757<<16>>16));
                $$sink62$us$i1169 = $2756 * $2758;
                $2759 = (($12) + ($$12649$us$i<<2)|0);
                $2760 = +HEAPF32[$2759>>2];
                $2761 = $2760 + $$sink62$us$i1169;
                HEAPF32[$2759>>2] = $2761;
                $2762 = (($$12649$us$i) + 1)|0;
                $2763 = (($$11582648$us$i) + ($$0$i806)|0);
                $exitcond816$i = ($2762|0)==($$0$i805|0);
                if ($exitcond816$i) {
                 label = 599;
                 break;
                } else {
                 $$11582648$us$i = $2763;$$12649$us$i = $2762;
                }
               }
              } else {
               $$11582648$i = $$lcssa$i1167;$$12649$i = 0;
               while(1) {
                $2764 = ((($$11582648$i)) + 1|0);
                $2765 = HEAP8[$2764>>0]|0;
                $2766 = $2765&255;
                $2767 = $2766 << 8;
                $2768 = HEAP8[$$11582648$i>>0]|0;
                $2769 = $2768&255;
                $2770 = $2767 | $2769;
                $sext587$i = $2770 << 16;
                $2771 = $sext587$i >> 16;
                $2772 = (+($2771|0));
                $$sink62$i1170 = $2756 * $2772;
                $2773 = (($12) + ($$12649$i<<2)|0);
                $2774 = +HEAPF32[$2773>>2];
                $2775 = $2774 + $$sink62$i1170;
                HEAPF32[$2773>>2] = $2775;
                $2776 = (($$12649$i) + 1)|0;
                $2777 = (($$11582648$i) + ($$0$i806)|0);
                $exitcond815$i = ($2776|0)==($$0$i805|0);
                if ($exitcond815$i) {
                 label = 599;
                 break;
                } else {
                 $$11582648$i = $2777;$$12649$i = $2776;
                }
               }
              }
             }
            } while(0);
            do {
             if ((label|0) == 599) {
              label = 0;
              if (!($2344)) {
               break;
              }
              $$3739$i = (($$0569756$i) + 1)|0;
              $$not$i1181 = ($$3739$i|0)<($$0567757$i|0);
              if (!($$not$i1181)) {
               break;
              }
              $2831 = (($141) + ($2350)|0);
              $2832 = (($2831) + ($126)|0);
              $2833 = (($2832) + ($2345)|0);
              $$0570749$i$us = $2833;$$2750$i$us = $$0541730$i;
              while(1) {
               if ($2337) {
                $$3741$us$i$us$us = $$3739$i;$$4562740$us$i$us$us = $$0570749$i$us;
                while(1) {
                 $$13584735$us$us$i$us$us = $$4562740$us$i$us$us;$$14736$us$us$i$us$us = 0;
                 while(1) {
                  $2852 = HEAP16[$$13584735$us$us$i$us$us>>1]|0;
                  $2853 = (+($2852<<16>>16));
                  $2854 = (($12) + ($$14736$us$us$i$us$us<<2)|0);
                  $2855 = +HEAPF32[$2854>>2];
                  $2856 = $2853 + $2855;
                  HEAPF32[$2854>>2] = $2856;
                  $2857 = (($$14736$us$us$i$us$us) + 1)|0;
                  $2858 = (($$13584735$us$us$i$us$us) + ($$0$i806)|0);
                  $exitcond862$i$us$us = ($2857|0)==($$0$i805|0);
                  if ($exitcond862$i$us$us) {
                   break;
                  } else {
                   $$13584735$us$us$i$us$us = $2858;$$14736$us$us$i$us$us = $2857;
                  }
                 }
                 $2851 = (($$4562740$us$i$us$us) + ($126)|0);
                 $$3$us$i1183$us$us = (($$3741$us$i$us$us) + 1)|0;
                 $exitcond863$i$us$us = ($$3$us$i1183$us$us|0)==($$0567757$i|0);
                 if ($exitcond863$i$us$us) {
                  break;
                 } else {
                  $$3741$us$i$us$us = $$3$us$i1183$us$us;$$4562740$us$i$us$us = $2851;
                 }
                }
               } else {
                $$3741$us$i$us2106 = $$3739$i;$$4562740$us$i$us2107 = $$0570749$i$us;
                while(1) {
                 $$13584735$us744$i$us2110 = $$4562740$us$i$us2107;$$14736$us743$i$us2109 = 0;
                 while(1) {
                  $2834 = ((($$13584735$us744$i$us2110)) + 1|0);
                  $2835 = HEAP8[$2834>>0]|0;
                  $2836 = $2835&255;
                  $2837 = $2836 << 8;
                  $2838 = HEAP8[$$13584735$us744$i$us2110>>0]|0;
                  $2839 = $2838&255;
                  $2840 = $2837 | $2839;
                  $sext$us745$i$us2111 = $2840 << 16;
                  $2841 = $sext$us745$i$us2111 >> 16;
                  $2842 = (+($2841|0));
                  $2843 = (($12) + ($$14736$us743$i$us2109<<2)|0);
                  $2844 = +HEAPF32[$2843>>2];
                  $2845 = $2844 + $2842;
                  HEAPF32[$2843>>2] = $2845;
                  $2846 = (($$14736$us743$i$us2109) + 1)|0;
                  $2847 = (($$13584735$us744$i$us2110) + ($$0$i806)|0);
                  $exitcond861$i$us2112 = ($2846|0)==($$0$i805|0);
                  if ($exitcond861$i$us2112) {
                   break;
                  } else {
                   $$13584735$us744$i$us2110 = $2847;$$14736$us743$i$us2109 = $2846;
                  }
                 }
                 $2848 = (($$4562740$us$i$us2107) + ($126)|0);
                 $$3$us$i1183$us2118 = (($$3741$us$i$us2106) + 1)|0;
                 $exitcond863$i$us2119 = ($$3$us$i1183$us2118|0)==($$0567757$i|0);
                 if ($exitcond863$i$us2119) {
                  break;
                 } else {
                  $$3741$us$i$us2106 = $$3$us$i1183$us2118;$$4562740$us$i$us2107 = $2848;
                 }
                }
               }
               $2849 = (($$0570749$i$us) + ($$0778)|0);
               $2850 = (($$2750$i$us) + 1)|0;
               $exitcond864$i$us = ($2850|0)==($$0563$$i|0);
               if ($exitcond864$i$us) {
                break;
               } else {
                $$0570749$i$us = $2849;$$2750$i$us = $2850;
               }
              }
             }
            } while(0);
            $2859 = (($$0547760$i) + ($2346))|0;
            $2860 = Math_imul($2859, $$0$i805)|0;
            $$15752$i = 0;
            while(1) {
             $2861 = (($12) + ($$15752$i<<2)|0);
             $2862 = +HEAPF32[$2861>>2];
             $2863 = $2862 / $2333;
             $2864 = (~~(($2863)));
             $2865 = (($$15752$i) + ($2860))|0;
             $2866 = (($1241) + ($2865<<1)|0);
             HEAP16[$2866>>1] = $2864;
             $2867 = (($$15752$i) + 1)|0;
             $exitcond865$i = ($2867|0)==($$0$i805|0);
             if ($exitcond865$i) {
              break;
             } else {
              $$15752$i = $2867;
             }
            }
            $2868 = (($$0567757$i) + ($2330))|0;
            $2869 = $2332 + $$0555759$i;
            $2870 = $2869 > 1.0;
            $2871 = $2869 + -1.0;
            $2872 = $2870&1;
            $$1568$i = (($2868) + ($2872))|0;
            $$1556$i = $2870 ? $2871 : $2869;
            $2873 = (($$0547760$i) + 1)|0;
            $exitcond866$i = ($2873|0)==($4|0);
            if ($exitcond866$i) {
             break;
            } else {
             $$0569756$i$phi = $$0567757$i;$$0557758$i$phi = $$0555759$i;$$0547760$i = $2873;$$0555759$i = $$1556$i;$$0567757$i = $$1568$i;$$0569756$i = $$0569756$i$phi;$$0557758$i = $$0557758$i$phi;
            }
           }
          }
          $2874 = $2328 + $$0552767$i;
          $2875 = $2874 > 1.0;
          $2876 = $2874 + -1.0;
          $2877 = $2875&1;
          $2878 = (($2877) + ($2326))|0;
          $$2565$i = (($2878) + ($$0563$$i))|0;
          $$1553$i = $2875 ? $2876 : $2874;
          $2879 = (($$0546768$i) + 1)|0;
          $exitcond867$i = ($2879|0)==($5|0);
          if ($exitcond867$i) {
           break;
          } else {
           $$0554766$i$phi = $$0552767$i;$$0546768$i = $2879;$$0552767$i = $$1553$i;$$0563765$i = $$2565$i;$$0566764$i = $$0563$$i;$$0554766$i = $$0554766$i$phi;
          }
         }
        }
       }
       break L470;
       break;
      }
      default: {
       break L470;
      }
      }
     }
     $switch$split1142D = ($7|0)<(5126);
     if (!($switch$split1142D)) {
      $switch$split1382D = ($7|0)<(32818);
      if (!($switch$split1382D)) {
       switch ($7|0) {
       case 32818:  {
        break;
       }
       case 32819:  {
        __ZN3osgL24scaleInternalPackedPixelEiPFviPKvPfEPFvPKfiPvEiiS1_iiS7_iii(4,4007,4008,$2,$3,$141,$4,$5,$1241,$$0$i806,$$0778,$$785);
        break L470;
        break;
       }
       default: {
        break L470;
       }
       }
       $4655 = $4 << 1;
       $4656 = ($4655|0)==($2|0);
       $4657 = $5 << 1;
       $4658 = ($4657|0)==($3|0);
       $or$cond$i1466 = $4656 & $4658;
       L1062: do {
        if ($or$cond$i1466) {
         $4659 = ($2|0)==(1);
         $4660 = ($3|0)==(1);
         $or$cond$i1726 = $4659 | $4660;
         $4661 = (($2|0) / 2)&-1;
         $4662 = (($3|0) / 2)&-1;
         if (!($or$cond$i1726)) {
          $4787 = Math_imul($$0$i806, $2)|0;
          $4788 = (($$0778) - ($4787))|0;
          $4789 = ($3|0)>(1);
          if (!($4789)) {
           break;
          }
          $4790 = ($2|0)>(1);
          $4791 = $$0$i806 << 1;
          if ($4790) {
           $$07999$us$i1744 = 0;$$08098$us$i1745 = 0;$$08197$us$i1746 = $141;
          } else {
           break;
          }
          while(1) {
           $$08391$us$us$i1751 = 0;$$18292$us$us$i1750 = $$08197$us$i1746;$$193$us$us$i1749 = $$07999$us$i1744;
           while(1) {
            $4797 = HEAP8[$$18292$us$us$i1750>>0]|0;
            $4798 = $4797&255;
            $4799 = $4798 >>> 5;
            $4800 = (+($4799|0));
            $4801 = $4800 / 7.0;
            $4802 = $4798 >>> 2;
            $4803 = $4802 & 7;
            $4804 = (+($4803|0));
            $4805 = $4804 / 7.0;
            $4806 = $4798 & 3;
            $4807 = (+($4806|0));
            $4808 = $4807 / 3.0;
            $4809 = (($$18292$us$us$i1750) + ($$0$i806)|0);
            $4810 = HEAP8[$4809>>0]|0;
            $4811 = $4810&255;
            $4812 = $4811 >>> 5;
            $4813 = (+($4812|0));
            $4814 = $4813 / 7.0;
            $4815 = $4811 >>> 2;
            $4816 = $4815 & 7;
            $4817 = (+($4816|0));
            $4818 = $4817 / 7.0;
            $4819 = $4811 & 3;
            $4820 = (+($4819|0));
            $4821 = $4820 / 3.0;
            $4822 = (($$18292$us$us$i1750) + ($$0778)|0);
            $4823 = HEAP8[$4822>>0]|0;
            $4824 = $4823&255;
            $4825 = $4824 >>> 5;
            $4826 = (+($4825|0));
            $4827 = $4826 / 7.0;
            $4828 = $4824 >>> 2;
            $4829 = $4828 & 7;
            $4830 = (+($4829|0));
            $4831 = $4830 / 7.0;
            $4832 = $4824 & 3;
            $4833 = (+($4832|0));
            $4834 = $4833 / 3.0;
            $4835 = (($4822) + ($$0$i806)|0);
            $4836 = HEAP8[$4835>>0]|0;
            $4837 = $4836&255;
            $4838 = $4837 >>> 5;
            $4839 = (+($4838|0));
            $4840 = $4839 / 7.0;
            $4841 = $4837 >>> 2;
            $4842 = $4841 & 7;
            $4843 = (+($4842|0));
            $4844 = $4843 / 7.0;
            $4845 = $4837 & 3;
            $4846 = (+($4845|0));
            $4847 = $4846 / 3.0;
            $4848 = $4801 + 0.0;
            $4849 = $4848 + $4814;
            $4850 = $4849 + $4827;
            $4851 = $4850 + $4840;
            $4852 = $4851 * 0.25;
            $4853 = $4805 + 0.0;
            $4854 = $4853 + $4818;
            $4855 = $4854 + $4831;
            $4856 = $4855 + $4844;
            $4857 = $4856 * 0.25;
            $4858 = $4808 + 0.0;
            $4859 = $4858 + $4821;
            $4860 = $4859 + $4834;
            $4861 = $4860 + $4847;
            $4862 = $4861 * 0.25;
            $4863 = $4852 * 7.0;
            $4864 = $4863;
            $4865 = $4864 + 0.5;
            $4866 = (~~(($4865))&255);
            $4867 = $4866&255;
            $4868 = $4867 << 5;
            $4869 = (($1241) + ($$193$us$us$i1749)|0);
            $4870 = $4857 * 7.0;
            $4871 = $4870;
            $4872 = $4871 + 0.5;
            $4873 = (~~(($4872))&255);
            $4874 = $4873&255;
            $4875 = $4874 << 2;
            $4876 = $4875 & 28;
            $4877 = $4876 | $4868;
            $4878 = $4862 * 3.0;
            $4879 = $4878;
            $4880 = $4879 + 0.5;
            $4881 = (~~(($4880))&255);
            $4882 = $4881 & 3;
            $4883 = $4882&255;
            $4884 = $4877 | $4883;
            $4885 = $4884&255;
            HEAP8[$4869>>0] = $4885;
            $4886 = (($$193$us$us$i1749) + 1)|0;
            $4793 = (($$18292$us$us$i1750) + ($4791)|0);
            $4887 = (($$08391$us$us$i1751) + 1)|0;
            $4888 = ($4887|0)<($4661|0);
            if ($4888) {
             $$08391$us$us$i1751 = $4887;$$18292$us$us$i1750 = $4793;$$193$us$us$i1749 = $4886;
            } else {
             break;
            }
           }
           $4792 = (($4793) + ($4788)|0);
           $4794 = (($4792) + ($$0778)|0);
           $4795 = (($$08098$us$i1745) + 1)|0;
           $4796 = ($4795|0)<($4662|0);
           if ($4796) {
            $$07999$us$i1744 = $4886;$$08098$us$i1745 = $4795;$$08197$us$i1746 = $4794;
           } else {
            break L1062;
           }
          }
         }
         if ($4660) {
          $4663 = ($2|0)>(1);
          if (!($4663)) {
           break;
          }
          $4664 = $$0$i806 << 1;
          $$088100$us$i$i1729 = 0;$$09098$us$i$i1730 = $141;
          while(1) {
           $4665 = HEAP8[$$09098$us$i$i1730>>0]|0;
           $4666 = $4665&255;
           $4667 = $4666 >>> 5;
           $4668 = (+($4667|0));
           $4669 = $4668 / 7.0;
           $4670 = $4666 >>> 2;
           $4671 = $4670 & 7;
           $4672 = (+($4671|0));
           $4673 = $4672 / 7.0;
           $4674 = $4666 & 3;
           $4675 = (+($4674|0));
           $4676 = $4675 / 3.0;
           $4677 = (($$09098$us$i$i1730) + ($$0$i806)|0);
           $4678 = HEAP8[$4677>>0]|0;
           $4679 = $4678&255;
           $4680 = $4679 >>> 5;
           $4681 = (+($4680|0));
           $4682 = $4681 / 7.0;
           $4683 = $4679 >>> 2;
           $4684 = $4683 & 7;
           $4685 = (+($4684|0));
           $4686 = $4685 / 7.0;
           $4687 = $4679 & 3;
           $4688 = (+($4687|0));
           $4689 = $4688 / 3.0;
           $4690 = $4669 + 0.0;
           $4691 = $4690 + $4682;
           $4692 = $4691 * 0.5;
           $4693 = $4673 + 0.0;
           $4694 = $4693 + $4686;
           $4695 = $4694 * 0.5;
           $4696 = $4676 + 0.0;
           $4697 = $4696 + $4689;
           $4698 = $4697 * 0.5;
           $4699 = $4692 * 7.0;
           $4700 = $4699;
           $4701 = $4700 + 0.5;
           $4702 = (~~(($4701))&255);
           $4703 = $4702&255;
           $4704 = $4703 << 5;
           $4705 = (($1241) + ($$088100$us$i$i1729)|0);
           $4706 = $4695 * 7.0;
           $4707 = $4706;
           $4708 = $4707 + 0.5;
           $4709 = (~~(($4708))&255);
           $4710 = $4709&255;
           $4711 = $4710 << 2;
           $4712 = $4711 & 28;
           $4713 = $4712 | $4704;
           $4714 = $4698 * 3.0;
           $4715 = $4714;
           $4716 = $4715 + 0.5;
           $4717 = (~~(($4716))&255);
           $4718 = $4717 & 3;
           $4719 = $4718&255;
           $4720 = $4713 | $4719;
           $4721 = $4720&255;
           HEAP8[$4705>>0] = $4721;
           $4722 = (($$088100$us$i$i1729) + 1)|0;
           $4723 = (($$09098$us$i$i1730) + ($4664)|0);
           $4724 = ($4722|0)<($4661|0);
           if ($4724) {
            $$088100$us$i$i1729 = $4722;$$09098$us$i$i1730 = $4723;
           } else {
            break;
           }
          }
         } else {
          $4725 = ($3|0)>(1);
          $or$cond$i$i1735 = $4659 & $4725;
          if (!($or$cond$i$i1735)) {
           break;
          }
          $4726 = $$0778 << 1;
          $$085110$us$i$i1737 = 0;$$191108$us$i$i1738 = $141;
          while(1) {
           $4727 = HEAP8[$$191108$us$i$i1738>>0]|0;
           $4728 = $4727&255;
           $4729 = $4728 >>> 5;
           $4730 = (+($4729|0));
           $4731 = $4730 / 7.0;
           $4732 = $4728 >>> 2;
           $4733 = $4732 & 7;
           $4734 = (+($4733|0));
           $4735 = $4734 / 7.0;
           $4736 = $4728 & 3;
           $4737 = (+($4736|0));
           $4738 = $4737 / 3.0;
           $4739 = (($$191108$us$i$i1738) + ($$0778)|0);
           $4740 = HEAP8[$4739>>0]|0;
           $4741 = $4740&255;
           $4742 = $4741 >>> 5;
           $4743 = (+($4742|0));
           $4744 = $4743 / 7.0;
           $4745 = $4741 >>> 2;
           $4746 = $4745 & 7;
           $4747 = (+($4746|0));
           $4748 = $4747 / 7.0;
           $4749 = $4741 & 3;
           $4750 = (+($4749|0));
           $4751 = $4750 / 3.0;
           $4752 = $4731 + 0.0;
           $4753 = $4752 + $4744;
           $4754 = $4753 * 0.5;
           $4755 = $4735 + 0.0;
           $4756 = $4755 + $4748;
           $4757 = $4756 * 0.5;
           $4758 = $4738 + 0.0;
           $4759 = $4758 + $4751;
           $4760 = $4759 * 0.5;
           $4761 = $4754 * 7.0;
           $4762 = $4761;
           $4763 = $4762 + 0.5;
           $4764 = (~~(($4763))&255);
           $4765 = $4764&255;
           $4766 = $4765 << 5;
           $4767 = (($1241) + ($$085110$us$i$i1737)|0);
           $4768 = $4757 * 7.0;
           $4769 = $4768;
           $4770 = $4769 + 0.5;
           $4771 = (~~(($4770))&255);
           $4772 = $4771&255;
           $4773 = $4772 << 2;
           $4774 = $4773 & 28;
           $4775 = $4774 | $4766;
           $4776 = $4760 * 3.0;
           $4777 = $4776;
           $4778 = $4777 + 0.5;
           $4779 = (~~(($4778))&255);
           $4780 = $4779 & 3;
           $4781 = $4780&255;
           $4782 = $4775 | $4781;
           $4783 = $4782&255;
           HEAP8[$4767>>0] = $4783;
           $4784 = (($$085110$us$i$i1737) + 1)|0;
           $4785 = (($$191108$us$i$i1738) + ($4726)|0);
           $4786 = ($4784|0)<($4662|0);
           if ($4786) {
            $$085110$us$i$i1737 = $4784;$$191108$us$i$i1738 = $4785;
           } else {
            break;
           }
          }
         }
        } else {
         $4889 = (+($3|0));
         $4890 = (+($5|0));
         $4891 = $4889 / $4890;
         $4892 = (+($2|0));
         $4893 = (+($4|0));
         $4894 = $4892 / $4893;
         $4895 = (+Math_floor((+$4891)));
         $4896 = (~~(($4895)));
         $4897 = (+($4896|0));
         $4898 = $4891 - $4897;
         $4899 = (+Math_floor((+$4894)));
         $4900 = (~~(($4899)));
         $4901 = (+($4900|0));
         $4902 = $4894 - $4901;
         $4903 = $4894 * $4891;
         $4904 = ($5|0)>(0);
         if ($4904) {
          $4905 = ($4|0)>(0);
          $4906 = ((($13)) + 4|0);
          $4907 = ((($13)) + 8|0);
          $4908 = ((($14)) + 4|0);
          $4909 = ((($14)) + 8|0);
          $4910 = ((($12)) + 4|0);
          $4911 = ((($12)) + 8|0);
          $4912 = ((($12)) + 4|0);
          $4913 = ((($12)) + 8|0);
          $4914 = ((($12)) + 4|0);
          $4915 = ((($12)) + 8|0);
          $4916 = ((($12)) + 4|0);
          $4917 = ((($12)) + 8|0);
          $4918 = ((($12)) + 4|0);
          $4919 = ((($12)) + 8|0);
          $$0374510$i = 0;$$0380509$i = $4898;$$0382508$i = 0.0;$$0391507$i = $4896;$$0393506$i = 0;
          while(1) {
           if ($4905) {
            $4920 = ($$0391507$i|0)>($$0393506$i|0);
            $4921 = Math_imul($$0393506$i, $$0778)|0;
            $4922 = 1.0 - $$0382508$i;
            $4923 = Math_imul($$0391507$i, $$0778)|0;
            $$0370474$i = (($$0393506$i) + 1)|0;
            $4924 = ($$0370474$i|0)<($$0391507$i|0);
            $4925 = Math_imul($$0370474$i, $$0778)|0;
            $4926 = Math_imul($$0374510$i, $4)|0;
            $4927 = $$0380509$i - $$0382508$i;
            $scevgep$i1467 = (($141) + ($4921)|0);
            $4928 = (($$0391507$i) + -1)|0;
            $4929 = Math_imul($4928, $$0778)|0;
            $scevgep537$i = (($141) + ($4929)|0);
            $scevgep555$i = (($141) + ($4923)|0);
            $$0375503$i = 0;$$0383499$i = $4902;$$0385498$i = 0.0;$$0394496$i = $4900;$$0396495$i = 0;
            while(1) {
             $4930 = Math_imul($$0396495$i, $$0$i806)|0;
             $4931 = ($$0394496$i|0)>($$0396495$i|0);
             $or$cond399$i = $4920 & $4931;
             ;HEAP32[$12>>2]=0|0;HEAP32[$12+4>>2]=0|0;HEAP32[$12+8>>2]=0|0;HEAP32[$12+12>>2]=0|0;
             do {
              if ($or$cond399$i) {
               $4932 = (($141) + ($4930)|0);
               $4933 = (($4932) + ($4921)|0);
               $4934 = 1.0 - $$0385498$i;
               $4935 = $4922 * $4934;
               $4936 = HEAP8[$4933>>0]|0;
               $4937 = $4936&255;
               $4938 = $4937 >>> 5;
               $4939 = (+($4938|0));
               $4940 = $4939 / 7.0;
               HEAPF32[$13>>2] = $4940;
               $4941 = $4937 >>> 2;
               $4942 = $4941 & 7;
               $4943 = (+($4942|0));
               $4944 = $4943 / 7.0;
               HEAPF32[$4906>>2] = $4944;
               $4945 = $4937 & 3;
               $4946 = (+($4945|0));
               $4947 = $4946 / 3.0;
               HEAPF32[$4907>>2] = $4947;
               $4948 = $4935 * $4940;
               $4949 = $4948 + 0.0;
               HEAPF32[$12>>2] = $4949;
               $4950 = $4935 * $4944;
               $4951 = $4950 + 0.0;
               HEAPF32[$4910>>2] = $4951;
               $4952 = $4935 * $4947;
               $4953 = $4952 + 0.0;
               HEAPF32[$4911>>2] = $4953;
               $4954 = (($$0396495$i) + 1)|0;
               $4955 = ($4954|0)<($$0394496$i|0);
               $4956 = (($4933) + ($$0$i806)|0);
               if ($4955) {
                $$0371448$us$i = $4954;$4958 = $4956;$4972 = $4949;$4975 = $4951;$4978 = $4953;
                while(1) {
                 $4957 = HEAP8[$4958>>0]|0;
                 $4959 = $4957&255;
                 $4960 = $4959 >>> 5;
                 $4961 = (+($4960|0));
                 $4962 = $4961 / 7.0;
                 HEAPF32[$13>>2] = $4962;
                 $4963 = $4959 >>> 2;
                 $4964 = $4963 & 7;
                 $4965 = (+($4964|0));
                 $4966 = $4965 / 7.0;
                 HEAPF32[$4906>>2] = $4966;
                 $4967 = $4959 & 3;
                 $4968 = (+($4967|0));
                 $4969 = $4968 / 3.0;
                 HEAPF32[$4907>>2] = $4969;
                 $4970 = $4922 * $4962;
                 $4971 = $4972 + $4970;
                 HEAPF32[$12>>2] = $4971;
                 $4973 = $4922 * $4966;
                 $4974 = $4975 + $4973;
                 HEAPF32[$4910>>2] = $4974;
                 $4976 = $4922 * $4969;
                 $4977 = $4978 + $4976;
                 HEAPF32[$4911>>2] = $4977;
                 $4979 = (($$0371448$us$i) + 1)|0;
                 $4980 = (($4958) + ($$0$i806)|0);
                 $exitcond552$i = ($4979|0)==($$0394496$i|0);
                 if ($exitcond552$i) {
                  break;
                 } else {
                  $$0371448$us$i = $4979;$4958 = $4980;$4972 = $4971;$4975 = $4974;$4978 = $4977;
                 }
                }
                $4981 = Math_imul($$0394496$i, $$0$i806)|0;
                $scevgep551$i = (($scevgep$i1467) + ($4981)|0);
                $$lcssa412$i = $scevgep551$i;$4997 = $4971;$5000 = $4974;$5003 = $4977;
               } else {
                $$lcssa412$i = $4956;$4997 = $4949;$5000 = $4951;$5003 = $4953;
               }
               $4982 = $4922 * $$0383499$i;
               $4983 = HEAP8[$$lcssa412$i>>0]|0;
               $4984 = $4983&255;
               $4985 = $4984 >>> 5;
               $4986 = (+($4985|0));
               $4987 = $4986 / 7.0;
               $4988 = $4984 >>> 2;
               $4989 = $4988 & 7;
               $4990 = (+($4989|0));
               $4991 = $4990 / 7.0;
               $4992 = $4984 & 3;
               $4993 = (+($4992|0));
               $4994 = $4993 / 3.0;
               $4995 = $4982 * $4987;
               $4996 = $4997 + $4995;
               $4998 = $4982 * $4991;
               $4999 = $5000 + $4998;
               $5001 = $4982 * $4994;
               $5002 = $5003 + $5001;
               $5004 = $$0380509$i * $4934;
               $5005 = (($4932) + ($4923)|0);
               $5006 = HEAP8[$5005>>0]|0;
               $5007 = $5006&255;
               $5008 = $5007 >>> 5;
               $5009 = (+($5008|0));
               $5010 = $5009 / 7.0;
               HEAPF32[$13>>2] = $5010;
               $5011 = $5007 >>> 2;
               $5012 = $5011 & 7;
               $5013 = (+($5012|0));
               $5014 = $5013 / 7.0;
               HEAPF32[$4906>>2] = $5014;
               $5015 = $5007 & 3;
               $5016 = (+($5015|0));
               $5017 = $5016 / 3.0;
               HEAPF32[$4907>>2] = $5017;
               $5018 = $5004 * $5010;
               $5019 = $4996 + $5018;
               HEAPF32[$12>>2] = $5019;
               $5020 = $5004 * $5014;
               $5021 = $4999 + $5020;
               HEAPF32[$4910>>2] = $5021;
               $5022 = $5004 * $5017;
               $5023 = $5002 + $5022;
               HEAPF32[$4911>>2] = $5023;
               $5024 = (($5005) + ($$0$i806)|0);
               if ($4955) {
                $$1372464$us$i = $4954;$5026 = $5024;$5040 = $5019;$5043 = $5021;$5046 = $5023;
                while(1) {
                 $5025 = HEAP8[$5026>>0]|0;
                 $5027 = $5025&255;
                 $5028 = $5027 >>> 5;
                 $5029 = (+($5028|0));
                 $5030 = $5029 / 7.0;
                 HEAPF32[$13>>2] = $5030;
                 $5031 = $5027 >>> 2;
                 $5032 = $5031 & 7;
                 $5033 = (+($5032|0));
                 $5034 = $5033 / 7.0;
                 HEAPF32[$4906>>2] = $5034;
                 $5035 = $5027 & 3;
                 $5036 = (+($5035|0));
                 $5037 = $5036 / 3.0;
                 HEAPF32[$4907>>2] = $5037;
                 $5038 = $$0380509$i * $5030;
                 $5039 = $5040 + $5038;
                 HEAPF32[$12>>2] = $5039;
                 $5041 = $$0380509$i * $5034;
                 $5042 = $5043 + $5041;
                 HEAPF32[$4910>>2] = $5042;
                 $5044 = $$0380509$i * $5037;
                 $5045 = $5046 + $5044;
                 HEAPF32[$4911>>2] = $5045;
                 $5047 = (($$1372464$us$i) + 1)|0;
                 $5048 = (($5026) + ($$0$i806)|0);
                 $exitcond561$i = ($5047|0)==($$0394496$i|0);
                 if ($exitcond561$i) {
                  break;
                 } else {
                  $$1372464$us$i = $5047;$5026 = $5048;$5040 = $5039;$5043 = $5042;$5046 = $5045;
                 }
                }
                $5049 = Math_imul($$0394496$i, $$0$i806)|0;
                $scevgep560$i = (($scevgep555$i) + ($5049)|0);
                $$lcssa413$i = $scevgep560$i;$5065 = $5039;$5068 = $5042;$5071 = $5045;
               } else {
                $$lcssa413$i = $5024;$5065 = $5019;$5068 = $5021;$5071 = $5023;
               }
               $5050 = $$0380509$i * $$0383499$i;
               $5051 = HEAP8[$$lcssa413$i>>0]|0;
               $5052 = $5051&255;
               $5053 = $5052 >>> 5;
               $5054 = (+($5053|0));
               $5055 = $5054 / 7.0;
               HEAPF32[$13>>2] = $5055;
               $5056 = $5052 >>> 2;
               $5057 = $5056 & 7;
               $5058 = (+($5057|0));
               $5059 = $5058 / 7.0;
               HEAPF32[$4906>>2] = $5059;
               $5060 = $5052 & 3;
               $5061 = (+($5060|0));
               $5062 = $5061 / 3.0;
               HEAPF32[$4907>>2] = $5062;
               $5063 = $5050 * $5055;
               $5064 = $5065 + $5063;
               HEAPF32[$12>>2] = $5064;
               $5066 = $5050 * $5059;
               $5067 = $5068 + $5066;
               HEAPF32[$4910>>2] = $5067;
               $5069 = $5050 * $5062;
               $5070 = $5071 + $5069;
               HEAPF32[$4911>>2] = $5070;
               if ($4924) {
                $$0369475$us$i = $4933;$$0370477$us$i = $$0370474$i;$$0476$us$i = $$lcssa412$i;$5102 = $5064;$5107 = $5067;$5112 = $5070;
               } else {
                $5298 = $5064;$5300 = $5067;$5302 = $5070;
                break;
               }
               while(1) {
                $5072 = (($$0369475$us$i) + ($$0778)|0);
                $5073 = (($$0476$us$i) + ($$0778)|0);
                $5074 = HEAP8[$5072>>0]|0;
                $5075 = $5074&255;
                $5076 = $5075 >>> 5;
                $5077 = (+($5076|0));
                $5078 = $5077 / 7.0;
                HEAPF32[$13>>2] = $5078;
                $5079 = $5075 >>> 2;
                $5080 = $5079 & 7;
                $5081 = (+($5080|0));
                $5082 = $5081 / 7.0;
                HEAPF32[$4906>>2] = $5082;
                $5083 = $5075 & 3;
                $5084 = (+($5083|0));
                $5085 = $5084 / 3.0;
                HEAPF32[$4907>>2] = $5085;
                $5086 = HEAP8[$5073>>0]|0;
                $5087 = $5086&255;
                $5088 = $5087 >>> 5;
                $5089 = (+($5088|0));
                $5090 = $5089 / 7.0;
                HEAPF32[$14>>2] = $5090;
                $5091 = $5087 >>> 2;
                $5092 = $5091 & 7;
                $5093 = (+($5092|0));
                $5094 = $5093 / 7.0;
                HEAPF32[$4908>>2] = $5094;
                $5095 = $5087 & 3;
                $5096 = (+($5095|0));
                $5097 = $5096 / 3.0;
                HEAPF32[$4909>>2] = $5097;
                $5098 = $4934 * $5078;
                $5099 = $$0383499$i * $5090;
                $5100 = $5098 + $5099;
                $5101 = $5102 + $5100;
                HEAPF32[$12>>2] = $5101;
                $5103 = $4934 * $5082;
                $5104 = $$0383499$i * $5094;
                $5105 = $5103 + $5104;
                $5106 = $5107 + $5105;
                HEAPF32[$4910>>2] = $5106;
                $5108 = $4934 * $5085;
                $5109 = $$0383499$i * $5097;
                $5110 = $5108 + $5109;
                $5111 = $5112 + $5110;
                HEAPF32[$4911>>2] = $5111;
                $$0370$us$i = (($$0370477$us$i) + 1)|0;
                $exitcond565$i = ($$0370$us$i|0)==($$0391507$i|0);
                if ($exitcond565$i) {
                 $7060 = $5111;$7061 = $5106;$7062 = $5101;
                 label = 977;
                 break;
                } else {
                 $$0369475$us$i = $5072;$$0370477$us$i = $$0370$us$i;$$0476$us$i = $5073;$5102 = $5101;$5107 = $5106;$5112 = $5111;
                }
               }
              } else {
               if ($4920) {
                $5113 = $$0383499$i - $$0385498$i;
                $5114 = $4922 * $5113;
                $5115 = (($141) + ($4930)|0);
                $5116 = (($5115) + ($4921)|0);
                $5117 = HEAP8[$5116>>0]|0;
                $5118 = $5117&255;
                $5119 = $5118 >>> 5;
                $5120 = (+($5119|0));
                $5121 = $5120 / 7.0;
                HEAPF32[$13>>2] = $5121;
                $5122 = $5118 >>> 2;
                $5123 = $5122 & 7;
                $5124 = (+($5123|0));
                $5125 = $5124 / 7.0;
                HEAPF32[$4906>>2] = $5125;
                $5126 = $5118 & 3;
                $5127 = (+($5126|0));
                $5128 = $5127 / 3.0;
                HEAPF32[$4907>>2] = $5128;
                $5129 = $5114 * $5121;
                $5130 = $5129 + 0.0;
                HEAPF32[$12>>2] = $5130;
                $5131 = $5114 * $5125;
                $5132 = $5131 + 0.0;
                HEAPF32[$4914>>2] = $5132;
                $5133 = $5114 * $5128;
                $5134 = $5133 + 0.0;
                HEAPF32[$4915>>2] = $5134;
                if ($4924) {
                 $$1433$us$i = $$0370474$i;$$2388432$us$i = $5116;$5150 = $5130;$5153 = $5132;$5156 = $5134;
                 while(1) {
                  $5135 = (($$2388432$us$i) + ($$0778)|0);
                  $5136 = HEAP8[$5135>>0]|0;
                  $5137 = $5136&255;
                  $5138 = $5137 >>> 5;
                  $5139 = (+($5138|0));
                  $5140 = $5139 / 7.0;
                  HEAPF32[$13>>2] = $5140;
                  $5141 = $5137 >>> 2;
                  $5142 = $5141 & 7;
                  $5143 = (+($5142|0));
                  $5144 = $5143 / 7.0;
                  HEAPF32[$4906>>2] = $5144;
                  $5145 = $5137 & 3;
                  $5146 = (+($5145|0));
                  $5147 = $5146 / 3.0;
                  HEAPF32[$4907>>2] = $5147;
                  $5148 = $5113 * $5140;
                  $5149 = $5150 + $5148;
                  HEAPF32[$12>>2] = $5149;
                  $5151 = $5113 * $5144;
                  $5152 = $5153 + $5151;
                  HEAPF32[$4914>>2] = $5152;
                  $5154 = $5113 * $5147;
                  $5155 = $5156 + $5154;
                  HEAPF32[$4915>>2] = $5155;
                  $$1$us$i1470 = (($$1433$us$i) + 1)|0;
                  $exitcond543$i = ($$1$us$i1470|0)==($$0391507$i|0);
                  if ($exitcond543$i) {
                   break;
                  } else {
                   $$1433$us$i = $$1$us$i1470;$$2388432$us$i = $5135;$5150 = $5149;$5153 = $5152;$5156 = $5155;
                  }
                 }
                 $scevgep542$i = (($scevgep537$i) + ($4930)|0);
                 $$2388$lcssa$i = $scevgep542$i;$5173 = $5149;$5176 = $5152;$5179 = $5155;
                } else {
                 $$2388$lcssa$i = $5116;$5173 = $5130;$5176 = $5132;$5179 = $5134;
                }
                $5157 = $$0380509$i * $5113;
                $5158 = (($$2388$lcssa$i) + ($$0778)|0);
                $5159 = HEAP8[$5158>>0]|0;
                $5160 = $5159&255;
                $5161 = $5160 >>> 5;
                $5162 = (+($5161|0));
                $5163 = $5162 / 7.0;
                HEAPF32[$13>>2] = $5163;
                $5164 = $5160 >>> 2;
                $5165 = $5164 & 7;
                $5166 = (+($5165|0));
                $5167 = $5166 / 7.0;
                HEAPF32[$4906>>2] = $5167;
                $5168 = $5160 & 3;
                $5169 = (+($5168|0));
                $5170 = $5169 / 3.0;
                HEAPF32[$4907>>2] = $5170;
                $5171 = $5157 * $5163;
                $5172 = $5173 + $5171;
                HEAPF32[$12>>2] = $5172;
                $5174 = $5157 * $5167;
                $5175 = $5176 + $5174;
                HEAPF32[$4914>>2] = $5175;
                $5177 = $5157 * $5170;
                $5178 = $5179 + $5177;
                HEAPF32[$4915>>2] = $5178;
                $7060 = $5178;$7061 = $5175;$7062 = $5172;
                label = 977;
                break;
               }
               if (!($4931)) {
                $5250 = $$0383499$i - $$0385498$i;
                $5251 = $4927 * $5250;
                $5252 = (($141) + ($4930)|0);
                $5253 = (($5252) + ($4921)|0);
                $5254 = HEAP8[$5253>>0]|0;
                $5255 = $5254&255;
                $5256 = $5255 >>> 5;
                $5257 = (+($5256|0));
                $5258 = $5257 / 7.0;
                HEAPF32[$13>>2] = $5258;
                $5259 = $5255 >>> 2;
                $5260 = $5259 & 7;
                $5261 = (+($5260|0));
                $5262 = $5261 / 7.0;
                HEAPF32[$4906>>2] = $5262;
                $5263 = $5255 & 3;
                $5264 = (+($5263|0));
                $5265 = $5264 / 3.0;
                HEAPF32[$4907>>2] = $5265;
                $5266 = $5251 * $5258;
                $5267 = $5266 + 0.0;
                HEAPF32[$12>>2] = $5267;
                $5268 = $5251 * $5262;
                $5269 = $5268 + 0.0;
                HEAPF32[$4918>>2] = $5269;
                $5270 = $5251 * $5265;
                $5271 = $5270 + 0.0;
                HEAPF32[$4919>>2] = $5271;
                $7060 = $5271;$7061 = $5269;$7062 = $5267;
                label = 977;
                break;
               }
               $5180 = 1.0 - $$0385498$i;
               $5181 = $4927 * $5180;
               $5182 = (($141) + ($4930)|0);
               $5183 = (($5182) + ($4921)|0);
               $5184 = HEAP8[$5183>>0]|0;
               $5185 = $5184&255;
               $5186 = $5185 >>> 5;
               $5187 = (+($5186|0));
               $5188 = $5187 / 7.0;
               HEAPF32[$13>>2] = $5188;
               $5189 = $5185 >>> 2;
               $5190 = $5189 & 7;
               $5191 = (+($5190|0));
               $5192 = $5191 / 7.0;
               HEAPF32[$4906>>2] = $5192;
               $5193 = $5185 & 3;
               $5194 = (+($5193|0));
               $5195 = $5194 / 3.0;
               HEAPF32[$4907>>2] = $5195;
               $5196 = $5181 * $5188;
               $5197 = $5196 + 0.0;
               HEAPF32[$12>>2] = $5197;
               $5198 = $5181 * $5192;
               $5199 = $5198 + 0.0;
               HEAPF32[$4916>>2] = $5199;
               $5200 = $5181 * $5195;
               $5201 = $5200 + 0.0;
               HEAPF32[$4917>>2] = $5201;
               $$2373419$i = (($$0396495$i) + 1)|0;
               $5202 = ($$2373419$i|0)<($$0394496$i|0);
               $5203 = (($5183) + ($$0$i806)|0);
               if ($5202) {
                $$2373420$us$i = $$2373419$i;$5205 = $5203;$5219 = $5197;$5222 = $5199;$5225 = $5201;
                while(1) {
                 $5204 = HEAP8[$5205>>0]|0;
                 $5206 = $5204&255;
                 $5207 = $5206 >>> 5;
                 $5208 = (+($5207|0));
                 $5209 = $5208 / 7.0;
                 HEAPF32[$13>>2] = $5209;
                 $5210 = $5206 >>> 2;
                 $5211 = $5210 & 7;
                 $5212 = (+($5211|0));
                 $5213 = $5212 / 7.0;
                 HEAPF32[$4906>>2] = $5213;
                 $5214 = $5206 & 3;
                 $5215 = (+($5214|0));
                 $5216 = $5215 / 3.0;
                 HEAPF32[$4907>>2] = $5216;
                 $5217 = $4927 * $5209;
                 $5218 = $5219 + $5217;
                 HEAPF32[$12>>2] = $5218;
                 $5220 = $4927 * $5213;
                 $5221 = $5222 + $5220;
                 HEAPF32[$4916>>2] = $5221;
                 $5223 = $4927 * $5216;
                 $5224 = $5225 + $5223;
                 HEAPF32[$4917>>2] = $5224;
                 $$2373$us$i = (($$2373420$us$i) + 1)|0;
                 $5226 = (($5205) + ($$0$i806)|0);
                 $exitcond534$i = ($$2373$us$i|0)==($$0394496$i|0);
                 if ($exitcond534$i) {
                  break;
                 } else {
                  $$2373420$us$i = $$2373$us$i;$5205 = $5226;$5219 = $5218;$5222 = $5221;$5225 = $5224;
                 }
                }
                $5227 = Math_imul($$0394496$i, $$0$i806)|0;
                $scevgep533$i = (($scevgep$i1467) + ($5227)|0);
                $$lcssa$i1473 = $scevgep533$i;$5243 = $5218;$5246 = $5221;$5249 = $5224;
               } else {
                $$lcssa$i1473 = $5203;$5243 = $5197;$5246 = $5199;$5249 = $5201;
               }
               $5228 = $4927 * $$0383499$i;
               $5229 = HEAP8[$$lcssa$i1473>>0]|0;
               $5230 = $5229&255;
               $5231 = $5230 >>> 5;
               $5232 = (+($5231|0));
               $5233 = $5232 / 7.0;
               HEAPF32[$13>>2] = $5233;
               $5234 = $5230 >>> 2;
               $5235 = $5234 & 7;
               $5236 = (+($5235|0));
               $5237 = $5236 / 7.0;
               HEAPF32[$4906>>2] = $5237;
               $5238 = $5230 & 3;
               $5239 = (+($5238|0));
               $5240 = $5239 / 3.0;
               HEAPF32[$4907>>2] = $5240;
               $5241 = $5228 * $5233;
               $5242 = $5243 + $5241;
               HEAPF32[$12>>2] = $5242;
               $5244 = $5228 * $5237;
               $5245 = $5246 + $5244;
               HEAPF32[$4916>>2] = $5245;
               $5247 = $5228 * $5240;
               $5248 = $5249 + $5247;
               HEAPF32[$4917>>2] = $5248;
               $7060 = $5248;$7061 = $5245;$7062 = $5242;
               label = 977;
              }
             } while(0);
             do {
              if ((label|0) == 977) {
               label = 0;
               if (!($4924)) {
                $5298 = $7062;$5300 = $7061;$5302 = $7060;
                break;
               }
               $$3483$i = (($$0396495$i) + 1)|0;
               $5272 = ($$3483$i|0)<($$0394496$i|0);
               if (!($5272)) {
                $5298 = $7062;$5300 = $7061;$5302 = $7060;
                break;
               }
               $5273 = (($141) + ($4930)|0);
               $5274 = (($5273) + ($$0$i806)|0);
               $5275 = (($5274) + ($4925)|0);
               $$0397488$i$us = $5275;$$2489$i$us = $$0370474$i;$7063 = $7060;$7064 = $7061;$7065 = $7062;
               while(1) {
                $$3485$us$i$us = $$3483$i;$$4390484$us$i$us = $$0397488$i$us;$5289 = $7065;$5291 = $7064;$5293 = $7063;
                while(1) {
                 $5276 = HEAP8[$$4390484$us$i$us>>0]|0;
                 $5277 = $5276&255;
                 $5278 = $5277 >>> 5;
                 $5279 = (+($5278|0));
                 $5280 = $5279 / 7.0;
                 HEAPF32[$13>>2] = $5280;
                 $5281 = $5277 >>> 2;
                 $5282 = $5281 & 7;
                 $5283 = (+($5282|0));
                 $5284 = $5283 / 7.0;
                 HEAPF32[$4906>>2] = $5284;
                 $5285 = $5277 & 3;
                 $5286 = (+($5285|0));
                 $5287 = $5286 / 3.0;
                 HEAPF32[$4907>>2] = $5287;
                 $5288 = $5280 + $5289;
                 HEAPF32[$12>>2] = $5288;
                 $5290 = $5284 + $5291;
                 HEAPF32[$4912>>2] = $5290;
                 $5292 = $5287 + $5293;
                 HEAPF32[$4913>>2] = $5292;
                 $5294 = (($$4390484$us$i$us) + ($$0$i806)|0);
                 $$3$us$i1480$us = (($$3485$us$i$us) + 1)|0;
                 $exitcond568$i1481$us = ($$3$us$i1480$us|0)==($$0394496$i|0);
                 if ($exitcond568$i1481$us) {
                  break;
                 } else {
                  $$3485$us$i$us = $$3$us$i1480$us;$$4390484$us$i$us = $5294;$5289 = $5288;$5291 = $5290;$5293 = $5292;
                 }
                }
                $5295 = (($$0397488$i$us) + ($$0778)|0);
                $5296 = (($$2489$i$us) + 1)|0;
                $exitcond569$i$us = ($5296|0)==($$0391507$i|0);
                if ($exitcond569$i$us) {
                 $5298 = $5288;$5300 = $5290;$5302 = $5292;
                 break;
                } else {
                 $$0397488$i$us = $5295;$$2489$i$us = $5296;$7063 = $5292;$7064 = $5290;$7065 = $5288;
                }
               }
              }
             } while(0);
             $5297 = $5298 / $4903;
             $5299 = $5300 / $4903;
             $5301 = $5302 / $4903;
             $5303 = (($$0375503$i) + ($4926))|0;
             $5304 = $5297 * 7.0;
             $5305 = $5304;
             $5306 = $5305 + 0.5;
             $5307 = (~~(($5306))&255);
             $5308 = $5307&255;
             $5309 = $5308 << 5;
             $5310 = (($1241) + ($5303)|0);
             $5311 = $5299 * 7.0;
             $5312 = $5311;
             $5313 = $5312 + 0.5;
             $5314 = (~~(($5313))&255);
             $5315 = $5314&255;
             $5316 = $5315 << 2;
             $5317 = $5316 & 28;
             $5318 = $5317 | $5309;
             $5319 = $5301 * 3.0;
             $5320 = $5319;
             $5321 = $5320 + 0.5;
             $5322 = (~~(($5321))&255);
             $5323 = $5322 & 3;
             $5324 = $5323&255;
             $5325 = $5318 | $5324;
             $5326 = $5325&255;
             HEAP8[$5310>>0] = $5326;
             $5327 = (($$0394496$i) + ($4900))|0;
             $5328 = $4902 + $$0383499$i;
             $5329 = $5328 > 1.0;
             $5330 = $5328 + -1.0;
             $5331 = $5329&1;
             $$1395$i = (($5327) + ($5331))|0;
             $$1384$i1482 = $5329 ? $5330 : $5328;
             $5332 = (($$0375503$i) + 1)|0;
             $exitcond571$i = ($5332|0)==($4|0);
             if ($exitcond571$i) {
              break;
             } else {
              $$0396495$i$phi = $$0394496$i;$$0385498$i$phi = $$0383499$i;$$0375503$i = $5332;$$0383499$i = $$1384$i1482;$$0394496$i = $$1395$i;$$0396495$i = $$0396495$i$phi;$$0385498$i = $$0385498$i$phi;
             }
            }
           }
           $5333 = (($$0391507$i) + ($4896))|0;
           $5334 = $4898 + $$0380509$i;
           $5335 = $5334 > 1.0;
           $5336 = $5334 + -1.0;
           $5337 = $5335&1;
           $$1392$i = (($5333) + ($5337))|0;
           $$1381$i = $5335 ? $5336 : $5334;
           $5338 = (($$0374510$i) + 1)|0;
           $exitcond572$i1483 = ($5338|0)==($5|0);
           if ($exitcond572$i1483) {
            break;
           } else {
            $$0393506$i$phi = $$0391507$i;$$0382508$i$phi = $$0380509$i;$$0374510$i = $5338;$$0380509$i = $$1381$i;$$0391507$i = $$1392$i;$$0393506$i = $$0393506$i$phi;$$0382508$i = $$0382508$i$phi;
           }
          }
         }
        }
       } while(0);
       break;
      }
      switch ($7|0) {
      case 5126:  {
       break;
      }
      default: {
       break L470;
      }
      }
      $4055 = $4 << 1;
      $4056 = ($4055|0)==($2|0);
      $4057 = $5 << 1;
      $4058 = ($4057|0)==($3|0);
      $or$cond$i1354 = $4056 & $4058;
      if ($or$cond$i1354) {
       __ZN3osgL16halveImage_floatEijjPKfPfiiii($$0$i805,$2,$3,$141,$1241,$$0$i806,$$0778,$126,$$785);
      } else {
       $4059 = (+($3|0));
       $4060 = (+($5|0));
       $4061 = $4059 / $4060;
       $4062 = (+($2|0));
       $4063 = (+($4|0));
       $4064 = $4062 / $4063;
       $4065 = (+Math_floor((+$4061)));
       $4066 = (~~(($4065)));
       $4067 = (+($4066|0));
       $4068 = $4061 - $4067;
       $4069 = (+Math_floor((+$4064)));
       $4070 = (~~(($4069)));
       $4071 = (+($4070|0));
       $4072 = $4064 - $4071;
       $4073 = $4064 * $4061;
       $4074 = ($5|0)>(0);
       if ($4074) {
        $4075 = (($3) + -1)|0;
        $4076 = ($4|0)>(0);
        $4077 = ($$785|0)==(0);
        $4078 = (($$0778) + ($126))|0;
        $exitcond840$i13572212 = ($$0$i805|0)==(1);
        $$phi$trans$insert890$i3039 = ((($12)) + 4|0);
        $exitcond840$i13573041 = ($$0$i805|0)==(2);
        $$phi$trans$insert886$i3036 = ((($12)) + 4|0);
        $exitcond828$i14043038 = ($$0$i805|0)==(2);
        $$phi$trans$insert882$i3033 = ((($12)) + 4|0);
        $exitcond818$i14233035 = ($$0$i805|0)==(2);
        $$phi$trans$insert878$i14473030 = ((($12)) + 4|0);
        $exitcond816$i14453032 = ($$0$i805|0)==(2);
        $$0576778$i = 0;$$0582777$i = $4068;$$0584776$i = 0.0;$$0593775$i = $4066;$$0596774$i = 0;
        while(1) {
         $4079 = ($$0593775$i|0)<($3|0);
         $$0593$$i = $4079 ? $$0593775$i : $4075;
         if ($4076) {
          $4080 = ($$0593$$i|0)>($$0596774$i|0);
          $4081 = Math_imul($$0596774$i, $$0778)|0;
          $4082 = 1.0 - $$0584776$i;
          $4083 = Math_imul($$0593$$i, $$0778)|0;
          $$0571741$i = (($$0596774$i) + 1)|0;
          $4084 = ($$0571741$i|0)<($$0593$$i|0);
          $4085 = Math_imul($$0571741$i, $$0778)|0;
          $4086 = Math_imul($$0576778$i, $4)|0;
          $4087 = $$0582777$i - $$0584776$i;
          $uglygep$i1355 = (($141) + ($4081)|0);
          $4088 = (($$0593$$i) + -1)|0;
          $4089 = Math_imul($4088, $$0778)|0;
          $uglygep829$i = (($141) + ($4089)|0);
          $uglygep853$i = (($141) + ($4083)|0);
          $$0577770$i = 0;$$0585769$i = $4072;$$0587768$i = 0.0;$$0597767$i = $4070;$$0599766$i = 0;
          while(1) {
           $4090 = Math_imul($$0599766$i, $126)|0;
           $4091 = ($$0597767$i|0)>($$0599766$i|0);
           $or$cond628$i = $4080 & $4091;
           ;HEAP32[$12>>2]=0|0;HEAP32[$12+4>>2]=0|0;HEAP32[$12+8>>2]=0|0;HEAP32[$12+12>>2]=0|0;
           L1145: do {
            if ($or$cond628$i) {
             $4092 = (($141) + ($4090)|0);
             $4093 = (($4092) + ($4081)|0);
             $4094 = 1.0 - $$0587768$i;
             $4095 = $4082 * $4094;
             L1147: do {
              if ($4077) {
               $4096 = +HEAPF32[$4093>>2];
               $$sink3$us$i13562211 = $4095 * $4096;
               $4097 = $$sink3$us$i13562211 + 0.0;
               HEAPF32[$12>>2] = $4097;
               if ($exitcond840$i13572212) {
                break;
               }
               $4098 = (($4093) + ($$0$i806)|0);
               $4099 = +HEAPF32[$4098>>2];
               $$sink3$us$i13563040 = $4095 * $4099;
               $4100 = $$sink3$us$i13563040 + 0.0;
               HEAPF32[$$phi$trans$insert890$i3039>>2] = $4100;
               if ($exitcond840$i13573041) {
                break;
               } else {
                $4101 = 2;$4103 = $4098;
               }
               while(1) {
                $$phi$trans$insert890$i$phi$trans$insert = (($12) + ($4101<<2)|0);
                $$pre891$i$pre = +HEAPF32[$$phi$trans$insert890$i$phi$trans$insert>>2];
                $4102 = (($4103) + ($$0$i806)|0);
                $$phi$trans$insert890$i = (($12) + ($4101<<2)|0);
                $4104 = +HEAPF32[$4102>>2];
                $$sink3$us$i1356 = $4095 * $4104;
                $4105 = $$pre891$i$pre + $$sink3$us$i1356;
                HEAPF32[$$phi$trans$insert890$i>>2] = $4105;
                $4106 = (($4101) + 1)|0;
                $exitcond840$i1357 = ($4106|0)==($$0$i805|0);
                if ($exitcond840$i1357) {
                 break;
                } else {
                 $4101 = $4106;$4103 = $4102;
                }
               }
              } else {
               $$0578691$i = 0;$$0601690$i = $4093;$4127 = 0.0;
               while(1) {
                $4107 = ((($$0601690$i)) + 3|0);
                $4108 = HEAP8[$4107>>0]|0;
                $4109 = $4108&255;
                $4110 = $4109 << 24;
                $4111 = ((($$0601690$i)) + 2|0);
                $4112 = HEAP8[$4111>>0]|0;
                $4113 = $4112&255;
                $4114 = $4113 << 16;
                $4115 = $4114 | $4110;
                $4116 = ((($$0601690$i)) + 1|0);
                $4117 = HEAP8[$4116>>0]|0;
                $4118 = $4117&255;
                $4119 = $4118 << 8;
                $4120 = $4115 | $4119;
                $4121 = HEAP8[$$0601690$i>>0]|0;
                $4122 = $4121&255;
                $4123 = $4120 | $4122;
                $4124 = (HEAP32[tempDoublePtr>>2]=$4123,+HEAPF32[tempDoublePtr>>2]);
                $$sink3$i1360 = $4095 * $4124;
                $4125 = (($12) + ($$0578691$i<<2)|0);
                $4126 = $4127 + $$sink3$i1360;
                HEAPF32[$4125>>2] = $4126;
                $4128 = (($$0578691$i) + 1)|0;
                $exitcond839$i1361 = ($4128|0)==($$0$i805|0);
                if ($exitcond839$i1361) {
                 break L1147;
                }
                $4129 = (($$0601690$i) + ($$0$i806)|0);
                $$phi$trans$insert888$i = (($12) + ($4128<<2)|0);
                $$pre889$i = +HEAPF32[$$phi$trans$insert888$i>>2];
                $$0578691$i = $4128;$$0601690$i = $4129;$4127 = $$pre889$i;
               }
              }
             } while(0);
             $4130 = (($$0599766$i) + 1)|0;
             $4131 = ($4130|0)<($$0597767$i|0);
             $4132 = (($4093) + ($126)|0);
             if ($4131) {
              $4133 = Math_imul($$0597767$i, $126)|0;
              if ($4077) {
               $$0573699$us$i$us = $4130;$4142 = $4132;
               while(1) {
                $$1579696$us$us$i$us = 0;$$1602695$us$us$i$us = $4142;
                while(1) {
                 $4134 = +HEAPF32[$$1602695$us$us$i$us>>2];
                 $$sink7$us$us$i1371$us = $4082 * $4134;
                 $4135 = (($12) + ($$1579696$us$us$i$us<<2)|0);
                 $4136 = +HEAPF32[$4135>>2];
                 $4137 = $4136 + $$sink7$us$us$i1371$us;
                 HEAPF32[$4135>>2] = $4137;
                 $4138 = (($$1579696$us$us$i$us) + 1)|0;
                 $4139 = (($$1602695$us$us$i$us) + ($$0$i806)|0);
                 $exitcond845$i1372$us = ($4138|0)==($$0$i805|0);
                 if ($exitcond845$i1372$us) {
                  break;
                 } else {
                  $$1579696$us$us$i$us = $4138;$$1602695$us$us$i$us = $4139;
                 }
                }
                $4140 = (($$0573699$us$i$us) + 1)|0;
                $4141 = (($4142) + ($126)|0);
                $exitcond848$i1369$us = ($4140|0)==($$0597767$i|0);
                if ($exitcond848$i1369$us) {
                 break;
                } else {
                 $$0573699$us$i$us = $4140;$4142 = $4141;
                }
               }
              } else {
               $$0573699$us$i = $4130;$4168 = $4132;
               while(1) {
                $$1579696$us702$i = 0;$$1602695$us703$i = $4168;
                while(1) {
                 $4143 = ((($$1602695$us703$i)) + 3|0);
                 $4144 = HEAP8[$4143>>0]|0;
                 $4145 = $4144&255;
                 $4146 = $4145 << 24;
                 $4147 = ((($$1602695$us703$i)) + 2|0);
                 $4148 = HEAP8[$4147>>0]|0;
                 $4149 = $4148&255;
                 $4150 = $4149 << 16;
                 $4151 = $4150 | $4146;
                 $4152 = ((($$1602695$us703$i)) + 1|0);
                 $4153 = HEAP8[$4152>>0]|0;
                 $4154 = $4153&255;
                 $4155 = $4154 << 8;
                 $4156 = $4151 | $4155;
                 $4157 = HEAP8[$$1602695$us703$i>>0]|0;
                 $4158 = $4157&255;
                 $4159 = $4156 | $4158;
                 $4160 = (HEAP32[tempDoublePtr>>2]=$4159,+HEAPF32[tempDoublePtr>>2]);
                 $$sink7$us705$i = $4082 * $4160;
                 $4161 = (($12) + ($$1579696$us702$i<<2)|0);
                 $4162 = +HEAPF32[$4161>>2];
                 $4163 = $4162 + $$sink7$us705$i;
                 HEAPF32[$4161>>2] = $4163;
                 $4164 = (($$1579696$us702$i) + 1)|0;
                 $4165 = (($$1602695$us703$i) + ($$0$i806)|0);
                 $exitcond844$i1367 = ($4164|0)==($$0$i805|0);
                 if ($exitcond844$i1367) {
                  break;
                 } else {
                  $$1579696$us702$i = $4164;$$1602695$us703$i = $4165;
                 }
                }
                $4166 = (($$0573699$us$i) + 1)|0;
                $4167 = (($4168) + ($126)|0);
                $exitcond848$i1369 = ($4166|0)==($$0597767$i|0);
                if ($exitcond848$i1369) {
                 break;
                } else {
                 $$0573699$us$i = $4166;$4168 = $4167;
                }
               }
              }
              $scevgep847$i = (($uglygep$i1355) + ($4133)|0);
              $$lcssa644$i = $scevgep847$i;
             } else {
              $$lcssa644$i = $4132;
             }
             $4169 = $4082 * $$0585769$i;
             if ($4077) {
              $$2580709$us$i = 0;$$2603708$us$i = $$lcssa644$i;
              while(1) {
               $4170 = +HEAPF32[$$2603708$us$i>>2];
               $$sink12$us$i1376 = $4169 * $4170;
               $4171 = (($12) + ($$2580709$us$i<<2)|0);
               $4172 = +HEAPF32[$4171>>2];
               $4173 = $4172 + $$sink12$us$i1376;
               HEAPF32[$4171>>2] = $4173;
               $4174 = (($$2580709$us$i) + 1)|0;
               $4175 = (($$2603708$us$i) + ($$0$i806)|0);
               $exitcond850$i1377 = ($4174|0)==($$0$i805|0);
               if ($exitcond850$i1377) {
                break;
               } else {
                $$2580709$us$i = $4174;$$2603708$us$i = $4175;
               }
              }
             } else {
              $$2580709$i = 0;$$2603708$i = $$lcssa644$i;
              while(1) {
               $4176 = ((($$2603708$i)) + 3|0);
               $4177 = HEAP8[$4176>>0]|0;
               $4178 = $4177&255;
               $4179 = $4178 << 24;
               $4180 = ((($$2603708$i)) + 2|0);
               $4181 = HEAP8[$4180>>0]|0;
               $4182 = $4181&255;
               $4183 = $4182 << 16;
               $4184 = $4183 | $4179;
               $4185 = ((($$2603708$i)) + 1|0);
               $4186 = HEAP8[$4185>>0]|0;
               $4187 = $4186&255;
               $4188 = $4187 << 8;
               $4189 = $4184 | $4188;
               $4190 = HEAP8[$$2603708$i>>0]|0;
               $4191 = $4190&255;
               $4192 = $4189 | $4191;
               $4193 = (HEAP32[tempDoublePtr>>2]=$4192,+HEAPF32[tempDoublePtr>>2]);
               $$sink12$i1378 = $4169 * $4193;
               $4194 = (($12) + ($$2580709$i<<2)|0);
               $4195 = +HEAPF32[$4194>>2];
               $4196 = $4195 + $$sink12$i1378;
               HEAPF32[$4194>>2] = $4196;
               $4197 = (($$2580709$i) + 1)|0;
               $4198 = (($$2603708$i) + ($$0$i806)|0);
               $exitcond849$i = ($4197|0)==($$0$i805|0);
               if ($exitcond849$i) {
                break;
               } else {
                $$2580709$i = $4197;$$2603708$i = $4198;
               }
              }
             }
             $4199 = $$0582777$i * $4094;
             $4200 = (($4092) + ($4083)|0);
             if ($4077) {
              $$3581714$us$i = 0;$$3604713$us$i = $4200;
              while(1) {
               $4201 = +HEAPF32[$$3604713$us$i>>2];
               $$sink17$us$i1379 = $4199 * $4201;
               $4202 = (($12) + ($$3581714$us$i<<2)|0);
               $4203 = +HEAPF32[$4202>>2];
               $4204 = $4203 + $$sink17$us$i1379;
               HEAPF32[$4202>>2] = $4204;
               $4205 = (($$3581714$us$i) + 1)|0;
               $4206 = (($$3604713$us$i) + ($$0$i806)|0);
               $exitcond852$i1380 = ($4205|0)==($$0$i805|0);
               if ($exitcond852$i1380) {
                break;
               } else {
                $$3581714$us$i = $4205;$$3604713$us$i = $4206;
               }
              }
             } else {
              $$3581714$i = 0;$$3604713$i = $4200;
              while(1) {
               $4244 = ((($$3604713$i)) + 3|0);
               $4245 = HEAP8[$4244>>0]|0;
               $4246 = $4245&255;
               $4247 = $4246 << 24;
               $4248 = ((($$3604713$i)) + 2|0);
               $4249 = HEAP8[$4248>>0]|0;
               $4250 = $4249&255;
               $4251 = $4250 << 16;
               $4252 = $4251 | $4247;
               $4253 = ((($$3604713$i)) + 1|0);
               $4254 = HEAP8[$4253>>0]|0;
               $4255 = $4254&255;
               $4256 = $4255 << 8;
               $4257 = $4252 | $4256;
               $4258 = HEAP8[$$3604713$i>>0]|0;
               $4259 = $4258&255;
               $4260 = $4257 | $4259;
               $4261 = (HEAP32[tempDoublePtr>>2]=$4260,+HEAPF32[tempDoublePtr>>2]);
               $$sink17$i1387 = $4199 * $4261;
               $4262 = (($12) + ($$3581714$i<<2)|0);
               $4263 = +HEAPF32[$4262>>2];
               $4264 = $4263 + $$sink17$i1387;
               HEAPF32[$4262>>2] = $4264;
               $4265 = (($$3581714$i) + 1)|0;
               $4266 = (($$3604713$i) + ($$0$i806)|0);
               $exitcond851$i1388 = ($4265|0)==($$0$i805|0);
               if ($exitcond851$i1388) {
                break;
               } else {
                $$3581714$i = $4265;$$3604713$i = $4266;
               }
              }
             }
             $4207 = (($4200) + ($126)|0);
             if ($4131) {
              $4208 = Math_imul($$0597767$i, $126)|0;
              if ($4077) {
               $$1574721$us$i$us = $4130;$4217 = $4207;
               while(1) {
                $$4605717$us$us$i$us = $4217;$$4718$us$us$i$us = 0;
                while(1) {
                 $4209 = +HEAPF32[$$4605717$us$us$i$us>>2];
                 $$sink22$us$us$i1385$us = $$0582777$i * $4209;
                 $4210 = (($12) + ($$4718$us$us$i$us<<2)|0);
                 $4211 = +HEAPF32[$4210>>2];
                 $4212 = $4211 + $$sink22$us$us$i1385$us;
                 HEAPF32[$4210>>2] = $4212;
                 $4213 = (($$4718$us$us$i$us) + 1)|0;
                 $4214 = (($$4605717$us$us$i$us) + ($$0$i806)|0);
                 $exitcond857$i1386$us = ($4213|0)==($$0$i805|0);
                 if ($exitcond857$i1386$us) {
                  break;
                 } else {
                  $$4605717$us$us$i$us = $4214;$$4718$us$us$i$us = $4213;
                 }
                }
                $4215 = (($$1574721$us$i$us) + 1)|0;
                $4216 = (($4217) + ($126)|0);
                $exitcond860$i1384$us = ($4215|0)==($$0597767$i|0);
                if ($exitcond860$i1384$us) {
                 break;
                } else {
                 $$1574721$us$i$us = $4215;$4217 = $4216;
                }
               }
              } else {
               $$1574721$us$i = $4130;$4243 = $4207;
               while(1) {
                $$4605717$us725$i = $4243;$$4718$us724$i = 0;
                while(1) {
                 $4218 = ((($$4605717$us725$i)) + 3|0);
                 $4219 = HEAP8[$4218>>0]|0;
                 $4220 = $4219&255;
                 $4221 = $4220 << 24;
                 $4222 = ((($$4605717$us725$i)) + 2|0);
                 $4223 = HEAP8[$4222>>0]|0;
                 $4224 = $4223&255;
                 $4225 = $4224 << 16;
                 $4226 = $4225 | $4221;
                 $4227 = ((($$4605717$us725$i)) + 1|0);
                 $4228 = HEAP8[$4227>>0]|0;
                 $4229 = $4228&255;
                 $4230 = $4229 << 8;
                 $4231 = $4226 | $4230;
                 $4232 = HEAP8[$$4605717$us725$i>>0]|0;
                 $4233 = $4232&255;
                 $4234 = $4231 | $4233;
                 $4235 = (HEAP32[tempDoublePtr>>2]=$4234,+HEAPF32[tempDoublePtr>>2]);
                 $$sink22$us727$i = $$0582777$i * $4235;
                 $4236 = (($12) + ($$4718$us724$i<<2)|0);
                 $4237 = +HEAPF32[$4236>>2];
                 $4238 = $4237 + $$sink22$us727$i;
                 HEAPF32[$4236>>2] = $4238;
                 $4239 = (($$4718$us724$i) + 1)|0;
                 $4240 = (($$4605717$us725$i) + ($$0$i806)|0);
                 $exitcond856$i1383 = ($4239|0)==($$0$i805|0);
                 if ($exitcond856$i1383) {
                  break;
                 } else {
                  $$4605717$us725$i = $4240;$$4718$us724$i = $4239;
                 }
                }
                $4241 = (($$1574721$us$i) + 1)|0;
                $4242 = (($4243) + ($126)|0);
                $exitcond860$i1384 = ($4241|0)==($$0597767$i|0);
                if ($exitcond860$i1384) {
                 break;
                } else {
                 $$1574721$us$i = $4241;$4243 = $4242;
                }
               }
              }
              $scevgep859$i = (($uglygep853$i) + ($4208)|0);
              $$lcssa645$i = $scevgep859$i;
             } else {
              $$lcssa645$i = $4207;
             }
             $4267 = $$0582777$i * $$0585769$i;
             if ($4077) {
              $$5606730$us$i = $$lcssa645$i;$$5731$us$i = 0;
              while(1) {
               $4268 = +HEAPF32[$$5606730$us$i>>2];
               $$sink27$us$i1390 = $4267 * $4268;
               $4269 = (($12) + ($$5731$us$i<<2)|0);
               $4270 = +HEAPF32[$4269>>2];
               $4271 = $4270 + $$sink27$us$i1390;
               HEAPF32[$4269>>2] = $4271;
               $4272 = (($$5731$us$i) + 1)|0;
               $4273 = (($$5606730$us$i) + ($$0$i806)|0);
               $exitcond862$i1391 = ($4272|0)==($$0$i805|0);
               if ($exitcond862$i1391) {
                break;
               } else {
                $$5606730$us$i = $4273;$$5731$us$i = $4272;
               }
              }
             } else {
              $$5606730$i = $$lcssa645$i;$$5731$i = 0;
              while(1) {
               $4287 = ((($$5606730$i)) + 3|0);
               $4288 = HEAP8[$4287>>0]|0;
               $4289 = $4288&255;
               $4290 = $4289 << 24;
               $4291 = ((($$5606730$i)) + 2|0);
               $4292 = HEAP8[$4291>>0]|0;
               $4293 = $4292&255;
               $4294 = $4293 << 16;
               $4295 = $4294 | $4290;
               $4296 = ((($$5606730$i)) + 1|0);
               $4297 = HEAP8[$4296>>0]|0;
               $4298 = $4297&255;
               $4299 = $4298 << 8;
               $4300 = $4295 | $4299;
               $4301 = HEAP8[$$5606730$i>>0]|0;
               $4302 = $4301&255;
               $4303 = $4300 | $4302;
               $4304 = (HEAP32[tempDoublePtr>>2]=$4303,+HEAPF32[tempDoublePtr>>2]);
               $$sink27$i1393 = $4267 * $4304;
               $4305 = (($12) + ($$5731$i<<2)|0);
               $4306 = +HEAPF32[$4305>>2];
               $4307 = $4306 + $$sink27$i1393;
               HEAPF32[$4305>>2] = $4307;
               $4308 = (($$5731$i) + 1)|0;
               $4309 = (($$5606730$i) + ($$0$i806)|0);
               $exitcond861$i1394 = ($4308|0)==($$0$i805|0);
               if ($exitcond861$i1394) {
                break;
               } else {
                $$5606730$i = $4309;$$5731$i = $4308;
               }
              }
             }
             if (!($4084)) {
              break;
             }
             if ($4077) {
              $$0569742$i$us = $4093;$$0571744$i$us = $$0571741$i;$$0743$i$us = $$lcssa644$i;
              while(1) {
               $4274 = (($$0569742$i$us) + ($$0778)|0);
               $4275 = (($$0743$i$us) + ($$0778)|0);
               $$1570735$us$i$us = $4274;$$1736$us$i$us = $4275;$$6734$us$i$us = 0;
               while(1) {
                $4276 = +HEAPF32[$$1570735$us$i$us>>2];
                $4277 = $4094 * $4276;
                $4278 = +HEAPF32[$$1736$us$i$us>>2];
                $4279 = $$0585769$i * $4278;
                $4280 = $4277 + $4279;
                $4281 = (($12) + ($$6734$us$i$us<<2)|0);
                $4282 = +HEAPF32[$4281>>2];
                $4283 = $4282 + $4280;
                HEAPF32[$4281>>2] = $4283;
                $4284 = (($$6734$us$i$us) + 1)|0;
                $4285 = (($$1570735$us$i$us) + ($$0$i806)|0);
                $4286 = (($$1736$us$i$us) + ($$0$i806)|0);
                $exitcond868$i1401$us = ($4284|0)==($$0$i805|0);
                if ($exitcond868$i1401$us) {
                 break;
                } else {
                 $$1570735$us$i$us = $4285;$$1736$us$i$us = $4286;$$6734$us$i$us = $4284;
                }
               }
               $scevgep866$i1400$us = (($$0569742$i$us) + ($4078)|0);
               $scevgep864$i$us = (($$0743$i$us) + ($4078)|0);
               $$0571$i$us = (($$0571744$i$us) + 1)|0;
               $exitcond869$i1398$us = ($$0571$i$us|0)==($$0593$$i|0);
               if ($exitcond869$i1398$us) {
                label = 923;
                break;
               } else {
                $$0569742$i$us = $scevgep866$i1400$us;$$0571744$i$us = $$0571$i$us;$$0743$i$us = $scevgep864$i$us;
               }
              }
             } else {
              $$0569742$i = $4093;$$0571744$i = $$0571741$i;$$0743$i = $$lcssa644$i;
              while(1) {
               $4310 = (($$0569742$i) + ($$0778)|0);
               $4311 = (($$0743$i) + ($$0778)|0);
               $$1570735$i = $4310;$$1736$i = $4311;$$6734$i = 0;
               while(1) {
                $4312 = ((($$1570735$i)) + 3|0);
                $4313 = HEAP8[$4312>>0]|0;
                $4314 = $4313&255;
                $4315 = $4314 << 24;
                $4316 = ((($$1570735$i)) + 2|0);
                $4317 = HEAP8[$4316>>0]|0;
                $4318 = $4317&255;
                $4319 = $4318 << 16;
                $4320 = $4319 | $4315;
                $4321 = ((($$1570735$i)) + 1|0);
                $4322 = HEAP8[$4321>>0]|0;
                $4323 = $4322&255;
                $4324 = $4323 << 8;
                $4325 = $4320 | $4324;
                $4326 = HEAP8[$$1570735$i>>0]|0;
                $4327 = $4326&255;
                $4328 = $4325 | $4327;
                $4329 = (HEAP32[tempDoublePtr>>2]=$4328,+HEAPF32[tempDoublePtr>>2]);
                $4330 = $4094 * $4329;
                $4331 = (($12) + ($$6734$i<<2)|0);
                $4332 = +HEAPF32[$4331>>2];
                $4333 = $4332 + $4330;
                HEAPF32[$4331>>2] = $4333;
                $4334 = ((($$1736$i)) + 3|0);
                $4335 = HEAP8[$4334>>0]|0;
                $4336 = $4335&255;
                $4337 = $4336 << 24;
                $4338 = ((($$1736$i)) + 2|0);
                $4339 = HEAP8[$4338>>0]|0;
                $4340 = $4339&255;
                $4341 = $4340 << 16;
                $4342 = $4341 | $4337;
                $4343 = ((($$1736$i)) + 1|0);
                $4344 = HEAP8[$4343>>0]|0;
                $4345 = $4344&255;
                $4346 = $4345 << 8;
                $4347 = $4342 | $4346;
                $4348 = HEAP8[$$1736$i>>0]|0;
                $4349 = $4348&255;
                $4350 = $4347 | $4349;
                $4351 = (HEAP32[tempDoublePtr>>2]=$4350,+HEAPF32[tempDoublePtr>>2]);
                $4352 = $$0585769$i * $4351;
                $4353 = $4333 + $4352;
                HEAPF32[$4331>>2] = $4353;
                $4354 = (($$6734$i) + 1)|0;
                $4355 = (($$1570735$i) + ($$0$i806)|0);
                $4356 = (($$1736$i) + ($$0$i806)|0);
                $exitcond865$i1402 = ($4354|0)==($$0$i805|0);
                if ($exitcond865$i1402) {
                 break;
                } else {
                 $$1570735$i = $4355;$$1736$i = $4356;$$6734$i = $4354;
                }
               }
               $scevgep866$i1400 = (($$0569742$i) + ($4078)|0);
               $scevgep864$i = (($$0743$i) + ($4078)|0);
               $$0571$i = (($$0571744$i) + 1)|0;
               $exitcond869$i1398 = ($$0571$i|0)==($$0593$$i|0);
               if ($exitcond869$i1398) {
                label = 923;
                break;
               } else {
                $$0569742$i = $scevgep866$i1400;$$0571744$i = $$0571$i;$$0743$i = $scevgep864$i;
               }
              }
             }
            } else {
             if ($4080) {
              $4357 = $$0585769$i - $$0587768$i;
              $4358 = $4082 * $4357;
              $4359 = (($141) + ($4090)|0);
              $4360 = (($4359) + ($4081)|0);
              L1219: do {
               if ($4077) {
                $4361 = +HEAPF32[$4360>>2];
                $$sink37$us$i14032208 = $4358 * $4361;
                $4362 = $$sink37$us$i14032208 + 0.0;
                HEAPF32[$12>>2] = $4362;
                if ($exitcond840$i13572212) {
                 break;
                }
                $4363 = (($4360) + ($$0$i806)|0);
                $4364 = +HEAPF32[$4363>>2];
                $$sink37$us$i14033037 = $4358 * $4364;
                $4365 = $$sink37$us$i14033037 + 0.0;
                HEAPF32[$$phi$trans$insert886$i3036>>2] = $4365;
                if ($exitcond828$i14043038) {
                 break;
                } else {
                 $4366 = 2;$4368 = $4363;
                }
                while(1) {
                 $$phi$trans$insert886$i$phi$trans$insert = (($12) + ($4366<<2)|0);
                 $$pre887$i$pre = +HEAPF32[$$phi$trans$insert886$i$phi$trans$insert>>2];
                 $4367 = (($4368) + ($$0$i806)|0);
                 $$phi$trans$insert886$i = (($12) + ($4366<<2)|0);
                 $4369 = +HEAPF32[$4367>>2];
                 $$sink37$us$i1403 = $4358 * $4369;
                 $4370 = $$pre887$i$pre + $$sink37$us$i1403;
                 HEAPF32[$$phi$trans$insert886$i>>2] = $4370;
                 $4371 = (($4366) + 1)|0;
                 $exitcond828$i1404 = ($4371|0)==($$0$i805|0);
                 if ($exitcond828$i1404) {
                  break;
                 } else {
                  $4366 = $4371;$4368 = $4367;
                 }
                }
               } else {
                $$6607666$i = $4360;$$7667$i = 0;$4423 = 0.0;
                while(1) {
                 $4403 = ((($$6607666$i)) + 3|0);
                 $4404 = HEAP8[$4403>>0]|0;
                 $4405 = $4404&255;
                 $4406 = $4405 << 24;
                 $4407 = ((($$6607666$i)) + 2|0);
                 $4408 = HEAP8[$4407>>0]|0;
                 $4409 = $4408&255;
                 $4410 = $4409 << 16;
                 $4411 = $4410 | $4406;
                 $4412 = ((($$6607666$i)) + 1|0);
                 $4413 = HEAP8[$4412>>0]|0;
                 $4414 = $4413&255;
                 $4415 = $4414 << 8;
                 $4416 = $4411 | $4415;
                 $4417 = HEAP8[$$6607666$i>>0]|0;
                 $4418 = $4417&255;
                 $4419 = $4416 | $4418;
                 $4420 = (HEAP32[tempDoublePtr>>2]=$4419,+HEAPF32[tempDoublePtr>>2]);
                 $$sink37$i1412 = $4358 * $4420;
                 $4421 = (($12) + ($$7667$i<<2)|0);
                 $4422 = $4423 + $$sink37$i1412;
                 HEAPF32[$4421>>2] = $4422;
                 $4424 = (($$7667$i) + 1)|0;
                 $exitcond827$i1413 = ($4424|0)==($$0$i805|0);
                 if ($exitcond827$i1413) {
                  break L1219;
                 }
                 $4425 = (($$6607666$i) + ($$0$i806)|0);
                 $$phi$trans$insert884$i = (($12) + ($4424<<2)|0);
                 $$pre885$i = +HEAPF32[$$phi$trans$insert884$i>>2];
                 $$6607666$i = $4425;$$7667$i = $4424;$4423 = $$pre885$i;
                }
               }
              } while(0);
              if ($4084) {
               if ($4077) {
                $$1572676$us$i$us = $$0571741$i;$$2590675$us$i$us = $4360;
                while(1) {
                 $4372 = (($$2590675$us$i$us) + ($$0778)|0);
                 $$7608670$us$us$i$us = $4372;$$8671$us$us$i$us = 0;
                 while(1) {
                  $4373 = +HEAPF32[$$7608670$us$us$i$us>>2];
                  $$sink42$us$us$i1410$us = $4357 * $4373;
                  $4374 = (($12) + ($$8671$us$us$i$us<<2)|0);
                  $4375 = +HEAPF32[$4374>>2];
                  $4376 = $4375 + $$sink42$us$us$i1410$us;
                  HEAPF32[$4374>>2] = $4376;
                  $4377 = (($$8671$us$us$i$us) + 1)|0;
                  $4378 = (($$7608670$us$us$i$us) + ($$0$i806)|0);
                  $exitcond833$i1411$us = ($4377|0)==($$0$i805|0);
                  if ($exitcond833$i1411$us) {
                   break;
                  } else {
                   $$7608670$us$us$i$us = $4378;$$8671$us$us$i$us = $4377;
                  }
                 }
                 $$1572$us$i$us = (($$1572676$us$i$us) + 1)|0;
                 $exitcond836$i1408$us = ($$1572$us$i$us|0)==($$0593$$i|0);
                 if ($exitcond836$i1408$us) {
                  break;
                 } else {
                  $$1572676$us$i$us = $$1572$us$i$us;$$2590675$us$i$us = $4372;
                 }
                }
               } else {
                $$1572676$us$i = $$0571741$i;$$2590675$us$i = $4360;
                while(1) {
                 $4379 = (($$2590675$us$i) + ($$0778)|0);
                 $$7608670$us681$i = $4379;$$8671$us680$i = 0;
                 while(1) {
                  $4380 = ((($$7608670$us681$i)) + 3|0);
                  $4381 = HEAP8[$4380>>0]|0;
                  $4382 = $4381&255;
                  $4383 = $4382 << 24;
                  $4384 = ((($$7608670$us681$i)) + 2|0);
                  $4385 = HEAP8[$4384>>0]|0;
                  $4386 = $4385&255;
                  $4387 = $4386 << 16;
                  $4388 = $4387 | $4383;
                  $4389 = ((($$7608670$us681$i)) + 1|0);
                  $4390 = HEAP8[$4389>>0]|0;
                  $4391 = $4390&255;
                  $4392 = $4391 << 8;
                  $4393 = $4388 | $4392;
                  $4394 = HEAP8[$$7608670$us681$i>>0]|0;
                  $4395 = $4394&255;
                  $4396 = $4393 | $4395;
                  $4397 = (HEAP32[tempDoublePtr>>2]=$4396,+HEAPF32[tempDoublePtr>>2]);
                  $$sink42$us683$i1406 = $4357 * $4397;
                  $4398 = (($12) + ($$8671$us680$i<<2)|0);
                  $4399 = +HEAPF32[$4398>>2];
                  $4400 = $4399 + $$sink42$us683$i1406;
                  HEAPF32[$4398>>2] = $4400;
                  $4401 = (($$8671$us680$i) + 1)|0;
                  $4402 = (($$7608670$us681$i) + ($$0$i806)|0);
                  $exitcond832$i1407 = ($4401|0)==($$0$i805|0);
                  if ($exitcond832$i1407) {
                   break;
                  } else {
                   $$7608670$us681$i = $4402;$$8671$us680$i = $4401;
                  }
                 }
                 $$1572$us$i = (($$1572676$us$i) + 1)|0;
                 $exitcond836$i1408 = ($$1572$us$i|0)==($$0593$$i|0);
                 if ($exitcond836$i1408) {
                  break;
                 } else {
                  $$1572676$us$i = $$1572$us$i;$$2590675$us$i = $4379;
                 }
                }
               }
               $scevgep835$i = (($uglygep829$i) + ($4090)|0);
               $$2590$lcssa$i = $scevgep835$i;
              } else {
               $$2590$lcssa$i = $4360;
              }
              $4426 = $$0582777$i * $4357;
              $4427 = (($$2590$lcssa$i) + ($$0778)|0);
              if ($4077) {
               $$8609686$us$i = $4427;$$9687$us$i1415 = 0;
               while(1) {
                $4428 = +HEAPF32[$$8609686$us$i>>2];
                $$sink47$us$i1416 = $4426 * $4428;
                $4429 = (($12) + ($$9687$us$i1415<<2)|0);
                $4430 = +HEAPF32[$4429>>2];
                $4431 = $4430 + $$sink47$us$i1416;
                HEAPF32[$4429>>2] = $4431;
                $4432 = (($$9687$us$i1415) + 1)|0;
                $4433 = (($$8609686$us$i) + ($$0$i806)|0);
                $exitcond838$i1417 = ($4432|0)==($$0$i805|0);
                if ($exitcond838$i1417) {
                 label = 923;
                 break L1145;
                } else {
                 $$8609686$us$i = $4433;$$9687$us$i1415 = $4432;
                }
               }
              } else {
               $$8609686$i = $4427;$$9687$i1419 = 0;
               while(1) {
                $4434 = ((($$8609686$i)) + 3|0);
                $4435 = HEAP8[$4434>>0]|0;
                $4436 = $4435&255;
                $4437 = $4436 << 24;
                $4438 = ((($$8609686$i)) + 2|0);
                $4439 = HEAP8[$4438>>0]|0;
                $4440 = $4439&255;
                $4441 = $4440 << 16;
                $4442 = $4441 | $4437;
                $4443 = ((($$8609686$i)) + 1|0);
                $4444 = HEAP8[$4443>>0]|0;
                $4445 = $4444&255;
                $4446 = $4445 << 8;
                $4447 = $4442 | $4446;
                $4448 = HEAP8[$$8609686$i>>0]|0;
                $4449 = $4448&255;
                $4450 = $4447 | $4449;
                $4451 = (HEAP32[tempDoublePtr>>2]=$4450,+HEAPF32[tempDoublePtr>>2]);
                $$sink47$i1420 = $4426 * $4451;
                $4452 = (($12) + ($$9687$i1419<<2)|0);
                $4453 = +HEAPF32[$4452>>2];
                $4454 = $4453 + $$sink47$i1420;
                HEAPF32[$4452>>2] = $4454;
                $4455 = (($$9687$i1419) + 1)|0;
                $4456 = (($$8609686$i) + ($$0$i806)|0);
                $exitcond837$i = ($4455|0)==($$0$i805|0);
                if ($exitcond837$i) {
                 label = 923;
                 break L1145;
                } else {
                 $$8609686$i = $4456;$$9687$i1419 = $4455;
                }
               }
              }
             }
             if (!($4091)) {
              $4561 = $$0585769$i - $$0587768$i;
              $4562 = $4087 * $4561;
              $4563 = (($141) + ($4090)|0);
              $4564 = (($4563) + ($4081)|0);
              if (!($4077)) {
               $$12613646$i = $4564;$$13647$i = 0;$4596 = 0.0;
               while(1) {
                $4576 = ((($$12613646$i)) + 3|0);
                $4577 = HEAP8[$4576>>0]|0;
                $4578 = $4577&255;
                $4579 = $4578 << 24;
                $4580 = ((($$12613646$i)) + 2|0);
                $4581 = HEAP8[$4580>>0]|0;
                $4582 = $4581&255;
                $4583 = $4582 << 16;
                $4584 = $4583 | $4579;
                $4585 = ((($$12613646$i)) + 1|0);
                $4586 = HEAP8[$4585>>0]|0;
                $4587 = $4586&255;
                $4588 = $4587 << 8;
                $4589 = $4584 | $4588;
                $4590 = HEAP8[$$12613646$i>>0]|0;
                $4591 = $4590&255;
                $4592 = $4589 | $4591;
                $4593 = (HEAP32[tempDoublePtr>>2]=$4592,+HEAPF32[tempDoublePtr>>2]);
                $$sink67$i1450 = $4562 * $4593;
                $4594 = (($12) + ($$13647$i<<2)|0);
                $4595 = $4596 + $$sink67$i1450;
                HEAPF32[$4594>>2] = $4595;
                $4597 = (($$13647$i) + 1)|0;
                $exitcond$i1451 = ($4597|0)==($$0$i805|0);
                if ($exitcond$i1451) {
                 label = 923;
                 break L1145;
                }
                $4598 = (($$12613646$i) + ($$0$i806)|0);
                $$phi$trans$insert$i1453 = (($12) + ($4597<<2)|0);
                $$pre$i1454 = +HEAPF32[$$phi$trans$insert$i1453>>2];
                $$12613646$i = $4598;$$13647$i = $4597;$4596 = $$pre$i1454;
               }
              }
              $4565 = +HEAPF32[$4564>>2];
              $$sink67$us$i14442202 = $4562 * $4565;
              $4566 = $$sink67$us$i14442202 + 0.0;
              HEAPF32[$12>>2] = $4566;
              if ($exitcond840$i13572212) {
               label = 923;
               break;
              }
              $4567 = (($4564) + ($$0$i806)|0);
              $4568 = +HEAPF32[$4567>>2];
              $$sink67$us$i14443031 = $4562 * $4568;
              $4569 = $$sink67$us$i14443031 + 0.0;
              HEAPF32[$$phi$trans$insert878$i14473030>>2] = $4569;
              if ($exitcond816$i14453032) {
               label = 923;
               break;
              } else {
               $4570 = 2;$4572 = $4567;
              }
              while(1) {
               $$phi$trans$insert878$i1447$phi$trans$insert = (($12) + ($4570<<2)|0);
               $$pre879$i1448$pre = +HEAPF32[$$phi$trans$insert878$i1447$phi$trans$insert>>2];
               $4571 = (($4572) + ($$0$i806)|0);
               $$phi$trans$insert878$i1447 = (($12) + ($4570<<2)|0);
               $4573 = +HEAPF32[$4571>>2];
               $$sink67$us$i1444 = $4562 * $4573;
               $4574 = $$pre879$i1448$pre + $$sink67$us$i1444;
               HEAPF32[$$phi$trans$insert878$i1447>>2] = $4574;
               $4575 = (($4570) + 1)|0;
               $exitcond816$i1445 = ($4575|0)==($$0$i805|0);
               if ($exitcond816$i1445) {
                label = 923;
                break L1145;
               } else {
                $4570 = $4575;$4572 = $4571;
               }
              }
             }
             $4457 = 1.0 - $$0587768$i;
             $4458 = $4087 * $4457;
             $4459 = (($141) + ($4090)|0);
             $4460 = (($4459) + ($4081)|0);
             L1260: do {
              if ($4077) {
               $4461 = +HEAPF32[$4460>>2];
               $$sink52$us$i14222205 = $4458 * $4461;
               $4462 = $$sink52$us$i14222205 + 0.0;
               HEAPF32[$12>>2] = $4462;
               if ($exitcond840$i13572212) {
                break;
               }
               $4463 = (($4460) + ($$0$i806)|0);
               $4464 = +HEAPF32[$4463>>2];
               $$sink52$us$i14223034 = $4458 * $4464;
               $4465 = $$sink52$us$i14223034 + 0.0;
               HEAPF32[$$phi$trans$insert882$i3033>>2] = $4465;
               if ($exitcond818$i14233035) {
                break;
               } else {
                $4466 = 2;$4468 = $4463;
               }
               while(1) {
                $$phi$trans$insert882$i$phi$trans$insert = (($12) + ($4466<<2)|0);
                $$pre883$i$pre = +HEAPF32[$$phi$trans$insert882$i$phi$trans$insert>>2];
                $4467 = (($4468) + ($$0$i806)|0);
                $$phi$trans$insert882$i = (($12) + ($4466<<2)|0);
                $4469 = +HEAPF32[$4467>>2];
                $$sink52$us$i1422 = $4458 * $4469;
                $4470 = $$pre883$i$pre + $$sink52$us$i1422;
                HEAPF32[$$phi$trans$insert882$i>>2] = $4470;
                $4471 = (($4466) + 1)|0;
                $exitcond818$i1423 = ($4471|0)==($$0$i805|0);
                if ($exitcond818$i1423) {
                 break;
                } else {
                 $4466 = $4471;$4468 = $4467;
                }
               }
              } else {
               $$10649$i = 0;$$9610648$i = $4460;$4528 = 0.0;
               while(1) {
                $4508 = ((($$9610648$i)) + 3|0);
                $4509 = HEAP8[$4508>>0]|0;
                $4510 = $4509&255;
                $4511 = $4510 << 24;
                $4512 = ((($$9610648$i)) + 2|0);
                $4513 = HEAP8[$4512>>0]|0;
                $4514 = $4513&255;
                $4515 = $4514 << 16;
                $4516 = $4515 | $4511;
                $4517 = ((($$9610648$i)) + 1|0);
                $4518 = HEAP8[$4517>>0]|0;
                $4519 = $4518&255;
                $4520 = $4519 << 8;
                $4521 = $4516 | $4520;
                $4522 = HEAP8[$$9610648$i>>0]|0;
                $4523 = $4522&255;
                $4524 = $4521 | $4523;
                $4525 = (HEAP32[tempDoublePtr>>2]=$4524,+HEAPF32[tempDoublePtr>>2]);
                $$sink52$i1432 = $4458 * $4525;
                $4526 = (($12) + ($$10649$i<<2)|0);
                $4527 = $4528 + $$sink52$i1432;
                HEAPF32[$4526>>2] = $4527;
                $4529 = (($$10649$i) + 1)|0;
                $exitcond817$i1433 = ($4529|0)==($$0$i805|0);
                if ($exitcond817$i1433) {
                 break L1260;
                }
                $4530 = (($$9610648$i) + ($$0$i806)|0);
                $$phi$trans$insert880$i1434 = (($12) + ($4529<<2)|0);
                $$pre881$i1435 = +HEAPF32[$$phi$trans$insert880$i1434>>2];
                $$10649$i = $4529;$$9610648$i = $4530;$4528 = $$pre881$i1435;
               }
              }
             } while(0);
             $$2575654$i = (($$0599766$i) + 1)|0;
             $4472 = ($$2575654$i|0)<($$0597767$i|0);
             $4473 = (($4460) + ($126)|0);
             if ($4472) {
              $4474 = Math_imul($$0597767$i, $126)|0;
              if ($4077) {
               $$2575655$us$i$us = $$2575654$i;$4482 = $4473;
               while(1) {
                $$10611651$us$us$i$us = $4482;$$11652$us$us$i$us = 0;
                while(1) {
                 $4475 = +HEAPF32[$$10611651$us$us$i$us>>2];
                 $$sink57$us$us$i1430$us = $4087 * $4475;
                 $4476 = (($12) + ($$11652$us$us$i$us<<2)|0);
                 $4477 = +HEAPF32[$4476>>2];
                 $4478 = $4477 + $$sink57$us$us$i1430$us;
                 HEAPF32[$4476>>2] = $4478;
                 $4479 = (($$11652$us$us$i$us) + 1)|0;
                 $4480 = (($$10611651$us$us$i$us) + ($$0$i806)|0);
                 $exitcond821$i1431$us = ($4479|0)==($$0$i805|0);
                 if ($exitcond821$i1431$us) {
                  break;
                 } else {
                  $$10611651$us$us$i$us = $4480;$$11652$us$us$i$us = $4479;
                 }
                }
                $$2575$us$i$us = (($$2575655$us$i$us) + 1)|0;
                $4481 = (($4482) + ($126)|0);
                $exitcond824$i1428$us = ($$2575$us$i$us|0)==($$0597767$i|0);
                if ($exitcond824$i1428$us) {
                 break;
                } else {
                 $$2575655$us$i$us = $$2575$us$i$us;$4482 = $4481;
                }
               }
              } else {
               $$2575655$us$i = $$2575654$i;$4507 = $4473;
               while(1) {
                $$10611651$us657$i = $4507;$$11652$us656$i = 0;
                while(1) {
                 $4483 = ((($$10611651$us657$i)) + 3|0);
                 $4484 = HEAP8[$4483>>0]|0;
                 $4485 = $4484&255;
                 $4486 = $4485 << 24;
                 $4487 = ((($$10611651$us657$i)) + 2|0);
                 $4488 = HEAP8[$4487>>0]|0;
                 $4489 = $4488&255;
                 $4490 = $4489 << 16;
                 $4491 = $4490 | $4486;
                 $4492 = ((($$10611651$us657$i)) + 1|0);
                 $4493 = HEAP8[$4492>>0]|0;
                 $4494 = $4493&255;
                 $4495 = $4494 << 8;
                 $4496 = $4491 | $4495;
                 $4497 = HEAP8[$$10611651$us657$i>>0]|0;
                 $4498 = $4497&255;
                 $4499 = $4496 | $4498;
                 $4500 = (HEAP32[tempDoublePtr>>2]=$4499,+HEAPF32[tempDoublePtr>>2]);
                 $$sink57$us659$i = $4087 * $4500;
                 $4501 = (($12) + ($$11652$us656$i<<2)|0);
                 $4502 = +HEAPF32[$4501>>2];
                 $4503 = $4502 + $$sink57$us659$i;
                 HEAPF32[$4501>>2] = $4503;
                 $4504 = (($$11652$us656$i) + 1)|0;
                 $4505 = (($$10611651$us657$i) + ($$0$i806)|0);
                 $exitcond820$i1427 = ($4504|0)==($$0$i805|0);
                 if ($exitcond820$i1427) {
                  break;
                 } else {
                  $$10611651$us657$i = $4505;$$11652$us656$i = $4504;
                 }
                }
                $$2575$us$i = (($$2575655$us$i) + 1)|0;
                $4506 = (($4507) + ($126)|0);
                $exitcond824$i1428 = ($$2575$us$i|0)==($$0597767$i|0);
                if ($exitcond824$i1428) {
                 break;
                } else {
                 $$2575655$us$i = $$2575$us$i;$4507 = $4506;
                }
               }
              }
              $scevgep823$i = (($uglygep$i1355) + ($4474)|0);
              $$lcssa$i1437 = $scevgep823$i;
             } else {
              $$lcssa$i1437 = $4473;
             }
             $4531 = $4087 * $$0585769$i;
             if ($4077) {
              $$11612662$us$i = $$lcssa$i1437;$$12663$us$i = 0;
              while(1) {
               $4532 = +HEAPF32[$$11612662$us$i>>2];
               $$sink62$us$i1439 = $4531 * $4532;
               $4533 = (($12) + ($$12663$us$i<<2)|0);
               $4534 = +HEAPF32[$4533>>2];
               $4535 = $4534 + $$sink62$us$i1439;
               HEAPF32[$4533>>2] = $4535;
               $4536 = (($$12663$us$i) + 1)|0;
               $4537 = (($$11612662$us$i) + ($$0$i806)|0);
               $exitcond826$i1440 = ($4536|0)==($$0$i805|0);
               if ($exitcond826$i1440) {
                label = 923;
                break;
               } else {
                $$11612662$us$i = $4537;$$12663$us$i = $4536;
               }
              }
             } else {
              $$11612662$i = $$lcssa$i1437;$$12663$i = 0;
              while(1) {
               $4538 = ((($$11612662$i)) + 3|0);
               $4539 = HEAP8[$4538>>0]|0;
               $4540 = $4539&255;
               $4541 = $4540 << 24;
               $4542 = ((($$11612662$i)) + 2|0);
               $4543 = HEAP8[$4542>>0]|0;
               $4544 = $4543&255;
               $4545 = $4544 << 16;
               $4546 = $4545 | $4541;
               $4547 = ((($$11612662$i)) + 1|0);
               $4548 = HEAP8[$4547>>0]|0;
               $4549 = $4548&255;
               $4550 = $4549 << 8;
               $4551 = $4546 | $4550;
               $4552 = HEAP8[$$11612662$i>>0]|0;
               $4553 = $4552&255;
               $4554 = $4551 | $4553;
               $4555 = (HEAP32[tempDoublePtr>>2]=$4554,+HEAPF32[tempDoublePtr>>2]);
               $$sink62$i1441 = $4531 * $4555;
               $4556 = (($12) + ($$12663$i<<2)|0);
               $4557 = +HEAPF32[$4556>>2];
               $4558 = $4557 + $$sink62$i1441;
               HEAPF32[$4556>>2] = $4558;
               $4559 = (($$12663$i) + 1)|0;
               $4560 = (($$11612662$i) + ($$0$i806)|0);
               $exitcond825$i1442 = ($4559|0)==($$0$i805|0);
               if ($exitcond825$i1442) {
                label = 923;
                break;
               } else {
                $$11612662$i = $4560;$$12663$i = $4559;
               }
              }
             }
            }
           } while(0);
           do {
            if ((label|0) == 923) {
             label = 0;
             if (!($4084)) {
              break;
             }
             $$3750$i = (($$0599766$i) + 1)|0;
             $$not$i1457 = ($$3750$i|0)<($$0597767$i|0);
             if (!($$not$i1457)) {
              break;
             }
             $4599 = (($141) + ($4090)|0);
             $4600 = (($4599) + ($126)|0);
             $4601 = (($4600) + ($4085)|0);
             $$0600759$i$us = $4601;$$2760$i$us = $$0571741$i;
             while(1) {
              if ($4077) {
               $$3752$us$i$us$us = $$3750$i;$$4592751$us$i$us$us = $$0600759$i$us;
               while(1) {
                $$13614746$us$us$i$us$us = $$4592751$us$i$us$us;$$14747$us$us$i$us$us = 0;
                while(1) {
                 $4629 = +HEAPF32[$$13614746$us$us$i$us$us>>2];
                 $4630 = (($12) + ($$14747$us$us$i$us$us<<2)|0);
                 $4631 = +HEAPF32[$4630>>2];
                 $4632 = $4629 + $4631;
                 HEAPF32[$4630>>2] = $4632;
                 $4633 = (($$14747$us$us$i$us$us) + 1)|0;
                 $4634 = (($$13614746$us$us$i$us$us) + ($$0$i806)|0);
                 $exitcond872$i1461$us$us = ($4633|0)==($$0$i805|0);
                 if ($exitcond872$i1461$us$us) {
                  break;
                 } else {
                  $$13614746$us$us$i$us$us = $4634;$$14747$us$us$i$us$us = $4633;
                 }
                }
                $4628 = (($$4592751$us$i$us$us) + ($126)|0);
                $$3$us$i1460$us$us = (($$3752$us$i$us$us) + 1)|0;
                $exitcond873$i$us$us = ($$3$us$i1460$us$us|0)==($$0597767$i|0);
                if ($exitcond873$i$us$us) {
                 break;
                } else {
                 $$3752$us$i$us$us = $$3$us$i1460$us$us;$$4592751$us$i$us$us = $4628;
                }
               }
              } else {
               $$3752$us$i$us2215 = $$3750$i;$$4592751$us$i$us2216 = $$0600759$i$us;
               while(1) {
                $$13614746$us755$i$us2219 = $$4592751$us$i$us2216;$$14747$us754$i$us2218 = 0;
                while(1) {
                 $4602 = ((($$13614746$us755$i$us2219)) + 3|0);
                 $4603 = HEAP8[$4602>>0]|0;
                 $4604 = $4603&255;
                 $4605 = $4604 << 24;
                 $4606 = ((($$13614746$us755$i$us2219)) + 2|0);
                 $4607 = HEAP8[$4606>>0]|0;
                 $4608 = $4607&255;
                 $4609 = $4608 << 16;
                 $4610 = $4609 | $4605;
                 $4611 = ((($$13614746$us755$i$us2219)) + 1|0);
                 $4612 = HEAP8[$4611>>0]|0;
                 $4613 = $4612&255;
                 $4614 = $4613 << 8;
                 $4615 = $4610 | $4614;
                 $4616 = HEAP8[$$13614746$us755$i$us2219>>0]|0;
                 $4617 = $4616&255;
                 $4618 = $4615 | $4617;
                 $4619 = (HEAP32[tempDoublePtr>>2]=$4618,+HEAPF32[tempDoublePtr>>2]);
                 $4620 = (($12) + ($$14747$us754$i$us2218<<2)|0);
                 $4621 = +HEAPF32[$4620>>2];
                 $4622 = $4621 + $4619;
                 HEAPF32[$4620>>2] = $4622;
                 $4623 = (($$14747$us754$i$us2218) + 1)|0;
                 $4624 = (($$13614746$us755$i$us2219) + ($$0$i806)|0);
                 $exitcond871$i1459$us2220 = ($4623|0)==($$0$i805|0);
                 if ($exitcond871$i1459$us2220) {
                  break;
                 } else {
                  $$13614746$us755$i$us2219 = $4624;$$14747$us754$i$us2218 = $4623;
                 }
                }
                $4625 = (($$4592751$us$i$us2216) + ($126)|0);
                $$3$us$i1460$us2226 = (($$3752$us$i$us2215) + 1)|0;
                $exitcond873$i$us2227 = ($$3$us$i1460$us2226|0)==($$0597767$i|0);
                if ($exitcond873$i$us2227) {
                 break;
                } else {
                 $$3752$us$i$us2215 = $$3$us$i1460$us2226;$$4592751$us$i$us2216 = $4625;
                }
               }
              }
              $4626 = (($$0600759$i$us) + ($$0778)|0);
              $4627 = (($$2760$i$us) + 1)|0;
              $exitcond874$i1462$us = ($4627|0)==($$0593$$i|0);
              if ($exitcond874$i1462$us) {
               break;
              } else {
               $$0600759$i$us = $4626;$$2760$i$us = $4627;
              }
             }
            }
           } while(0);
           $4635 = (($$0577770$i) + ($4086))|0;
           $4636 = Math_imul($4635, $$0$i805)|0;
           $$15762$i = 0;
           while(1) {
            $4637 = (($12) + ($$15762$i<<2)|0);
            $4638 = +HEAPF32[$4637>>2];
            $4639 = $4638 / $4073;
            $4640 = (($$15762$i) + ($4636))|0;
            $4641 = (($1241) + ($4640<<2)|0);
            HEAPF32[$4641>>2] = $4639;
            $4642 = (($$15762$i) + 1)|0;
            $exitcond875$i1463 = ($4642|0)==($$0$i805|0);
            if ($exitcond875$i1463) {
             break;
            } else {
             $$15762$i = $4642;
            }
           }
           $4643 = (($$0597767$i) + ($4070))|0;
           $4644 = $4072 + $$0585769$i;
           $4645 = $4644 > 1.0;
           $4646 = $4644 + -1.0;
           $4647 = $4645&1;
           $$1598$i = (($4643) + ($4647))|0;
           $$1586$i = $4645 ? $4646 : $4644;
           $4648 = (($$0577770$i) + 1)|0;
           $exitcond876$i1464 = ($4648|0)==($4|0);
           if ($exitcond876$i1464) {
            break;
           } else {
            $$0599766$i$phi = $$0597767$i;$$0587768$i$phi = $$0585769$i;$$0577770$i = $4648;$$0585769$i = $$1586$i;$$0597767$i = $$1598$i;$$0599766$i = $$0599766$i$phi;$$0587768$i = $$0587768$i$phi;
           }
          }
         }
         $4649 = $4068 + $$0582777$i;
         $4650 = $4649 > 1.0;
         $4651 = $4649 + -1.0;
         $4652 = $4650&1;
         $4653 = (($4652) + ($4066))|0;
         $$2595$i = (($4653) + ($$0593$$i))|0;
         $$1583$i = $4650 ? $4651 : $4649;
         $4654 = (($$0576778$i) + 1)|0;
         $exitcond877$i1465 = ($4654|0)==($5|0);
         if ($exitcond877$i1465) {
          break;
         } else {
          $$0584776$i$phi = $$0582777$i;$$0576778$i = $4654;$$0582777$i = $$1583$i;$$0593775$i = $$2595$i;$$0596774$i = $$0593$$i;$$0584776$i = $$0584776$i$phi;
         }
        }
       }
      }
      break;
     }
     switch ($7|0) {
     case 5125:  {
      $2880 = $4 << 1;
      $2881 = ($2880|0)==($2|0);
      $2882 = $5 << 1;
      $2883 = ($2882|0)==($3|0);
      $or$cond$i1184 = $2881 & $2883;
      if ($or$cond$i1184) {
       __ZN3osgL15halveImage_uintEijjPKjPjiiii($$0$i805,$2,$3,$141,$1241,$$0$i806,$$0778,$126,$$785);
      } else {
       $2884 = (+($3|0));
       $2885 = (+($5|0));
       $2886 = $2884 / $2885;
       $2887 = (+($2|0));
       $2888 = (+($4|0));
       $2889 = $2887 / $2888;
       $2890 = (+Math_floor((+$2886)));
       $2891 = (~~(($2890)));
       $2892 = (+($2891|0));
       $2893 = $2886 - $2892;
       $2894 = (+Math_floor((+$2889)));
       $2895 = (~~(($2894)));
       $2896 = (+($2895|0));
       $2897 = $2889 - $2896;
       $2898 = $2889 * $2886;
       $2899 = ($5|0)>(0);
       if ($2899) {
        $2900 = (($3) + -1)|0;
        $2901 = ($4|0)>(0);
        $2902 = ($$785|0)==(0);
        $2903 = (($$0778) + ($126))|0;
        $exitcond843$i2140 = ($$0$i805|0)==(1);
        $$phi$trans$insert893$i3010 = ((($12)) + 4|0);
        $exitcond843$i3013 = ($$0$i805|0)==(2);
        $$phi$trans$insert889$i3006 = ((($12)) + 4|0);
        $exitcond831$i3009 = ($$0$i805|0)==(2);
        $$phi$trans$insert885$i3002 = ((($12)) + 4|0);
        $exitcond821$i3005 = ($$0$i805|0)==(2);
        $$phi$trans$insert881$i2998 = ((($12)) + 4|0);
        $exitcond819$i3001 = ($$0$i805|0)==(2);
        $$0570781$i = 0;$$0581780$i = $2893;$$0583779$i = 0.0;$$0588778$i = $2891;$$0591777$i = 0;
        while(1) {
         $2904 = ($$0588778$i|0)<($3|0);
         $$0588$$i = $2904 ? $$0588778$i : $2900;
         if ($2901) {
          $2905 = ($$0588$$i|0)>($$0591777$i|0);
          $2906 = Math_imul($$0591777$i, $$0778)|0;
          $2907 = 1.0 - $$0583779$i;
          $2908 = Math_imul($$0588$$i, $$0778)|0;
          $$0565743$i = (($$0591777$i) + 1)|0;
          $2909 = ($$0565743$i|0)<($$0588$$i|0);
          $2910 = Math_imul($$0565743$i, $$0778)|0;
          $2911 = Math_imul($$0570781$i, $4)|0;
          $2912 = $$0581780$i - $$0583779$i;
          $uglygep$i1185 = (($141) + ($2906)|0);
          $2913 = (($$0588$$i) + -1)|0;
          $2914 = Math_imul($2913, $$0778)|0;
          $uglygep832$i = (($141) + ($2914)|0);
          $uglygep856$i = (($141) + ($2908)|0);
          $$0571773$i = 0;$$0584772$i = $2897;$$0586771$i = 0.0;$$0592770$i = $2895;$$0594769$i = 0;
          while(1) {
           $2915 = Math_imul($$0594769$i, $126)|0;
           $2916 = ($$0592770$i|0)>($$0594769$i|0);
           $or$cond622$i = $2905 & $2916;
           ;HEAP32[$12>>2]=0|0;HEAP32[$12+4>>2]=0|0;HEAP32[$12+8>>2]=0|0;HEAP32[$12+12>>2]=0|0;
           L1326: do {
            if ($or$cond622$i) {
             $2917 = (($141) + ($2915)|0);
             $2918 = (($2917) + ($2906)|0);
             $2919 = 1.0 - $$0586771$i;
             $2920 = $2907 * $2919;
             L1328: do {
              if ($2902) {
               $2921 = HEAP32[$2918>>2]|0;
               $$pn620$us$i2138 = (+($2921>>>0));
               $$sink3$us$i11862139 = $2920 * $$pn620$us$i2138;
               $2922 = $$sink3$us$i11862139 + 0.0;
               HEAPF32[$12>>2] = $2922;
               if ($exitcond843$i2140) {
                break;
               }
               $2923 = (($2918) + ($$0$i806)|0);
               $2924 = HEAP32[$2923>>2]|0;
               $$pn620$us$i3011 = (+($2924>>>0));
               $$sink3$us$i11863012 = $2920 * $$pn620$us$i3011;
               $2925 = $$sink3$us$i11863012 + 0.0;
               HEAPF32[$$phi$trans$insert893$i3010>>2] = $2925;
               if ($exitcond843$i3013) {
                break;
               } else {
                $2926 = 2;$2928 = $2923;
               }
               while(1) {
                $$phi$trans$insert893$i$phi$trans$insert = (($12) + ($2926<<2)|0);
                $$pre894$i$pre = +HEAPF32[$$phi$trans$insert893$i$phi$trans$insert>>2];
                $2927 = (($2928) + ($$0$i806)|0);
                $$phi$trans$insert893$i = (($12) + ($2926<<2)|0);
                $2929 = HEAP32[$2927>>2]|0;
                $$pn620$us$i = (+($2929>>>0));
                $$sink3$us$i1186 = $2920 * $$pn620$us$i;
                $2930 = $$pre894$i$pre + $$sink3$us$i1186;
                HEAPF32[$$phi$trans$insert893$i>>2] = $2930;
                $2931 = (($2926) + 1)|0;
                $exitcond843$i = ($2931|0)==($$0$i805|0);
                if ($exitcond843$i) {
                 break;
                } else {
                 $2926 = $2931;$2928 = $2927;
                }
               }
              } else {
               $$0572691$i = 0;$$0595690$i = $2918;$2951 = 0.0;
               while(1) {
                $2932 = ((($$0595690$i)) + 3|0);
                $2933 = HEAP8[$2932>>0]|0;
                $2934 = $2933&255;
                $2935 = $2934 << 24;
                $2936 = ((($$0595690$i)) + 2|0);
                $2937 = HEAP8[$2936>>0]|0;
                $2938 = $2937&255;
                $2939 = $2938 << 16;
                $2940 = $2939 | $2935;
                $2941 = ((($$0595690$i)) + 1|0);
                $2942 = HEAP8[$2941>>0]|0;
                $2943 = $2942&255;
                $2944 = $2943 << 8;
                $2945 = $2940 | $2944;
                $2946 = HEAP8[$$0595690$i>>0]|0;
                $2947 = $2946&255;
                $2948 = $2945 | $2947;
                $$pn620$i = (+($2948>>>0));
                $$sink3$i1187 = $2920 * $$pn620$i;
                $2949 = (($12) + ($$0572691$i<<2)|0);
                $2950 = $2951 + $$sink3$i1187;
                HEAPF32[$2949>>2] = $2950;
                $2952 = (($$0572691$i) + 1)|0;
                $exitcond842$i1188 = ($2952|0)==($$0$i805|0);
                if ($exitcond842$i1188) {
                 break L1328;
                }
                $2953 = (($$0595690$i) + ($$0$i806)|0);
                $$phi$trans$insert891$i = (($12) + ($2952<<2)|0);
                $$pre892$i = +HEAPF32[$$phi$trans$insert891$i>>2];
                $$0572691$i = $2952;$$0595690$i = $2953;$2951 = $$pre892$i;
               }
              }
             } while(0);
             $2954 = (($$0594769$i) + 1)|0;
             $2955 = ($2954|0)<($$0592770$i|0);
             $2956 = (($2918) + ($126)|0);
             if ($2955) {
              $2957 = Math_imul($$0592770$i, $126)|0;
              if ($2902) {
               $$0567699$us$i$us = $2954;$2966 = $2956;
               while(1) {
                $$1573696$us$us$i$us = 0;$$1596695$us$us$i$us = $2966;
                while(1) {
                 $2958 = HEAP32[$$1596695$us$us$i$us>>2]|0;
                 $$pn619$us$us$i$us = (+($2958>>>0));
                 $$sink7$us$us$i1191$us = $2907 * $$pn619$us$us$i$us;
                 $2959 = (($12) + ($$1573696$us$us$i$us<<2)|0);
                 $2960 = +HEAPF32[$2959>>2];
                 $2961 = $2960 + $$sink7$us$us$i1191$us;
                 HEAPF32[$2959>>2] = $2961;
                 $2962 = (($$1573696$us$us$i$us) + 1)|0;
                 $2963 = (($$1596695$us$us$i$us) + ($$0$i806)|0);
                 $exitcond848$i$us = ($2962|0)==($$0$i805|0);
                 if ($exitcond848$i$us) {
                  break;
                 } else {
                  $$1573696$us$us$i$us = $2962;$$1596695$us$us$i$us = $2963;
                 }
                }
                $2964 = (($$0567699$us$i$us) + 1)|0;
                $2965 = (($2966) + ($126)|0);
                $exitcond851$i1190$us = ($2964|0)==($$0592770$i|0);
                if ($exitcond851$i1190$us) {
                 break;
                } else {
                 $$0567699$us$i$us = $2964;$2966 = $2965;
                }
               }
              } else {
               $$0567699$us$i = $2954;$2991 = $2956;
               while(1) {
                $$1573696$us702$i = 0;$$1596695$us703$i = $2991;
                while(1) {
                 $2967 = ((($$1596695$us703$i)) + 3|0);
                 $2968 = HEAP8[$2967>>0]|0;
                 $2969 = $2968&255;
                 $2970 = $2969 << 24;
                 $2971 = ((($$1596695$us703$i)) + 2|0);
                 $2972 = HEAP8[$2971>>0]|0;
                 $2973 = $2972&255;
                 $2974 = $2973 << 16;
                 $2975 = $2974 | $2970;
                 $2976 = ((($$1596695$us703$i)) + 1|0);
                 $2977 = HEAP8[$2976>>0]|0;
                 $2978 = $2977&255;
                 $2979 = $2978 << 8;
                 $2980 = $2975 | $2979;
                 $2981 = HEAP8[$$1596695$us703$i>>0]|0;
                 $2982 = $2981&255;
                 $2983 = $2980 | $2982;
                 $$pn619$us705$i = (+($2983>>>0));
                 $$sink7$us706$i = $2907 * $$pn619$us705$i;
                 $2984 = (($12) + ($$1573696$us702$i<<2)|0);
                 $2985 = +HEAPF32[$2984>>2];
                 $2986 = $2985 + $$sink7$us706$i;
                 HEAPF32[$2984>>2] = $2986;
                 $2987 = (($$1573696$us702$i) + 1)|0;
                 $2988 = (($$1596695$us703$i) + ($$0$i806)|0);
                 $exitcond847$i1189 = ($2987|0)==($$0$i805|0);
                 if ($exitcond847$i1189) {
                  break;
                 } else {
                  $$1573696$us702$i = $2987;$$1596695$us703$i = $2988;
                 }
                }
                $2989 = (($$0567699$us$i) + 1)|0;
                $2990 = (($2991) + ($126)|0);
                $exitcond851$i1190 = ($2989|0)==($$0592770$i|0);
                if ($exitcond851$i1190) {
                 break;
                } else {
                 $$0567699$us$i = $2989;$2991 = $2990;
                }
               }
              }
              $scevgep850$i = (($uglygep$i1185) + ($2957)|0);
              $$lcssa642$i = $scevgep850$i;
             } else {
              $$lcssa642$i = $2956;
             }
             $2992 = $2907 * $$0584772$i;
             if ($2902) {
              $$2574710$us$i = 0;$$2597709$us$i = $$lcssa642$i;
              while(1) {
               $2993 = HEAP32[$$2597709$us$i>>2]|0;
               $$pn618$us$i = (+($2993>>>0));
               $$sink12$us$i1193 = $2992 * $$pn618$us$i;
               $2994 = (($12) + ($$2574710$us$i<<2)|0);
               $2995 = +HEAPF32[$2994>>2];
               $2996 = $2995 + $$sink12$us$i1193;
               HEAPF32[$2994>>2] = $2996;
               $2997 = (($$2574710$us$i) + 1)|0;
               $2998 = (($$2597709$us$i) + ($$0$i806)|0);
               $exitcond853$i = ($2997|0)==($$0$i805|0);
               if ($exitcond853$i) {
                break;
               } else {
                $$2574710$us$i = $2997;$$2597709$us$i = $2998;
               }
              }
             } else {
              $$2574710$i = 0;$$2597709$i = $$lcssa642$i;
              while(1) {
               $2999 = ((($$2597709$i)) + 3|0);
               $3000 = HEAP8[$2999>>0]|0;
               $3001 = $3000&255;
               $3002 = $3001 << 24;
               $3003 = ((($$2597709$i)) + 2|0);
               $3004 = HEAP8[$3003>>0]|0;
               $3005 = $3004&255;
               $3006 = $3005 << 16;
               $3007 = $3006 | $3002;
               $3008 = ((($$2597709$i)) + 1|0);
               $3009 = HEAP8[$3008>>0]|0;
               $3010 = $3009&255;
               $3011 = $3010 << 8;
               $3012 = $3007 | $3011;
               $3013 = HEAP8[$$2597709$i>>0]|0;
               $3014 = $3013&255;
               $3015 = $3012 | $3014;
               $$pn618$i = (+($3015>>>0));
               $$sink12$i1194 = $2992 * $$pn618$i;
               $3016 = (($12) + ($$2574710$i<<2)|0);
               $3017 = +HEAPF32[$3016>>2];
               $3018 = $3017 + $$sink12$i1194;
               HEAPF32[$3016>>2] = $3018;
               $3019 = (($$2574710$i) + 1)|0;
               $3020 = (($$2597709$i) + ($$0$i806)|0);
               $exitcond852$i1195 = ($3019|0)==($$0$i805|0);
               if ($exitcond852$i1195) {
                break;
               } else {
                $$2574710$i = $3019;$$2597709$i = $3020;
               }
              }
             }
             $3021 = $$0581780$i * $2919;
             $3022 = (($2917) + ($2908)|0);
             if ($2902) {
              $$3575715$us$i = 0;$$3598714$us$i = $3022;
              while(1) {
               $3023 = HEAP32[$$3598714$us$i>>2]|0;
               $$pn617$us$i = (+($3023>>>0));
               $$sink17$us$i1196 = $3021 * $$pn617$us$i;
               $3024 = (($12) + ($$3575715$us$i<<2)|0);
               $3025 = +HEAPF32[$3024>>2];
               $3026 = $3025 + $$sink17$us$i1196;
               HEAPF32[$3024>>2] = $3026;
               $3027 = (($$3575715$us$i) + 1)|0;
               $3028 = (($$3598714$us$i) + ($$0$i806)|0);
               $exitcond855$i1197 = ($3027|0)==($$0$i805|0);
               if ($exitcond855$i1197) {
                break;
               } else {
                $$3575715$us$i = $3027;$$3598714$us$i = $3028;
               }
              }
             } else {
              $$3575715$i = 0;$$3598714$i = $3022;
              while(1) {
               $3065 = ((($$3598714$i)) + 3|0);
               $3066 = HEAP8[$3065>>0]|0;
               $3067 = $3066&255;
               $3068 = $3067 << 24;
               $3069 = ((($$3598714$i)) + 2|0);
               $3070 = HEAP8[$3069>>0]|0;
               $3071 = $3070&255;
               $3072 = $3071 << 16;
               $3073 = $3072 | $3068;
               $3074 = ((($$3598714$i)) + 1|0);
               $3075 = HEAP8[$3074>>0]|0;
               $3076 = $3075&255;
               $3077 = $3076 << 8;
               $3078 = $3073 | $3077;
               $3079 = HEAP8[$$3598714$i>>0]|0;
               $3080 = $3079&255;
               $3081 = $3078 | $3080;
               $$pn617$i = (+($3081>>>0));
               $$sink17$i1201 = $3021 * $$pn617$i;
               $3082 = (($12) + ($$3575715$i<<2)|0);
               $3083 = +HEAPF32[$3082>>2];
               $3084 = $3083 + $$sink17$i1201;
               HEAPF32[$3082>>2] = $3084;
               $3085 = (($$3575715$i) + 1)|0;
               $3086 = (($$3598714$i) + ($$0$i806)|0);
               $exitcond854$i = ($3085|0)==($$0$i805|0);
               if ($exitcond854$i) {
                break;
               } else {
                $$3575715$i = $3085;$$3598714$i = $3086;
               }
              }
             }
             $3029 = (($3022) + ($126)|0);
             if ($2955) {
              $3030 = Math_imul($$0592770$i, $126)|0;
              if ($2902) {
               $$1568722$us$i$us = $2954;$3039 = $3029;
               while(1) {
                $$4599718$us$us$i$us = $3039;$$4719$us$us$i$us = 0;
                while(1) {
                 $3031 = HEAP32[$$4599718$us$us$i$us>>2]|0;
                 $$pn616$us$us$i$us = (+($3031>>>0));
                 $$sink22$us$us$i1200$us = $$0581780$i * $$pn616$us$us$i$us;
                 $3032 = (($12) + ($$4719$us$us$i$us<<2)|0);
                 $3033 = +HEAPF32[$3032>>2];
                 $3034 = $3033 + $$sink22$us$us$i1200$us;
                 HEAPF32[$3032>>2] = $3034;
                 $3035 = (($$4719$us$us$i$us) + 1)|0;
                 $3036 = (($$4599718$us$us$i$us) + ($$0$i806)|0);
                 $exitcond860$i$us = ($3035|0)==($$0$i805|0);
                 if ($exitcond860$i$us) {
                  break;
                 } else {
                  $$4599718$us$us$i$us = $3036;$$4719$us$us$i$us = $3035;
                 }
                }
                $3037 = (($$1568722$us$i$us) + 1)|0;
                $3038 = (($3039) + ($126)|0);
                $exitcond863$i1199$us = ($3037|0)==($$0592770$i|0);
                if ($exitcond863$i1199$us) {
                 break;
                } else {
                 $$1568722$us$i$us = $3037;$3039 = $3038;
                }
               }
              } else {
               $$1568722$us$i = $2954;$3064 = $3029;
               while(1) {
                $$4599718$us726$i = $3064;$$4719$us725$i = 0;
                while(1) {
                 $3040 = ((($$4599718$us726$i)) + 3|0);
                 $3041 = HEAP8[$3040>>0]|0;
                 $3042 = $3041&255;
                 $3043 = $3042 << 24;
                 $3044 = ((($$4599718$us726$i)) + 2|0);
                 $3045 = HEAP8[$3044>>0]|0;
                 $3046 = $3045&255;
                 $3047 = $3046 << 16;
                 $3048 = $3047 | $3043;
                 $3049 = ((($$4599718$us726$i)) + 1|0);
                 $3050 = HEAP8[$3049>>0]|0;
                 $3051 = $3050&255;
                 $3052 = $3051 << 8;
                 $3053 = $3048 | $3052;
                 $3054 = HEAP8[$$4599718$us726$i>>0]|0;
                 $3055 = $3054&255;
                 $3056 = $3053 | $3055;
                 $$pn616$us728$i = (+($3056>>>0));
                 $$sink22$us729$i = $$0581780$i * $$pn616$us728$i;
                 $3057 = (($12) + ($$4719$us725$i<<2)|0);
                 $3058 = +HEAPF32[$3057>>2];
                 $3059 = $3058 + $$sink22$us729$i;
                 HEAPF32[$3057>>2] = $3059;
                 $3060 = (($$4719$us725$i) + 1)|0;
                 $3061 = (($$4599718$us726$i) + ($$0$i806)|0);
                 $exitcond859$i1198 = ($3060|0)==($$0$i805|0);
                 if ($exitcond859$i1198) {
                  break;
                 } else {
                  $$4599718$us726$i = $3061;$$4719$us725$i = $3060;
                 }
                }
                $3062 = (($$1568722$us$i) + 1)|0;
                $3063 = (($3064) + ($126)|0);
                $exitcond863$i1199 = ($3062|0)==($$0592770$i|0);
                if ($exitcond863$i1199) {
                 break;
                } else {
                 $$1568722$us$i = $3062;$3064 = $3063;
                }
               }
              }
              $scevgep862$i = (($uglygep856$i) + ($3030)|0);
              $$lcssa643$i = $scevgep862$i;
             } else {
              $$lcssa643$i = $3029;
             }
             $3087 = $$0581780$i * $$0584772$i;
             if ($2902) {
              $$5600732$us$i = $$lcssa643$i;$$5733$us$i = 0;
              while(1) {
               $3088 = HEAP32[$$5600732$us$i>>2]|0;
               $$pn615$us$i = (+($3088>>>0));
               $$sink27$us$i1202 = $3087 * $$pn615$us$i;
               $3089 = (($12) + ($$5733$us$i<<2)|0);
               $3090 = +HEAPF32[$3089>>2];
               $3091 = $3090 + $$sink27$us$i1202;
               HEAPF32[$3089>>2] = $3091;
               $3092 = (($$5733$us$i) + 1)|0;
               $3093 = (($$5600732$us$i) + ($$0$i806)|0);
               $exitcond865$i1203 = ($3092|0)==($$0$i805|0);
               if ($exitcond865$i1203) {
                break;
               } else {
                $$5600732$us$i = $3093;$$5733$us$i = $3092;
               }
              }
             } else {
              $$5600732$i = $$lcssa643$i;$$5733$i = 0;
              while(1) {
               $3107 = ((($$5600732$i)) + 3|0);
               $3108 = HEAP8[$3107>>0]|0;
               $3109 = $3108&255;
               $3110 = $3109 << 24;
               $3111 = ((($$5600732$i)) + 2|0);
               $3112 = HEAP8[$3111>>0]|0;
               $3113 = $3112&255;
               $3114 = $3113 << 16;
               $3115 = $3114 | $3110;
               $3116 = ((($$5600732$i)) + 1|0);
               $3117 = HEAP8[$3116>>0]|0;
               $3118 = $3117&255;
               $3119 = $3118 << 8;
               $3120 = $3115 | $3119;
               $3121 = HEAP8[$$5600732$i>>0]|0;
               $3122 = $3121&255;
               $3123 = $3120 | $3122;
               $$pn615$i = (+($3123>>>0));
               $$sink27$i1204 = $3087 * $$pn615$i;
               $3124 = (($12) + ($$5733$i<<2)|0);
               $3125 = +HEAPF32[$3124>>2];
               $3126 = $3125 + $$sink27$i1204;
               HEAPF32[$3124>>2] = $3126;
               $3127 = (($$5733$i) + 1)|0;
               $3128 = (($$5600732$i) + ($$0$i806)|0);
               $exitcond864$i1205 = ($3127|0)==($$0$i805|0);
               if ($exitcond864$i1205) {
                break;
               } else {
                $$5600732$i = $3128;$$5733$i = $3127;
               }
              }
             }
             if (!($2909)) {
              break;
             }
             if ($2902) {
              $$0563744$i$us = $2918;$$0565746$i$us = $$0565743$i;$$0745$i$us = $$lcssa642$i;
              while(1) {
               $3094 = (($$0563744$i$us) + ($$0778)|0);
               $3095 = (($$0745$i$us) + ($$0778)|0);
               $$1564737$us$i$us = $3094;$$1738$us$i$us = $3095;$$6736$us$i$us = 0;
               while(1) {
                $3096 = HEAP32[$$1564737$us$i$us>>2]|0;
                $3097 = HEAP32[$$1738$us$i$us>>2]|0;
                $$pn626$us$i$us = (+($3096>>>0));
                $$sink$us$i1209$us = $2919 * $$pn626$us$i$us;
                $3098 = (+($3097>>>0));
                $3099 = $$0584772$i * $3098;
                $3100 = $$sink$us$i1209$us + $3099;
                $3101 = (($12) + ($$6736$us$i$us<<2)|0);
                $3102 = +HEAPF32[$3101>>2];
                $3103 = $3102 + $3100;
                HEAPF32[$3101>>2] = $3103;
                $3104 = (($$6736$us$i$us) + 1)|0;
                $3105 = (($$1564737$us$i$us) + ($$0$i806)|0);
                $3106 = (($$1738$us$i$us) + ($$0$i806)|0);
                $exitcond871$i$us = ($3104|0)==($$0$i805|0);
                if ($exitcond871$i$us) {
                 break;
                } else {
                 $$1564737$us$i$us = $3105;$$1738$us$i$us = $3106;$$6736$us$i$us = $3104;
                }
               }
               $scevgep869$i$us = (($$0563744$i$us) + ($2903)|0);
               $scevgep867$i$us = (($$0745$i$us) + ($2903)|0);
               $$0565$i$us = (($$0565746$i$us) + 1)|0;
               $exitcond872$i$us = ($$0565$i$us|0)==($$0588$$i|0);
               if ($exitcond872$i$us) {
                label = 707;
                break;
               } else {
                $$0563744$i$us = $scevgep869$i$us;$$0565746$i$us = $$0565$i$us;$$0745$i$us = $scevgep867$i$us;
               }
              }
             } else {
              $$0563744$i = $2918;$$0565746$i = $$0565743$i;$$0745$i = $$lcssa642$i;
              while(1) {
               $3129 = (($$0563744$i) + ($$0778)|0);
               $3130 = (($$0745$i) + ($$0778)|0);
               $$1564737$i = $3129;$$1738$i = $3130;$$6736$i = 0;
               while(1) {
                $3131 = ((($$1564737$i)) + 3|0);
                $3132 = HEAP8[$3131>>0]|0;
                $3133 = $3132&255;
                $3134 = $3133 << 24;
                $3135 = ((($$1564737$i)) + 2|0);
                $3136 = HEAP8[$3135>>0]|0;
                $3137 = $3136&255;
                $3138 = $3137 << 16;
                $3139 = $3138 | $3134;
                $3140 = ((($$1564737$i)) + 1|0);
                $3141 = HEAP8[$3140>>0]|0;
                $3142 = $3141&255;
                $3143 = $3142 << 8;
                $3144 = $3139 | $3143;
                $3145 = HEAP8[$$1564737$i>>0]|0;
                $3146 = $3145&255;
                $3147 = $3144 | $3146;
                $3148 = ((($$1738$i)) + 3|0);
                $3149 = HEAP8[$3148>>0]|0;
                $3150 = $3149&255;
                $3151 = $3150 << 24;
                $3152 = ((($$1738$i)) + 2|0);
                $3153 = HEAP8[$3152>>0]|0;
                $3154 = $3153&255;
                $3155 = $3154 << 16;
                $3156 = $3155 | $3151;
                $3157 = ((($$1738$i)) + 1|0);
                $3158 = HEAP8[$3157>>0]|0;
                $3159 = $3158&255;
                $3160 = $3159 << 8;
                $3161 = $3156 | $3160;
                $3162 = HEAP8[$$1738$i>>0]|0;
                $3163 = $3162&255;
                $3164 = $3161 | $3163;
                $$pn626$i = (+($3147>>>0));
                $$sink$i1210 = $2919 * $$pn626$i;
                $3165 = (+($3164>>>0));
                $3166 = $$0584772$i * $3165;
                $3167 = $$sink$i1210 + $3166;
                $3168 = (($12) + ($$6736$i<<2)|0);
                $3169 = +HEAPF32[$3168>>2];
                $3170 = $3169 + $3167;
                HEAPF32[$3168>>2] = $3170;
                $3171 = (($$6736$i) + 1)|0;
                $3172 = (($$1564737$i) + ($$0$i806)|0);
                $3173 = (($$1738$i) + ($$0$i806)|0);
                $exitcond868$i = ($3171|0)==($$0$i805|0);
                if ($exitcond868$i) {
                 break;
                } else {
                 $$1564737$i = $3172;$$1738$i = $3173;$$6736$i = $3171;
                }
               }
               $scevgep869$i = (($$0563744$i) + ($2903)|0);
               $scevgep867$i = (($$0745$i) + ($2903)|0);
               $$0565$i = (($$0565746$i) + 1)|0;
               $exitcond872$i = ($$0565$i|0)==($$0588$$i|0);
               if ($exitcond872$i) {
                label = 707;
                break;
               } else {
                $$0563744$i = $scevgep869$i;$$0565746$i = $$0565$i;$$0745$i = $scevgep867$i;
               }
              }
             }
            } else {
             if ($2905) {
              $3174 = $$0584772$i - $$0586771$i;
              $3175 = $2907 * $3174;
              $3176 = (($141) + ($2915)|0);
              $3177 = (($3176) + ($2906)|0);
              L1400: do {
               if ($2902) {
                $3178 = HEAP32[$3177>>2]|0;
                $$pn614$us$i2134 = (+($3178>>>0));
                $$sink37$us$i12112135 = $3175 * $$pn614$us$i2134;
                $3179 = $$sink37$us$i12112135 + 0.0;
                HEAPF32[$12>>2] = $3179;
                if ($exitcond843$i2140) {
                 break;
                }
                $3180 = (($3177) + ($$0$i806)|0);
                $3181 = HEAP32[$3180>>2]|0;
                $$pn614$us$i3007 = (+($3181>>>0));
                $$sink37$us$i12113008 = $3175 * $$pn614$us$i3007;
                $3182 = $$sink37$us$i12113008 + 0.0;
                HEAPF32[$$phi$trans$insert889$i3006>>2] = $3182;
                if ($exitcond831$i3009) {
                 break;
                } else {
                 $3183 = 2;$3185 = $3180;
                }
                while(1) {
                 $$phi$trans$insert889$i$phi$trans$insert = (($12) + ($3183<<2)|0);
                 $$pre890$i$pre = +HEAPF32[$$phi$trans$insert889$i$phi$trans$insert>>2];
                 $3184 = (($3185) + ($$0$i806)|0);
                 $$phi$trans$insert889$i = (($12) + ($3183<<2)|0);
                 $3186 = HEAP32[$3184>>2]|0;
                 $$pn614$us$i = (+($3186>>>0));
                 $$sink37$us$i1211 = $3175 * $$pn614$us$i;
                 $3187 = $$pre890$i$pre + $$sink37$us$i1211;
                 HEAPF32[$$phi$trans$insert889$i>>2] = $3187;
                 $3188 = (($3183) + 1)|0;
                 $exitcond831$i = ($3188|0)==($$0$i805|0);
                 if ($exitcond831$i) {
                  break;
                 } else {
                  $3183 = $3188;$3185 = $3184;
                 }
                }
               } else {
                $$6601665$i = $3177;$$7666$i = 0;$3238 = 0.0;
                while(1) {
                 $3219 = ((($$6601665$i)) + 3|0);
                 $3220 = HEAP8[$3219>>0]|0;
                 $3221 = $3220&255;
                 $3222 = $3221 << 24;
                 $3223 = ((($$6601665$i)) + 2|0);
                 $3224 = HEAP8[$3223>>0]|0;
                 $3225 = $3224&255;
                 $3226 = $3225 << 16;
                 $3227 = $3226 | $3222;
                 $3228 = ((($$6601665$i)) + 1|0);
                 $3229 = HEAP8[$3228>>0]|0;
                 $3230 = $3229&255;
                 $3231 = $3230 << 8;
                 $3232 = $3227 | $3231;
                 $3233 = HEAP8[$$6601665$i>>0]|0;
                 $3234 = $3233&255;
                 $3235 = $3232 | $3234;
                 $$pn614$i = (+($3235>>>0));
                 $$sink37$i1217 = $3175 * $$pn614$i;
                 $3236 = (($12) + ($$7666$i<<2)|0);
                 $3237 = $3238 + $$sink37$i1217;
                 HEAPF32[$3236>>2] = $3237;
                 $3239 = (($$7666$i) + 1)|0;
                 $exitcond830$i1218 = ($3239|0)==($$0$i805|0);
                 if ($exitcond830$i1218) {
                  break L1400;
                 }
                 $3240 = (($$6601665$i) + ($$0$i806)|0);
                 $$phi$trans$insert887$i = (($12) + ($3239<<2)|0);
                 $$pre888$i = +HEAPF32[$$phi$trans$insert887$i>>2];
                 $$6601665$i = $3240;$$7666$i = $3239;$3238 = $$pre888$i;
                }
               }
              } while(0);
              if ($2909) {
               if ($2902) {
                $$1566675$us$i$us = $$0565743$i;$$2578674$us$i$us = $3177;
                while(1) {
                 $3189 = (($$2578674$us$i$us) + ($$0778)|0);
                 $$7602669$us$us$i$us = $3189;$$8670$us$us$i$us = 0;
                 while(1) {
                  $3190 = HEAP32[$$7602669$us$us$i$us>>2]|0;
                  $$pn613$us$us$i$us = (+($3190>>>0));
                  $$sink42$us$us$i1216$us = $3174 * $$pn613$us$us$i$us;
                  $3191 = (($12) + ($$8670$us$us$i$us<<2)|0);
                  $3192 = +HEAPF32[$3191>>2];
                  $3193 = $3192 + $$sink42$us$us$i1216$us;
                  HEAPF32[$3191>>2] = $3193;
                  $3194 = (($$8670$us$us$i$us) + 1)|0;
                  $3195 = (($$7602669$us$us$i$us) + ($$0$i806)|0);
                  $exitcond836$i$us = ($3194|0)==($$0$i805|0);
                  if ($exitcond836$i$us) {
                   break;
                  } else {
                   $$7602669$us$us$i$us = $3195;$$8670$us$us$i$us = $3194;
                  }
                 }
                 $$1566$us$i$us = (($$1566675$us$i$us) + 1)|0;
                 $exitcond839$i1215$us = ($$1566$us$i$us|0)==($$0588$$i|0);
                 if ($exitcond839$i1215$us) {
                  break;
                 } else {
                  $$1566675$us$i$us = $$1566$us$i$us;$$2578674$us$i$us = $3189;
                 }
                }
               } else {
                $$1566675$us$i = $$0565743$i;$$2578674$us$i = $3177;
                while(1) {
                 $3196 = (($$2578674$us$i) + ($$0778)|0);
                 $$7602669$us680$i = $3196;$$8670$us679$i = 0;
                 while(1) {
                  $3197 = ((($$7602669$us680$i)) + 3|0);
                  $3198 = HEAP8[$3197>>0]|0;
                  $3199 = $3198&255;
                  $3200 = $3199 << 24;
                  $3201 = ((($$7602669$us680$i)) + 2|0);
                  $3202 = HEAP8[$3201>>0]|0;
                  $3203 = $3202&255;
                  $3204 = $3203 << 16;
                  $3205 = $3204 | $3200;
                  $3206 = ((($$7602669$us680$i)) + 1|0);
                  $3207 = HEAP8[$3206>>0]|0;
                  $3208 = $3207&255;
                  $3209 = $3208 << 8;
                  $3210 = $3205 | $3209;
                  $3211 = HEAP8[$$7602669$us680$i>>0]|0;
                  $3212 = $3211&255;
                  $3213 = $3210 | $3212;
                  $$pn613$us682$i = (+($3213>>>0));
                  $$sink42$us683$i = $3174 * $$pn613$us682$i;
                  $3214 = (($12) + ($$8670$us679$i<<2)|0);
                  $3215 = +HEAPF32[$3214>>2];
                  $3216 = $3215 + $$sink42$us683$i;
                  HEAPF32[$3214>>2] = $3216;
                  $3217 = (($$8670$us679$i) + 1)|0;
                  $3218 = (($$7602669$us680$i) + ($$0$i806)|0);
                  $exitcond835$i1214 = ($3217|0)==($$0$i805|0);
                  if ($exitcond835$i1214) {
                   break;
                  } else {
                   $$7602669$us680$i = $3218;$$8670$us679$i = $3217;
                  }
                 }
                 $$1566$us$i = (($$1566675$us$i) + 1)|0;
                 $exitcond839$i1215 = ($$1566$us$i|0)==($$0588$$i|0);
                 if ($exitcond839$i1215) {
                  break;
                 } else {
                  $$1566675$us$i = $$1566$us$i;$$2578674$us$i = $3196;
                 }
                }
               }
               $scevgep838$i = (($uglygep832$i) + ($2915)|0);
               $$2578$lcssa$i = $scevgep838$i;
              } else {
               $$2578$lcssa$i = $3177;
              }
              $3241 = $$0581780$i * $3174;
              $3242 = (($$2578$lcssa$i) + ($$0778)|0);
              if ($2902) {
               $$8603686$us$i = $3242;$$9687$us$i = 0;
               while(1) {
                $3243 = HEAP32[$$8603686$us$i>>2]|0;
                $$pn612$us$i = (+($3243>>>0));
                $$sink47$us$i1221 = $3241 * $$pn612$us$i;
                $3244 = (($12) + ($$9687$us$i<<2)|0);
                $3245 = +HEAPF32[$3244>>2];
                $3246 = $3245 + $$sink47$us$i1221;
                HEAPF32[$3244>>2] = $3246;
                $3247 = (($$9687$us$i) + 1)|0;
                $3248 = (($$8603686$us$i) + ($$0$i806)|0);
                $exitcond841$i1222 = ($3247|0)==($$0$i805|0);
                if ($exitcond841$i1222) {
                 label = 707;
                 break L1326;
                } else {
                 $$8603686$us$i = $3248;$$9687$us$i = $3247;
                }
               }
              } else {
               $$8603686$i = $3242;$$9687$i = 0;
               while(1) {
                $3249 = ((($$8603686$i)) + 3|0);
                $3250 = HEAP8[$3249>>0]|0;
                $3251 = $3250&255;
                $3252 = $3251 << 24;
                $3253 = ((($$8603686$i)) + 2|0);
                $3254 = HEAP8[$3253>>0]|0;
                $3255 = $3254&255;
                $3256 = $3255 << 16;
                $3257 = $3256 | $3252;
                $3258 = ((($$8603686$i)) + 1|0);
                $3259 = HEAP8[$3258>>0]|0;
                $3260 = $3259&255;
                $3261 = $3260 << 8;
                $3262 = $3257 | $3261;
                $3263 = HEAP8[$$8603686$i>>0]|0;
                $3264 = $3263&255;
                $3265 = $3262 | $3264;
                $$pn612$i = (+($3265>>>0));
                $$sink47$i1223 = $3241 * $$pn612$i;
                $3266 = (($12) + ($$9687$i<<2)|0);
                $3267 = +HEAPF32[$3266>>2];
                $3268 = $3267 + $$sink47$i1223;
                HEAPF32[$3266>>2] = $3268;
                $3269 = (($$9687$i) + 1)|0;
                $3270 = (($$8603686$i) + ($$0$i806)|0);
                $exitcond840$i1224 = ($3269|0)==($$0$i805|0);
                if ($exitcond840$i1224) {
                 label = 707;
                 break L1326;
                } else {
                 $$8603686$i = $3270;$$9687$i = $3269;
                }
               }
              }
             }
             if (!($2916)) {
              $3372 = $$0584772$i - $$0586771$i;
              $3373 = $2912 * $3372;
              $3374 = (($141) + ($2915)|0);
              $3375 = (($3374) + ($2906)|0);
              if (!($2902)) {
               $$12607644$i = $3375;$$13645$i = 0;$3406 = 0.0;
               while(1) {
                $3387 = ((($$12607644$i)) + 3|0);
                $3388 = HEAP8[$3387>>0]|0;
                $3389 = $3388&255;
                $3390 = $3389 << 24;
                $3391 = ((($$12607644$i)) + 2|0);
                $3392 = HEAP8[$3391>>0]|0;
                $3393 = $3392&255;
                $3394 = $3393 << 16;
                $3395 = $3394 | $3390;
                $3396 = ((($$12607644$i)) + 1|0);
                $3397 = HEAP8[$3396>>0]|0;
                $3398 = $3397&255;
                $3399 = $3398 << 8;
                $3400 = $3395 | $3399;
                $3401 = HEAP8[$$12607644$i>>0]|0;
                $3402 = $3401&255;
                $3403 = $3400 | $3402;
                $$pn$i = (+($3403>>>0));
                $$sink67$i1241 = $3373 * $$pn$i;
                $3404 = (($12) + ($$13645$i<<2)|0);
                $3405 = $3406 + $$sink67$i1241;
                HEAPF32[$3404>>2] = $3405;
                $3407 = (($$13645$i) + 1)|0;
                $exitcond$i1242 = ($3407|0)==($$0$i805|0);
                if ($exitcond$i1242) {
                 label = 707;
                 break L1326;
                }
                $3408 = (($$12607644$i) + ($$0$i806)|0);
                $$phi$trans$insert$i1244 = (($12) + ($3407<<2)|0);
                $$pre$i1245 = +HEAPF32[$$phi$trans$insert$i1244>>2];
                $$12607644$i = $3408;$$13645$i = $3407;$3406 = $$pre$i1245;
               }
              }
              $3376 = HEAP32[$3375>>2]|0;
              $$pn$us$i2126 = (+($3376>>>0));
              $$sink67$us$i12382127 = $3373 * $$pn$us$i2126;
              $3377 = $$sink67$us$i12382127 + 0.0;
              HEAPF32[$12>>2] = $3377;
              if ($exitcond843$i2140) {
               label = 707;
               break;
              }
              $3378 = (($3375) + ($$0$i806)|0);
              $3379 = HEAP32[$3378>>2]|0;
              $$pn$us$i2999 = (+($3379>>>0));
              $$sink67$us$i12383000 = $3373 * $$pn$us$i2999;
              $3380 = $$sink67$us$i12383000 + 0.0;
              HEAPF32[$$phi$trans$insert881$i2998>>2] = $3380;
              if ($exitcond819$i3001) {
               label = 707;
               break;
              } else {
               $3381 = 2;$3383 = $3378;
              }
              while(1) {
               $$phi$trans$insert881$i$phi$trans$insert = (($12) + ($3381<<2)|0);
               $$pre882$i$pre = +HEAPF32[$$phi$trans$insert881$i$phi$trans$insert>>2];
               $3382 = (($3383) + ($$0$i806)|0);
               $$phi$trans$insert881$i = (($12) + ($3381<<2)|0);
               $3384 = HEAP32[$3382>>2]|0;
               $$pn$us$i = (+($3384>>>0));
               $$sink67$us$i1238 = $3373 * $$pn$us$i;
               $3385 = $$pre882$i$pre + $$sink67$us$i1238;
               HEAPF32[$$phi$trans$insert881$i>>2] = $3385;
               $3386 = (($3381) + 1)|0;
               $exitcond819$i = ($3386|0)==($$0$i805|0);
               if ($exitcond819$i) {
                label = 707;
                break L1326;
               } else {
                $3381 = $3386;$3383 = $3382;
               }
              }
             }
             $3271 = 1.0 - $$0586771$i;
             $3272 = $2912 * $3271;
             $3273 = (($141) + ($2915)|0);
             $3274 = (($3273) + ($2906)|0);
             L1441: do {
              if ($2902) {
               $3275 = HEAP32[$3274>>2]|0;
               $$pn611$us$i2130 = (+($3275>>>0));
               $$sink52$us$i12252131 = $3272 * $$pn611$us$i2130;
               $3276 = $$sink52$us$i12252131 + 0.0;
               HEAPF32[$12>>2] = $3276;
               if ($exitcond843$i2140) {
                break;
               }
               $3277 = (($3274) + ($$0$i806)|0);
               $3278 = HEAP32[$3277>>2]|0;
               $$pn611$us$i3003 = (+($3278>>>0));
               $$sink52$us$i12253004 = $3272 * $$pn611$us$i3003;
               $3279 = $$sink52$us$i12253004 + 0.0;
               HEAPF32[$$phi$trans$insert885$i3002>>2] = $3279;
               if ($exitcond821$i3005) {
                break;
               } else {
                $3280 = 2;$3282 = $3277;
               }
               while(1) {
                $$phi$trans$insert885$i$phi$trans$insert = (($12) + ($3280<<2)|0);
                $$pre886$i$pre = +HEAPF32[$$phi$trans$insert885$i$phi$trans$insert>>2];
                $3281 = (($3282) + ($$0$i806)|0);
                $$phi$trans$insert885$i = (($12) + ($3280<<2)|0);
                $3283 = HEAP32[$3281>>2]|0;
                $$pn611$us$i = (+($3283>>>0));
                $$sink52$us$i1225 = $3272 * $$pn611$us$i;
                $3284 = $$pre886$i$pre + $$sink52$us$i1225;
                HEAPF32[$$phi$trans$insert885$i>>2] = $3284;
                $3285 = (($3280) + 1)|0;
                $exitcond821$i = ($3285|0)==($$0$i805|0);
                if ($exitcond821$i) {
                 break;
                } else {
                 $3280 = $3285;$3282 = $3281;
                }
               }
              } else {
               $$10647$i = 0;$$9604646$i = $3274;$3340 = 0.0;
               while(1) {
                $3321 = ((($$9604646$i)) + 3|0);
                $3322 = HEAP8[$3321>>0]|0;
                $3323 = $3322&255;
                $3324 = $3323 << 24;
                $3325 = ((($$9604646$i)) + 2|0);
                $3326 = HEAP8[$3325>>0]|0;
                $3327 = $3326&255;
                $3328 = $3327 << 16;
                $3329 = $3328 | $3324;
                $3330 = ((($$9604646$i)) + 1|0);
                $3331 = HEAP8[$3330>>0]|0;
                $3332 = $3331&255;
                $3333 = $3332 << 8;
                $3334 = $3329 | $3333;
                $3335 = HEAP8[$$9604646$i>>0]|0;
                $3336 = $3335&255;
                $3337 = $3334 | $3336;
                $$pn611$i = (+($3337>>>0));
                $$sink52$i1229 = $3272 * $$pn611$i;
                $3338 = (($12) + ($$10647$i<<2)|0);
                $3339 = $3340 + $$sink52$i1229;
                HEAPF32[$3338>>2] = $3339;
                $3341 = (($$10647$i) + 1)|0;
                $exitcond820$i = ($3341|0)==($$0$i805|0);
                if ($exitcond820$i) {
                 break L1441;
                }
                $3342 = (($$9604646$i) + ($$0$i806)|0);
                $$phi$trans$insert883$i = (($12) + ($3341<<2)|0);
                $$pre884$i = +HEAPF32[$$phi$trans$insert883$i>>2];
                $$10647$i = $3341;$$9604646$i = $3342;$3340 = $$pre884$i;
               }
              }
             } while(0);
             $$2569652$i = (($$0594769$i) + 1)|0;
             $3286 = ($$2569652$i|0)<($$0592770$i|0);
             $3287 = (($3274) + ($126)|0);
             if ($3286) {
              $3288 = Math_imul($$0592770$i, $126)|0;
              if ($2902) {
               $$2569653$us$i$us = $$2569652$i;$3296 = $3287;
               while(1) {
                $$10605649$us$us$i$us = $3296;$$11650$us$us$i$us = 0;
                while(1) {
                 $3289 = HEAP32[$$10605649$us$us$i$us>>2]|0;
                 $$pn610$us$us$i$us = (+($3289>>>0));
                 $$sink57$us$us$i1228$us = $2912 * $$pn610$us$us$i$us;
                 $3290 = (($12) + ($$11650$us$us$i$us<<2)|0);
                 $3291 = +HEAPF32[$3290>>2];
                 $3292 = $3291 + $$sink57$us$us$i1228$us;
                 HEAPF32[$3290>>2] = $3292;
                 $3293 = (($$11650$us$us$i$us) + 1)|0;
                 $3294 = (($$10605649$us$us$i$us) + ($$0$i806)|0);
                 $exitcond824$i$us = ($3293|0)==($$0$i805|0);
                 if ($exitcond824$i$us) {
                  break;
                 } else {
                  $$10605649$us$us$i$us = $3294;$$11650$us$us$i$us = $3293;
                 }
                }
                $$2569$us$i$us = (($$2569653$us$i$us) + 1)|0;
                $3295 = (($3296) + ($126)|0);
                $exitcond827$i1227$us = ($$2569$us$i$us|0)==($$0592770$i|0);
                if ($exitcond827$i1227$us) {
                 break;
                } else {
                 $$2569653$us$i$us = $$2569$us$i$us;$3296 = $3295;
                }
               }
              } else {
               $$2569653$us$i = $$2569652$i;$3320 = $3287;
               while(1) {
                $$10605649$us655$i = $3320;$$11650$us654$i = 0;
                while(1) {
                 $3297 = ((($$10605649$us655$i)) + 3|0);
                 $3298 = HEAP8[$3297>>0]|0;
                 $3299 = $3298&255;
                 $3300 = $3299 << 24;
                 $3301 = ((($$10605649$us655$i)) + 2|0);
                 $3302 = HEAP8[$3301>>0]|0;
                 $3303 = $3302&255;
                 $3304 = $3303 << 16;
                 $3305 = $3304 | $3300;
                 $3306 = ((($$10605649$us655$i)) + 1|0);
                 $3307 = HEAP8[$3306>>0]|0;
                 $3308 = $3307&255;
                 $3309 = $3308 << 8;
                 $3310 = $3305 | $3309;
                 $3311 = HEAP8[$$10605649$us655$i>>0]|0;
                 $3312 = $3311&255;
                 $3313 = $3310 | $3312;
                 $$pn610$us657$i = (+($3313>>>0));
                 $$sink57$us658$i = $2912 * $$pn610$us657$i;
                 $3314 = (($12) + ($$11650$us654$i<<2)|0);
                 $3315 = +HEAPF32[$3314>>2];
                 $3316 = $3315 + $$sink57$us658$i;
                 HEAPF32[$3314>>2] = $3316;
                 $3317 = (($$11650$us654$i) + 1)|0;
                 $3318 = (($$10605649$us655$i) + ($$0$i806)|0);
                 $exitcond823$i1226 = ($3317|0)==($$0$i805|0);
                 if ($exitcond823$i1226) {
                  break;
                 } else {
                  $$10605649$us655$i = $3318;$$11650$us654$i = $3317;
                 }
                }
                $$2569$us$i = (($$2569653$us$i) + 1)|0;
                $3319 = (($3320) + ($126)|0);
                $exitcond827$i1227 = ($$2569$us$i|0)==($$0592770$i|0);
                if ($exitcond827$i1227) {
                 break;
                } else {
                 $$2569653$us$i = $$2569$us$i;$3320 = $3319;
                }
               }
              }
              $scevgep826$i = (($uglygep$i1185) + ($3288)|0);
              $$lcssa$i1231 = $scevgep826$i;
             } else {
              $$lcssa$i1231 = $3287;
             }
             $3343 = $2912 * $$0584772$i;
             if ($2902) {
              $$11606661$us$i = $$lcssa$i1231;$$12662$us$i = 0;
              while(1) {
               $3344 = HEAP32[$$11606661$us$i>>2]|0;
               $$pn609$us$i = (+($3344>>>0));
               $$sink62$us$i1233 = $3343 * $$pn609$us$i;
               $3345 = (($12) + ($$12662$us$i<<2)|0);
               $3346 = +HEAPF32[$3345>>2];
               $3347 = $3346 + $$sink62$us$i1233;
               HEAPF32[$3345>>2] = $3347;
               $3348 = (($$12662$us$i) + 1)|0;
               $3349 = (($$11606661$us$i) + ($$0$i806)|0);
               $exitcond829$i1234 = ($3348|0)==($$0$i805|0);
               if ($exitcond829$i1234) {
                label = 707;
                break;
               } else {
                $$11606661$us$i = $3349;$$12662$us$i = $3348;
               }
              }
             } else {
              $$11606661$i = $$lcssa$i1231;$$12662$i = 0;
              while(1) {
               $3350 = ((($$11606661$i)) + 3|0);
               $3351 = HEAP8[$3350>>0]|0;
               $3352 = $3351&255;
               $3353 = $3352 << 24;
               $3354 = ((($$11606661$i)) + 2|0);
               $3355 = HEAP8[$3354>>0]|0;
               $3356 = $3355&255;
               $3357 = $3356 << 16;
               $3358 = $3357 | $3353;
               $3359 = ((($$11606661$i)) + 1|0);
               $3360 = HEAP8[$3359>>0]|0;
               $3361 = $3360&255;
               $3362 = $3361 << 8;
               $3363 = $3358 | $3362;
               $3364 = HEAP8[$$11606661$i>>0]|0;
               $3365 = $3364&255;
               $3366 = $3363 | $3365;
               $$pn609$i = (+($3366>>>0));
               $$sink62$i1235 = $3343 * $$pn609$i;
               $3367 = (($12) + ($$12662$i<<2)|0);
               $3368 = +HEAPF32[$3367>>2];
               $3369 = $3368 + $$sink62$i1235;
               HEAPF32[$3367>>2] = $3369;
               $3370 = (($$12662$i) + 1)|0;
               $3371 = (($$11606661$i) + ($$0$i806)|0);
               $exitcond828$i1236 = ($3370|0)==($$0$i805|0);
               if ($exitcond828$i1236) {
                label = 707;
                break;
               } else {
                $$11606661$i = $3371;$$12662$i = $3370;
               }
              }
             }
            }
           } while(0);
           do {
            if ((label|0) == 707) {
             label = 0;
             if (!($2909)) {
              break;
             }
             $$3752$i = (($$0594769$i) + 1)|0;
             $$not$i1247 = ($$3752$i|0)<($$0592770$i|0);
             if (!($$not$i1247)) {
              break;
             }
             $3409 = (($141) + ($2915)|0);
             $3410 = (($3409) + ($126)|0);
             $3411 = (($3410) + ($2910)|0);
             $$0587762$i$us = $3411;$$2763$i$us = $$0565743$i;
             while(1) {
              if ($2902) {
               $$3754$us$i$us$us = $$3752$i;$$4580753$us$i$us$us = $$0587762$i$us;
               while(1) {
                $$13608748$us$us$i$us$us = $$4580753$us$i$us$us;$$14749$us$us$i$us$us = 0;
                while(1) {
                 $3438 = HEAP32[$$13608748$us$us$i$us$us>>2]|0;
                 $$sink72$us$us$i$us$us = (+($3438>>>0));
                 $3439 = (($12) + ($$14749$us$us$i$us$us<<2)|0);
                 $3440 = +HEAPF32[$3439>>2];
                 $3441 = $3440 + $$sink72$us$us$i$us$us;
                 HEAPF32[$3439>>2] = $3441;
                 $3442 = (($$14749$us$us$i$us$us) + 1)|0;
                 $3443 = (($$13608748$us$us$i$us$us) + ($$0$i806)|0);
                 $exitcond875$i$us$us = ($3442|0)==($$0$i805|0);
                 if ($exitcond875$i$us$us) {
                  break;
                 } else {
                  $$13608748$us$us$i$us$us = $3443;$$14749$us$us$i$us$us = $3442;
                 }
                }
                $3437 = (($$4580753$us$i$us$us) + ($126)|0);
                $$3$us$i1249$us$us = (($$3754$us$i$us$us) + 1)|0;
                $exitcond876$i$us$us = ($$3$us$i1249$us$us|0)==($$0592770$i|0);
                if ($exitcond876$i$us$us) {
                 break;
                } else {
                 $$3754$us$i$us$us = $$3$us$i1249$us$us;$$4580753$us$i$us$us = $3437;
                }
               }
              } else {
               $$3754$us$i$us2143 = $$3752$i;$$4580753$us$i$us2144 = $$0587762$i$us;
               while(1) {
                $$13608748$us757$i$us2147 = $$4580753$us$i$us2144;$$14749$us756$i$us2146 = 0;
                while(1) {
                 $3412 = ((($$13608748$us757$i$us2147)) + 3|0);
                 $3413 = HEAP8[$3412>>0]|0;
                 $3414 = $3413&255;
                 $3415 = $3414 << 24;
                 $3416 = ((($$13608748$us757$i$us2147)) + 2|0);
                 $3417 = HEAP8[$3416>>0]|0;
                 $3418 = $3417&255;
                 $3419 = $3418 << 16;
                 $3420 = $3419 | $3415;
                 $3421 = ((($$13608748$us757$i$us2147)) + 1|0);
                 $3422 = HEAP8[$3421>>0]|0;
                 $3423 = $3422&255;
                 $3424 = $3423 << 8;
                 $3425 = $3420 | $3424;
                 $3426 = HEAP8[$$13608748$us757$i$us2147>>0]|0;
                 $3427 = $3426&255;
                 $3428 = $3425 | $3427;
                 $$sink72$us759$i$us2148 = (+($3428>>>0));
                 $3429 = (($12) + ($$14749$us756$i$us2146<<2)|0);
                 $3430 = +HEAPF32[$3429>>2];
                 $3431 = $3430 + $$sink72$us759$i$us2148;
                 HEAPF32[$3429>>2] = $3431;
                 $3432 = (($$14749$us756$i$us2146) + 1)|0;
                 $3433 = (($$13608748$us757$i$us2147) + ($$0$i806)|0);
                 $exitcond874$i$us2149 = ($3432|0)==($$0$i805|0);
                 if ($exitcond874$i$us2149) {
                  break;
                 } else {
                  $$13608748$us757$i$us2147 = $3433;$$14749$us756$i$us2146 = $3432;
                 }
                }
                $3434 = (($$4580753$us$i$us2144) + ($126)|0);
                $$3$us$i1249$us2156 = (($$3754$us$i$us2143) + 1)|0;
                $exitcond876$i$us2157 = ($$3$us$i1249$us2156|0)==($$0592770$i|0);
                if ($exitcond876$i$us2157) {
                 break;
                } else {
                 $$3754$us$i$us2143 = $$3$us$i1249$us2156;$$4580753$us$i$us2144 = $3434;
                }
               }
              }
              $3435 = (($$0587762$i$us) + ($$0778)|0);
              $3436 = (($$2763$i$us) + 1)|0;
              $exitcond877$i$us = ($3436|0)==($$0588$$i|0);
              if ($exitcond877$i$us) {
               break;
              } else {
               $$0587762$i$us = $3435;$$2763$i$us = $3436;
              }
             }
            }
           } while(0);
           $3444 = (($$0571773$i) + ($2911))|0;
           $3445 = Math_imul($3444, $$0$i805)|0;
           $$15765$i = 0;
           while(1) {
            $3446 = (($12) + ($$15765$i<<2)|0);
            $3447 = +HEAPF32[$3446>>2];
            $3448 = $3447 / $2898;
            $3449 = !($3448 >= 4294967296.0);
            $3450 = (($$15765$i) + ($3445))|0;
            $3451 = (~~(($3448))>>>0);
            $$sink74$i = $3449 ? $3451 : -1;
            $3452 = (($1241) + ($3450<<2)|0);
            HEAP32[$3452>>2] = $$sink74$i;
            $3453 = (($$15765$i) + 1)|0;
            $exitcond878$i = ($3453|0)==($$0$i805|0);
            if ($exitcond878$i) {
             break;
            } else {
             $$15765$i = $3453;
            }
           }
           $3454 = (($$0592770$i) + ($2895))|0;
           $3455 = $2897 + $$0584772$i;
           $3456 = $3455 > 1.0;
           $3457 = $3455 + -1.0;
           $3458 = $3456&1;
           $$1593$i = (($3454) + ($3458))|0;
           $$1585$i = $3456 ? $3457 : $3455;
           $3459 = (($$0571773$i) + 1)|0;
           $exitcond879$i = ($3459|0)==($4|0);
           if ($exitcond879$i) {
            break;
           } else {
            $$0594769$i$phi = $$0592770$i;$$0586771$i$phi = $$0584772$i;$$0571773$i = $3459;$$0584772$i = $$1585$i;$$0592770$i = $$1593$i;$$0594769$i = $$0594769$i$phi;$$0586771$i = $$0586771$i$phi;
           }
          }
         }
         $3460 = $2893 + $$0581780$i;
         $3461 = $3460 > 1.0;
         $3462 = $3460 + -1.0;
         $3463 = $3461&1;
         $3464 = (($3463) + ($2891))|0;
         $$2590$i = (($3464) + ($$0588$$i))|0;
         $$1582$i = $3461 ? $3462 : $3460;
         $3465 = (($$0570781$i) + 1)|0;
         $exitcond880$i = ($3465|0)==($5|0);
         if ($exitcond880$i) {
          break;
         } else {
          $$0583779$i$phi = $$0581780$i;$$0570781$i = $3465;$$0581780$i = $$1582$i;$$0588778$i = $$2590$i;$$0591777$i = $$0588$$i;$$0583779$i = $$0583779$i$phi;
         }
        }
       }
      }
      break L470;
      break;
     }
     case 5124:  {
      $3466 = $4 << 1;
      $3467 = ($3466|0)==($2|0);
      $3468 = $5 << 1;
      $3469 = ($3468|0)==($3|0);
      $or$cond$i1251 = $3467 & $3469;
      if ($or$cond$i1251) {
       __ZN3osgL14halveImage_intEijjPKiPiiiii($$0$i805,$2,$3,$141,$1241,$$0$i806,$$0778,$126,$$785);
      } else {
       $3470 = (+($3|0));
       $3471 = (+($5|0));
       $3472 = $3470 / $3471;
       $3473 = (+($2|0));
       $3474 = (+($4|0));
       $3475 = $3473 / $3474;
       $3476 = (+Math_floor((+$3472)));
       $3477 = (~~(($3476)));
       $3478 = (+($3477|0));
       $3479 = $3472 - $3478;
       $3480 = (+Math_floor((+$3475)));
       $3481 = (~~(($3480)));
       $3482 = (+($3481|0));
       $3483 = $3475 - $3482;
       $3484 = $3475 * $3472;
       $3485 = ($5|0)>(0);
       if ($3485) {
        $3486 = (($3) + -1)|0;
        $3487 = ($4|0)>(0);
        $3488 = ($$785|0)==(0);
        $3489 = (($$0778) + ($126))|0;
        $exitcond847$i12552178 = ($$0$i805|0)==(1);
        $$phi$trans$insert897$i3026 = ((($12)) + 4|0);
        $exitcond847$i12553029 = ($$0$i805|0)==(2);
        $$phi$trans$insert893$i12893022 = ((($12)) + 4|0);
        $exitcond835$i12883025 = ($$0$i805|0)==(2);
        $$phi$trans$insert889$i13093018 = ((($12)) + 4|0);
        $exitcond825$i3021 = ($$0$i805|0)==(2);
        $$phi$trans$insert885$i13343014 = ((($12)) + 4|0);
        $exitcond823$i13323017 = ($$0$i805|0)==(2);
        $$0578785$i = 0;$$0584784$i = $3479;$$0586783$i = 0.0;$$0595782$i = $3477;$$0598781$i = 0;
        while(1) {
         $3490 = ($$0595782$i|0)<($3|0);
         $$0595$$i = $3490 ? $$0595782$i : $3486;
         if ($3487) {
          $3491 = ($$0595$$i|0)>($$0598781$i|0);
          $3492 = Math_imul($$0598781$i, $$0778)|0;
          $3493 = 1.0 - $$0586783$i;
          $3494 = Math_imul($$0595$$i, $$0778)|0;
          $$0573747$i = (($$0598781$i) + 1)|0;
          $3495 = ($$0573747$i|0)<($$0595$$i|0);
          $3496 = Math_imul($$0573747$i, $$0778)|0;
          $3497 = Math_imul($$0578785$i, $4)|0;
          $3498 = $$0584784$i - $$0586783$i;
          $uglygep$i1252 = (($141) + ($3492)|0);
          $3499 = (($$0595$$i) + -1)|0;
          $3500 = Math_imul($3499, $$0778)|0;
          $uglygep836$i = (($141) + ($3500)|0);
          $uglygep860$i = (($141) + ($3494)|0);
          $$0579777$i = 0;$$0587776$i = $3483;$$0589775$i = 0.0;$$0599774$i = $3481;$$0601773$i = 0;
          while(1) {
           $3501 = Math_imul($$0601773$i, $126)|0;
           $3502 = ($$0599774$i|0)>($$0601773$i|0);
           $or$cond630$i = $3491 & $3502;
           ;HEAP32[$12>>2]=0|0;HEAP32[$12+4>>2]=0|0;HEAP32[$12+8>>2]=0|0;HEAP32[$12+12>>2]=0|0;
           L1505: do {
            if ($or$cond630$i) {
             $3503 = (($141) + ($3501)|0);
             $3504 = (($3503) + ($3492)|0);
             $3505 = 1.0 - $$0589775$i;
             $3506 = $3493 * $3505;
             L1507: do {
              if ($3488) {
               $3507 = HEAP32[$3504>>2]|0;
               $$pn628$us$i2176 = (+($3507|0));
               $$sink3$us$i12542177 = $3506 * $$pn628$us$i2176;
               $3508 = $$sink3$us$i12542177 + 0.0;
               HEAPF32[$12>>2] = $3508;
               if ($exitcond847$i12552178) {
                break;
               }
               $3509 = (($3504) + ($$0$i806)|0);
               $3510 = HEAP32[$3509>>2]|0;
               $$pn628$us$i3027 = (+($3510|0));
               $$sink3$us$i12543028 = $3506 * $$pn628$us$i3027;
               $3511 = $$sink3$us$i12543028 + 0.0;
               HEAPF32[$$phi$trans$insert897$i3026>>2] = $3511;
               if ($exitcond847$i12553029) {
                break;
               } else {
                $3512 = 2;$3514 = $3509;
               }
               while(1) {
                $$phi$trans$insert897$i$phi$trans$insert = (($12) + ($3512<<2)|0);
                $$pre898$i$pre = +HEAPF32[$$phi$trans$insert897$i$phi$trans$insert>>2];
                $3513 = (($3514) + ($$0$i806)|0);
                $$phi$trans$insert897$i = (($12) + ($3512<<2)|0);
                $3515 = HEAP32[$3513>>2]|0;
                $$pn628$us$i = (+($3515|0));
                $$sink3$us$i1254 = $3506 * $$pn628$us$i;
                $3516 = $$pre898$i$pre + $$sink3$us$i1254;
                HEAPF32[$$phi$trans$insert897$i>>2] = $3516;
                $3517 = (($3512) + 1)|0;
                $exitcond847$i1255 = ($3517|0)==($$0$i805|0);
                if ($exitcond847$i1255) {
                 break;
                } else {
                 $3512 = $3517;$3514 = $3513;
                }
               }
              } else {
               $$0580695$i = 0;$$0603694$i = $3504;$3537 = 0.0;
               while(1) {
                $3518 = ((($$0603694$i)) + 3|0);
                $3519 = HEAP8[$3518>>0]|0;
                $3520 = $3519&255;
                $3521 = $3520 << 24;
                $3522 = ((($$0603694$i)) + 2|0);
                $3523 = HEAP8[$3522>>0]|0;
                $3524 = $3523&255;
                $3525 = $3524 << 16;
                $3526 = $3525 | $3521;
                $3527 = ((($$0603694$i)) + 1|0);
                $3528 = HEAP8[$3527>>0]|0;
                $3529 = $3528&255;
                $3530 = $3529 << 8;
                $3531 = $3526 | $3530;
                $3532 = HEAP8[$$0603694$i>>0]|0;
                $3533 = $3532&255;
                $3534 = $3531 | $3533;
                $$pn628$i = (+($3534|0));
                $$sink3$i1256 = $3506 * $$pn628$i;
                $3535 = (($12) + ($$0580695$i<<2)|0);
                $3536 = $3537 + $$sink3$i1256;
                HEAPF32[$3535>>2] = $3536;
                $3538 = (($$0580695$i) + 1)|0;
                $exitcond846$i1257 = ($3538|0)==($$0$i805|0);
                if ($exitcond846$i1257) {
                 break L1507;
                }
                $3539 = (($$0603694$i) + ($$0$i806)|0);
                $$phi$trans$insert895$i = (($12) + ($3538<<2)|0);
                $$pre896$i = +HEAPF32[$$phi$trans$insert895$i>>2];
                $$0580695$i = $3538;$$0603694$i = $3539;$3537 = $$pre896$i;
               }
              }
             } while(0);
             $3540 = (($$0601773$i) + 1)|0;
             $3541 = ($3540|0)<($$0599774$i|0);
             $3542 = (($3504) + ($126)|0);
             if ($3541) {
              $3543 = Math_imul($$0599774$i, $126)|0;
              if ($3488) {
               $$0575703$us$i$us = $3540;$3552 = $3542;
               while(1) {
                $$1581700$us$us$i$us = 0;$$1604699$us$us$i$us = $3552;
                while(1) {
                 $3544 = HEAP32[$$1604699$us$us$i$us>>2]|0;
                 $$pn627$us$us$i$us = (+($3544|0));
                 $$sink7$us$us$i1261$us = $3493 * $$pn627$us$us$i$us;
                 $3545 = (($12) + ($$1581700$us$us$i$us<<2)|0);
                 $3546 = +HEAPF32[$3545>>2];
                 $3547 = $3546 + $$sink7$us$us$i1261$us;
                 HEAPF32[$3545>>2] = $3547;
                 $3548 = (($$1581700$us$us$i$us) + 1)|0;
                 $3549 = (($$1604699$us$us$i$us) + ($$0$i806)|0);
                 $exitcond852$i1262$us = ($3548|0)==($$0$i805|0);
                 if ($exitcond852$i1262$us) {
                  break;
                 } else {
                  $$1581700$us$us$i$us = $3548;$$1604699$us$us$i$us = $3549;
                 }
                }
                $3550 = (($$0575703$us$i$us) + 1)|0;
                $3551 = (($3552) + ($126)|0);
                $exitcond855$i1260$us = ($3550|0)==($$0599774$i|0);
                if ($exitcond855$i1260$us) {
                 break;
                } else {
                 $$0575703$us$i$us = $3550;$3552 = $3551;
                }
               }
              } else {
               $$0575703$us$i = $3540;$3577 = $3542;
               while(1) {
                $$1581700$us706$i = 0;$$1604699$us707$i = $3577;
                while(1) {
                 $3553 = ((($$1604699$us707$i)) + 3|0);
                 $3554 = HEAP8[$3553>>0]|0;
                 $3555 = $3554&255;
                 $3556 = $3555 << 24;
                 $3557 = ((($$1604699$us707$i)) + 2|0);
                 $3558 = HEAP8[$3557>>0]|0;
                 $3559 = $3558&255;
                 $3560 = $3559 << 16;
                 $3561 = $3560 | $3556;
                 $3562 = ((($$1604699$us707$i)) + 1|0);
                 $3563 = HEAP8[$3562>>0]|0;
                 $3564 = $3563&255;
                 $3565 = $3564 << 8;
                 $3566 = $3561 | $3565;
                 $3567 = HEAP8[$$1604699$us707$i>>0]|0;
                 $3568 = $3567&255;
                 $3569 = $3566 | $3568;
                 $$pn627$us709$i = (+($3569|0));
                 $$sink7$us710$i = $3493 * $$pn627$us709$i;
                 $3570 = (($12) + ($$1581700$us706$i<<2)|0);
                 $3571 = +HEAPF32[$3570>>2];
                 $3572 = $3571 + $$sink7$us710$i;
                 HEAPF32[$3570>>2] = $3572;
                 $3573 = (($$1581700$us706$i) + 1)|0;
                 $3574 = (($$1604699$us707$i) + ($$0$i806)|0);
                 $exitcond851$i1259 = ($3573|0)==($$0$i805|0);
                 if ($exitcond851$i1259) {
                  break;
                 } else {
                  $$1581700$us706$i = $3573;$$1604699$us707$i = $3574;
                 }
                }
                $3575 = (($$0575703$us$i) + 1)|0;
                $3576 = (($3577) + ($126)|0);
                $exitcond855$i1260 = ($3575|0)==($$0599774$i|0);
                if ($exitcond855$i1260) {
                 break;
                } else {
                 $$0575703$us$i = $3575;$3577 = $3576;
                }
               }
              }
              $scevgep854$i1263 = (($uglygep$i1252) + ($3543)|0);
              $$lcssa646$i = $scevgep854$i1263;
             } else {
              $$lcssa646$i = $3542;
             }
             $3578 = $3493 * $$0587776$i;
             if ($3488) {
              $$2582714$us$i = 0;$$2605713$us$i = $$lcssa646$i;
              while(1) {
               $3579 = HEAP32[$$2605713$us$i>>2]|0;
               $$pn626$us$i1264 = (+($3579|0));
               $$sink12$us$i1265 = $3578 * $$pn626$us$i1264;
               $3580 = (($12) + ($$2582714$us$i<<2)|0);
               $3581 = +HEAPF32[$3580>>2];
               $3582 = $3581 + $$sink12$us$i1265;
               HEAPF32[$3580>>2] = $3582;
               $3583 = (($$2582714$us$i) + 1)|0;
               $3584 = (($$2605713$us$i) + ($$0$i806)|0);
               $exitcond857$i = ($3583|0)==($$0$i805|0);
               if ($exitcond857$i) {
                break;
               } else {
                $$2582714$us$i = $3583;$$2605713$us$i = $3584;
               }
              }
             } else {
              $$2582714$i = 0;$$2605713$i = $$lcssa646$i;
              while(1) {
               $3585 = ((($$2605713$i)) + 3|0);
               $3586 = HEAP8[$3585>>0]|0;
               $3587 = $3586&255;
               $3588 = $3587 << 24;
               $3589 = ((($$2605713$i)) + 2|0);
               $3590 = HEAP8[$3589>>0]|0;
               $3591 = $3590&255;
               $3592 = $3591 << 16;
               $3593 = $3592 | $3588;
               $3594 = ((($$2605713$i)) + 1|0);
               $3595 = HEAP8[$3594>>0]|0;
               $3596 = $3595&255;
               $3597 = $3596 << 8;
               $3598 = $3593 | $3597;
               $3599 = HEAP8[$$2605713$i>>0]|0;
               $3600 = $3599&255;
               $3601 = $3598 | $3600;
               $$pn626$i1266 = (+($3601|0));
               $$sink12$i1267 = $3578 * $$pn626$i1266;
               $3602 = (($12) + ($$2582714$i<<2)|0);
               $3603 = +HEAPF32[$3602>>2];
               $3604 = $3603 + $$sink12$i1267;
               HEAPF32[$3602>>2] = $3604;
               $3605 = (($$2582714$i) + 1)|0;
               $3606 = (($$2605713$i) + ($$0$i806)|0);
               $exitcond856$i = ($3605|0)==($$0$i805|0);
               if ($exitcond856$i) {
                break;
               } else {
                $$2582714$i = $3605;$$2605713$i = $3606;
               }
              }
             }
             $3607 = $$0584784$i * $3505;
             $3608 = (($3503) + ($3494)|0);
             if ($3488) {
              $$3583719$us$i = 0;$$3606718$us$i = $3608;
              while(1) {
               $3609 = HEAP32[$$3606718$us$i>>2]|0;
               $$pn625$us$i = (+($3609|0));
               $$sink17$us$i1268 = $3607 * $$pn625$us$i;
               $3610 = (($12) + ($$3583719$us$i<<2)|0);
               $3611 = +HEAPF32[$3610>>2];
               $3612 = $3611 + $$sink17$us$i1268;
               HEAPF32[$3610>>2] = $3612;
               $3613 = (($$3583719$us$i) + 1)|0;
               $3614 = (($$3606718$us$i) + ($$0$i806)|0);
               $exitcond859$i1269 = ($3613|0)==($$0$i805|0);
               if ($exitcond859$i1269) {
                break;
               } else {
                $$3583719$us$i = $3613;$$3606718$us$i = $3614;
               }
              }
             } else {
              $$3583719$i = 0;$$3606718$i = $3608;
              while(1) {
               $3651 = ((($$3606718$i)) + 3|0);
               $3652 = HEAP8[$3651>>0]|0;
               $3653 = $3652&255;
               $3654 = $3653 << 24;
               $3655 = ((($$3606718$i)) + 2|0);
               $3656 = HEAP8[$3655>>0]|0;
               $3657 = $3656&255;
               $3658 = $3657 << 16;
               $3659 = $3658 | $3654;
               $3660 = ((($$3606718$i)) + 1|0);
               $3661 = HEAP8[$3660>>0]|0;
               $3662 = $3661&255;
               $3663 = $3662 << 8;
               $3664 = $3659 | $3663;
               $3665 = HEAP8[$$3606718$i>>0]|0;
               $3666 = $3665&255;
               $3667 = $3664 | $3666;
               $$pn625$i = (+($3667|0));
               $$sink17$i1275 = $3607 * $$pn625$i;
               $3668 = (($12) + ($$3583719$i<<2)|0);
               $3669 = +HEAPF32[$3668>>2];
               $3670 = $3669 + $$sink17$i1275;
               HEAPF32[$3668>>2] = $3670;
               $3671 = (($$3583719$i) + 1)|0;
               $3672 = (($$3606718$i) + ($$0$i806)|0);
               $exitcond858$i1276 = ($3671|0)==($$0$i805|0);
               if ($exitcond858$i1276) {
                break;
               } else {
                $$3583719$i = $3671;$$3606718$i = $3672;
               }
              }
             }
             $3615 = (($3608) + ($126)|0);
             if ($3541) {
              $3616 = Math_imul($$0599774$i, $126)|0;
              if ($3488) {
               $$1576726$us$i$us = $3540;$3625 = $3615;
               while(1) {
                $$4607722$us$us$i$us = $3625;$$4723$us$us$i$us = 0;
                while(1) {
                 $3617 = HEAP32[$$4607722$us$us$i$us>>2]|0;
                 $$pn624$us$us$i$us = (+($3617|0));
                 $$sink22$us$us$i1273$us = $$0584784$i * $$pn624$us$us$i$us;
                 $3618 = (($12) + ($$4723$us$us$i$us<<2)|0);
                 $3619 = +HEAPF32[$3618>>2];
                 $3620 = $3619 + $$sink22$us$us$i1273$us;
                 HEAPF32[$3618>>2] = $3620;
                 $3621 = (($$4723$us$us$i$us) + 1)|0;
                 $3622 = (($$4607722$us$us$i$us) + ($$0$i806)|0);
                 $exitcond864$i1274$us = ($3621|0)==($$0$i805|0);
                 if ($exitcond864$i1274$us) {
                  break;
                 } else {
                  $$4607722$us$us$i$us = $3622;$$4723$us$us$i$us = $3621;
                 }
                }
                $3623 = (($$1576726$us$i$us) + 1)|0;
                $3624 = (($3625) + ($126)|0);
                $exitcond867$i1272$us = ($3623|0)==($$0599774$i|0);
                if ($exitcond867$i1272$us) {
                 break;
                } else {
                 $$1576726$us$i$us = $3623;$3625 = $3624;
                }
               }
              } else {
               $$1576726$us$i = $3540;$3650 = $3615;
               while(1) {
                $$4607722$us730$i = $3650;$$4723$us729$i = 0;
                while(1) {
                 $3626 = ((($$4607722$us730$i)) + 3|0);
                 $3627 = HEAP8[$3626>>0]|0;
                 $3628 = $3627&255;
                 $3629 = $3628 << 24;
                 $3630 = ((($$4607722$us730$i)) + 2|0);
                 $3631 = HEAP8[$3630>>0]|0;
                 $3632 = $3631&255;
                 $3633 = $3632 << 16;
                 $3634 = $3633 | $3629;
                 $3635 = ((($$4607722$us730$i)) + 1|0);
                 $3636 = HEAP8[$3635>>0]|0;
                 $3637 = $3636&255;
                 $3638 = $3637 << 8;
                 $3639 = $3634 | $3638;
                 $3640 = HEAP8[$$4607722$us730$i>>0]|0;
                 $3641 = $3640&255;
                 $3642 = $3639 | $3641;
                 $$pn624$us732$i = (+($3642|0));
                 $$sink22$us733$i = $$0584784$i * $$pn624$us732$i;
                 $3643 = (($12) + ($$4723$us729$i<<2)|0);
                 $3644 = +HEAPF32[$3643>>2];
                 $3645 = $3644 + $$sink22$us733$i;
                 HEAPF32[$3643>>2] = $3645;
                 $3646 = (($$4723$us729$i) + 1)|0;
                 $3647 = (($$4607722$us730$i) + ($$0$i806)|0);
                 $exitcond863$i1271 = ($3646|0)==($$0$i805|0);
                 if ($exitcond863$i1271) {
                  break;
                 } else {
                  $$4607722$us730$i = $3647;$$4723$us729$i = $3646;
                 }
                }
                $3648 = (($$1576726$us$i) + 1)|0;
                $3649 = (($3650) + ($126)|0);
                $exitcond867$i1272 = ($3648|0)==($$0599774$i|0);
                if ($exitcond867$i1272) {
                 break;
                } else {
                 $$1576726$us$i = $3648;$3650 = $3649;
                }
               }
              }
              $scevgep866$i = (($uglygep860$i) + ($3616)|0);
              $$lcssa647$i = $scevgep866$i;
             } else {
              $$lcssa647$i = $3615;
             }
             $3673 = $$0584784$i * $$0587776$i;
             if ($3488) {
              $$5608736$us$i = $$lcssa647$i;$$5737$us$i = 0;
              while(1) {
               $3674 = HEAP32[$$5608736$us$i>>2]|0;
               $$pn623$us$i = (+($3674|0));
               $$sink27$us$i1277 = $3673 * $$pn623$us$i;
               $3675 = (($12) + ($$5737$us$i<<2)|0);
               $3676 = +HEAPF32[$3675>>2];
               $3677 = $3676 + $$sink27$us$i1277;
               HEAPF32[$3675>>2] = $3677;
               $3678 = (($$5737$us$i) + 1)|0;
               $3679 = (($$5608736$us$i) + ($$0$i806)|0);
               $exitcond869$i = ($3678|0)==($$0$i805|0);
               if ($exitcond869$i) {
                break;
               } else {
                $$5608736$us$i = $3679;$$5737$us$i = $3678;
               }
              }
             } else {
              $$5608736$i = $$lcssa647$i;$$5737$i = 0;
              while(1) {
               $3695 = ((($$5608736$i)) + 3|0);
               $3696 = HEAP8[$3695>>0]|0;
               $3697 = $3696&255;
               $3698 = $3697 << 24;
               $3699 = ((($$5608736$i)) + 2|0);
               $3700 = HEAP8[$3699>>0]|0;
               $3701 = $3700&255;
               $3702 = $3701 << 16;
               $3703 = $3702 | $3698;
               $3704 = ((($$5608736$i)) + 1|0);
               $3705 = HEAP8[$3704>>0]|0;
               $3706 = $3705&255;
               $3707 = $3706 << 8;
               $3708 = $3703 | $3707;
               $3709 = HEAP8[$$5608736$i>>0]|0;
               $3710 = $3709&255;
               $3711 = $3708 | $3710;
               $$pn623$i = (+($3711|0));
               $$sink27$i1279 = $3673 * $$pn623$i;
               $3712 = (($12) + ($$5737$i<<2)|0);
               $3713 = +HEAPF32[$3712>>2];
               $3714 = $3713 + $$sink27$i1279;
               HEAPF32[$3712>>2] = $3714;
               $3715 = (($$5737$i) + 1)|0;
               $3716 = (($$5608736$i) + ($$0$i806)|0);
               $exitcond868$i1280 = ($3715|0)==($$0$i805|0);
               if ($exitcond868$i1280) {
                break;
               } else {
                $$5608736$i = $3716;$$5737$i = $3715;
               }
              }
             }
             if (!($3495)) {
              break;
             }
             if ($3488) {
              $$0571748$i$us = $3504;$$0573750$i$us = $$0573747$i;$$0749$i$us = $$lcssa646$i;
              while(1) {
               $3680 = (($$0571748$i$us) + ($$0778)|0);
               $3681 = (($$0749$i$us) + ($$0778)|0);
               $$1572741$us$i$us = $3680;$$1742$us$i$us = $3681;$$6740$us$i$us = 0;
               while(1) {
                $3682 = HEAP32[$$1572741$us$i$us>>2]|0;
                $3683 = (+($3682|0));
                $3684 = $3505 * $3683;
                $3685 = HEAP32[$$1742$us$i$us>>2]|0;
                $3686 = (+($3685|0));
                $3687 = $$0587776$i * $3686;
                $3688 = $3684 + $3687;
                $3689 = (($12) + ($$6740$us$i$us<<2)|0);
                $3690 = +HEAPF32[$3689>>2];
                $3691 = $3690 + $3688;
                HEAPF32[$3689>>2] = $3691;
                $3692 = (($$6740$us$i$us) + 1)|0;
                $3693 = (($$1572741$us$i$us) + ($$0$i806)|0);
                $3694 = (($$1742$us$i$us) + ($$0$i806)|0);
                $exitcond875$i1285$us = ($3692|0)==($$0$i805|0);
                if ($exitcond875$i1285$us) {
                 break;
                } else {
                 $$1572741$us$i$us = $3693;$$1742$us$i$us = $3694;$$6740$us$i$us = $3692;
                }
               }
               $scevgep873$i$us = (($$0571748$i$us) + ($3489)|0);
               $scevgep871$i$us = (($$0749$i$us) + ($3489)|0);
               $$0573$i$us = (($$0573750$i$us) + 1)|0;
               $exitcond876$i1283$us = ($$0573$i$us|0)==($$0595$$i|0);
               if ($exitcond876$i1283$us) {
                label = 815;
                break;
               } else {
                $$0571748$i$us = $scevgep873$i$us;$$0573750$i$us = $$0573$i$us;$$0749$i$us = $scevgep871$i$us;
               }
              }
             } else {
              $$0571748$i = $3504;$$0573750$i = $$0573747$i;$$0749$i = $$lcssa646$i;
              while(1) {
               $3717 = (($$0571748$i) + ($$0778)|0);
               $3718 = (($$0749$i) + ($$0778)|0);
               $$1572741$i = $3717;$$1742$i = $3718;$$6740$i = 0;
               while(1) {
                $3719 = ((($$1572741$i)) + 3|0);
                $3720 = HEAP8[$3719>>0]|0;
                $3721 = $3720&255;
                $3722 = $3721 << 24;
                $3723 = ((($$1572741$i)) + 2|0);
                $3724 = HEAP8[$3723>>0]|0;
                $3725 = $3724&255;
                $3726 = $3725 << 16;
                $3727 = $3726 | $3722;
                $3728 = ((($$1572741$i)) + 1|0);
                $3729 = HEAP8[$3728>>0]|0;
                $3730 = $3729&255;
                $3731 = $3730 << 8;
                $3732 = $3727 | $3731;
                $3733 = HEAP8[$$1572741$i>>0]|0;
                $3734 = $3733&255;
                $3735 = $3732 | $3734;
                $3736 = (+($3735|0));
                $3737 = $3505 * $3736;
                $3738 = (($12) + ($$6740$i<<2)|0);
                $3739 = +HEAPF32[$3738>>2];
                $3740 = $3739 + $3737;
                HEAPF32[$3738>>2] = $3740;
                $3741 = ((($$1742$i)) + 3|0);
                $3742 = HEAP8[$3741>>0]|0;
                $3743 = $3742&255;
                $3744 = $3743 << 24;
                $3745 = ((($$1742$i)) + 2|0);
                $3746 = HEAP8[$3745>>0]|0;
                $3747 = $3746&255;
                $3748 = $3747 << 16;
                $3749 = $3748 | $3744;
                $3750 = ((($$1742$i)) + 1|0);
                $3751 = HEAP8[$3750>>0]|0;
                $3752 = $3751&255;
                $3753 = $3752 << 8;
                $3754 = $3749 | $3753;
                $3755 = HEAP8[$$1742$i>>0]|0;
                $3756 = $3755&255;
                $3757 = $3754 | $3756;
                $3758 = (+($3757|0));
                $3759 = $$0587776$i * $3758;
                $3760 = $3740 + $3759;
                HEAPF32[$3738>>2] = $3760;
                $3761 = (($$6740$i) + 1)|0;
                $3762 = (($$1572741$i) + ($$0$i806)|0);
                $3763 = (($$1742$i) + ($$0$i806)|0);
                $exitcond872$i1286 = ($3761|0)==($$0$i805|0);
                if ($exitcond872$i1286) {
                 break;
                } else {
                 $$1572741$i = $3762;$$1742$i = $3763;$$6740$i = $3761;
                }
               }
               $scevgep873$i = (($$0571748$i) + ($3489)|0);
               $scevgep871$i = (($$0749$i) + ($3489)|0);
               $$0573$i = (($$0573750$i) + 1)|0;
               $exitcond876$i1283 = ($$0573$i|0)==($$0595$$i|0);
               if ($exitcond876$i1283) {
                label = 815;
                break;
               } else {
                $$0571748$i = $scevgep873$i;$$0573750$i = $$0573$i;$$0749$i = $scevgep871$i;
               }
              }
             }
            } else {
             if ($3491) {
              $3764 = $$0587776$i - $$0589775$i;
              $3765 = $3493 * $3764;
              $3766 = (($141) + ($3501)|0);
              $3767 = (($3766) + ($3492)|0);
              L1579: do {
               if ($3488) {
                $3768 = HEAP32[$3767>>2]|0;
                $$pn622$us$i2172 = (+($3768|0));
                $$sink37$us$i12872173 = $3765 * $$pn622$us$i2172;
                $3769 = $$sink37$us$i12872173 + 0.0;
                HEAPF32[$12>>2] = $3769;
                if ($exitcond847$i12552178) {
                 break;
                }
                $3770 = (($3767) + ($$0$i806)|0);
                $3771 = HEAP32[$3770>>2]|0;
                $$pn622$us$i3023 = (+($3771|0));
                $$sink37$us$i12873024 = $3765 * $$pn622$us$i3023;
                $3772 = $$sink37$us$i12873024 + 0.0;
                HEAPF32[$$phi$trans$insert893$i12893022>>2] = $3772;
                if ($exitcond835$i12883025) {
                 break;
                } else {
                 $3773 = 2;$3775 = $3770;
                }
                while(1) {
                 $$phi$trans$insert893$i1289$phi$trans$insert = (($12) + ($3773<<2)|0);
                 $$pre894$i1290$pre = +HEAPF32[$$phi$trans$insert893$i1289$phi$trans$insert>>2];
                 $3774 = (($3775) + ($$0$i806)|0);
                 $$phi$trans$insert893$i1289 = (($12) + ($3773<<2)|0);
                 $3776 = HEAP32[$3774>>2]|0;
                 $$pn622$us$i = (+($3776|0));
                 $$sink37$us$i1287 = $3765 * $$pn622$us$i;
                 $3777 = $$pre894$i1290$pre + $$sink37$us$i1287;
                 HEAPF32[$$phi$trans$insert893$i1289>>2] = $3777;
                 $3778 = (($3773) + 1)|0;
                 $exitcond835$i1288 = ($3778|0)==($$0$i805|0);
                 if ($exitcond835$i1288) {
                  break;
                 } else {
                  $3773 = $3778;$3775 = $3774;
                 }
                }
               } else {
                $$6609669$i = $3767;$$7670$i = 0;$3828 = 0.0;
                while(1) {
                 $3809 = ((($$6609669$i)) + 3|0);
                 $3810 = HEAP8[$3809>>0]|0;
                 $3811 = $3810&255;
                 $3812 = $3811 << 24;
                 $3813 = ((($$6609669$i)) + 2|0);
                 $3814 = HEAP8[$3813>>0]|0;
                 $3815 = $3814&255;
                 $3816 = $3815 << 16;
                 $3817 = $3816 | $3812;
                 $3818 = ((($$6609669$i)) + 1|0);
                 $3819 = HEAP8[$3818>>0]|0;
                 $3820 = $3819&255;
                 $3821 = $3820 << 8;
                 $3822 = $3817 | $3821;
                 $3823 = HEAP8[$$6609669$i>>0]|0;
                 $3824 = $3823&255;
                 $3825 = $3822 | $3824;
                 $$pn622$i = (+($3825|0));
                 $$sink37$i1296 = $3765 * $$pn622$i;
                 $3826 = (($12) + ($$7670$i<<2)|0);
                 $3827 = $3828 + $$sink37$i1296;
                 HEAPF32[$3826>>2] = $3827;
                 $3829 = (($$7670$i) + 1)|0;
                 $exitcond834$i1297 = ($3829|0)==($$0$i805|0);
                 if ($exitcond834$i1297) {
                  break L1579;
                 }
                 $3830 = (($$6609669$i) + ($$0$i806)|0);
                 $$phi$trans$insert891$i1298 = (($12) + ($3829<<2)|0);
                 $$pre892$i1299 = +HEAPF32[$$phi$trans$insert891$i1298>>2];
                 $$6609669$i = $3830;$$7670$i = $3829;$3828 = $$pre892$i1299;
                }
               }
              } while(0);
              if ($3495) {
               if ($3488) {
                $$1574679$us$i$us = $$0573747$i;$$2592678$us$i$us = $3767;
                while(1) {
                 $3779 = (($$2592678$us$i$us) + ($$0778)|0);
                 $$7610673$us$us$i$us = $3779;$$8674$us$us$i$us = 0;
                 while(1) {
                  $3780 = HEAP32[$$7610673$us$us$i$us>>2]|0;
                  $$pn621$us$us$i$us = (+($3780|0));
                  $$sink42$us$us$i1294$us = $3764 * $$pn621$us$us$i$us;
                  $3781 = (($12) + ($$8674$us$us$i$us<<2)|0);
                  $3782 = +HEAPF32[$3781>>2];
                  $3783 = $3782 + $$sink42$us$us$i1294$us;
                  HEAPF32[$3781>>2] = $3783;
                  $3784 = (($$8674$us$us$i$us) + 1)|0;
                  $3785 = (($$7610673$us$us$i$us) + ($$0$i806)|0);
                  $exitcond840$i1295$us = ($3784|0)==($$0$i805|0);
                  if ($exitcond840$i1295$us) {
                   break;
                  } else {
                   $$7610673$us$us$i$us = $3785;$$8674$us$us$i$us = $3784;
                  }
                 }
                 $$1574$us$i$us = (($$1574679$us$i$us) + 1)|0;
                 $exitcond843$i1293$us = ($$1574$us$i$us|0)==($$0595$$i|0);
                 if ($exitcond843$i1293$us) {
                  break;
                 } else {
                  $$1574679$us$i$us = $$1574$us$i$us;$$2592678$us$i$us = $3779;
                 }
                }
               } else {
                $$1574679$us$i = $$0573747$i;$$2592678$us$i = $3767;
                while(1) {
                 $3786 = (($$2592678$us$i) + ($$0778)|0);
                 $$7610673$us684$i = $3786;$$8674$us683$i = 0;
                 while(1) {
                  $3787 = ((($$7610673$us684$i)) + 3|0);
                  $3788 = HEAP8[$3787>>0]|0;
                  $3789 = $3788&255;
                  $3790 = $3789 << 24;
                  $3791 = ((($$7610673$us684$i)) + 2|0);
                  $3792 = HEAP8[$3791>>0]|0;
                  $3793 = $3792&255;
                  $3794 = $3793 << 16;
                  $3795 = $3794 | $3790;
                  $3796 = ((($$7610673$us684$i)) + 1|0);
                  $3797 = HEAP8[$3796>>0]|0;
                  $3798 = $3797&255;
                  $3799 = $3798 << 8;
                  $3800 = $3795 | $3799;
                  $3801 = HEAP8[$$7610673$us684$i>>0]|0;
                  $3802 = $3801&255;
                  $3803 = $3800 | $3802;
                  $$pn621$us686$i = (+($3803|0));
                  $$sink42$us687$i = $3764 * $$pn621$us686$i;
                  $3804 = (($12) + ($$8674$us683$i<<2)|0);
                  $3805 = +HEAPF32[$3804>>2];
                  $3806 = $3805 + $$sink42$us687$i;
                  HEAPF32[$3804>>2] = $3806;
                  $3807 = (($$8674$us683$i) + 1)|0;
                  $3808 = (($$7610673$us684$i) + ($$0$i806)|0);
                  $exitcond839$i1292 = ($3807|0)==($$0$i805|0);
                  if ($exitcond839$i1292) {
                   break;
                  } else {
                   $$7610673$us684$i = $3808;$$8674$us683$i = $3807;
                  }
                 }
                 $$1574$us$i = (($$1574679$us$i) + 1)|0;
                 $exitcond843$i1293 = ($$1574$us$i|0)==($$0595$$i|0);
                 if ($exitcond843$i1293) {
                  break;
                 } else {
                  $$1574679$us$i = $$1574$us$i;$$2592678$us$i = $3786;
                 }
                }
               }
               $scevgep842$i = (($uglygep836$i) + ($3501)|0);
               $$2592$lcssa$i = $scevgep842$i;
              } else {
               $$2592$lcssa$i = $3767;
              }
              $3831 = $$0584784$i * $3764;
              $3832 = (($$2592$lcssa$i) + ($$0778)|0);
              if ($3488) {
               $$8611690$us$i = $3832;$$9691$us$i = 0;
               while(1) {
                $3833 = HEAP32[$$8611690$us$i>>2]|0;
                $$pn620$us$i1301 = (+($3833|0));
                $$sink47$us$i1302 = $3831 * $$pn620$us$i1301;
                $3834 = (($12) + ($$9691$us$i<<2)|0);
                $3835 = +HEAPF32[$3834>>2];
                $3836 = $3835 + $$sink47$us$i1302;
                HEAPF32[$3834>>2] = $3836;
                $3837 = (($$9691$us$i) + 1)|0;
                $3838 = (($$8611690$us$i) + ($$0$i806)|0);
                $exitcond845$i = ($3837|0)==($$0$i805|0);
                if ($exitcond845$i) {
                 label = 815;
                 break L1505;
                } else {
                 $$8611690$us$i = $3838;$$9691$us$i = $3837;
                }
               }
              } else {
               $$8611690$i = $3832;$$9691$i = 0;
               while(1) {
                $3839 = ((($$8611690$i)) + 3|0);
                $3840 = HEAP8[$3839>>0]|0;
                $3841 = $3840&255;
                $3842 = $3841 << 24;
                $3843 = ((($$8611690$i)) + 2|0);
                $3844 = HEAP8[$3843>>0]|0;
                $3845 = $3844&255;
                $3846 = $3845 << 16;
                $3847 = $3846 | $3842;
                $3848 = ((($$8611690$i)) + 1|0);
                $3849 = HEAP8[$3848>>0]|0;
                $3850 = $3849&255;
                $3851 = $3850 << 8;
                $3852 = $3847 | $3851;
                $3853 = HEAP8[$$8611690$i>>0]|0;
                $3854 = $3853&255;
                $3855 = $3852 | $3854;
                $$pn620$i1304 = (+($3855|0));
                $$sink47$i1305 = $3831 * $$pn620$i1304;
                $3856 = (($12) + ($$9691$i<<2)|0);
                $3857 = +HEAPF32[$3856>>2];
                $3858 = $3857 + $$sink47$i1305;
                HEAPF32[$3856>>2] = $3858;
                $3859 = (($$9691$i) + 1)|0;
                $3860 = (($$8611690$i) + ($$0$i806)|0);
                $exitcond844$i = ($3859|0)==($$0$i805|0);
                if ($exitcond844$i) {
                 label = 815;
                 break L1505;
                } else {
                 $$8611690$i = $3860;$$9691$i = $3859;
                }
               }
              }
             }
             if (!($3502)) {
              $3962 = $$0587776$i - $$0589775$i;
              $3963 = $3498 * $3962;
              $3964 = (($141) + ($3501)|0);
              $3965 = (($3964) + ($3492)|0);
              if (!($3488)) {
               $$12615648$i = $3965;$$13649$i = 0;$3996 = 0.0;
               while(1) {
                $3977 = ((($$12615648$i)) + 3|0);
                $3978 = HEAP8[$3977>>0]|0;
                $3979 = $3978&255;
                $3980 = $3979 << 24;
                $3981 = ((($$12615648$i)) + 2|0);
                $3982 = HEAP8[$3981>>0]|0;
                $3983 = $3982&255;
                $3984 = $3983 << 16;
                $3985 = $3984 | $3980;
                $3986 = ((($$12615648$i)) + 1|0);
                $3987 = HEAP8[$3986>>0]|0;
                $3988 = $3987&255;
                $3989 = $3988 << 8;
                $3990 = $3985 | $3989;
                $3991 = HEAP8[$$12615648$i>>0]|0;
                $3992 = $3991&255;
                $3993 = $3990 | $3992;
                $$pn$i1337 = (+($3993|0));
                $$sink67$i1338 = $3963 * $$pn$i1337;
                $3994 = (($12) + ($$13649$i<<2)|0);
                $3995 = $3996 + $$sink67$i1338;
                HEAPF32[$3994>>2] = $3995;
                $3997 = (($$13649$i) + 1)|0;
                $exitcond$i1339 = ($3997|0)==($$0$i805|0);
                if ($exitcond$i1339) {
                 label = 815;
                 break L1505;
                }
                $3998 = (($$12615648$i) + ($$0$i806)|0);
                $$phi$trans$insert$i1341 = (($12) + ($3997<<2)|0);
                $$pre$i1342 = +HEAPF32[$$phi$trans$insert$i1341>>2];
                $$12615648$i = $3998;$$13649$i = $3997;$3996 = $$pre$i1342;
               }
              }
              $3966 = HEAP32[$3965>>2]|0;
              $$pn$us$i13302164 = (+($3966|0));
              $$sink67$us$i13312165 = $3963 * $$pn$us$i13302164;
              $3967 = $$sink67$us$i13312165 + 0.0;
              HEAPF32[$12>>2] = $3967;
              if ($exitcond847$i12552178) {
               label = 815;
               break;
              }
              $3968 = (($3965) + ($$0$i806)|0);
              $3969 = HEAP32[$3968>>2]|0;
              $$pn$us$i13303015 = (+($3969|0));
              $$sink67$us$i13313016 = $3963 * $$pn$us$i13303015;
              $3970 = $$sink67$us$i13313016 + 0.0;
              HEAPF32[$$phi$trans$insert885$i13343014>>2] = $3970;
              if ($exitcond823$i13323017) {
               label = 815;
               break;
              } else {
               $3971 = 2;$3973 = $3968;
              }
              while(1) {
               $$phi$trans$insert885$i1334$phi$trans$insert = (($12) + ($3971<<2)|0);
               $$pre886$i1335$pre = +HEAPF32[$$phi$trans$insert885$i1334$phi$trans$insert>>2];
               $3972 = (($3973) + ($$0$i806)|0);
               $$phi$trans$insert885$i1334 = (($12) + ($3971<<2)|0);
               $3974 = HEAP32[$3972>>2]|0;
               $$pn$us$i1330 = (+($3974|0));
               $$sink67$us$i1331 = $3963 * $$pn$us$i1330;
               $3975 = $$pre886$i1335$pre + $$sink67$us$i1331;
               HEAPF32[$$phi$trans$insert885$i1334>>2] = $3975;
               $3976 = (($3971) + 1)|0;
               $exitcond823$i1332 = ($3976|0)==($$0$i805|0);
               if ($exitcond823$i1332) {
                label = 815;
                break L1505;
               } else {
                $3971 = $3976;$3973 = $3972;
               }
              }
             }
             $3861 = 1.0 - $$0589775$i;
             $3862 = $3498 * $3861;
             $3863 = (($141) + ($3501)|0);
             $3864 = (($3863) + ($3492)|0);
             L1620: do {
              if ($3488) {
               $3865 = HEAP32[$3864>>2]|0;
               $$pn619$us$i2168 = (+($3865|0));
               $$sink52$us$i13072169 = $3862 * $$pn619$us$i2168;
               $3866 = $$sink52$us$i13072169 + 0.0;
               HEAPF32[$12>>2] = $3866;
               if ($exitcond847$i12552178) {
                break;
               }
               $3867 = (($3864) + ($$0$i806)|0);
               $3868 = HEAP32[$3867>>2]|0;
               $$pn619$us$i3019 = (+($3868|0));
               $$sink52$us$i13073020 = $3862 * $$pn619$us$i3019;
               $3869 = $$sink52$us$i13073020 + 0.0;
               HEAPF32[$$phi$trans$insert889$i13093018>>2] = $3869;
               if ($exitcond825$i3021) {
                break;
               } else {
                $3870 = 2;$3872 = $3867;
               }
               while(1) {
                $$phi$trans$insert889$i1309$phi$trans$insert = (($12) + ($3870<<2)|0);
                $$pre890$i1310$pre = +HEAPF32[$$phi$trans$insert889$i1309$phi$trans$insert>>2];
                $3871 = (($3872) + ($$0$i806)|0);
                $$phi$trans$insert889$i1309 = (($12) + ($3870<<2)|0);
                $3873 = HEAP32[$3871>>2]|0;
                $$pn619$us$i = (+($3873|0));
                $$sink52$us$i1307 = $3862 * $$pn619$us$i;
                $3874 = $$pre890$i1310$pre + $$sink52$us$i1307;
                HEAPF32[$$phi$trans$insert889$i1309>>2] = $3874;
                $3875 = (($3870) + 1)|0;
                $exitcond825$i = ($3875|0)==($$0$i805|0);
                if ($exitcond825$i) {
                 break;
                } else {
                 $3870 = $3875;$3872 = $3871;
                }
               }
              } else {
               $$10651$i = 0;$$9612650$i = $3864;$3930 = 0.0;
               while(1) {
                $3911 = ((($$9612650$i)) + 3|0);
                $3912 = HEAP8[$3911>>0]|0;
                $3913 = $3912&255;
                $3914 = $3913 << 24;
                $3915 = ((($$9612650$i)) + 2|0);
                $3916 = HEAP8[$3915>>0]|0;
                $3917 = $3916&255;
                $3918 = $3917 << 16;
                $3919 = $3918 | $3914;
                $3920 = ((($$9612650$i)) + 1|0);
                $3921 = HEAP8[$3920>>0]|0;
                $3922 = $3921&255;
                $3923 = $3922 << 8;
                $3924 = $3919 | $3923;
                $3925 = HEAP8[$$9612650$i>>0]|0;
                $3926 = $3925&255;
                $3927 = $3924 | $3926;
                $$pn619$i = (+($3927|0));
                $$sink52$i1315 = $3862 * $$pn619$i;
                $3928 = (($12) + ($$10651$i<<2)|0);
                $3929 = $3930 + $$sink52$i1315;
                HEAPF32[$3928>>2] = $3929;
                $3931 = (($$10651$i) + 1)|0;
                $exitcond824$i1316 = ($3931|0)==($$0$i805|0);
                if ($exitcond824$i1316) {
                 break L1620;
                }
                $3932 = (($$9612650$i) + ($$0$i806)|0);
                $$phi$trans$insert887$i1318 = (($12) + ($3931<<2)|0);
                $$pre888$i1319 = +HEAPF32[$$phi$trans$insert887$i1318>>2];
                $$10651$i = $3931;$$9612650$i = $3932;$3930 = $$pre888$i1319;
               }
              }
             } while(0);
             $$2577656$i = (($$0601773$i) + 1)|0;
             $3876 = ($$2577656$i|0)<($$0599774$i|0);
             $3877 = (($3864) + ($126)|0);
             if ($3876) {
              $3878 = Math_imul($$0599774$i, $126)|0;
              if ($3488) {
               $$2577657$us$i$us = $$2577656$i;$3886 = $3877;
               while(1) {
                $$10613653$us$us$i$us = $3886;$$11654$us$us$i$us = 0;
                while(1) {
                 $3879 = HEAP32[$$10613653$us$us$i$us>>2]|0;
                 $$pn618$us$us$i$us = (+($3879|0));
                 $$sink57$us$us$i1313$us = $3498 * $$pn618$us$us$i$us;
                 $3880 = (($12) + ($$11654$us$us$i$us<<2)|0);
                 $3881 = +HEAPF32[$3880>>2];
                 $3882 = $3881 + $$sink57$us$us$i1313$us;
                 HEAPF32[$3880>>2] = $3882;
                 $3883 = (($$11654$us$us$i$us) + 1)|0;
                 $3884 = (($$10613653$us$us$i$us) + ($$0$i806)|0);
                 $exitcond828$i1314$us = ($3883|0)==($$0$i805|0);
                 if ($exitcond828$i1314$us) {
                  break;
                 } else {
                  $$10613653$us$us$i$us = $3884;$$11654$us$us$i$us = $3883;
                 }
                }
                $$2577$us$i$us = (($$2577657$us$i$us) + 1)|0;
                $3885 = (($3886) + ($126)|0);
                $exitcond831$i1312$us = ($$2577$us$i$us|0)==($$0599774$i|0);
                if ($exitcond831$i1312$us) {
                 break;
                } else {
                 $$2577657$us$i$us = $$2577$us$i$us;$3886 = $3885;
                }
               }
              } else {
               $$2577657$us$i = $$2577656$i;$3910 = $3877;
               while(1) {
                $$10613653$us659$i = $3910;$$11654$us658$i = 0;
                while(1) {
                 $3887 = ((($$10613653$us659$i)) + 3|0);
                 $3888 = HEAP8[$3887>>0]|0;
                 $3889 = $3888&255;
                 $3890 = $3889 << 24;
                 $3891 = ((($$10613653$us659$i)) + 2|0);
                 $3892 = HEAP8[$3891>>0]|0;
                 $3893 = $3892&255;
                 $3894 = $3893 << 16;
                 $3895 = $3894 | $3890;
                 $3896 = ((($$10613653$us659$i)) + 1|0);
                 $3897 = HEAP8[$3896>>0]|0;
                 $3898 = $3897&255;
                 $3899 = $3898 << 8;
                 $3900 = $3895 | $3899;
                 $3901 = HEAP8[$$10613653$us659$i>>0]|0;
                 $3902 = $3901&255;
                 $3903 = $3900 | $3902;
                 $$pn618$us661$i = (+($3903|0));
                 $$sink57$us662$i = $3498 * $$pn618$us661$i;
                 $3904 = (($12) + ($$11654$us658$i<<2)|0);
                 $3905 = +HEAPF32[$3904>>2];
                 $3906 = $3905 + $$sink57$us662$i;
                 HEAPF32[$3904>>2] = $3906;
                 $3907 = (($$11654$us658$i) + 1)|0;
                 $3908 = (($$10613653$us659$i) + ($$0$i806)|0);
                 $exitcond827$i1311 = ($3907|0)==($$0$i805|0);
                 if ($exitcond827$i1311) {
                  break;
                 } else {
                  $$10613653$us659$i = $3908;$$11654$us658$i = $3907;
                 }
                }
                $$2577$us$i = (($$2577657$us$i) + 1)|0;
                $3909 = (($3910) + ($126)|0);
                $exitcond831$i1312 = ($$2577$us$i|0)==($$0599774$i|0);
                if ($exitcond831$i1312) {
                 break;
                } else {
                 $$2577657$us$i = $$2577$us$i;$3910 = $3909;
                }
               }
              }
              $scevgep830$i = (($uglygep$i1252) + ($3878)|0);
              $$lcssa$i1321 = $scevgep830$i;
             } else {
              $$lcssa$i1321 = $3877;
             }
             $3933 = $3498 * $$0587776$i;
             if ($3488) {
              $$11614665$us$i = $$lcssa$i1321;$$12666$us$i = 0;
              while(1) {
               $3934 = HEAP32[$$11614665$us$i>>2]|0;
               $$pn617$us$i1323 = (+($3934|0));
               $$sink62$us$i1324 = $3933 * $$pn617$us$i1323;
               $3935 = (($12) + ($$12666$us$i<<2)|0);
               $3936 = +HEAPF32[$3935>>2];
               $3937 = $3936 + $$sink62$us$i1324;
               HEAPF32[$3935>>2] = $3937;
               $3938 = (($$12666$us$i) + 1)|0;
               $3939 = (($$11614665$us$i) + ($$0$i806)|0);
               $exitcond833$i = ($3938|0)==($$0$i805|0);
               if ($exitcond833$i) {
                label = 815;
                break;
               } else {
                $$11614665$us$i = $3939;$$12666$us$i = $3938;
               }
              }
             } else {
              $$11614665$i = $$lcssa$i1321;$$12666$i = 0;
              while(1) {
               $3940 = ((($$11614665$i)) + 3|0);
               $3941 = HEAP8[$3940>>0]|0;
               $3942 = $3941&255;
               $3943 = $3942 << 24;
               $3944 = ((($$11614665$i)) + 2|0);
               $3945 = HEAP8[$3944>>0]|0;
               $3946 = $3945&255;
               $3947 = $3946 << 16;
               $3948 = $3947 | $3943;
               $3949 = ((($$11614665$i)) + 1|0);
               $3950 = HEAP8[$3949>>0]|0;
               $3951 = $3950&255;
               $3952 = $3951 << 8;
               $3953 = $3948 | $3952;
               $3954 = HEAP8[$$11614665$i>>0]|0;
               $3955 = $3954&255;
               $3956 = $3953 | $3955;
               $$pn617$i1326 = (+($3956|0));
               $$sink62$i1327 = $3933 * $$pn617$i1326;
               $3957 = (($12) + ($$12666$i<<2)|0);
               $3958 = +HEAPF32[$3957>>2];
               $3959 = $3958 + $$sink62$i1327;
               HEAPF32[$3957>>2] = $3959;
               $3960 = (($$12666$i) + 1)|0;
               $3961 = (($$11614665$i) + ($$0$i806)|0);
               $exitcond832$i = ($3960|0)==($$0$i805|0);
               if ($exitcond832$i) {
                label = 815;
                break;
               } else {
                $$11614665$i = $3961;$$12666$i = $3960;
               }
              }
             }
            }
           } while(0);
           do {
            if ((label|0) == 815) {
             label = 0;
             if (!($3495)) {
              break;
             }
             $$3756$i = (($$0601773$i) + 1)|0;
             $$not$i1345 = ($$3756$i|0)<($$0599774$i|0);
             if (!($$not$i1345)) {
              break;
             }
             $3999 = (($141) + ($3501)|0);
             $4000 = (($3999) + ($126)|0);
             $4001 = (($4000) + ($3496)|0);
             $$0602766$i$us = $4001;$$2767$i$us = $$0573747$i;
             while(1) {
              if ($3488) {
               $$3758$us$i$us$us = $$3756$i;$$4594757$us$i$us$us = $$0602766$i$us;
               while(1) {
                $$13616752$us$us$i$us$us = $$4594757$us$i$us$us;$$14753$us$us$i$us$us = 0;
                while(1) {
                 $4028 = HEAP32[$$13616752$us$us$i$us$us>>2]|0;
                 $$sink72$us$us$i1350$us$us = (+($4028|0));
                 $4029 = (($12) + ($$14753$us$us$i$us$us<<2)|0);
                 $4030 = +HEAPF32[$4029>>2];
                 $4031 = $4030 + $$sink72$us$us$i1350$us$us;
                 HEAPF32[$4029>>2] = $4031;
                 $4032 = (($$14753$us$us$i$us$us) + 1)|0;
                 $4033 = (($$13616752$us$us$i$us$us) + ($$0$i806)|0);
                 $exitcond879$i1351$us$us = ($4032|0)==($$0$i805|0);
                 if ($exitcond879$i1351$us$us) {
                  break;
                 } else {
                  $$13616752$us$us$i$us$us = $4033;$$14753$us$us$i$us$us = $4032;
                 }
                }
                $4027 = (($$4594757$us$i$us$us) + ($126)|0);
                $$3$us$i1348$us$us = (($$3758$us$i$us$us) + 1)|0;
                $exitcond880$i1349$us$us = ($$3$us$i1348$us$us|0)==($$0599774$i|0);
                if ($exitcond880$i1349$us$us) {
                 break;
                } else {
                 $$3758$us$i$us$us = $$3$us$i1348$us$us;$$4594757$us$i$us$us = $4027;
                }
               }
              } else {
               $$3758$us$i$us2181 = $$3756$i;$$4594757$us$i$us2182 = $$0602766$i$us;
               while(1) {
                $$13616752$us761$i$us2185 = $$4594757$us$i$us2182;$$14753$us760$i$us2184 = 0;
                while(1) {
                 $4002 = ((($$13616752$us761$i$us2185)) + 3|0);
                 $4003 = HEAP8[$4002>>0]|0;
                 $4004 = $4003&255;
                 $4005 = $4004 << 24;
                 $4006 = ((($$13616752$us761$i$us2185)) + 2|0);
                 $4007 = HEAP8[$4006>>0]|0;
                 $4008 = $4007&255;
                 $4009 = $4008 << 16;
                 $4010 = $4009 | $4005;
                 $4011 = ((($$13616752$us761$i$us2185)) + 1|0);
                 $4012 = HEAP8[$4011>>0]|0;
                 $4013 = $4012&255;
                 $4014 = $4013 << 8;
                 $4015 = $4010 | $4014;
                 $4016 = HEAP8[$$13616752$us761$i$us2185>>0]|0;
                 $4017 = $4016&255;
                 $4018 = $4015 | $4017;
                 $$sink72$us763$i$us2186 = (+($4018|0));
                 $4019 = (($12) + ($$14753$us760$i$us2184<<2)|0);
                 $4020 = +HEAPF32[$4019>>2];
                 $4021 = $4020 + $$sink72$us763$i$us2186;
                 HEAPF32[$4019>>2] = $4021;
                 $4022 = (($$14753$us760$i$us2184) + 1)|0;
                 $4023 = (($$13616752$us761$i$us2185) + ($$0$i806)|0);
                 $exitcond878$i1347$us2187 = ($4022|0)==($$0$i805|0);
                 if ($exitcond878$i1347$us2187) {
                  break;
                 } else {
                  $$13616752$us761$i$us2185 = $4023;$$14753$us760$i$us2184 = $4022;
                 }
                }
                $4024 = (($$4594757$us$i$us2182) + ($126)|0);
                $$3$us$i1348$us2194 = (($$3758$us$i$us2181) + 1)|0;
                $exitcond880$i1349$us2195 = ($$3$us$i1348$us2194|0)==($$0599774$i|0);
                if ($exitcond880$i1349$us2195) {
                 break;
                } else {
                 $$3758$us$i$us2181 = $$3$us$i1348$us2194;$$4594757$us$i$us2182 = $4024;
                }
               }
              }
              $4025 = (($$0602766$i$us) + ($$0778)|0);
              $4026 = (($$2767$i$us) + 1)|0;
              $exitcond881$i$us = ($4026|0)==($$0595$$i|0);
              if ($exitcond881$i$us) {
               break;
              } else {
               $$0602766$i$us = $4025;$$2767$i$us = $4026;
              }
             }
            }
           } while(0);
           $4034 = (($$0579777$i) + ($3497))|0;
           $4035 = Math_imul($4034, $$0$i805)|0;
           $$15769$i = 0;
           while(1) {
            $4036 = (($12) + ($$15769$i<<2)|0);
            $4037 = +HEAPF32[$4036>>2];
            $4038 = $4037 / $3484;
            $4039 = (~~(($4038)));
            $4040 = (($$15769$i) + ($4035))|0;
            $4041 = (($1241) + ($4040<<2)|0);
            HEAP32[$4041>>2] = $4039;
            $4042 = (($$15769$i) + 1)|0;
            $exitcond882$i = ($4042|0)==($$0$i805|0);
            if ($exitcond882$i) {
             break;
            } else {
             $$15769$i = $4042;
            }
           }
           $4043 = (($$0599774$i) + ($3481))|0;
           $4044 = $3483 + $$0587776$i;
           $4045 = $4044 > 1.0;
           $4046 = $4044 + -1.0;
           $4047 = $4045&1;
           $$1600$i = (($4043) + ($4047))|0;
           $$1588$i = $4045 ? $4046 : $4044;
           $4048 = (($$0579777$i) + 1)|0;
           $exitcond883$i = ($4048|0)==($4|0);
           if ($exitcond883$i) {
            break;
           } else {
            $$0601773$i$phi = $$0599774$i;$$0589775$i$phi = $$0587776$i;$$0579777$i = $4048;$$0587776$i = $$1588$i;$$0599774$i = $$1600$i;$$0601773$i = $$0601773$i$phi;$$0589775$i = $$0589775$i$phi;
           }
          }
         }
         $4049 = $3479 + $$0584784$i;
         $4050 = $4049 > 1.0;
         $4051 = $4049 + -1.0;
         $4052 = $4050&1;
         $4053 = (($4052) + ($3477))|0;
         $$2597$i = (($4053) + ($$0595$$i))|0;
         $$1585$i1353 = $4050 ? $4051 : $4049;
         $4054 = (($$0578785$i) + 1)|0;
         $exitcond884$i = ($4054|0)==($5|0);
         if ($exitcond884$i) {
          break;
         } else {
          $$0586783$i$phi = $$0584784$i;$$0578785$i = $4054;$$0584784$i = $$1585$i1353;$$0595782$i = $$2597$i;$$0598781$i = $$0595$$i;$$0586783$i = $$0586783$i$phi;
         }
        }
       }
      }
      break L470;
      break;
     }
     default: {
      break L470;
     }
     }
    } else {
     do {
      switch ($7|0) {
      case 33634:  {
       $5339 = $4 << 1;
       $5340 = ($5339|0)==($2|0);
       $5341 = $5 << 1;
       $5342 = ($5341|0)==($3|0);
       $or$cond$i1484 = $5340 & $5342;
       L1676: do {
        if ($or$cond$i1484) {
         $5343 = ($2|0)==(1);
         $5344 = ($3|0)==(1);
         $or$cond$i1664 = $5343 | $5344;
         $5345 = (($2|0) / 2)&-1;
         $5346 = (($3|0) / 2)&-1;
         if (!($or$cond$i1664)) {
          $5471 = Math_imul($$0$i806, $2)|0;
          $5472 = (($$0778) - ($5471))|0;
          $5473 = ($3|0)>(1);
          if (!($5473)) {
           break;
          }
          $5474 = ($2|0)>(1);
          $5475 = $$0$i806 << 1;
          if ($5474) {
           $$07999$us$i1682 = 0;$$08098$us$i1683 = 0;$$08197$us$i1684 = $141;
          } else {
           break;
          }
          while(1) {
           $$08391$us$us$i1689 = 0;$$18292$us$us$i1688 = $$08197$us$i1684;$$193$us$us$i1687 = $$07999$us$i1682;
           while(1) {
            $5481 = HEAP8[$$18292$us$us$i1688>>0]|0;
            $5482 = $5481&255;
            $5483 = $5482 & 7;
            $5484 = (+($5483|0));
            $5485 = $5484 / 7.0;
            $5486 = $5482 >>> 3;
            $5487 = $5486 & 7;
            $5488 = (+($5487|0));
            $5489 = $5488 / 7.0;
            $5490 = $5482 >>> 6;
            $5491 = (+($5490|0));
            $5492 = $5491 / 3.0;
            $5493 = (($$18292$us$us$i1688) + ($$0$i806)|0);
            $5494 = HEAP8[$5493>>0]|0;
            $5495 = $5494&255;
            $5496 = $5495 & 7;
            $5497 = (+($5496|0));
            $5498 = $5497 / 7.0;
            $5499 = $5495 >>> 3;
            $5500 = $5499 & 7;
            $5501 = (+($5500|0));
            $5502 = $5501 / 7.0;
            $5503 = $5495 >>> 6;
            $5504 = (+($5503|0));
            $5505 = $5504 / 3.0;
            $5506 = (($$18292$us$us$i1688) + ($$0778)|0);
            $5507 = HEAP8[$5506>>0]|0;
            $5508 = $5507&255;
            $5509 = $5508 & 7;
            $5510 = (+($5509|0));
            $5511 = $5510 / 7.0;
            $5512 = $5508 >>> 3;
            $5513 = $5512 & 7;
            $5514 = (+($5513|0));
            $5515 = $5514 / 7.0;
            $5516 = $5508 >>> 6;
            $5517 = (+($5516|0));
            $5518 = $5517 / 3.0;
            $5519 = (($5506) + ($$0$i806)|0);
            $5520 = HEAP8[$5519>>0]|0;
            $5521 = $5520&255;
            $5522 = $5521 & 7;
            $5523 = (+($5522|0));
            $5524 = $5523 / 7.0;
            $5525 = $5521 >>> 3;
            $5526 = $5525 & 7;
            $5527 = (+($5526|0));
            $5528 = $5527 / 7.0;
            $5529 = $5521 >>> 6;
            $5530 = (+($5529|0));
            $5531 = $5530 / 3.0;
            $5532 = $5485 + 0.0;
            $5533 = $5532 + $5498;
            $5534 = $5533 + $5511;
            $5535 = $5534 + $5524;
            $5536 = $5535 * 0.25;
            $5537 = $5489 + 0.0;
            $5538 = $5537 + $5502;
            $5539 = $5538 + $5515;
            $5540 = $5539 + $5528;
            $5541 = $5540 * 0.25;
            $5542 = $5492 + 0.0;
            $5543 = $5542 + $5505;
            $5544 = $5543 + $5518;
            $5545 = $5544 + $5531;
            $5546 = $5545 * 0.25;
            $5547 = $5536;
            $5548 = $5547 * 7.0;
            $5549 = $5548 + 0.5;
            $5550 = (~~(($5549))&255);
            $5551 = $5550 & 7;
            $5552 = (($1241) + ($$193$us$us$i1687)|0);
            $5553 = $5541;
            $5554 = $5553 * 7.0;
            $5555 = $5554 + 0.5;
            $5556 = (~~(($5555))&255);
            $5557 = $5556&255;
            $5558 = $5557 << 3;
            $5559 = $5558 & 56;
            $5560 = $5551&255;
            $5561 = $5559 | $5560;
            $5562 = $5546;
            $5563 = $5562 * 3.0;
            $5564 = $5563 + 0.5;
            $5565 = (~~(($5564))&255);
            $5566 = $5565&255;
            $5567 = $5566 << 6;
            $5568 = $5561 | $5567;
            $5569 = $5568&255;
            HEAP8[$5552>>0] = $5569;
            $5570 = (($$193$us$us$i1687) + 1)|0;
            $5477 = (($$18292$us$us$i1688) + ($5475)|0);
            $5571 = (($$08391$us$us$i1689) + 1)|0;
            $5572 = ($5571|0)<($5345|0);
            if ($5572) {
             $$08391$us$us$i1689 = $5571;$$18292$us$us$i1688 = $5477;$$193$us$us$i1687 = $5570;
            } else {
             break;
            }
           }
           $5476 = (($5477) + ($5472)|0);
           $5478 = (($5476) + ($$0778)|0);
           $5479 = (($$08098$us$i1683) + 1)|0;
           $5480 = ($5479|0)<($5346|0);
           if ($5480) {
            $$07999$us$i1682 = $5570;$$08098$us$i1683 = $5479;$$08197$us$i1684 = $5478;
           } else {
            break L1676;
           }
          }
         }
         if ($5344) {
          $5347 = ($2|0)>(1);
          if (!($5347)) {
           break;
          }
          $5348 = $$0$i806 << 1;
          $$088100$us$i$i1667 = 0;$$09098$us$i$i1668 = $141;
          while(1) {
           $5349 = HEAP8[$$09098$us$i$i1668>>0]|0;
           $5350 = $5349&255;
           $5351 = $5350 & 7;
           $5352 = (+($5351|0));
           $5353 = $5352 / 7.0;
           $5354 = $5350 >>> 3;
           $5355 = $5354 & 7;
           $5356 = (+($5355|0));
           $5357 = $5356 / 7.0;
           $5358 = $5350 >>> 6;
           $5359 = (+($5358|0));
           $5360 = $5359 / 3.0;
           $5361 = (($$09098$us$i$i1668) + ($$0$i806)|0);
           $5362 = HEAP8[$5361>>0]|0;
           $5363 = $5362&255;
           $5364 = $5363 & 7;
           $5365 = (+($5364|0));
           $5366 = $5365 / 7.0;
           $5367 = $5363 >>> 3;
           $5368 = $5367 & 7;
           $5369 = (+($5368|0));
           $5370 = $5369 / 7.0;
           $5371 = $5363 >>> 6;
           $5372 = (+($5371|0));
           $5373 = $5372 / 3.0;
           $5374 = $5353 + 0.0;
           $5375 = $5374 + $5366;
           $5376 = $5375 * 0.5;
           $5377 = $5357 + 0.0;
           $5378 = $5377 + $5370;
           $5379 = $5378 * 0.5;
           $5380 = $5360 + 0.0;
           $5381 = $5380 + $5373;
           $5382 = $5381 * 0.5;
           $5383 = $5376;
           $5384 = $5383 * 7.0;
           $5385 = $5384 + 0.5;
           $5386 = (~~(($5385))&255);
           $5387 = $5386 & 7;
           $5388 = (($1241) + ($$088100$us$i$i1667)|0);
           $5389 = $5379;
           $5390 = $5389 * 7.0;
           $5391 = $5390 + 0.5;
           $5392 = (~~(($5391))&255);
           $5393 = $5392&255;
           $5394 = $5393 << 3;
           $5395 = $5394 & 56;
           $5396 = $5387&255;
           $5397 = $5395 | $5396;
           $5398 = $5382;
           $5399 = $5398 * 3.0;
           $5400 = $5399 + 0.5;
           $5401 = (~~(($5400))&255);
           $5402 = $5401&255;
           $5403 = $5402 << 6;
           $5404 = $5397 | $5403;
           $5405 = $5404&255;
           HEAP8[$5388>>0] = $5405;
           $5406 = (($$088100$us$i$i1667) + 1)|0;
           $5407 = (($$09098$us$i$i1668) + ($5348)|0);
           $5408 = ($5406|0)<($5345|0);
           if ($5408) {
            $$088100$us$i$i1667 = $5406;$$09098$us$i$i1668 = $5407;
           } else {
            break;
           }
          }
         } else {
          $5409 = ($3|0)>(1);
          $or$cond$i$i1673 = $5343 & $5409;
          if (!($or$cond$i$i1673)) {
           break;
          }
          $5410 = $$0778 << 1;
          $$085110$us$i$i1675 = 0;$$191108$us$i$i1676 = $141;
          while(1) {
           $5411 = HEAP8[$$191108$us$i$i1676>>0]|0;
           $5412 = $5411&255;
           $5413 = $5412 & 7;
           $5414 = (+($5413|0));
           $5415 = $5414 / 7.0;
           $5416 = $5412 >>> 3;
           $5417 = $5416 & 7;
           $5418 = (+($5417|0));
           $5419 = $5418 / 7.0;
           $5420 = $5412 >>> 6;
           $5421 = (+($5420|0));
           $5422 = $5421 / 3.0;
           $5423 = (($$191108$us$i$i1676) + ($$0778)|0);
           $5424 = HEAP8[$5423>>0]|0;
           $5425 = $5424&255;
           $5426 = $5425 & 7;
           $5427 = (+($5426|0));
           $5428 = $5427 / 7.0;
           $5429 = $5425 >>> 3;
           $5430 = $5429 & 7;
           $5431 = (+($5430|0));
           $5432 = $5431 / 7.0;
           $5433 = $5425 >>> 6;
           $5434 = (+($5433|0));
           $5435 = $5434 / 3.0;
           $5436 = $5415 + 0.0;
           $5437 = $5436 + $5428;
           $5438 = $5437 * 0.5;
           $5439 = $5419 + 0.0;
           $5440 = $5439 + $5432;
           $5441 = $5440 * 0.5;
           $5442 = $5422 + 0.0;
           $5443 = $5442 + $5435;
           $5444 = $5443 * 0.5;
           $5445 = $5438;
           $5446 = $5445 * 7.0;
           $5447 = $5446 + 0.5;
           $5448 = (~~(($5447))&255);
           $5449 = $5448 & 7;
           $5450 = (($1241) + ($$085110$us$i$i1675)|0);
           $5451 = $5441;
           $5452 = $5451 * 7.0;
           $5453 = $5452 + 0.5;
           $5454 = (~~(($5453))&255);
           $5455 = $5454&255;
           $5456 = $5455 << 3;
           $5457 = $5456 & 56;
           $5458 = $5449&255;
           $5459 = $5457 | $5458;
           $5460 = $5444;
           $5461 = $5460 * 3.0;
           $5462 = $5461 + 0.5;
           $5463 = (~~(($5462))&255);
           $5464 = $5463&255;
           $5465 = $5464 << 6;
           $5466 = $5459 | $5465;
           $5467 = $5466&255;
           HEAP8[$5450>>0] = $5467;
           $5468 = (($$085110$us$i$i1675) + 1)|0;
           $5469 = (($$191108$us$i$i1676) + ($5410)|0);
           $5470 = ($5468|0)<($5346|0);
           if ($5470) {
            $$085110$us$i$i1675 = $5468;$$191108$us$i$i1676 = $5469;
           } else {
            break;
           }
          }
         }
        } else {
         $5573 = (+($3|0));
         $5574 = (+($5|0));
         $5575 = $5573 / $5574;
         $5576 = (+($2|0));
         $5577 = (+($4|0));
         $5578 = $5576 / $5577;
         $5579 = (+Math_floor((+$5575)));
         $5580 = (~~(($5579)));
         $5581 = (+($5580|0));
         $5582 = $5575 - $5581;
         $5583 = (+Math_floor((+$5578)));
         $5584 = (~~(($5583)));
         $5585 = (+($5584|0));
         $5586 = $5578 - $5585;
         $5587 = $5578 * $5575;
         $5588 = ($5|0)>(0);
         if ($5588) {
          $5589 = ($4|0)>(0);
          $5590 = ((($13)) + 4|0);
          $5591 = ((($13)) + 8|0);
          $5592 = ((($14)) + 4|0);
          $5593 = ((($14)) + 8|0);
          $5594 = ((($12)) + 4|0);
          $5595 = ((($12)) + 8|0);
          $5596 = ((($12)) + 4|0);
          $5597 = ((($12)) + 8|0);
          $5598 = ((($12)) + 4|0);
          $5599 = ((($12)) + 8|0);
          $5600 = ((($12)) + 4|0);
          $5601 = ((($12)) + 8|0);
          $5602 = ((($12)) + 4|0);
          $5603 = ((($12)) + 8|0);
          $$0374510$i1486 = 0;$$0380509$i1487 = $5582;$$0382508$i1488 = 0.0;$$0391507$i1489 = $5580;$$0393506$i1490 = 0;
          while(1) {
           if ($5589) {
            $5604 = ($$0391507$i1489|0)>($$0393506$i1490|0);
            $5605 = Math_imul($$0393506$i1490, $$0778)|0;
            $5606 = 1.0 - $$0382508$i1488;
            $5607 = Math_imul($$0391507$i1489, $$0778)|0;
            $$0370474$i1492 = (($$0393506$i1490) + 1)|0;
            $5608 = ($$0370474$i1492|0)<($$0391507$i1489|0);
            $5609 = Math_imul($$0370474$i1492, $$0778)|0;
            $5610 = Math_imul($$0374510$i1486, $4)|0;
            $5611 = $$0380509$i1487 - $$0382508$i1488;
            $scevgep$i1493 = (($141) + ($5605)|0);
            $5612 = (($$0391507$i1489) + -1)|0;
            $5613 = Math_imul($5612, $$0778)|0;
            $scevgep537$i1494 = (($141) + ($5613)|0);
            $scevgep555$i1495 = (($141) + ($5607)|0);
            $$0375503$i1497 = 0;$$0383499$i1498 = $5586;$$0385498$i1499 = 0.0;$$0394496$i1500 = $5584;$$0396495$i1501 = 0;
            while(1) {
             $5614 = Math_imul($$0396495$i1501, $$0$i806)|0;
             $5615 = ($$0394496$i1500|0)>($$0396495$i1501|0);
             $or$cond399$i1502 = $5604 & $5615;
             ;HEAP32[$12>>2]=0|0;HEAP32[$12+4>>2]=0|0;HEAP32[$12+8>>2]=0|0;HEAP32[$12+12>>2]=0|0;
             do {
              if ($or$cond399$i1502) {
               $5616 = (($141) + ($5614)|0);
               $5617 = (($5616) + ($5605)|0);
               $5618 = 1.0 - $$0385498$i1499;
               $5619 = $5606 * $5618;
               $5620 = HEAP8[$5617>>0]|0;
               $5621 = $5620&255;
               $5622 = $5621 & 7;
               $5623 = (+($5622|0));
               $5624 = $5623 / 7.0;
               HEAPF32[$13>>2] = $5624;
               $5625 = $5621 >>> 3;
               $5626 = $5625 & 7;
               $5627 = (+($5626|0));
               $5628 = $5627 / 7.0;
               HEAPF32[$5590>>2] = $5628;
               $5629 = $5621 >>> 6;
               $5630 = (+($5629|0));
               $5631 = $5630 / 3.0;
               HEAPF32[$5591>>2] = $5631;
               $5632 = $5619 * $5624;
               $5633 = $5632 + 0.0;
               HEAPF32[$12>>2] = $5633;
               $5634 = $5619 * $5628;
               $5635 = $5634 + 0.0;
               HEAPF32[$5594>>2] = $5635;
               $5636 = $5619 * $5631;
               $5637 = $5636 + 0.0;
               HEAPF32[$5595>>2] = $5637;
               $5638 = (($$0396495$i1501) + 1)|0;
               $5639 = ($5638|0)<($$0394496$i1500|0);
               $5640 = (($5617) + ($$0$i806)|0);
               if ($5639) {
                $$0371448$us$i1508 = $5638;$5642 = $5640;$5656 = $5633;$5659 = $5635;$5662 = $5637;
                while(1) {
                 $5641 = HEAP8[$5642>>0]|0;
                 $5643 = $5641&255;
                 $5644 = $5643 & 7;
                 $5645 = (+($5644|0));
                 $5646 = $5645 / 7.0;
                 HEAPF32[$13>>2] = $5646;
                 $5647 = $5643 >>> 3;
                 $5648 = $5647 & 7;
                 $5649 = (+($5648|0));
                 $5650 = $5649 / 7.0;
                 HEAPF32[$5590>>2] = $5650;
                 $5651 = $5643 >>> 6;
                 $5652 = (+($5651|0));
                 $5653 = $5652 / 3.0;
                 HEAPF32[$5591>>2] = $5653;
                 $5654 = $5606 * $5646;
                 $5655 = $5656 + $5654;
                 HEAPF32[$12>>2] = $5655;
                 $5657 = $5606 * $5650;
                 $5658 = $5659 + $5657;
                 HEAPF32[$5594>>2] = $5658;
                 $5660 = $5606 * $5653;
                 $5661 = $5662 + $5660;
                 HEAPF32[$5595>>2] = $5661;
                 $5663 = (($$0371448$us$i1508) + 1)|0;
                 $5664 = (($5642) + ($$0$i806)|0);
                 $exitcond552$i1512 = ($5663|0)==($$0394496$i1500|0);
                 if ($exitcond552$i1512) {
                  break;
                 } else {
                  $$0371448$us$i1508 = $5663;$5642 = $5664;$5656 = $5655;$5659 = $5658;$5662 = $5661;
                 }
                }
                $5665 = Math_imul($$0394496$i1500, $$0$i806)|0;
                $scevgep551$i1514 = (($scevgep$i1493) + ($5665)|0);
                $$lcssa412$i1516 = $scevgep551$i1514;$5681 = $5655;$5684 = $5658;$5687 = $5661;
               } else {
                $$lcssa412$i1516 = $5640;$5681 = $5633;$5684 = $5635;$5687 = $5637;
               }
               $5666 = $5606 * $$0383499$i1498;
               $5667 = HEAP8[$$lcssa412$i1516>>0]|0;
               $5668 = $5667&255;
               $5669 = $5668 & 7;
               $5670 = (+($5669|0));
               $5671 = $5670 / 7.0;
               $5672 = $5668 >>> 3;
               $5673 = $5672 & 7;
               $5674 = (+($5673|0));
               $5675 = $5674 / 7.0;
               $5676 = $5668 >>> 6;
               $5677 = (+($5676|0));
               $5678 = $5677 / 3.0;
               $5679 = $5666 * $5671;
               $5680 = $5681 + $5679;
               $5682 = $5666 * $5675;
               $5683 = $5684 + $5682;
               $5685 = $5666 * $5678;
               $5686 = $5687 + $5685;
               $5688 = $$0380509$i1487 * $5618;
               $5689 = (($5616) + ($5607)|0);
               $5690 = HEAP8[$5689>>0]|0;
               $5691 = $5690&255;
               $5692 = $5691 & 7;
               $5693 = (+($5692|0));
               $5694 = $5693 / 7.0;
               HEAPF32[$13>>2] = $5694;
               $5695 = $5691 >>> 3;
               $5696 = $5695 & 7;
               $5697 = (+($5696|0));
               $5698 = $5697 / 7.0;
               HEAPF32[$5590>>2] = $5698;
               $5699 = $5691 >>> 6;
               $5700 = (+($5699|0));
               $5701 = $5700 / 3.0;
               HEAPF32[$5591>>2] = $5701;
               $5702 = $5688 * $5694;
               $5703 = $5680 + $5702;
               HEAPF32[$12>>2] = $5703;
               $5704 = $5688 * $5698;
               $5705 = $5683 + $5704;
               HEAPF32[$5594>>2] = $5705;
               $5706 = $5688 * $5701;
               $5707 = $5686 + $5706;
               HEAPF32[$5595>>2] = $5707;
               $5708 = (($5689) + ($$0$i806)|0);
               if ($5639) {
                $$1372464$us$i1524 = $5638;$5710 = $5708;$5724 = $5703;$5727 = $5705;$5730 = $5707;
                while(1) {
                 $5709 = HEAP8[$5710>>0]|0;
                 $5711 = $5709&255;
                 $5712 = $5711 & 7;
                 $5713 = (+($5712|0));
                 $5714 = $5713 / 7.0;
                 HEAPF32[$13>>2] = $5714;
                 $5715 = $5711 >>> 3;
                 $5716 = $5715 & 7;
                 $5717 = (+($5716|0));
                 $5718 = $5717 / 7.0;
                 HEAPF32[$5590>>2] = $5718;
                 $5719 = $5711 >>> 6;
                 $5720 = (+($5719|0));
                 $5721 = $5720 / 3.0;
                 HEAPF32[$5591>>2] = $5721;
                 $5722 = $$0380509$i1487 * $5714;
                 $5723 = $5724 + $5722;
                 HEAPF32[$12>>2] = $5723;
                 $5725 = $$0380509$i1487 * $5718;
                 $5726 = $5727 + $5725;
                 HEAPF32[$5594>>2] = $5726;
                 $5728 = $$0380509$i1487 * $5721;
                 $5729 = $5730 + $5728;
                 HEAPF32[$5595>>2] = $5729;
                 $5731 = (($$1372464$us$i1524) + 1)|0;
                 $5732 = (($5710) + ($$0$i806)|0);
                 $exitcond561$i1528 = ($5731|0)==($$0394496$i1500|0);
                 if ($exitcond561$i1528) {
                  break;
                 } else {
                  $$1372464$us$i1524 = $5731;$5710 = $5732;$5724 = $5723;$5727 = $5726;$5730 = $5729;
                 }
                }
                $5733 = Math_imul($$0394496$i1500, $$0$i806)|0;
                $scevgep560$i1533 = (($scevgep555$i1495) + ($5733)|0);
                $$lcssa413$i1535 = $scevgep560$i1533;$5749 = $5723;$5752 = $5726;$5755 = $5729;
               } else {
                $$lcssa413$i1535 = $5708;$5749 = $5703;$5752 = $5705;$5755 = $5707;
               }
               $5734 = $$0380509$i1487 * $$0383499$i1498;
               $5735 = HEAP8[$$lcssa413$i1535>>0]|0;
               $5736 = $5735&255;
               $5737 = $5736 & 7;
               $5738 = (+($5737|0));
               $5739 = $5738 / 7.0;
               HEAPF32[$13>>2] = $5739;
               $5740 = $5736 >>> 3;
               $5741 = $5740 & 7;
               $5742 = (+($5741|0));
               $5743 = $5742 / 7.0;
               HEAPF32[$5590>>2] = $5743;
               $5744 = $5736 >>> 6;
               $5745 = (+($5744|0));
               $5746 = $5745 / 3.0;
               HEAPF32[$5591>>2] = $5746;
               $5747 = $5734 * $5739;
               $5748 = $5749 + $5747;
               HEAPF32[$12>>2] = $5748;
               $5750 = $5734 * $5743;
               $5751 = $5752 + $5750;
               HEAPF32[$5594>>2] = $5751;
               $5753 = $5734 * $5746;
               $5754 = $5755 + $5753;
               HEAPF32[$5595>>2] = $5754;
               if ($5608) {
                $$0369475$us$i1541 = $5617;$$0370477$us$i1539 = $$0370474$i1492;$$0476$us$i1540 = $$lcssa412$i1516;$5786 = $5748;$5791 = $5751;$5796 = $5754;
               } else {
                $5982 = $5748;$5984 = $5751;$5986 = $5754;
                break;
               }
               while(1) {
                $5756 = (($$0369475$us$i1541) + ($$0778)|0);
                $5757 = (($$0476$us$i1540) + ($$0778)|0);
                $5758 = HEAP8[$5756>>0]|0;
                $5759 = $5758&255;
                $5760 = $5759 & 7;
                $5761 = (+($5760|0));
                $5762 = $5761 / 7.0;
                HEAPF32[$13>>2] = $5762;
                $5763 = $5759 >>> 3;
                $5764 = $5763 & 7;
                $5765 = (+($5764|0));
                $5766 = $5765 / 7.0;
                HEAPF32[$5590>>2] = $5766;
                $5767 = $5759 >>> 6;
                $5768 = (+($5767|0));
                $5769 = $5768 / 3.0;
                HEAPF32[$5591>>2] = $5769;
                $5770 = HEAP8[$5757>>0]|0;
                $5771 = $5770&255;
                $5772 = $5771 & 7;
                $5773 = (+($5772|0));
                $5774 = $5773 / 7.0;
                HEAPF32[$14>>2] = $5774;
                $5775 = $5771 >>> 3;
                $5776 = $5775 & 7;
                $5777 = (+($5776|0));
                $5778 = $5777 / 7.0;
                HEAPF32[$5592>>2] = $5778;
                $5779 = $5771 >>> 6;
                $5780 = (+($5779|0));
                $5781 = $5780 / 3.0;
                HEAPF32[$5593>>2] = $5781;
                $5782 = $5618 * $5762;
                $5783 = $$0383499$i1498 * $5774;
                $5784 = $5782 + $5783;
                $5785 = $5786 + $5784;
                HEAPF32[$12>>2] = $5785;
                $5787 = $5618 * $5766;
                $5788 = $$0383499$i1498 * $5778;
                $5789 = $5787 + $5788;
                $5790 = $5791 + $5789;
                HEAPF32[$5594>>2] = $5790;
                $5792 = $5618 * $5769;
                $5793 = $$0383499$i1498 * $5781;
                $5794 = $5792 + $5793;
                $5795 = $5796 + $5794;
                HEAPF32[$5595>>2] = $5795;
                $$0370$us$i1545 = (($$0370477$us$i1539) + 1)|0;
                $exitcond565$i1546 = ($$0370$us$i1545|0)==($$0391507$i1489|0);
                if ($exitcond565$i1546) {
                 $7066 = $5795;$7067 = $5790;$7068 = $5785;
                 label = 1024;
                 break;
                } else {
                 $$0369475$us$i1541 = $5756;$$0370477$us$i1539 = $$0370$us$i1545;$$0476$us$i1540 = $5757;$5786 = $5785;$5791 = $5790;$5796 = $5795;
                }
               }
              } else {
               if ($5604) {
                $5797 = $$0383499$i1498 - $$0385498$i1499;
                $5798 = $5606 * $5797;
                $5799 = (($141) + ($5614)|0);
                $5800 = (($5799) + ($5605)|0);
                $5801 = HEAP8[$5800>>0]|0;
                $5802 = $5801&255;
                $5803 = $5802 & 7;
                $5804 = (+($5803|0));
                $5805 = $5804 / 7.0;
                HEAPF32[$13>>2] = $5805;
                $5806 = $5802 >>> 3;
                $5807 = $5806 & 7;
                $5808 = (+($5807|0));
                $5809 = $5808 / 7.0;
                HEAPF32[$5590>>2] = $5809;
                $5810 = $5802 >>> 6;
                $5811 = (+($5810|0));
                $5812 = $5811 / 3.0;
                HEAPF32[$5591>>2] = $5812;
                $5813 = $5798 * $5805;
                $5814 = $5813 + 0.0;
                HEAPF32[$12>>2] = $5814;
                $5815 = $5798 * $5809;
                $5816 = $5815 + 0.0;
                HEAPF32[$5598>>2] = $5816;
                $5817 = $5798 * $5812;
                $5818 = $5817 + 0.0;
                HEAPF32[$5599>>2] = $5818;
                if ($5608) {
                 $$1433$us$i1553 = $$0370474$i1492;$$2388432$us$i1554 = $5800;$5834 = $5814;$5837 = $5816;$5840 = $5818;
                 while(1) {
                  $5819 = (($$2388432$us$i1554) + ($$0778)|0);
                  $5820 = HEAP8[$5819>>0]|0;
                  $5821 = $5820&255;
                  $5822 = $5821 & 7;
                  $5823 = (+($5822|0));
                  $5824 = $5823 / 7.0;
                  HEAPF32[$13>>2] = $5824;
                  $5825 = $5821 >>> 3;
                  $5826 = $5825 & 7;
                  $5827 = (+($5826|0));
                  $5828 = $5827 / 7.0;
                  HEAPF32[$5590>>2] = $5828;
                  $5829 = $5821 >>> 6;
                  $5830 = (+($5829|0));
                  $5831 = $5830 / 3.0;
                  HEAPF32[$5591>>2] = $5831;
                  $5832 = $5797 * $5824;
                  $5833 = $5834 + $5832;
                  HEAPF32[$12>>2] = $5833;
                  $5835 = $5797 * $5828;
                  $5836 = $5837 + $5835;
                  HEAPF32[$5598>>2] = $5836;
                  $5838 = $5797 * $5831;
                  $5839 = $5840 + $5838;
                  HEAPF32[$5599>>2] = $5839;
                  $$1$us$i1558 = (($$1433$us$i1553) + 1)|0;
                  $exitcond543$i1559 = ($$1$us$i1558|0)==($$0391507$i1489|0);
                  if ($exitcond543$i1559) {
                   break;
                  } else {
                   $$1433$us$i1553 = $$1$us$i1558;$$2388432$us$i1554 = $5819;$5834 = $5833;$5837 = $5836;$5840 = $5839;
                  }
                 }
                 $scevgep542$i1564 = (($scevgep537$i1494) + ($5614)|0);
                 $$2388$lcssa$i1566 = $scevgep542$i1564;$5857 = $5833;$5860 = $5836;$5863 = $5839;
                } else {
                 $$2388$lcssa$i1566 = $5800;$5857 = $5814;$5860 = $5816;$5863 = $5818;
                }
                $5841 = $$0380509$i1487 * $5797;
                $5842 = (($$2388$lcssa$i1566) + ($$0778)|0);
                $5843 = HEAP8[$5842>>0]|0;
                $5844 = $5843&255;
                $5845 = $5844 & 7;
                $5846 = (+($5845|0));
                $5847 = $5846 / 7.0;
                HEAPF32[$13>>2] = $5847;
                $5848 = $5844 >>> 3;
                $5849 = $5848 & 7;
                $5850 = (+($5849|0));
                $5851 = $5850 / 7.0;
                HEAPF32[$5590>>2] = $5851;
                $5852 = $5844 >>> 6;
                $5853 = (+($5852|0));
                $5854 = $5853 / 3.0;
                HEAPF32[$5591>>2] = $5854;
                $5855 = $5841 * $5847;
                $5856 = $5857 + $5855;
                HEAPF32[$12>>2] = $5856;
                $5858 = $5841 * $5851;
                $5859 = $5860 + $5858;
                HEAPF32[$5598>>2] = $5859;
                $5861 = $5841 * $5854;
                $5862 = $5863 + $5861;
                HEAPF32[$5599>>2] = $5862;
                $7066 = $5862;$7067 = $5859;$7068 = $5856;
                label = 1024;
                break;
               }
               if (!($5615)) {
                $5934 = $$0383499$i1498 - $$0385498$i1499;
                $5935 = $5611 * $5934;
                $5936 = (($141) + ($5614)|0);
                $5937 = (($5936) + ($5605)|0);
                $5938 = HEAP8[$5937>>0]|0;
                $5939 = $5938&255;
                $5940 = $5939 & 7;
                $5941 = (+($5940|0));
                $5942 = $5941 / 7.0;
                HEAPF32[$13>>2] = $5942;
                $5943 = $5939 >>> 3;
                $5944 = $5943 & 7;
                $5945 = (+($5944|0));
                $5946 = $5945 / 7.0;
                HEAPF32[$5590>>2] = $5946;
                $5947 = $5939 >>> 6;
                $5948 = (+($5947|0));
                $5949 = $5948 / 3.0;
                HEAPF32[$5591>>2] = $5949;
                $5950 = $5935 * $5942;
                $5951 = $5950 + 0.0;
                HEAPF32[$12>>2] = $5951;
                $5952 = $5935 * $5946;
                $5953 = $5952 + 0.0;
                HEAPF32[$5602>>2] = $5953;
                $5954 = $5935 * $5949;
                $5955 = $5954 + 0.0;
                HEAPF32[$5603>>2] = $5955;
                $7066 = $5955;$7067 = $5953;$7068 = $5951;
                label = 1024;
                break;
               }
               $5864 = 1.0 - $$0385498$i1499;
               $5865 = $5611 * $5864;
               $5866 = (($141) + ($5614)|0);
               $5867 = (($5866) + ($5605)|0);
               $5868 = HEAP8[$5867>>0]|0;
               $5869 = $5868&255;
               $5870 = $5869 & 7;
               $5871 = (+($5870|0));
               $5872 = $5871 / 7.0;
               HEAPF32[$13>>2] = $5872;
               $5873 = $5869 >>> 3;
               $5874 = $5873 & 7;
               $5875 = (+($5874|0));
               $5876 = $5875 / 7.0;
               HEAPF32[$5590>>2] = $5876;
               $5877 = $5869 >>> 6;
               $5878 = (+($5877|0));
               $5879 = $5878 / 3.0;
               HEAPF32[$5591>>2] = $5879;
               $5880 = $5865 * $5872;
               $5881 = $5880 + 0.0;
               HEAPF32[$12>>2] = $5881;
               $5882 = $5865 * $5876;
               $5883 = $5882 + 0.0;
               HEAPF32[$5600>>2] = $5883;
               $5884 = $5865 * $5879;
               $5885 = $5884 + 0.0;
               HEAPF32[$5601>>2] = $5885;
               $$2373419$i1571 = (($$0396495$i1501) + 1)|0;
               $5886 = ($$2373419$i1571|0)<($$0394496$i1500|0);
               $5887 = (($5867) + ($$0$i806)|0);
               if ($5886) {
                $$2373420$us$i1574 = $$2373419$i1571;$5889 = $5887;$5903 = $5881;$5906 = $5883;$5909 = $5885;
                while(1) {
                 $5888 = HEAP8[$5889>>0]|0;
                 $5890 = $5888&255;
                 $5891 = $5890 & 7;
                 $5892 = (+($5891|0));
                 $5893 = $5892 / 7.0;
                 HEAPF32[$13>>2] = $5893;
                 $5894 = $5890 >>> 3;
                 $5895 = $5894 & 7;
                 $5896 = (+($5895|0));
                 $5897 = $5896 / 7.0;
                 HEAPF32[$5590>>2] = $5897;
                 $5898 = $5890 >>> 6;
                 $5899 = (+($5898|0));
                 $5900 = $5899 / 3.0;
                 HEAPF32[$5591>>2] = $5900;
                 $5901 = $5611 * $5893;
                 $5902 = $5903 + $5901;
                 HEAPF32[$12>>2] = $5902;
                 $5904 = $5611 * $5897;
                 $5905 = $5906 + $5904;
                 HEAPF32[$5600>>2] = $5905;
                 $5907 = $5611 * $5900;
                 $5908 = $5909 + $5907;
                 HEAPF32[$5601>>2] = $5908;
                 $$2373$us$i1578 = (($$2373420$us$i1574) + 1)|0;
                 $5910 = (($5889) + ($$0$i806)|0);
                 $exitcond534$i1579 = ($$2373$us$i1578|0)==($$0394496$i1500|0);
                 if ($exitcond534$i1579) {
                  break;
                 } else {
                  $$2373420$us$i1574 = $$2373$us$i1578;$5889 = $5910;$5903 = $5902;$5906 = $5905;$5909 = $5908;
                 }
                }
                $5911 = Math_imul($$0394496$i1500, $$0$i806)|0;
                $scevgep533$i1584 = (($scevgep$i1493) + ($5911)|0);
                $$lcssa$i1586 = $scevgep533$i1584;$5927 = $5902;$5930 = $5905;$5933 = $5908;
               } else {
                $$lcssa$i1586 = $5887;$5927 = $5881;$5930 = $5883;$5933 = $5885;
               }
               $5912 = $5611 * $$0383499$i1498;
               $5913 = HEAP8[$$lcssa$i1586>>0]|0;
               $5914 = $5913&255;
               $5915 = $5914 & 7;
               $5916 = (+($5915|0));
               $5917 = $5916 / 7.0;
               HEAPF32[$13>>2] = $5917;
               $5918 = $5914 >>> 3;
               $5919 = $5918 & 7;
               $5920 = (+($5919|0));
               $5921 = $5920 / 7.0;
               HEAPF32[$5590>>2] = $5921;
               $5922 = $5914 >>> 6;
               $5923 = (+($5922|0));
               $5924 = $5923 / 3.0;
               HEAPF32[$5591>>2] = $5924;
               $5925 = $5912 * $5917;
               $5926 = $5927 + $5925;
               HEAPF32[$12>>2] = $5926;
               $5928 = $5912 * $5921;
               $5929 = $5930 + $5928;
               HEAPF32[$5600>>2] = $5929;
               $5931 = $5912 * $5924;
               $5932 = $5933 + $5931;
               HEAPF32[$5601>>2] = $5932;
               $7066 = $5932;$7067 = $5929;$7068 = $5926;
               label = 1024;
              }
             } while(0);
             do {
              if ((label|0) == 1024) {
               label = 0;
               if (!($5608)) {
                $5982 = $7068;$5984 = $7067;$5986 = $7066;
                break;
               }
               $$3483$i1595 = (($$0396495$i1501) + 1)|0;
               $5956 = ($$3483$i1595|0)<($$0394496$i1500|0);
               if (!($5956)) {
                $5982 = $7068;$5984 = $7067;$5986 = $7066;
                break;
               }
               $5957 = (($141) + ($5614)|0);
               $5958 = (($5957) + ($$0$i806)|0);
               $5959 = (($5958) + ($5609)|0);
               $$0397488$i1598$us = $5959;$$2489$i1597$us = $$0370474$i1492;$7069 = $7066;$7070 = $7067;$7071 = $7068;
               while(1) {
                $$3485$us$i1601$us = $$3483$i1595;$$4390484$us$i1602$us = $$0397488$i1598$us;$5973 = $7071;$5975 = $7070;$5977 = $7069;
                while(1) {
                 $5960 = HEAP8[$$4390484$us$i1602$us>>0]|0;
                 $5961 = $5960&255;
                 $5962 = $5961 & 7;
                 $5963 = (+($5962|0));
                 $5964 = $5963 / 7.0;
                 HEAPF32[$13>>2] = $5964;
                 $5965 = $5961 >>> 3;
                 $5966 = $5965 & 7;
                 $5967 = (+($5966|0));
                 $5968 = $5967 / 7.0;
                 HEAPF32[$5590>>2] = $5968;
                 $5969 = $5961 >>> 6;
                 $5970 = (+($5969|0));
                 $5971 = $5970 / 3.0;
                 HEAPF32[$5591>>2] = $5971;
                 $5972 = $5964 + $5973;
                 HEAPF32[$12>>2] = $5972;
                 $5974 = $5968 + $5975;
                 HEAPF32[$5596>>2] = $5974;
                 $5976 = $5971 + $5977;
                 HEAPF32[$5597>>2] = $5976;
                 $5978 = (($$4390484$us$i1602$us) + ($$0$i806)|0);
                 $$3$us$i1606$us = (($$3485$us$i1601$us) + 1)|0;
                 $exitcond568$i1607$us = ($$3$us$i1606$us|0)==($$0394496$i1500|0);
                 if ($exitcond568$i1607$us) {
                  break;
                 } else {
                  $$3485$us$i1601$us = $$3$us$i1606$us;$$4390484$us$i1602$us = $5978;$5973 = $5972;$5975 = $5974;$5977 = $5976;
                 }
                }
                $5979 = (($$0397488$i1598$us) + ($$0778)|0);
                $5980 = (($$2489$i1597$us) + 1)|0;
                $exitcond569$i1609$us = ($5980|0)==($$0391507$i1489|0);
                if ($exitcond569$i1609$us) {
                 $5982 = $5972;$5984 = $5974;$5986 = $5976;
                 break;
                } else {
                 $$0397488$i1598$us = $5979;$$2489$i1597$us = $5980;$7069 = $5976;$7070 = $5974;$7071 = $5972;
                }
               }
              }
             } while(0);
             $5981 = $5982 / $5587;
             $5983 = $5984 / $5587;
             $5985 = $5986 / $5587;
             $5987 = (($$0375503$i1497) + ($5610))|0;
             $5988 = $5981;
             $5989 = $5988 * 7.0;
             $5990 = $5989 + 0.5;
             $5991 = (~~(($5990))&255);
             $5992 = $5991 & 7;
             $5993 = (($1241) + ($5987)|0);
             $5994 = $5983;
             $5995 = $5994 * 7.0;
             $5996 = $5995 + 0.5;
             $5997 = (~~(($5996))&255);
             $5998 = $5997&255;
             $5999 = $5998 << 3;
             $6000 = $5999 & 56;
             $6001 = $5992&255;
             $6002 = $6000 | $6001;
             $6003 = $5985;
             $6004 = $6003 * 3.0;
             $6005 = $6004 + 0.5;
             $6006 = (~~(($6005))&255);
             $6007 = $6006&255;
             $6008 = $6007 << 6;
             $6009 = $6002 | $6008;
             $6010 = $6009&255;
             HEAP8[$5993>>0] = $6010;
             $6011 = (($$0394496$i1500) + ($5584))|0;
             $6012 = $5586 + $$0383499$i1498;
             $6013 = $6012 > 1.0;
             $6014 = $6012 + -1.0;
             $6015 = $6013&1;
             $$1395$i1615 = (($6011) + ($6015))|0;
             $$1384$i1616 = $6013 ? $6014 : $6012;
             $6016 = (($$0375503$i1497) + 1)|0;
             $exitcond571$i1617 = ($6016|0)==($4|0);
             if ($exitcond571$i1617) {
              break;
             } else {
              $$0396495$i1501$phi = $$0394496$i1500;$$0385498$i1499$phi = $$0383499$i1498;$$0375503$i1497 = $6016;$$0383499$i1498 = $$1384$i1616;$$0394496$i1500 = $$1395$i1615;$$0396495$i1501 = $$0396495$i1501$phi;$$0385498$i1499 = $$0385498$i1499$phi;
             }
            }
           }
           $6017 = (($$0391507$i1489) + ($5580))|0;
           $6018 = $5582 + $$0380509$i1487;
           $6019 = $6018 > 1.0;
           $6020 = $6018 + -1.0;
           $6021 = $6019&1;
           $$1392$i1619 = (($6017) + ($6021))|0;
           $$1381$i1620 = $6019 ? $6020 : $6018;
           $6022 = (($$0374510$i1486) + 1)|0;
           $exitcond572$i1621 = ($6022|0)==($5|0);
           if ($exitcond572$i1621) {
            break;
           } else {
            $$0393506$i1490$phi = $$0391507$i1489;$$0382508$i1488$phi = $$0380509$i1487;$$0374510$i1486 = $6022;$$0380509$i1487 = $$1381$i1620;$$0391507$i1489 = $$1392$i1619;$$0393506$i1490 = $$0393506$i1490$phi;$$0382508$i1488 = $$0382508$i1488$phi;
           }
          }
         }
        }
       } while(0);
       break L470;
       break;
      }
      case 33635:  {
       __ZN3osgL24scaleInternalPackedPixelEiPFviPKvPfEPFvPKfiPvEiiS1_iiS7_iii(3,4023,4024,$2,$3,$141,$4,$5,$1241,$$0$i806,$$0778,$$785);
       break L470;
       break;
      }
      case 33636:  {
       __ZN3osgL24scaleInternalPackedPixelEiPFviPKvPfEPFvPKfiPvEiiS1_iiS7_iii(3,4025,4026,$2,$3,$141,$4,$5,$1241,$$0$i806,$$0778,$$785);
       break L470;
       break;
      }
      case 33637:  {
       __ZN3osgL24scaleInternalPackedPixelEiPFviPKvPfEPFvPKfiPvEiiS1_iiS7_iii(4,4009,4010,$2,$3,$141,$4,$5,$1241,$$0$i806,$$0778,$$785);
       break L470;
       break;
      }
      case 32820:  {
       __ZN3osgL24scaleInternalPackedPixelEiPFviPKvPfEPFvPKfiPvEiiS1_iiS7_iii(4,4011,4012,$2,$3,$141,$4,$5,$1241,$$0$i806,$$0778,$$785);
       break L470;
       break;
      }
      case 33638:  {
       __ZN3osgL24scaleInternalPackedPixelEiPFviPKvPfEPFvPKfiPvEiiS1_iiS7_iii(4,4013,4014,$2,$3,$141,$4,$5,$1241,$$0$i806,$$0778,$$785);
       break L470;
       break;
      }
      case 32821:  {
       __ZN3osgL24scaleInternalPackedPixelEiPFviPKvPfEPFvPKfiPvEiiS1_iiS7_iii(4,4015,4016,$2,$3,$141,$4,$5,$1241,$$0$i806,$$0778,$$785);
       break L470;
       break;
      }
      case 33639:  {
       __ZN3osgL24scaleInternalPackedPixelEiPFviPKvPfEPFvPKfiPvEiiS1_iiS7_iii(4,4017,4018,$2,$3,$141,$4,$5,$1241,$$0$i806,$$0778,$$785);
       break L470;
       break;
      }
      case 32822:  {
       __ZN3osgL24scaleInternalPackedPixelEiPFviPKvPfEPFvPKfiPvEiiS1_iiS7_iii(4,4019,4020,$2,$3,$141,$4,$5,$1241,$$0$i806,$$0778,$$785);
       break L470;
       break;
      }
      case 33640:  {
       __ZN3osgL24scaleInternalPackedPixelEiPFviPKvPfEPFvPKfiPvEiiS1_iiS7_iii(4,4021,4022,$2,$3,$141,$4,$5,$1241,$$0$i806,$$0778,$$785);
       break L470;
       break;
      }
      default: {
       break L470;
      }
      }
     } while(0);
    }
   } while(0);
   $6023 = Math_imul($126, $4)|0;
   $6024 = ($121|0)==(0);
   if ($6024) {
    $$0762 = $8;$$0767 = $1241;$$1755 = $4;$$1759 = $5;$$1779 = $6023;$$5 = 0;
   } else {
    $6025 = (($4|0) / 2)&-1;
    $6026 = (($5|0) / 2)&-1;
    $6027 = ($4|0)<(2);
    $$789 = $6027 ? 1 : $6025;
    $6028 = ($5|0)<(2);
    $$0764 = $6028 ? 1 : $6026;
    L1758: do {
     switch ($7|0) {
     case 32818: case 32819: case 32820: case 32821: case 32822: case 33634: case 33635: case 33636: case 33637: case 33638: case 33639: case 33640:  {
      $$0$i14$i1626 = 1;
      break;
     }
     default: {
      $switch$split422D = ($6|0)<(6410);
      L1760: do {
       if ($switch$split422D) {
        switch ($6|0) {
        case 6407:  {
         $$0$i14$i1626 = 3;
         break L1758;
         break;
        }
        case 6408:  {
         label = 1047;
         break;
        }
        default: {
         label = 1048;
        }
        }
       } else {
        $switch$split902D = ($6|0)<(32992);
        if (!($switch$split902D)) {
         switch ($6|0) {
         case 32992:  {
          $$0$i14$i1626 = 3;
          break L1758;
          break;
         }
         case 32993:  {
          label = 1047;
          break L1760;
          break;
         }
         default: {
          label = 1048;
          break L1760;
         }
         }
        }
        switch ($6|0) {
        case 6410:  {
         break;
        }
        default: {
         label = 1048;
         break L1760;
        }
        }
        $$0$i14$i1626 = 2;
        break L1758;
       }
      } while(0);
      if ((label|0) == 1047) {
       $$0$i14$i1626 = 4;
       break L1758;
      }
      else if ((label|0) == 1048) {
       $$0$i14$i1626 = 1;
       break L1758;
      }
     }
     }
    } while(0);
    $switch$split452D = ($7|0)<(32820);
    L1771: do {
     if ($switch$split452D) {
      $switch$split932D = ($7|0)<(5125);
      L1773: do {
       if ($switch$split932D) {
        switch ($7|0) {
        case 5122: case 5123:  {
         $$0$i12$i1628$ph = 2.0;
         break L1773;
         break;
        }
        case 5121:  {
         $$0$i12$i1628$ph = 1.0;
         break L1773;
         break;
        }
        case 5120:  {
         $$0$i12$i1628$ph = 1.0;
         break L1773;
         break;
        }
        case 5124:  {
         $$0$i12$i1628$ph = 4.0;
         break L1773;
         break;
        }
        default: {
         label = 1057;
         break L1771;
        }
        }
       } else {
        $switch$split1172D = ($7|0)<(6656);
        if ($switch$split1172D) {
         switch ($7|0) {
         case 5125:  {
          $$0$i12$i1628$ph = 4.0;
          break L1773;
          break;
         }
         case 5126:  {
          $$0$i12$i1628$ph = 4.0;
          break L1773;
          break;
         }
         default: {
          label = 1057;
          break L1771;
         }
         }
        }
        $switch$split1412D = ($7|0)<(32818);
        if (!($switch$split1412D)) {
         switch ($7|0) {
         case 32818:  {
          $$0$i12$i1628 = 1.0;
          label = 1059;
          break L1771;
          break;
         }
         case 32819:  {
          label = 1055;
          break L1771;
          break;
         }
         default: {
          label = 1057;
          break L1771;
         }
         }
        }
        switch ($7|0) {
        case 6656:  {
         $$4 = 100900;
         break;
        }
        default: {
         label = 1057;
         break L1771;
        }
        }
        STACKTOP = sp;return ($$4|0);
       }
      } while(0);
      $6029 = (+($$789|0));
      $6030 = $6029 * $$0$i12$i1628$ph;
      $6031 = (~~(($6030))>>>0);
      $6032 = Math_imul($$0$i14$i1626, $$0764)|0;
      $6033 = Math_imul($6032, $6031)|0;
      $6039 = $6033;
     } else {
      switch ($7|0) {
      case 33634:  {
       $$0$i12$i1628 = 1.0;
       label = 1059;
       break L1771;
       break;
      }
      case 33638: case 32820: case 33637: case 33636: case 33635:  {
       label = 1055;
       break L1771;
       break;
      }
      case 33640: case 32822: case 33639: case 32821:  {
       break;
      }
      default: {
       label = 1057;
       break L1771;
      }
      }
      $$0$i12$i1628 = 4.0;
      label = 1059;
     }
    } while(0);
    if ((label|0) == 1055) {
     $$0$i12$i1628 = 2.0;
     label = 1059;
    }
    else if ((label|0) == 1057) {
     $$0$i12$i1628 = 4.0;
     label = 1059;
    }
    L1796: do {
     if ((label|0) == 1059) {
      $6034 = (+($$789|0));
      $6035 = $6034 * $$0$i12$i1628;
      $6036 = (~~(($6035))>>>0);
      $6037 = Math_imul($$0$i14$i1626, $$0764)|0;
      $6038 = Math_imul($6037, $6036)|0;
      switch ($7|0) {
      case 32819: case 33636: case 33635: case 33634: case 32818: case 33640: case 32822: case 33639: case 32821: case 33638: case 32820: case 33637:  {
       $6039 = $6038;
       break L1796;
       break;
      }
      default: {
       $$4 = 100900;
      }
      }
      STACKTOP = sp;return ($$4|0);
     }
    } while(0);
    $6040 = (_malloc($6039)|0);
    $6041 = ($6040|0)==(0|0);
    if ($6041) {
     $6042 = HEAP32[$19>>2]|0;
     _glPixelStorei(3317,($6042|0));
     _free($1241);
     $$4 = 100902;
     STACKTOP = sp;return ($$4|0);
    } else {
     $$0762 = $8;$$0767 = $1241;$$1755 = $4;$$1759 = $5;$$1779 = $6023;$$5 = $6040;
    }
   }
  }
 } while(0);
 $6043 = ($$0762|0)<($9|0);
 $6044 = ($$0762|0)>($10|0);
 $or$cond790 = $6043 | $6044;
 if (!($or$cond790)) {
  _glTexImage2D(($0|0),($$0762|0),($1|0),($$1755|0),($$1759|0),0,($6|0),($7|0),($$0767|0));
 }
 $6045 = ($$0762|0)<($121|0);
 L1806: do {
  if ($6045) {
   $6046 = $$0$i806 << 1;
   $6047 = ((($12)) + 4|0);
   $6048 = ((($12)) + 8|0);
   $6049 = ((($13)) + 4|0);
   $6050 = ((($13)) + 8|0);
   $6051 = ((($14)) + 4|0);
   $6052 = ((($14)) + 8|0);
   $$17632034$in = $$0762;$$17682030 = $$0767;$$27562033 = $$1755;$$27602032 = $$1759;$$27802028 = $$1779;$$62029 = $$5;
   while(1) {
    $$17632034 = (($$17632034$in) + 1)|0;
    $switch$split482D = ($7|0)<(32820);
    L1810: do {
     if ($switch$split482D) {
      $switch$split962D = ($7|0)<(5124);
      if ($switch$split962D) {
       switch ($7|0) {
       case 5121:  {
        __ZN3osgL16halveImage_ubyteEijjPKhPhiii($$0$i805,$$27562033,$$27602032,$$17682030,$$62029,$$0$i806,$$27802028,$126);
        label = 1134;
        break L1810;
        break;
       }
       case 5120:  {
        __ZN3osgL15halveImage_byteEijjPKaPaiii($$0$i805,$$27562033,$$27602032,$$17682030,$$62029,$$0$i806,$$27802028,$126);
        label = 1134;
        break L1810;
        break;
       }
       case 5123:  {
        __ZN3osgL17halveImage_ushortEijjPKtPtiiii($$0$i805,$$27562033,$$27602032,$$17682030,$$62029,$$0$i806,$$27802028,$126,0);
        label = 1134;
        break L1810;
        break;
       }
       case 5122:  {
        __ZN3osgL16halveImage_shortEijjPKsPsiiii($$0$i805,$$27562033,$$27602032,$$17682030,$$62029,$$0$i806,$$27802028,$126,0);
        label = 1134;
        break L1810;
        break;
       }
       default: {
        label = 1134;
        break L1810;
       }
       }
      }
      $switch$split1202D = ($7|0)<(5126);
      if ($switch$split1202D) {
       switch ($7|0) {
       case 5125:  {
        __ZN3osgL15halveImage_uintEijjPKjPjiiii($$0$i805,$$27562033,$$27602032,$$17682030,$$62029,$$0$i806,$$27802028,$126,0);
        label = 1134;
        break L1810;
        break;
       }
       case 5124:  {
        __ZN3osgL14halveImage_intEijjPKiPiiiii($$0$i805,$$27562033,$$27602032,$$17682030,$$62029,$$0$i806,$$27802028,$126,0);
        label = 1134;
        break L1810;
        break;
       }
       default: {
        label = 1134;
        break L1810;
       }
       }
      }
      $switch$split1442D = ($7|0)<(32818);
      if ($switch$split1442D) {
       switch ($7|0) {
       case 5126:  {
        break;
       }
       default: {
        label = 1134;
        break L1810;
       }
       }
       __ZN3osgL16halveImage_floatEijjPKfPfiiii($$0$i805,$$27562033,$$27602032,$$17682030,$$62029,$$0$i806,$$27802028,$126,0);
       label = 1134;
       break;
      }
      switch ($7|0) {
      case 32818:  {
       break;
      }
      case 32819:  {
       __ZN3osgL21halveImagePackedPixelEiPFviPKvPfEPFvPKfiPvEiiS1_S7_iii(4,4007,4008,$$27562033,$$27602032,$$17682030,$$62029,$$0$i806,$$27802028,0);
       label = 1134;
       break L1810;
       break;
      }
      default: {
       label = 1134;
       break L1810;
      }
      }
      $6053 = ($$27562033|0)==(1);
      $6054 = ($$27602032|0)==(1);
      $or$cond$i1633 = $6054 | $6053;
      $6055 = (($$27562033|0) / 2)&-1;
      $6056 = (($$27602032|0) / 2)&-1;
      if (!($or$cond$i1633)) {
       $6188 = Math_imul($$27562033, $$0$i806)|0;
       $6189 = (($$27802028) - ($6188))|0;
       $6190 = ($$27602032|0)>(1);
       if (!($6190)) {
        label = 1134;
        break;
       }
       $6191 = ($$27562033|0)>(1);
       if ($6191) {
        $$07999$us$i1651 = 0;$$08098$us$i1652 = 0;$$08197$us$i1653 = $$17682030;
       } else {
        $$3757 = $$27562033;$$3781 = $$27802028;
        break;
       }
       while(1) {
        $$08391$us$us$i1658 = 0;$$18292$us$us$i1657 = $$08197$us$i1653;$$193$us$us$i1656 = $$07999$us$i1651;
        while(1) {
         $6197 = HEAP8[$$18292$us$us$i1657>>0]|0;
         $6198 = $6197&255;
         $6199 = $6198 >>> 5;
         $6200 = (+($6199|0));
         $6201 = $6200 / 7.0;
         $6202 = $6198 >>> 2;
         $6203 = $6202 & 7;
         $6204 = (+($6203|0));
         $6205 = $6204 / 7.0;
         $6206 = $6198 & 3;
         $6207 = (+($6206|0));
         $6208 = $6207 / 3.0;
         $6209 = (($$18292$us$us$i1657) + ($$0$i806)|0);
         $6210 = HEAP8[$6209>>0]|0;
         $6211 = $6210&255;
         $6212 = $6211 >>> 5;
         $6213 = (+($6212|0));
         $6214 = $6213 / 7.0;
         $6215 = $6211 >>> 2;
         $6216 = $6215 & 7;
         $6217 = (+($6216|0));
         $6218 = $6217 / 7.0;
         $6219 = $6211 & 3;
         $6220 = (+($6219|0));
         $6221 = $6220 / 3.0;
         $6222 = (($$18292$us$us$i1657) + ($$27802028)|0);
         $6223 = HEAP8[$6222>>0]|0;
         $6224 = $6223&255;
         $6225 = $6224 >>> 5;
         $6226 = (+($6225|0));
         $6227 = $6226 / 7.0;
         $6228 = $6224 >>> 2;
         $6229 = $6228 & 7;
         $6230 = (+($6229|0));
         $6231 = $6230 / 7.0;
         $6232 = $6224 & 3;
         $6233 = (+($6232|0));
         $6234 = $6233 / 3.0;
         $6235 = (($6222) + ($$0$i806)|0);
         $6236 = HEAP8[$6235>>0]|0;
         $6237 = $6236&255;
         $6238 = $6237 >>> 5;
         $6239 = (+($6238|0));
         $6240 = $6239 / 7.0;
         $6241 = $6237 >>> 2;
         $6242 = $6241 & 7;
         $6243 = (+($6242|0));
         $6244 = $6243 / 7.0;
         $6245 = $6237 & 3;
         $6246 = (+($6245|0));
         $6247 = $6246 / 3.0;
         $6248 = $6201 + 0.0;
         $6249 = $6248 + $6214;
         $6250 = $6249 + $6227;
         $6251 = $6250 + $6240;
         $6252 = $6251 * 0.25;
         HEAPF32[$14>>2] = $6252;
         $6253 = $6205 + 0.0;
         $6254 = $6253 + $6218;
         $6255 = $6254 + $6231;
         $6256 = $6255 + $6244;
         $6257 = $6256 * 0.25;
         HEAPF32[$6051>>2] = $6257;
         $6258 = $6208 + 0.0;
         $6259 = $6258 + $6221;
         $6260 = $6259 + $6234;
         $6261 = $6260 + $6247;
         $6262 = $6261 * 0.25;
         HEAPF32[$6052>>2] = $6262;
         $6263 = $6252 * 7.0;
         $6264 = $6263;
         $6265 = $6264 + 0.5;
         $6266 = (~~(($6265))&255);
         $6267 = $6266&255;
         $6268 = $6267 << 5;
         $6269 = $6268&255;
         $6270 = (($$62029) + ($$193$us$us$i1656)|0);
         HEAP8[$6270>>0] = $6269;
         $6271 = +HEAPF32[$6051>>2];
         $6272 = $6271 * 7.0;
         $6273 = $6272;
         $6274 = $6273 + 0.5;
         $6275 = (~~(($6274))&255);
         $6276 = $6275&255;
         $6277 = $6276 << 2;
         $6278 = $6277 & 28;
         $6279 = $6278 | $6268;
         $6280 = $6279&255;
         HEAP8[$6270>>0] = $6280;
         $6281 = +HEAPF32[$6052>>2];
         $6282 = $6281 * 3.0;
         $6283 = $6282;
         $6284 = $6283 + 0.5;
         $6285 = (~~(($6284))&255);
         $6286 = $6285 & 3;
         $6287 = $6286&255;
         $6288 = $6279 | $6287;
         $6289 = $6288&255;
         HEAP8[$6270>>0] = $6289;
         $6290 = (($$193$us$us$i1656) + 1)|0;
         $6193 = (($$18292$us$us$i1657) + ($6046)|0);
         $6291 = (($$08391$us$us$i1658) + 1)|0;
         $6292 = ($6291|0)<($6055|0);
         if ($6292) {
          $$08391$us$us$i1658 = $6291;$$18292$us$us$i1657 = $6193;$$193$us$us$i1656 = $6290;
         } else {
          break;
         }
        }
        $6192 = (($6193) + ($6189)|0);
        $6194 = (($6192) + ($$27802028)|0);
        $6195 = (($$08098$us$i1652) + 1)|0;
        $6196 = ($6195|0)<($6056|0);
        if ($6196) {
         $$07999$us$i1651 = $6290;$$08098$us$i1652 = $6195;$$08197$us$i1653 = $6194;
        } else {
         label = 1134;
         break L1810;
        }
       }
      }
      if ($6054) {
       $6057 = ($$27562033|0)>(1);
       if ($6057) {
        $$088100$us$i$i1636 = 0;$$09098$us$i$i1637 = $$17682030;
       } else {
        $$3757 = $$27562033;$$3781 = $$27802028;
        break;
       }
       while(1) {
        $6058 = HEAP8[$$09098$us$i$i1637>>0]|0;
        $6059 = $6058&255;
        $6060 = $6059 >>> 5;
        $6061 = (+($6060|0));
        $6062 = $6061 / 7.0;
        $6063 = $6059 >>> 2;
        $6064 = $6063 & 7;
        $6065 = (+($6064|0));
        $6066 = $6065 / 7.0;
        $6067 = $6059 & 3;
        $6068 = (+($6067|0));
        $6069 = $6068 / 3.0;
        $6070 = (($$09098$us$i$i1637) + ($$0$i806)|0);
        $6071 = HEAP8[$6070>>0]|0;
        $6072 = $6071&255;
        $6073 = $6072 >>> 5;
        $6074 = (+($6073|0));
        $6075 = $6074 / 7.0;
        $6076 = $6072 >>> 2;
        $6077 = $6076 & 7;
        $6078 = (+($6077|0));
        $6079 = $6078 / 7.0;
        $6080 = $6072 & 3;
        $6081 = (+($6080|0));
        $6082 = $6081 / 3.0;
        $6083 = $6062 + 0.0;
        $6084 = $6083 + $6075;
        $6085 = $6084 * 0.5;
        HEAPF32[$12>>2] = $6085;
        $6086 = $6066 + 0.0;
        $6087 = $6086 + $6079;
        $6088 = $6087 * 0.5;
        HEAPF32[$6047>>2] = $6088;
        $6089 = $6069 + 0.0;
        $6090 = $6089 + $6082;
        $6091 = $6090 * 0.5;
        HEAPF32[$6048>>2] = $6091;
        $6092 = $6085 * 7.0;
        $6093 = $6092;
        $6094 = $6093 + 0.5;
        $6095 = (~~(($6094))&255);
        $6096 = $6095&255;
        $6097 = $6096 << 5;
        $6098 = $6097&255;
        $6099 = (($$62029) + ($$088100$us$i$i1636)|0);
        HEAP8[$6099>>0] = $6098;
        $6100 = +HEAPF32[$6047>>2];
        $6101 = $6100 * 7.0;
        $6102 = $6101;
        $6103 = $6102 + 0.5;
        $6104 = (~~(($6103))&255);
        $6105 = $6104&255;
        $6106 = $6105 << 2;
        $6107 = $6106 & 28;
        $6108 = $6107 | $6097;
        $6109 = $6108&255;
        HEAP8[$6099>>0] = $6109;
        $6110 = +HEAPF32[$6048>>2];
        $6111 = $6110 * 3.0;
        $6112 = $6111;
        $6113 = $6112 + 0.5;
        $6114 = (~~(($6113))&255);
        $6115 = $6114 & 3;
        $6116 = $6115&255;
        $6117 = $6108 | $6116;
        $6118 = $6117&255;
        HEAP8[$6099>>0] = $6118;
        $6119 = (($$088100$us$i$i1636) + 1)|0;
        $6120 = (($$09098$us$i$i1637) + ($6046)|0);
        $6121 = ($6119|0)<($6055|0);
        if ($6121) {
         $$088100$us$i$i1636 = $6119;$$09098$us$i$i1637 = $6120;
        } else {
         label = 1134;
         break L1810;
        }
       }
      }
      $6122 = ($$27602032|0)>(1);
      $or$cond$i$i1642 = $6122 & $6053;
      if ($or$cond$i$i1642) {
       $6123 = $$27802028 << 1;
       $$085110$us$i$i1644 = 0;$$191108$us$i$i1645 = $$17682030;
       while(1) {
        $6124 = HEAP8[$$191108$us$i$i1645>>0]|0;
        $6125 = $6124&255;
        $6126 = $6125 >>> 5;
        $6127 = (+($6126|0));
        $6128 = $6127 / 7.0;
        $6129 = $6125 >>> 2;
        $6130 = $6129 & 7;
        $6131 = (+($6130|0));
        $6132 = $6131 / 7.0;
        $6133 = $6125 & 3;
        $6134 = (+($6133|0));
        $6135 = $6134 / 3.0;
        $6136 = (($$191108$us$i$i1645) + ($$27802028)|0);
        $6137 = HEAP8[$6136>>0]|0;
        $6138 = $6137&255;
        $6139 = $6138 >>> 5;
        $6140 = (+($6139|0));
        $6141 = $6140 / 7.0;
        $6142 = $6138 >>> 2;
        $6143 = $6142 & 7;
        $6144 = (+($6143|0));
        $6145 = $6144 / 7.0;
        $6146 = $6138 & 3;
        $6147 = (+($6146|0));
        $6148 = $6147 / 3.0;
        $6149 = $6128 + 0.0;
        $6150 = $6149 + $6141;
        $6151 = $6150 * 0.5;
        HEAPF32[$13>>2] = $6151;
        $6152 = $6132 + 0.0;
        $6153 = $6152 + $6145;
        $6154 = $6153 * 0.5;
        HEAPF32[$6049>>2] = $6154;
        $6155 = $6135 + 0.0;
        $6156 = $6155 + $6148;
        $6157 = $6156 * 0.5;
        HEAPF32[$6050>>2] = $6157;
        $6158 = $6151 * 7.0;
        $6159 = $6158;
        $6160 = $6159 + 0.5;
        $6161 = (~~(($6160))&255);
        $6162 = $6161&255;
        $6163 = $6162 << 5;
        $6164 = $6163&255;
        $6165 = (($$62029) + ($$085110$us$i$i1644)|0);
        HEAP8[$6165>>0] = $6164;
        $6166 = +HEAPF32[$6049>>2];
        $6167 = $6166 * 7.0;
        $6168 = $6167;
        $6169 = $6168 + 0.5;
        $6170 = (~~(($6169))&255);
        $6171 = $6170&255;
        $6172 = $6171 << 2;
        $6173 = $6172 & 28;
        $6174 = $6173 | $6163;
        $6175 = $6174&255;
        HEAP8[$6165>>0] = $6175;
        $6176 = +HEAPF32[$6050>>2];
        $6177 = $6176 * 3.0;
        $6178 = $6177;
        $6179 = $6178 + 0.5;
        $6180 = (~~(($6179))&255);
        $6181 = $6180 & 3;
        $6182 = $6181&255;
        $6183 = $6174 | $6182;
        $6184 = $6183&255;
        HEAP8[$6165>>0] = $6184;
        $6185 = (($$085110$us$i$i1644) + 1)|0;
        $6186 = (($$191108$us$i$i1645) + ($6123)|0);
        $6187 = ($6185|0)<($6056|0);
        if ($6187) {
         $$085110$us$i$i1644 = $6185;$$191108$us$i$i1645 = $6186;
        } else {
         label = 1134;
         break;
        }
       }
      } else {
       label = 1134;
      }
     } else {
      do {
       switch ($7|0) {
       case 33634:  {
        $6293 = ($$27562033|0)==(1);
        $6294 = ($$27602032|0)==(1);
        $or$cond$i1695 = $6294 | $6293;
        $6295 = (($$27562033|0) / 2)&-1;
        $6296 = (($$27602032|0) / 2)&-1;
        if (!($or$cond$i1695)) {
         $6426 = Math_imul($$27562033, $$0$i806)|0;
         $6427 = (($$27802028) - ($6426))|0;
         $6428 = ($$27602032|0)>(1);
         if (!($6428)) {
          label = 1134;
          break L1810;
         }
         $6429 = ($$27562033|0)>(1);
         if ($6429) {
          $$07999$us$i1713 = 0;$$08098$us$i1714 = 0;$$08197$us$i1715 = $$17682030;
         } else {
          $$3757 = $$27562033;$$3781 = $$27802028;
          break L1810;
         }
         while(1) {
          $$08391$us$us$i1720 = 0;$$18292$us$us$i1719 = $$08197$us$i1715;$$193$us$us$i1718 = $$07999$us$i1713;
          while(1) {
           $6435 = HEAP8[$$18292$us$us$i1719>>0]|0;
           $6436 = $6435&255;
           $6437 = $6436 & 7;
           $6438 = (+($6437|0));
           $6439 = $6438 / 7.0;
           $6440 = $6436 >>> 3;
           $6441 = $6440 & 7;
           $6442 = (+($6441|0));
           $6443 = $6442 / 7.0;
           $6444 = $6436 >>> 6;
           $6445 = (+($6444|0));
           $6446 = $6445 / 3.0;
           $6447 = (($$18292$us$us$i1719) + ($$0$i806)|0);
           $6448 = HEAP8[$6447>>0]|0;
           $6449 = $6448&255;
           $6450 = $6449 & 7;
           $6451 = (+($6450|0));
           $6452 = $6451 / 7.0;
           $6453 = $6449 >>> 3;
           $6454 = $6453 & 7;
           $6455 = (+($6454|0));
           $6456 = $6455 / 7.0;
           $6457 = $6449 >>> 6;
           $6458 = (+($6457|0));
           $6459 = $6458 / 3.0;
           $6460 = (($$18292$us$us$i1719) + ($$27802028)|0);
           $6461 = HEAP8[$6460>>0]|0;
           $6462 = $6461&255;
           $6463 = $6462 & 7;
           $6464 = (+($6463|0));
           $6465 = $6464 / 7.0;
           $6466 = $6462 >>> 3;
           $6467 = $6466 & 7;
           $6468 = (+($6467|0));
           $6469 = $6468 / 7.0;
           $6470 = $6462 >>> 6;
           $6471 = (+($6470|0));
           $6472 = $6471 / 3.0;
           $6473 = (($6460) + ($$0$i806)|0);
           $6474 = HEAP8[$6473>>0]|0;
           $6475 = $6474&255;
           $6476 = $6475 & 7;
           $6477 = (+($6476|0));
           $6478 = $6477 / 7.0;
           $6479 = $6475 >>> 3;
           $6480 = $6479 & 7;
           $6481 = (+($6480|0));
           $6482 = $6481 / 7.0;
           $6483 = $6475 >>> 6;
           $6484 = (+($6483|0));
           $6485 = $6484 / 3.0;
           $6486 = $6439 + 0.0;
           $6487 = $6486 + $6452;
           $6488 = $6487 + $6465;
           $6489 = $6488 + $6478;
           $6490 = $6489 * 0.25;
           HEAPF32[$14>>2] = $6490;
           $6491 = $6443 + 0.0;
           $6492 = $6491 + $6456;
           $6493 = $6492 + $6469;
           $6494 = $6493 + $6482;
           $6495 = $6494 * 0.25;
           HEAPF32[$6051>>2] = $6495;
           $6496 = $6446 + 0.0;
           $6497 = $6496 + $6459;
           $6498 = $6497 + $6472;
           $6499 = $6498 + $6485;
           $6500 = $6499 * 0.25;
           HEAPF32[$6052>>2] = $6500;
           $6501 = $6490;
           $6502 = $6501 * 7.0;
           $6503 = $6502 + 0.5;
           $6504 = (~~(($6503))&255);
           $6505 = $6504 & 7;
           $6506 = (($$62029) + ($$193$us$us$i1718)|0);
           HEAP8[$6506>>0] = $6505;
           $6507 = +HEAPF32[$6051>>2];
           $6508 = $6507;
           $6509 = $6508 * 7.0;
           $6510 = $6509 + 0.5;
           $6511 = (~~(($6510))&255);
           $6512 = $6511&255;
           $6513 = $6512 << 3;
           $6514 = $6513 & 56;
           $6515 = $6505&255;
           $6516 = $6514 | $6515;
           $6517 = $6516&255;
           HEAP8[$6506>>0] = $6517;
           $6518 = +HEAPF32[$6052>>2];
           $6519 = $6518;
           $6520 = $6519 * 3.0;
           $6521 = $6520 + 0.5;
           $6522 = (~~(($6521))&255);
           $6523 = $6522&255;
           $6524 = $6523 << 6;
           $6525 = $6516 | $6524;
           $6526 = $6525&255;
           HEAP8[$6506>>0] = $6526;
           $6527 = (($$193$us$us$i1718) + 1)|0;
           $6431 = (($$18292$us$us$i1719) + ($6046)|0);
           $6528 = (($$08391$us$us$i1720) + 1)|0;
           $6529 = ($6528|0)<($6295|0);
           if ($6529) {
            $$08391$us$us$i1720 = $6528;$$18292$us$us$i1719 = $6431;$$193$us$us$i1718 = $6527;
           } else {
            break;
           }
          }
          $6430 = (($6431) + ($6427)|0);
          $6432 = (($6430) + ($$27802028)|0);
          $6433 = (($$08098$us$i1714) + 1)|0;
          $6434 = ($6433|0)<($6296|0);
          if ($6434) {
           $$07999$us$i1713 = $6527;$$08098$us$i1714 = $6433;$$08197$us$i1715 = $6432;
          } else {
           label = 1134;
           break L1810;
          }
         }
        }
        if ($6294) {
         $6297 = ($$27562033|0)>(1);
         if ($6297) {
          $$088100$us$i$i1698 = 0;$$09098$us$i$i1699 = $$17682030;
         } else {
          $$3757 = $$27562033;$$3781 = $$27802028;
          break L1810;
         }
         while(1) {
          $6298 = HEAP8[$$09098$us$i$i1699>>0]|0;
          $6299 = $6298&255;
          $6300 = $6299 & 7;
          $6301 = (+($6300|0));
          $6302 = $6301 / 7.0;
          $6303 = $6299 >>> 3;
          $6304 = $6303 & 7;
          $6305 = (+($6304|0));
          $6306 = $6305 / 7.0;
          $6307 = $6299 >>> 6;
          $6308 = (+($6307|0));
          $6309 = $6308 / 3.0;
          $6310 = (($$09098$us$i$i1699) + ($$0$i806)|0);
          $6311 = HEAP8[$6310>>0]|0;
          $6312 = $6311&255;
          $6313 = $6312 & 7;
          $6314 = (+($6313|0));
          $6315 = $6314 / 7.0;
          $6316 = $6312 >>> 3;
          $6317 = $6316 & 7;
          $6318 = (+($6317|0));
          $6319 = $6318 / 7.0;
          $6320 = $6312 >>> 6;
          $6321 = (+($6320|0));
          $6322 = $6321 / 3.0;
          $6323 = $6302 + 0.0;
          $6324 = $6323 + $6315;
          $6325 = $6324 * 0.5;
          HEAPF32[$12>>2] = $6325;
          $6326 = $6306 + 0.0;
          $6327 = $6326 + $6319;
          $6328 = $6327 * 0.5;
          HEAPF32[$6047>>2] = $6328;
          $6329 = $6309 + 0.0;
          $6330 = $6329 + $6322;
          $6331 = $6330 * 0.5;
          HEAPF32[$6048>>2] = $6331;
          $6332 = $6325;
          $6333 = $6332 * 7.0;
          $6334 = $6333 + 0.5;
          $6335 = (~~(($6334))&255);
          $6336 = $6335 & 7;
          $6337 = (($$62029) + ($$088100$us$i$i1698)|0);
          HEAP8[$6337>>0] = $6336;
          $6338 = +HEAPF32[$6047>>2];
          $6339 = $6338;
          $6340 = $6339 * 7.0;
          $6341 = $6340 + 0.5;
          $6342 = (~~(($6341))&255);
          $6343 = $6342&255;
          $6344 = $6343 << 3;
          $6345 = $6344 & 56;
          $6346 = $6336&255;
          $6347 = $6345 | $6346;
          $6348 = $6347&255;
          HEAP8[$6337>>0] = $6348;
          $6349 = +HEAPF32[$6048>>2];
          $6350 = $6349;
          $6351 = $6350 * 3.0;
          $6352 = $6351 + 0.5;
          $6353 = (~~(($6352))&255);
          $6354 = $6353&255;
          $6355 = $6354 << 6;
          $6356 = $6347 | $6355;
          $6357 = $6356&255;
          HEAP8[$6337>>0] = $6357;
          $6358 = (($$088100$us$i$i1698) + 1)|0;
          $6359 = (($$09098$us$i$i1699) + ($6046)|0);
          $6360 = ($6358|0)<($6295|0);
          if ($6360) {
           $$088100$us$i$i1698 = $6358;$$09098$us$i$i1699 = $6359;
          } else {
           label = 1134;
           break L1810;
          }
         }
        }
        $6361 = ($$27602032|0)>(1);
        $or$cond$i$i1704 = $6361 & $6293;
        if (!($or$cond$i$i1704)) {
         label = 1134;
         break L1810;
        }
        $6362 = $$27802028 << 1;
        $$085110$us$i$i1706 = 0;$$191108$us$i$i1707 = $$17682030;
        while(1) {
         $6363 = HEAP8[$$191108$us$i$i1707>>0]|0;
         $6364 = $6363&255;
         $6365 = $6364 & 7;
         $6366 = (+($6365|0));
         $6367 = $6366 / 7.0;
         $6368 = $6364 >>> 3;
         $6369 = $6368 & 7;
         $6370 = (+($6369|0));
         $6371 = $6370 / 7.0;
         $6372 = $6364 >>> 6;
         $6373 = (+($6372|0));
         $6374 = $6373 / 3.0;
         $6375 = (($$191108$us$i$i1707) + ($$27802028)|0);
         $6376 = HEAP8[$6375>>0]|0;
         $6377 = $6376&255;
         $6378 = $6377 & 7;
         $6379 = (+($6378|0));
         $6380 = $6379 / 7.0;
         $6381 = $6377 >>> 3;
         $6382 = $6381 & 7;
         $6383 = (+($6382|0));
         $6384 = $6383 / 7.0;
         $6385 = $6377 >>> 6;
         $6386 = (+($6385|0));
         $6387 = $6386 / 3.0;
         $6388 = $6367 + 0.0;
         $6389 = $6388 + $6380;
         $6390 = $6389 * 0.5;
         HEAPF32[$13>>2] = $6390;
         $6391 = $6371 + 0.0;
         $6392 = $6391 + $6384;
         $6393 = $6392 * 0.5;
         HEAPF32[$6049>>2] = $6393;
         $6394 = $6374 + 0.0;
         $6395 = $6394 + $6387;
         $6396 = $6395 * 0.5;
         HEAPF32[$6050>>2] = $6396;
         $6397 = $6390;
         $6398 = $6397 * 7.0;
         $6399 = $6398 + 0.5;
         $6400 = (~~(($6399))&255);
         $6401 = $6400 & 7;
         $6402 = (($$62029) + ($$085110$us$i$i1706)|0);
         HEAP8[$6402>>0] = $6401;
         $6403 = +HEAPF32[$6049>>2];
         $6404 = $6403;
         $6405 = $6404 * 7.0;
         $6406 = $6405 + 0.5;
         $6407 = (~~(($6406))&255);
         $6408 = $6407&255;
         $6409 = $6408 << 3;
         $6410 = $6409 & 56;
         $6411 = $6401&255;
         $6412 = $6410 | $6411;
         $6413 = $6412&255;
         HEAP8[$6402>>0] = $6413;
         $6414 = +HEAPF32[$6050>>2];
         $6415 = $6414;
         $6416 = $6415 * 3.0;
         $6417 = $6416 + 0.5;
         $6418 = (~~(($6417))&255);
         $6419 = $6418&255;
         $6420 = $6419 << 6;
         $6421 = $6412 | $6420;
         $6422 = $6421&255;
         HEAP8[$6402>>0] = $6422;
         $6423 = (($$085110$us$i$i1706) + 1)|0;
         $6424 = (($$191108$us$i$i1707) + ($6362)|0);
         $6425 = ($6423|0)<($6296|0);
         if ($6425) {
          $$085110$us$i$i1706 = $6423;$$191108$us$i$i1707 = $6424;
         } else {
          label = 1134;
          break;
         }
        }
        break;
       }
       case 33635:  {
        $6530 = ($$27562033|0)==(1);
        $6531 = ($$27602032|0)==(1);
        $or$cond$i1757 = $6531 | $6530;
        $6532 = (($$27562033|0) / 2)&-1;
        $6533 = (($$27602032|0) / 2)&-1;
        if (!($or$cond$i1757)) {
         $6657 = Math_imul($$27562033, $$0$i806)|0;
         $6658 = (($$27802028) - ($6657))|0;
         $6659 = ($$27602032|0)>(1);
         if (!($6659)) {
          label = 1134;
          break L1810;
         }
         $6660 = ($$27562033|0)>(1);
         if (!($6660)) {
          $$3757 = $$27562033;$$3781 = $$27802028;
          break L1810;
         }
         $$07999$us$i1775 = 0;$$08098$us$i1776 = 0;$$08197$us$i1777 = $$17682030;
         while(1) {
          $$08391$us$us$i1782 = 0;$$18292$us$us$i1781 = $$08197$us$i1777;$$193$us$us$i1780 = $$07999$us$i1775;
          while(1) {
           $6666 = HEAP16[$$18292$us$us$i1781>>1]|0;
           $6667 = $6666&65535;
           $6668 = $6667 >>> 11;
           $6669 = (+($6668|0));
           $6670 = $6669 / 31.0;
           $6671 = $6667 >>> 5;
           $6672 = $6671 & 63;
           $6673 = (+($6672|0));
           $6674 = $6673 / 63.0;
           $6675 = $6667 & 31;
           $6676 = (+($6675|0));
           $6677 = $6676 / 31.0;
           $6678 = (($$18292$us$us$i1781) + ($$0$i806)|0);
           $6679 = HEAP16[$6678>>1]|0;
           $6680 = $6679&65535;
           $6681 = $6680 >>> 11;
           $6682 = (+($6681|0));
           $6683 = $6682 / 31.0;
           $6684 = $6680 >>> 5;
           $6685 = $6684 & 63;
           $6686 = (+($6685|0));
           $6687 = $6686 / 63.0;
           $6688 = $6680 & 31;
           $6689 = (+($6688|0));
           $6690 = $6689 / 31.0;
           $6691 = (($$18292$us$us$i1781) + ($$27802028)|0);
           $6692 = HEAP16[$6691>>1]|0;
           $6693 = $6692&65535;
           $6694 = $6693 >>> 11;
           $6695 = (+($6694|0));
           $6696 = $6695 / 31.0;
           $6697 = $6693 >>> 5;
           $6698 = $6697 & 63;
           $6699 = (+($6698|0));
           $6700 = $6699 / 63.0;
           $6701 = $6693 & 31;
           $6702 = (+($6701|0));
           $6703 = $6702 / 31.0;
           $6704 = (($6691) + ($$0$i806)|0);
           $6705 = HEAP16[$6704>>1]|0;
           $6706 = $6705&65535;
           $6707 = $6706 >>> 11;
           $6708 = (+($6707|0));
           $6709 = $6708 / 31.0;
           $6710 = $6706 >>> 5;
           $6711 = $6710 & 63;
           $6712 = (+($6711|0));
           $6713 = $6712 / 63.0;
           $6714 = $6706 & 31;
           $6715 = (+($6714|0));
           $6716 = $6715 / 31.0;
           $6717 = $6670 + 0.0;
           $6718 = $6717 + $6683;
           $6719 = $6718 + $6696;
           $6720 = $6719 + $6709;
           $6721 = $6720 * 0.25;
           $6722 = $6674 + 0.0;
           $6723 = $6722 + $6687;
           $6724 = $6723 + $6700;
           $6725 = $6724 + $6713;
           $6726 = $6725 * 0.25;
           $6727 = $6677 + 0.0;
           $6728 = $6727 + $6690;
           $6729 = $6728 + $6703;
           $6730 = $6729 + $6716;
           $6731 = $6730 * 0.25;
           $6732 = $6721 * 31.0;
           $6733 = $6732;
           $6734 = $6733 + 0.5;
           $6735 = (~~(($6734))&65535);
           $6736 = $6735&65535;
           $6737 = $6736 << 11;
           $6738 = (($$62029) + ($$193$us$us$i1780<<1)|0);
           $6739 = $6726 * 63.0;
           $6740 = $6739;
           $6741 = $6740 + 0.5;
           $6742 = (~~(($6741))&65535);
           $6743 = $6742&65535;
           $6744 = $6743 << 5;
           $6745 = $6744 & 2016;
           $6746 = $6745 | $6737;
           $6747 = $6731 * 31.0;
           $6748 = $6747;
           $6749 = $6748 + 0.5;
           $6750 = (~~(($6749))&65535);
           $6751 = $6750 & 31;
           $6752 = $6751&65535;
           $6753 = $6746 | $6752;
           $6754 = $6753&65535;
           HEAP16[$6738>>1] = $6754;
           $6755 = (($$193$us$us$i1780) + 1)|0;
           $6662 = (($$18292$us$us$i1781) + ($6046)|0);
           $6756 = (($$08391$us$us$i1782) + 1)|0;
           $6757 = ($6756|0)<($6532|0);
           if ($6757) {
            $$08391$us$us$i1782 = $6756;$$18292$us$us$i1781 = $6662;$$193$us$us$i1780 = $6755;
           } else {
            break;
           }
          }
          $6661 = (($6662) + ($6658)|0);
          $6663 = (($6661) + ($$27802028)|0);
          $6664 = (($$08098$us$i1776) + 1)|0;
          $6665 = ($6664|0)<($6533|0);
          if ($6665) {
           $$07999$us$i1775 = $6755;$$08098$us$i1776 = $6664;$$08197$us$i1777 = $6663;
          } else {
           label = 1134;
           break L1810;
          }
         }
        }
        if ($6531) {
         $6534 = ($$27562033|0)>(1);
         if (!($6534)) {
          $$3757 = $$27562033;$$3781 = $$27802028;
          break L1810;
         }
         $$088100$us$i$i1760 = 0;$$09098$us$i$i1761 = $$17682030;
         while(1) {
          $6535 = HEAP16[$$09098$us$i$i1761>>1]|0;
          $6536 = $6535&65535;
          $6537 = $6536 >>> 11;
          $6538 = (+($6537|0));
          $6539 = $6538 / 31.0;
          $6540 = $6536 >>> 5;
          $6541 = $6540 & 63;
          $6542 = (+($6541|0));
          $6543 = $6542 / 63.0;
          $6544 = $6536 & 31;
          $6545 = (+($6544|0));
          $6546 = $6545 / 31.0;
          $6547 = (($$09098$us$i$i1761) + ($$0$i806)|0);
          $6548 = HEAP16[$6547>>1]|0;
          $6549 = $6548&65535;
          $6550 = $6549 >>> 11;
          $6551 = (+($6550|0));
          $6552 = $6551 / 31.0;
          $6553 = $6549 >>> 5;
          $6554 = $6553 & 63;
          $6555 = (+($6554|0));
          $6556 = $6555 / 63.0;
          $6557 = $6549 & 31;
          $6558 = (+($6557|0));
          $6559 = $6558 / 31.0;
          $6560 = $6539 + 0.0;
          $6561 = $6560 + $6552;
          $6562 = $6561 * 0.5;
          $6563 = $6543 + 0.0;
          $6564 = $6563 + $6556;
          $6565 = $6564 * 0.5;
          $6566 = $6546 + 0.0;
          $6567 = $6566 + $6559;
          $6568 = $6567 * 0.5;
          $6569 = $6562 * 31.0;
          $6570 = $6569;
          $6571 = $6570 + 0.5;
          $6572 = (~~(($6571))&65535);
          $6573 = $6572&65535;
          $6574 = $6573 << 11;
          $6575 = (($$62029) + ($$088100$us$i$i1760<<1)|0);
          $6576 = $6565 * 63.0;
          $6577 = $6576;
          $6578 = $6577 + 0.5;
          $6579 = (~~(($6578))&65535);
          $6580 = $6579&65535;
          $6581 = $6580 << 5;
          $6582 = $6581 & 2016;
          $6583 = $6582 | $6574;
          $6584 = $6568 * 31.0;
          $6585 = $6584;
          $6586 = $6585 + 0.5;
          $6587 = (~~(($6586))&65535);
          $6588 = $6587 & 31;
          $6589 = $6588&65535;
          $6590 = $6583 | $6589;
          $6591 = $6590&65535;
          HEAP16[$6575>>1] = $6591;
          $6592 = (($$088100$us$i$i1760) + 1)|0;
          $6593 = (($$09098$us$i$i1761) + ($6046)|0);
          $6594 = ($6592|0)<($6532|0);
          if ($6594) {
           $$088100$us$i$i1760 = $6592;$$09098$us$i$i1761 = $6593;
          } else {
           label = 1134;
           break;
          }
         }
        } else {
         $6595 = ($$27602032|0)>(1);
         $or$cond$i$i1766 = $6595 & $6530;
         if (!($or$cond$i$i1766)) {
          label = 1134;
          break L1810;
         }
         $6596 = $$27802028 << 1;
         $$085110$us$i$i1768 = 0;$$191108$us$i$i1769 = $$17682030;
         while(1) {
          $6597 = HEAP16[$$191108$us$i$i1769>>1]|0;
          $6598 = $6597&65535;
          $6599 = $6598 >>> 11;
          $6600 = (+($6599|0));
          $6601 = $6600 / 31.0;
          $6602 = $6598 >>> 5;
          $6603 = $6602 & 63;
          $6604 = (+($6603|0));
          $6605 = $6604 / 63.0;
          $6606 = $6598 & 31;
          $6607 = (+($6606|0));
          $6608 = $6607 / 31.0;
          $6609 = (($$191108$us$i$i1769) + ($$27802028)|0);
          $6610 = HEAP16[$6609>>1]|0;
          $6611 = $6610&65535;
          $6612 = $6611 >>> 11;
          $6613 = (+($6612|0));
          $6614 = $6613 / 31.0;
          $6615 = $6611 >>> 5;
          $6616 = $6615 & 63;
          $6617 = (+($6616|0));
          $6618 = $6617 / 63.0;
          $6619 = $6611 & 31;
          $6620 = (+($6619|0));
          $6621 = $6620 / 31.0;
          $6622 = $6601 + 0.0;
          $6623 = $6622 + $6614;
          $6624 = $6623 * 0.5;
          $6625 = $6605 + 0.0;
          $6626 = $6625 + $6618;
          $6627 = $6626 * 0.5;
          $6628 = $6608 + 0.0;
          $6629 = $6628 + $6621;
          $6630 = $6629 * 0.5;
          $6631 = $6624 * 31.0;
          $6632 = $6631;
          $6633 = $6632 + 0.5;
          $6634 = (~~(($6633))&65535);
          $6635 = $6634&65535;
          $6636 = $6635 << 11;
          $6637 = (($$62029) + ($$085110$us$i$i1768<<1)|0);
          $6638 = $6627 * 63.0;
          $6639 = $6638;
          $6640 = $6639 + 0.5;
          $6641 = (~~(($6640))&65535);
          $6642 = $6641&65535;
          $6643 = $6642 << 5;
          $6644 = $6643 & 2016;
          $6645 = $6644 | $6636;
          $6646 = $6630 * 31.0;
          $6647 = $6646;
          $6648 = $6647 + 0.5;
          $6649 = (~~(($6648))&65535);
          $6650 = $6649 & 31;
          $6651 = $6650&65535;
          $6652 = $6645 | $6651;
          $6653 = $6652&65535;
          HEAP16[$6637>>1] = $6653;
          $6654 = (($$085110$us$i$i1768) + 1)|0;
          $6655 = (($$191108$us$i$i1769) + ($6596)|0);
          $6656 = ($6654|0)<($6533|0);
          if ($6656) {
           $$085110$us$i$i1768 = $6654;$$191108$us$i$i1769 = $6655;
          } else {
           label = 1134;
           break;
          }
         }
        }
        break;
       }
       case 33636:  {
        $6758 = ($$27562033|0)==(1);
        $6759 = ($$27602032|0)==(1);
        $or$cond$i1796 = $6759 | $6758;
        $6760 = (($$27562033|0) / 2)&-1;
        $6761 = (($$27602032|0) / 2)&-1;
        if (!($or$cond$i1796)) {
         $6885 = Math_imul($$27562033, $$0$i806)|0;
         $6886 = (($$27802028) - ($6885))|0;
         $6887 = ($$27602032|0)>(1);
         if (!($6887)) {
          label = 1134;
          break L1810;
         }
         $6888 = ($$27562033|0)>(1);
         if (!($6888)) {
          $$3757 = $$27562033;$$3781 = $$27802028;
          break L1810;
         }
         $$07999$us$i1814 = 0;$$08098$us$i1815 = 0;$$08197$us$i1816 = $$17682030;
         while(1) {
          $$08391$us$us$i1821 = 0;$$18292$us$us$i1820 = $$08197$us$i1816;$$193$us$us$i1819 = $$07999$us$i1814;
          while(1) {
           $6894 = HEAP16[$$18292$us$us$i1820>>1]|0;
           $6895 = $6894&65535;
           $6896 = $6895 & 31;
           $6897 = (+($6896|0));
           $6898 = $6897 / 31.0;
           $6899 = $6895 >>> 5;
           $6900 = $6899 & 63;
           $6901 = (+($6900|0));
           $6902 = $6901 / 63.0;
           $6903 = $6895 >>> 11;
           $6904 = (+($6903|0));
           $6905 = $6904 / 31.0;
           $6906 = (($$18292$us$us$i1820) + ($$0$i806)|0);
           $6907 = HEAP16[$6906>>1]|0;
           $6908 = $6907&65535;
           $6909 = $6908 & 31;
           $6910 = (+($6909|0));
           $6911 = $6910 / 31.0;
           $6912 = $6908 >>> 5;
           $6913 = $6912 & 63;
           $6914 = (+($6913|0));
           $6915 = $6914 / 63.0;
           $6916 = $6908 >>> 11;
           $6917 = (+($6916|0));
           $6918 = $6917 / 31.0;
           $6919 = (($$18292$us$us$i1820) + ($$27802028)|0);
           $6920 = HEAP16[$6919>>1]|0;
           $6921 = $6920&65535;
           $6922 = $6921 & 31;
           $6923 = (+($6922|0));
           $6924 = $6923 / 31.0;
           $6925 = $6921 >>> 5;
           $6926 = $6925 & 63;
           $6927 = (+($6926|0));
           $6928 = $6927 / 63.0;
           $6929 = $6921 >>> 11;
           $6930 = (+($6929|0));
           $6931 = $6930 / 31.0;
           $6932 = (($6919) + ($$0$i806)|0);
           $6933 = HEAP16[$6932>>1]|0;
           $6934 = $6933&65535;
           $6935 = $6934 & 31;
           $6936 = (+($6935|0));
           $6937 = $6936 / 31.0;
           $6938 = $6934 >>> 5;
           $6939 = $6938 & 63;
           $6940 = (+($6939|0));
           $6941 = $6940 / 63.0;
           $6942 = $6934 >>> 11;
           $6943 = (+($6942|0));
           $6944 = $6943 / 31.0;
           $6945 = $6898 + 0.0;
           $6946 = $6945 + $6911;
           $6947 = $6946 + $6924;
           $6948 = $6947 + $6937;
           $6949 = $6948 * 0.25;
           $6950 = $6902 + 0.0;
           $6951 = $6950 + $6915;
           $6952 = $6951 + $6928;
           $6953 = $6952 + $6941;
           $6954 = $6953 * 0.25;
           $6955 = $6905 + 0.0;
           $6956 = $6955 + $6918;
           $6957 = $6956 + $6931;
           $6958 = $6957 + $6944;
           $6959 = $6958 * 0.25;
           $6960 = $6949;
           $6961 = $6960 * 31.0;
           $6962 = $6961 + 0.5;
           $6963 = (~~(($6962))&65535);
           $6964 = $6963 & 31;
           $6965 = (($$62029) + ($$193$us$us$i1819<<1)|0);
           $6966 = $6954;
           $6967 = $6966 * 63.0;
           $6968 = $6967 + 0.5;
           $6969 = (~~(($6968))&65535);
           $6970 = $6969&65535;
           $6971 = $6970 << 5;
           $6972 = $6971 & 2016;
           $6973 = $6964&65535;
           $6974 = $6972 | $6973;
           $6975 = $6959;
           $6976 = $6975 * 31.0;
           $6977 = $6976 + 0.5;
           $6978 = (~~(($6977))&65535);
           $6979 = $6978&65535;
           $6980 = $6979 << 11;
           $6981 = $6974 | $6980;
           $6982 = $6981&65535;
           HEAP16[$6965>>1] = $6982;
           $6983 = (($$193$us$us$i1819) + 1)|0;
           $6890 = (($$18292$us$us$i1820) + ($6046)|0);
           $6984 = (($$08391$us$us$i1821) + 1)|0;
           $6985 = ($6984|0)<($6760|0);
           if ($6985) {
            $$08391$us$us$i1821 = $6984;$$18292$us$us$i1820 = $6890;$$193$us$us$i1819 = $6983;
           } else {
            break;
           }
          }
          $6889 = (($6890) + ($6886)|0);
          $6891 = (($6889) + ($$27802028)|0);
          $6892 = (($$08098$us$i1815) + 1)|0;
          $6893 = ($6892|0)<($6761|0);
          if ($6893) {
           $$07999$us$i1814 = $6983;$$08098$us$i1815 = $6892;$$08197$us$i1816 = $6891;
          } else {
           label = 1134;
           break L1810;
          }
         }
        }
        if ($6759) {
         $6762 = ($$27562033|0)>(1);
         if (!($6762)) {
          $$3757 = $$27562033;$$3781 = $$27802028;
          break L1810;
         }
         $$088100$us$i$i1799 = 0;$$09098$us$i$i1800 = $$17682030;
         while(1) {
          $6763 = HEAP16[$$09098$us$i$i1800>>1]|0;
          $6764 = $6763&65535;
          $6765 = $6764 & 31;
          $6766 = (+($6765|0));
          $6767 = $6766 / 31.0;
          $6768 = $6764 >>> 5;
          $6769 = $6768 & 63;
          $6770 = (+($6769|0));
          $6771 = $6770 / 63.0;
          $6772 = $6764 >>> 11;
          $6773 = (+($6772|0));
          $6774 = $6773 / 31.0;
          $6775 = (($$09098$us$i$i1800) + ($$0$i806)|0);
          $6776 = HEAP16[$6775>>1]|0;
          $6777 = $6776&65535;
          $6778 = $6777 & 31;
          $6779 = (+($6778|0));
          $6780 = $6779 / 31.0;
          $6781 = $6777 >>> 5;
          $6782 = $6781 & 63;
          $6783 = (+($6782|0));
          $6784 = $6783 / 63.0;
          $6785 = $6777 >>> 11;
          $6786 = (+($6785|0));
          $6787 = $6786 / 31.0;
          $6788 = $6767 + 0.0;
          $6789 = $6788 + $6780;
          $6790 = $6789 * 0.5;
          $6791 = $6771 + 0.0;
          $6792 = $6791 + $6784;
          $6793 = $6792 * 0.5;
          $6794 = $6774 + 0.0;
          $6795 = $6794 + $6787;
          $6796 = $6795 * 0.5;
          $6797 = $6790;
          $6798 = $6797 * 31.0;
          $6799 = $6798 + 0.5;
          $6800 = (~~(($6799))&65535);
          $6801 = $6800 & 31;
          $6802 = (($$62029) + ($$088100$us$i$i1799<<1)|0);
          $6803 = $6793;
          $6804 = $6803 * 63.0;
          $6805 = $6804 + 0.5;
          $6806 = (~~(($6805))&65535);
          $6807 = $6806&65535;
          $6808 = $6807 << 5;
          $6809 = $6808 & 2016;
          $6810 = $6801&65535;
          $6811 = $6809 | $6810;
          $6812 = $6796;
          $6813 = $6812 * 31.0;
          $6814 = $6813 + 0.5;
          $6815 = (~~(($6814))&65535);
          $6816 = $6815&65535;
          $6817 = $6816 << 11;
          $6818 = $6811 | $6817;
          $6819 = $6818&65535;
          HEAP16[$6802>>1] = $6819;
          $6820 = (($$088100$us$i$i1799) + 1)|0;
          $6821 = (($$09098$us$i$i1800) + ($6046)|0);
          $6822 = ($6820|0)<($6760|0);
          if ($6822) {
           $$088100$us$i$i1799 = $6820;$$09098$us$i$i1800 = $6821;
          } else {
           label = 1134;
           break;
          }
         }
        } else {
         $6823 = ($$27602032|0)>(1);
         $or$cond$i$i1805 = $6823 & $6758;
         if (!($or$cond$i$i1805)) {
          label = 1134;
          break L1810;
         }
         $6824 = $$27802028 << 1;
         $$085110$us$i$i1807 = 0;$$191108$us$i$i1808 = $$17682030;
         while(1) {
          $6825 = HEAP16[$$191108$us$i$i1808>>1]|0;
          $6826 = $6825&65535;
          $6827 = $6826 & 31;
          $6828 = (+($6827|0));
          $6829 = $6828 / 31.0;
          $6830 = $6826 >>> 5;
          $6831 = $6830 & 63;
          $6832 = (+($6831|0));
          $6833 = $6832 / 63.0;
          $6834 = $6826 >>> 11;
          $6835 = (+($6834|0));
          $6836 = $6835 / 31.0;
          $6837 = (($$191108$us$i$i1808) + ($$27802028)|0);
          $6838 = HEAP16[$6837>>1]|0;
          $6839 = $6838&65535;
          $6840 = $6839 & 31;
          $6841 = (+($6840|0));
          $6842 = $6841 / 31.0;
          $6843 = $6839 >>> 5;
          $6844 = $6843 & 63;
          $6845 = (+($6844|0));
          $6846 = $6845 / 63.0;
          $6847 = $6839 >>> 11;
          $6848 = (+($6847|0));
          $6849 = $6848 / 31.0;
          $6850 = $6829 + 0.0;
          $6851 = $6850 + $6842;
          $6852 = $6851 * 0.5;
          $6853 = $6833 + 0.0;
          $6854 = $6853 + $6846;
          $6855 = $6854 * 0.5;
          $6856 = $6836 + 0.0;
          $6857 = $6856 + $6849;
          $6858 = $6857 * 0.5;
          $6859 = $6852;
          $6860 = $6859 * 31.0;
          $6861 = $6860 + 0.5;
          $6862 = (~~(($6861))&65535);
          $6863 = $6862 & 31;
          $6864 = (($$62029) + ($$085110$us$i$i1807<<1)|0);
          $6865 = $6855;
          $6866 = $6865 * 63.0;
          $6867 = $6866 + 0.5;
          $6868 = (~~(($6867))&65535);
          $6869 = $6868&65535;
          $6870 = $6869 << 5;
          $6871 = $6870 & 2016;
          $6872 = $6863&65535;
          $6873 = $6871 | $6872;
          $6874 = $6858;
          $6875 = $6874 * 31.0;
          $6876 = $6875 + 0.5;
          $6877 = (~~(($6876))&65535);
          $6878 = $6877&65535;
          $6879 = $6878 << 11;
          $6880 = $6873 | $6879;
          $6881 = $6880&65535;
          HEAP16[$6864>>1] = $6881;
          $6882 = (($$085110$us$i$i1807) + 1)|0;
          $6883 = (($$191108$us$i$i1808) + ($6824)|0);
          $6884 = ($6882|0)<($6761|0);
          if ($6884) {
           $$085110$us$i$i1807 = $6882;$$191108$us$i$i1808 = $6883;
          } else {
           label = 1134;
           break;
          }
         }
        }
        break;
       }
       case 33637:  {
        __ZN3osgL21halveImagePackedPixelEiPFviPKvPfEPFvPKfiPvEiiS1_S7_iii(4,4009,4010,$$27562033,$$27602032,$$17682030,$$62029,$$0$i806,$$27802028,0);
        label = 1134;
        break L1810;
        break;
       }
       case 32820:  {
        __ZN3osgL21halveImagePackedPixelEiPFviPKvPfEPFvPKfiPvEiiS1_S7_iii(4,4011,4012,$$27562033,$$27602032,$$17682030,$$62029,$$0$i806,$$27802028,0);
        label = 1134;
        break L1810;
        break;
       }
       case 33638:  {
        __ZN3osgL21halveImagePackedPixelEiPFviPKvPfEPFvPKfiPvEiiS1_S7_iii(4,4013,4014,$$27562033,$$27602032,$$17682030,$$62029,$$0$i806,$$27802028,0);
        label = 1134;
        break L1810;
        break;
       }
       case 32821:  {
        __ZN3osgL21halveImagePackedPixelEiPFviPKvPfEPFvPKfiPvEiiS1_S7_iii(4,4015,4016,$$27562033,$$27602032,$$17682030,$$62029,$$0$i806,$$27802028,0);
        label = 1134;
        break L1810;
        break;
       }
       case 33639:  {
        __ZN3osgL21halveImagePackedPixelEiPFviPKvPfEPFvPKfiPvEiiS1_S7_iii(4,4017,4018,$$27562033,$$27602032,$$17682030,$$62029,$$0$i806,$$27802028,0);
        label = 1134;
        break L1810;
        break;
       }
       case 32822:  {
        __ZN3osgL21halveImagePackedPixelEiPFviPKvPfEPFvPKfiPvEiiS1_S7_iii(4,4019,4020,$$27562033,$$27602032,$$17682030,$$62029,$$0$i806,$$27802028,0);
        label = 1134;
        break L1810;
        break;
       }
       case 33640:  {
        __ZN3osgL21halveImagePackedPixelEiPFviPKvPfEPFvPKfiPvEiiS1_S7_iii(4,4021,4022,$$27562033,$$27602032,$$17682030,$$62029,$$0$i806,$$27802028,0);
        label = 1134;
        break L1810;
        break;
       }
       default: {
        label = 1134;
        break L1810;
       }
       }
      } while(0);
     }
    } while(0);
    if ((label|0) == 1134) {
     label = 0;
     $6986 = ($$27562033|0)>(1);
     if ($6986) {
      $6987 = $$27562033 >>> 1;
      $6988 = (($$27802028|0) / 2)&-1;
      $$3757 = $6987;$$3781 = $6988;
     } else {
      $$3757 = $$27562033;$$3781 = $$27802028;
     }
    }
    $6989 = ($$27602032|0)>(1);
    $6990 = (($$27602032|0) / 2)&-1;
    $$3761 = $6989 ? $6990 : $$27602032;
    $6991 = HEAP32[$19>>2]|0;
    $6992 = (($$3781|0) % ($6991|0))&-1;
    $6993 = ($6992|0)==(0);
    if ($6993) {
     $6994 = ($$17632034|0)>=($9|0);
     $6995 = ($$17632034$in|0)<($10|0);
     $or$cond791 = $6995 & $6994;
     if ($or$cond791) {
      _glTexImage2D(($0|0),($$17632034|0),($1|0),($$3757|0),($$3761|0),0,($6|0),($7|0),($$62029|0));
     }
    } else {
     $6996 = (($6991) + ($$3781))|0;
     $6997 = (($6996) - ($6992))|0;
     $6998 = Math_imul($6997, $$3761)|0;
     $6999 = (_malloc($6998)|0);
     $7000 = ($6999|0)==(0|0);
     if ($7000) {
      break;
     }
     $7001 = ($$3761|0)>(0);
     if ($7001) {
      $$07512026 = $$62029;$$07522025 = $6999;$$07532024 = 0;
      while(1) {
       _memcpy(($$07522025|0),($$07512026|0),($$3781|0))|0;
       $7004 = (($$07532024) + 1)|0;
       $7005 = (($$07522025) + ($6997)|0);
       $7006 = (($$07512026) + ($$3781)|0);
       $exitcond = ($7004|0)==($$3761|0);
       if ($exitcond) {
        break;
       } else {
        $$07512026 = $7006;$$07522025 = $7005;$$07532024 = $7004;
       }
      }
     }
     $7007 = ($$17632034|0)>=($9|0);
     $7008 = ($$17632034$in|0)<($10|0);
     $or$cond792 = $7008 & $7007;
     if ($or$cond792) {
      _glTexImage2D(($0|0),($$17632034|0),($1|0),($$3757|0),($$3761|0),0,($6|0),($7|0),($6999|0));
     }
     _free($6999);
    }
    $7009 = ($$17632034|0)<($121|0);
    if ($7009) {
     $$62029$phi = $$17682030;$$17682030$phi = $$62029;$$17632034$in = $$17632034;$$27562033 = $$3757;$$27602032 = $$3761;$$27802028 = $$3781;$$62029 = $$62029$phi;$$17682030 = $$17682030$phi;
    } else {
     $$1768$lcssa = $$62029;$$6$lcssa = $$17682030;
     break L1806;
    }
   }
   _glPixelStorei(3317,($6991|0));
   $7002 = ($$62029|0)==(0|0);
   if (!($7002)) {
    _free($$62029);
   }
   $7003 = ($$17682030|0)==(0|0);
   if ($7003) {
    $$4 = 100902;
    STACKTOP = sp;return ($$4|0);
   }
   _free($$17682030);
   $$4 = 100902;
   STACKTOP = sp;return ($$4|0);
  } else {
   $$1768$lcssa = $$0767;$$6$lcssa = $$5;
  }
 } while(0);
 $7010 = HEAP32[$19>>2]|0;
 _glPixelStorei(3317,($7010|0));
 _free($$1768$lcssa);
 $7011 = ($$6$lcssa|0)==(0|0);
 if ($7011) {
  $$4 = 0;
  STACKTOP = sp;return ($$4|0);
 }
 _free($$6$lcssa);
 $$4 = 0;
 STACKTOP = sp;return ($$4|0);
}
function __ZN3osgL16halveImage_ubyteEijjPKhPhiii($0,$1,$2,$3,$4,$5,$6,$7) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 var $$05979$us = 0, $$06275$us$i = 0, $$06278$us = 0, $$06372$us$us = 0, $$06379$us$i = 0, $$06468$us$us = 0, $$06478$us$i = 0, $$06677$us$i = 0, $$080$us = 0, $$082$us$i = 0, $$16073$us$us = 0, $$16574$us$i = 0, $$16773$us$i = 0, $$174$us$us = 0, $$189$us$i = 0, $$26169$us$us = 0, $$26887$us$i = 0, $$270$us$us = 0, $$288$us$i = 0, $$36980$us$i = 0;
 var $$381$us$i = 0, $$pn = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $9 = 0, $exitcond = 0;
 var $exitcond$i = 0, $exitcond101$i = 0, $exitcond102$i = 0, $exitcond107 = 0, $exitcond108 = 0, $exitcond97$i = 0, $or$cond = 0, $or$cond$i = 0, $or$cond105$i = 0, $scevgep$i = 0, $scevgep100$i = 0, $scevgep103 = 0, $scevgep104 = 0, $scevgep105 = 0, $scevgep96$i = 0, $scevgep99$i = 0, $split76$us = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $8 = ($1|0)==(1);
 $9 = ($2|0)==(1);
 $or$cond = $8 | $9;
 $10 = $1 >>> 1;
 $11 = $2 >>> 1;
 if (!($or$cond)) {
  $46 = Math_imul($7, $1)|0;
  $47 = (($6) - ($46))|0;
  $48 = ($11|0)==(0);
  if ($48) {
   return;
  }
  $49 = ($10|0)==(0);
  $50 = ($0|0)>(0);
  if ($49) {
   return;
  }
  $51 = (($10) + -1)|0;
  $52 = Math_imul($51, $7)|0;
  $53 = Math_imul($5, $0)|0;
  $54 = Math_imul($10, $0)|0;
  $55 = (($53) + ($7))|0;
  $56 = Math_imul($55, $51)|0;
  $57 = (($53) + ($56))|0;
  $$05979$us = $4;$$06278$us = 0;$$080$us = $3;
  while(1) {
   if ($50) {
    $scevgep105 = (($$05979$us) + ($54)|0);
    $$06372$us$us = 0;$$16073$us$us = $$05979$us;$$174$us$us = $$080$us;
    while(1) {
     $scevgep103 = (($$16073$us$us) + ($0)|0);
     $$06468$us$us = 0;$$26169$us$us = $$16073$us$us;$$270$us$us = $$174$us$us;
     while(1) {
      $65 = HEAP8[$$270$us$us>>0]|0;
      $66 = $65&255;
      $67 = (($$270$us$us) + ($7)|0);
      $68 = HEAP8[$67>>0]|0;
      $69 = $68&255;
      $70 = (($$270$us$us) + ($6)|0);
      $71 = HEAP8[$70>>0]|0;
      $72 = $71&255;
      $73 = (($70) + ($7)|0);
      $74 = HEAP8[$73>>0]|0;
      $75 = $74&255;
      $76 = (($66) + 2)|0;
      $77 = (($76) + ($69))|0;
      $78 = (($77) + ($72))|0;
      $79 = (($78) + ($75))|0;
      $80 = $79 >>> 2;
      $81 = $80&255;
      HEAP8[$$26169$us$us>>0] = $81;
      $82 = ((($$26169$us$us)) + 1|0);
      $83 = (($$270$us$us) + ($5)|0);
      $84 = (($$06468$us$us) + 1)|0;
      $exitcond = ($84|0)==($0|0);
      if ($exitcond) {
       break;
      } else {
       $$06468$us$us = $84;$$26169$us$us = $82;$$270$us$us = $83;
      }
     }
     $scevgep104 = (($$174$us$us) + ($53)|0);
     $63 = (($scevgep104) + ($7)|0);
     $64 = (($$06372$us$us) + 1)|0;
     $exitcond107 = ($64|0)==($10|0);
     if ($exitcond107) {
      $$pn = $57;$split76$us = $scevgep105;
      break;
     } else {
      $$06372$us$us = $64;$$16073$us$us = $scevgep103;$$174$us$us = $63;
     }
    }
   } else {
    $$pn = $52;$split76$us = $$05979$us;
   }
   $58 = (($$080$us) + ($$pn)|0);
   $59 = (($58) + ($7)|0);
   $60 = (($59) + ($47)|0);
   $61 = (($60) + ($6)|0);
   $62 = (($$06278$us) + 1)|0;
   $exitcond108 = ($62|0)==($11|0);
   if ($exitcond108) {
    break;
   } else {
    $$05979$us = $split76$us;$$06278$us = $62;$$080$us = $61;
   }
  }
  return;
 }
 if ($9) {
  $12 = ($10|0)!=(0);
  $13 = ($0|0)>(0);
  $or$cond$i = $13 & $12;
  if (!($or$cond$i)) {
   return;
  }
  $14 = Math_imul($5, $0)|0;
  $$06379$us$i = 0;$$06478$us$i = $4;$$06677$us$i = $3;
  while(1) {
   $$06275$us$i = 0;$$16574$us$i = $$06478$us$i;$$16773$us$i = $$06677$us$i;
   while(1) {
    $15 = HEAP8[$$16773$us$i>>0]|0;
    $16 = $15&255;
    $17 = (($$16773$us$i) + ($7)|0);
    $18 = HEAP8[$17>>0]|0;
    $19 = $18&255;
    $20 = (($19) + ($16))|0;
    $21 = $20 >>> 1;
    $22 = $21&255;
    HEAP8[$$16574$us$i>>0] = $22;
    $23 = (($$16773$us$i) + ($5)|0);
    $24 = ((($$16574$us$i)) + 1|0);
    $25 = (($$06275$us$i) + 1)|0;
    $exitcond$i = ($25|0)==($0|0);
    if ($exitcond$i) {
     break;
    } else {
     $$06275$us$i = $25;$$16574$us$i = $24;$$16773$us$i = $23;
    }
   }
   $scevgep$i = (($$06677$us$i) + ($14)|0);
   $scevgep96$i = (($$06478$us$i) + ($0)|0);
   $26 = (($scevgep$i) + ($7)|0);
   $27 = (($$06379$us$i) + 1)|0;
   $exitcond97$i = ($27|0)==($10|0);
   if ($exitcond97$i) {
    break;
   } else {
    $$06379$us$i = $27;$$06478$us$i = $scevgep96$i;$$06677$us$i = $26;
   }
  }
  return;
 }
 if (!($8)) {
  return;
 }
 $28 = (($6) - ($7))|0;
 $29 = ($11|0)!=(0);
 $30 = ($0|0)>(0);
 $or$cond105$i = $30 & $29;
 if (!($or$cond105$i)) {
  return;
 }
 $31 = Math_imul($5, $0)|0;
 $$189$us$i = 0;$$26887$us$i = $3;$$288$us$i = $4;
 while(1) {
  $$082$us$i = 0;$$36980$us$i = $$26887$us$i;$$381$us$i = $$288$us$i;
  while(1) {
   $32 = HEAP8[$$36980$us$i>>0]|0;
   $33 = $32&255;
   $34 = (($$36980$us$i) + ($6)|0);
   $35 = HEAP8[$34>>0]|0;
   $36 = $35&255;
   $37 = (($36) + ($33))|0;
   $38 = $37 >>> 1;
   $39 = $38&255;
   HEAP8[$$381$us$i>>0] = $39;
   $40 = (($$36980$us$i) + ($5)|0);
   $41 = ((($$381$us$i)) + 1|0);
   $42 = (($$082$us$i) + 1)|0;
   $exitcond101$i = ($42|0)==($0|0);
   if ($exitcond101$i) {
    break;
   } else {
    $$082$us$i = $42;$$36980$us$i = $40;$$381$us$i = $41;
   }
  }
  $scevgep99$i = (($$26887$us$i) + ($31)|0);
  $scevgep100$i = (($$288$us$i) + ($0)|0);
  $43 = (($scevgep99$i) + ($28)|0);
  $44 = (($43) + ($6)|0);
  $45 = (($$189$us$i) + 1)|0;
  $exitcond102$i = ($45|0)==($11|0);
  if ($exitcond102$i) {
   break;
  } else {
   $$189$us$i = $45;$$26887$us$i = $44;$$288$us$i = $scevgep100$i;
  }
 }
 return;
}
function __ZN3osgL15halveImage_byteEijjPKaPaiii($0,$1,$2,$3,$4,$5,$6,$7) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 var $$05979$us = 0, $$06275$us$i = 0, $$06278$us = 0, $$06372$us$us = 0, $$06379$us$i = 0, $$06468$us$us = 0, $$06478$us$i = 0, $$06677$us$i = 0, $$080$us = 0, $$082$us$i = 0, $$16073$us$us = 0, $$16574$us$i = 0, $$16773$us$i = 0, $$174$us$us = 0, $$189$us$i = 0, $$26169$us$us = 0, $$26887$us$i = 0, $$270$us$us = 0, $$288$us$i = 0, $$36980$us$i = 0;
 var $$381$us$i = 0, $$pn = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $9 = 0, $exitcond = 0;
 var $exitcond$i = 0, $exitcond101$i = 0, $exitcond102$i = 0, $exitcond107 = 0, $exitcond108 = 0, $exitcond97$i = 0, $or$cond = 0, $or$cond$i = 0, $or$cond105$i = 0, $scevgep$i = 0, $scevgep100$i = 0, $scevgep103 = 0, $scevgep104 = 0, $scevgep105 = 0, $scevgep96$i = 0, $scevgep99$i = 0, $split76$us = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $8 = ($1|0)==(1);
 $9 = ($2|0)==(1);
 $or$cond = $8 | $9;
 $10 = $1 >>> 1;
 $11 = $2 >>> 1;
 if (!($or$cond)) {
  $46 = Math_imul($7, $1)|0;
  $47 = (($6) - ($46))|0;
  $48 = ($11|0)==(0);
  if ($48) {
   return;
  }
  $49 = ($10|0)==(0);
  $50 = ($0|0)>(0);
  if ($49) {
   return;
  }
  $51 = (($10) + -1)|0;
  $52 = Math_imul($51, $7)|0;
  $53 = Math_imul($5, $0)|0;
  $54 = Math_imul($10, $0)|0;
  $55 = (($53) + ($7))|0;
  $56 = Math_imul($55, $51)|0;
  $57 = (($53) + ($56))|0;
  $$05979$us = $4;$$06278$us = 0;$$080$us = $3;
  while(1) {
   if ($50) {
    $scevgep105 = (($$05979$us) + ($54)|0);
    $$06372$us$us = 0;$$16073$us$us = $$05979$us;$$174$us$us = $$080$us;
    while(1) {
     $scevgep103 = (($$16073$us$us) + ($0)|0);
     $$06468$us$us = 0;$$26169$us$us = $$16073$us$us;$$270$us$us = $$174$us$us;
     while(1) {
      $65 = HEAP8[$$270$us$us>>0]|0;
      $66 = $65 << 24 >> 24;
      $67 = (($$270$us$us) + ($7)|0);
      $68 = HEAP8[$67>>0]|0;
      $69 = $68 << 24 >> 24;
      $70 = (($$270$us$us) + ($6)|0);
      $71 = HEAP8[$70>>0]|0;
      $72 = $71 << 24 >> 24;
      $73 = (($70) + ($7)|0);
      $74 = HEAP8[$73>>0]|0;
      $75 = $74 << 24 >> 24;
      $76 = (($66) + 2)|0;
      $77 = (($76) + ($69))|0;
      $78 = (($77) + ($72))|0;
      $79 = (($78) + ($75))|0;
      $80 = (($79|0) / 4)&-1;
      $81 = $80&255;
      HEAP8[$$26169$us$us>>0] = $81;
      $82 = ((($$26169$us$us)) + 1|0);
      $83 = (($$270$us$us) + ($5)|0);
      $84 = (($$06468$us$us) + 1)|0;
      $exitcond = ($84|0)==($0|0);
      if ($exitcond) {
       break;
      } else {
       $$06468$us$us = $84;$$26169$us$us = $82;$$270$us$us = $83;
      }
     }
     $scevgep104 = (($$174$us$us) + ($53)|0);
     $63 = (($scevgep104) + ($7)|0);
     $64 = (($$06372$us$us) + 1)|0;
     $exitcond107 = ($64|0)==($10|0);
     if ($exitcond107) {
      $$pn = $57;$split76$us = $scevgep105;
      break;
     } else {
      $$06372$us$us = $64;$$16073$us$us = $scevgep103;$$174$us$us = $63;
     }
    }
   } else {
    $$pn = $52;$split76$us = $$05979$us;
   }
   $58 = (($$080$us) + ($$pn)|0);
   $59 = (($58) + ($7)|0);
   $60 = (($59) + ($47)|0);
   $61 = (($60) + ($6)|0);
   $62 = (($$06278$us) + 1)|0;
   $exitcond108 = ($62|0)==($11|0);
   if ($exitcond108) {
    break;
   } else {
    $$05979$us = $split76$us;$$06278$us = $62;$$080$us = $61;
   }
  }
  return;
 }
 if ($9) {
  $12 = ($10|0)!=(0);
  $13 = ($0|0)>(0);
  $or$cond$i = $13 & $12;
  if (!($or$cond$i)) {
   return;
  }
  $14 = Math_imul($5, $0)|0;
  $$06379$us$i = 0;$$06478$us$i = $4;$$06677$us$i = $3;
  while(1) {
   $$06275$us$i = 0;$$16574$us$i = $$06478$us$i;$$16773$us$i = $$06677$us$i;
   while(1) {
    $15 = HEAP8[$$16773$us$i>>0]|0;
    $16 = $15 << 24 >> 24;
    $17 = (($$16773$us$i) + ($7)|0);
    $18 = HEAP8[$17>>0]|0;
    $19 = $18 << 24 >> 24;
    $20 = (($19) + ($16))|0;
    $21 = (($20|0) / 2)&-1;
    $22 = $21&255;
    HEAP8[$$16574$us$i>>0] = $22;
    $23 = (($$16773$us$i) + ($5)|0);
    $24 = ((($$16574$us$i)) + 1|0);
    $25 = (($$06275$us$i) + 1)|0;
    $exitcond$i = ($25|0)==($0|0);
    if ($exitcond$i) {
     break;
    } else {
     $$06275$us$i = $25;$$16574$us$i = $24;$$16773$us$i = $23;
    }
   }
   $scevgep$i = (($$06677$us$i) + ($14)|0);
   $scevgep96$i = (($$06478$us$i) + ($0)|0);
   $26 = (($scevgep$i) + ($7)|0);
   $27 = (($$06379$us$i) + 1)|0;
   $exitcond97$i = ($27|0)==($10|0);
   if ($exitcond97$i) {
    break;
   } else {
    $$06379$us$i = $27;$$06478$us$i = $scevgep96$i;$$06677$us$i = $26;
   }
  }
  return;
 }
 if (!($8)) {
  return;
 }
 $28 = (($6) - ($7))|0;
 $29 = ($11|0)!=(0);
 $30 = ($0|0)>(0);
 $or$cond105$i = $30 & $29;
 if (!($or$cond105$i)) {
  return;
 }
 $31 = Math_imul($5, $0)|0;
 $$189$us$i = 0;$$26887$us$i = $3;$$288$us$i = $4;
 while(1) {
  $$082$us$i = 0;$$36980$us$i = $$26887$us$i;$$381$us$i = $$288$us$i;
  while(1) {
   $32 = HEAP8[$$36980$us$i>>0]|0;
   $33 = $32 << 24 >> 24;
   $34 = (($$36980$us$i) + ($6)|0);
   $35 = HEAP8[$34>>0]|0;
   $36 = $35 << 24 >> 24;
   $37 = (($36) + ($33))|0;
   $38 = (($37|0) / 2)&-1;
   $39 = $38&255;
   HEAP8[$$381$us$i>>0] = $39;
   $40 = (($$36980$us$i) + ($5)|0);
   $41 = ((($$381$us$i)) + 1|0);
   $42 = (($$082$us$i) + 1)|0;
   $exitcond101$i = ($42|0)==($0|0);
   if ($exitcond101$i) {
    break;
   } else {
    $$082$us$i = $42;$$36980$us$i = $40;$$381$us$i = $41;
   }
  }
  $scevgep99$i = (($$26887$us$i) + ($31)|0);
  $scevgep100$i = (($$288$us$i) + ($0)|0);
  $43 = (($scevgep99$i) + ($28)|0);
  $44 = (($43) + ($6)|0);
  $45 = (($$189$us$i) + 1)|0;
  $exitcond102$i = ($45|0)==($11|0);
  if ($exitcond102$i) {
   break;
  } else {
   $$189$us$i = $45;$$26887$us$i = $44;$$288$us$i = $scevgep100$i;
  }
 }
 return;
}
function __ZN3osgL17halveImage_ushortEijjPKtPtiiii($0,$1,$2,$3,$4,$5,$6,$7,$8) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 $8 = $8|0;
 var $$0102128$us = 0, $$0104122$us$us = 0, $$0106118$us$us = 0, $$0112$us$us$i$us = 0, $$0112$us120$i = 0, $$0130$us = 0, $$083100$us$i = 0, $$083100$us$i$us = 0, $$08499$us$i = 0, $$08499$us$i$us = 0, $$08894$us$us$i$us = 0, $$08894$us103$i = 0, $$08998$us$i = 0, $$08998$us$i$us = 0, $$096129$us = 0, $$1103161$us = 0, $$1105155$us$us = 0, $$1107148$us$us = 0, $$1124$us$us = 0, $$18595$us$us$i$us = 0;
 var $$18595$us102$i = 0, $$190117$us$i = 0, $$190117$us$i$us = 0, $$196$us$us$i$us = 0, $$196$us101$i = 0, $$197123$us$us = 0, $$2119$us$i = 0, $$2119$us$i$us = 0, $$2120$us$us = 0, $$286118$us$i = 0, $$286118$us$i$us = 0, $$298119$us$us = 0, $$3111$us$us$i$us = 0, $$3111$us121$i = 0, $$3163$us = 0, $$387110$us$us$i$us = 0, $$387110$us122$i = 0, $$399162$us = 0, $$4100156$us$us = 0, $$4157$us$us = 0;
 var $$5101149$us$us = 0, $$5150$us$us = 0, $$pn = 0, $$pn209 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $exitcond$i = 0, $exitcond140$i$us = 0;
 var $exitcond141$i = 0, $exitcond141$i$us = 0, $exitcond145$i = 0, $exitcond148$i$us = 0, $exitcond149$i = 0, $exitcond149$i$us = 0, $exitcond197 = 0, $exitcond198 = 0, $exitcond204 = 0, $exitcond207 = 0, $exitcond208 = 0, $or$cond = 0, $or$cond215 = 0, $or$cond216 = 0, $scevgep193 = 0, $scevgep194 = 0, $scevgep195 = 0, $scevgep202 = 0, $scevgep203 = 0, $scevgep205 = 0;
 var $split$us$i = 0, $split$us$i$us = 0, $split115$us$i = 0, $split115$us$i$us = 0, $split126$us = 0, $split159$us = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $9 = ($1|0)==(1);
 $10 = ($2|0)==(1);
 $or$cond = $9 | $10;
 $11 = $1 >>> 1;
 $12 = $2 >>> 1;
 if ($or$cond) {
  if ($10) {
   $13 = ($11|0)!=(0);
   $14 = ($0|0)>(0);
   $or$cond215 = $13 & $14;
   if (!($or$cond215)) {
    return;
   }
   $15 = ($8|0)==(0);
   $16 = (($0) + -1)|0;
   $17 = Math_imul($16, $5)|0;
   if ($15) {
    $$083100$us$i$us = $3;$$08499$us$i$us = $4;$$08998$us$i$us = 0;
    while(1) {
     $$08894$us$us$i$us = 0;$$18595$us$us$i$us = $$08499$us$i$us;$$196$us$us$i$us = $$083100$us$i$us;
     while(1) {
      $18 = HEAP16[$$196$us$us$i$us>>1]|0;
      $19 = (($$196$us$us$i$us) + ($7)|0);
      $20 = HEAP16[$19>>1]|0;
      $21 = $18&65535;
      $22 = $20&65535;
      $23 = (($22) + ($21))|0;
      $24 = $23 >>> 1;
      $25 = $24&65535;
      HEAP16[$$18595$us$us$i$us>>1] = $25;
      $26 = (($$196$us$us$i$us) + ($5)|0);
      $27 = ((($$18595$us$us$i$us)) + 2|0);
      $28 = (($$08894$us$us$i$us) + 1)|0;
      $exitcond140$i$us = ($28|0)==($0|0);
      if ($exitcond140$i$us) {
       break;
      } else {
       $$08894$us$us$i$us = $28;$$18595$us$us$i$us = $27;$$196$us$us$i$us = $26;
      }
     }
     $29 = (($$083100$us$i$us) + ($17)|0);
     $split$us$i$us = (($$08499$us$i$us) + ($0<<1)|0);
     $30 = (($29) + ($5)|0);
     $31 = (($30) + ($7)|0);
     $32 = (($$08998$us$i$us) + 1)|0;
     $exitcond141$i$us = ($32|0)==($11|0);
     if ($exitcond141$i$us) {
      break;
     } else {
      $$083100$us$i$us = $31;$$08499$us$i$us = $split$us$i$us;$$08998$us$i$us = $32;
     }
    }
    return;
   } else {
    $$083100$us$i = $3;$$08499$us$i = $4;$$08998$us$i = 0;
    while(1) {
     $$08894$us103$i = 0;$$18595$us102$i = $$08499$us$i;$$196$us101$i = $$083100$us$i;
     while(1) {
      $33 = ((($$196$us101$i)) + 1|0);
      $34 = HEAP8[$33>>0]|0;
      $35 = $34&255;
      $36 = $35 << 8;
      $37 = HEAP8[$$196$us101$i>>0]|0;
      $38 = $37&255;
      $39 = $36 | $38;
      $40 = (($$196$us101$i) + ($7)|0);
      $41 = ((($40)) + 1|0);
      $42 = HEAP8[$41>>0]|0;
      $43 = $42&255;
      $44 = $43 << 8;
      $45 = HEAP8[$40>>0]|0;
      $46 = $45&255;
      $47 = $44 | $46;
      $48 = (($47) + ($39))|0;
      $49 = $48 >>> 1;
      $50 = $49&65535;
      HEAP16[$$18595$us102$i>>1] = $50;
      $51 = (($$196$us101$i) + ($5)|0);
      $52 = ((($$18595$us102$i)) + 2|0);
      $53 = (($$08894$us103$i) + 1)|0;
      $exitcond$i = ($53|0)==($0|0);
      if ($exitcond$i) {
       break;
      } else {
       $$08894$us103$i = $53;$$18595$us102$i = $52;$$196$us101$i = $51;
      }
     }
     $54 = (($$083100$us$i) + ($17)|0);
     $split$us$i = (($$08499$us$i) + ($0<<1)|0);
     $55 = (($54) + ($5)|0);
     $56 = (($55) + ($7)|0);
     $57 = (($$08998$us$i) + 1)|0;
     $exitcond141$i = ($57|0)==($11|0);
     if ($exitcond141$i) {
      break;
     } else {
      $$083100$us$i = $56;$$08499$us$i = $split$us$i;$$08998$us$i = $57;
     }
    }
    return;
   }
  }
  if (!($9)) {
   return;
  }
  $58 = (($6) - ($7))|0;
  $59 = ($12|0)!=(0);
  $60 = ($0|0)>(0);
  $or$cond216 = $59 & $60;
  if (!($or$cond216)) {
   return;
  }
  $61 = ($8|0)==(0);
  $62 = (($0) + -1)|0;
  $63 = Math_imul($62, $5)|0;
  if ($61) {
   $$190117$us$i$us = 0;$$2119$us$i$us = $3;$$286118$us$i$us = $4;
   while(1) {
    $$0112$us$us$i$us = 0;$$3111$us$us$i$us = $$2119$us$i$us;$$387110$us$us$i$us = $$286118$us$i$us;
    while(1) {
     $64 = HEAP16[$$3111$us$us$i$us>>1]|0;
     $65 = (($$3111$us$us$i$us) + ($6)|0);
     $66 = HEAP16[$65>>1]|0;
     $67 = $64&65535;
     $68 = $66&65535;
     $69 = (($68) + ($67))|0;
     $70 = $69 >>> 1;
     $71 = $70&65535;
     HEAP16[$$387110$us$us$i$us>>1] = $71;
     $72 = (($$3111$us$us$i$us) + ($5)|0);
     $73 = ((($$387110$us$us$i$us)) + 2|0);
     $74 = (($$0112$us$us$i$us) + 1)|0;
     $exitcond148$i$us = ($74|0)==($0|0);
     if ($exitcond148$i$us) {
      break;
     } else {
      $$0112$us$us$i$us = $74;$$3111$us$us$i$us = $72;$$387110$us$us$i$us = $73;
     }
    }
    $75 = (($$2119$us$i$us) + ($63)|0);
    $split115$us$i$us = (($$286118$us$i$us) + ($0<<1)|0);
    $76 = (($75) + ($5)|0);
    $77 = (($76) + ($58)|0);
    $78 = (($77) + ($6)|0);
    $79 = (($$190117$us$i$us) + 1)|0;
    $exitcond149$i$us = ($79|0)==($12|0);
    if ($exitcond149$i$us) {
     break;
    } else {
     $$190117$us$i$us = $79;$$2119$us$i$us = $78;$$286118$us$i$us = $split115$us$i$us;
    }
   }
   return;
  } else {
   $$190117$us$i = 0;$$2119$us$i = $3;$$286118$us$i = $4;
   while(1) {
    $$0112$us120$i = 0;$$3111$us121$i = $$2119$us$i;$$387110$us122$i = $$286118$us$i;
    while(1) {
     $80 = ((($$3111$us121$i)) + 1|0);
     $81 = HEAP8[$80>>0]|0;
     $82 = $81&255;
     $83 = $82 << 8;
     $84 = HEAP8[$$3111$us121$i>>0]|0;
     $85 = $84&255;
     $86 = $83 | $85;
     $87 = (($$3111$us121$i) + ($6)|0);
     $88 = ((($87)) + 1|0);
     $89 = HEAP8[$88>>0]|0;
     $90 = $89&255;
     $91 = $90 << 8;
     $92 = HEAP8[$87>>0]|0;
     $93 = $92&255;
     $94 = $91 | $93;
     $95 = (($94) + ($86))|0;
     $96 = $95 >>> 1;
     $97 = $96&65535;
     HEAP16[$$387110$us122$i>>1] = $97;
     $98 = (($$3111$us121$i) + ($5)|0);
     $99 = ((($$387110$us122$i)) + 2|0);
     $100 = (($$0112$us120$i) + 1)|0;
     $exitcond145$i = ($100|0)==($0|0);
     if ($exitcond145$i) {
      break;
     } else {
      $$0112$us120$i = $100;$$3111$us121$i = $98;$$387110$us122$i = $99;
     }
    }
    $101 = (($$2119$us$i) + ($63)|0);
    $split115$us$i = (($$286118$us$i) + ($0<<1)|0);
    $102 = (($101) + ($5)|0);
    $103 = (($102) + ($58)|0);
    $104 = (($103) + ($6)|0);
    $105 = (($$190117$us$i) + 1)|0;
    $exitcond149$i = ($105|0)==($12|0);
    if ($exitcond149$i) {
     break;
    } else {
     $$190117$us$i = $105;$$2119$us$i = $104;$$286118$us$i = $split115$us$i;
    }
   }
   return;
  }
 } else {
  $106 = Math_imul($7, $1)|0;
  $107 = (($6) - ($106))|0;
  $108 = ($8|0)==(0);
  $109 = ($12|0)!=(0);
  if ($108) {
   if (!($109)) {
    return;
   }
   $166 = ($11|0)==(0);
   $167 = ($0|0)>(0);
   if ($166) {
    return;
   }
   $168 = (($11) + -1)|0;
   $169 = Math_imul($168, $7)|0;
   $170 = Math_imul($5, $0)|0;
   $171 = Math_imul($11, $0)|0;
   $172 = (($170) + ($7))|0;
   $173 = Math_imul($172, $168)|0;
   $174 = (($170) + ($173))|0;
   $$0102128$us = 0;$$0130$us = $3;$$096129$us = $4;
   while(1) {
    if ($167) {
     $scevgep195 = (($$096129$us) + ($171<<1)|0);
     $$0104122$us$us = 0;$$1124$us$us = $$0130$us;$$197123$us$us = $$096129$us;
     while(1) {
      $scevgep193 = (($$197123$us$us) + ($0<<1)|0);
      $$0106118$us$us = 0;$$2120$us$us = $$1124$us$us;$$298119$us$us = $$197123$us$us;
      while(1) {
       $182 = HEAP16[$$2120$us$us>>1]|0;
       $183 = $182&65535;
       $184 = (($$2120$us$us) + ($7)|0);
       $185 = HEAP16[$184>>1]|0;
       $186 = $185&65535;
       $187 = (($$2120$us$us) + ($6)|0);
       $188 = HEAP16[$187>>1]|0;
       $189 = $188&65535;
       $190 = (($187) + ($7)|0);
       $191 = HEAP16[$190>>1]|0;
       $192 = $191&65535;
       $193 = (($183) + 2)|0;
       $194 = (($193) + ($186))|0;
       $195 = (($194) + ($189))|0;
       $196 = (($195) + ($192))|0;
       $197 = $196 >>> 2;
       $198 = $197&65535;
       HEAP16[$$298119$us$us>>1] = $198;
       $199 = ((($$298119$us$us)) + 2|0);
       $200 = (($$2120$us$us) + ($5)|0);
       $201 = (($$0106118$us$us) + 1)|0;
       $exitcond = ($201|0)==($0|0);
       if ($exitcond) {
        break;
       } else {
        $$0106118$us$us = $201;$$2120$us$us = $200;$$298119$us$us = $199;
       }
      }
      $scevgep194 = (($$1124$us$us) + ($170)|0);
      $180 = (($scevgep194) + ($7)|0);
      $181 = (($$0104122$us$us) + 1)|0;
      $exitcond197 = ($181|0)==($11|0);
      if ($exitcond197) {
       $$pn209 = $174;$split126$us = $scevgep195;
       break;
      } else {
       $$0104122$us$us = $181;$$1124$us$us = $180;$$197123$us$us = $scevgep193;
      }
     }
    } else {
     $$pn209 = $169;$split126$us = $$096129$us;
    }
    $175 = (($$0130$us) + ($$pn209)|0);
    $176 = (($175) + ($7)|0);
    $177 = (($176) + ($107)|0);
    $178 = (($177) + ($6)|0);
    $179 = (($$0102128$us) + 1)|0;
    $exitcond198 = ($179|0)==($12|0);
    if ($exitcond198) {
     break;
    } else {
     $$0102128$us = $179;$$0130$us = $178;$$096129$us = $split126$us;
    }
   }
   return;
  } else {
   if (!($109)) {
    return;
   }
   $110 = ($11|0)==(0);
   $111 = ($0|0)>(0);
   if ($110) {
    return;
   }
   $112 = (($11) + -1)|0;
   $113 = Math_imul($112, $7)|0;
   $114 = Math_imul($5, $0)|0;
   $115 = Math_imul($11, $0)|0;
   $116 = (($114) + ($7))|0;
   $117 = Math_imul($116, $112)|0;
   $118 = (($114) + ($117))|0;
   $$1103161$us = 0;$$3163$us = $3;$$399162$us = $4;
   while(1) {
    if ($111) {
     $scevgep205 = (($$399162$us) + ($115<<1)|0);
     $$1105155$us$us = 0;$$4100156$us$us = $$399162$us;$$4157$us$us = $$3163$us;
     while(1) {
      $scevgep202 = (($$4100156$us$us) + ($0<<1)|0);
      $$1107148$us$us = 0;$$5101149$us$us = $$4100156$us$us;$$5150$us$us = $$4157$us$us;
      while(1) {
       $126 = ((($$5150$us$us)) + 1|0);
       $127 = HEAP8[$126>>0]|0;
       $128 = $127&255;
       $129 = $128 << 8;
       $130 = HEAP8[$$5150$us$us>>0]|0;
       $131 = $130&255;
       $132 = $129 | $131;
       $133 = (($$5150$us$us) + ($7)|0);
       $134 = ((($133)) + 1|0);
       $135 = HEAP8[$134>>0]|0;
       $136 = $135&255;
       $137 = $136 << 8;
       $138 = HEAP8[$133>>0]|0;
       $139 = $138&255;
       $140 = $137 | $139;
       $141 = (($$5150$us$us) + ($6)|0);
       $142 = ((($141)) + 1|0);
       $143 = HEAP8[$142>>0]|0;
       $144 = $143&255;
       $145 = $144 << 8;
       $146 = HEAP8[$141>>0]|0;
       $147 = $146&255;
       $148 = $145 | $147;
       $149 = (($141) + ($7)|0);
       $150 = ((($149)) + 1|0);
       $151 = HEAP8[$150>>0]|0;
       $152 = $151&255;
       $153 = $152 << 8;
       $154 = HEAP8[$149>>0]|0;
       $155 = $154&255;
       $156 = $153 | $155;
       $157 = (($132) + 2)|0;
       $158 = (($157) + ($140))|0;
       $159 = (($158) + ($148))|0;
       $160 = (($159) + ($156))|0;
       $161 = (($160|0) / 4)&-1;
       $162 = $161&65535;
       HEAP16[$$5101149$us$us>>1] = $162;
       $163 = ((($$5101149$us$us)) + 2|0);
       $164 = (($$5150$us$us) + ($5)|0);
       $165 = (($$1107148$us$us) + 1)|0;
       $exitcond204 = ($165|0)==($0|0);
       if ($exitcond204) {
        break;
       } else {
        $$1107148$us$us = $165;$$5101149$us$us = $163;$$5150$us$us = $164;
       }
      }
      $scevgep203 = (($$4157$us$us) + ($114)|0);
      $124 = (($scevgep203) + ($7)|0);
      $125 = (($$1105155$us$us) + 1)|0;
      $exitcond207 = ($125|0)==($11|0);
      if ($exitcond207) {
       $$pn = $118;$split159$us = $scevgep205;
       break;
      } else {
       $$1105155$us$us = $125;$$4100156$us$us = $scevgep202;$$4157$us$us = $124;
      }
     }
    } else {
     $$pn = $113;$split159$us = $$399162$us;
    }
    $119 = (($$3163$us) + ($$pn)|0);
    $120 = (($119) + ($7)|0);
    $121 = (($120) + ($107)|0);
    $122 = (($121) + ($6)|0);
    $123 = (($$1103161$us) + 1)|0;
    $exitcond208 = ($123|0)==($12|0);
    if ($exitcond208) {
     break;
    } else {
     $$1103161$us = $123;$$3163$us = $122;$$399162$us = $split159$us;
    }
   }
   return;
  }
 }
}
function __ZN3osgL16halveImage_shortEijjPKsPsiiii($0,$1,$2,$3,$4,$5,$6,$7,$8) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 $8 = $8|0;
 var $$0108139$us$us = 0, $$0110144$us = 0, $$0112$us$us$i$us = 0, $$0112$us120$i = 0, $$0112143$us = 0, $$0118133$us$us = 0, $$0145$us = 0, $$083100$us$i = 0, $$083100$us$i$us = 0, $$08499$us$i = 0, $$08499$us$i$us = 0, $$08894$us$us$i$us = 0, $$08894$us103$i = 0, $$08998$us$i = 0, $$08998$us$i$us = 0, $$1109172$us = 0, $$1111138$us$us = 0, $$1113137$us$us = 0, $$1119163$us = 0, $$1178 = 0;
 var $$18595$us$us$i$us = 0, $$18595$us102$i = 0, $$190117$us$i = 0, $$190117$us$i$us = 0, $$196$us$us$i$us = 0, $$196$us101$i = 0, $$2114134$us$us = 0, $$2119$us$i = 0, $$2119$us$i$us = 0, $$2135$us$us = 0, $$286118$us$i = 0, $$286118$us$i$us = 0, $$3111$us$us$i$us = 0, $$3111$us121$i = 0, $$3115176 = 0, $$3177 = 0, $$387110$us$us$i$us = 0, $$387110$us122$i = 0, $$4$lcssa = 0, $$4116$lcssa = 0;
 var $$4116170$us = 0, $$4171$us = 0, $$5117164$us = 0, $$5165$us = 0, $$pn = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0;
 var $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $exitcond = 0, $exitcond$i = 0, $exitcond143$i$us = 0, $exitcond144$i = 0, $exitcond144$i$us = 0, $exitcond148$i = 0, $exitcond151$i$us = 0, $exitcond152$i = 0, $exitcond152$i$us = 0, $exitcond196 = 0, $exitcond197 = 0, $exitcond202 = 0, $exitcond205 = 0, $exitcond206 = 0, $or$cond = 0, $or$cond212 = 0, $or$cond213 = 0, $scevgep192 = 0;
 var $scevgep193 = 0, $scevgep194 = 0, $scevgep198 = 0, $scevgep200 = 0, $scevgep201 = 0, $scevgep203 = 0, $scevgep204 = 0, $sext$i = 0, $sext$us = 0, $sext120$us = 0, $sext121$us = 0, $sext122$us = 0, $sext129$i = 0, $sext130$i = 0, $sext131$i = 0, $split$us$i = 0, $split$us$i$us = 0, $split115$us$i = 0, $split115$us$i$us = 0, $split141$us = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $9 = ($1|0)==(1);
 $10 = ($2|0)==(1);
 $or$cond = $9 | $10;
 $11 = $1 >>> 1;
 $12 = $2 >>> 1;
 if ($or$cond) {
  if ($10) {
   $13 = ($11|0)!=(0);
   $14 = ($0|0)>(0);
   $or$cond212 = $13 & $14;
   if (!($or$cond212)) {
    return;
   }
   $15 = ($8|0)==(0);
   $16 = (($0) + -1)|0;
   $17 = Math_imul($16, $5)|0;
   if ($15) {
    $$083100$us$i$us = $3;$$08499$us$i$us = $4;$$08998$us$i$us = 0;
    while(1) {
     $$08894$us$us$i$us = 0;$$18595$us$us$i$us = $$08499$us$i$us;$$196$us$us$i$us = $$083100$us$i$us;
     while(1) {
      $18 = HEAP16[$$196$us$us$i$us>>1]|0;
      $19 = (($$196$us$us$i$us) + ($7)|0);
      $20 = HEAP16[$19>>1]|0;
      $21 = $18 << 16 >> 16;
      $22 = $20 << 16 >> 16;
      $23 = (($22) + ($21))|0;
      $24 = (($23|0) / 2)&-1;
      $25 = $24&65535;
      HEAP16[$$18595$us$us$i$us>>1] = $25;
      $26 = (($$196$us$us$i$us) + ($5)|0);
      $27 = ((($$18595$us$us$i$us)) + 2|0);
      $28 = (($$08894$us$us$i$us) + 1)|0;
      $exitcond143$i$us = ($28|0)==($0|0);
      if ($exitcond143$i$us) {
       break;
      } else {
       $$08894$us$us$i$us = $28;$$18595$us$us$i$us = $27;$$196$us$us$i$us = $26;
      }
     }
     $29 = (($$083100$us$i$us) + ($17)|0);
     $split$us$i$us = (($$08499$us$i$us) + ($0<<1)|0);
     $30 = (($29) + ($5)|0);
     $31 = (($30) + ($7)|0);
     $32 = (($$08998$us$i$us) + 1)|0;
     $exitcond144$i$us = ($32|0)==($11|0);
     if ($exitcond144$i$us) {
      break;
     } else {
      $$083100$us$i$us = $31;$$08499$us$i$us = $split$us$i$us;$$08998$us$i$us = $32;
     }
    }
    return;
   } else {
    $$083100$us$i = $3;$$08499$us$i = $4;$$08998$us$i = 0;
    while(1) {
     $$08894$us103$i = 0;$$18595$us102$i = $$08499$us$i;$$196$us101$i = $$083100$us$i;
     while(1) {
      $33 = ((($$196$us101$i)) + 1|0);
      $34 = HEAP8[$33>>0]|0;
      $35 = $34&255;
      $36 = $35 << 8;
      $37 = HEAP8[$$196$us101$i>>0]|0;
      $38 = $37&255;
      $39 = $36 | $38;
      $40 = (($$196$us101$i) + ($7)|0);
      $41 = ((($40)) + 1|0);
      $42 = HEAP8[$41>>0]|0;
      $43 = $42&255;
      $44 = $43 << 8;
      $45 = HEAP8[$40>>0]|0;
      $46 = $45&255;
      $47 = $44 | $46;
      $sext130$i = $39 << 16;
      $48 = $sext130$i >> 16;
      $sext131$i = $47 << 16;
      $49 = $sext131$i >> 16;
      $50 = (($49) + ($48))|0;
      $51 = (($50|0) / 2)&-1;
      $52 = $51&65535;
      HEAP16[$$18595$us102$i>>1] = $52;
      $53 = (($$196$us101$i) + ($5)|0);
      $54 = ((($$18595$us102$i)) + 2|0);
      $55 = (($$08894$us103$i) + 1)|0;
      $exitcond$i = ($55|0)==($0|0);
      if ($exitcond$i) {
       break;
      } else {
       $$08894$us103$i = $55;$$18595$us102$i = $54;$$196$us101$i = $53;
      }
     }
     $56 = (($$083100$us$i) + ($17)|0);
     $split$us$i = (($$08499$us$i) + ($0<<1)|0);
     $57 = (($56) + ($5)|0);
     $58 = (($57) + ($7)|0);
     $59 = (($$08998$us$i) + 1)|0;
     $exitcond144$i = ($59|0)==($11|0);
     if ($exitcond144$i) {
      break;
     } else {
      $$083100$us$i = $58;$$08499$us$i = $split$us$i;$$08998$us$i = $59;
     }
    }
    return;
   }
  }
  if (!($9)) {
   return;
  }
  $60 = (($6) - ($7))|0;
  $61 = ($12|0)!=(0);
  $62 = ($0|0)>(0);
  $or$cond213 = $61 & $62;
  if (!($or$cond213)) {
   return;
  }
  $63 = ($8|0)==(0);
  $64 = (($0) + -1)|0;
  $65 = Math_imul($64, $5)|0;
  if ($63) {
   $$190117$us$i$us = 0;$$2119$us$i$us = $3;$$286118$us$i$us = $4;
   while(1) {
    $$0112$us$us$i$us = 0;$$3111$us$us$i$us = $$2119$us$i$us;$$387110$us$us$i$us = $$286118$us$i$us;
    while(1) {
     $66 = HEAP16[$$3111$us$us$i$us>>1]|0;
     $67 = (($$3111$us$us$i$us) + ($6)|0);
     $68 = HEAP16[$67>>1]|0;
     $69 = $66 << 16 >> 16;
     $70 = $68 << 16 >> 16;
     $71 = (($70) + ($69))|0;
     $72 = (($71|0) / 2)&-1;
     $73 = $72&65535;
     HEAP16[$$387110$us$us$i$us>>1] = $73;
     $74 = (($$3111$us$us$i$us) + ($5)|0);
     $75 = ((($$387110$us$us$i$us)) + 2|0);
     $76 = (($$0112$us$us$i$us) + 1)|0;
     $exitcond151$i$us = ($76|0)==($0|0);
     if ($exitcond151$i$us) {
      break;
     } else {
      $$0112$us$us$i$us = $76;$$3111$us$us$i$us = $74;$$387110$us$us$i$us = $75;
     }
    }
    $77 = (($$2119$us$i$us) + ($65)|0);
    $split115$us$i$us = (($$286118$us$i$us) + ($0<<1)|0);
    $78 = (($77) + ($5)|0);
    $79 = (($78) + ($60)|0);
    $80 = (($79) + ($6)|0);
    $81 = (($$190117$us$i$us) + 1)|0;
    $exitcond152$i$us = ($81|0)==($12|0);
    if ($exitcond152$i$us) {
     break;
    } else {
     $$190117$us$i$us = $81;$$2119$us$i$us = $80;$$286118$us$i$us = $split115$us$i$us;
    }
   }
   return;
  } else {
   $$190117$us$i = 0;$$2119$us$i = $3;$$286118$us$i = $4;
   while(1) {
    $$0112$us120$i = 0;$$3111$us121$i = $$2119$us$i;$$387110$us122$i = $$286118$us$i;
    while(1) {
     $82 = ((($$3111$us121$i)) + 1|0);
     $83 = HEAP8[$82>>0]|0;
     $84 = $83&255;
     $85 = $84 << 8;
     $86 = HEAP8[$$3111$us121$i>>0]|0;
     $87 = $86&255;
     $88 = $85 | $87;
     $89 = (($$3111$us121$i) + ($6)|0);
     $90 = ((($89)) + 1|0);
     $91 = HEAP8[$90>>0]|0;
     $92 = $91&255;
     $93 = $92 << 8;
     $94 = HEAP8[$89>>0]|0;
     $95 = $94&255;
     $96 = $93 | $95;
     $sext$i = $88 << 16;
     $97 = $sext$i >> 16;
     $sext129$i = $96 << 16;
     $98 = $sext129$i >> 16;
     $99 = (($98) + ($97))|0;
     $100 = (($99|0) / 2)&-1;
     $101 = $100&65535;
     HEAP16[$$387110$us122$i>>1] = $101;
     $102 = (($$3111$us121$i) + ($5)|0);
     $103 = ((($$387110$us122$i)) + 2|0);
     $104 = (($$0112$us120$i) + 1)|0;
     $exitcond148$i = ($104|0)==($0|0);
     if ($exitcond148$i) {
      break;
     } else {
      $$0112$us120$i = $104;$$3111$us121$i = $102;$$387110$us122$i = $103;
     }
    }
    $105 = (($$2119$us$i) + ($65)|0);
    $split115$us$i = (($$286118$us$i) + ($0<<1)|0);
    $106 = (($105) + ($5)|0);
    $107 = (($106) + ($60)|0);
    $108 = (($107) + ($6)|0);
    $109 = (($$190117$us$i) + 1)|0;
    $exitcond152$i = ($109|0)==($12|0);
    if ($exitcond152$i) {
     break;
    } else {
     $$190117$us$i = $109;$$2119$us$i = $108;$$286118$us$i = $split115$us$i;
    }
   }
   return;
  }
 }
 $110 = Math_imul($7, $1)|0;
 $111 = (($6) - ($110))|0;
 $112 = ($8|0)==(0);
 $113 = ($12|0)!=(0);
 if ($112) {
  if (!($113)) {
   return;
  }
  $121 = ($11|0)==(0);
  $122 = ($0|0)>(0);
  if ($121) {
   return;
  }
  $123 = (($11) + -1)|0;
  $124 = Math_imul($123, $7)|0;
  $125 = Math_imul($5, $0)|0;
  $126 = Math_imul($11, $0)|0;
  $127 = (($125) + ($7))|0;
  $128 = Math_imul($127, $123)|0;
  $129 = (($125) + ($128))|0;
  $$0110144$us = $3;$$0112143$us = $4;$$0145$us = 0;
  while(1) {
   if ($122) {
    $scevgep194 = (($$0112143$us) + ($126<<1)|0);
    $$0108139$us$us = 0;$$1111138$us$us = $$0110144$us;$$1113137$us$us = $$0112143$us;
    while(1) {
     $scevgep192 = (($$1113137$us$us) + ($0<<1)|0);
     $$0118133$us$us = 0;$$2114134$us$us = $$1113137$us$us;$$2135$us$us = $$1111138$us$us;
     while(1) {
      $137 = HEAP16[$$2135$us$us>>1]|0;
      $138 = $137 << 16 >> 16;
      $139 = (($$2135$us$us) + ($7)|0);
      $140 = HEAP16[$139>>1]|0;
      $141 = $140 << 16 >> 16;
      $142 = (($$2135$us$us) + ($6)|0);
      $143 = HEAP16[$142>>1]|0;
      $144 = $143 << 16 >> 16;
      $145 = (($142) + ($7)|0);
      $146 = HEAP16[$145>>1]|0;
      $147 = $146 << 16 >> 16;
      $148 = (($138) + 2)|0;
      $149 = (($148) + ($141))|0;
      $150 = (($149) + ($144))|0;
      $151 = (($150) + ($147))|0;
      $152 = (($151|0) / 4)&-1;
      $153 = $152&65535;
      HEAP16[$$2114134$us$us>>1] = $153;
      $154 = ((($$2114134$us$us)) + 2|0);
      $155 = (($$2135$us$us) + ($5)|0);
      $156 = (($$0118133$us$us) + 1)|0;
      $exitcond = ($156|0)==($0|0);
      if ($exitcond) {
       break;
      } else {
       $$0118133$us$us = $156;$$2114134$us$us = $154;$$2135$us$us = $155;
      }
     }
     $scevgep193 = (($$1111138$us$us) + ($125)|0);
     $135 = (($scevgep193) + ($7)|0);
     $136 = (($$0108139$us$us) + 1)|0;
     $exitcond196 = ($136|0)==($11|0);
     if ($exitcond196) {
      $$pn = $129;$split141$us = $scevgep194;
      break;
     } else {
      $$0108139$us$us = $136;$$1111138$us$us = $135;$$1113137$us$us = $scevgep192;
     }
    }
   } else {
    $$pn = $124;$split141$us = $$0112143$us;
   }
   $130 = (($$0110144$us) + ($$pn)|0);
   $131 = (($130) + ($7)|0);
   $132 = (($131) + ($111)|0);
   $133 = (($132) + ($6)|0);
   $134 = (($$0145$us) + 1)|0;
   $exitcond197 = ($134|0)==($12|0);
   if ($exitcond197) {
    break;
   } else {
    $$0110144$us = $133;$$0112143$us = $split141$us;$$0145$us = $134;
   }
  }
  return;
 }
 if (!($113)) {
  return;
 }
 $114 = ($11|0)==(0);
 $115 = ($0|0)>(0);
 $116 = Math_imul($11, $7)|0;
 $117 = Math_imul($5, $0)|0;
 $118 = (($117) + ($7))|0;
 $119 = Math_imul($118, $11)|0;
 $120 = Math_imul($11, $0)|0;
 $$1178 = 0;$$3115176 = $4;$$3177 = $3;
 while(1) {
  do {
   if ($114) {
    $$4$lcssa = $$3177;$$4116$lcssa = $$3115176;
   } else {
    if (!($115)) {
     $scevgep198 = (($$3177) + ($116)|0);
     $$4$lcssa = $scevgep198;$$4116$lcssa = $$3115176;
     break;
    }
    $scevgep203 = (($$3177) + ($119)|0);
    $$1109172$us = 0;$$4116170$us = $$3115176;$$4171$us = $$3177;
    while(1) {
     $scevgep200 = (($$4116170$us) + ($0<<1)|0);
     $$1119163$us = 0;$$5117164$us = $$4116170$us;$$5165$us = $$4171$us;
     while(1) {
      $157 = ((($$5165$us)) + 1|0);
      $158 = HEAP8[$157>>0]|0;
      $159 = $158&255;
      $160 = $159 << 8;
      $161 = HEAP8[$$5165$us>>0]|0;
      $162 = $161&255;
      $163 = $160 | $162;
      $sext$us = $163 << 16;
      $164 = $sext$us >> 16;
      $165 = (($$5165$us) + ($7)|0);
      $166 = ((($165)) + 1|0);
      $167 = HEAP8[$166>>0]|0;
      $168 = $167&255;
      $169 = $168 << 8;
      $170 = HEAP8[$165>>0]|0;
      $171 = $170&255;
      $172 = $169 | $171;
      $sext120$us = $172 << 16;
      $173 = $sext120$us >> 16;
      $174 = (($$5165$us) + ($6)|0);
      $175 = ((($174)) + 1|0);
      $176 = HEAP8[$175>>0]|0;
      $177 = $176&255;
      $178 = $177 << 8;
      $179 = HEAP8[$174>>0]|0;
      $180 = $179&255;
      $181 = $178 | $180;
      $sext121$us = $181 << 16;
      $182 = $sext121$us >> 16;
      $183 = (($174) + ($7)|0);
      $184 = ((($183)) + 1|0);
      $185 = HEAP8[$184>>0]|0;
      $186 = $185&255;
      $187 = $186 << 8;
      $188 = HEAP8[$183>>0]|0;
      $189 = $188&255;
      $190 = $187 | $189;
      $sext122$us = $190 << 16;
      $191 = $sext122$us >> 16;
      $192 = (($164) + 2)|0;
      $193 = (($192) + ($173))|0;
      $194 = (($193) + ($182))|0;
      $195 = (($194) + ($191))|0;
      $196 = (($195|0) / 4)&-1;
      $197 = $196&65535;
      HEAP16[$$5117164$us>>1] = $197;
      $198 = ((($$5117164$us)) + 2|0);
      $199 = (($$5165$us) + ($5)|0);
      $200 = (($$1119163$us) + 1)|0;
      $exitcond202 = ($200|0)==($0|0);
      if ($exitcond202) {
       break;
      } else {
       $$1119163$us = $200;$$5117164$us = $198;$$5165$us = $199;
      }
     }
     $scevgep201 = (($$4171$us) + ($117)|0);
     $201 = (($scevgep201) + ($7)|0);
     $202 = (($$1109172$us) + 1)|0;
     $exitcond205 = ($202|0)==($11|0);
     if ($exitcond205) {
      break;
     } else {
      $$1109172$us = $202;$$4116170$us = $scevgep200;$$4171$us = $201;
     }
    }
    $scevgep204 = (($$3115176) + ($120<<1)|0);
    $$4$lcssa = $scevgep203;$$4116$lcssa = $scevgep204;
   }
  } while(0);
  $203 = (($$4$lcssa) + ($111)|0);
  $204 = (($203) + ($6)|0);
  $205 = (($$1178) + 1)|0;
  $exitcond206 = ($205|0)==($12|0);
  if ($exitcond206) {
   break;
  } else {
   $$1178 = $205;$$3115176 = $$4116$lcssa;$$3177 = $204;
  }
 }
 return;
}
function __ZN3osgL15halveImage_uintEijjPKjPjiiii($0,$1,$2,$3,$4,$5,$6,$7,$8) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 $8 = $8|0;
 var $$0100106$us$us$i$us = 0, $$0100106$us115$i = 0, $$0101110$us$i = 0, $$0101110$us$i$us = 0, $$0118146$us$us = 0, $$0120151$us = 0, $$0122150$us = 0, $$0124$us$us$i$us = 0, $$0124$us132$i = 0, $$0128140$us$us = 0, $$0152$us = 0, $$095112$us$i = 0, $$095112$us$i$us = 0, $$096111$us$i = 0, $$096111$us$i$us = 0, $$1102129$us$i = 0, $$1102129$us$i$us = 0, $$1108$us$us$i$us = 0, $$1108$us113$i = 0, $$1119179$us = 0;
 var $$1121145$us$us = 0, $$1123144$us$us = 0, $$1129170$us = 0, $$1185 = 0, $$197107$us$us$i$us = 0, $$197107$us114$i = 0, $$2124141$us$us = 0, $$2131$us$i = 0, $$2131$us$i$us = 0, $$2142$us$us = 0, $$298130$us$i = 0, $$298130$us$i$us = 0, $$3123$us$us$i$us = 0, $$3123$us133$i = 0, $$3125183 = 0, $$3184 = 0, $$399122$us$us$i$us = 0, $$399122$us134$i = 0, $$4$lcssa = 0, $$4126$lcssa = 0;
 var $$4126177$us = 0, $$4178$us = 0, $$5127171$us = 0, $$5172$us = 0, $$pn = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0.0, $138 = 0.0, $139 = 0.0, $14 = 0, $140 = 0.0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0.0, $179 = 0, $18 = 0, $180 = 0, $181 = 0.0, $182 = 0.0, $183 = 0, $184 = 0, $185 = 0.0;
 var $186 = 0.0, $187 = 0, $188 = 0, $189 = 0.0, $19 = 0, $190 = 0.0, $191 = 0.0, $192 = 0.0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0.0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0.0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0.0, $220 = 0, $221 = 0;
 var $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0.0, $230 = 0, $231 = 0, $232 = 0, $233 = 0.0, $234 = 0.0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0.0;
 var $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0.0, $254 = 0.0, $255 = 0, $256 = 0, $257 = 0, $258 = 0;
 var $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0.0, $274 = 0.0, $275 = 0.0, $276 = 0.0;
 var $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0.0, $69 = 0.0, $70 = 0.0, $71 = 0.0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0.0, $9 = 0, $90 = 0.0, $91 = 0.0, $92 = 0.0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $exitcond = 0, $exitcond$i = 0, $exitcond152$i$us = 0, $exitcond153$i = 0, $exitcond153$i$us = 0, $exitcond157$i = 0, $exitcond160$i$us = 0, $exitcond161$i = 0, $exitcond161$i$us = 0, $exitcond203 = 0, $exitcond204 = 0, $exitcond209 = 0, $exitcond212 = 0, $exitcond213 = 0, $or$cond = 0, $or$cond219 = 0, $or$cond220 = 0, $scevgep199 = 0;
 var $scevgep200 = 0, $scevgep201 = 0, $scevgep205 = 0, $scevgep207 = 0, $scevgep208 = 0, $scevgep210 = 0, $scevgep211 = 0, $split$us$i = 0, $split$us$i$us = 0, $split127$us$i = 0, $split127$us$i$us = 0, $split148$us = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $9 = ($1|0)==(1);
 $10 = ($2|0)==(1);
 $or$cond = $9 | $10;
 $11 = $1 >>> 1;
 $12 = $2 >>> 1;
 if ($or$cond) {
  if ($10) {
   $13 = ($11|0)!=(0);
   $14 = ($0|0)>(0);
   $or$cond219 = $13 & $14;
   if (!($or$cond219)) {
    return;
   }
   $15 = ($8|0)==(0);
   $16 = (($0) + -1)|0;
   $17 = Math_imul($16, $5)|0;
   if ($15) {
    $$0101110$us$i$us = 0;$$095112$us$i$us = $3;$$096111$us$i$us = $4;
    while(1) {
     $$0100106$us$us$i$us = 0;$$1108$us$us$i$us = $$095112$us$i$us;$$197107$us$us$i$us = $$096111$us$i$us;
     while(1) {
      $18 = HEAP32[$$1108$us$us$i$us>>2]|0;
      $19 = (($$1108$us$us$i$us) + ($7)|0);
      $20 = HEAP32[$19>>2]|0;
      $21 = (+($18>>>0));
      $22 = (+($20>>>0));
      $23 = $21 + $22;
      $24 = $23 * 0.5;
      $25 = (~~(($24))>>>0);
      HEAP32[$$197107$us$us$i$us>>2] = $25;
      $26 = (($$1108$us$us$i$us) + ($5)|0);
      $27 = ((($$197107$us$us$i$us)) + 4|0);
      $28 = (($$0100106$us$us$i$us) + 1)|0;
      $exitcond152$i$us = ($28|0)==($0|0);
      if ($exitcond152$i$us) {
       break;
      } else {
       $$0100106$us$us$i$us = $28;$$1108$us$us$i$us = $26;$$197107$us$us$i$us = $27;
      }
     }
     $29 = (($$095112$us$i$us) + ($17)|0);
     $split$us$i$us = (($$096111$us$i$us) + ($0<<2)|0);
     $30 = (($29) + ($5)|0);
     $31 = (($30) + ($7)|0);
     $32 = (($$0101110$us$i$us) + 1)|0;
     $exitcond153$i$us = ($32|0)==($11|0);
     if ($exitcond153$i$us) {
      break;
     } else {
      $$0101110$us$i$us = $32;$$095112$us$i$us = $31;$$096111$us$i$us = $split$us$i$us;
     }
    }
    return;
   } else {
    $$0101110$us$i = 0;$$095112$us$i = $3;$$096111$us$i = $4;
    while(1) {
     $$0100106$us115$i = 0;$$1108$us113$i = $$095112$us$i;$$197107$us114$i = $$096111$us$i;
     while(1) {
      $33 = ((($$1108$us113$i)) + 3|0);
      $34 = HEAP8[$33>>0]|0;
      $35 = $34&255;
      $36 = $35 << 24;
      $37 = ((($$1108$us113$i)) + 2|0);
      $38 = HEAP8[$37>>0]|0;
      $39 = $38&255;
      $40 = $39 << 16;
      $41 = $40 | $36;
      $42 = ((($$1108$us113$i)) + 1|0);
      $43 = HEAP8[$42>>0]|0;
      $44 = $43&255;
      $45 = $44 << 8;
      $46 = $41 | $45;
      $47 = HEAP8[$$1108$us113$i>>0]|0;
      $48 = $47&255;
      $49 = $46 | $48;
      $50 = (($$1108$us113$i) + ($7)|0);
      $51 = ((($50)) + 3|0);
      $52 = HEAP8[$51>>0]|0;
      $53 = $52&255;
      $54 = $53 << 24;
      $55 = ((($50)) + 2|0);
      $56 = HEAP8[$55>>0]|0;
      $57 = $56&255;
      $58 = $57 << 16;
      $59 = $58 | $54;
      $60 = ((($50)) + 1|0);
      $61 = HEAP8[$60>>0]|0;
      $62 = $61&255;
      $63 = $62 << 8;
      $64 = $59 | $63;
      $65 = HEAP8[$50>>0]|0;
      $66 = $65&255;
      $67 = $64 | $66;
      $68 = (+($49>>>0));
      $69 = (+($67>>>0));
      $70 = $68 + $69;
      $71 = $70 * 0.5;
      $72 = (~~(($71))>>>0);
      HEAP32[$$197107$us114$i>>2] = $72;
      $73 = (($$1108$us113$i) + ($5)|0);
      $74 = ((($$197107$us114$i)) + 4|0);
      $75 = (($$0100106$us115$i) + 1)|0;
      $exitcond$i = ($75|0)==($0|0);
      if ($exitcond$i) {
       break;
      } else {
       $$0100106$us115$i = $75;$$1108$us113$i = $73;$$197107$us114$i = $74;
      }
     }
     $76 = (($$095112$us$i) + ($17)|0);
     $split$us$i = (($$096111$us$i) + ($0<<2)|0);
     $77 = (($76) + ($5)|0);
     $78 = (($77) + ($7)|0);
     $79 = (($$0101110$us$i) + 1)|0;
     $exitcond153$i = ($79|0)==($11|0);
     if ($exitcond153$i) {
      break;
     } else {
      $$0101110$us$i = $79;$$095112$us$i = $78;$$096111$us$i = $split$us$i;
     }
    }
    return;
   }
  }
  if (!($9)) {
   return;
  }
  $80 = (($6) - ($7))|0;
  $81 = ($12|0)!=(0);
  $82 = ($0|0)>(0);
  $or$cond220 = $81 & $82;
  if (!($or$cond220)) {
   return;
  }
  $83 = ($8|0)==(0);
  $84 = (($0) + -1)|0;
  $85 = Math_imul($84, $5)|0;
  if ($83) {
   $$1102129$us$i$us = 0;$$2131$us$i$us = $3;$$298130$us$i$us = $4;
   while(1) {
    $$0124$us$us$i$us = 0;$$3123$us$us$i$us = $$2131$us$i$us;$$399122$us$us$i$us = $$298130$us$i$us;
    while(1) {
     $86 = HEAP32[$$3123$us$us$i$us>>2]|0;
     $87 = (($$3123$us$us$i$us) + ($6)|0);
     $88 = HEAP32[$87>>2]|0;
     $89 = (+($86>>>0));
     $90 = (+($88>>>0));
     $91 = $89 + $90;
     $92 = $91 * 0.5;
     $93 = (~~(($92))>>>0);
     HEAP32[$$399122$us$us$i$us>>2] = $93;
     $94 = (($$3123$us$us$i$us) + ($5)|0);
     $95 = ((($$399122$us$us$i$us)) + 4|0);
     $96 = (($$0124$us$us$i$us) + 1)|0;
     $exitcond160$i$us = ($96|0)==($0|0);
     if ($exitcond160$i$us) {
      break;
     } else {
      $$0124$us$us$i$us = $96;$$3123$us$us$i$us = $94;$$399122$us$us$i$us = $95;
     }
    }
    $97 = (($$2131$us$i$us) + ($85)|0);
    $split127$us$i$us = (($$298130$us$i$us) + ($0<<2)|0);
    $98 = (($97) + ($5)|0);
    $99 = (($98) + ($80)|0);
    $100 = (($99) + ($6)|0);
    $101 = (($$1102129$us$i$us) + 1)|0;
    $exitcond161$i$us = ($101|0)==($12|0);
    if ($exitcond161$i$us) {
     break;
    } else {
     $$1102129$us$i$us = $101;$$2131$us$i$us = $100;$$298130$us$i$us = $split127$us$i$us;
    }
   }
   return;
  } else {
   $$1102129$us$i = 0;$$2131$us$i = $3;$$298130$us$i = $4;
   while(1) {
    $$0124$us132$i = 0;$$3123$us133$i = $$2131$us$i;$$399122$us134$i = $$298130$us$i;
    while(1) {
     $102 = ((($$3123$us133$i)) + 3|0);
     $103 = HEAP8[$102>>0]|0;
     $104 = $103&255;
     $105 = $104 << 24;
     $106 = ((($$3123$us133$i)) + 2|0);
     $107 = HEAP8[$106>>0]|0;
     $108 = $107&255;
     $109 = $108 << 16;
     $110 = $109 | $105;
     $111 = ((($$3123$us133$i)) + 1|0);
     $112 = HEAP8[$111>>0]|0;
     $113 = $112&255;
     $114 = $113 << 8;
     $115 = $110 | $114;
     $116 = HEAP8[$$3123$us133$i>>0]|0;
     $117 = $116&255;
     $118 = $115 | $117;
     $119 = (($$3123$us133$i) + ($6)|0);
     $120 = ((($119)) + 3|0);
     $121 = HEAP8[$120>>0]|0;
     $122 = $121&255;
     $123 = $122 << 24;
     $124 = ((($119)) + 2|0);
     $125 = HEAP8[$124>>0]|0;
     $126 = $125&255;
     $127 = $126 << 16;
     $128 = $127 | $123;
     $129 = ((($119)) + 1|0);
     $130 = HEAP8[$129>>0]|0;
     $131 = $130&255;
     $132 = $131 << 8;
     $133 = $128 | $132;
     $134 = HEAP8[$119>>0]|0;
     $135 = $134&255;
     $136 = $133 | $135;
     $137 = (+($118>>>0));
     $138 = (+($136>>>0));
     $139 = $137 + $138;
     $140 = $139 * 0.5;
     $141 = (~~(($140))>>>0);
     HEAP32[$$399122$us134$i>>2] = $141;
     $142 = (($$3123$us133$i) + ($5)|0);
     $143 = ((($$399122$us134$i)) + 4|0);
     $144 = (($$0124$us132$i) + 1)|0;
     $exitcond157$i = ($144|0)==($0|0);
     if ($exitcond157$i) {
      break;
     } else {
      $$0124$us132$i = $144;$$3123$us133$i = $142;$$399122$us134$i = $143;
     }
    }
    $145 = (($$2131$us$i) + ($85)|0);
    $split127$us$i = (($$298130$us$i) + ($0<<2)|0);
    $146 = (($145) + ($5)|0);
    $147 = (($146) + ($80)|0);
    $148 = (($147) + ($6)|0);
    $149 = (($$1102129$us$i) + 1)|0;
    $exitcond161$i = ($149|0)==($12|0);
    if ($exitcond161$i) {
     break;
    } else {
     $$1102129$us$i = $149;$$2131$us$i = $148;$$298130$us$i = $split127$us$i;
    }
   }
   return;
  }
 }
 $150 = Math_imul($7, $1)|0;
 $151 = (($6) - ($150))|0;
 $152 = ($8|0)==(0);
 $153 = ($12|0)!=(0);
 if ($152) {
  if (!($153)) {
   return;
  }
  $161 = ($11|0)==(0);
  $162 = ($0|0)>(0);
  if ($161) {
   return;
  }
  $163 = (($11) + -1)|0;
  $164 = Math_imul($163, $7)|0;
  $165 = Math_imul($5, $0)|0;
  $166 = Math_imul($11, $0)|0;
  $167 = (($165) + ($7))|0;
  $168 = Math_imul($167, $163)|0;
  $169 = (($165) + ($168))|0;
  $$0120151$us = $3;$$0122150$us = $4;$$0152$us = 0;
  while(1) {
   if ($162) {
    $scevgep201 = (($$0122150$us) + ($166<<2)|0);
    $$0118146$us$us = 0;$$1121145$us$us = $$0120151$us;$$1123144$us$us = $$0122150$us;
    while(1) {
     $scevgep199 = (($$1123144$us$us) + ($0<<2)|0);
     $$0128140$us$us = 0;$$2124141$us$us = $$1123144$us$us;$$2142$us$us = $$1121145$us$us;
     while(1) {
      $177 = HEAP32[$$2142$us$us>>2]|0;
      $178 = (+($177>>>0));
      $179 = (($$2142$us$us) + ($7)|0);
      $180 = HEAP32[$179>>2]|0;
      $181 = (+($180>>>0));
      $182 = $178 + $181;
      $183 = (($$2142$us$us) + ($6)|0);
      $184 = HEAP32[$183>>2]|0;
      $185 = (+($184>>>0));
      $186 = $182 + $185;
      $187 = (($183) + ($7)|0);
      $188 = HEAP32[$187>>2]|0;
      $189 = (+($188>>>0));
      $190 = $186 + $189;
      $191 = $190 * 0.25;
      $192 = $191 + 0.5;
      $193 = (~~(($192))>>>0);
      HEAP32[$$2124141$us$us>>2] = $193;
      $194 = ((($$2124141$us$us)) + 4|0);
      $195 = (($$2142$us$us) + ($5)|0);
      $196 = (($$0128140$us$us) + 1)|0;
      $exitcond = ($196|0)==($0|0);
      if ($exitcond) {
       break;
      } else {
       $$0128140$us$us = $196;$$2124141$us$us = $194;$$2142$us$us = $195;
      }
     }
     $scevgep200 = (($$1121145$us$us) + ($165)|0);
     $175 = (($scevgep200) + ($7)|0);
     $176 = (($$0118146$us$us) + 1)|0;
     $exitcond203 = ($176|0)==($11|0);
     if ($exitcond203) {
      $$pn = $169;$split148$us = $scevgep201;
      break;
     } else {
      $$0118146$us$us = $176;$$1121145$us$us = $175;$$1123144$us$us = $scevgep199;
     }
    }
   } else {
    $$pn = $164;$split148$us = $$0122150$us;
   }
   $170 = (($$0120151$us) + ($$pn)|0);
   $171 = (($170) + ($7)|0);
   $172 = (($171) + ($151)|0);
   $173 = (($172) + ($6)|0);
   $174 = (($$0152$us) + 1)|0;
   $exitcond204 = ($174|0)==($12|0);
   if ($exitcond204) {
    break;
   } else {
    $$0120151$us = $173;$$0122150$us = $split148$us;$$0152$us = $174;
   }
  }
  return;
 }
 if (!($153)) {
  return;
 }
 $154 = ($11|0)==(0);
 $155 = ($0|0)>(0);
 $156 = Math_imul($11, $7)|0;
 $157 = Math_imul($5, $0)|0;
 $158 = (($157) + ($7))|0;
 $159 = Math_imul($158, $11)|0;
 $160 = Math_imul($11, $0)|0;
 $$1185 = 0;$$3125183 = $4;$$3184 = $3;
 while(1) {
  do {
   if ($154) {
    $$4$lcssa = $$3184;$$4126$lcssa = $$3125183;
   } else {
    if (!($155)) {
     $scevgep205 = (($$3184) + ($156)|0);
     $$4$lcssa = $scevgep205;$$4126$lcssa = $$3125183;
     break;
    }
    $scevgep210 = (($$3184) + ($159)|0);
    $$1119179$us = 0;$$4126177$us = $$3125183;$$4178$us = $$3184;
    while(1) {
     $scevgep207 = (($$4126177$us) + ($0<<2)|0);
     $$1129170$us = 0;$$5127171$us = $$4126177$us;$$5172$us = $$4178$us;
     while(1) {
      $197 = ((($$5172$us)) + 3|0);
      $198 = HEAP8[$197>>0]|0;
      $199 = $198&255;
      $200 = $199 << 24;
      $201 = ((($$5172$us)) + 2|0);
      $202 = HEAP8[$201>>0]|0;
      $203 = $202&255;
      $204 = $203 << 16;
      $205 = $204 | $200;
      $206 = ((($$5172$us)) + 1|0);
      $207 = HEAP8[$206>>0]|0;
      $208 = $207&255;
      $209 = $208 << 8;
      $210 = $205 | $209;
      $211 = HEAP8[$$5172$us>>0]|0;
      $212 = $211&255;
      $213 = $210 | $212;
      $214 = (+($213>>>0));
      $215 = (($$5172$us) + ($7)|0);
      $216 = ((($215)) + 3|0);
      $217 = HEAP8[$216>>0]|0;
      $218 = $217&255;
      $219 = $218 << 24;
      $220 = ((($215)) + 2|0);
      $221 = HEAP8[$220>>0]|0;
      $222 = $221&255;
      $223 = $222 << 16;
      $224 = $223 | $219;
      $225 = ((($215)) + 1|0);
      $226 = HEAP8[$225>>0]|0;
      $227 = $226&255;
      $228 = $227 << 8;
      $229 = $224 | $228;
      $230 = HEAP8[$215>>0]|0;
      $231 = $230&255;
      $232 = $229 | $231;
      $233 = (+($232>>>0));
      $234 = $214 + $233;
      $235 = (($$5172$us) + ($6)|0);
      $236 = ((($235)) + 3|0);
      $237 = HEAP8[$236>>0]|0;
      $238 = $237&255;
      $239 = $238 << 24;
      $240 = ((($235)) + 2|0);
      $241 = HEAP8[$240>>0]|0;
      $242 = $241&255;
      $243 = $242 << 16;
      $244 = $243 | $239;
      $245 = ((($235)) + 1|0);
      $246 = HEAP8[$245>>0]|0;
      $247 = $246&255;
      $248 = $247 << 8;
      $249 = $244 | $248;
      $250 = HEAP8[$235>>0]|0;
      $251 = $250&255;
      $252 = $249 | $251;
      $253 = (+($252>>>0));
      $254 = $234 + $253;
      $255 = (($235) + ($7)|0);
      $256 = ((($255)) + 3|0);
      $257 = HEAP8[$256>>0]|0;
      $258 = $257&255;
      $259 = $258 << 24;
      $260 = ((($255)) + 2|0);
      $261 = HEAP8[$260>>0]|0;
      $262 = $261&255;
      $263 = $262 << 16;
      $264 = $263 | $259;
      $265 = ((($255)) + 1|0);
      $266 = HEAP8[$265>>0]|0;
      $267 = $266&255;
      $268 = $267 << 8;
      $269 = $264 | $268;
      $270 = HEAP8[$255>>0]|0;
      $271 = $270&255;
      $272 = $269 | $271;
      $273 = (+($272>>>0));
      $274 = $254 + $273;
      $275 = $274 * 0.25;
      $276 = $275 + 0.5;
      $277 = (~~(($276))>>>0);
      HEAP32[$$5127171$us>>2] = $277;
      $278 = ((($$5127171$us)) + 4|0);
      $279 = (($$5172$us) + ($5)|0);
      $280 = (($$1129170$us) + 1)|0;
      $exitcond209 = ($280|0)==($0|0);
      if ($exitcond209) {
       break;
      } else {
       $$1129170$us = $280;$$5127171$us = $278;$$5172$us = $279;
      }
     }
     $scevgep208 = (($$4178$us) + ($157)|0);
     $281 = (($scevgep208) + ($7)|0);
     $282 = (($$1119179$us) + 1)|0;
     $exitcond212 = ($282|0)==($11|0);
     if ($exitcond212) {
      break;
     } else {
      $$1119179$us = $282;$$4126177$us = $scevgep207;$$4178$us = $281;
     }
    }
    $scevgep211 = (($$3125183) + ($160<<2)|0);
    $$4$lcssa = $scevgep210;$$4126$lcssa = $scevgep211;
   }
  } while(0);
  $283 = (($$4$lcssa) + ($151)|0);
  $284 = (($283) + ($6)|0);
  $285 = (($$1185) + 1)|0;
  $exitcond213 = ($285|0)==($12|0);
  if ($exitcond213) {
   break;
  } else {
   $$1185 = $285;$$3125183 = $$4126$lcssa;$$3184 = $284;
  }
 }
 return;
}
function __ZN3osgL14halveImage_intEijjPKiPiiiii($0,$1,$2,$3,$4,$5,$6,$7,$8) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 $8 = $8|0;
 var $$0100106$us$us$i$us = 0, $$0100106$us115$i = 0, $$0101110$us$i = 0, $$0101110$us$i$us = 0, $$0124$us$us$i$us = 0, $$0124$us132$i = 0, $$0124152$us$us = 0, $$0126157$us = 0, $$0128156$us = 0, $$0134146$us$us = 0, $$0158$us = 0, $$095112$us$i = 0, $$095112$us$i$us = 0, $$096111$us$i = 0, $$096111$us$i$us = 0, $$1102129$us$i = 0, $$1102129$us$i$us = 0, $$1108$us$us$i$us = 0, $$1108$us113$i = 0, $$1125185$us = 0;
 var $$1127151$us$us = 0, $$1129150$us$us = 0, $$1135176$us = 0, $$1191 = 0, $$197107$us$us$i$us = 0, $$197107$us114$i = 0, $$2130147$us$us = 0, $$2131$us$i = 0, $$2131$us$i$us = 0, $$2148$us$us = 0, $$298130$us$i = 0, $$298130$us$i$us = 0, $$3123$us$us$i$us = 0, $$3123$us133$i = 0, $$3131189 = 0, $$3190 = 0, $$399122$us$us$i$us = 0, $$399122$us134$i = 0, $$4$lcssa = 0, $$4132$lcssa = 0;
 var $$4132183$us = 0, $$4184$us = 0, $$5133177$us = 0, $$5178$us = 0, $$pn = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0.0, $141 = 0.0, $142 = 0.0, $143 = 0.0, $144 = 0.0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0.0, $183 = 0, $184 = 0, $185 = 0.0;
 var $186 = 0.0, $187 = 0, $188 = 0, $189 = 0.0, $19 = 0, $190 = 0.0, $191 = 0, $192 = 0, $193 = 0.0, $194 = 0.0, $195 = 0.0, $196 = 0.0, $197 = 0.0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0.0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0.0, $22 = 0.0, $220 = 0, $221 = 0;
 var $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0.0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0.0, $239 = 0.0, $24 = 0.0;
 var $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0.0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0.0;
 var $259 = 0.0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0;
 var $277 = 0, $278 = 0.0, $279 = 0.0, $28 = 0, $280 = 0.0, $281 = 0.0, $282 = 0.0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0.0, $70 = 0.0, $71 = 0.0, $72 = 0.0;
 var $73 = 0.0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0.0;
 var $92 = 0.0, $93 = 0.0, $94 = 0.0, $95 = 0.0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $exitcond$i = 0, $exitcond152$i$us = 0, $exitcond153$i = 0, $exitcond153$i$us = 0, $exitcond157$i = 0, $exitcond160$i$us = 0, $exitcond161$i = 0, $exitcond161$i$us = 0, $exitcond209 = 0, $exitcond210 = 0, $exitcond215 = 0;
 var $exitcond218 = 0, $exitcond219 = 0, $or$cond = 0, $or$cond225 = 0, $or$cond226 = 0, $scevgep205 = 0, $scevgep206 = 0, $scevgep207 = 0, $scevgep211 = 0, $scevgep213 = 0, $scevgep214 = 0, $scevgep216 = 0, $scevgep217 = 0, $split$us$i = 0, $split$us$i$us = 0, $split127$us$i = 0, $split127$us$i$us = 0, $split154$us = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $9 = ($1|0)==(1);
 $10 = ($2|0)==(1);
 $or$cond = $9 | $10;
 $11 = $1 >>> 1;
 $12 = $2 >>> 1;
 if ($or$cond) {
  if ($10) {
   $13 = ($11|0)!=(0);
   $14 = ($0|0)>(0);
   $or$cond225 = $13 & $14;
   if (!($or$cond225)) {
    return;
   }
   $15 = ($8|0)==(0);
   $16 = (($0) + -1)|0;
   $17 = Math_imul($16, $5)|0;
   if ($15) {
    $$0101110$us$i$us = 0;$$095112$us$i$us = $3;$$096111$us$i$us = $4;
    while(1) {
     $$0100106$us$us$i$us = 0;$$1108$us$us$i$us = $$095112$us$i$us;$$197107$us$us$i$us = $$096111$us$i$us;
     while(1) {
      $18 = HEAP32[$$1108$us$us$i$us>>2]|0;
      $19 = (($$1108$us$us$i$us) + ($7)|0);
      $20 = HEAP32[$19>>2]|0;
      $21 = (+($18>>>0));
      $22 = (+($20>>>0));
      $23 = $21 + $22;
      $24 = $23;
      $25 = $24 * 0.5;
      $26 = (~~(($25)));
      HEAP32[$$197107$us$us$i$us>>2] = $26;
      $27 = (($$1108$us$us$i$us) + ($5)|0);
      $28 = ((($$197107$us$us$i$us)) + 4|0);
      $29 = (($$0100106$us$us$i$us) + 1)|0;
      $exitcond152$i$us = ($29|0)==($0|0);
      if ($exitcond152$i$us) {
       break;
      } else {
       $$0100106$us$us$i$us = $29;$$1108$us$us$i$us = $27;$$197107$us$us$i$us = $28;
      }
     }
     $30 = (($$095112$us$i$us) + ($17)|0);
     $split$us$i$us = (($$096111$us$i$us) + ($0<<2)|0);
     $31 = (($30) + ($5)|0);
     $32 = (($31) + ($7)|0);
     $33 = (($$0101110$us$i$us) + 1)|0;
     $exitcond153$i$us = ($33|0)==($11|0);
     if ($exitcond153$i$us) {
      break;
     } else {
      $$0101110$us$i$us = $33;$$095112$us$i$us = $32;$$096111$us$i$us = $split$us$i$us;
     }
    }
    return;
   } else {
    $$0101110$us$i = 0;$$095112$us$i = $3;$$096111$us$i = $4;
    while(1) {
     $$0100106$us115$i = 0;$$1108$us113$i = $$095112$us$i;$$197107$us114$i = $$096111$us$i;
     while(1) {
      $34 = ((($$1108$us113$i)) + 3|0);
      $35 = HEAP8[$34>>0]|0;
      $36 = $35&255;
      $37 = $36 << 24;
      $38 = ((($$1108$us113$i)) + 2|0);
      $39 = HEAP8[$38>>0]|0;
      $40 = $39&255;
      $41 = $40 << 16;
      $42 = $41 | $37;
      $43 = ((($$1108$us113$i)) + 1|0);
      $44 = HEAP8[$43>>0]|0;
      $45 = $44&255;
      $46 = $45 << 8;
      $47 = $42 | $46;
      $48 = HEAP8[$$1108$us113$i>>0]|0;
      $49 = $48&255;
      $50 = $47 | $49;
      $51 = (($$1108$us113$i) + ($7)|0);
      $52 = ((($51)) + 3|0);
      $53 = HEAP8[$52>>0]|0;
      $54 = $53&255;
      $55 = $54 << 24;
      $56 = ((($51)) + 2|0);
      $57 = HEAP8[$56>>0]|0;
      $58 = $57&255;
      $59 = $58 << 16;
      $60 = $59 | $55;
      $61 = ((($51)) + 1|0);
      $62 = HEAP8[$61>>0]|0;
      $63 = $62&255;
      $64 = $63 << 8;
      $65 = $60 | $64;
      $66 = HEAP8[$51>>0]|0;
      $67 = $66&255;
      $68 = $65 | $67;
      $69 = (+($50>>>0));
      $70 = (+($68>>>0));
      $71 = $69 + $70;
      $72 = $71;
      $73 = $72 * 0.5;
      $74 = (~~(($73)));
      HEAP32[$$197107$us114$i>>2] = $74;
      $75 = (($$1108$us113$i) + ($5)|0);
      $76 = ((($$197107$us114$i)) + 4|0);
      $77 = (($$0100106$us115$i) + 1)|0;
      $exitcond$i = ($77|0)==($0|0);
      if ($exitcond$i) {
       break;
      } else {
       $$0100106$us115$i = $77;$$1108$us113$i = $75;$$197107$us114$i = $76;
      }
     }
     $78 = (($$095112$us$i) + ($17)|0);
     $split$us$i = (($$096111$us$i) + ($0<<2)|0);
     $79 = (($78) + ($5)|0);
     $80 = (($79) + ($7)|0);
     $81 = (($$0101110$us$i) + 1)|0;
     $exitcond153$i = ($81|0)==($11|0);
     if ($exitcond153$i) {
      break;
     } else {
      $$0101110$us$i = $81;$$095112$us$i = $80;$$096111$us$i = $split$us$i;
     }
    }
    return;
   }
  }
  if (!($9)) {
   return;
  }
  $82 = (($6) - ($7))|0;
  $83 = ($12|0)!=(0);
  $84 = ($0|0)>(0);
  $or$cond226 = $83 & $84;
  if (!($or$cond226)) {
   return;
  }
  $85 = ($8|0)==(0);
  $86 = (($0) + -1)|0;
  $87 = Math_imul($86, $5)|0;
  if ($85) {
   $$1102129$us$i$us = 0;$$2131$us$i$us = $3;$$298130$us$i$us = $4;
   while(1) {
    $$0124$us$us$i$us = 0;$$3123$us$us$i$us = $$2131$us$i$us;$$399122$us$us$i$us = $$298130$us$i$us;
    while(1) {
     $88 = HEAP32[$$3123$us$us$i$us>>2]|0;
     $89 = (($$3123$us$us$i$us) + ($6)|0);
     $90 = HEAP32[$89>>2]|0;
     $91 = (+($88>>>0));
     $92 = (+($90>>>0));
     $93 = $91 + $92;
     $94 = $93;
     $95 = $94 * 0.5;
     $96 = (~~(($95)));
     HEAP32[$$399122$us$us$i$us>>2] = $96;
     $97 = (($$3123$us$us$i$us) + ($5)|0);
     $98 = ((($$399122$us$us$i$us)) + 4|0);
     $99 = (($$0124$us$us$i$us) + 1)|0;
     $exitcond160$i$us = ($99|0)==($0|0);
     if ($exitcond160$i$us) {
      break;
     } else {
      $$0124$us$us$i$us = $99;$$3123$us$us$i$us = $97;$$399122$us$us$i$us = $98;
     }
    }
    $100 = (($$2131$us$i$us) + ($87)|0);
    $split127$us$i$us = (($$298130$us$i$us) + ($0<<2)|0);
    $101 = (($100) + ($5)|0);
    $102 = (($101) + ($82)|0);
    $103 = (($102) + ($6)|0);
    $104 = (($$1102129$us$i$us) + 1)|0;
    $exitcond161$i$us = ($104|0)==($12|0);
    if ($exitcond161$i$us) {
     break;
    } else {
     $$1102129$us$i$us = $104;$$2131$us$i$us = $103;$$298130$us$i$us = $split127$us$i$us;
    }
   }
   return;
  } else {
   $$1102129$us$i = 0;$$2131$us$i = $3;$$298130$us$i = $4;
   while(1) {
    $$0124$us132$i = 0;$$3123$us133$i = $$2131$us$i;$$399122$us134$i = $$298130$us$i;
    while(1) {
     $105 = ((($$3123$us133$i)) + 3|0);
     $106 = HEAP8[$105>>0]|0;
     $107 = $106&255;
     $108 = $107 << 24;
     $109 = ((($$3123$us133$i)) + 2|0);
     $110 = HEAP8[$109>>0]|0;
     $111 = $110&255;
     $112 = $111 << 16;
     $113 = $112 | $108;
     $114 = ((($$3123$us133$i)) + 1|0);
     $115 = HEAP8[$114>>0]|0;
     $116 = $115&255;
     $117 = $116 << 8;
     $118 = $113 | $117;
     $119 = HEAP8[$$3123$us133$i>>0]|0;
     $120 = $119&255;
     $121 = $118 | $120;
     $122 = (($$3123$us133$i) + ($6)|0);
     $123 = ((($122)) + 3|0);
     $124 = HEAP8[$123>>0]|0;
     $125 = $124&255;
     $126 = $125 << 24;
     $127 = ((($122)) + 2|0);
     $128 = HEAP8[$127>>0]|0;
     $129 = $128&255;
     $130 = $129 << 16;
     $131 = $130 | $126;
     $132 = ((($122)) + 1|0);
     $133 = HEAP8[$132>>0]|0;
     $134 = $133&255;
     $135 = $134 << 8;
     $136 = $131 | $135;
     $137 = HEAP8[$122>>0]|0;
     $138 = $137&255;
     $139 = $136 | $138;
     $140 = (+($121>>>0));
     $141 = (+($139>>>0));
     $142 = $140 + $141;
     $143 = $142;
     $144 = $143 * 0.5;
     $145 = (~~(($144)));
     HEAP32[$$399122$us134$i>>2] = $145;
     $146 = (($$3123$us133$i) + ($5)|0);
     $147 = ((($$399122$us134$i)) + 4|0);
     $148 = (($$0124$us132$i) + 1)|0;
     $exitcond157$i = ($148|0)==($0|0);
     if ($exitcond157$i) {
      break;
     } else {
      $$0124$us132$i = $148;$$3123$us133$i = $146;$$399122$us134$i = $147;
     }
    }
    $149 = (($$2131$us$i) + ($87)|0);
    $split127$us$i = (($$298130$us$i) + ($0<<2)|0);
    $150 = (($149) + ($5)|0);
    $151 = (($150) + ($82)|0);
    $152 = (($151) + ($6)|0);
    $153 = (($$1102129$us$i) + 1)|0;
    $exitcond161$i = ($153|0)==($12|0);
    if ($exitcond161$i) {
     break;
    } else {
     $$1102129$us$i = $153;$$2131$us$i = $152;$$298130$us$i = $split127$us$i;
    }
   }
   return;
  }
 }
 $154 = Math_imul($7, $1)|0;
 $155 = (($6) - ($154))|0;
 $156 = ($8|0)==(0);
 $157 = ($12|0)!=(0);
 if ($156) {
  if (!($157)) {
   return;
  }
  $165 = ($11|0)==(0);
  $166 = ($0|0)>(0);
  if ($165) {
   return;
  }
  $167 = (($11) + -1)|0;
  $168 = Math_imul($167, $7)|0;
  $169 = Math_imul($5, $0)|0;
  $170 = Math_imul($11, $0)|0;
  $171 = (($169) + ($7))|0;
  $172 = Math_imul($171, $167)|0;
  $173 = (($169) + ($172))|0;
  $$0126157$us = $3;$$0128156$us = $4;$$0158$us = 0;
  while(1) {
   if ($166) {
    $scevgep207 = (($$0128156$us) + ($170<<2)|0);
    $$0124152$us$us = 0;$$1127151$us$us = $$0126157$us;$$1129150$us$us = $$0128156$us;
    while(1) {
     $scevgep205 = (($$1129150$us$us) + ($0<<2)|0);
     $$0134146$us$us = 0;$$2130147$us$us = $$1129150$us$us;$$2148$us$us = $$1127151$us$us;
     while(1) {
      $181 = HEAP32[$$2148$us$us>>2]|0;
      $182 = (+($181|0));
      $183 = (($$2148$us$us) + ($7)|0);
      $184 = HEAP32[$183>>2]|0;
      $185 = (+($184|0));
      $186 = $182 + $185;
      $187 = (($$2148$us$us) + ($6)|0);
      $188 = HEAP32[$187>>2]|0;
      $189 = (+($188|0));
      $190 = $186 + $189;
      $191 = (($187) + ($7)|0);
      $192 = HEAP32[$191>>2]|0;
      $193 = (+($192|0));
      $194 = $190 + $193;
      $195 = $194 * 0.25;
      $196 = $195;
      $197 = $196 + 0.5;
      $198 = (~~(($197)));
      HEAP32[$$2130147$us$us>>2] = $198;
      $199 = ((($$2130147$us$us)) + 4|0);
      $200 = (($$2148$us$us) + ($5)|0);
      $201 = (($$0134146$us$us) + 1)|0;
      $exitcond = ($201|0)==($0|0);
      if ($exitcond) {
       break;
      } else {
       $$0134146$us$us = $201;$$2130147$us$us = $199;$$2148$us$us = $200;
      }
     }
     $scevgep206 = (($$1127151$us$us) + ($169)|0);
     $179 = (($scevgep206) + ($7)|0);
     $180 = (($$0124152$us$us) + 1)|0;
     $exitcond209 = ($180|0)==($11|0);
     if ($exitcond209) {
      $$pn = $173;$split154$us = $scevgep207;
      break;
     } else {
      $$0124152$us$us = $180;$$1127151$us$us = $179;$$1129150$us$us = $scevgep205;
     }
    }
   } else {
    $$pn = $168;$split154$us = $$0128156$us;
   }
   $174 = (($$0126157$us) + ($$pn)|0);
   $175 = (($174) + ($7)|0);
   $176 = (($175) + ($155)|0);
   $177 = (($176) + ($6)|0);
   $178 = (($$0158$us) + 1)|0;
   $exitcond210 = ($178|0)==($12|0);
   if ($exitcond210) {
    break;
   } else {
    $$0126157$us = $177;$$0128156$us = $split154$us;$$0158$us = $178;
   }
  }
  return;
 }
 if (!($157)) {
  return;
 }
 $158 = ($11|0)==(0);
 $159 = ($0|0)>(0);
 $160 = Math_imul($11, $7)|0;
 $161 = Math_imul($5, $0)|0;
 $162 = (($161) + ($7))|0;
 $163 = Math_imul($162, $11)|0;
 $164 = Math_imul($11, $0)|0;
 $$1191 = 0;$$3131189 = $4;$$3190 = $3;
 while(1) {
  do {
   if ($158) {
    $$4$lcssa = $$3190;$$4132$lcssa = $$3131189;
   } else {
    if (!($159)) {
     $scevgep211 = (($$3190) + ($160)|0);
     $$4$lcssa = $scevgep211;$$4132$lcssa = $$3131189;
     break;
    }
    $scevgep216 = (($$3190) + ($163)|0);
    $$1125185$us = 0;$$4132183$us = $$3131189;$$4184$us = $$3190;
    while(1) {
     $scevgep213 = (($$4132183$us) + ($0<<2)|0);
     $$1135176$us = 0;$$5133177$us = $$4132183$us;$$5178$us = $$4184$us;
     while(1) {
      $202 = ((($$5178$us)) + 3|0);
      $203 = HEAP8[$202>>0]|0;
      $204 = $203&255;
      $205 = $204 << 24;
      $206 = ((($$5178$us)) + 2|0);
      $207 = HEAP8[$206>>0]|0;
      $208 = $207&255;
      $209 = $208 << 16;
      $210 = $209 | $205;
      $211 = ((($$5178$us)) + 1|0);
      $212 = HEAP8[$211>>0]|0;
      $213 = $212&255;
      $214 = $213 << 8;
      $215 = $210 | $214;
      $216 = HEAP8[$$5178$us>>0]|0;
      $217 = $216&255;
      $218 = $215 | $217;
      $219 = (+($218|0));
      $220 = (($$5178$us) + ($7)|0);
      $221 = ((($220)) + 3|0);
      $222 = HEAP8[$221>>0]|0;
      $223 = $222&255;
      $224 = $223 << 24;
      $225 = ((($220)) + 2|0);
      $226 = HEAP8[$225>>0]|0;
      $227 = $226&255;
      $228 = $227 << 16;
      $229 = $228 | $224;
      $230 = ((($220)) + 1|0);
      $231 = HEAP8[$230>>0]|0;
      $232 = $231&255;
      $233 = $232 << 8;
      $234 = $229 | $233;
      $235 = HEAP8[$220>>0]|0;
      $236 = $235&255;
      $237 = $234 | $236;
      $238 = (+($237|0));
      $239 = $219 + $238;
      $240 = (($$5178$us) + ($6)|0);
      $241 = ((($240)) + 3|0);
      $242 = HEAP8[$241>>0]|0;
      $243 = $242&255;
      $244 = $243 << 24;
      $245 = ((($240)) + 2|0);
      $246 = HEAP8[$245>>0]|0;
      $247 = $246&255;
      $248 = $247 << 16;
      $249 = $248 | $244;
      $250 = ((($240)) + 1|0);
      $251 = HEAP8[$250>>0]|0;
      $252 = $251&255;
      $253 = $252 << 8;
      $254 = $249 | $253;
      $255 = HEAP8[$240>>0]|0;
      $256 = $255&255;
      $257 = $254 | $256;
      $258 = (+($257|0));
      $259 = $239 + $258;
      $260 = (($240) + ($7)|0);
      $261 = ((($260)) + 3|0);
      $262 = HEAP8[$261>>0]|0;
      $263 = $262&255;
      $264 = $263 << 24;
      $265 = ((($260)) + 2|0);
      $266 = HEAP8[$265>>0]|0;
      $267 = $266&255;
      $268 = $267 << 16;
      $269 = $268 | $264;
      $270 = ((($260)) + 1|0);
      $271 = HEAP8[$270>>0]|0;
      $272 = $271&255;
      $273 = $272 << 8;
      $274 = $269 | $273;
      $275 = HEAP8[$260>>0]|0;
      $276 = $275&255;
      $277 = $274 | $276;
      $278 = (+($277|0));
      $279 = $259 + $278;
      $280 = $279 * 0.25;
      $281 = $280;
      $282 = $281 + 0.5;
      $283 = (~~(($282)));
      HEAP32[$$5133177$us>>2] = $283;
      $284 = ((($$5133177$us)) + 4|0);
      $285 = (($$5178$us) + ($5)|0);
      $286 = (($$1135176$us) + 1)|0;
      $exitcond215 = ($286|0)==($0|0);
      if ($exitcond215) {
       break;
      } else {
       $$1135176$us = $286;$$5133177$us = $284;$$5178$us = $285;
      }
     }
     $scevgep214 = (($$4184$us) + ($161)|0);
     $287 = (($scevgep214) + ($7)|0);
     $288 = (($$1125185$us) + 1)|0;
     $exitcond218 = ($288|0)==($11|0);
     if ($exitcond218) {
      break;
     } else {
      $$1125185$us = $288;$$4132183$us = $scevgep213;$$4184$us = $287;
     }
    }
    $scevgep217 = (($$3131189) + ($164<<2)|0);
    $$4$lcssa = $scevgep216;$$4132$lcssa = $scevgep217;
   }
  } while(0);
  $289 = (($$4$lcssa) + ($155)|0);
  $290 = (($289) + ($6)|0);
  $291 = (($$1191) + 1)|0;
  $exitcond219 = ($291|0)==($12|0);
  if ($exitcond219) {
   break;
  } else {
   $$1191 = $291;$$3131189 = $$4132$lcssa;$$3190 = $290;
  }
 }
 return;
}
function __ZN3osgL16halveImage_floatEijjPKfPfiiii($0,$1,$2,$3,$4,$5,$6,$7,$8) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 $8 = $8|0;
 var $$0100106$us$us$i$us = 0, $$0100106$us115$i = 0, $$0101110$us$i = 0, $$0101110$us$i$us = 0, $$0120153$us = 0, $$0122152$us = 0, $$0124$us$us$i$us = 0, $$0124$us132$i = 0, $$0128146$us$us = 0, $$0130142$us$us = 0, $$0154$us = 0, $$095112$us$i = 0, $$095112$us$i$us = 0, $$096111$us$i = 0, $$096111$us$i$us = 0, $$1102129$us$i = 0, $$1102129$us$i$us = 0, $$1108$us$us$i$us = 0, $$1108$us113$i = 0, $$1121148$us$us = 0;
 var $$1123147$us$us = 0, $$1129179$us = 0, $$1131172$us = 0, $$1187 = 0, $$197107$us$us$i$us = 0, $$197107$us114$i = 0, $$2124143$us$us = 0, $$2131$us$i = 0, $$2131$us$i$us = 0, $$2144$us$us = 0, $$298130$us$i = 0, $$298130$us$i$us = 0, $$3123$us$us$i$us = 0, $$3123$us133$i = 0, $$3125185 = 0, $$3186 = 0, $$399122$us$us$i$us = 0, $$399122$us134$i = 0, $$4$lcssa = 0, $$4126$lcssa = 0;
 var $$4126180$us = 0, $$4181$us = 0, $$5127173$us = 0, $$5174$us = 0, $$pn = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0.0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0.0, $132 = 0.0, $133 = 0.0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0.0, $17 = 0, $170 = 0, $171 = 0.0, $172 = 0.0, $173 = 0, $174 = 0.0, $175 = 0.0, $176 = 0, $177 = 0.0, $178 = 0.0, $179 = 0.0, $18 = 0.0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0;
 var $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0.0, $200 = 0.0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0.0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0.0, $22 = 0.0, $220 = 0.0, $221 = 0;
 var $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0.0, $24 = 0;
 var $240 = 0.0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0;
 var $259 = 0.0, $26 = 0, $260 = 0.0, $261 = 0.0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0.0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0.0, $67 = 0.0, $68 = 0.0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0.0, $83 = 0, $84 = 0.0, $85 = 0.0, $86 = 0.0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $exitcond$i = 0, $exitcond152$i$us = 0, $exitcond153$i = 0, $exitcond153$i$us = 0, $exitcond157$i = 0, $exitcond160$i$us = 0, $exitcond161$i = 0, $exitcond161$i$us = 0, $exitcond205 = 0, $exitcond206 = 0, $exitcond211 = 0, $exitcond214 = 0, $exitcond215 = 0;
 var $or$cond = 0, $or$cond221 = 0, $or$cond222 = 0, $scevgep201 = 0, $scevgep202 = 0, $scevgep203 = 0, $scevgep207 = 0, $scevgep209 = 0, $scevgep210 = 0, $scevgep212 = 0, $scevgep213 = 0, $split$us$i = 0, $split$us$i$us = 0, $split127$us$i = 0, $split127$us$i$us = 0, $split150$us = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $9 = ($1|0)==(1);
 $10 = ($2|0)==(1);
 $or$cond = $9 | $10;
 $11 = $1 >>> 1;
 $12 = $2 >>> 1;
 if ($or$cond) {
  if ($10) {
   $13 = ($11|0)!=(0);
   $14 = ($0|0)>(0);
   $or$cond221 = $13 & $14;
   if (!($or$cond221)) {
    return;
   }
   $15 = ($8|0)==(0);
   $16 = (($0) + -1)|0;
   $17 = Math_imul($16, $5)|0;
   if ($15) {
    $$0101110$us$i$us = 0;$$095112$us$i$us = $3;$$096111$us$i$us = $4;
    while(1) {
     $$0100106$us$us$i$us = 0;$$1108$us$us$i$us = $$095112$us$i$us;$$197107$us$us$i$us = $$096111$us$i$us;
     while(1) {
      $18 = +HEAPF32[$$1108$us$us$i$us>>2];
      $19 = (($$1108$us$us$i$us) + ($7)|0);
      $20 = +HEAPF32[$19>>2];
      $21 = $18 + $20;
      $22 = $21 * 0.5;
      HEAPF32[$$197107$us$us$i$us>>2] = $22;
      $23 = (($$1108$us$us$i$us) + ($5)|0);
      $24 = ((($$197107$us$us$i$us)) + 4|0);
      $25 = (($$0100106$us$us$i$us) + 1)|0;
      $exitcond152$i$us = ($25|0)==($0|0);
      if ($exitcond152$i$us) {
       break;
      } else {
       $$0100106$us$us$i$us = $25;$$1108$us$us$i$us = $23;$$197107$us$us$i$us = $24;
      }
     }
     $26 = (($$095112$us$i$us) + ($17)|0);
     $split$us$i$us = (($$096111$us$i$us) + ($0<<2)|0);
     $27 = (($26) + ($5)|0);
     $28 = (($27) + ($7)|0);
     $29 = (($$0101110$us$i$us) + 1)|0;
     $exitcond153$i$us = ($29|0)==($11|0);
     if ($exitcond153$i$us) {
      break;
     } else {
      $$0101110$us$i$us = $29;$$095112$us$i$us = $28;$$096111$us$i$us = $split$us$i$us;
     }
    }
    return;
   } else {
    $$0101110$us$i = 0;$$095112$us$i = $3;$$096111$us$i = $4;
    while(1) {
     $$0100106$us115$i = 0;$$1108$us113$i = $$095112$us$i;$$197107$us114$i = $$096111$us$i;
     while(1) {
      $30 = ((($$1108$us113$i)) + 3|0);
      $31 = HEAP8[$30>>0]|0;
      $32 = $31&255;
      $33 = $32 << 24;
      $34 = ((($$1108$us113$i)) + 2|0);
      $35 = HEAP8[$34>>0]|0;
      $36 = $35&255;
      $37 = $36 << 16;
      $38 = $37 | $33;
      $39 = ((($$1108$us113$i)) + 1|0);
      $40 = HEAP8[$39>>0]|0;
      $41 = $40&255;
      $42 = $41 << 8;
      $43 = $38 | $42;
      $44 = HEAP8[$$1108$us113$i>>0]|0;
      $45 = $44&255;
      $46 = $43 | $45;
      $47 = (+($46>>>0));
      $48 = (($$1108$us113$i) + ($7)|0);
      $49 = ((($48)) + 3|0);
      $50 = HEAP8[$49>>0]|0;
      $51 = $50&255;
      $52 = $51 << 24;
      $53 = ((($48)) + 2|0);
      $54 = HEAP8[$53>>0]|0;
      $55 = $54&255;
      $56 = $55 << 16;
      $57 = $56 | $52;
      $58 = ((($48)) + 1|0);
      $59 = HEAP8[$58>>0]|0;
      $60 = $59&255;
      $61 = $60 << 8;
      $62 = $57 | $61;
      $63 = HEAP8[$48>>0]|0;
      $64 = $63&255;
      $65 = $62 | $64;
      $66 = (+($65>>>0));
      $67 = $47 + $66;
      $68 = $67 * 0.5;
      HEAPF32[$$197107$us114$i>>2] = $68;
      $69 = (($$1108$us113$i) + ($5)|0);
      $70 = ((($$197107$us114$i)) + 4|0);
      $71 = (($$0100106$us115$i) + 1)|0;
      $exitcond$i = ($71|0)==($0|0);
      if ($exitcond$i) {
       break;
      } else {
       $$0100106$us115$i = $71;$$1108$us113$i = $69;$$197107$us114$i = $70;
      }
     }
     $72 = (($$095112$us$i) + ($17)|0);
     $split$us$i = (($$096111$us$i) + ($0<<2)|0);
     $73 = (($72) + ($5)|0);
     $74 = (($73) + ($7)|0);
     $75 = (($$0101110$us$i) + 1)|0;
     $exitcond153$i = ($75|0)==($11|0);
     if ($exitcond153$i) {
      break;
     } else {
      $$0101110$us$i = $75;$$095112$us$i = $74;$$096111$us$i = $split$us$i;
     }
    }
    return;
   }
  }
  if (!($9)) {
   return;
  }
  $76 = (($6) - ($7))|0;
  $77 = ($12|0)!=(0);
  $78 = ($0|0)>(0);
  $or$cond222 = $77 & $78;
  if (!($or$cond222)) {
   return;
  }
  $79 = ($8|0)==(0);
  $80 = (($0) + -1)|0;
  $81 = Math_imul($80, $5)|0;
  if ($79) {
   $$1102129$us$i$us = 0;$$2131$us$i$us = $3;$$298130$us$i$us = $4;
   while(1) {
    $$0124$us$us$i$us = 0;$$3123$us$us$i$us = $$2131$us$i$us;$$399122$us$us$i$us = $$298130$us$i$us;
    while(1) {
     $82 = +HEAPF32[$$3123$us$us$i$us>>2];
     $83 = (($$3123$us$us$i$us) + ($6)|0);
     $84 = +HEAPF32[$83>>2];
     $85 = $82 + $84;
     $86 = $85 * 0.5;
     HEAPF32[$$399122$us$us$i$us>>2] = $86;
     $87 = (($$3123$us$us$i$us) + ($5)|0);
     $88 = ((($$399122$us$us$i$us)) + 4|0);
     $89 = (($$0124$us$us$i$us) + 1)|0;
     $exitcond160$i$us = ($89|0)==($0|0);
     if ($exitcond160$i$us) {
      break;
     } else {
      $$0124$us$us$i$us = $89;$$3123$us$us$i$us = $87;$$399122$us$us$i$us = $88;
     }
    }
    $90 = (($$2131$us$i$us) + ($81)|0);
    $split127$us$i$us = (($$298130$us$i$us) + ($0<<2)|0);
    $91 = (($90) + ($5)|0);
    $92 = (($91) + ($76)|0);
    $93 = (($92) + ($6)|0);
    $94 = (($$1102129$us$i$us) + 1)|0;
    $exitcond161$i$us = ($94|0)==($12|0);
    if ($exitcond161$i$us) {
     break;
    } else {
     $$1102129$us$i$us = $94;$$2131$us$i$us = $93;$$298130$us$i$us = $split127$us$i$us;
    }
   }
   return;
  } else {
   $$1102129$us$i = 0;$$2131$us$i = $3;$$298130$us$i = $4;
   while(1) {
    $$0124$us132$i = 0;$$3123$us133$i = $$2131$us$i;$$399122$us134$i = $$298130$us$i;
    while(1) {
     $95 = ((($$3123$us133$i)) + 3|0);
     $96 = HEAP8[$95>>0]|0;
     $97 = $96&255;
     $98 = $97 << 24;
     $99 = ((($$3123$us133$i)) + 2|0);
     $100 = HEAP8[$99>>0]|0;
     $101 = $100&255;
     $102 = $101 << 16;
     $103 = $102 | $98;
     $104 = ((($$3123$us133$i)) + 1|0);
     $105 = HEAP8[$104>>0]|0;
     $106 = $105&255;
     $107 = $106 << 8;
     $108 = $103 | $107;
     $109 = HEAP8[$$3123$us133$i>>0]|0;
     $110 = $109&255;
     $111 = $108 | $110;
     $112 = (+($111>>>0));
     $113 = (($$3123$us133$i) + ($6)|0);
     $114 = ((($113)) + 3|0);
     $115 = HEAP8[$114>>0]|0;
     $116 = $115&255;
     $117 = $116 << 24;
     $118 = ((($113)) + 2|0);
     $119 = HEAP8[$118>>0]|0;
     $120 = $119&255;
     $121 = $120 << 16;
     $122 = $121 | $117;
     $123 = ((($113)) + 1|0);
     $124 = HEAP8[$123>>0]|0;
     $125 = $124&255;
     $126 = $125 << 8;
     $127 = $122 | $126;
     $128 = HEAP8[$113>>0]|0;
     $129 = $128&255;
     $130 = $127 | $129;
     $131 = (+($130>>>0));
     $132 = $112 + $131;
     $133 = $132 * 0.5;
     HEAPF32[$$399122$us134$i>>2] = $133;
     $134 = (($$3123$us133$i) + ($5)|0);
     $135 = ((($$399122$us134$i)) + 4|0);
     $136 = (($$0124$us132$i) + 1)|0;
     $exitcond157$i = ($136|0)==($0|0);
     if ($exitcond157$i) {
      break;
     } else {
      $$0124$us132$i = $136;$$3123$us133$i = $134;$$399122$us134$i = $135;
     }
    }
    $137 = (($$2131$us$i) + ($81)|0);
    $split127$us$i = (($$298130$us$i) + ($0<<2)|0);
    $138 = (($137) + ($5)|0);
    $139 = (($138) + ($76)|0);
    $140 = (($139) + ($6)|0);
    $141 = (($$1102129$us$i) + 1)|0;
    $exitcond161$i = ($141|0)==($12|0);
    if ($exitcond161$i) {
     break;
    } else {
     $$1102129$us$i = $141;$$2131$us$i = $140;$$298130$us$i = $split127$us$i;
    }
   }
   return;
  }
 }
 $142 = Math_imul($7, $1)|0;
 $143 = (($6) - ($142))|0;
 $144 = ($8|0)==(0);
 $145 = ($12|0)!=(0);
 if ($144) {
  if (!($145)) {
   return;
  }
  $153 = ($11|0)==(0);
  $154 = ($0|0)>(0);
  if ($153) {
   return;
  }
  $155 = (($11) + -1)|0;
  $156 = Math_imul($155, $7)|0;
  $157 = Math_imul($5, $0)|0;
  $158 = Math_imul($11, $0)|0;
  $159 = (($157) + ($7))|0;
  $160 = Math_imul($159, $155)|0;
  $161 = (($157) + ($160))|0;
  $$0120153$us = $3;$$0122152$us = $4;$$0154$us = 0;
  while(1) {
   if ($154) {
    $scevgep203 = (($$0122152$us) + ($158<<2)|0);
    $$0128146$us$us = 0;$$1121148$us$us = $$0120153$us;$$1123147$us$us = $$0122152$us;
    while(1) {
     $scevgep201 = (($$1123147$us$us) + ($0<<2)|0);
     $$0130142$us$us = 0;$$2124143$us$us = $$1123147$us$us;$$2144$us$us = $$1121148$us$us;
     while(1) {
      $169 = +HEAPF32[$$2144$us$us>>2];
      $170 = (($$2144$us$us) + ($7)|0);
      $171 = +HEAPF32[$170>>2];
      $172 = $169 + $171;
      $173 = (($$2144$us$us) + ($6)|0);
      $174 = +HEAPF32[$173>>2];
      $175 = $172 + $174;
      $176 = (($173) + ($7)|0);
      $177 = +HEAPF32[$176>>2];
      $178 = $175 + $177;
      $179 = $178 * 0.25;
      HEAPF32[$$2124143$us$us>>2] = $179;
      $180 = ((($$2124143$us$us)) + 4|0);
      $181 = (($$2144$us$us) + ($5)|0);
      $182 = (($$0130142$us$us) + 1)|0;
      $exitcond = ($182|0)==($0|0);
      if ($exitcond) {
       break;
      } else {
       $$0130142$us$us = $182;$$2124143$us$us = $180;$$2144$us$us = $181;
      }
     }
     $scevgep202 = (($$1121148$us$us) + ($157)|0);
     $167 = (($scevgep202) + ($7)|0);
     $168 = (($$0128146$us$us) + 1)|0;
     $exitcond205 = ($168|0)==($11|0);
     if ($exitcond205) {
      $$pn = $161;$split150$us = $scevgep203;
      break;
     } else {
      $$0128146$us$us = $168;$$1121148$us$us = $167;$$1123147$us$us = $scevgep201;
     }
    }
   } else {
    $$pn = $156;$split150$us = $$0122152$us;
   }
   $162 = (($$0120153$us) + ($$pn)|0);
   $163 = (($162) + ($7)|0);
   $164 = (($163) + ($143)|0);
   $165 = (($164) + ($6)|0);
   $166 = (($$0154$us) + 1)|0;
   $exitcond206 = ($166|0)==($12|0);
   if ($exitcond206) {
    break;
   } else {
    $$0120153$us = $165;$$0122152$us = $split150$us;$$0154$us = $166;
   }
  }
  return;
 }
 if (!($145)) {
  return;
 }
 $146 = ($11|0)==(0);
 $147 = ($0|0)>(0);
 $148 = Math_imul($11, $7)|0;
 $149 = Math_imul($5, $0)|0;
 $150 = (($149) + ($7))|0;
 $151 = Math_imul($150, $11)|0;
 $152 = Math_imul($11, $0)|0;
 $$1187 = 0;$$3125185 = $4;$$3186 = $3;
 while(1) {
  do {
   if ($146) {
    $$4$lcssa = $$3186;$$4126$lcssa = $$3125185;
   } else {
    if (!($147)) {
     $scevgep207 = (($$3186) + ($148)|0);
     $$4$lcssa = $scevgep207;$$4126$lcssa = $$3125185;
     break;
    }
    $scevgep212 = (($$3186) + ($151)|0);
    $$1129179$us = 0;$$4126180$us = $$3125185;$$4181$us = $$3186;
    while(1) {
     $scevgep209 = (($$4126180$us) + ($0<<2)|0);
     $$1131172$us = 0;$$5127173$us = $$4126180$us;$$5174$us = $$4181$us;
     while(1) {
      $183 = ((($$5174$us)) + 3|0);
      $184 = HEAP8[$183>>0]|0;
      $185 = $184&255;
      $186 = $185 << 24;
      $187 = ((($$5174$us)) + 2|0);
      $188 = HEAP8[$187>>0]|0;
      $189 = $188&255;
      $190 = $189 << 16;
      $191 = $190 | $186;
      $192 = ((($$5174$us)) + 1|0);
      $193 = HEAP8[$192>>0]|0;
      $194 = $193&255;
      $195 = $194 << 8;
      $196 = $191 | $195;
      $197 = HEAP8[$$5174$us>>0]|0;
      $198 = $197&255;
      $199 = $196 | $198;
      $200 = (HEAP32[tempDoublePtr>>2]=$199,+HEAPF32[tempDoublePtr>>2]);
      HEAP32[$$5127173$us>>2] = $199;
      $201 = (($$5174$us) + ($7)|0);
      $202 = ((($201)) + 3|0);
      $203 = HEAP8[$202>>0]|0;
      $204 = $203&255;
      $205 = $204 << 24;
      $206 = ((($201)) + 2|0);
      $207 = HEAP8[$206>>0]|0;
      $208 = $207&255;
      $209 = $208 << 16;
      $210 = $209 | $205;
      $211 = ((($201)) + 1|0);
      $212 = HEAP8[$211>>0]|0;
      $213 = $212&255;
      $214 = $213 << 8;
      $215 = $210 | $214;
      $216 = HEAP8[$201>>0]|0;
      $217 = $216&255;
      $218 = $215 | $217;
      $219 = (HEAP32[tempDoublePtr>>2]=$218,+HEAPF32[tempDoublePtr>>2]);
      $220 = $200 + $219;
      HEAPF32[$$5127173$us>>2] = $220;
      $221 = (($$5174$us) + ($6)|0);
      $222 = ((($221)) + 3|0);
      $223 = HEAP8[$222>>0]|0;
      $224 = $223&255;
      $225 = $224 << 24;
      $226 = ((($221)) + 2|0);
      $227 = HEAP8[$226>>0]|0;
      $228 = $227&255;
      $229 = $228 << 16;
      $230 = $229 | $225;
      $231 = ((($221)) + 1|0);
      $232 = HEAP8[$231>>0]|0;
      $233 = $232&255;
      $234 = $233 << 8;
      $235 = $230 | $234;
      $236 = HEAP8[$221>>0]|0;
      $237 = $236&255;
      $238 = $235 | $237;
      $239 = (HEAP32[tempDoublePtr>>2]=$238,+HEAPF32[tempDoublePtr>>2]);
      $240 = $220 + $239;
      HEAPF32[$$5127173$us>>2] = $240;
      $241 = (($221) + ($7)|0);
      $242 = ((($241)) + 3|0);
      $243 = HEAP8[$242>>0]|0;
      $244 = $243&255;
      $245 = $244 << 24;
      $246 = ((($241)) + 2|0);
      $247 = HEAP8[$246>>0]|0;
      $248 = $247&255;
      $249 = $248 << 16;
      $250 = $249 | $245;
      $251 = ((($241)) + 1|0);
      $252 = HEAP8[$251>>0]|0;
      $253 = $252&255;
      $254 = $253 << 8;
      $255 = $250 | $254;
      $256 = HEAP8[$241>>0]|0;
      $257 = $256&255;
      $258 = $255 | $257;
      $259 = (HEAP32[tempDoublePtr>>2]=$258,+HEAPF32[tempDoublePtr>>2]);
      $260 = $240 + $259;
      $261 = $260 * 0.25;
      HEAPF32[$$5127173$us>>2] = $261;
      $262 = ((($$5127173$us)) + 4|0);
      $263 = (($$5174$us) + ($5)|0);
      $264 = (($$1131172$us) + 1)|0;
      $exitcond211 = ($264|0)==($0|0);
      if ($exitcond211) {
       break;
      } else {
       $$1131172$us = $264;$$5127173$us = $262;$$5174$us = $263;
      }
     }
     $scevgep210 = (($$4181$us) + ($149)|0);
     $265 = (($scevgep210) + ($7)|0);
     $266 = (($$1129179$us) + 1)|0;
     $exitcond214 = ($266|0)==($11|0);
     if ($exitcond214) {
      break;
     } else {
      $$1129179$us = $266;$$4126180$us = $scevgep209;$$4181$us = $265;
     }
    }
    $scevgep213 = (($$3125185) + ($152<<2)|0);
    $$4$lcssa = $scevgep212;$$4126$lcssa = $scevgep213;
   }
  } while(0);
  $267 = (($$4$lcssa) + ($143)|0);
  $268 = (($267) + ($6)|0);
  $269 = (($$1187) + 1)|0;
  $exitcond215 = ($269|0)==($12|0);
  if ($exitcond215) {
   break;
  } else {
   $$1187 = $269;$$3125185 = $$4126$lcssa;$$3186 = $268;
  }
 }
 return;
}
function __ZN3osgL11extract4444EiPKvPf($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0.0, $16 = 0.0, $17 = 0, $18 = 0, $19 = 0.0, $20 = 0.0, $21 = 0, $22 = 0, $23 = 0, $24 = 0.0, $25 = 0.0, $26 = 0, $27 = 0, $28 = 0.0;
 var $29 = 0.0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($0|0)==(0);
 if ($3) {
  $12 = HEAP16[$1>>1]|0;
  $$0 = $12;
 } else {
  $4 = ((($1)) + 1|0);
  $5 = HEAP8[$4>>0]|0;
  $6 = $5&255;
  $7 = $6 << 8;
  $8 = HEAP8[$1>>0]|0;
  $9 = $8&255;
  $10 = $7 | $9;
  $11 = $10&65535;
  $$0 = $11;
 }
 $13 = $$0&65535;
 $14 = $13 >>> 12;
 $15 = (+($14|0));
 $16 = $15 / 15.0;
 HEAPF32[$2>>2] = $16;
 $17 = $13 >>> 8;
 $18 = $17 & 15;
 $19 = (+($18|0));
 $20 = $19 / 15.0;
 $21 = ((($2)) + 4|0);
 HEAPF32[$21>>2] = $20;
 $22 = $13 >>> 4;
 $23 = $22 & 15;
 $24 = (+($23|0));
 $25 = $24 / 15.0;
 $26 = ((($2)) + 8|0);
 HEAPF32[$26>>2] = $25;
 $27 = $13 & 15;
 $28 = (+($27|0));
 $29 = $28 / 15.0;
 $30 = ((($2)) + 12|0);
 HEAPF32[$30>>2] = $29;
 return;
}
function __ZN3osgL9shove4444EPKfiPv($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0.0, $13 = 0.0, $14 = 0.0, $15 = 0.0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0.0, $23 = 0.0, $24 = 0.0, $25 = 0.0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0.0, $30 = 0, $31 = 0, $32 = 0.0, $33 = 0.0, $34 = 0.0, $35 = 0.0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0.0, $40 = 0, $5 = 0.0, $6 = 0.0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = +HEAPF32[$0>>2];
 $4 = $3 * 15.0;
 $5 = $4;
 $6 = $5 + 0.5;
 $7 = (~~(($6))&65535);
 $8 = $7&65535;
 $9 = $8 << 12;
 $10 = (($2) + ($1<<1)|0);
 $11 = ((($0)) + 4|0);
 $12 = +HEAPF32[$11>>2];
 $13 = $12 * 15.0;
 $14 = $13;
 $15 = $14 + 0.5;
 $16 = (~~(($15))&65535);
 $17 = $16&65535;
 $18 = $17 << 8;
 $19 = $18 & 3840;
 $20 = $19 | $9;
 $21 = ((($0)) + 8|0);
 $22 = +HEAPF32[$21>>2];
 $23 = $22 * 15.0;
 $24 = $23;
 $25 = $24 + 0.5;
 $26 = (~~(($25))&65535);
 $27 = $26&65535;
 $28 = $27 << 4;
 $29 = $28 & 240;
 $30 = $29 | $20;
 $31 = ((($0)) + 12|0);
 $32 = +HEAPF32[$31>>2];
 $33 = $32 * 15.0;
 $34 = $33;
 $35 = $34 + 0.5;
 $36 = (~~(($35))&65535);
 $37 = $36 & 15;
 $38 = $37&65535;
 $39 = $30 | $38;
 $40 = $39&65535;
 HEAP16[$10>>1] = $40;
 return;
}
function __ZN3osgL21halveImagePackedPixelEiPFviPKvPfEPFvPKfiPvEiiS1_S7_iii($0,$1,$2,$3,$4,$5,$6,$7,$8,$9) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 $8 = $8|0;
 $9 = $9|0;
 var $$07890$us$us = 0, $$07999$us = 0, $$08098$us = 0, $$08197$us = 0, $$08391$us$us = 0, $$08391$us102 = 0, $$084104$us$i = 0, $$085110$i = 0, $$085110$us$i = 0, $$08797$us$i = 0, $$088100$i = 0, $$088100$us$i = 0, $$09098$i = 0, $$09098$us$i = 0, $$18292$us$us = 0, $$18292$us101 = 0, $$191108$i = 0, $$191108$us$i = 0, $$193$us$us = 0, $$193$us100 = 0;
 var $10 = 0, $100 = 0, $101 = 0.0, $102 = 0.0, $103 = 0, $104 = 0.0, $105 = 0.0, $106 = 0.0, $107 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0.0, $28 = 0.0, $29 = 0, $30 = 0.0, $31 = 0.0, $32 = 0.0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0.0, $49 = 0.0, $50 = 0, $51 = 0.0, $52 = 0.0, $53 = 0.0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0.0, $96 = 0.0, $97 = 0, $98 = 0.0, $99 = 0.0, $exitcond = 0, $exitcond$i = 0;
 var $exitcond117$i = 0, $or$cond = 0, $or$cond$i = 0, $split96$us = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(176|0);
 $10 = sp + 160|0;
 $11 = sp + 128|0;
 $12 = sp + 112|0;
 $13 = sp + 80|0;
 $14 = sp + 64|0;
 $15 = sp;
 $16 = ($3|0)==(1);
 $17 = ($4|0)==(1);
 $or$cond = $16 | $17;
 if (!($or$cond)) {
  $62 = (($3|0) / 2)&-1;
  $63 = (($4|0) / 2)&-1;
  $64 = Math_imul($7, $3)|0;
  $65 = (($8) - ($64))|0;
  $66 = ($4|0)>(1);
  if (!($66)) {
   STACKTOP = sp;return;
  }
  $67 = ($3|0)>(1);
  $68 = ((($15)) + 16|0);
  $69 = ((($15)) + 32|0);
  $70 = ((($15)) + 48|0);
  $71 = ($0|0)>(0);
  $72 = $7 << 1;
  if ($67) {
   $$07999$us = 0;$$08098$us = 0;$$08197$us = $5;
  } else {
   STACKTOP = sp;return;
  }
  while(1) {
   if ($71) {
    $$08391$us$us = 0;$$18292$us$us = $$08197$us;$$193$us$us = $$07999$us;
    while(1) {
     FUNCTION_TABLE_viii[$1 & 8191]($9,$$18292$us$us,$15);
     $86 = (($$18292$us$us) + ($7)|0);
     FUNCTION_TABLE_viii[$1 & 8191]($9,$86,$68);
     $87 = (($$18292$us$us) + ($8)|0);
     FUNCTION_TABLE_viii[$1 & 8191]($9,$87,$69);
     $88 = (($87) + ($7)|0);
     FUNCTION_TABLE_viii[$1 & 8191]($9,$88,$70);
     $$07890$us$us = 0;
     while(1) {
      $93 = (($14) + ($$07890$us$us<<2)|0);
      $94 = (($15) + ($$07890$us$us<<2)|0);
      $95 = +HEAPF32[$94>>2];
      $96 = $95 + 0.0;
      $97 = (((($15)) + 16|0) + ($$07890$us$us<<2)|0);
      $98 = +HEAPF32[$97>>2];
      $99 = $96 + $98;
      $100 = (((($15)) + 32|0) + ($$07890$us$us<<2)|0);
      $101 = +HEAPF32[$100>>2];
      $102 = $99 + $101;
      $103 = (((($15)) + 48|0) + ($$07890$us$us<<2)|0);
      $104 = +HEAPF32[$103>>2];
      $105 = $102 + $104;
      $106 = $105 * 0.25;
      HEAPF32[$93>>2] = $106;
      $107 = (($$07890$us$us) + 1)|0;
      $exitcond = ($107|0)==($0|0);
      if ($exitcond) {
       break;
      } else {
       $$07890$us$us = $107;
      }
     }
     FUNCTION_TABLE_viii[$2 & 8191]($14,$$193$us$us,$6);
     $89 = (($$193$us$us) + 1)|0;
     $90 = (($$18292$us$us) + ($72)|0);
     $91 = (($$08391$us$us) + 1)|0;
     $92 = ($91|0)<($62|0);
     if ($92) {
      $$08391$us$us = $91;$$18292$us$us = $90;$$193$us$us = $89;
     } else {
      $81 = $$18292$us$us;$split96$us = $89;
      break;
     }
    }
   } else {
    $$08391$us102 = 0;$$18292$us101 = $$08197$us;$$193$us100 = $$07999$us;
    while(1) {
     FUNCTION_TABLE_viii[$1 & 8191]($9,$$18292$us101,$15);
     $73 = (($$18292$us101) + ($7)|0);
     FUNCTION_TABLE_viii[$1 & 8191]($9,$73,$68);
     $74 = (($$18292$us101) + ($8)|0);
     FUNCTION_TABLE_viii[$1 & 8191]($9,$74,$69);
     $75 = (($74) + ($7)|0);
     FUNCTION_TABLE_viii[$1 & 8191]($9,$75,$70);
     FUNCTION_TABLE_viii[$2 & 8191]($14,$$193$us100,$6);
     $76 = (($$193$us100) + 1)|0;
     $77 = (($$18292$us101) + ($72)|0);
     $78 = (($$08391$us102) + 1)|0;
     $79 = ($78|0)<($62|0);
     if ($79) {
      $$08391$us102 = $78;$$18292$us101 = $77;$$193$us100 = $76;
     } else {
      $81 = $$18292$us101;$split96$us = $76;
      break;
     }
    }
   }
   $80 = (($81) + ($72)|0);
   $82 = (($80) + ($65)|0);
   $83 = (($82) + ($8)|0);
   $84 = (($$08098$us) + 1)|0;
   $85 = ($84|0)<($63|0);
   if ($85) {
    $$07999$us = $split96$us;$$08098$us = $84;$$08197$us = $83;
   } else {
    break;
   }
  }
  STACKTOP = sp;return;
 }
 $18 = (($3|0) / 2)&-1;
 $19 = (($4|0) / 2)&-1;
 if ($17) {
  $20 = ($3|0)>(1);
  if (!($20)) {
   STACKTOP = sp;return;
  }
  $21 = ((($11)) + 16|0);
  $22 = ($0|0)>(0);
  $23 = $7 << 1;
  if ($22) {
   $$088100$us$i = 0;$$09098$us$i = $5;
  } else {
   $$088100$i = 0;$$09098$i = $5;
   while(1) {
    FUNCTION_TABLE_viii[$1 & 8191]($9,$$09098$i,$11);
    $37 = (($$09098$i) + ($7)|0);
    FUNCTION_TABLE_viii[$1 & 8191]($9,$37,$21);
    FUNCTION_TABLE_viii[$2 & 8191]($10,$$088100$i,$6);
    $38 = (($$088100$i) + 1)|0;
    $39 = (($$09098$i) + ($23)|0);
    $40 = ($38|0)<($18|0);
    if ($40) {
     $$088100$i = $38;$$09098$i = $39;
    } else {
     break;
    }
   }
   STACKTOP = sp;return;
  }
  while(1) {
   FUNCTION_TABLE_viii[$1 & 8191]($9,$$09098$us$i,$11);
   $24 = (($$09098$us$i) + ($7)|0);
   FUNCTION_TABLE_viii[$1 & 8191]($9,$24,$21);
   $$08797$us$i = 0;
   while(1) {
    $25 = (($10) + ($$08797$us$i<<2)|0);
    $26 = (($11) + ($$08797$us$i<<2)|0);
    $27 = +HEAPF32[$26>>2];
    $28 = $27 + 0.0;
    $29 = (((($11)) + 16|0) + ($$08797$us$i<<2)|0);
    $30 = +HEAPF32[$29>>2];
    $31 = $28 + $30;
    $32 = $31 * 0.5;
    HEAPF32[$25>>2] = $32;
    $33 = (($$08797$us$i) + 1)|0;
    $exitcond$i = ($33|0)==($0|0);
    if ($exitcond$i) {
     break;
    } else {
     $$08797$us$i = $33;
    }
   }
   FUNCTION_TABLE_viii[$2 & 8191]($10,$$088100$us$i,$6);
   $34 = (($$088100$us$i) + 1)|0;
   $35 = (($$09098$us$i) + ($23)|0);
   $36 = ($34|0)<($18|0);
   if ($36) {
    $$088100$us$i = $34;$$09098$us$i = $35;
   } else {
    break;
   }
  }
  STACKTOP = sp;return;
 } else {
  $41 = ($4|0)>(1);
  $or$cond$i = $16 & $41;
  if (!($or$cond$i)) {
   STACKTOP = sp;return;
  }
  $42 = ((($13)) + 16|0);
  $43 = ($0|0)>(0);
  $44 = $8 << 1;
  if ($43) {
   $$085110$us$i = 0;$$191108$us$i = $5;
  } else {
   $$085110$i = 0;$$191108$i = $5;
   while(1) {
    FUNCTION_TABLE_viii[$1 & 8191]($9,$$191108$i,$13);
    $58 = (($$191108$i) + ($8)|0);
    FUNCTION_TABLE_viii[$1 & 8191]($9,$58,$42);
    FUNCTION_TABLE_viii[$2 & 8191]($12,$$085110$i,$6);
    $59 = (($$085110$i) + 1)|0;
    $60 = (($$191108$i) + ($44)|0);
    $61 = ($59|0)<($19|0);
    if ($61) {
     $$085110$i = $59;$$191108$i = $60;
    } else {
     break;
    }
   }
   STACKTOP = sp;return;
  }
  while(1) {
   FUNCTION_TABLE_viii[$1 & 8191]($9,$$191108$us$i,$13);
   $45 = (($$191108$us$i) + ($8)|0);
   FUNCTION_TABLE_viii[$1 & 8191]($9,$45,$42);
   $$084104$us$i = 0;
   while(1) {
    $46 = (($12) + ($$084104$us$i<<2)|0);
    $47 = (($13) + ($$084104$us$i<<2)|0);
    $48 = +HEAPF32[$47>>2];
    $49 = $48 + 0.0;
    $50 = (((($13)) + 16|0) + ($$084104$us$i<<2)|0);
    $51 = +HEAPF32[$50>>2];
    $52 = $49 + $51;
    $53 = $52 * 0.5;
    HEAPF32[$46>>2] = $53;
    $54 = (($$084104$us$i) + 1)|0;
    $exitcond117$i = ($54|0)==($0|0);
    if ($exitcond117$i) {
     break;
    } else {
     $$084104$us$i = $54;
    }
   }
   FUNCTION_TABLE_viii[$2 & 8191]($12,$$085110$us$i,$6);
   $55 = (($$085110$us$i) + 1)|0;
   $56 = (($$191108$us$i) + ($44)|0);
   $57 = ($55|0)<($19|0);
   if ($57) {
    $$085110$us$i = $55;$$191108$us$i = $56;
   } else {
    break;
   }
  }
  STACKTOP = sp;return;
 }
}
function __ZN3osgL14extract4444revEiPKvPf($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0.0, $16 = 0.0, $17 = 0, $18 = 0, $19 = 0.0, $20 = 0.0, $21 = 0, $22 = 0, $23 = 0, $24 = 0.0, $25 = 0.0, $26 = 0, $27 = 0, $28 = 0.0;
 var $29 = 0.0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($0|0)==(0);
 if ($3) {
  $12 = HEAP16[$1>>1]|0;
  $$0 = $12;
 } else {
  $4 = ((($1)) + 1|0);
  $5 = HEAP8[$4>>0]|0;
  $6 = $5&255;
  $7 = $6 << 8;
  $8 = HEAP8[$1>>0]|0;
  $9 = $8&255;
  $10 = $7 | $9;
  $11 = $10&65535;
  $$0 = $11;
 }
 $13 = $$0&65535;
 $14 = $13 & 15;
 $15 = (+($14|0));
 $16 = $15 / 15.0;
 HEAPF32[$2>>2] = $16;
 $17 = $13 >>> 4;
 $18 = $17 & 15;
 $19 = (+($18|0));
 $20 = $19 / 15.0;
 $21 = ((($2)) + 4|0);
 HEAPF32[$21>>2] = $20;
 $22 = $13 >>> 8;
 $23 = $22 & 15;
 $24 = (+($23|0));
 $25 = $24 / 15.0;
 $26 = ((($2)) + 8|0);
 HEAPF32[$26>>2] = $25;
 $27 = $13 >>> 12;
 $28 = (+($27|0));
 $29 = $28 / 15.0;
 $30 = ((($2)) + 12|0);
 HEAPF32[$30>>2] = $29;
 return;
}
function __ZN3osgL12shove4444revEPKfiPv($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0.0, $12 = 0.0, $13 = 0.0, $14 = 0.0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0.0, $23 = 0.0, $24 = 0.0, $25 = 0.0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0.0, $30 = 0, $31 = 0, $32 = 0.0, $33 = 0.0, $34 = 0.0, $35 = 0.0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0.0, $40 = 0, $5 = 0.0, $6 = 0.0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = +HEAPF32[$0>>2];
 $4 = $3 * 15.0;
 $5 = $4;
 $6 = $5 + 0.5;
 $7 = (~~(($6))&65535);
 $8 = $7 & 15;
 $9 = (($2) + ($1<<1)|0);
 $10 = ((($0)) + 4|0);
 $11 = +HEAPF32[$10>>2];
 $12 = $11 * 15.0;
 $13 = $12;
 $14 = $13 + 0.5;
 $15 = (~~(($14))&65535);
 $16 = $15&65535;
 $17 = $16 << 4;
 $18 = $17 & 240;
 $19 = $8&65535;
 $20 = $18 | $19;
 $21 = ((($0)) + 8|0);
 $22 = +HEAPF32[$21>>2];
 $23 = $22 * 15.0;
 $24 = $23;
 $25 = $24 + 0.5;
 $26 = (~~(($25))&65535);
 $27 = $26&65535;
 $28 = $27 << 8;
 $29 = $28 & 3840;
 $30 = $29 | $20;
 $31 = ((($0)) + 12|0);
 $32 = +HEAPF32[$31>>2];
 $33 = $32 * 15.0;
 $34 = $33;
 $35 = $34 + 0.5;
 $36 = (~~(($35))&65535);
 $37 = $36&65535;
 $38 = $37 << 12;
 $39 = $30 | $38;
 $40 = $39&65535;
 HEAP16[$9>>1] = $40;
 return;
}
function __ZN3osgL11extract5551EiPKvPf($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0.0, $16 = 0.0, $17 = 0, $18 = 0, $19 = 0.0, $20 = 0.0, $21 = 0, $22 = 0, $23 = 0, $24 = 0.0, $25 = 0.0, $26 = 0, $27 = 0, $28 = 0.0;
 var $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($0|0)==(0);
 if ($3) {
  $12 = HEAP16[$1>>1]|0;
  $$0 = $12;
 } else {
  $4 = ((($1)) + 1|0);
  $5 = HEAP8[$4>>0]|0;
  $6 = $5&255;
  $7 = $6 << 8;
  $8 = HEAP8[$1>>0]|0;
  $9 = $8&255;
  $10 = $7 | $9;
  $11 = $10&65535;
  $$0 = $11;
 }
 $13 = $$0&65535;
 $14 = $13 >>> 11;
 $15 = (+($14|0));
 $16 = $15 / 31.0;
 HEAPF32[$2>>2] = $16;
 $17 = $13 >>> 6;
 $18 = $17 & 31;
 $19 = (+($18|0));
 $20 = $19 / 31.0;
 $21 = ((($2)) + 4|0);
 HEAPF32[$21>>2] = $20;
 $22 = $13 >>> 1;
 $23 = $22 & 31;
 $24 = (+($23|0));
 $25 = $24 / 31.0;
 $26 = ((($2)) + 8|0);
 HEAPF32[$26>>2] = $25;
 $27 = $13 & 1;
 $28 = (+($27|0));
 $29 = ((($2)) + 12|0);
 HEAPF32[$29>>2] = $28;
 return;
}
function __ZN3osgL9shove5551EPKfiPv($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0.0, $13 = 0.0, $14 = 0.0, $15 = 0.0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0.0, $23 = 0.0, $24 = 0.0, $25 = 0.0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0.0, $30 = 0, $31 = 0, $32 = 0.0, $33 = 0.0, $34 = 0.0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0.0, $5 = 0.0, $6 = 0.0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = +HEAPF32[$0>>2];
 $4 = $3 * 31.0;
 $5 = $4;
 $6 = $5 + 0.5;
 $7 = (~~(($6))&65535);
 $8 = $7&65535;
 $9 = $8 << 11;
 $10 = (($2) + ($1<<1)|0);
 $11 = ((($0)) + 4|0);
 $12 = +HEAPF32[$11>>2];
 $13 = $12 * 31.0;
 $14 = $13;
 $15 = $14 + 0.5;
 $16 = (~~(($15))&65535);
 $17 = $16&65535;
 $18 = $17 << 6;
 $19 = $18 & 1984;
 $20 = $19 | $9;
 $21 = ((($0)) + 8|0);
 $22 = +HEAPF32[$21>>2];
 $23 = $22 * 31.0;
 $24 = $23;
 $25 = $24 + 0.5;
 $26 = (~~(($25))&65535);
 $27 = $26&65535;
 $28 = $27 << 1;
 $29 = $28 & 62;
 $30 = $29 | $20;
 $31 = ((($0)) + 12|0);
 $32 = +HEAPF32[$31>>2];
 $33 = $32;
 $34 = $33 + 0.5;
 $35 = (~~(($34))&65535);
 $36 = $35 & 1;
 $37 = $36&65535;
 $38 = $30 | $37;
 $39 = $38&65535;
 HEAP16[$10>>1] = $39;
 return;
}
function __ZN3osgL14extract1555revEiPKvPf($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0.0, $16 = 0.0, $17 = 0, $18 = 0, $19 = 0.0, $20 = 0.0, $21 = 0, $22 = 0, $23 = 0, $24 = 0.0, $25 = 0.0, $26 = 0, $27 = 0, $28 = 0.0;
 var $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($0|0)==(0);
 if ($3) {
  $12 = HEAP16[$1>>1]|0;
  $$0 = $12;
 } else {
  $4 = ((($1)) + 1|0);
  $5 = HEAP8[$4>>0]|0;
  $6 = $5&255;
  $7 = $6 << 8;
  $8 = HEAP8[$1>>0]|0;
  $9 = $8&255;
  $10 = $7 | $9;
  $11 = $10&65535;
  $$0 = $11;
 }
 $13 = $$0&65535;
 $14 = $13 & 31;
 $15 = (+($14|0));
 $16 = $15 / 31.0;
 HEAPF32[$2>>2] = $16;
 $17 = $13 >>> 5;
 $18 = $17 & 31;
 $19 = (+($18|0));
 $20 = $19 / 31.0;
 $21 = ((($2)) + 4|0);
 HEAPF32[$21>>2] = $20;
 $22 = $13 >>> 10;
 $23 = $22 & 31;
 $24 = (+($23|0));
 $25 = $24 / 31.0;
 $26 = ((($2)) + 8|0);
 HEAPF32[$26>>2] = $25;
 $27 = $13 >>> 15;
 $28 = (+($27|0));
 $29 = ((($2)) + 12|0);
 HEAPF32[$29>>2] = $28;
 return;
}
function __ZN3osgL12shove1555revEPKfiPv($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0.0, $12 = 0.0, $13 = 0.0, $14 = 0.0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0.0, $23 = 0.0, $24 = 0.0, $25 = 0.0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0.0, $30 = 0, $31 = 0, $32 = 0.0, $33 = 0.0, $34 = 0.0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0.0, $5 = 0.0, $6 = 0.0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = +HEAPF32[$0>>2];
 $4 = $3 * 31.0;
 $5 = $4;
 $6 = $5 + 0.5;
 $7 = (~~(($6))&65535);
 $8 = $7 & 31;
 $9 = (($2) + ($1<<1)|0);
 $10 = ((($0)) + 4|0);
 $11 = +HEAPF32[$10>>2];
 $12 = $11 * 31.0;
 $13 = $12;
 $14 = $13 + 0.5;
 $15 = (~~(($14))&65535);
 $16 = $15&65535;
 $17 = $16 << 5;
 $18 = $17 & 992;
 $19 = $8&65535;
 $20 = $18 | $19;
 $21 = ((($0)) + 8|0);
 $22 = +HEAPF32[$21>>2];
 $23 = $22 * 31.0;
 $24 = $23;
 $25 = $24 + 0.5;
 $26 = (~~(($25))&65535);
 $27 = $26&65535;
 $28 = $27 << 10;
 $29 = $28 & 31744;
 $30 = $29 | $20;
 $31 = ((($0)) + 12|0);
 $32 = +HEAPF32[$31>>2];
 $33 = $32;
 $34 = $33 + 0.5;
 $35 = (~~(($34))&65535);
 $36 = $35&65535;
 $37 = $36 << 15;
 $38 = $30 | $37;
 $39 = $38&65535;
 HEAP16[$9>>1] = $39;
 return;
}
function __ZN3osgL11extract8888EiPKvPf($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0.0, $24 = 0.0, $25 = 0, $26 = 0, $27 = 0.0, $28 = 0.0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0.0, $33 = 0.0, $34 = 0, $35 = 0, $36 = 0.0, $37 = 0.0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($0|0)==(0);
 if ($3) {
  $21 = HEAP32[$1>>2]|0;
  $$0 = $21;
 } else {
  $4 = ((($1)) + 3|0);
  $5 = HEAP8[$4>>0]|0;
  $6 = $5&255;
  $7 = $6 << 24;
  $8 = ((($1)) + 2|0);
  $9 = HEAP8[$8>>0]|0;
  $10 = $9&255;
  $11 = $10 << 16;
  $12 = $11 | $7;
  $13 = ((($1)) + 1|0);
  $14 = HEAP8[$13>>0]|0;
  $15 = $14&255;
  $16 = $15 << 8;
  $17 = $12 | $16;
  $18 = HEAP8[$1>>0]|0;
  $19 = $18&255;
  $20 = $17 | $19;
  $$0 = $20;
 }
 $22 = $$0 >>> 24;
 $23 = (+($22>>>0));
 $24 = $23 / 255.0;
 HEAPF32[$2>>2] = $24;
 $25 = $$0 >>> 16;
 $26 = $25 & 255;
 $27 = (+($26>>>0));
 $28 = $27 / 255.0;
 $29 = ((($2)) + 4|0);
 HEAPF32[$29>>2] = $28;
 $30 = $$0 >>> 8;
 $31 = $30 & 255;
 $32 = (+($31>>>0));
 $33 = $32 / 255.0;
 $34 = ((($2)) + 8|0);
 HEAPF32[$34>>2] = $33;
 $35 = $$0 & 255;
 $36 = (+($35>>>0));
 $37 = $36 / 255.0;
 $38 = ((($2)) + 12|0);
 HEAPF32[$38>>2] = $37;
 return;
}
function __ZN3osgL9shove8888EPKfiPv($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0.0, $12 = 0.0, $13 = 0.0, $14 = 0.0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0.0;
 var $3 = 0.0, $30 = 0.0, $31 = 0.0, $32 = 0.0, $33 = 0, $34 = 0, $35 = 0, $4 = 0.0, $5 = 0.0, $6 = 0.0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = +HEAPF32[$0>>2];
 $4 = $3 * 255.0;
 $5 = $4;
 $6 = $5 + 0.5;
 $7 = (~~(($6))>>>0);
 $8 = $7 << 24;
 $9 = (($2) + ($1<<2)|0);
 $10 = ((($0)) + 4|0);
 $11 = +HEAPF32[$10>>2];
 $12 = $11 * 255.0;
 $13 = $12;
 $14 = $13 + 0.5;
 $15 = (~~(($14))>>>0);
 $16 = $15 << 16;
 $17 = $16 & 16711680;
 $18 = $17 | $8;
 $19 = ((($0)) + 8|0);
 $20 = +HEAPF32[$19>>2];
 $21 = $20 * 255.0;
 $22 = $21;
 $23 = $22 + 0.5;
 $24 = (~~(($23))>>>0);
 $25 = $24 << 8;
 $26 = $25 & 65280;
 $27 = $26 | $18;
 $28 = ((($0)) + 12|0);
 $29 = +HEAPF32[$28>>2];
 $30 = $29 * 255.0;
 $31 = $30;
 $32 = $31 + 0.5;
 $33 = (~~(($32))>>>0);
 $34 = $33 & 255;
 $35 = $27 | $34;
 HEAP32[$9>>2] = $35;
 return;
}
function __ZN3osgL14extract8888revEiPKvPf($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0.0, $24 = 0.0, $25 = 0, $26 = 0, $27 = 0.0, $28 = 0.0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0.0, $33 = 0.0, $34 = 0, $35 = 0, $36 = 0.0, $37 = 0.0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($0|0)==(0);
 if ($3) {
  $21 = HEAP32[$1>>2]|0;
  $$0 = $21;
 } else {
  $4 = ((($1)) + 3|0);
  $5 = HEAP8[$4>>0]|0;
  $6 = $5&255;
  $7 = $6 << 24;
  $8 = ((($1)) + 2|0);
  $9 = HEAP8[$8>>0]|0;
  $10 = $9&255;
  $11 = $10 << 16;
  $12 = $11 | $7;
  $13 = ((($1)) + 1|0);
  $14 = HEAP8[$13>>0]|0;
  $15 = $14&255;
  $16 = $15 << 8;
  $17 = $12 | $16;
  $18 = HEAP8[$1>>0]|0;
  $19 = $18&255;
  $20 = $17 | $19;
  $$0 = $20;
 }
 $22 = $$0 & 255;
 $23 = (+($22>>>0));
 $24 = $23 / 255.0;
 HEAPF32[$2>>2] = $24;
 $25 = $$0 >>> 8;
 $26 = $25 & 255;
 $27 = (+($26>>>0));
 $28 = $27 / 255.0;
 $29 = ((($2)) + 4|0);
 HEAPF32[$29>>2] = $28;
 $30 = $$0 >>> 16;
 $31 = $30 & 255;
 $32 = (+($31>>>0));
 $33 = $32 / 255.0;
 $34 = ((($2)) + 8|0);
 HEAPF32[$34>>2] = $33;
 $35 = $$0 >>> 24;
 $36 = (+($35>>>0));
 $37 = $36 / 255.0;
 $38 = ((($2)) + 12|0);
 HEAPF32[$38>>2] = $37;
 return;
}
function __ZN3osgL12shove8888revEPKfiPv($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0.0, $12 = 0.0, $13 = 0.0, $14 = 0.0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0.0;
 var $3 = 0.0, $30 = 0.0, $31 = 0.0, $32 = 0.0, $33 = 0, $34 = 0, $35 = 0, $4 = 0.0, $5 = 0.0, $6 = 0.0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = +HEAPF32[$0>>2];
 $4 = $3 * 255.0;
 $5 = $4;
 $6 = $5 + 0.5;
 $7 = (~~(($6))>>>0);
 $8 = $7 & 255;
 $9 = (($2) + ($1<<2)|0);
 $10 = ((($0)) + 4|0);
 $11 = +HEAPF32[$10>>2];
 $12 = $11 * 255.0;
 $13 = $12;
 $14 = $13 + 0.5;
 $15 = (~~(($14))>>>0);
 $16 = $15 << 8;
 $17 = $16 & 65280;
 $18 = $17 | $8;
 $19 = ((($0)) + 8|0);
 $20 = +HEAPF32[$19>>2];
 $21 = $20 * 255.0;
 $22 = $21;
 $23 = $22 + 0.5;
 $24 = (~~(($23))>>>0);
 $25 = $24 << 16;
 $26 = $25 & 16711680;
 $27 = $26 | $18;
 $28 = ((($0)) + 12|0);
 $29 = +HEAPF32[$28>>2];
 $30 = $29 * 255.0;
 $31 = $30;
 $32 = $31 + 0.5;
 $33 = (~~(($32))>>>0);
 $34 = $33 << 24;
 $35 = $27 | $34;
 HEAP32[$9>>2] = $35;
 return;
}
function __ZN3osgL14extract1010102EiPKvPf($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0.0, $24 = 0.0, $25 = 0, $26 = 0, $27 = 0.0, $28 = 0.0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0.0, $33 = 0.0, $34 = 0, $35 = 0, $36 = 0.0, $37 = 0.0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($0|0)==(0);
 if ($3) {
  $21 = HEAP32[$1>>2]|0;
  $$0 = $21;
 } else {
  $4 = ((($1)) + 3|0);
  $5 = HEAP8[$4>>0]|0;
  $6 = $5&255;
  $7 = $6 << 24;
  $8 = ((($1)) + 2|0);
  $9 = HEAP8[$8>>0]|0;
  $10 = $9&255;
  $11 = $10 << 16;
  $12 = $11 | $7;
  $13 = ((($1)) + 1|0);
  $14 = HEAP8[$13>>0]|0;
  $15 = $14&255;
  $16 = $15 << 8;
  $17 = $12 | $16;
  $18 = HEAP8[$1>>0]|0;
  $19 = $18&255;
  $20 = $17 | $19;
  $$0 = $20;
 }
 $22 = $$0 >>> 22;
 $23 = (+($22>>>0));
 $24 = $23 / 1023.0;
 HEAPF32[$2>>2] = $24;
 $25 = $$0 >>> 12;
 $26 = $25 & 1023;
 $27 = (+($26>>>0));
 $28 = $27 / 1023.0;
 $29 = ((($2)) + 4|0);
 HEAPF32[$29>>2] = $28;
 $30 = $$0 >>> 2;
 $31 = $30 & 1023;
 $32 = (+($31>>>0));
 $33 = $32 / 1023.0;
 $34 = ((($2)) + 8|0);
 HEAPF32[$34>>2] = $33;
 $35 = $$0 & 3;
 $36 = (+($35>>>0));
 $37 = $36 / 3.0;
 $38 = ((($2)) + 12|0);
 HEAPF32[$38>>2] = $37;
 return;
}
function __ZN3osgL12shove1010102EPKfiPv($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0.0, $12 = 0.0, $13 = 0.0, $14 = 0.0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0.0;
 var $3 = 0.0, $30 = 0.0, $31 = 0.0, $32 = 0.0, $33 = 0, $34 = 0, $35 = 0, $4 = 0.0, $5 = 0.0, $6 = 0.0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = +HEAPF32[$0>>2];
 $4 = $3 * 1023.0;
 $5 = $4;
 $6 = $5 + 0.5;
 $7 = (~~(($6))>>>0);
 $8 = $7 << 22;
 $9 = (($2) + ($1<<2)|0);
 $10 = ((($0)) + 4|0);
 $11 = +HEAPF32[$10>>2];
 $12 = $11 * 1023.0;
 $13 = $12;
 $14 = $13 + 0.5;
 $15 = (~~(($14))>>>0);
 $16 = $15 << 12;
 $17 = $16 & 4190208;
 $18 = $17 | $8;
 $19 = ((($0)) + 8|0);
 $20 = +HEAPF32[$19>>2];
 $21 = $20 * 1023.0;
 $22 = $21;
 $23 = $22 + 0.5;
 $24 = (~~(($23))>>>0);
 $25 = $24 << 2;
 $26 = $25 & 4092;
 $27 = $26 | $18;
 $28 = ((($0)) + 12|0);
 $29 = +HEAPF32[$28>>2];
 $30 = $29 * 3.0;
 $31 = $30;
 $32 = $31 + 0.5;
 $33 = (~~(($32))>>>0);
 $34 = $33 & 3;
 $35 = $27 | $34;
 HEAP32[$9>>2] = $35;
 return;
}
function __ZN3osgL17extract2101010revEiPKvPf($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0.0, $24 = 0.0, $25 = 0, $26 = 0, $27 = 0.0, $28 = 0.0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0.0, $33 = 0.0, $34 = 0, $35 = 0, $36 = 0.0, $37 = 0.0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($0|0)==(0);
 if ($3) {
  $21 = HEAP32[$1>>2]|0;
  $$0 = $21;
 } else {
  $4 = ((($1)) + 3|0);
  $5 = HEAP8[$4>>0]|0;
  $6 = $5&255;
  $7 = $6 << 24;
  $8 = ((($1)) + 2|0);
  $9 = HEAP8[$8>>0]|0;
  $10 = $9&255;
  $11 = $10 << 16;
  $12 = $11 | $7;
  $13 = ((($1)) + 1|0);
  $14 = HEAP8[$13>>0]|0;
  $15 = $14&255;
  $16 = $15 << 8;
  $17 = $12 | $16;
  $18 = HEAP8[$1>>0]|0;
  $19 = $18&255;
  $20 = $17 | $19;
  $$0 = $20;
 }
 $22 = $$0 & 1023;
 $23 = (+($22>>>0));
 $24 = $23 / 1023.0;
 HEAPF32[$2>>2] = $24;
 $25 = $$0 >>> 10;
 $26 = $25 & 1023;
 $27 = (+($26>>>0));
 $28 = $27 / 1023.0;
 $29 = ((($2)) + 4|0);
 HEAPF32[$29>>2] = $28;
 $30 = $$0 >>> 20;
 $31 = $30 & 1023;
 $32 = (+($31>>>0));
 $33 = $32 / 1023.0;
 $34 = ((($2)) + 8|0);
 HEAPF32[$34>>2] = $33;
 $35 = $$0 >>> 30;
 $36 = (+($35>>>0));
 $37 = $36 / 3.0;
 $38 = ((($2)) + 12|0);
 HEAPF32[$38>>2] = $37;
 return;
}
function __ZN3osgL15shove2101010revEPKfiPv($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0.0, $12 = 0.0, $13 = 0.0, $14 = 0.0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0.0;
 var $3 = 0.0, $30 = 0.0, $31 = 0.0, $32 = 0.0, $33 = 0, $34 = 0, $35 = 0, $4 = 0.0, $5 = 0.0, $6 = 0.0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = +HEAPF32[$0>>2];
 $4 = $3 * 1023.0;
 $5 = $4;
 $6 = $5 + 0.5;
 $7 = (~~(($6))>>>0);
 $8 = $7 & 1023;
 $9 = (($2) + ($1<<2)|0);
 $10 = ((($0)) + 4|0);
 $11 = +HEAPF32[$10>>2];
 $12 = $11 * 1023.0;
 $13 = $12;
 $14 = $13 + 0.5;
 $15 = (~~(($14))>>>0);
 $16 = $15 << 10;
 $17 = $16 & 1047552;
 $18 = $17 | $8;
 $19 = ((($0)) + 8|0);
 $20 = +HEAPF32[$19>>2];
 $21 = $20 * 1023.0;
 $22 = $21;
 $23 = $22 + 0.5;
 $24 = (~~(($23))>>>0);
 $25 = $24 << 20;
 $26 = $25 & 1072693248;
 $27 = $26 | $18;
 $28 = ((($0)) + 12|0);
 $29 = +HEAPF32[$28>>2];
 $30 = $29 * 3.0;
 $31 = $30;
 $32 = $31 + 0.5;
 $33 = (~~(($32))>>>0);
 $34 = $33 << 30;
 $35 = $27 | $34;
 HEAP32[$9>>2] = $35;
 return;
}
function __ZN3osgL10extract565EiPKvPf($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0.0, $16 = 0.0, $17 = 0, $18 = 0, $19 = 0.0, $20 = 0.0, $21 = 0, $22 = 0, $23 = 0.0, $24 = 0.0, $25 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($0|0)==(0);
 if ($3) {
  $12 = HEAP16[$1>>1]|0;
  $$0 = $12;
 } else {
  $4 = ((($1)) + 1|0);
  $5 = HEAP8[$4>>0]|0;
  $6 = $5&255;
  $7 = $6 << 8;
  $8 = HEAP8[$1>>0]|0;
  $9 = $8&255;
  $10 = $7 | $9;
  $11 = $10&65535;
  $$0 = $11;
 }
 $13 = $$0&65535;
 $14 = $13 >>> 11;
 $15 = (+($14|0));
 $16 = $15 / 31.0;
 HEAPF32[$2>>2] = $16;
 $17 = $13 >>> 5;
 $18 = $17 & 63;
 $19 = (+($18|0));
 $20 = $19 / 63.0;
 $21 = ((($2)) + 4|0);
 HEAPF32[$21>>2] = $20;
 $22 = $13 & 31;
 $23 = (+($22|0));
 $24 = $23 / 31.0;
 $25 = ((($2)) + 8|0);
 HEAPF32[$25>>2] = $24;
 return;
}
function __ZN3osgL8shove565EPKfiPv($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0.0, $13 = 0.0, $14 = 0.0, $15 = 0.0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0.0, $23 = 0.0, $24 = 0.0, $25 = 0.0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0.0, $30 = 0, $4 = 0.0, $5 = 0.0, $6 = 0.0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = +HEAPF32[$0>>2];
 $4 = $3 * 31.0;
 $5 = $4;
 $6 = $5 + 0.5;
 $7 = (~~(($6))&65535);
 $8 = $7&65535;
 $9 = $8 << 11;
 $10 = (($2) + ($1<<1)|0);
 $11 = ((($0)) + 4|0);
 $12 = +HEAPF32[$11>>2];
 $13 = $12 * 63.0;
 $14 = $13;
 $15 = $14 + 0.5;
 $16 = (~~(($15))&65535);
 $17 = $16&65535;
 $18 = $17 << 5;
 $19 = $18 & 2016;
 $20 = $19 | $9;
 $21 = ((($0)) + 8|0);
 $22 = +HEAPF32[$21>>2];
 $23 = $22 * 31.0;
 $24 = $23;
 $25 = $24 + 0.5;
 $26 = (~~(($25))&65535);
 $27 = $26 & 31;
 $28 = $27&65535;
 $29 = $20 | $28;
 $30 = $29&65535;
 HEAP16[$10>>1] = $30;
 return;
}
function __ZN3osgL24scaleInternalPackedPixelEiPFviPKvPfEPFvPKfiPvEiiS1_iiS7_iii($0,$1,$2,$3,$4,$5,$6,$7,$8,$9,$10,$11) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 $8 = $8|0;
 $9 = $9|0;
 $10 = $10|0;
 $11 = $11|0;
 var $$0369475 = 0, $$0369475$us = 0, $$0370 = 0, $$0370$us = 0, $$0370474 = 0, $$0370477 = 0, $$0370477$us = 0, $$0371448 = 0, $$0371448$us = 0, $$0374510 = 0, $$0375503 = 0, $$0376440 = 0, $$0380509 = 0.0, $$0382508 = 0.0, $$0382508$phi = 0.0, $$0383499 = 0.0, $$0385498 = 0.0, $$0385498$phi = 0.0, $$0391507 = 0, $$0393506 = 0;
 var $$0393506$phi = 0, $$0394496 = 0, $$0396495 = 0, $$0396495$phi = 0, $$0397488 = 0, $$0476 = 0, $$0476$us = 0, $$1 = 0, $$1$us = 0, $$10415 = 0, $$11417$us = 0, $$12422 = 0, $$13414 = 0, $$1372464 = 0, $$1372464$us = 0, $$1377444$us = 0, $$1381 = 0.0, $$1384 = 0.0, $$1392 = 0, $$1395 = 0;
 var $$1433 = 0, $$1433$us = 0, $$14479$us = 0, $$15491 = 0, $$2373 = 0, $$2373$us = 0, $$2373419 = 0, $$2373420 = 0, $$2373420$us = 0, $$2378453 = 0, $$2388$lcssa = 0, $$2388432 = 0, $$2388432$us = 0, $$2489 = 0, $$3 = 0, $$3$us = 0, $$3379457 = 0, $$3483 = 0, $$3485 = 0, $$3485$us = 0;
 var $$4390484 = 0, $$4390484$us = 0, $$4460$us = 0, $$5468 = 0, $$6471$us = 0, $$7425 = 0, $$8428$us = 0, $$9437 = 0, $$lcssa = 0, $$lcssa412 = 0, $$lcssa413 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0.0, $104 = 0.0, $105 = 0, $106 = 0.0, $107 = 0.0, $108 = 0;
 var $109 = 0, $110 = 0, $111 = 0, $112 = 0.0, $113 = 0, $114 = 0, $115 = 0, $116 = 0.0, $117 = 0.0, $118 = 0, $119 = 0.0, $12 = 0, $120 = 0.0, $121 = 0.0, $122 = 0, $123 = 0.0, $124 = 0.0, $125 = 0, $126 = 0, $127 = 0.0;
 var $128 = 0.0, $129 = 0, $13 = 0, $130 = 0.0, $131 = 0.0, $132 = 0, $133 = 0, $134 = 0, $135 = 0.0, $136 = 0.0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0.0, $142 = 0.0, $143 = 0, $144 = 0.0, $145 = 0.0;
 var $146 = 0, $147 = 0, $148 = 0.0, $149 = 0.0, $15 = 0, $150 = 0, $151 = 0.0, $152 = 0.0, $153 = 0, $154 = 0, $155 = 0.0, $156 = 0, $157 = 0, $158 = 0.0, $159 = 0.0, $16 = 0, $160 = 0, $161 = 0.0, $162 = 0.0, $163 = 0;
 var $164 = 0.0, $165 = 0.0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0.0, $174 = 0.0, $175 = 0, $176 = 0.0, $177 = 0.0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0.0;
 var $182 = 0.0, $183 = 0, $184 = 0.0, $185 = 0.0, $186 = 0, $187 = 0, $188 = 0, $189 = 0.0, $19 = 0, $190 = 0, $191 = 0.0, $192 = 0.0, $193 = 0, $194 = 0.0, $195 = 0.0, $196 = 0, $197 = 0.0, $198 = 0.0, $199 = 0, $20 = 0.0;
 var $200 = 0, $201 = 0, $202 = 0.0, $203 = 0.0, $204 = 0, $205 = 0.0, $206 = 0.0, $207 = 0, $208 = 0, $209 = 0, $21 = 0.0, $210 = 0, $211 = 0, $212 = 0, $213 = 0.0, $214 = 0, $215 = 0.0, $216 = 0.0, $217 = 0, $218 = 0;
 var $219 = 0, $22 = 0.0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0.0, $225 = 0.0, $226 = 0, $227 = 0, $228 = 0, $229 = 0.0, $23 = 0.0, $230 = 0, $231 = 0.0, $232 = 0, $233 = 0, $234 = 0, $235 = 0.0, $236 = 0;
 var $237 = 0.0, $238 = 0, $239 = 0, $24 = 0.0, $25 = 0.0, $26 = 0.0, $27 = 0, $28 = 0.0, $29 = 0.0, $30 = 0.0, $31 = 0, $32 = 0.0, $33 = 0.0, $34 = 0.0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0.0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0.0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0.0, $53 = 0.0, $54 = 0, $55 = 0.0, $56 = 0.0, $57 = 0, $58 = 0.0, $59 = 0.0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0.0, $68 = 0.0, $69 = 0, $70 = 0.0, $71 = 0.0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0.0, $79 = 0, $80 = 0;
 var $81 = 0.0, $82 = 0.0, $83 = 0, $84 = 0.0, $85 = 0.0, $86 = 0, $87 = 0.0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0.0, $95 = 0.0, $96 = 0, $97 = 0.0, $98 = 0.0, $99 = 0, $exitcond = 0;
 var $exitcond528 = 0, $exitcond530 = 0, $exitcond531 = 0, $exitcond534 = 0, $exitcond535 = 0, $exitcond536 = 0, $exitcond539 = 0, $exitcond540 = 0, $exitcond543 = 0, $exitcond544 = 0, $exitcond545 = 0, $exitcond548 = 0, $exitcond549 = 0, $exitcond552 = 0, $exitcond553 = 0, $exitcond554 = 0, $exitcond557 = 0, $exitcond558 = 0, $exitcond561 = 0, $exitcond562 = 0;
 var $exitcond563 = 0, $exitcond564 = 0, $exitcond565 = 0, $exitcond566 = 0, $exitcond567 = 0, $exitcond568 = 0, $exitcond569 = 0, $exitcond570 = 0, $exitcond571 = 0, $exitcond572 = 0, $or$cond = 0, $or$cond399 = 0, $scevgep = 0, $scevgep529 = 0, $scevgep533 = 0, $scevgep537 = 0, $scevgep538 = 0, $scevgep542 = 0, $scevgep547 = 0, $scevgep551 = 0;
 var $scevgep555 = 0, $scevgep556 = 0, $scevgep560 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(64|0);
 $12 = sp + 48|0;
 $13 = sp + 32|0;
 $14 = sp + 16|0;
 $15 = sp;
 $16 = $6 << 1;
 $17 = ($16|0)==($3|0);
 $18 = $7 << 1;
 $19 = ($18|0)==($4|0);
 $or$cond = $17 & $19;
 if ($or$cond) {
  __ZN3osgL21halveImagePackedPixelEiPFviPKvPfEPFvPKfiPvEiiS1_S7_iii($0,$1,$2,$3,$4,$5,$8,$9,$10,$11);
  STACKTOP = sp;return;
 }
 $20 = (+($4|0));
 $21 = (+($7|0));
 $22 = $20 / $21;
 $23 = (+($3|0));
 $24 = (+($6|0));
 $25 = $23 / $24;
 $26 = (+Math_floor((+$22)));
 $27 = (~~(($26)));
 $28 = (+($27|0));
 $29 = $22 - $28;
 $30 = (+Math_floor((+$25)));
 $31 = (~~(($30)));
 $32 = (+($31|0));
 $33 = $25 - $32;
 $34 = $25 * $22;
 $35 = ($7|0)>(0);
 if (!($35)) {
  STACKTOP = sp;return;
 }
 $36 = ($6|0)>(0);
 $37 = ($0|0)>(0);
 $$0374510 = 0;$$0380509 = $29;$$0382508 = 0.0;$$0391507 = $27;$$0393506 = 0;
 while(1) {
  if ($36) {
   $38 = ($$0391507|0)>($$0393506|0);
   $39 = Math_imul($$0393506, $10)|0;
   $40 = 1.0 - $$0382508;
   $41 = Math_imul($$0391507, $10)|0;
   $$0370474 = (($$0393506) + 1)|0;
   $42 = ($$0370474|0)<($$0391507|0);
   $43 = Math_imul($$0370474, $10)|0;
   $44 = Math_imul($$0374510, $6)|0;
   $45 = $$0380509 - $$0382508;
   $scevgep = (($5) + ($39)|0);
   $46 = (($$0391507) + -1)|0;
   $47 = Math_imul($46, $10)|0;
   $scevgep537 = (($5) + ($47)|0);
   $scevgep555 = (($5) + ($41)|0);
   $$0375503 = 0;$$0383499 = $33;$$0385498 = 0.0;$$0394496 = $31;$$0396495 = 0;
   while(1) {
    $48 = Math_imul($$0396495, $9)|0;
    $49 = ($$0394496|0)>($$0396495|0);
    $or$cond399 = $38 & $49;
    ;HEAP32[$12>>2]=0|0;HEAP32[$12+4>>2]=0|0;HEAP32[$12+8>>2]=0|0;HEAP32[$12+12>>2]=0|0;
    L14: do {
     if ($or$cond399) {
      $50 = (($5) + ($48)|0);
      $51 = (($50) + ($39)|0);
      $52 = 1.0 - $$0385498;
      $53 = $40 * $52;
      FUNCTION_TABLE_viii[$1 & 8191]($11,$51,$13);
      if ($37) {
       $$0376440 = 0;
       while(1) {
        $54 = (($13) + ($$0376440<<2)|0);
        $55 = +HEAPF32[$54>>2];
        $56 = $53 * $55;
        $57 = (($12) + ($$0376440<<2)|0);
        $58 = +HEAPF32[$57>>2];
        $59 = $58 + $56;
        HEAPF32[$57>>2] = $59;
        $60 = (($$0376440) + 1)|0;
        $exitcond545 = ($60|0)==($0|0);
        if ($exitcond545) {
         break;
        } else {
         $$0376440 = $60;
        }
       }
      }
      $61 = (($$0396495) + 1)|0;
      $62 = ($61|0)<($$0394496|0);
      $63 = (($51) + ($9)|0);
      do {
       if ($62) {
        $64 = Math_imul($$0394496, $9)|0;
        if ($37) {
         $$0371448$us = $61;$65 = $63;
        } else {
         $$0371448 = $61;$75 = $63;
         while(1) {
          FUNCTION_TABLE_viii[$1 & 8191]($11,$75,$13);
          $76 = (($$0371448) + 1)|0;
          $77 = (($75) + ($9)|0);
          $exitcond548 = ($76|0)==($$0394496|0);
          if ($exitcond548) {
           break;
          } else {
           $$0371448 = $76;$75 = $77;
          }
         }
         $scevgep547 = (($scevgep) + ($64)|0);
         $$lcssa412 = $scevgep547;
         break;
        }
        while(1) {
         FUNCTION_TABLE_viii[$1 & 8191]($11,$65,$13);
         $$1377444$us = 0;
         while(1) {
          $66 = (($13) + ($$1377444$us<<2)|0);
          $67 = +HEAPF32[$66>>2];
          $68 = $40 * $67;
          $69 = (($12) + ($$1377444$us<<2)|0);
          $70 = +HEAPF32[$69>>2];
          $71 = $70 + $68;
          HEAPF32[$69>>2] = $71;
          $72 = (($$1377444$us) + 1)|0;
          $exitcond549 = ($72|0)==($0|0);
          if ($exitcond549) {
           break;
          } else {
           $$1377444$us = $72;
          }
         }
         $73 = (($$0371448$us) + 1)|0;
         $74 = (($65) + ($9)|0);
         $exitcond552 = ($73|0)==($$0394496|0);
         if ($exitcond552) {
          break;
         } else {
          $$0371448$us = $73;$65 = $74;
         }
        }
        $scevgep551 = (($scevgep) + ($64)|0);
        $$lcssa412 = $scevgep551;
       } else {
        $$lcssa412 = $63;
       }
      } while(0);
      $78 = $40 * $$0383499;
      FUNCTION_TABLE_viii[$1 & 8191]($11,$$lcssa412,$13);
      if ($37) {
       $$2378453 = 0;
       while(1) {
        $80 = (($13) + ($$2378453<<2)|0);
        $81 = +HEAPF32[$80>>2];
        $82 = $78 * $81;
        $83 = (($12) + ($$2378453<<2)|0);
        $84 = +HEAPF32[$83>>2];
        $85 = $84 + $82;
        HEAPF32[$83>>2] = $85;
        $86 = (($$2378453) + 1)|0;
        $exitcond553 = ($86|0)==($0|0);
        if ($exitcond553) {
         break;
        } else {
         $$2378453 = $86;
        }
       }
       $87 = $$0380509 * $52;
       $88 = (($50) + ($41)|0);
       FUNCTION_TABLE_viii[$1 & 8191]($11,$88,$13);
       if ($37) {
        $$3379457 = 0;
        while(1) {
         $102 = (($13) + ($$3379457<<2)|0);
         $103 = +HEAPF32[$102>>2];
         $104 = $87 * $103;
         $105 = (($12) + ($$3379457<<2)|0);
         $106 = +HEAPF32[$105>>2];
         $107 = $106 + $104;
         HEAPF32[$105>>2] = $107;
         $108 = (($$3379457) + 1)|0;
         $exitcond554 = ($108|0)==($0|0);
         if ($exitcond554) {
          break;
         } else {
          $$3379457 = $108;
         }
        }
       }
      } else {
       $79 = (($50) + ($41)|0);
       FUNCTION_TABLE_viii[$1 & 8191]($11,$79,$13);
      }
      $89 = (($50) + ($41)|0);
      $90 = (($89) + ($9)|0);
      do {
       if ($62) {
        $91 = Math_imul($$0394496, $9)|0;
        if ($37) {
         $$1372464$us = $61;$92 = $90;
        } else {
         $$1372464 = $61;$109 = $90;
         while(1) {
          FUNCTION_TABLE_viii[$1 & 8191]($11,$109,$13);
          $110 = (($$1372464) + 1)|0;
          $111 = (($109) + ($9)|0);
          $exitcond557 = ($110|0)==($$0394496|0);
          if ($exitcond557) {
           break;
          } else {
           $$1372464 = $110;$109 = $111;
          }
         }
         $scevgep556 = (($scevgep555) + ($91)|0);
         $$lcssa413 = $scevgep556;
         break;
        }
        while(1) {
         FUNCTION_TABLE_viii[$1 & 8191]($11,$92,$13);
         $$4460$us = 0;
         while(1) {
          $93 = (($13) + ($$4460$us<<2)|0);
          $94 = +HEAPF32[$93>>2];
          $95 = $$0380509 * $94;
          $96 = (($12) + ($$4460$us<<2)|0);
          $97 = +HEAPF32[$96>>2];
          $98 = $97 + $95;
          HEAPF32[$96>>2] = $98;
          $99 = (($$4460$us) + 1)|0;
          $exitcond558 = ($99|0)==($0|0);
          if ($exitcond558) {
           break;
          } else {
           $$4460$us = $99;
          }
         }
         $100 = (($$1372464$us) + 1)|0;
         $101 = (($92) + ($9)|0);
         $exitcond561 = ($100|0)==($$0394496|0);
         if ($exitcond561) {
          break;
         } else {
          $$1372464$us = $100;$92 = $101;
         }
        }
        $scevgep560 = (($scevgep555) + ($91)|0);
        $$lcssa413 = $scevgep560;
       } else {
        $$lcssa413 = $90;
       }
      } while(0);
      $112 = $$0380509 * $$0383499;
      FUNCTION_TABLE_viii[$1 & 8191]($11,$$lcssa413,$13);
      if ($37) {
       $$5468 = 0;
       while(1) {
        $126 = (($13) + ($$5468<<2)|0);
        $127 = +HEAPF32[$126>>2];
        $128 = $112 * $127;
        $129 = (($12) + ($$5468<<2)|0);
        $130 = +HEAPF32[$129>>2];
        $131 = $130 + $128;
        HEAPF32[$129>>2] = $131;
        $132 = (($$5468) + 1)|0;
        $exitcond562 = ($132|0)==($0|0);
        if ($exitcond562) {
         break;
        } else {
         $$5468 = $132;
        }
       }
      }
      if ($42) {
       if ($37) {
        $$0369475$us = $51;$$0370477$us = $$0370474;$$0476$us = $$lcssa412;
       } else {
        $$0369475 = $51;$$0370477 = $$0370474;$$0476 = $$lcssa412;
        while(1) {
         $133 = (($$0369475) + ($10)|0);
         $134 = (($$0476) + ($10)|0);
         FUNCTION_TABLE_viii[$1 & 8191]($11,$133,$13);
         FUNCTION_TABLE_viii[$1 & 8191]($11,$134,$14);
         $$0370 = (($$0370477) + 1)|0;
         $exitcond563 = ($$0370|0)==($$0391507|0);
         if ($exitcond563) {
          label = 67;
          break L14;
         } else {
          $$0369475 = $133;$$0370477 = $$0370;$$0476 = $134;
         }
        }
       }
       while(1) {
        $113 = (($$0369475$us) + ($10)|0);
        $114 = (($$0476$us) + ($10)|0);
        FUNCTION_TABLE_viii[$1 & 8191]($11,$113,$13);
        FUNCTION_TABLE_viii[$1 & 8191]($11,$114,$14);
        $$6471$us = 0;
        while(1) {
         $115 = (($13) + ($$6471$us<<2)|0);
         $116 = +HEAPF32[$115>>2];
         $117 = $52 * $116;
         $118 = (($14) + ($$6471$us<<2)|0);
         $119 = +HEAPF32[$118>>2];
         $120 = $$0383499 * $119;
         $121 = $117 + $120;
         $122 = (($12) + ($$6471$us<<2)|0);
         $123 = +HEAPF32[$122>>2];
         $124 = $123 + $121;
         HEAPF32[$122>>2] = $124;
         $125 = (($$6471$us) + 1)|0;
         $exitcond564 = ($125|0)==($0|0);
         if ($exitcond564) {
          break;
         } else {
          $$6471$us = $125;
         }
        }
        $$0370$us = (($$0370477$us) + 1)|0;
        $exitcond565 = ($$0370$us|0)==($$0391507|0);
        if ($exitcond565) {
         label = 67;
         break;
        } else {
         $$0369475$us = $113;$$0370477$us = $$0370$us;$$0476$us = $114;
        }
       }
      }
     } else {
      if ($38) {
       $135 = $$0383499 - $$0385498;
       $136 = $40 * $135;
       $137 = (($5) + ($48)|0);
       $138 = (($137) + ($39)|0);
       FUNCTION_TABLE_viii[$1 & 8191]($11,$138,$13);
       if ($37) {
        $$7425 = 0;
        while(1) {
         $147 = (($13) + ($$7425<<2)|0);
         $148 = +HEAPF32[$147>>2];
         $149 = $136 * $148;
         $150 = (($12) + ($$7425<<2)|0);
         $151 = +HEAPF32[$150>>2];
         $152 = $151 + $149;
         HEAPF32[$150>>2] = $152;
         $153 = (($$7425) + 1)|0;
         $exitcond536 = ($153|0)==($0|0);
         if ($exitcond536) {
          break;
         } else {
          $$7425 = $153;
         }
        }
       }
       do {
        if ($42) {
         if ($37) {
          $$1433$us = $$0370474;$$2388432$us = $138;
         } else {
          $$1433 = $$0370474;$$2388432 = $138;
          while(1) {
           $154 = (($$2388432) + ($10)|0);
           FUNCTION_TABLE_viii[$1 & 8191]($11,$154,$13);
           $$1 = (($$1433) + 1)|0;
           $exitcond539 = ($$1|0)==($$0391507|0);
           if ($exitcond539) {
            break;
           } else {
            $$1433 = $$1;$$2388432 = $154;
           }
          }
          $scevgep538 = (($scevgep537) + ($48)|0);
          $$2388$lcssa = $scevgep538;
          break;
         }
         while(1) {
          $139 = (($$2388432$us) + ($10)|0);
          FUNCTION_TABLE_viii[$1 & 8191]($11,$139,$13);
          $$8428$us = 0;
          while(1) {
           $140 = (($13) + ($$8428$us<<2)|0);
           $141 = +HEAPF32[$140>>2];
           $142 = $135 * $141;
           $143 = (($12) + ($$8428$us<<2)|0);
           $144 = +HEAPF32[$143>>2];
           $145 = $144 + $142;
           HEAPF32[$143>>2] = $145;
           $146 = (($$8428$us) + 1)|0;
           $exitcond540 = ($146|0)==($0|0);
           if ($exitcond540) {
            break;
           } else {
            $$8428$us = $146;
           }
          }
          $$1$us = (($$1433$us) + 1)|0;
          $exitcond543 = ($$1$us|0)==($$0391507|0);
          if ($exitcond543) {
           break;
          } else {
           $$1433$us = $$1$us;$$2388432$us = $139;
          }
         }
         $scevgep542 = (($scevgep537) + ($48)|0);
         $$2388$lcssa = $scevgep542;
        } else {
         $$2388$lcssa = $138;
        }
       } while(0);
       $155 = $$0380509 * $135;
       $156 = (($$2388$lcssa) + ($10)|0);
       FUNCTION_TABLE_viii[$1 & 8191]($11,$156,$13);
       if ($37) {
        $$9437 = 0;
       } else {
        label = 67;
        break;
       }
       while(1) {
        $157 = (($13) + ($$9437<<2)|0);
        $158 = +HEAPF32[$157>>2];
        $159 = $155 * $158;
        $160 = (($12) + ($$9437<<2)|0);
        $161 = +HEAPF32[$160>>2];
        $162 = $161 + $159;
        HEAPF32[$160>>2] = $162;
        $163 = (($$9437) + 1)|0;
        $exitcond544 = ($163|0)==($0|0);
        if ($exitcond544) {
         label = 67;
         break L14;
        } else {
         $$9437 = $163;
        }
       }
      }
      if (!($49)) {
       $197 = $$0383499 - $$0385498;
       $198 = $45 * $197;
       $199 = (($5) + ($48)|0);
       $200 = (($199) + ($39)|0);
       FUNCTION_TABLE_viii[$1 & 8191]($11,$200,$13);
       if ($37) {
        $$13414 = 0;
       } else {
        label = 67;
        break;
       }
       while(1) {
        $201 = (($13) + ($$13414<<2)|0);
        $202 = +HEAPF32[$201>>2];
        $203 = $198 * $202;
        $204 = (($12) + ($$13414<<2)|0);
        $205 = +HEAPF32[$204>>2];
        $206 = $205 + $203;
        HEAPF32[$204>>2] = $206;
        $207 = (($$13414) + 1)|0;
        $exitcond = ($207|0)==($0|0);
        if ($exitcond) {
         label = 67;
         break L14;
        } else {
         $$13414 = $207;
        }
       }
      }
      $164 = 1.0 - $$0385498;
      $165 = $45 * $164;
      $166 = (($5) + ($48)|0);
      $167 = (($166) + ($39)|0);
      FUNCTION_TABLE_viii[$1 & 8191]($11,$167,$13);
      if ($37) {
       $$10415 = 0;
       while(1) {
        $180 = (($13) + ($$10415<<2)|0);
        $181 = +HEAPF32[$180>>2];
        $182 = $165 * $181;
        $183 = (($12) + ($$10415<<2)|0);
        $184 = +HEAPF32[$183>>2];
        $185 = $184 + $182;
        HEAPF32[$183>>2] = $185;
        $186 = (($$10415) + 1)|0;
        $exitcond528 = ($186|0)==($0|0);
        if ($exitcond528) {
         break;
        } else {
         $$10415 = $186;
        }
       }
      }
      $$2373419 = (($$0396495) + 1)|0;
      $168 = ($$2373419|0)<($$0394496|0);
      $169 = (($167) + ($9)|0);
      do {
       if ($168) {
        $170 = Math_imul($$0394496, $9)|0;
        if ($37) {
         $$2373420$us = $$2373419;$171 = $169;
        } else {
         $$2373420 = $$2373419;$187 = $169;
         while(1) {
          FUNCTION_TABLE_viii[$1 & 8191]($11,$187,$13);
          $$2373 = (($$2373420) + 1)|0;
          $188 = (($187) + ($9)|0);
          $exitcond530 = ($$2373|0)==($$0394496|0);
          if ($exitcond530) {
           break;
          } else {
           $$2373420 = $$2373;$187 = $188;
          }
         }
         $scevgep529 = (($scevgep) + ($170)|0);
         $$lcssa = $scevgep529;
         break;
        }
        while(1) {
         FUNCTION_TABLE_viii[$1 & 8191]($11,$171,$13);
         $$11417$us = 0;
         while(1) {
          $172 = (($13) + ($$11417$us<<2)|0);
          $173 = +HEAPF32[$172>>2];
          $174 = $45 * $173;
          $175 = (($12) + ($$11417$us<<2)|0);
          $176 = +HEAPF32[$175>>2];
          $177 = $176 + $174;
          HEAPF32[$175>>2] = $177;
          $178 = (($$11417$us) + 1)|0;
          $exitcond531 = ($178|0)==($0|0);
          if ($exitcond531) {
           break;
          } else {
           $$11417$us = $178;
          }
         }
         $$2373$us = (($$2373420$us) + 1)|0;
         $179 = (($171) + ($9)|0);
         $exitcond534 = ($$2373$us|0)==($$0394496|0);
         if ($exitcond534) {
          break;
         } else {
          $$2373420$us = $$2373$us;$171 = $179;
         }
        }
        $scevgep533 = (($scevgep) + ($170)|0);
        $$lcssa = $scevgep533;
       } else {
        $$lcssa = $169;
       }
      } while(0);
      $189 = $45 * $$0383499;
      FUNCTION_TABLE_viii[$1 & 8191]($11,$$lcssa,$13);
      if ($37) {
       $$12422 = 0;
       while(1) {
        $190 = (($13) + ($$12422<<2)|0);
        $191 = +HEAPF32[$190>>2];
        $192 = $189 * $191;
        $193 = (($12) + ($$12422<<2)|0);
        $194 = +HEAPF32[$193>>2];
        $195 = $194 + $192;
        HEAPF32[$193>>2] = $195;
        $196 = (($$12422) + 1)|0;
        $exitcond535 = ($196|0)==($0|0);
        if ($exitcond535) {
         label = 67;
         break;
        } else {
         $$12422 = $196;
        }
       }
      } else {
       label = 67;
      }
     }
    } while(0);
    if ((label|0) == 67) {
     label = 0;
     if ($42) {
      $208 = (($5) + ($48)|0);
      $209 = (($208) + ($9)|0);
      $210 = (($209) + ($43)|0);
      $$3483 = (($$0396495) + 1)|0;
      $211 = ($$3483|0)<($$0394496|0);
      $$0397488 = $210;$$2489 = $$0370474;
      while(1) {
       L119: do {
        if ($211) {
         if ($37) {
          $$3485$us = $$3483;$$4390484$us = $$0397488;
         } else {
          $$3485 = $$3483;$$4390484 = $$0397488;
          while(1) {
           FUNCTION_TABLE_viii[$1 & 8191]($11,$$4390484,$13);
           $219 = (($$4390484) + ($9)|0);
           $$3 = (($$3485) + 1)|0;
           $exitcond566 = ($$3|0)==($$0394496|0);
           if ($exitcond566) {
            break L119;
           } else {
            $$3485 = $$3;$$4390484 = $219;
           }
          }
         }
         while(1) {
          FUNCTION_TABLE_viii[$1 & 8191]($11,$$4390484$us,$13);
          $$14479$us = 0;
          while(1) {
           $212 = (($13) + ($$14479$us<<2)|0);
           $213 = +HEAPF32[$212>>2];
           $214 = (($12) + ($$14479$us<<2)|0);
           $215 = +HEAPF32[$214>>2];
           $216 = $213 + $215;
           HEAPF32[$214>>2] = $216;
           $217 = (($$14479$us) + 1)|0;
           $exitcond567 = ($217|0)==($0|0);
           if ($exitcond567) {
            break;
           } else {
            $$14479$us = $217;
           }
          }
          $218 = (($$4390484$us) + ($9)|0);
          $$3$us = (($$3485$us) + 1)|0;
          $exitcond568 = ($$3$us|0)==($$0394496|0);
          if ($exitcond568) {
           break;
          } else {
           $$3485$us = $$3$us;$$4390484$us = $218;
          }
         }
        }
       } while(0);
       $220 = (($$0397488) + ($10)|0);
       $221 = (($$2489) + 1)|0;
       $exitcond569 = ($221|0)==($$0391507|0);
       if ($exitcond569) {
        break;
       } else {
        $$0397488 = $220;$$2489 = $221;
       }
      }
     }
    }
    $222 = (($$0375503) + ($44))|0;
    if ($37) {
     $$15491 = 0;
     while(1) {
      $223 = (($12) + ($$15491<<2)|0);
      $224 = +HEAPF32[$223>>2];
      $225 = $224 / $34;
      $226 = (($15) + ($$15491<<2)|0);
      HEAPF32[$226>>2] = $225;
      $227 = (($$15491) + 1)|0;
      $exitcond570 = ($227|0)==($0|0);
      if ($exitcond570) {
       break;
      } else {
       $$15491 = $227;
      }
     }
    }
    FUNCTION_TABLE_viii[$2 & 8191]($15,$222,$8);
    $228 = (($$0394496) + ($31))|0;
    $229 = $33 + $$0383499;
    $230 = $229 > 1.0;
    $231 = $229 + -1.0;
    $232 = $230&1;
    $$1395 = (($228) + ($232))|0;
    $$1384 = $230 ? $231 : $229;
    $233 = (($$0375503) + 1)|0;
    $exitcond571 = ($233|0)==($6|0);
    if ($exitcond571) {
     break;
    } else {
     $$0396495$phi = $$0394496;$$0385498$phi = $$0383499;$$0375503 = $233;$$0383499 = $$1384;$$0394496 = $$1395;$$0396495 = $$0396495$phi;$$0385498 = $$0385498$phi;
    }
   }
  }
  $234 = (($$0391507) + ($27))|0;
  $235 = $29 + $$0380509;
  $236 = $235 > 1.0;
  $237 = $235 + -1.0;
  $238 = $236&1;
  $$1392 = (($234) + ($238))|0;
  $$1381 = $236 ? $237 : $235;
  $239 = (($$0374510) + 1)|0;
  $exitcond572 = ($239|0)==($7|0);
  if ($exitcond572) {
   break;
  } else {
   $$0393506$phi = $$0391507;$$0382508$phi = $$0380509;$$0374510 = $239;$$0380509 = $$1381;$$0391507 = $$1392;$$0393506 = $$0393506$phi;$$0382508 = $$0382508$phi;
  }
 }
 STACKTOP = sp;return;
}
function __ZN3osgL13extract565revEiPKvPf($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0.0, $16 = 0.0, $17 = 0, $18 = 0, $19 = 0.0, $20 = 0.0, $21 = 0, $22 = 0, $23 = 0.0, $24 = 0.0, $25 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($0|0)==(0);
 if ($3) {
  $12 = HEAP16[$1>>1]|0;
  $$0 = $12;
 } else {
  $4 = ((($1)) + 1|0);
  $5 = HEAP8[$4>>0]|0;
  $6 = $5&255;
  $7 = $6 << 8;
  $8 = HEAP8[$1>>0]|0;
  $9 = $8&255;
  $10 = $7 | $9;
  $11 = $10&65535;
  $$0 = $11;
 }
 $13 = $$0&65535;
 $14 = $13 & 31;
 $15 = (+($14|0));
 $16 = $15 / 31.0;
 HEAPF32[$2>>2] = $16;
 $17 = $13 >>> 5;
 $18 = $17 & 63;
 $19 = (+($18|0));
 $20 = $19 / 63.0;
 $21 = ((($2)) + 4|0);
 HEAPF32[$21>>2] = $20;
 $22 = $13 >>> 11;
 $23 = (+($22|0));
 $24 = $23 / 31.0;
 $25 = ((($2)) + 8|0);
 HEAPF32[$25>>2] = $24;
 return;
}
function __ZN3osgL11shove565revEPKfiPv($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0.0, $12 = 0.0, $13 = 0.0, $14 = 0.0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0.0, $23 = 0.0, $24 = 0.0, $25 = 0.0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0.0, $30 = 0, $4 = 0.0, $5 = 0.0, $6 = 0.0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = +HEAPF32[$0>>2];
 $4 = $3;
 $5 = $4 * 31.0;
 $6 = $5 + 0.5;
 $7 = (~~(($6))&65535);
 $8 = $7 & 31;
 $9 = (($2) + ($1<<1)|0);
 $10 = ((($0)) + 4|0);
 $11 = +HEAPF32[$10>>2];
 $12 = $11;
 $13 = $12 * 63.0;
 $14 = $13 + 0.5;
 $15 = (~~(($14))&65535);
 $16 = $15&65535;
 $17 = $16 << 5;
 $18 = $17 & 2016;
 $19 = $8&65535;
 $20 = $18 | $19;
 $21 = ((($0)) + 8|0);
 $22 = +HEAPF32[$21>>2];
 $23 = $22;
 $24 = $23 * 31.0;
 $25 = $24 + 0.5;
 $26 = (~~(($25))&65535);
 $27 = $26&65535;
 $28 = $27 << 11;
 $29 = $20 | $28;
 $30 = $29&65535;
 HEAP16[$9>>1] = $30;
 return;
}
function __ZN3osg17gluBuild2DMipmapsEjiiijjPKv($0,$1,$2,$3,$4,$5,$6) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 var $$ = 0, $$$i = 0, $$0 = 0, $$0$$i = 0, $$0$$i34 = 0, $$0$i$i = 0, $$0$i3$i = 0, $$0$lcssa$i = 0, $$0$lcssa$i33 = 0, $$010$i = 0, $$010$i$i = 0, $$010$i36 = 0, $$010$i5$i = 0, $$07$lcssa$i = 0, $$07$lcssa$i32 = 0, $$079$i = 0, $$079$i37 = 0, $$08$i = 0, $$08$i39 = 0, $$09$i$i = 0;
 var $$09$i2$i = 0, $$1$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $or$cond = 0, $or$cond5$i$i = 0, $or$cond7$i$i = 0, $switch$split102D = 0, $switch$split12D = 0, $switch$split132D = 0, $switch$split162D = 0, $switch$split192D = 0, $switch$split2D = 0, $switch$split42D = 0, $switch$split72D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $7 = sp;
 $switch$split2D = ($4|0)<(6406);
 L1: do {
  if ($switch$split2D) {
   switch ($4|0) {
   case 6405: case 6404: case 6403: case 6402: case 6401: case 6400:  {
    label = 2;
    break;
   }
   default: {
    $$0 = 100900;
   }
   }
  } else {
   $switch$split72D = ($4|0)<(6409);
   if ($switch$split72D) {
    switch ($4|0) {
    case 6408: case 6407: case 6406:  {
     label = 2;
     break L1;
     break;
    }
    default: {
     $$0 = 100900;
     break L1;
    }
    }
   }
   $switch$split132D = ($4|0)<(32992);
   if ($switch$split132D) {
    switch ($4|0) {
    case 6410: case 6409:  {
     label = 2;
     break L1;
     break;
    }
    default: {
     $$0 = 100900;
     break L1;
    }
    }
   } else {
    switch ($4|0) {
    case 32993: case 32992:  {
     label = 2;
     break L1;
     break;
    }
    default: {
     $$0 = 100900;
     break L1;
    }
    }
   }
  }
 } while(0);
 L10: do {
  if ((label|0) == 2) {
   $switch$split12D = ($5|0)<(32820);
   L12: do {
    if ($switch$split12D) {
     $switch$split102D = ($5|0)<(5125);
     if ($switch$split102D) {
      switch ($5|0) {
      case 5124: case 5123: case 5122: case 5121: case 5120:  {
       break L12;
       break;
      }
      default: {
       $$0 = 100900;
       break L10;
      }
      }
     }
     $switch$split162D = ($5|0)<(6656);
     if ($switch$split162D) {
      switch ($5|0) {
      case 5126: case 5125:  {
       break L12;
       break;
      }
      default: {
       $$0 = 100900;
       break L10;
      }
      }
     }
     $switch$split192D = ($5|0)<(32818);
     if ($switch$split192D) {
      switch ($5|0) {
      case 6656:  {
       break L12;
       break;
      }
      default: {
       $$0 = 100900;
       break L10;
      }
      }
     } else {
      switch ($5|0) {
      case 32819: case 32818:  {
       break L12;
       break;
      }
      default: {
       $$0 = 100900;
       break L10;
      }
      }
     }
    } else {
     switch ($5|0) {
     case 33640: case 32822: case 33639: case 32821: case 33638: case 32820: case 33637: case 33636: case 33635: case 33634:  {
      break;
     }
     default: {
      $$0 = 100900;
      break L10;
     }
     }
    }
   } while(0);
   $8 = ($4|0)==(6401);
   if ($8) {
    $$0 = 100900;
   } else {
    L26: do {
     switch ($5|0) {
     case 32818: case 32819: case 32820: case 32821: case 32822: case 33634: case 33635: case 33636: case 33637: case 33638: case 33639: case 33640:  {
      $9 = ($5|0)==(32818);
      $10 = $5 | 1;
      $11 = ($10|0)==(33635);
      $12 = $9 | $11;
      $13 = ($5|0)==(33636);
      $or$cond5$i$i = $13 | $12;
      $14 = ($4|0)!=(6407);
      $or$cond7$i$i = $14 & $or$cond5$i$i;
      if ($or$cond7$i$i) {
       $$0 = 100904;
       break L10;
      }
      switch ($5|0) {
      case 32819: case 32820: case 32821: case 32822: case 33637: case 33638: case 33639: case 33640:  {
       break;
      }
      default: {
       break L26;
      }
      }
      $switch$split42D = ($4|0)<(32993);
      if ($switch$split42D) {
       switch ($4|0) {
       case 6408:  {
        break L26;
        break;
       }
       default: {
        $$0 = 100904;
        break L10;
       }
       }
      } else {
       switch ($4|0) {
       case 32993:  {
        break L26;
        break;
       }
       default: {
        $$0 = 100904;
        break L10;
       }
       }
      }
      break;
     }
     default: {
     }
     }
    } while(0);
    $15 = ($2|0)<(1);
    $16 = ($3|0)<(1);
    $or$cond = $15 | $16;
    if ($or$cond) {
     $$0 = 100901;
    } else {
     _glGetIntegerv(3379,($7|0));
     $17 = ($2|0)==(0);
     L35: do {
      if ($17) {
       $$010$i$i = -1;
      } else {
       $$0$i$i = 1;$$09$i$i = $2;
       L36: while(1) {
        switch ($$09$i$i|0) {
        case 1:  {
         $$010$i$i = $$0$i$i;
         break L35;
         break;
        }
        case 3:  {
         break L36;
         break;
        }
        default: {
        }
        }
        $19 = $$09$i$i >>> 1;
        $20 = $$0$i$i << 1;
        $$0$i$i = $20;$$09$i$i = $19;
       }
       $18 = $$0$i$i << 2;
       $$010$i$i = $18;
      }
     } while(0);
     $21 = HEAP32[$7>>2]|0;
     $22 = ($$010$i$i|0)>($21|0);
     $$$i = $22 ? $21 : $$010$i$i;
     $23 = ($3|0)==(0);
     L41: do {
      if ($23) {
       $$010$i5$i = -1;
      } else {
       $$0$i3$i = 1;$$09$i2$i = $3;
       L42: while(1) {
        switch ($$09$i2$i|0) {
        case 1:  {
         $$010$i5$i = $$0$i3$i;
         break L41;
         break;
        }
        case 3:  {
         break L42;
         break;
        }
        default: {
        }
        }
        $25 = $$09$i2$i >>> 1;
        $26 = $$0$i3$i << 1;
        $$0$i3$i = $26;$$09$i2$i = $25;
       }
       $24 = $$0$i3$i << 2;
       $$010$i5$i = $24;
      }
     } while(0);
     $27 = ($$010$i5$i|0)>($21|0);
     $$1$i = $27 ? $21 : $$010$i5$i;
     $28 = ($$$i|0)==(0);
     if ($28) {
      $$08$i = -1;
     } else {
      $29 = $$$i & 1;
      $30 = ($29|0)==(0);
      if ($30) {
       $$010$i = 0;$$079$i = $$$i;
       while(1) {
        $32 = $$079$i >>> 1;
        $33 = (($$010$i) + 1)|0;
        $34 = $32 & 1;
        $35 = ($34|0)==(0);
        if ($35) {
         $$010$i = $33;$$079$i = $32;
        } else {
         $$0$lcssa$i = $33;$$07$lcssa$i = $32;
         break;
        }
       }
      } else {
       $$0$lcssa$i = 0;$$07$lcssa$i = $$$i;
      }
      $31 = ($$07$lcssa$i|0)==(1);
      $$0$$i = $31 ? $$0$lcssa$i : -1;
      $$08$i = $$0$$i;
     }
     $36 = ($$1$i|0)==(0);
     if ($36) {
      $$08$i39 = -1;
     } else {
      $37 = $$1$i & 1;
      $38 = ($37|0)==(0);
      if ($38) {
       $$010$i36 = 0;$$079$i37 = $$1$i;
       while(1) {
        $40 = $$079$i37 >>> 1;
        $41 = (($$010$i36) + 1)|0;
        $42 = $40 & 1;
        $43 = ($42|0)==(0);
        if ($43) {
         $$010$i36 = $41;$$079$i37 = $40;
        } else {
         $$0$lcssa$i33 = $41;$$07$lcssa$i32 = $40;
         break;
        }
       }
      } else {
       $$0$lcssa$i33 = 0;$$07$lcssa$i32 = $$1$i;
      }
      $39 = ($$07$lcssa$i32|0)==(1);
      $$0$$i34 = $39 ? $$0$lcssa$i33 : -1;
      $$08$i39 = $$0$$i34;
     }
     $44 = ($$08$i39|0)>($$08$i|0);
     $$ = $44 ? $$08$i39 : $$08$i;
     $45 = (__ZN3osgL26gluBuild2DMipmapLevelsCoreEjiiiiijjiiiPKv($0,$1,$2,$3,$$$i,$$1$i,$4,$5,0,0,$$,$6)|0);
     $$0 = $45;
    }
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function __ZN3osg20AttributeDispatchersD2Ev($0) {
 $0 = $0|0;
 var $$pre = 0, $$pre$i$i = 0, $$pre$i$i15 = 0, $$pre$i$i22 = 0, $$pre$i$i29 = 0, $$pre$i$i8 = 0, $$sroa$047$052 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i33 = 0, $scevgep5$i$i$i = 0, $scevgep5$i$i$i34 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (70508);
 $1 = ((($0)) + 20|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = HEAP32[$2>>2]|0;
  $5 = ($4|0)==(0|0);
  if (!($5)) {
   $6 = ((($2)) + 4|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($7|0)==($4|0);
   do {
    if ($8) {
     $22 = $4;
    } else {
     $10 = $7;
     while(1) {
      $9 = ((($10)) + -4|0);
      HEAP32[$6>>2] = $9;
      $11 = HEAP32[$9>>2]|0;
      $12 = ($11|0)==(0|0);
      if (!($12)) {
       $13 = ((($11)) + 8|0);
       $14 = HEAP32[$13>>2]|0;HEAP32[$13>>2] = (($14-1)|0);
       $15 = ($14|0)==(1);
       if ($15) {
        __THREW__ = 0;
        invoke_viii(3262,($11|0),1,1);
        $16 = __THREW__; __THREW__ = 0;
        $17 = $16&1;
        if ($17) {
         label = 8;
         break;
        }
       }
      }
      HEAP32[$9>>2] = 0;
      $18 = HEAP32[$6>>2]|0;
      $19 = ($18|0)==($4|0);
      if ($19) {
       label = 9;
       break;
      } else {
       $10 = $18;
      }
     }
     if ((label|0) == 8) {
      $20 = ___cxa_find_matching_catch_2()|0;
      $21 = tempRet0;
      ___cxa_call_unexpected(($20|0));
      // unreachable;
     }
     else if ((label|0) == 9) {
      $$pre$i$i = HEAP32[$2>>2]|0;
      $22 = $$pre$i$i;
      break;
     }
    }
   } while(0);
   __ZdlPv($22);
  }
  __ZdlPv($2);
 }
 $23 = ((($0)) + 24|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)==(0|0);
 if (!($25)) {
  $26 = HEAP32[$24>>2]|0;
  $27 = ($26|0)==(0|0);
  if (!($27)) {
   $28 = ((($24)) + 4|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = ($29|0)==($26|0);
   do {
    if ($30) {
     $44 = $26;
    } else {
     $32 = $29;
     while(1) {
      $31 = ((($32)) + -4|0);
      HEAP32[$28>>2] = $31;
      $33 = HEAP32[$31>>2]|0;
      $34 = ($33|0)==(0|0);
      if (!($34)) {
       $35 = ((($33)) + 8|0);
       $36 = HEAP32[$35>>2]|0;HEAP32[$35>>2] = (($36-1)|0);
       $37 = ($36|0)==(1);
       if ($37) {
        __THREW__ = 0;
        invoke_viii(3262,($33|0),1,1);
        $38 = __THREW__; __THREW__ = 0;
        $39 = $38&1;
        if ($39) {
         label = 19;
         break;
        }
       }
      }
      HEAP32[$31>>2] = 0;
      $40 = HEAP32[$28>>2]|0;
      $41 = ($40|0)==($26|0);
      if ($41) {
       label = 20;
       break;
      } else {
       $32 = $40;
      }
     }
     if ((label|0) == 19) {
      $42 = ___cxa_find_matching_catch_2()|0;
      $43 = tempRet0;
      ___cxa_call_unexpected(($42|0));
      // unreachable;
     }
     else if ((label|0) == 20) {
      $$pre$i$i8 = HEAP32[$24>>2]|0;
      $44 = $$pre$i$i8;
      break;
     }
    }
   } while(0);
   __ZdlPv($44);
  }
  __ZdlPv($24);
 }
 $45 = ((($0)) + 28|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = ($46|0)==(0|0);
 if (!($47)) {
  $48 = HEAP32[$46>>2]|0;
  $49 = ($48|0)==(0|0);
  if (!($49)) {
   $50 = ((($46)) + 4|0);
   $51 = HEAP32[$50>>2]|0;
   $52 = ($51|0)==($48|0);
   do {
    if ($52) {
     $66 = $48;
    } else {
     $54 = $51;
     while(1) {
      $53 = ((($54)) + -4|0);
      HEAP32[$50>>2] = $53;
      $55 = HEAP32[$53>>2]|0;
      $56 = ($55|0)==(0|0);
      if (!($56)) {
       $57 = ((($55)) + 8|0);
       $58 = HEAP32[$57>>2]|0;HEAP32[$57>>2] = (($58-1)|0);
       $59 = ($58|0)==(1);
       if ($59) {
        __THREW__ = 0;
        invoke_viii(3262,($55|0),1,1);
        $60 = __THREW__; __THREW__ = 0;
        $61 = $60&1;
        if ($61) {
         label = 30;
         break;
        }
       }
      }
      HEAP32[$53>>2] = 0;
      $62 = HEAP32[$50>>2]|0;
      $63 = ($62|0)==($48|0);
      if ($63) {
       label = 31;
       break;
      } else {
       $54 = $62;
      }
     }
     if ((label|0) == 30) {
      $64 = ___cxa_find_matching_catch_2()|0;
      $65 = tempRet0;
      ___cxa_call_unexpected(($64|0));
      // unreachable;
     }
     else if ((label|0) == 31) {
      $$pre$i$i15 = HEAP32[$46>>2]|0;
      $66 = $$pre$i$i15;
      break;
     }
    }
   } while(0);
   __ZdlPv($66);
  }
  __ZdlPv($46);
 }
 $67 = ((($0)) + 32|0);
 $68 = HEAP32[$67>>2]|0;
 $69 = ($68|0)==(0|0);
 if (!($69)) {
  $70 = HEAP32[$68>>2]|0;
  $71 = ($70|0)==(0|0);
  if (!($71)) {
   $72 = ((($68)) + 4|0);
   $73 = HEAP32[$72>>2]|0;
   $74 = ($73|0)==($70|0);
   do {
    if ($74) {
     $88 = $70;
    } else {
     $76 = $73;
     while(1) {
      $75 = ((($76)) + -4|0);
      HEAP32[$72>>2] = $75;
      $77 = HEAP32[$75>>2]|0;
      $78 = ($77|0)==(0|0);
      if (!($78)) {
       $79 = ((($77)) + 8|0);
       $80 = HEAP32[$79>>2]|0;HEAP32[$79>>2] = (($80-1)|0);
       $81 = ($80|0)==(1);
       if ($81) {
        __THREW__ = 0;
        invoke_viii(3262,($77|0),1,1);
        $82 = __THREW__; __THREW__ = 0;
        $83 = $82&1;
        if ($83) {
         label = 41;
         break;
        }
       }
      }
      HEAP32[$75>>2] = 0;
      $84 = HEAP32[$72>>2]|0;
      $85 = ($84|0)==($70|0);
      if ($85) {
       label = 42;
       break;
      } else {
       $76 = $84;
      }
     }
     if ((label|0) == 41) {
      $86 = ___cxa_find_matching_catch_2()|0;
      $87 = tempRet0;
      ___cxa_call_unexpected(($86|0));
      // unreachable;
     }
     else if ((label|0) == 42) {
      $$pre$i$i22 = HEAP32[$68>>2]|0;
      $88 = $$pre$i$i22;
      break;
     }
    }
   } while(0);
   __ZdlPv($88);
  }
  __ZdlPv($68);
 }
 $89 = ((($0)) + 36|0);
 $90 = HEAP32[$89>>2]|0;
 $91 = ((($0)) + 40|0);
 $92 = HEAP32[$91>>2]|0;
 $93 = ($90|0)==($92|0);
 L69: do {
  if (!($93)) {
   $$sroa$047$052 = $90;$138 = $92;
   L70: while(1) {
    $105 = HEAP32[$$sroa$047$052>>2]|0;
    $106 = ($105|0)==(0|0);
    if ($106) {
     $128 = $138;
    } else {
     $107 = HEAP32[$105>>2]|0;
     $108 = ($107|0)==(0|0);
     if (!($108)) {
      $109 = ((($105)) + 4|0);
      $110 = HEAP32[$109>>2]|0;
      $111 = ($110|0)==($107|0);
      if ($111) {
       $125 = $107;
      } else {
       $113 = $110;
       while(1) {
        $112 = ((($113)) + -4|0);
        HEAP32[$109>>2] = $112;
        $114 = HEAP32[$112>>2]|0;
        $115 = ($114|0)==(0|0);
        if (!($115)) {
         $116 = ((($114)) + 8|0);
         $117 = HEAP32[$116>>2]|0;HEAP32[$116>>2] = (($117-1)|0);
         $118 = ($117|0)==(1);
         if ($118) {
          __THREW__ = 0;
          invoke_viii(3262,($114|0),1,1);
          $119 = __THREW__; __THREW__ = 0;
          $120 = $119&1;
          if ($120) {
           break L70;
          }
         }
        }
        HEAP32[$112>>2] = 0;
        $121 = HEAP32[$109>>2]|0;
        $122 = ($121|0)==($107|0);
        if ($122) {
         break;
        } else {
         $113 = $121;
        }
       }
       $$pre$i$i29 = HEAP32[$105>>2]|0;
       $125 = $$pre$i$i29;
      }
      __ZdlPv($125);
     }
     __ZdlPv($105);
     $$pre = HEAP32[$91>>2]|0;
     $128 = $$pre;
    }
    $126 = ((($$sroa$047$052)) + 4|0);
    $127 = ($126|0)==($128|0);
    if ($127) {
     break L69;
    } else {
     $$sroa$047$052 = $126;$138 = $128;
    }
   }
   $123 = ___cxa_find_matching_catch_2()|0;
   $124 = tempRet0;
   ___cxa_call_unexpected(($123|0));
   // unreachable;
  }
 } while(0);
 $94 = ((($0)) + 48|0);
 $95 = HEAP32[$94>>2]|0;
 $96 = ($95|0)==(0|0);
 if (!($96)) {
  $97 = ((($0)) + 52|0);
  $98 = HEAP32[$97>>2]|0;
  $99 = ($98|0)==($95|0);
  if (!($99)) {
   $scevgep$i$i$i = ((($98)) + -4|0);
   $100 = $scevgep$i$i$i;
   $101 = $95;
   $102 = (($100) - ($101))|0;
   $103 = $102 >>> 2;
   $104 = $103 ^ -1;
   $scevgep5$i$i$i = (($98) + ($104<<2)|0);
   HEAP32[$97>>2] = $scevgep5$i$i$i;
  }
  __ZdlPv($95);
 }
 $129 = HEAP32[$89>>2]|0;
 $130 = ($129|0)==(0|0);
 if ($130) {
  __ZN3osg10ReferencedD2Ev($0);
  return;
 }
 $131 = HEAP32[$91>>2]|0;
 $132 = ($131|0)==($129|0);
 if (!($132)) {
  $scevgep$i$i$i33 = ((($131)) + -4|0);
  $133 = $scevgep$i$i$i33;
  $134 = $129;
  $135 = (($133) - ($134))|0;
  $136 = $135 >>> 2;
  $137 = $136 ^ -1;
  $scevgep5$i$i$i34 = (($131) + ($137<<2)|0);
  HEAP32[$91>>2] = $scevgep5$i$i$i34;
 }
 __ZdlPv($129);
 __ZN3osg10ReferencedD2Ev($0);
 return;
}
function __ZN3osg20AttributeDispatchersD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(2450,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZN3osg20AttributeDispatchersC2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 __ZN3osg10ReferencedC2Ev($0);
 HEAP32[$0>>2] = (70508);
 $1 = ((($0)) + 12|0);
 HEAP8[$1>>0] = 0;
 $2 = ((($0)) + 16|0);
 dest=$2; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));HEAP8[$2+44>>0]=0|0;
 return;
}
function __ZN3osg20AttributeDispatchers8setStateEPNS_5StateE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 16|0);
 HEAP32[$2>>2] = $1;
 return;
}
function __ZN3osg20AttributeDispatchers4initEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i = 0, $scevgep5$i$i$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 12|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if (!($3)) {
  return;
 }
 HEAP8[$1>>0] = 1;
 $4 = (__Znwj(12)|0);
 HEAP32[$4>>2] = 0;
 $5 = ((($4)) + 4|0);
 HEAP32[$5>>2] = 0;
 $6 = ((($4)) + 8|0);
 HEAP32[$6>>2] = 0;
 $7 = ((($0)) + 20|0);
 HEAP32[$7>>2] = $4;
 $8 = (__Znwj(12)|0);
 HEAP32[$8>>2] = 0;
 $9 = ((($8)) + 4|0);
 HEAP32[$9>>2] = 0;
 $10 = ((($8)) + 8|0);
 HEAP32[$10>>2] = 0;
 $11 = ((($0)) + 24|0);
 HEAP32[$11>>2] = $8;
 $12 = (__Znwj(12)|0);
 HEAP32[$12>>2] = 0;
 $13 = ((($12)) + 4|0);
 HEAP32[$13>>2] = 0;
 $14 = ((($12)) + 8|0);
 HEAP32[$14>>2] = 0;
 $15 = ((($0)) + 28|0);
 HEAP32[$15>>2] = $12;
 $16 = (__Znwj(12)|0);
 HEAP32[$16>>2] = 0;
 $17 = ((($16)) + 4|0);
 HEAP32[$17>>2] = 0;
 $18 = ((($16)) + 8|0);
 HEAP32[$18>>2] = 0;
 $19 = ((($0)) + 32|0);
 HEAP32[$19>>2] = $16;
 $20 = ((($0)) + 48|0);
 $21 = ((($0)) + 52|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = HEAP32[$20>>2]|0;
 $24 = (($22) - ($23))|0;
 $25 = $24 >> 2;
 $26 = ($25>>>0)<(5);
 $27 = $23;
 $28 = $22;
 if ($26) {
  $29 = (5 - ($25))|0;
  __ZNSt3__26vectorIPN3osg17AttributeDispatchENS_9allocatorIS3_EEE8__appendEj($20,$29);
  return;
 }
 $30 = ($25|0)==(5);
 if ($30) {
  return;
 }
 $31 = ((($27)) + 20|0);
 $32 = ($28|0)==($31|0);
 if ($32) {
  return;
 }
 $scevgep$i$i$i = ((($28)) + -4|0);
 $33 = $scevgep$i$i$i;
 $34 = $31;
 $35 = (($33) - ($34))|0;
 $36 = $35 >>> 2;
 $37 = $36 ^ -1;
 $scevgep5$i$i$i = (($28) + ($37<<2)|0);
 HEAP32[$21>>2] = $scevgep5$i$i$i;
 return;
}
function __ZNSt3__26vectorIPN3osg17AttributeDispatchENS_9allocatorIS3_EEE8__appendEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i = 0, $$0$i16 = 0, $$sroa$15$0 = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) - ($5))|0;
 $7 = $6 >> 2;
 $8 = ($7>>>0)<($1>>>0);
 if (!($8)) {
  $9 = $5;
  $$0$i = $1;$10 = $9;
  while(1) {
   HEAP32[$10>>2] = 0;
   $11 = HEAP32[$4>>2]|0;
   $12 = ((($11)) + 4|0);
   HEAP32[$4>>2] = $12;
   $13 = (($$0$i) + -1)|0;
   $14 = ($13|0)==(0);
   if ($14) {
    break;
   } else {
    $$0$i = $13;$10 = $12;
   }
  }
  return;
 }
 $15 = HEAP32[$0>>2]|0;
 $16 = (($5) - ($15))|0;
 $17 = $16 >> 2;
 $18 = (($17) + ($1))|0;
 $19 = ($18>>>0)>(1073741823);
 if ($19) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $20 = (($3) - ($15))|0;
 $21 = $20 >> 2;
 $22 = ($21>>>0)<(536870911);
 $23 = $20 >> 1;
 $24 = ($23>>>0)<($18>>>0);
 $$sroa$speculated$i = $24 ? $18 : $23;
 $$sroa$speculated$$i = $22 ? $$sroa$speculated$i : 1073741823;
 $25 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($25) {
   $35 = 0;
  } else {
   $26 = ($$sroa$speculated$$i>>>0)>(1073741823);
   if (!($26)) {
    $32 = $$sroa$speculated$$i << 2;
    $33 = (__Znwj($32)|0);
    $35 = $33;
    break;
   }
   $27 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($27|0),(204840|0));
   $28 = __THREW__; __THREW__ = 0;
   $29 = $28&1;
   if ($29) {
    $30 = ___cxa_find_matching_catch_2()|0;
    $31 = tempRet0;
    ___cxa_free_exception(($27|0));
    ___resumeException($30|0);
    // unreachable;
   } else {
    HEAP32[$27>>2] = (99824);
    ___cxa_throw(($27|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $34 = (($35) + ($17<<2)|0);
 $36 = $34;
 $37 = (($35) + ($$sroa$speculated$$i<<2)|0);
 $$0$i16 = $1;$$sroa$15$0 = $36;$38 = $34;
 while(1) {
  HEAP32[$38>>2] = 0;
  $39 = $$sroa$15$0;
  $40 = ((($39)) + 4|0);
  $41 = $40;
  $42 = (($$0$i16) + -1)|0;
  $43 = ($42|0)==(0);
  if ($43) {
   break;
  } else {
   $$0$i16 = $42;$$sroa$15$0 = $41;$38 = $40;
  }
 }
 $44 = $37;
 $45 = HEAP32[$0>>2]|0;
 $46 = HEAP32[$4>>2]|0;
 $47 = $45;
 $48 = (($46) - ($47))|0;
 $49 = $48 >> 2;
 $50 = (0 - ($49))|0;
 $51 = (($34) + ($50<<2)|0);
 $52 = $51;
 $53 = ($48|0)>(0);
 if ($53) {
  _memcpy(($51|0),($45|0),($48|0))|0;
 }
 HEAP32[$0>>2] = $52;
 HEAP32[$4>>2] = $41;
 HEAP32[$2>>2] = $44;
 $54 = ($45|0)==(0|0);
 if ($54) {
  return;
 }
 __ZdlPv($45);
 return;
}
function __ZN3osg20AttributeDispatchers16normalDispatcherEPNS_5ArrayE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$pre$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 60|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  $40 = ((($0)) + 20|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = ($1|0)==(0|0);
  if ($42) {
   $62 = 0;
   return ($62|0);
  }
  $43 = ((($1)) + 52|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = ((($41)) + 4|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = HEAP32[$41>>2]|0;
  $48 = (($46) - ($47))|0;
  $49 = $48 >> 2;
  $50 = ($44>>>0)<($49>>>0);
  if (!($50)) {
   $62 = 0;
   return ($62|0);
  }
  $51 = $47;
  $52 = (($51) + ($44<<2)|0);
  $53 = HEAP32[$52>>2]|0;
  $54 = ($53|0)==(0|0);
  if ($54) {
   $62 = 0;
   return ($62|0);
  }
  $55 = HEAP32[$53>>2]|0;
  $56 = ((($55)) + 12|0);
  $57 = HEAP32[$56>>2]|0;
  $58 = HEAP32[$1>>2]|0;
  $59 = ((($58)) + 140|0);
  $60 = HEAP32[$59>>2]|0;
  $61 = (FUNCTION_TABLE_ii[$60 & 8191]($1)|0);
  FUNCTION_TABLE_vii[$57 & 8191]($53,$61);
  $62 = $53;
  return ($62|0);
 }
 $5 = ((($0)) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($6)) + 392|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($0)) + 36|0);
 $10 = ((($0)) + 40|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = HEAP32[$9>>2]|0;
 $13 = (($11) - ($12))|0;
 $14 = $13 >> 2;
 $15 = ($14>>>0)>($8>>>0);
 if ($15) {
  $16 = $12;
  $18 = $16;
 } else {
  __ZN3osg20AttributeDispatchers29assignVertexAttribDispatchersEj($0,$8);
  $$pre$i = HEAP32[$9>>2]|0;
  $18 = $$pre$i;
 }
 $17 = (($18) + ($8<<2)|0);
 $19 = HEAP32[$17>>2]|0;
 $20 = ($1|0)==(0|0);
 if ($20) {
  $62 = 0;
  return ($62|0);
 }
 $21 = ((($1)) + 52|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ((($19)) + 4|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = HEAP32[$19>>2]|0;
 $26 = (($24) - ($25))|0;
 $27 = $26 >> 2;
 $28 = ($22>>>0)<($27>>>0);
 if (!($28)) {
  $62 = 0;
  return ($62|0);
 }
 $29 = $25;
 $30 = (($29) + ($22<<2)|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ($31|0)==(0|0);
 if ($32) {
  $62 = 0;
  return ($62|0);
 }
 $33 = HEAP32[$31>>2]|0;
 $34 = ((($33)) + 12|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = HEAP32[$1>>2]|0;
 $37 = ((($36)) + 140|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (FUNCTION_TABLE_ii[$38 & 8191]($1)|0);
 FUNCTION_TABLE_vii[$35 & 8191]($31,$39);
 $62 = $31;
 return ($62|0);
}
function __ZN3osg20AttributeDispatchers29assignVertexAttribDispatchersEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$025 = 0, $$pre = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = ((($0)) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($4)) + 784|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($0)) + 36|0);
 $8 = ((($0)) + 40|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$7>>2]|0;
 $11 = (($9) - ($10))|0;
 $12 = $11 >> 2;
 $13 = ($12>>>0)>($1>>>0);
 if ($13) {
  STACKTOP = sp;return;
 }
 $14 = $9;
 $15 = ((($0)) + 44|0);
 $16 = ((($6)) + 272|0);
 $17 = ((($6)) + 296|0);
 $18 = ((($6)) + 320|0);
 $19 = ((($6)) + 376|0);
 $$025 = $12;$24 = $14;
 while(1) {
  $20 = (__Znwj(12)|0);
  HEAP32[$20>>2] = 0;
  $21 = ((($20)) + 4|0);
  HEAP32[$21>>2] = 0;
  $22 = ((($20)) + 8|0);
  HEAP32[$22>>2] = 0;
  HEAP32[$2>>2] = $20;
  $23 = HEAP32[$15>>2]|0;
  $25 = ($24|0)==($23|0);
  if ($25) {
   __ZNSt3__26vectorIPN3osg20AttributeDispatchMapENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_($7,$2);
  } else {
   $26 = $20;
   HEAP32[$24>>2] = $26;
   $27 = HEAP32[$8>>2]|0;
   $28 = ((($27)) + 4|0);
   HEAP32[$8>>2] = $28;
  }
  $29 = HEAP32[$7>>2]|0;
  $30 = (($29) + ($$025<<2)|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = HEAP32[$16>>2]|0;
  __ZN3osg20AttributeDispatchMap12targetAssignIjfEEvT_NS_5Array4TypeEPFvS2_PKT0_Ej($31,$$025,7,$32,1);
  $33 = HEAP32[$17>>2]|0;
  __ZN3osg20AttributeDispatchMap12targetAssignIjfEEvT_NS_5Array4TypeEPFvS2_PKT0_Ej($31,$$025,27,$33,2);
  $34 = HEAP32[$18>>2]|0;
  __ZN3osg20AttributeDispatchMap12targetAssignIjfEEvT_NS_5Array4TypeEPFvS2_PKT0_Ej($31,$$025,28,$34,3);
  $35 = HEAP32[$19>>2]|0;
  __ZN3osg20AttributeDispatchMap12targetAssignIjfEEvT_NS_5Array4TypeEPFvS2_PKT0_Ej($31,$$025,29,$35,4);
  $36 = (($$025) + 1)|0;
  $37 = ($36>>>0)>($1>>>0);
  if ($37) {
   break;
  }
  $$pre = HEAP32[$8>>2]|0;
  $$025 = $36;$24 = $$pre;
 }
 STACKTOP = sp;return;
}
function __ZNSt3__26vectorIPN3osg20AttributeDispatchMapENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(1073741823);
 if ($8) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $9 = ((($0)) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) - ($4))|0;
 $12 = $11 >> 2;
 $13 = ($12>>>0)<(536870911);
 $14 = $11 >> 1;
 $15 = ($14>>>0)<($7>>>0);
 $$sroa$speculated$i = $15 ? $7 : $14;
 $$sroa$speculated$$i = $13 ? $$sroa$speculated$i : 1073741823;
 $16 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($16) {
   $26 = 0;
  } else {
   $17 = ($$sroa$speculated$$i>>>0)>(1073741823);
   if (!($17)) {
    $23 = $$sroa$speculated$$i << 2;
    $24 = (__Znwj($23)|0);
    $26 = $24;
    break;
   }
   $18 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($18|0),(204840|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if ($20) {
    $21 = ___cxa_find_matching_catch_2()|0;
    $22 = tempRet0;
    ___cxa_free_exception(($18|0));
    ___resumeException($21|0);
    // unreachable;
   } else {
    HEAP32[$18>>2] = (99824);
    ___cxa_throw(($18|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $25 = (($26) + ($6<<2)|0);
 $27 = (($26) + ($$sroa$speculated$$i<<2)|0);
 $28 = $27;
 $29 = HEAP32[$1>>2]|0;
 HEAP32[$25>>2] = $29;
 $30 = ((($25)) + 4|0);
 $31 = $30;
 $32 = (0 - ($6))|0;
 $33 = (($25) + ($32<<2)|0);
 $34 = $33;
 $35 = ($5|0)>(0);
 if ($35) {
  $36 = $4;
  _memcpy(($33|0),($36|0),($5|0))|0;
 }
 HEAP32[$0>>2] = $34;
 HEAP32[$2>>2] = $31;
 HEAP32[$9>>2] = $28;
 $37 = ($4|0)==(0);
 if ($37) {
  return;
 }
 $38 = $4;
 __ZdlPv($38);
 return;
}
function __ZN3osg20AttributeDispatchMap12targetAssignIjfEEvT_NS_5Array4TypeEPFvS2_PKT0_Ej($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = ((($0)) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$0>>2]|0;
 $8 = (($6) - ($7))|0;
 $9 = $8 >> 2;
 $10 = ($9>>>0)>($2>>>0);
 L1: do {
  if (!($10)) {
   $11 = (($2) + 1)|0;
   $12 = ($11>>>0)>($9>>>0);
   $13 = $7;
   $14 = $6;
   if ($12) {
    $15 = (($11) - ($9))|0;
    __ZNSt3__26vectorIN3osg7ref_ptrINS1_17AttributeDispatchEEENS_9allocatorIS4_EEE8__appendEj($0,$15);
    break;
   }
   $16 = ($11>>>0)<($9>>>0);
   if ($16) {
    $17 = (($13) + ($11<<2)|0);
    $18 = ($14|0)==($17|0);
    if (!($18)) {
     $20 = $14;
     while(1) {
      $19 = ((($20)) + -4|0);
      HEAP32[$5>>2] = $19;
      $21 = HEAP32[$19>>2]|0;
      $22 = ($21|0)==(0|0);
      if (!($22)) {
       $23 = ((($21)) + 8|0);
       $24 = HEAP32[$23>>2]|0;HEAP32[$23>>2] = (($24-1)|0);
       $25 = ($24|0)==(1);
       if ($25) {
        __THREW__ = 0;
        invoke_viii(3262,($21|0),1,1);
        $26 = __THREW__; __THREW__ = 0;
        $27 = $26&1;
        if ($27) {
         break;
        }
       }
      }
      HEAP32[$19>>2] = 0;
      $28 = HEAP32[$5>>2]|0;
      $29 = ($28|0)==($17|0);
      if ($29) {
       break L1;
      } else {
       $20 = $28;
      }
     }
     $30 = ___cxa_find_matching_catch_2()|0;
     $31 = tempRet0;
     ___cxa_call_unexpected(($30|0));
     // unreachable;
    }
   }
  }
 } while(0);
 $32 = ($3|0)==(0|0);
 do {
  if ($32) {
   $44 = 0;
  } else {
   $33 = (__Znwj(28)|0);
   __THREW__ = 0;
   invoke_vi(3282,($33|0));
   $34 = __THREW__; __THREW__ = 0;
   $35 = $34&1;
   if ($35) {
    $52 = ___cxa_find_matching_catch_2()|0;
    $53 = tempRet0;
    __ZdlPv($33);
    ___resumeException($52|0);
    // unreachable;
   } else {
    HEAP32[$33>>2] = (70528);
    $36 = ((($33)) + 12|0);
    HEAP32[$36>>2] = $3;
    $37 = ((($33)) + 16|0);
    HEAP32[$37>>2] = $1;
    $38 = ((($33)) + 20|0);
    HEAP32[$38>>2] = $4;
    $39 = ((($33)) + 24|0);
    HEAP32[$39>>2] = 0;
    $44 = $33;
    break;
   }
  }
 } while(0);
 $40 = HEAP32[$0>>2]|0;
 $41 = (($40) + ($2<<2)|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ($42|0)==($44|0);
 if ($43) {
  return;
 }
 HEAP32[$41>>2] = $44;
 $45 = ($44|0)==(0|0);
 if (!($45)) {
  $46 = ((($44)) + 8|0);
  $47 = HEAP32[$46>>2]|0;HEAP32[$46>>2] = (($47+1)|0);
 }
 $48 = ($42|0)==(0|0);
 if ($48) {
  return;
 }
 $49 = ((($42)) + 8|0);
 $50 = HEAP32[$49>>2]|0;HEAP32[$49>>2] = (($50-1)|0);
 $51 = ($50|0)==(1);
 if (!($51)) {
  return;
 }
 __ZNK3osg10Referenced24signalObserversAndDeleteEbb($42,1,1);
 return;
}
function __ZNSt3__26vectorIN3osg7ref_ptrINS1_17AttributeDispatchEEENS_9allocatorIS4_EEE8__appendEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$06$i$i = 0, $$pre = 0, $$pre$i = 0, $$promoted4$i = 0, $$sroa$7$0 = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i = 0, $scevgep$i15 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) - ($5))|0;
 $7 = $6 >> 2;
 $8 = ($7>>>0)<($1>>>0);
 $9 = $5;
 if (!($8)) {
  $$promoted4$i = $5;
  $10 = $1 << 2;
  _memset(($$promoted4$i|0),0,($10|0))|0;
  $scevgep$i = (($9) + ($1<<2)|0);
  HEAP32[$4>>2] = $scevgep$i;
  return;
 }
 $11 = HEAP32[$0>>2]|0;
 $12 = (($5) - ($11))|0;
 $13 = $12 >> 2;
 $14 = (($13) + ($1))|0;
 $15 = ($14>>>0)>(1073741823);
 $16 = $11;
 if ($15) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $17 = (($3) - ($11))|0;
 $18 = $17 >> 2;
 $19 = ($18>>>0)<(536870911);
 $20 = $17 >> 1;
 $21 = ($20>>>0)<($14>>>0);
 $$sroa$speculated$i = $21 ? $14 : $20;
 $$sroa$speculated$$i = $19 ? $$sroa$speculated$i : 1073741823;
 $22 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($22) {
   $32 = 0;
  } else {
   $23 = ($$sroa$speculated$$i>>>0)>(1073741823);
   if (!($23)) {
    $29 = $$sroa$speculated$$i << 2;
    $30 = (__Znwj($29)|0);
    $32 = $30;
    break;
   }
   $24 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($24|0),(204840|0));
   $25 = __THREW__; __THREW__ = 0;
   $26 = $25&1;
   if ($26) {
    $27 = ___cxa_find_matching_catch_2()|0;
    $28 = tempRet0;
    ___cxa_free_exception(($24|0));
    ___resumeException($27|0);
    // unreachable;
   } else {
    HEAP32[$24>>2] = (99824);
    ___cxa_throw(($24|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $31 = (($32) + ($13<<2)|0);
 $33 = $31;
 $34 = (($32) + ($$sroa$speculated$$i<<2)|0);
 $35 = $34;
 $36 = $1 << 2;
 _memset(($31|0),0,($36|0))|0;
 $scevgep$i15 = (($31) + ($1<<2)|0);
 $37 = $scevgep$i15;
 $38 = ($9|0)==($16|0);
 if ($38) {
  $50 = $33;$51 = $5;$53 = $9;
 } else {
  $$06$i$i = $9;$$sroa$7$0 = $33;$41 = $31;
  while(1) {
   $39 = ((($$06$i$i)) + -4|0);
   $40 = ((($41)) + -4|0);
   $42 = HEAP32[$39>>2]|0;
   HEAP32[$40>>2] = $42;
   $43 = ($42|0)==(0|0);
   if (!($43)) {
    $44 = ((($42)) + 8|0);
    $45 = HEAP32[$44>>2]|0;HEAP32[$44>>2] = (($45+1)|0);
   }
   $46 = $$sroa$7$0;
   $47 = ((($46)) + -4|0);
   $48 = $47;
   $49 = ($39|0)==($16|0);
   if ($49) {
    break;
   } else {
    $$06$i$i = $39;$$sroa$7$0 = $48;$41 = $47;
   }
  }
  $$pre$i = HEAP32[$0>>2]|0;
  $$pre = HEAP32[$4>>2]|0;
  $50 = $48;$51 = $$pre$i;$53 = $$pre;
 }
 HEAP32[$0>>2] = $50;
 HEAP32[$4>>2] = $37;
 HEAP32[$2>>2] = $35;
 $52 = $51;
 $54 = ($53|0)==($52|0);
 L25: do {
  if (!($54)) {
   $56 = $53;
   while(1) {
    $55 = ((($56)) + -4|0);
    $57 = HEAP32[$55>>2]|0;
    $58 = ($57|0)==(0|0);
    if (!($58)) {
     $59 = ((($57)) + 8|0);
     $60 = HEAP32[$59>>2]|0;HEAP32[$59>>2] = (($60-1)|0);
     $61 = ($60|0)==(1);
     if ($61) {
      __THREW__ = 0;
      invoke_viii(3262,($57|0),1,1);
      $62 = __THREW__; __THREW__ = 0;
      $63 = $62&1;
      if ($63) {
       break;
      }
     }
    }
    HEAP32[$55>>2] = 0;
    $64 = ($55|0)==($52|0);
    if ($64) {
     break L25;
    } else {
     $56 = $55;
    }
   }
   $65 = ___cxa_find_matching_catch_2()|0;
   $66 = tempRet0;
   ___cxa_call_unexpected(($65|0));
   // unreachable;
  }
 } while(0);
 $67 = ($51|0)==(0);
 if ($67) {
  return;
 }
 $68 = $51;
 __ZdlPv($68);
 return;
}
function __ZN3osg31TemplateTargetAttributeDispatchIjfED0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZN3osg31TemplateTargetAttributeDispatchIjfE6assignEPKv($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 24|0);
 HEAP32[$2>>2] = $1;
 return;
}
function __ZN3osg31TemplateTargetAttributeDispatchIjfEclEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 16|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($0)) + 24|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($0)) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = Math_imul($9, $1)|0;
 $11 = (($7) + ($10<<2)|0);
 FUNCTION_TABLE_vii[$3 & 8191]($5,$11);
 return;
}
function __ZN3osg20AttributeDispatchers22vertexAttribDispatcherEjPNS_5ArrayE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$1$i = 0, $$pre = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 36|0);
 $4 = ((($0)) + 40|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$3>>2]|0;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 2;
 $9 = ($8>>>0)>($1>>>0);
 if ($9) {
  $10 = $6;
  $12 = $10;
 } else {
  __ZN3osg20AttributeDispatchers29assignVertexAttribDispatchersEj($0,$1);
  $$pre = HEAP32[$3>>2]|0;
  $12 = $$pre;
 }
 $11 = (($12) + ($1<<2)|0);
 $13 = HEAP32[$11>>2]|0;
 $14 = ($2|0)==(0|0);
 if ($14) {
  $$1$i = 0;
  return ($$1$i|0);
 }
 $15 = ((($2)) + 52|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ((($13)) + 4|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = HEAP32[$13>>2]|0;
 $20 = (($18) - ($19))|0;
 $21 = $20 >> 2;
 $22 = ($16>>>0)<($21>>>0);
 if (!($22)) {
  $$1$i = 0;
  return ($$1$i|0);
 }
 $23 = $19;
 $24 = (($23) + ($16<<2)|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)==(0|0);
 if ($26) {
  $$1$i = 0;
  return ($$1$i|0);
 }
 $27 = HEAP32[$25>>2]|0;
 $28 = ((($27)) + 12|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = HEAP32[$2>>2]|0;
 $31 = ((($30)) + 140|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (FUNCTION_TABLE_ii[$32 & 8191]($2)|0);
 FUNCTION_TABLE_vii[$29 & 8191]($25,$33);
 $$1$i = $25;
 return ($$1$i|0);
}
function __ZN3osg20AttributeDispatchers15colorDispatcherEPNS_5ArrayE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$pre$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 60|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  $40 = ((($0)) + 24|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = ($1|0)==(0|0);
  if ($42) {
   $62 = 0;
   return ($62|0);
  }
  $43 = ((($1)) + 52|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = ((($41)) + 4|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = HEAP32[$41>>2]|0;
  $48 = (($46) - ($47))|0;
  $49 = $48 >> 2;
  $50 = ($44>>>0)<($49>>>0);
  if (!($50)) {
   $62 = 0;
   return ($62|0);
  }
  $51 = $47;
  $52 = (($51) + ($44<<2)|0);
  $53 = HEAP32[$52>>2]|0;
  $54 = ($53|0)==(0|0);
  if ($54) {
   $62 = 0;
   return ($62|0);
  }
  $55 = HEAP32[$53>>2]|0;
  $56 = ((($55)) + 12|0);
  $57 = HEAP32[$56>>2]|0;
  $58 = HEAP32[$1>>2]|0;
  $59 = ((($58)) + 140|0);
  $60 = HEAP32[$59>>2]|0;
  $61 = (FUNCTION_TABLE_ii[$60 & 8191]($1)|0);
  FUNCTION_TABLE_vii[$57 & 8191]($53,$61);
  $62 = $53;
  return ($62|0);
 }
 $5 = ((($0)) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($6)) + 432|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($0)) + 36|0);
 $10 = ((($0)) + 40|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = HEAP32[$9>>2]|0;
 $13 = (($11) - ($12))|0;
 $14 = $13 >> 2;
 $15 = ($14>>>0)>($8>>>0);
 if ($15) {
  $16 = $12;
  $18 = $16;
 } else {
  __ZN3osg20AttributeDispatchers29assignVertexAttribDispatchersEj($0,$8);
  $$pre$i = HEAP32[$9>>2]|0;
  $18 = $$pre$i;
 }
 $17 = (($18) + ($8<<2)|0);
 $19 = HEAP32[$17>>2]|0;
 $20 = ($1|0)==(0|0);
 if ($20) {
  $62 = 0;
  return ($62|0);
 }
 $21 = ((($1)) + 52|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ((($19)) + 4|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = HEAP32[$19>>2]|0;
 $26 = (($24) - ($25))|0;
 $27 = $26 >> 2;
 $28 = ($22>>>0)<($27>>>0);
 if (!($28)) {
  $62 = 0;
  return ($62|0);
 }
 $29 = $25;
 $30 = (($29) + ($22<<2)|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ($31|0)==(0|0);
 if ($32) {
  $62 = 0;
  return ($62|0);
 }
 $33 = HEAP32[$31>>2]|0;
 $34 = ((($33)) + 12|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = HEAP32[$1>>2]|0;
 $37 = ((($36)) + 140|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (FUNCTION_TABLE_ii[$38 & 8191]($1)|0);
 FUNCTION_TABLE_vii[$35 & 8191]($31,$39);
 $62 = $31;
 return ($62|0);
}
function __ZN3osg20AttributeDispatchers24secondaryColorDispatcherEPNS_5ArrayE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$pre$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 60|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  $40 = ((($0)) + 28|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = ($1|0)==(0|0);
  if ($42) {
   $62 = 0;
   return ($62|0);
  }
  $43 = ((($1)) + 52|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = ((($41)) + 4|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = HEAP32[$41>>2]|0;
  $48 = (($46) - ($47))|0;
  $49 = $48 >> 2;
  $50 = ($44>>>0)<($49>>>0);
  if (!($50)) {
   $62 = 0;
   return ($62|0);
  }
  $51 = $47;
  $52 = (($51) + ($44<<2)|0);
  $53 = HEAP32[$52>>2]|0;
  $54 = ($53|0)==(0|0);
  if ($54) {
   $62 = 0;
   return ($62|0);
  }
  $55 = HEAP32[$53>>2]|0;
  $56 = ((($55)) + 12|0);
  $57 = HEAP32[$56>>2]|0;
  $58 = HEAP32[$1>>2]|0;
  $59 = ((($58)) + 140|0);
  $60 = HEAP32[$59>>2]|0;
  $61 = (FUNCTION_TABLE_ii[$60 & 8191]($1)|0);
  FUNCTION_TABLE_vii[$57 & 8191]($53,$61);
  $62 = $53;
  return ($62|0);
 }
 $5 = ((($0)) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($6)) + 472|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($0)) + 36|0);
 $10 = ((($0)) + 40|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = HEAP32[$9>>2]|0;
 $13 = (($11) - ($12))|0;
 $14 = $13 >> 2;
 $15 = ($14>>>0)>($8>>>0);
 if ($15) {
  $16 = $12;
  $18 = $16;
 } else {
  __ZN3osg20AttributeDispatchers29assignVertexAttribDispatchersEj($0,$8);
  $$pre$i = HEAP32[$9>>2]|0;
  $18 = $$pre$i;
 }
 $17 = (($18) + ($8<<2)|0);
 $19 = HEAP32[$17>>2]|0;
 $20 = ($1|0)==(0|0);
 if ($20) {
  $62 = 0;
  return ($62|0);
 }
 $21 = ((($1)) + 52|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ((($19)) + 4|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = HEAP32[$19>>2]|0;
 $26 = (($24) - ($25))|0;
 $27 = $26 >> 2;
 $28 = ($22>>>0)<($27>>>0);
 if (!($28)) {
  $62 = 0;
  return ($62|0);
 }
 $29 = $25;
 $30 = (($29) + ($22<<2)|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ($31|0)==(0|0);
 if ($32) {
  $62 = 0;
  return ($62|0);
 }
 $33 = HEAP32[$31>>2]|0;
 $34 = ((($33)) + 12|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = HEAP32[$1>>2]|0;
 $37 = ((($36)) + 140|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (FUNCTION_TABLE_ii[$38 & 8191]($1)|0);
 FUNCTION_TABLE_vii[$35 & 8191]($31,$39);
 $62 = $31;
 return ($62|0);
}
function __ZN3osg20AttributeDispatchers18fogCoordDispatcherEPNS_5ArrayE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$pre$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 60|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  $40 = ((($0)) + 32|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = ($1|0)==(0|0);
  if ($42) {
   $62 = 0;
   return ($62|0);
  }
  $43 = ((($1)) + 52|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = ((($41)) + 4|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = HEAP32[$41>>2]|0;
  $48 = (($46) - ($47))|0;
  $49 = $48 >> 2;
  $50 = ($44>>>0)<($49>>>0);
  if (!($50)) {
   $62 = 0;
   return ($62|0);
  }
  $51 = $47;
  $52 = (($51) + ($44<<2)|0);
  $53 = HEAP32[$52>>2]|0;
  $54 = ($53|0)==(0|0);
  if ($54) {
   $62 = 0;
   return ($62|0);
  }
  $55 = HEAP32[$53>>2]|0;
  $56 = ((($55)) + 12|0);
  $57 = HEAP32[$56>>2]|0;
  $58 = HEAP32[$1>>2]|0;
  $59 = ((($58)) + 140|0);
  $60 = HEAP32[$59>>2]|0;
  $61 = (FUNCTION_TABLE_ii[$60 & 8191]($1)|0);
  FUNCTION_TABLE_vii[$57 & 8191]($53,$61);
  $62 = $53;
  return ($62|0);
 }
 $5 = ((($0)) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($6)) + 512|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($0)) + 36|0);
 $10 = ((($0)) + 40|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = HEAP32[$9>>2]|0;
 $13 = (($11) - ($12))|0;
 $14 = $13 >> 2;
 $15 = ($14>>>0)>($8>>>0);
 if ($15) {
  $16 = $12;
  $18 = $16;
 } else {
  __ZN3osg20AttributeDispatchers29assignVertexAttribDispatchersEj($0,$8);
  $$pre$i = HEAP32[$9>>2]|0;
  $18 = $$pre$i;
 }
 $17 = (($18) + ($8<<2)|0);
 $19 = HEAP32[$17>>2]|0;
 $20 = ($1|0)==(0|0);
 if ($20) {
  $62 = 0;
  return ($62|0);
 }
 $21 = ((($1)) + 52|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ((($19)) + 4|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = HEAP32[$19>>2]|0;
 $26 = (($24) - ($25))|0;
 $27 = $26 >> 2;
 $28 = ($22>>>0)<($27>>>0);
 if (!($28)) {
  $62 = 0;
  return ($62|0);
 }
 $29 = $25;
 $30 = (($29) + ($22<<2)|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ($31|0)==(0|0);
 if ($32) {
  $62 = 0;
  return ($62|0);
 }
 $33 = HEAP32[$31>>2]|0;
 $34 = ((($33)) + 12|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = HEAP32[$1>>2]|0;
 $37 = ((($36)) + 140|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (FUNCTION_TABLE_ii[$38 & 8191]($1)|0);
 FUNCTION_TABLE_vii[$35 & 8191]($31,$39);
 $62 = $31;
 return ($62|0);
}
function __ZN3osg20AttributeDispatchers5resetEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i = 0, $scevgep5$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 12|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  __ZN3osg20AttributeDispatchers4initEv($0);
 }
 $4 = ((($0)) + 60|0);
 HEAP8[$4>>0] = 0;
 $5 = ((($0)) + 48|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($0)) + 52|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==($6|0);
 if ($9) {
  return;
 }
 $scevgep$i$i$i = ((($8)) + -4|0);
 $10 = $scevgep$i$i$i;
 $11 = $6;
 $12 = (($10) - ($11))|0;
 $13 = $12 >>> 2;
 $14 = $13 ^ -1;
 $scevgep5$i$i$i = (($8) + ($14<<2)|0);
 HEAP32[$7>>2] = $scevgep5$i$i$i;
 return;
}
function __ZN3osg9BlendFuncD2Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg14StateAttributeD2Ev($0);
 return;
}
function __ZN3osg9BlendFuncD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1573,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK3osg9BlendFunc9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(72)|0);
 __THREW__ = 0;
 invoke_vi(3339,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $8 = ___cxa_find_matching_catch_2()|0;
  $9 = tempRet0;
  __ZdlPv($1);
  ___resumeException($8|0);
  // unreachable;
 } else {
  HEAP32[$1>>2] = (70556);
  $4 = ((($1)) + 56|0);
  HEAP32[$4>>2] = 770;
  $5 = ((($1)) + 60|0);
  HEAP32[$5>>2] = 771;
  $6 = ((($1)) + 64|0);
  HEAP32[$6>>2] = 770;
  $7 = ((($1)) + 68|0);
  HEAP32[$7>>2] = 771;
  return ($1|0);
 }
 return (0)|0;
}
function __ZNK3osg9BlendFunc5cloneERKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(72)|0);
 __THREW__ = 0;
 invoke_viii(3729,($2|0),($0|0),($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $17 = ___cxa_find_matching_catch_2()|0;
  $18 = tempRet0;
  __ZdlPv($2);
  ___resumeException($17|0);
  // unreachable;
 } else {
  HEAP32[$2>>2] = (70556);
  $5 = ((($2)) + 56|0);
  $6 = ((($0)) + 56|0);
  $7 = HEAP32[$6>>2]|0;
  HEAP32[$5>>2] = $7;
  $8 = ((($2)) + 60|0);
  $9 = ((($0)) + 60|0);
  $10 = HEAP32[$9>>2]|0;
  HEAP32[$8>>2] = $10;
  $11 = ((($2)) + 64|0);
  $12 = ((($0)) + 64|0);
  $13 = HEAP32[$12>>2]|0;
  HEAP32[$11>>2] = $13;
  $14 = ((($2)) + 68|0);
  $15 = ((($0)) + 68|0);
  $16 = HEAP32[$15>>2]|0;
  HEAP32[$14>>2] = $16;
  return ($2|0);
 }
 return (0)|0;
}
function __ZNK3osg9BlendFunc12isSameKindAsEPKNS_6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,27168,0)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK3osg9BlendFunc11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175113|0);
}
function __ZNK3osg9BlendFunc9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (159736|0);
}
function __ZNK3osg9BlendFunc7getTypeEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 21;
}
function __ZNK3osg9BlendFunc7compareERKNS_14StateAttributeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$ = 0, $$$ = 0, $$2 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($0|0)==($1|0);
 if ($2) {
  $$2 = 0;
  return ($$2|0);
 }
 $3 = ($0|0)==(0|0);
 if ($3) {
  ___cxa_bad_typeid();
  // unreachable;
 }
 $4 = HEAP32[$0>>2]|0;
 $5 = ((($4)) + -4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$1>>2]|0;
 $8 = ((($7)) + -4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($6)) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($9)) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($11>>>0)<($13>>>0);
 if ($14) {
  $$2 = -1;
  return ($$2|0);
 }
 $15 = ($11|0)==($13|0);
 if (!($15)) {
  $$2 = 1;
  return ($$2|0);
 }
 $16 = ((($0)) + 56|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ((($1)) + 56|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($17>>>0)<($19>>>0);
 if ($20) {
  $$2 = -1;
  return ($$2|0);
 }
 $21 = ($19>>>0)<($17>>>0);
 if ($21) {
  $$2 = 1;
  return ($$2|0);
 }
 $22 = ((($0)) + 60|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ((($1)) + 60|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($23>>>0)<($25>>>0);
 if ($26) {
  $$2 = -1;
  return ($$2|0);
 }
 $27 = ($25>>>0)<($23>>>0);
 if ($27) {
  $$2 = 1;
  return ($$2|0);
 }
 $28 = ((($0)) + 64|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ((($1)) + 64|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ($29>>>0)<($31>>>0);
 if ($32) {
  $$2 = -1;
  return ($$2|0);
 }
 $33 = ($31>>>0)<($29>>>0);
 if ($33) {
  $$2 = 1;
  return ($$2|0);
 } else {
  $34 = ((($0)) + 68|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = ((($1)) + 68|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = ($35>>>0)<($37>>>0);
  $39 = ($37>>>0)<($35>>>0);
  $$ = $39&1;
  $$$ = $38 ? -1 : $$;
  return ($$$|0);
 }
 return (0)|0;
}
function __ZNK3osg9BlendFunc12getModeUsageERNS_14StateAttribute9ModeUsageE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 8191]($1,3042);
 return 1;
}
function __ZNK3osg9BlendFunc5applyERNS_5StateE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = ((($0)) + 56|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 64|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4|0)==($6|0);
 if ($7) {
  $8 = ((($0)) + 60|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ((($0)) + 68|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($9|0)==($11|0);
  if (!($12)) {
   label = 3;
  }
 } else {
  label = 3;
 }
 do {
  if ((label|0) == 3) {
   $13 = ((($1)) + 784|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = ((($14)) + 784|0);
   $16 = HEAP8[$15>>0]|0;
   $17 = ($16<<24>>24)==(0);
   if (!($17)) {
    $40 = ((($14)) + 788|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = ((($0)) + 60|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = ((($0)) + 68|0);
    $45 = HEAP32[$44>>2]|0;
    FUNCTION_TABLE_viiii[$41 & 8191]($4,$43,$6,$45);
    STACKTOP = sp;return;
   }
   $18 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
   if ($18) {
    $19 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
    $20 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($19,159620,115)|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = ((($21)) + -12|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = (($20) + ($23)|0);
    __ZNKSt3__28ios_base6getlocEv($2,$24);
    __THREW__ = 0;
    $25 = (invoke_iii(3255,($2|0),(215188|0))|0);
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if (!($27)) {
     $28 = HEAP32[$25>>2]|0;
     $29 = ((($28)) + 28|0);
     $30 = HEAP32[$29>>2]|0;
     __THREW__ = 0;
     $31 = (invoke_iii($30|0,($25|0),10)|0);
     $32 = __THREW__; __THREW__ = 0;
     $33 = $32&1;
     if (!($33)) {
      __ZNSt3__26localeD2Ev($2);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($20,$31)|0);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($20)|0);
      break;
     }
    }
    $34 = ___cxa_find_matching_catch_2()|0;
    $35 = tempRet0;
    __THREW__ = 0;
    invoke_vi(3263,($2|0));
    $36 = __THREW__; __THREW__ = 0;
    $37 = $36&1;
    if ($37) {
     $38 = ___cxa_find_matching_catch_3(0|0)|0;
     $39 = tempRet0;
     ___clang_call_terminate($38);
     // unreachable;
    } else {
     ___resumeException($34|0);
     // unreachable;
    }
   }
  }
 } while(0);
 $46 = HEAP32[$3>>2]|0;
 $47 = ((($0)) + 60|0);
 $48 = HEAP32[$47>>2]|0;
 _glBlendFunc(($46|0),($48|0));
 STACKTOP = sp;return;
}
function __ZN3osg9BlendFuncC2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg14StateAttributeC2Ev($0);
 HEAP32[$0>>2] = (70556);
 $1 = ((($0)) + 56|0);
 HEAP32[$1>>2] = 770;
 $2 = ((($0)) + 60|0);
 HEAP32[$2>>2] = 771;
 $3 = ((($0)) + 64|0);
 HEAP32[$3>>2] = 770;
 $4 = ((($0)) + 68|0);
 HEAP32[$4>>2] = 771;
 return;
}
function __ZN9dxtc_tool26CompressedImageTranslucentEjjjPv($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$02328 = 0, $$02427 = 0, $$4 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond32 = 0, $or$cond34 = 0, $or$cond36 = 0, $or$cond38 = 0, $or$cond40 = 0, $or$cond42 = 0, $or$cond44 = 0, $or$cond46 = 0, $or$cond48 = 0, $or$cond50 = 0, $or$cond52 = 0, $or$cond54 = 0, $or$cond56 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 switch ($2|0) {
 case 33779:  {
  $$4 = 1;
  return ($$4|0);
  break;
 }
 case 33777:  {
  $4 = Math_imul($1, $0)|0;
  $5 = $4 >>> 4;
  $6 = ($5|0)==(0);
  if ($6) {
   $$4 = 0;
   return ($$4|0);
  }
  $$02328 = $5;$$02427 = $3;
  while(1) {
   $7 = HEAP16[$$02427>>1]|0;
   $8 = ((($$02427)) + 2|0);
   $9 = HEAP16[$8>>1]|0;
   $10 = ($7&65535)>($9&65535);
   if (!($10)) {
    $11 = ((($$02427)) + 4|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = $12 & 3;
    $14 = ($13|0)==(3);
    $15 = $12 & 12;
    $16 = ($15|0)==(12);
    $or$cond32 = $14 | $16;
    $17 = $12 & 48;
    $18 = ($17|0)==(48);
    $or$cond34 = $or$cond32 | $18;
    $19 = $12 & 192;
    $20 = ($19|0)==(192);
    $or$cond36 = $or$cond34 | $20;
    $21 = $12 & 768;
    $22 = ($21|0)==(768);
    $or$cond38 = $or$cond36 | $22;
    $23 = $12 & 3072;
    $24 = ($23|0)==(3072);
    $or$cond40 = $or$cond38 | $24;
    $25 = $12 & 12288;
    $26 = ($25|0)==(12288);
    $or$cond42 = $or$cond40 | $26;
    $27 = $12 & 49152;
    $28 = ($27|0)==(49152);
    $or$cond44 = $or$cond42 | $28;
    $29 = $12 & 196608;
    $30 = ($29|0)==(196608);
    $or$cond46 = $or$cond44 | $30;
    $31 = $12 & 786432;
    $32 = ($31|0)==(786432);
    $or$cond48 = $or$cond46 | $32;
    $33 = $12 & 3145728;
    $34 = ($33|0)==(3145728);
    $or$cond50 = $or$cond48 | $34;
    $35 = $12 & 12582912;
    $36 = ($35|0)==(12582912);
    $or$cond52 = $or$cond50 | $36;
    $37 = $12 & 50331648;
    $38 = ($37|0)==(50331648);
    $or$cond54 = $or$cond52 | $38;
    $39 = $12 & 201326592;
    $40 = ($39|0)==(201326592);
    $or$cond56 = $or$cond54 | $40;
    if ($or$cond56) {
     $$4 = 1;
     label = 9;
     break;
    }
    $44 = $12 & 805306368;
    $45 = ($44|0)==(805306368);
    $46 = ($12>>>0)>(3221225471);
    $or$cond = $45 | $46;
    if ($or$cond) {
     $$4 = 1;
     label = 9;
     break;
    }
   }
   $41 = (($$02328) + -1)|0;
   $42 = ((($$02427)) + 8|0);
   $43 = ($$02328|0)>(1);
   if ($43) {
    $$02328 = $41;$$02427 = $42;
   } else {
    $$4 = 0;
    label = 9;
    break;
   }
  }
  if ((label|0) == 9) {
   return ($$4|0);
  }
  break;
 }
 case 33778:  {
  $$4 = 1;
  return ($$4|0);
  break;
 }
 default: {
  $$4 = 0;
  return ($$4|0);
 }
 }
 return (0)|0;
}
function __ZN3osg5LightD2Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg14StateAttributeD2Ev($0);
 return;
}
function __ZN3osg5LightD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1573,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK3osg5Light9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(156)|0);
 $2 = ((($0)) + 56|0);
 $3 = HEAP32[$2>>2]|0;
 __THREW__ = 0;
 invoke_vi(3339,($1|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $31 = ___cxa_find_matching_catch_2()|0;
  $32 = tempRet0;
  __ZdlPv($1);
  ___resumeException($31|0);
  // unreachable;
 } else {
  HEAP32[$1>>2] = (70744);
  $6 = ((($1)) + 124|0);
  $7 = ((($1)) + 128|0);
  $8 = ((($1)) + 132|0);
  $9 = ((($1)) + 56|0);
  $10 = ((($1)) + 60|0);
  HEAPF32[$10>>2] = 0.05000000074505806;
  $11 = ((($1)) + 64|0);
  HEAPF32[$11>>2] = 0.05000000074505806;
  $12 = ((($1)) + 68|0);
  HEAPF32[$12>>2] = 0.05000000074505806;
  $13 = ((($1)) + 72|0);
  HEAPF32[$13>>2] = 1.0;
  $14 = ((($1)) + 76|0);
  HEAPF32[$14>>2] = 0.80000001192092896;
  $15 = ((($1)) + 80|0);
  HEAPF32[$15>>2] = 0.80000001192092896;
  $16 = ((($1)) + 84|0);
  HEAPF32[$16>>2] = 0.80000001192092896;
  $17 = ((($1)) + 88|0);
  HEAPF32[$17>>2] = 1.0;
  $18 = ((($1)) + 92|0);
  HEAPF32[$18>>2] = 0.05000000074505806;
  $19 = ((($1)) + 96|0);
  HEAPF32[$19>>2] = 0.05000000074505806;
  $20 = ((($1)) + 100|0);
  HEAPF32[$20>>2] = 0.05000000074505806;
  $21 = ((($1)) + 104|0);
  HEAPF32[$21>>2] = 1.0;
  $22 = ((($1)) + 108|0);
  HEAPF32[$22>>2] = 0.0;
  $23 = ((($1)) + 112|0);
  HEAPF32[$23>>2] = 0.0;
  $24 = ((($1)) + 116|0);
  HEAPF32[$24>>2] = 1.0;
  $25 = ((($1)) + 120|0);
  HEAPF32[$25>>2] = 0.0;
  HEAPF32[$6>>2] = 0.0;
  HEAPF32[$7>>2] = 0.0;
  HEAPF32[$8>>2] = -1.0;
  $26 = ((($1)) + 148|0);
  HEAPF32[$26>>2] = 0.0;
  $27 = ((($1)) + 152|0);
  HEAPF32[$27>>2] = 180.0;
  $28 = ((($1)) + 136|0);
  HEAPF32[$28>>2] = 1.0;
  $29 = ((($1)) + 140|0);
  HEAPF32[$29>>2] = 0.0;
  $30 = ((($1)) + 144|0);
  HEAPF32[$30>>2] = 0.0;
  HEAP32[$9>>2] = $3;
  return ($1|0);
 }
 return (0)|0;
}
function __ZNK3osg5Light5cloneERKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(156)|0);
 __THREW__ = 0;
 invoke_viii(3729,($2|0),($0|0),($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $33 = ___cxa_find_matching_catch_2()|0;
  $34 = tempRet0;
  __ZdlPv($2);
  ___resumeException($33|0);
  // unreachable;
 } else {
  HEAP32[$2>>2] = (70744);
  $5 = ((($2)) + 56|0);
  $6 = ((($0)) + 56|0);
  $7 = HEAP32[$6>>2]|0;
  HEAP32[$5>>2] = $7;
  $8 = ((($2)) + 60|0);
  $9 = ((($0)) + 60|0);
  ;HEAP32[$8>>2]=HEAP32[$9>>2]|0;HEAP32[$8+4>>2]=HEAP32[$9+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$9+8>>2]|0;HEAP32[$8+12>>2]=HEAP32[$9+12>>2]|0;
  $10 = ((($2)) + 76|0);
  $11 = ((($0)) + 76|0);
  ;HEAP32[$10>>2]=HEAP32[$11>>2]|0;HEAP32[$10+4>>2]=HEAP32[$11+4>>2]|0;HEAP32[$10+8>>2]=HEAP32[$11+8>>2]|0;HEAP32[$10+12>>2]=HEAP32[$11+12>>2]|0;
  $12 = ((($2)) + 92|0);
  $13 = ((($0)) + 92|0);
  ;HEAP32[$12>>2]=HEAP32[$13>>2]|0;HEAP32[$12+4>>2]=HEAP32[$13+4>>2]|0;HEAP32[$12+8>>2]=HEAP32[$13+8>>2]|0;HEAP32[$12+12>>2]=HEAP32[$13+12>>2]|0;
  $14 = ((($2)) + 108|0);
  $15 = ((($0)) + 108|0);
  ;HEAP32[$14>>2]=HEAP32[$15>>2]|0;HEAP32[$14+4>>2]=HEAP32[$15+4>>2]|0;HEAP32[$14+8>>2]=HEAP32[$15+8>>2]|0;HEAP32[$14+12>>2]=HEAP32[$15+12>>2]|0;
  $16 = ((($2)) + 124|0);
  $17 = ((($0)) + 124|0);
  ;HEAP32[$16>>2]=HEAP32[$17>>2]|0;HEAP32[$16+4>>2]=HEAP32[$17+4>>2]|0;HEAP32[$16+8>>2]=HEAP32[$17+8>>2]|0;
  $18 = ((($2)) + 136|0);
  $19 = ((($0)) + 136|0);
  $20 = HEAP32[$19>>2]|0;
  HEAP32[$18>>2] = $20;
  $21 = ((($2)) + 140|0);
  $22 = ((($0)) + 140|0);
  $23 = HEAP32[$22>>2]|0;
  HEAP32[$21>>2] = $23;
  $24 = ((($2)) + 144|0);
  $25 = ((($0)) + 144|0);
  $26 = HEAP32[$25>>2]|0;
  HEAP32[$24>>2] = $26;
  $27 = ((($2)) + 148|0);
  $28 = ((($0)) + 148|0);
  $29 = HEAP32[$28>>2]|0;
  HEAP32[$27>>2] = $29;
  $30 = ((($2)) + 152|0);
  $31 = ((($0)) + 152|0);
  $32 = HEAP32[$31>>2]|0;
  HEAP32[$30>>2] = $32;
  return ($2|0);
 }
 return (0)|0;
}
function __ZNK3osg5Light12isSameKindAsEPKNS_6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,27184,0)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK3osg5Light11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175113|0);
}
function __ZNK3osg5Light9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (159810|0);
}
function __ZNK3osg5Light7getTypeEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 10;
}
function __ZNK3osg5Light9getMemberEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 56|0);
 $2 = HEAP32[$1>>2]|0;
 return ($2|0);
}
function __ZNK3osg5Light7compareERKNS_14StateAttributeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$ = 0, $$2 = 0, $10 = 0, $100 = 0.0, $101 = 0, $102 = 0, $103 = 0, $104 = 0.0, $105 = 0.0, $106 = 0, $107 = 0, $108 = 0, $109 = 0.0, $11 = 0, $110 = 0, $111 = 0.0, $112 = 0, $113 = 0, $114 = 0, $115 = 0.0;
 var $116 = 0, $117 = 0.0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0.0, $122 = 0, $123 = 0.0, $124 = 0, $125 = 0, $126 = 0.0, $127 = 0, $128 = 0.0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0.0, $133 = 0;
 var $134 = 0.0, $135 = 0, $136 = 0, $137 = 0, $138 = 0.0, $139 = 0, $14 = 0, $140 = 0.0, $141 = 0, $142 = 0, $143 = 0, $144 = 0.0, $145 = 0.0, $146 = 0, $147 = 0, $148 = 0, $149 = 0.0, $15 = 0, $150 = 0, $151 = 0.0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0.0, $156 = 0, $157 = 0.0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0.0, $162 = 0, $163 = 0.0, $164 = 0, $165 = 0, $166 = 0.0, $167 = 0, $168 = 0.0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0.0, $173 = 0, $174 = 0.0, $175 = 0, $176 = 0, $177 = 0, $178 = 0.0, $179 = 0, $18 = 0, $180 = 0.0, $181 = 0, $182 = 0, $183 = 0, $184 = 0.0, $185 = 0.0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0.0, $19 = 0, $190 = 0, $191 = 0.0, $192 = 0, $193 = 0, $194 = 0, $195 = 0.0, $196 = 0, $197 = 0.0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0.0, $201 = 0, $202 = 0.0, $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0.0, $207 = 0, $208 = 0.0, $209 = 0, $21 = 0, $210 = 0, $211 = 0.0, $212 = 0, $213 = 0.0, $214 = 0, $215 = 0, $216 = 0, $217 = 0.0, $218 = 0, $219 = 0.0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0.0;
 var $224 = 0, $225 = 0.0, $226 = 0, $227 = 0, $228 = 0, $229 = 0.0, $23 = 0, $230 = 0, $231 = 0.0, $232 = 0, $233 = 0, $234 = 0, $235 = 0.0, $236 = 0, $237 = 0.0, $238 = 0, $239 = 0, $24 = 0.0, $25 = 0.0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0.0, $32 = 0, $33 = 0, $34 = 0, $35 = 0.0, $36 = 0, $37 = 0.0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0.0, $42 = 0, $43 = 0.0, $44 = 0;
 var $45 = 0, $46 = 0.0, $47 = 0, $48 = 0.0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0.0, $53 = 0, $54 = 0.0, $55 = 0, $56 = 0, $57 = 0, $58 = 0.0, $59 = 0, $6 = 0, $60 = 0.0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0.0, $65 = 0.0, $66 = 0, $67 = 0, $68 = 0, $69 = 0.0, $7 = 0, $70 = 0, $71 = 0.0, $72 = 0, $73 = 0, $74 = 0, $75 = 0.0, $76 = 0, $77 = 0.0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0.0, $82 = 0, $83 = 0.0, $84 = 0, $85 = 0, $86 = 0.0, $87 = 0, $88 = 0.0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0.0, $93 = 0, $94 = 0.0, $95 = 0, $96 = 0, $97 = 0, $98 = 0.0, $99 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($0|0)==($1|0);
 if ($2) {
  $$2 = 0;
  return ($$2|0);
 }
 $3 = ($0|0)==(0|0);
 if ($3) {
  ___cxa_bad_typeid();
  // unreachable;
 }
 $4 = HEAP32[$0>>2]|0;
 $5 = ((($4)) + -4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$1>>2]|0;
 $8 = ((($7)) + -4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($6)) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($9)) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($11>>>0)<($13>>>0);
 if ($14) {
  $$2 = -1;
  return ($$2|0);
 }
 $15 = ($11|0)==($13|0);
 if (!($15)) {
  $$2 = 1;
  return ($$2|0);
 }
 $16 = ((($0)) + 56|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ((($1)) + 56|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($17|0)<($19|0);
 if ($20) {
  $$2 = -1;
  return ($$2|0);
 }
 $21 = ($19|0)<($17|0);
 if ($21) {
  $$2 = 1;
  return ($$2|0);
 }
 $22 = ((($1)) + 60|0);
 $23 = ((($0)) + 60|0);
 $24 = +HEAPF32[$23>>2];
 $25 = +HEAPF32[$22>>2];
 $26 = $24 < $25;
 if ($26) {
  $$2 = -1;
  return ($$2|0);
 }
 $27 = $24 > $25;
 if ($27) {
  $$2 = 1;
  return ($$2|0);
 }
 $28 = ((($0)) + 64|0);
 $29 = +HEAPF32[$28>>2];
 $30 = ((($22)) + 4|0);
 $31 = +HEAPF32[$30>>2];
 $32 = $29 < $31;
 if ($32) {
  $$2 = -1;
  return ($$2|0);
 }
 $33 = $29 > $31;
 if (!($33)) {
  $34 = ((($0)) + 68|0);
  $35 = +HEAPF32[$34>>2];
  $36 = ((($22)) + 8|0);
  $37 = +HEAPF32[$36>>2];
  $38 = $35 < $37;
  if ($38) {
   $$2 = -1;
   return ($$2|0);
  }
  $39 = $35 > $37;
  if (!($39)) {
   $40 = ((($0)) + 72|0);
   $41 = +HEAPF32[$40>>2];
   $42 = ((($22)) + 12|0);
   $43 = +HEAPF32[$42>>2];
   $44 = $41 < $43;
   if ($44) {
    $$2 = -1;
    return ($$2|0);
   }
  }
 }
 $45 = ((($22)) + 4|0);
 $46 = +HEAPF32[$45>>2];
 $47 = ((($0)) + 64|0);
 $48 = +HEAPF32[$47>>2];
 $49 = $46 < $48;
 if ($49) {
  $$2 = 1;
  return ($$2|0);
 }
 $50 = $46 > $48;
 if (!($50)) {
  $51 = ((($22)) + 8|0);
  $52 = +HEAPF32[$51>>2];
  $53 = ((($0)) + 68|0);
  $54 = +HEAPF32[$53>>2];
  $55 = $52 < $54;
  if ($55) {
   $$2 = 1;
   return ($$2|0);
  }
  $56 = $52 > $54;
  if (!($56)) {
   $57 = ((($22)) + 12|0);
   $58 = +HEAPF32[$57>>2];
   $59 = ((($0)) + 72|0);
   $60 = +HEAPF32[$59>>2];
   $61 = $58 < $60;
   if ($61) {
    $$2 = 1;
    return ($$2|0);
   }
  }
 }
 $62 = ((($1)) + 76|0);
 $63 = ((($0)) + 76|0);
 $64 = +HEAPF32[$63>>2];
 $65 = +HEAPF32[$62>>2];
 $66 = $64 < $65;
 if ($66) {
  $$2 = -1;
  return ($$2|0);
 }
 $67 = $64 > $65;
 if ($67) {
  $$2 = 1;
  return ($$2|0);
 }
 $68 = ((($0)) + 80|0);
 $69 = +HEAPF32[$68>>2];
 $70 = ((($62)) + 4|0);
 $71 = +HEAPF32[$70>>2];
 $72 = $69 < $71;
 if ($72) {
  $$2 = -1;
  return ($$2|0);
 }
 $73 = $69 > $71;
 if (!($73)) {
  $74 = ((($0)) + 84|0);
  $75 = +HEAPF32[$74>>2];
  $76 = ((($62)) + 8|0);
  $77 = +HEAPF32[$76>>2];
  $78 = $75 < $77;
  if ($78) {
   $$2 = -1;
   return ($$2|0);
  }
  $79 = $75 > $77;
  if (!($79)) {
   $80 = ((($0)) + 88|0);
   $81 = +HEAPF32[$80>>2];
   $82 = ((($62)) + 12|0);
   $83 = +HEAPF32[$82>>2];
   $84 = $81 < $83;
   if ($84) {
    $$2 = -1;
    return ($$2|0);
   }
  }
 }
 $85 = ((($62)) + 4|0);
 $86 = +HEAPF32[$85>>2];
 $87 = ((($0)) + 80|0);
 $88 = +HEAPF32[$87>>2];
 $89 = $86 < $88;
 if ($89) {
  $$2 = 1;
  return ($$2|0);
 }
 $90 = $86 > $88;
 do {
  if (!($90)) {
   $91 = ((($62)) + 8|0);
   $92 = +HEAPF32[$91>>2];
   $93 = ((($0)) + 84|0);
   $94 = +HEAPF32[$93>>2];
   $95 = $92 < $94;
   if ($95) {
    $$2 = 1;
    return ($$2|0);
   }
   $96 = $92 > $94;
   if ($96) {
    break;
   }
   $97 = ((($62)) + 12|0);
   $98 = +HEAPF32[$97>>2];
   $99 = ((($0)) + 88|0);
   $100 = +HEAPF32[$99>>2];
   $101 = $98 < $100;
   if ($101) {
    $$2 = 1;
   } else {
    break;
   }
   return ($$2|0);
  }
 } while(0);
 $102 = ((($1)) + 92|0);
 $103 = ((($0)) + 92|0);
 $104 = +HEAPF32[$103>>2];
 $105 = +HEAPF32[$102>>2];
 $106 = $104 < $105;
 if ($106) {
  $$2 = -1;
  return ($$2|0);
 }
 $107 = $104 > $105;
 if ($107) {
  $$2 = 1;
  return ($$2|0);
 }
 $108 = ((($0)) + 96|0);
 $109 = +HEAPF32[$108>>2];
 $110 = ((($102)) + 4|0);
 $111 = +HEAPF32[$110>>2];
 $112 = $109 < $111;
 if ($112) {
  $$2 = -1;
  return ($$2|0);
 }
 $113 = $109 > $111;
 do {
  if (!($113)) {
   $114 = ((($0)) + 100|0);
   $115 = +HEAPF32[$114>>2];
   $116 = ((($102)) + 8|0);
   $117 = +HEAPF32[$116>>2];
   $118 = $115 < $117;
   if ($118) {
    $$2 = -1;
    return ($$2|0);
   }
   $119 = $115 > $117;
   if ($119) {
    break;
   }
   $120 = ((($0)) + 104|0);
   $121 = +HEAPF32[$120>>2];
   $122 = ((($102)) + 12|0);
   $123 = +HEAPF32[$122>>2];
   $124 = $121 < $123;
   if ($124) {
    $$2 = -1;
   } else {
    break;
   }
   return ($$2|0);
  }
 } while(0);
 $125 = ((($102)) + 4|0);
 $126 = +HEAPF32[$125>>2];
 $127 = ((($0)) + 96|0);
 $128 = +HEAPF32[$127>>2];
 $129 = $126 < $128;
 if ($129) {
  $$2 = 1;
  return ($$2|0);
 }
 $130 = $126 > $128;
 do {
  if (!($130)) {
   $131 = ((($102)) + 8|0);
   $132 = +HEAPF32[$131>>2];
   $133 = ((($0)) + 100|0);
   $134 = +HEAPF32[$133>>2];
   $135 = $132 < $134;
   if ($135) {
    $$2 = 1;
    return ($$2|0);
   }
   $136 = $132 > $134;
   if ($136) {
    break;
   }
   $137 = ((($102)) + 12|0);
   $138 = +HEAPF32[$137>>2];
   $139 = ((($0)) + 104|0);
   $140 = +HEAPF32[$139>>2];
   $141 = $138 < $140;
   if ($141) {
    $$2 = 1;
   } else {
    break;
   }
   return ($$2|0);
  }
 } while(0);
 $142 = ((($1)) + 108|0);
 $143 = ((($0)) + 108|0);
 $144 = +HEAPF32[$143>>2];
 $145 = +HEAPF32[$142>>2];
 $146 = $144 < $145;
 if ($146) {
  $$2 = -1;
  return ($$2|0);
 }
 $147 = $144 > $145;
 if ($147) {
  $$2 = 1;
  return ($$2|0);
 }
 $148 = ((($0)) + 112|0);
 $149 = +HEAPF32[$148>>2];
 $150 = ((($142)) + 4|0);
 $151 = +HEAPF32[$150>>2];
 $152 = $149 < $151;
 if ($152) {
  $$2 = -1;
  return ($$2|0);
 }
 $153 = $149 > $151;
 do {
  if (!($153)) {
   $154 = ((($0)) + 116|0);
   $155 = +HEAPF32[$154>>2];
   $156 = ((($142)) + 8|0);
   $157 = +HEAPF32[$156>>2];
   $158 = $155 < $157;
   if ($158) {
    $$2 = -1;
    return ($$2|0);
   }
   $159 = $155 > $157;
   if ($159) {
    break;
   }
   $160 = ((($0)) + 120|0);
   $161 = +HEAPF32[$160>>2];
   $162 = ((($142)) + 12|0);
   $163 = +HEAPF32[$162>>2];
   $164 = $161 < $163;
   if ($164) {
    $$2 = -1;
   } else {
    break;
   }
   return ($$2|0);
  }
 } while(0);
 $165 = ((($142)) + 4|0);
 $166 = +HEAPF32[$165>>2];
 $167 = ((($0)) + 112|0);
 $168 = +HEAPF32[$167>>2];
 $169 = $166 < $168;
 if ($169) {
  $$2 = 1;
  return ($$2|0);
 }
 $170 = $166 > $168;
 do {
  if (!($170)) {
   $171 = ((($142)) + 8|0);
   $172 = +HEAPF32[$171>>2];
   $173 = ((($0)) + 116|0);
   $174 = +HEAPF32[$173>>2];
   $175 = $172 < $174;
   if ($175) {
    $$2 = 1;
    return ($$2|0);
   }
   $176 = $172 > $174;
   if ($176) {
    break;
   }
   $177 = ((($142)) + 12|0);
   $178 = +HEAPF32[$177>>2];
   $179 = ((($0)) + 120|0);
   $180 = +HEAPF32[$179>>2];
   $181 = $178 < $180;
   if ($181) {
    $$2 = 1;
   } else {
    break;
   }
   return ($$2|0);
  }
 } while(0);
 $182 = ((($1)) + 124|0);
 $183 = ((($0)) + 124|0);
 $184 = +HEAPF32[$183>>2];
 $185 = +HEAPF32[$182>>2];
 $186 = $184 < $185;
 if ($186) {
  $$2 = -1;
  return ($$2|0);
 }
 $187 = $184 > $185;
 if ($187) {
  $$2 = 1;
  return ($$2|0);
 }
 $188 = ((($0)) + 128|0);
 $189 = +HEAPF32[$188>>2];
 $190 = ((($1)) + 128|0);
 $191 = +HEAPF32[$190>>2];
 $192 = $189 < $191;
 if ($192) {
  $$2 = -1;
  return ($$2|0);
 }
 $193 = $189 > $191;
 do {
  if (!($193)) {
   $194 = ((($0)) + 132|0);
   $195 = +HEAPF32[$194>>2];
   $196 = ((($1)) + 132|0);
   $197 = +HEAPF32[$196>>2];
   $198 = $195 < $197;
   if ($198) {
    $$2 = -1;
   } else {
    break;
   }
   return ($$2|0);
  }
 } while(0);
 $199 = ((($1)) + 128|0);
 $200 = +HEAPF32[$199>>2];
 $201 = ((($0)) + 128|0);
 $202 = +HEAPF32[$201>>2];
 $203 = $200 < $202;
 if ($203) {
  $$2 = 1;
  return ($$2|0);
 }
 $204 = $200 > $202;
 do {
  if (!($204)) {
   $205 = ((($1)) + 132|0);
   $206 = +HEAPF32[$205>>2];
   $207 = ((($0)) + 132|0);
   $208 = +HEAPF32[$207>>2];
   $209 = $206 < $208;
   if ($209) {
    $$2 = 1;
   } else {
    break;
   }
   return ($$2|0);
  }
 } while(0);
 $210 = ((($0)) + 136|0);
 $211 = +HEAPF32[$210>>2];
 $212 = ((($1)) + 136|0);
 $213 = +HEAPF32[$212>>2];
 $214 = $211 < $213;
 if ($214) {
  $$2 = -1;
  return ($$2|0);
 }
 $215 = $213 < $211;
 if ($215) {
  $$2 = 1;
  return ($$2|0);
 }
 $216 = ((($0)) + 140|0);
 $217 = +HEAPF32[$216>>2];
 $218 = ((($1)) + 140|0);
 $219 = +HEAPF32[$218>>2];
 $220 = $217 < $219;
 if ($220) {
  $$2 = -1;
  return ($$2|0);
 }
 $221 = $219 < $217;
 if ($221) {
  $$2 = 1;
  return ($$2|0);
 }
 $222 = ((($0)) + 144|0);
 $223 = +HEAPF32[$222>>2];
 $224 = ((($1)) + 144|0);
 $225 = +HEAPF32[$224>>2];
 $226 = $223 < $225;
 if ($226) {
  $$2 = -1;
  return ($$2|0);
 }
 $227 = $225 < $223;
 if ($227) {
  $$2 = 1;
  return ($$2|0);
 }
 $228 = ((($0)) + 148|0);
 $229 = +HEAPF32[$228>>2];
 $230 = ((($1)) + 148|0);
 $231 = +HEAPF32[$230>>2];
 $232 = $229 < $231;
 if ($232) {
  $$2 = -1;
  return ($$2|0);
 }
 $233 = $231 < $229;
 if ($233) {
  $$2 = 1;
  return ($$2|0);
 }
 $234 = ((($0)) + 152|0);
 $235 = +HEAPF32[$234>>2];
 $236 = ((($1)) + 152|0);
 $237 = +HEAPF32[$236>>2];
 $238 = $235 < $237;
 if ($238) {
  $$2 = -1;
  return ($$2|0);
 }
 $239 = $237 < $235;
 $$ = $239&1;
 $$2 = $$;
 return ($$2|0);
}
function __ZNK3osg5Light12getModeUsageERNS_14StateAttribute9ModeUsageE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 56|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 16384)|0;
 FUNCTION_TABLE_vii[$4 & 8191]($1,$7);
 return 1;
}
function __ZNK3osg5Light5applyERNS_5StateE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $4 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
 $5 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($4,159763,46)|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($6)) + -12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($5) + ($8)|0);
 __ZNKSt3__28ios_base6getlocEv($2,$9);
 __THREW__ = 0;
 $10 = (invoke_iii(3255,($2|0),(215188|0))|0);
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if (!($12)) {
  $13 = HEAP32[$10>>2]|0;
  $14 = ((($13)) + 28|0);
  $15 = HEAP32[$14>>2]|0;
  __THREW__ = 0;
  $16 = (invoke_iii($15|0,($10|0),10)|0);
  $17 = __THREW__; __THREW__ = 0;
  $18 = $17&1;
  if (!($18)) {
   __ZNSt3__26localeD2Ev($2);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($5,$16)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($5)|0);
   STACKTOP = sp;return;
  }
 }
 $19 = ___cxa_find_matching_catch_2()|0;
 $20 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($2|0));
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if ($22) {
  $23 = ___cxa_find_matching_catch_3(0|0)|0;
  $24 = tempRet0;
  ___clang_call_terminate($23);
  // unreachable;
 } else {
  ___resumeException($19|0);
  // unreachable;
 }
}
function __ZN3osg5LightC2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg14StateAttributeC2Ev($0);
 HEAP32[$0>>2] = (70744);
 $1 = ((($0)) + 124|0);
 $2 = ((($0)) + 128|0);
 $3 = ((($0)) + 132|0);
 $4 = ((($0)) + 56|0);
 $5 = ((($0)) + 60|0);
 HEAP32[$4>>2] = 0;
 HEAPF32[$5>>2] = 0.05000000074505806;
 $6 = ((($0)) + 64|0);
 HEAPF32[$6>>2] = 0.05000000074505806;
 $7 = ((($0)) + 68|0);
 HEAPF32[$7>>2] = 0.05000000074505806;
 $8 = ((($0)) + 72|0);
 HEAPF32[$8>>2] = 1.0;
 $9 = ((($0)) + 76|0);
 HEAPF32[$9>>2] = 0.80000001192092896;
 $10 = ((($0)) + 80|0);
 HEAPF32[$10>>2] = 0.80000001192092896;
 $11 = ((($0)) + 84|0);
 HEAPF32[$11>>2] = 0.80000001192092896;
 $12 = ((($0)) + 88|0);
 HEAPF32[$12>>2] = 1.0;
 $13 = ((($0)) + 92|0);
 HEAPF32[$13>>2] = 0.05000000074505806;
 $14 = ((($0)) + 96|0);
 HEAPF32[$14>>2] = 0.05000000074505806;
 $15 = ((($0)) + 100|0);
 HEAPF32[$15>>2] = 0.05000000074505806;
 $16 = ((($0)) + 104|0);
 HEAPF32[$16>>2] = 1.0;
 $17 = ((($0)) + 108|0);
 HEAPF32[$17>>2] = 0.0;
 $18 = ((($0)) + 112|0);
 HEAPF32[$18>>2] = 0.0;
 $19 = ((($0)) + 116|0);
 HEAPF32[$19>>2] = 1.0;
 $20 = ((($0)) + 120|0);
 HEAPF32[$20>>2] = 0.0;
 HEAPF32[$1>>2] = 0.0;
 HEAPF32[$2>>2] = 0.0;
 HEAPF32[$3>>2] = -1.0;
 $21 = ((($0)) + 148|0);
 HEAPF32[$21>>2] = 0.0;
 $22 = ((($0)) + 152|0);
 HEAPF32[$22>>2] = 180.0;
 $23 = ((($0)) + 136|0);
 HEAPF32[$23>>2] = 1.0;
 $24 = ((($0)) + 140|0);
 HEAPF32[$24>>2] = 0.0;
 $25 = ((($0)) + 144|0);
 HEAPF32[$25>>2] = 0.0;
 return;
}
function __ZN3osg5Light11setLightNumEi($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = ((($0)) + 56|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==($1|0);
 if ($5) {
  STACKTOP = sp;return;
 }
 __ZN3osg14StateAttribute17ReassignToParentsC2EPS0_($2,$0);
 HEAP32[$3>>2] = $1;
 __ZN3osg14StateAttribute17ReassignToParentsD2Ev($2);
 STACKTOP = sp;return;
}
function __ZN3osg14ShaderComposerD2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 HEAP32[$0>>2] = (70932);
 __THREW__ = 0;
 $2 = (invoke_ii(3265,4)|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 L1: do {
  if ($4) {
   label = 15;
  } else {
   do {
    if ($2) {
     __THREW__ = 0;
     $5 = (invoke_ii(3266,4)|0);
     $6 = __THREW__; __THREW__ = 0;
     $7 = $6&1;
     if ($7) {
      label = 15;
      break L1;
     }
     __THREW__ = 0;
     $8 = (invoke_iiii(3267,($5|0),(160389|0),34)|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      label = 15;
      break L1;
     }
     __THREW__ = 0;
     $11 = (invoke_iii(3275,($8|0),($0|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      label = 15;
      break L1;
     }
     $14 = HEAP32[$11>>2]|0;
     $15 = ((($14)) + -12|0);
     $16 = HEAP32[$15>>2]|0;
     $17 = (($11) + ($16)|0);
     __THREW__ = 0;
     invoke_vii(3257,($1|0),($17|0));
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      label = 15;
      break L1;
     }
     __THREW__ = 0;
     $20 = (invoke_iii(3255,($1|0),(215188|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if (!($22)) {
      $23 = HEAP32[$20>>2]|0;
      $24 = ((($23)) + 28|0);
      $25 = HEAP32[$24>>2]|0;
      __THREW__ = 0;
      $26 = (invoke_iii($25|0,($20|0),10)|0);
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if (!($28)) {
       __THREW__ = 0;
       invoke_vi(3263,($1|0));
       $35 = __THREW__; __THREW__ = 0;
       $36 = $35&1;
       if ($36) {
        label = 15;
        break L1;
       }
       __THREW__ = 0;
       (invoke_iii(3268,($11|0),($26|0))|0);
       $37 = __THREW__; __THREW__ = 0;
       $38 = $37&1;
       if ($38) {
        label = 15;
        break L1;
       }
       __THREW__ = 0;
       (invoke_ii(3269,($11|0))|0);
       $39 = __THREW__; __THREW__ = 0;
       $40 = $39&1;
       if ($40) {
        label = 15;
        break L1;
       } else {
        break;
       }
      }
     }
     $29 = ___cxa_find_matching_catch_2()|0;
     $30 = tempRet0;
     __THREW__ = 0;
     invoke_vi(3263,($1|0));
     $31 = __THREW__; __THREW__ = 0;
     $32 = $31&1;
     if ($32) {
      $33 = ___cxa_find_matching_catch_3(0|0)|0;
      $34 = tempRet0;
      ___clang_call_terminate($33);
      // unreachable;
     } else {
      $eh$lpad$body$index2Z2D = $30;$eh$lpad$body$indexZ2D = $29;
      break L1;
     }
    }
   } while(0);
   $43 = ((($0)) + 44|0);
   $44 = ((($0)) + 48|0);
   $45 = HEAP32[$44>>2]|0;
   __ZNSt3__26__treeINS_12__value_typeINS_6vectorIPKN3osg6ShaderENS_9allocatorIS6_EEEENS3_7ref_ptrIS4_EEEENS_19__map_value_compareIS9_SC_NS_4lessIS9_EELb1EEENS7_ISC_EEE7destroyEPNS_11__tree_nodeISC_PvEE($43,$45);
   $46 = ((($0)) + 32|0);
   $47 = ((($0)) + 36|0);
   $48 = HEAP32[$47>>2]|0;
   __ZNSt3__26__treeINS_12__value_typeINS_6vectorIPN3osg15ShaderComponentENS_9allocatorIS5_EEEENS3_7ref_ptrINS3_7ProgramEEEEENS_19__map_value_compareIS8_SC_NS_4lessIS8_EELb1EEENS6_ISC_EEE7destroyEPNS_11__tree_nodeISC_PvEE($46,$48);
   __ZN3osg6ObjectD2Ev($0);
   STACKTOP = sp;return;
  }
 } while(0);
 if ((label|0) == 15) {
  $41 = ___cxa_find_matching_catch_2()|0;
  $42 = tempRet0;
  $eh$lpad$body$index2Z2D = $42;$eh$lpad$body$indexZ2D = $41;
 }
 $49 = ((($0)) + 44|0);
 $50 = ((($0)) + 48|0);
 $51 = HEAP32[$50>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_6vectorIPKN3osg6ShaderENS_9allocatorIS6_EEEENS3_7ref_ptrIS4_EEEENS_19__map_value_compareIS9_SC_NS_4lessIS9_EELb1EEENS7_ISC_EEE7destroyEPNS_11__tree_nodeISC_PvEE($49,$51);
 $52 = ((($0)) + 32|0);
 $53 = ((($0)) + 36|0);
 $54 = HEAP32[$53>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_6vectorIPN3osg15ShaderComponentENS_9allocatorIS5_EEEENS3_7ref_ptrINS3_7ProgramEEEEENS_19__map_value_compareIS8_SC_NS_4lessIS8_EELb1EEENS6_ISC_EEE7destroyEPNS_11__tree_nodeISC_PvEE($52,$54);
 __THREW__ = 0;
 invoke_vi(388,($0|0));
 $55 = __THREW__; __THREW__ = 0;
 $56 = $55&1;
 if ($56) {
  $57 = ___cxa_find_matching_catch_3(0|0)|0;
  $58 = tempRet0;
  ___clang_call_terminate($57);
  // unreachable;
 } else {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
}
function __ZN3osg14ShaderComposerD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(2478,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK3osg14ShaderComposer9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(56)|0);
 __THREW__ = 0;
 invoke_vi(3919,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch_2()|0;
  $5 = tempRet0;
  __ZdlPv($1);
  ___resumeException($4|0);
  // unreachable;
 } else {
  return ($1|0);
 }
 return (0)|0;
}
function __ZNK3osg14ShaderComposer5cloneERKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(56)|0);
 __THREW__ = 0;
 invoke_viii(4027,($2|0),($0|0),($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch_2()|0;
  $6 = tempRet0;
  __ZdlPv($2);
  ___resumeException($5|0);
  // unreachable;
 } else {
  return ($2|0);
 }
 return (0)|0;
}
function __ZNK3osg14ShaderComposer12isSameKindAsEPKNS_6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,27200,0)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK3osg14ShaderComposer11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175113|0);
}
function __ZNK3osg14ShaderComposer9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (160263|0);
}
function __ZNK3osg14ShaderComposer16releaseGLObjectsEPNS_5StateE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i$i$i = 0, $$0$i$i$i$i4 = 0, $$sroa$010$0$be = 0, $$sroa$010$021 = 0, $$sroa$016$0$be = 0, $$sroa$016$022 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 32|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 36|0);
 $5 = ($3|0)==($4|0);
 if (!($5)) {
  $$sroa$016$022 = $3;
  while(1) {
   $10 = ((($$sroa$016$022)) + 28|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = HEAP32[$11>>2]|0;
   $13 = ((($12)) + 136|0);
   $14 = HEAP32[$13>>2]|0;
   FUNCTION_TABLE_vii[$14 & 8191]($11,$1);
   $15 = ((($$sroa$016$022)) + 4|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ($16|0)==(0|0);
   if ($17) {
    $18 = ((($$sroa$016$022)) + 8|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = HEAP32[$19>>2]|0;
    $21 = ($20|0)==($$sroa$016$022|0);
    if ($21) {
     $$sroa$016$0$be = $19;
    } else {
     $26 = $18;
     while(1) {
      $25 = HEAP32[$26>>2]|0;
      $27 = ((($25)) + 8|0);
      $28 = HEAP32[$27>>2]|0;
      $29 = HEAP32[$28>>2]|0;
      $30 = ($29|0)==($25|0);
      if ($30) {
       $$sroa$016$0$be = $28;
       break;
      } else {
       $26 = $27;
      }
     }
    }
   } else {
    $$0$i$i$i$i4 = $16;
    while(1) {
     $23 = HEAP32[$$0$i$i$i$i4>>2]|0;
     $24 = ($23|0)==(0|0);
     if ($24) {
      break;
     } else {
      $$0$i$i$i$i4 = $23;
     }
    }
    $$sroa$016$0$be = $$0$i$i$i$i4;
   }
   $22 = ($$sroa$016$0$be|0)==($4|0);
   if ($22) {
    break;
   } else {
    $$sroa$016$022 = $$sroa$016$0$be;
   }
  }
 }
 $6 = ((($0)) + 44|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($0)) + 48|0);
 $9 = ($7|0)==($8|0);
 if ($9) {
  return;
 } else {
  $$sroa$010$021 = $7;
 }
 while(1) {
  $31 = ((($$sroa$010$021)) + 28|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = HEAP32[$32>>2]|0;
  $34 = ((($33)) + 136|0);
  $35 = HEAP32[$34>>2]|0;
  FUNCTION_TABLE_vii[$35 & 8191]($32,$1);
  $36 = ((($$sroa$010$021)) + 4|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = ($37|0)==(0|0);
  if ($38) {
   $39 = ((($$sroa$010$021)) + 8|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = HEAP32[$40>>2]|0;
   $42 = ($41|0)==($$sroa$010$021|0);
   if ($42) {
    $$sroa$010$0$be = $40;
   } else {
    $47 = $39;
    while(1) {
     $46 = HEAP32[$47>>2]|0;
     $48 = ((($46)) + 8|0);
     $49 = HEAP32[$48>>2]|0;
     $50 = HEAP32[$49>>2]|0;
     $51 = ($50|0)==($46|0);
     if ($51) {
      $$sroa$010$0$be = $49;
      break;
     } else {
      $47 = $48;
     }
    }
   }
  } else {
   $$0$i$i$i$i = $37;
   while(1) {
    $44 = HEAP32[$$0$i$i$i$i>>2]|0;
    $45 = ($44|0)==(0|0);
    if ($45) {
     break;
    } else {
     $$0$i$i$i$i = $44;
    }
   }
   $$sroa$010$0$be = $$0$i$i$i$i;
  }
  $43 = ($$sroa$010$0$be|0)==($8|0);
  if ($43) {
   break;
  } else {
   $$sroa$010$021 = $$sroa$010$0$be;
  }
 }
 return;
}
function __ZN3osg14ShaderComposer18getOrCreateProgramERKNSt3__26vectorIPNS_15ShaderComponentENS1_9allocatorIS4_EEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$ph$lcssa$i$i$i = 0, $$0$ph16$i$i$i = 0, $$0160 = 0, $$018 = 0, $$07$ph15$i$i$i = 0, $$07$ph15$us$i$i$i = 0, $$0713$i$i$i = 0, $$2 = 0, $$222 = 0, $$in = 0, $$pre = 0, $$pre$phiZ2D = 0, $$pre167 = 0, $$sroa$0143$0161 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0;
 var $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0;
 var $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0;
 var $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0;
 var $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0;
 var $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0;
 var $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0;
 var $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0;
 var $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0;
 var $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0;
 var $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0;
 var $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0;
 var $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0;
 var $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0;
 var $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0;
 var $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0;
 var $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0;
 var $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0;
 var $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, $eh$lpad$body104$index7Z2D = 0, $eh$lpad$body104$indexZ2D = 0, $eh$lpad$body122$index12Z2D = 0, $eh$lpad$body122$indexZ2D = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i110 = 0, $scevgep$i$i$i33 = 0, $scevgep$i$i$i38 = 0, $scevgep$i$i$i43 = 0, $scevgep$i$i$i48 = 0, $scevgep$i$i$i53 = 0;
 var $scevgep$i$i$i58 = 0, $scevgep$i$i$i63 = 0, $scevgep$i$i$i68 = 0, $scevgep$i$i$i73 = 0, $scevgep$i$i$i81 = 0, $scevgep5$i$i$i = 0, $scevgep5$i$i$i111 = 0, $scevgep5$i$i$i34 = 0, $scevgep5$i$i$i39 = 0, $scevgep5$i$i$i44 = 0, $scevgep5$i$i$i49 = 0, $scevgep5$i$i$i54 = 0, $scevgep5$i$i$i59 = 0, $scevgep5$i$i$i64 = 0, $scevgep5$i$i$i69 = 0, $scevgep5$i$i$i74 = 0, $scevgep5$i$i$i82 = 0, $switch$split252D = 0, $switch$split2D = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(96|0);
 $2 = sp + 84|0;
 $3 = sp + 80|0;
 $4 = sp + 76|0;
 $5 = sp + 64|0;
 $6 = sp + 52|0;
 $7 = sp + 40|0;
 $8 = sp + 28|0;
 $9 = sp + 16|0;
 $10 = sp + 4|0;
 $11 = sp;
 $12 = ((($0)) + 32|0);
 $13 = ((($0)) + 36|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(0|0);
 L1: do {
  if (!($15)) {
   $16 = HEAP32[$1>>2]|0;
   $17 = ((($1)) + 4|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = ($16|0)==($18|0);
   L3: do {
    if ($19) {
     $$07$ph15$us$i$i$i = $14;
     while(1) {
      $20 = HEAP32[$$07$ph15$us$i$i$i>>2]|0;
      $21 = ($20|0)==(0|0);
      if ($21) {
       break;
      } else {
       $$07$ph15$us$i$i$i = $20;
      }
     }
     $$0$ph$lcssa$i$i$i = $$07$ph15$us$i$i$i;
    } else {
     $$0$ph16$i$i$i = $13;$$07$ph15$i$i$i = $14;
     while(1) {
      $$0713$i$i$i = $$07$ph15$i$i$i;
      L9: while(1) {
       $22 = ((($$0713$i$i$i)) + 20|0);
       $23 = HEAP32[$22>>2]|0;
       $24 = ((($$0713$i$i$i)) + 16|0);
       $25 = HEAP32[$24>>2]|0;
       $26 = $25;$30 = $16;
       while(1) {
        $27 = ($26|0)==($23|0);
        if ($27) {
         break;
        }
        $28 = HEAP32[$26>>2]|0;
        $29 = HEAP32[$30>>2]|0;
        $31 = ($28>>>0)<($29>>>0);
        if ($31) {
         break;
        }
        $32 = ($29>>>0)<($28>>>0);
        if ($32) {
         break L9;
        }
        $33 = ((($26)) + 4|0);
        $34 = ((($30)) + 4|0);
        $35 = ($34|0)==($18|0);
        if ($35) {
         break L9;
        } else {
         $26 = $33;$30 = $34;
        }
       }
       $38 = ((($$0713$i$i$i)) + 4|0);
       $39 = HEAP32[$38>>2]|0;
       $40 = ($39|0)==(0|0);
       if ($40) {
        $$0$ph$lcssa$i$i$i = $$0$ph16$i$i$i;
        break L3;
       } else {
        $$0713$i$i$i = $39;
       }
      }
      $36 = HEAP32[$$0713$i$i$i>>2]|0;
      $37 = ($36|0)==(0|0);
      if ($37) {
       $$0$ph$lcssa$i$i$i = $$0713$i$i$i;
       break;
      } else {
       $$0$ph16$i$i$i = $$0713$i$i$i;$$07$ph15$i$i$i = $36;
      }
     }
    }
   } while(0);
   $41 = ($$0$ph$lcssa$i$i$i|0)==($13|0);
   if (!($41)) {
    $42 = ((($$0$ph$lcssa$i$i$i)) + 16|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = ((($$0$ph$lcssa$i$i$i)) + 20|0);
    $45 = HEAP32[$44>>2]|0;
    $46 = ($43|0)==($45|0);
    L20: do {
     if (!($46)) {
      $47 = $16;$51 = $43;
      while(1) {
       $48 = ($47|0)==($18|0);
       if ($48) {
        break L1;
       }
       $49 = HEAP32[$47>>2]|0;
       $50 = HEAP32[$51>>2]|0;
       $52 = ($49>>>0)<($50>>>0);
       if ($52) {
        break L1;
       }
       $53 = ($50>>>0)<($49>>>0);
       if ($53) {
        break L20;
       }
       $54 = ((($47)) + 4|0);
       $55 = ((($51)) + 4|0);
       $56 = ($55|0)==($45|0);
       if ($56) {
        break;
       } else {
        $47 = $54;$51 = $55;
       }
      }
     }
    } while(0);
    $57 = ((($$0$ph$lcssa$i$i$i)) + 28|0);
    $58 = HEAP32[$57>>2]|0;
    $$018 = $58;
    STACKTOP = sp;return ($$018|0);
   }
  }
 } while(0);
 HEAP32[$5>>2] = 0;
 $59 = ((($5)) + 4|0);
 HEAP32[$59>>2] = 0;
 $60 = ((($5)) + 8|0);
 HEAP32[$60>>2] = 0;
 HEAP32[$6>>2] = 0;
 $61 = ((($6)) + 4|0);
 HEAP32[$61>>2] = 0;
 $62 = ((($6)) + 8|0);
 HEAP32[$62>>2] = 0;
 HEAP32[$7>>2] = 0;
 $63 = ((($7)) + 4|0);
 HEAP32[$63>>2] = 0;
 $64 = ((($7)) + 8|0);
 HEAP32[$64>>2] = 0;
 HEAP32[$8>>2] = 0;
 $65 = ((($8)) + 4|0);
 HEAP32[$65>>2] = 0;
 $66 = ((($8)) + 8|0);
 HEAP32[$66>>2] = 0;
 HEAP32[$9>>2] = 0;
 $67 = ((($9)) + 4|0);
 HEAP32[$67>>2] = 0;
 $68 = ((($9)) + 8|0);
 HEAP32[$68>>2] = 0;
 HEAP32[$10>>2] = 0;
 $69 = ((($10)) + 4|0);
 HEAP32[$69>>2] = 0;
 $70 = ((($10)) + 8|0);
 HEAP32[$70>>2] = 0;
 __THREW__ = 0;
 $71 = (invoke_ii(3265,3)|0);
 $72 = __THREW__; __THREW__ = 0;
 $73 = $72&1;
 L29: do {
  if ($73) {
   label = 35;
  } else {
   do {
    if ($71) {
     __THREW__ = 0;
     $74 = (invoke_ii(3266,3)|0);
     $75 = __THREW__; __THREW__ = 0;
     $76 = $75&1;
     if ($76) {
      label = 35;
      break L29;
     }
     __THREW__ = 0;
     $77 = (invoke_iiii(3267,($74|0),(160052|0),60)|0);
     $78 = __THREW__; __THREW__ = 0;
     $79 = $78&1;
     if ($79) {
      label = 35;
      break L29;
     }
     $80 = ((($1)) + 4|0);
     $81 = HEAP32[$80>>2]|0;
     $82 = HEAP32[$1>>2]|0;
     $83 = (($81) - ($82))|0;
     $84 = $83 >> 2;
     __THREW__ = 0;
     $85 = (invoke_iii(3417,($77|0),($84|0))|0);
     $86 = __THREW__; __THREW__ = 0;
     $87 = $86&1;
     if ($87) {
      label = 35;
      break L29;
     }
     $88 = HEAP32[$85>>2]|0;
     $89 = ((($88)) + -12|0);
     $90 = HEAP32[$89>>2]|0;
     $91 = (($85) + ($90)|0);
     __THREW__ = 0;
     invoke_vii(3257,($4|0),($91|0));
     $92 = __THREW__; __THREW__ = 0;
     $93 = $92&1;
     if ($93) {
      label = 35;
      break L29;
     }
     __THREW__ = 0;
     $94 = (invoke_iii(3255,($4|0),(215188|0))|0);
     $95 = __THREW__; __THREW__ = 0;
     $96 = $95&1;
     if (!($96)) {
      $97 = HEAP32[$94>>2]|0;
      $98 = ((($97)) + 28|0);
      $99 = HEAP32[$98>>2]|0;
      __THREW__ = 0;
      $100 = (invoke_iii($99|0,($94|0),10)|0);
      $101 = __THREW__; __THREW__ = 0;
      $102 = $101&1;
      if (!($102)) {
       __THREW__ = 0;
       invoke_vi(3263,($4|0));
       $109 = __THREW__; __THREW__ = 0;
       $110 = $109&1;
       if ($110) {
        label = 35;
        break L29;
       }
       __THREW__ = 0;
       (invoke_iii(3268,($85|0),($100|0))|0);
       $111 = __THREW__; __THREW__ = 0;
       $112 = $111&1;
       if ($112) {
        label = 35;
        break L29;
       }
       __THREW__ = 0;
       (invoke_ii(3269,($85|0))|0);
       $113 = __THREW__; __THREW__ = 0;
       $114 = $113&1;
       if ($114) {
        label = 35;
        break L29;
       } else {
        $$pre$phiZ2D = $80;
        break;
       }
      }
     }
     $103 = ___cxa_find_matching_catch_2()|0;
     $104 = tempRet0;
     __THREW__ = 0;
     invoke_vi(3263,($4|0));
     $105 = __THREW__; __THREW__ = 0;
     $106 = $105&1;
     if ($106) {
      $107 = ___cxa_find_matching_catch_3(0|0)|0;
      $108 = tempRet0;
      ___clang_call_terminate($107);
      // unreachable;
     } else {
      $eh$lpad$body$index2Z2D = $104;$eh$lpad$body$indexZ2D = $103;
      label = 36;
      break L29;
     }
    } else {
     $$pre167 = ((($1)) + 4|0);
     $$pre$phiZ2D = $$pre167;
    }
   } while(0);
   $117 = HEAP32[$1>>2]|0;
   $118 = HEAP32[$$pre$phiZ2D>>2]|0;
   $119 = ($117|0)==($118|0);
   L48: do {
    if (!($119)) {
     $120 = ((($5)) + 8|0);
     $121 = ((($6)) + 8|0);
     $122 = ((($7)) + 8|0);
     $123 = ((($8)) + 8|0);
     $124 = ((($9)) + 8|0);
     $125 = ((($10)) + 8|0);
     $$sroa$0143$0161 = $117;$454 = $118;
     L50: while(1) {
      $129 = HEAP32[$$sroa$0143$0161>>2]|0;
      $130 = ((($129)) + 32|0);
      $131 = ((($129)) + 36|0);
      $132 = HEAP32[$131>>2]|0;
      $133 = HEAP32[$130>>2]|0;
      $134 = ($132|0)==($133|0);
      if ($134) {
       $137 = $454;
      } else {
       $$0160 = 0;$$in = $133;
       while(1) {
        $138 = $$in;
        $139 = (($138) + ($$0160<<2)|0);
        $140 = HEAP32[$139>>2]|0;
        HEAP32[$11>>2] = $140;
        $141 = ((($140)) + 32|0);
        $142 = HEAP32[$141>>2]|0;
        $143 = $140;
        $switch$split2D = ($142|0)<(36313);
        L55: do {
         if ($switch$split2D) {
          $switch$split252D = ($142|0)<(35632);
          if (!($switch$split252D)) {
           switch ($142|0) {
           case 35633:  {
            $146 = HEAP32[$59>>2]|0;
            $147 = HEAP32[$120>>2]|0;
            $148 = ($146|0)==($147|0);
            if ($148) {
             __THREW__ = 0;
             invoke_vii(4028,($5|0),($11|0));
             $151 = __THREW__; __THREW__ = 0;
             $152 = $151&1;
             if ($152) {
              label = 44;
              break L50;
             } else {
              break L55;
             }
            } else {
             HEAP32[$146>>2] = $143;
             $149 = HEAP32[$59>>2]|0;
             $150 = ((($149)) + 4|0);
             HEAP32[$59>>2] = $150;
             break L55;
            }
            break;
           }
           case 35632:  {
            $174 = HEAP32[$67>>2]|0;
            $175 = HEAP32[$124>>2]|0;
            $176 = ($174|0)==($175|0);
            if ($176) {
             __THREW__ = 0;
             invoke_vii(4028,($9|0),($11|0));
             $179 = __THREW__; __THREW__ = 0;
             $180 = $179&1;
             if ($180) {
              label = 44;
              break L50;
             } else {
              break L55;
             }
            } else {
             HEAP32[$174>>2] = $143;
             $177 = HEAP32[$67>>2]|0;
             $178 = ((($177)) + 4|0);
             HEAP32[$67>>2] = $178;
             break L55;
            }
            break;
           }
           default: {
            break L55;
           }
           }
          }
          switch ($142|0) {
          case -1:  {
           break;
          }
          default: {
           break L55;
          }
          }
          __THREW__ = 0;
          $188 = (invoke_ii(3265,2)|0);
          $189 = __THREW__; __THREW__ = 0;
          $190 = $189&1;
          if ($190) {
           label = 44;
           break L50;
          }
          if ($188) {
           __THREW__ = 0;
           $191 = (invoke_ii(3266,2)|0);
           $192 = __THREW__; __THREW__ = 0;
           $193 = $192&1;
           if ($193) {
            label = 44;
            break L50;
           }
           __THREW__ = 0;
           $194 = (invoke_iiii(3267,($191|0),(160113|0),90)|0);
           $195 = __THREW__; __THREW__ = 0;
           $196 = $195&1;
           if ($196) {
            label = 44;
            break L50;
           }
           $197 = HEAP32[$194>>2]|0;
           $198 = ((($197)) + -12|0);
           $199 = HEAP32[$198>>2]|0;
           $200 = (($194) + ($199)|0);
           __THREW__ = 0;
           invoke_vii(3257,($3|0),($200|0));
           $201 = __THREW__; __THREW__ = 0;
           $202 = $201&1;
           if ($202) {
            label = 44;
            break L50;
           }
           __THREW__ = 0;
           $203 = (invoke_iii(3255,($3|0),(215188|0))|0);
           $204 = __THREW__; __THREW__ = 0;
           $205 = $204&1;
           if ($205) {
            label = 70;
            break L50;
           }
           $206 = HEAP32[$203>>2]|0;
           $207 = ((($206)) + 28|0);
           $208 = HEAP32[$207>>2]|0;
           __THREW__ = 0;
           $209 = (invoke_iii($208|0,($203|0),10)|0);
           $210 = __THREW__; __THREW__ = 0;
           $211 = $210&1;
           if ($211) {
            label = 70;
            break L50;
           }
           __THREW__ = 0;
           invoke_vi(3263,($3|0));
           $218 = __THREW__; __THREW__ = 0;
           $219 = $218&1;
           if ($219) {
            label = 44;
            break L50;
           }
           __THREW__ = 0;
           (invoke_iii(3268,($194|0),($209|0))|0);
           $220 = __THREW__; __THREW__ = 0;
           $221 = $220&1;
           if ($221) {
            label = 44;
            break L50;
           }
           __THREW__ = 0;
           (invoke_ii(3269,($194|0))|0);
           $222 = __THREW__; __THREW__ = 0;
           $223 = $222&1;
           if ($223) {
            label = 44;
            break L50;
           }
          }
         } else {
          switch ($142|0) {
          case 36488:  {
           $153 = HEAP32[$61>>2]|0;
           $154 = HEAP32[$121>>2]|0;
           $155 = ($153|0)==($154|0);
           if ($155) {
            __THREW__ = 0;
            invoke_vii(4028,($6|0),($11|0));
            $158 = __THREW__; __THREW__ = 0;
            $159 = $158&1;
            if ($159) {
             label = 44;
             break L50;
            } else {
             break L55;
            }
           } else {
            HEAP32[$153>>2] = $143;
            $156 = HEAP32[$61>>2]|0;
            $157 = ((($156)) + 4|0);
            HEAP32[$61>>2] = $157;
            break L55;
           }
           break;
          }
          case 36487:  {
           $160 = HEAP32[$63>>2]|0;
           $161 = HEAP32[$122>>2]|0;
           $162 = ($160|0)==($161|0);
           if ($162) {
            __THREW__ = 0;
            invoke_vii(4028,($7|0),($11|0));
            $165 = __THREW__; __THREW__ = 0;
            $166 = $165&1;
            if ($166) {
             label = 44;
             break L50;
            } else {
             break L55;
            }
           } else {
            HEAP32[$160>>2] = $143;
            $163 = HEAP32[$63>>2]|0;
            $164 = ((($163)) + 4|0);
            HEAP32[$63>>2] = $164;
            break L55;
           }
           break;
          }
          case 36313:  {
           $167 = HEAP32[$65>>2]|0;
           $168 = HEAP32[$123>>2]|0;
           $169 = ($167|0)==($168|0);
           if ($169) {
            __THREW__ = 0;
            invoke_vii(4028,($8|0),($11|0));
            $172 = __THREW__; __THREW__ = 0;
            $173 = $172&1;
            if ($173) {
             label = 44;
             break L50;
            } else {
             break L55;
            }
           } else {
            HEAP32[$167>>2] = $143;
            $170 = HEAP32[$65>>2]|0;
            $171 = ((($170)) + 4|0);
            HEAP32[$65>>2] = $171;
            break L55;
           }
           break;
          }
          case 37305:  {
           $181 = HEAP32[$69>>2]|0;
           $182 = HEAP32[$125>>2]|0;
           $183 = ($181|0)==($182|0);
           if ($183) {
            __THREW__ = 0;
            invoke_vii(4028,($10|0),($11|0));
            $186 = __THREW__; __THREW__ = 0;
            $187 = $186&1;
            if ($187) {
             label = 44;
             break L50;
            } else {
             break L55;
            }
           } else {
            HEAP32[$181>>2] = $143;
            $184 = HEAP32[$69>>2]|0;
            $185 = ((($184)) + 4|0);
            HEAP32[$69>>2] = $185;
            break L55;
           }
           break;
          }
          default: {
           break L55;
          }
          }
         }
        } while(0);
        $224 = (($$0160) + 1)|0;
        $225 = HEAP32[$131>>2]|0;
        $226 = HEAP32[$130>>2]|0;
        $227 = (($225) - ($226))|0;
        $228 = $227 >> 2;
        $229 = ($224>>>0)<($228>>>0);
        if ($229) {
         $$0160 = $224;$$in = $226;
        } else {
         break;
        }
       }
       $$pre = HEAP32[$$pre$phiZ2D>>2]|0;
       $137 = $$pre;
      }
      $135 = ((($$sroa$0143$0161)) + 4|0);
      $136 = ($135|0)==($137|0);
      if ($136) {
       break L48;
      } else {
       $$sroa$0143$0161 = $135;$454 = $137;
      }
     }
     do {
      if ((label|0) == 44) {
       $144 = ___cxa_find_matching_catch_2()|0;
       $145 = tempRet0;
       $eh$lpad$body104$index7Z2D = $145;$eh$lpad$body104$indexZ2D = $144;
      }
      else if ((label|0) == 70) {
       $212 = ___cxa_find_matching_catch_2()|0;
       $213 = tempRet0;
       __THREW__ = 0;
       invoke_vi(3263,($3|0));
       $214 = __THREW__; __THREW__ = 0;
       $215 = $214&1;
       if ($215) {
        $216 = ___cxa_find_matching_catch_3(0|0)|0;
        $217 = tempRet0;
        ___clang_call_terminate($216);
        // unreachable;
       } else {
        $eh$lpad$body104$index7Z2D = $213;$eh$lpad$body104$indexZ2D = $212;
        break;
       }
      }
     } while(0);
     $$2 = $eh$lpad$body104$index7Z2D;$$222 = $eh$lpad$body104$indexZ2D;
     break L29;
    }
   } while(0);
   __THREW__ = 0;
   $126 = (invoke_ii(3276,172)|0);
   $127 = __THREW__; __THREW__ = 0;
   $128 = $127&1;
   if ($128) {
    label = 35;
   } else {
    __THREW__ = 0;
    invoke_vi(3613,($126|0));
    $230 = __THREW__; __THREW__ = 0;
    $231 = $230&1;
    if ($231) {
     $242 = ___cxa_find_matching_catch_2()|0;
     $243 = tempRet0;
     __ZdlPv($126);
     $$2 = $243;$$222 = $242;
     break;
    }
    $232 = ((($126)) + 8|0);
    $233 = HEAP32[$232>>2]|0;HEAP32[$232>>2] = (($233+1)|0);
    $234 = HEAP32[$5>>2]|0;
    $235 = HEAP32[$59>>2]|0;
    $236 = ($234|0)==($235|0);
    if ($236) {
     label = 85;
    } else {
     $237 = HEAP32[$0>>2]|0;
     $238 = ((($237)) + 148|0);
     $239 = HEAP32[$238>>2]|0;
     __THREW__ = 0;
     invoke_viii($239|0,($0|0),($126|0),($5|0));
     $240 = __THREW__; __THREW__ = 0;
     $241 = $240&1;
     if ($241) {
      label = 82;
     } else {
      label = 85;
     }
    }
    L114: do {
     if ((label|0) == 85) {
      $250 = HEAP32[$6>>2]|0;
      $251 = HEAP32[$61>>2]|0;
      $252 = ($250|0)==($251|0);
      if (!($252)) {
       $253 = HEAP32[$0>>2]|0;
       $254 = ((($253)) + 148|0);
       $255 = HEAP32[$254>>2]|0;
       __THREW__ = 0;
       invoke_viii($255|0,($0|0),($126|0),($6|0));
       $256 = __THREW__; __THREW__ = 0;
       $257 = $256&1;
       if ($257) {
        label = 82;
        break;
       }
      }
      $258 = HEAP32[$8>>2]|0;
      $259 = HEAP32[$65>>2]|0;
      $260 = ($258|0)==($259|0);
      if (!($260)) {
       $261 = HEAP32[$0>>2]|0;
       $262 = ((($261)) + 148|0);
       $263 = HEAP32[$262>>2]|0;
       __THREW__ = 0;
       invoke_viii($263|0,($0|0),($126|0),($8|0));
       $264 = __THREW__; __THREW__ = 0;
       $265 = $264&1;
       if ($265) {
        label = 82;
        break;
       }
      }
      $266 = HEAP32[$7>>2]|0;
      $267 = HEAP32[$63>>2]|0;
      $268 = ($266|0)==($267|0);
      if (!($268)) {
       $269 = HEAP32[$0>>2]|0;
       $270 = ((($269)) + 148|0);
       $271 = HEAP32[$270>>2]|0;
       __THREW__ = 0;
       invoke_viii($271|0,($0|0),($126|0),($7|0));
       $272 = __THREW__; __THREW__ = 0;
       $273 = $272&1;
       if ($273) {
        label = 82;
        break;
       }
      }
      $274 = HEAP32[$9>>2]|0;
      $275 = HEAP32[$67>>2]|0;
      $276 = ($274|0)==($275|0);
      if (!($276)) {
       $277 = HEAP32[$0>>2]|0;
       $278 = ((($277)) + 148|0);
       $279 = HEAP32[$278>>2]|0;
       __THREW__ = 0;
       invoke_viii($279|0,($0|0),($126|0),($9|0));
       $280 = __THREW__; __THREW__ = 0;
       $281 = $280&1;
       if ($281) {
        label = 82;
        break;
       }
      }
      $282 = HEAP32[$10>>2]|0;
      $283 = HEAP32[$69>>2]|0;
      $284 = ($282|0)==($283|0);
      if (!($284)) {
       $285 = HEAP32[$0>>2]|0;
       $286 = ((($285)) + 148|0);
       $287 = HEAP32[$286>>2]|0;
       __THREW__ = 0;
       invoke_viii($287|0,($0|0),($126|0),($10|0));
       $288 = __THREW__; __THREW__ = 0;
       $289 = $288&1;
       if ($289) {
        label = 82;
        break;
       }
      }
      __THREW__ = 0;
      $290 = (invoke_iii(4029,($12|0),($1|0))|0);
      $291 = __THREW__; __THREW__ = 0;
      $292 = $291&1;
      if ($292) {
       label = 82;
      } else {
       $293 = HEAP32[$290>>2]|0;
       $294 = ($293|0)==($126|0);
       if (!($294)) {
        HEAP32[$290>>2] = $126;
        $295 = HEAP32[$232>>2]|0;HEAP32[$232>>2] = (($295+1)|0);
        $296 = ($293|0)==(0|0);
        if (!($296)) {
         $297 = ((($293)) + 8|0);
         $298 = HEAP32[$297>>2]|0;HEAP32[$297>>2] = (($298-1)|0);
         $299 = ($298|0)==(1);
         if ($299) {
          __THREW__ = 0;
          invoke_viii(3262,($293|0),1,1);
          $300 = __THREW__; __THREW__ = 0;
          $301 = $300&1;
          if ($301) {
           label = 82;
           break;
          }
         }
        }
       }
       __THREW__ = 0;
       $302 = (invoke_ii(3265,3)|0);
       $303 = __THREW__; __THREW__ = 0;
       $304 = $303&1;
       if ($304) {
        label = 82;
       } else {
        L138: do {
         if ($302) {
          __THREW__ = 0;
          $305 = (invoke_ii(3266,3)|0);
          $306 = __THREW__; __THREW__ = 0;
          $307 = $306&1;
          if ($307) {
           label = 82;
           break L114;
          }
          __THREW__ = 0;
          $308 = (invoke_iiii(3267,($305|0),(160204|0),58)|0);
          $309 = __THREW__; __THREW__ = 0;
          $310 = $309&1;
          if ($310) {
           label = 82;
           break L114;
          }
          $311 = HEAP32[$308>>2]|0;
          $312 = ((($311)) + -12|0);
          $313 = HEAP32[$312>>2]|0;
          $314 = (($308) + ($313)|0);
          __THREW__ = 0;
          invoke_vii(3257,($2|0),($314|0));
          $315 = __THREW__; __THREW__ = 0;
          $316 = $315&1;
          if ($316) {
           label = 82;
           break L114;
          }
          __THREW__ = 0;
          $317 = (invoke_iii(3255,($2|0),(215188|0))|0);
          $318 = __THREW__; __THREW__ = 0;
          $319 = $318&1;
          do {
           if (!($319)) {
            $320 = HEAP32[$317>>2]|0;
            $321 = ((($320)) + 28|0);
            $322 = HEAP32[$321>>2]|0;
            __THREW__ = 0;
            $323 = (invoke_iii($322|0,($317|0),10)|0);
            $324 = __THREW__; __THREW__ = 0;
            $325 = $324&1;
            if ($325) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3263,($2|0));
            $332 = __THREW__; __THREW__ = 0;
            $333 = $332&1;
            if ($333) {
             label = 82;
             break L114;
            }
            __THREW__ = 0;
            (invoke_iii(3268,($308|0),($323|0))|0);
            $334 = __THREW__; __THREW__ = 0;
            $335 = $334&1;
            if ($335) {
             label = 82;
             break L114;
            }
            __THREW__ = 0;
            (invoke_ii(3269,($308|0))|0);
            $336 = __THREW__; __THREW__ = 0;
            $337 = $336&1;
            if ($337) {
             label = 82;
             break L114;
            } else {
             break L138;
            }
           }
          } while(0);
          $326 = ___cxa_find_matching_catch_2()|0;
          $327 = tempRet0;
          __THREW__ = 0;
          invoke_vi(3263,($2|0));
          $328 = __THREW__; __THREW__ = 0;
          $329 = $328&1;
          if ($329) {
           $330 = ___cxa_find_matching_catch_3(0|0)|0;
           $331 = tempRet0;
           ___clang_call_terminate($330);
           // unreachable;
          } else {
           $eh$lpad$body122$index12Z2D = $327;$eh$lpad$body122$indexZ2D = $326;
           break L114;
          }
         }
        } while(0);
        $338 = HEAP32[$232>>2]|0;HEAP32[$232>>2] = (($338-1)|0);
        $339 = ($338|0)==(1);
        do {
         if ($339) {
          __THREW__ = 0;
          invoke_viii(3262,($126|0),1,1);
          $340 = __THREW__; __THREW__ = 0;
          $341 = $340&1;
          if (!($341)) {
           break;
          }
          $351 = ___cxa_find_matching_catch_2()|0;
          $352 = tempRet0;
          $$2 = $352;$$222 = $351;
          break L29;
         }
        } while(0);
        $342 = HEAP32[$10>>2]|0;
        $343 = ($342|0)==(0|0);
        if (!($343)) {
         $344 = HEAP32[$69>>2]|0;
         $345 = ($344|0)==($342|0);
         if (!($345)) {
          $scevgep$i$i$i110 = ((($344)) + -4|0);
          $346 = $scevgep$i$i$i110;
          $347 = $342;
          $348 = (($346) - ($347))|0;
          $349 = $348 >>> 2;
          $350 = $349 ^ -1;
          $scevgep5$i$i$i111 = (($344) + ($350<<2)|0);
          HEAP32[$69>>2] = $scevgep5$i$i$i111;
         }
         __ZdlPv($342);
        }
        $353 = HEAP32[$9>>2]|0;
        $354 = ($353|0)==(0|0);
        if (!($354)) {
         $355 = HEAP32[$67>>2]|0;
         $356 = ($355|0)==($353|0);
         if (!($356)) {
          $scevgep$i$i$i81 = ((($355)) + -4|0);
          $357 = $scevgep$i$i$i81;
          $358 = $353;
          $359 = (($357) - ($358))|0;
          $360 = $359 >>> 2;
          $361 = $360 ^ -1;
          $scevgep5$i$i$i82 = (($355) + ($361<<2)|0);
          HEAP32[$67>>2] = $scevgep5$i$i$i82;
         }
         __ZdlPv($353);
        }
        $371 = HEAP32[$8>>2]|0;
        $372 = ($371|0)==(0|0);
        if (!($372)) {
         $373 = HEAP32[$65>>2]|0;
         $374 = ($373|0)==($371|0);
         if (!($374)) {
          $scevgep$i$i$i68 = ((($373)) + -4|0);
          $375 = $scevgep$i$i$i68;
          $376 = $371;
          $377 = (($375) - ($376))|0;
          $378 = $377 >>> 2;
          $379 = $378 ^ -1;
          $scevgep5$i$i$i69 = (($373) + ($379<<2)|0);
          HEAP32[$65>>2] = $scevgep5$i$i$i69;
         }
         __ZdlPv($371);
        }
        $389 = HEAP32[$7>>2]|0;
        $390 = ($389|0)==(0|0);
        if (!($390)) {
         $391 = HEAP32[$63>>2]|0;
         $392 = ($391|0)==($389|0);
         if (!($392)) {
          $scevgep$i$i$i58 = ((($391)) + -4|0);
          $393 = $scevgep$i$i$i58;
          $394 = $389;
          $395 = (($393) - ($394))|0;
          $396 = $395 >>> 2;
          $397 = $396 ^ -1;
          $scevgep5$i$i$i59 = (($391) + ($397<<2)|0);
          HEAP32[$63>>2] = $scevgep5$i$i$i59;
         }
         __ZdlPv($389);
        }
        $407 = HEAP32[$6>>2]|0;
        $408 = ($407|0)==(0|0);
        if (!($408)) {
         $409 = HEAP32[$61>>2]|0;
         $410 = ($409|0)==($407|0);
         if (!($410)) {
          $scevgep$i$i$i48 = ((($409)) + -4|0);
          $411 = $scevgep$i$i$i48;
          $412 = $407;
          $413 = (($411) - ($412))|0;
          $414 = $413 >>> 2;
          $415 = $414 ^ -1;
          $scevgep5$i$i$i49 = (($409) + ($415<<2)|0);
          HEAP32[$61>>2] = $scevgep5$i$i$i49;
         }
         __ZdlPv($407);
        }
        $425 = HEAP32[$5>>2]|0;
        $426 = ($425|0)==(0|0);
        if (!($426)) {
         $427 = HEAP32[$59>>2]|0;
         $428 = ($427|0)==($425|0);
         if (!($428)) {
          $scevgep$i$i$i38 = ((($427)) + -4|0);
          $429 = $scevgep$i$i$i38;
          $430 = $425;
          $431 = (($429) - ($430))|0;
          $432 = $431 >>> 2;
          $433 = $432 ^ -1;
          $scevgep5$i$i$i39 = (($427) + ($433<<2)|0);
          HEAP32[$59>>2] = $scevgep5$i$i$i39;
         }
         __ZdlPv($425);
        }
        $$018 = $126;
        STACKTOP = sp;return ($$018|0);
       }
      }
     }
    } while(0);
    if ((label|0) == 82) {
     $244 = ___cxa_find_matching_catch_2()|0;
     $245 = tempRet0;
     $eh$lpad$body122$index12Z2D = $245;$eh$lpad$body122$indexZ2D = $244;
    }
    $246 = HEAP32[$232>>2]|0;HEAP32[$232>>2] = (($246-1)|0);
    $247 = ($246|0)==(1);
    if ($247) {
     __THREW__ = 0;
     invoke_viii(3262,($126|0),1,1);
     $248 = __THREW__; __THREW__ = 0;
     $249 = $248&1;
     if ($249) {
      $452 = ___cxa_find_matching_catch_3(0|0)|0;
      $453 = tempRet0;
      ___clang_call_terminate($452);
      // unreachable;
     } else {
      $$2 = $eh$lpad$body122$index12Z2D;$$222 = $eh$lpad$body122$indexZ2D;
     }
    } else {
     $$2 = $eh$lpad$body122$index12Z2D;$$222 = $eh$lpad$body122$indexZ2D;
    }
   }
  }
 } while(0);
 if ((label|0) == 35) {
  $115 = ___cxa_find_matching_catch_2()|0;
  $116 = tempRet0;
  $eh$lpad$body$index2Z2D = $116;$eh$lpad$body$indexZ2D = $115;
  label = 36;
 }
 if ((label|0) == 36) {
  $$2 = $eh$lpad$body$index2Z2D;$$222 = $eh$lpad$body$indexZ2D;
 }
 $362 = HEAP32[$10>>2]|0;
 $363 = ($362|0)==(0|0);
 if (!($363)) {
  $364 = HEAP32[$69>>2]|0;
  $365 = ($364|0)==($362|0);
  if (!($365)) {
   $scevgep$i$i$i73 = ((($364)) + -4|0);
   $366 = $scevgep$i$i$i73;
   $367 = $362;
   $368 = (($366) - ($367))|0;
   $369 = $368 >>> 2;
   $370 = $369 ^ -1;
   $scevgep5$i$i$i74 = (($364) + ($370<<2)|0);
   HEAP32[$69>>2] = $scevgep5$i$i$i74;
  }
  __ZdlPv($362);
 }
 $380 = HEAP32[$9>>2]|0;
 $381 = ($380|0)==(0|0);
 if (!($381)) {
  $382 = HEAP32[$67>>2]|0;
  $383 = ($382|0)==($380|0);
  if (!($383)) {
   $scevgep$i$i$i63 = ((($382)) + -4|0);
   $384 = $scevgep$i$i$i63;
   $385 = $380;
   $386 = (($384) - ($385))|0;
   $387 = $386 >>> 2;
   $388 = $387 ^ -1;
   $scevgep5$i$i$i64 = (($382) + ($388<<2)|0);
   HEAP32[$67>>2] = $scevgep5$i$i$i64;
  }
  __ZdlPv($380);
 }
 $398 = HEAP32[$8>>2]|0;
 $399 = ($398|0)==(0|0);
 if (!($399)) {
  $400 = HEAP32[$65>>2]|0;
  $401 = ($400|0)==($398|0);
  if (!($401)) {
   $scevgep$i$i$i53 = ((($400)) + -4|0);
   $402 = $scevgep$i$i$i53;
   $403 = $398;
   $404 = (($402) - ($403))|0;
   $405 = $404 >>> 2;
   $406 = $405 ^ -1;
   $scevgep5$i$i$i54 = (($400) + ($406<<2)|0);
   HEAP32[$65>>2] = $scevgep5$i$i$i54;
  }
  __ZdlPv($398);
 }
 $416 = HEAP32[$7>>2]|0;
 $417 = ($416|0)==(0|0);
 if (!($417)) {
  $418 = HEAP32[$63>>2]|0;
  $419 = ($418|0)==($416|0);
  if (!($419)) {
   $scevgep$i$i$i43 = ((($418)) + -4|0);
   $420 = $scevgep$i$i$i43;
   $421 = $416;
   $422 = (($420) - ($421))|0;
   $423 = $422 >>> 2;
   $424 = $423 ^ -1;
   $scevgep5$i$i$i44 = (($418) + ($424<<2)|0);
   HEAP32[$63>>2] = $scevgep5$i$i$i44;
  }
  __ZdlPv($416);
 }
 $434 = HEAP32[$6>>2]|0;
 $435 = ($434|0)==(0|0);
 if (!($435)) {
  $436 = HEAP32[$61>>2]|0;
  $437 = ($436|0)==($434|0);
  if (!($437)) {
   $scevgep$i$i$i33 = ((($436)) + -4|0);
   $438 = $scevgep$i$i$i33;
   $439 = $434;
   $440 = (($438) - ($439))|0;
   $441 = $440 >>> 2;
   $442 = $441 ^ -1;
   $scevgep5$i$i$i34 = (($436) + ($442<<2)|0);
   HEAP32[$61>>2] = $scevgep5$i$i$i34;
  }
  __ZdlPv($434);
 }
 $443 = HEAP32[$5>>2]|0;
 $444 = ($443|0)==(0|0);
 if ($444) {
  ___resumeException($$222|0);
  // unreachable;
 }
 $445 = HEAP32[$59>>2]|0;
 $446 = ($445|0)==($443|0);
 if (!($446)) {
  $scevgep$i$i$i = ((($445)) + -4|0);
  $447 = $scevgep$i$i$i;
  $448 = $443;
  $449 = (($447) - ($448))|0;
  $450 = $449 >>> 2;
  $451 = $450 ^ -1;
  $scevgep5$i$i$i = (($445) + ($451<<2)|0);
  HEAP32[$59>>2] = $scevgep5$i$i$i;
 }
 __ZdlPv($443);
 ___resumeException($$222|0);
 // unreachable;
 return (0)|0;
}
function __ZN3osg14ShaderComposer11composeMainERKNSt3__26vectorIPKNS_6ShaderENS1_9allocatorIS5_EEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i63 = 0, $$0$lcssa = 0, $$015$i$i$i = 0, $$0210 = 0, $$030$i$i = 0, $$1 = 0, $$11 = 0, $$1144 = 0, $$2 = 0, $$7 = 0, $$740 = 0, $$8 = 0, $$841 = 0, $$in$i$i$i = 0, $$phi$trans$insert218 = 0, $$phi$trans$insert222 = 0, $$pre = 0, $$pre$i$i = 0;
 var $$pre$i$i$i = 0, $$pre$phi227Z2D = 0, $$pre$phi231Z2D = 0, $$pre$phi233Z2D = 0, $$pre$phiZ2D = 0, $$pre219 = 0, $$pre221 = 0, $$pre223 = 0, $$pre226 = 0, $$pre230 = 0, $$sroa$0173$0$be = 0, $$sroa$0173$0206 = 0, $$sroa$0184$0$be = 0, $$sroa$0184$0207 = 0, $$sroa$0191$0209 = 0, $10 = 0, $100 = 0.0, $101 = 0, $102 = 0, $103 = 0.0;
 var $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0;
 var $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0;
 var $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0.0, $156 = 0, $157 = 0, $158 = 0;
 var $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0;
 var $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0;
 var $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0;
 var $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0;
 var $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0;
 var $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0;
 var $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0;
 var $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0;
 var $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0;
 var $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0;
 var $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0;
 var $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0;
 var $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0;
 var $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0;
 var $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0;
 var $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0;
 var $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0;
 var $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0;
 var $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0;
 var $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, $eh$lpad$body104$index16Z2D = 0, $eh$lpad$body104$indexZ2D = 0, $eh$lpad$body51$index7Z2D = 0, $eh$lpad$body51$indexZ2D = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(112|0);
 $2 = sp + 108|0;
 $3 = sp + 104|0;
 $4 = sp + 100|0;
 $5 = sp + 96|0;
 $6 = sp + 92|0;
 $7 = sp + 88|0;
 $8 = sp + 84|0;
 $9 = sp + 72|0;
 $10 = sp + 60|0;
 $11 = sp + 48|0;
 $12 = sp + 36|0;
 $13 = sp + 24|0;
 $14 = sp + 12|0;
 $15 = sp;
 $16 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
 do {
  if ($16) {
   $17 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
   $18 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($17,159829,53)|0);
   $19 = ((($1)) + 4|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = HEAP32[$1>>2]|0;
   $22 = (($20) - ($21))|0;
   $23 = $22 >> 2;
   $24 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($18,$23)|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = ((($25)) + -12|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = (($24) + ($27)|0);
   __ZNKSt3__28ios_base6getlocEv($8,$28);
   __THREW__ = 0;
   $29 = (invoke_iii(3255,($8|0),(215188|0))|0);
   $30 = __THREW__; __THREW__ = 0;
   $31 = $30&1;
   if (!($31)) {
    $32 = HEAP32[$29>>2]|0;
    $33 = ((($32)) + 28|0);
    $34 = HEAP32[$33>>2]|0;
    __THREW__ = 0;
    $35 = (invoke_iii($34|0,($29|0),10)|0);
    $36 = __THREW__; __THREW__ = 0;
    $37 = $36&1;
    if (!($37)) {
     __ZNSt3__26localeD2Ev($8);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($24,$35)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($24)|0);
     $$pre$phi227Z2D = $19;
     break;
    }
   }
   $38 = ___cxa_find_matching_catch_2()|0;
   $39 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($8|0));
   $40 = __THREW__; __THREW__ = 0;
   $41 = $40&1;
   if ($41) {
    $42 = ___cxa_find_matching_catch_3(0|0)|0;
    $43 = tempRet0;
    ___clang_call_terminate($42);
    // unreachable;
   } else {
    ___resumeException($38|0);
    // unreachable;
   }
  } else {
   $$pre226 = ((($1)) + 4|0);
   $$pre$phi227Z2D = $$pre226;
  }
 } while(0);
 $44 = ((($9)) + 4|0);
 HEAP32[$44>>2] = 0;
 $45 = ((($9)) + 8|0);
 HEAP32[$45>>2] = 0;
 $46 = ((($9)) + 4|0);
 HEAP32[$9>>2] = $46;
 $47 = HEAP32[$1>>2]|0;
 $48 = HEAP32[$$pre$phi227Z2D>>2]|0;
 $49 = ($47|0)==($48|0);
 L12: do {
  if ($49) {
   $$0$lcssa = -1;$152 = $46;
  } else {
   $$0210 = -1;$$sroa$0191$0209 = $47;
   L14: while(1) {
    $50 = HEAP32[$$sroa$0191$0209>>2]|0;
    $51 = ($$0210|0)==(-1);
    $52 = ((($50)) + 32|0);
    $53 = HEAP32[$52>>2]|0;
    if ($51) {
     $$1 = $53;
     label = 28;
    } else {
     $56 = ($$0210|0)==($53|0);
     if ($56) {
      $$1 = $$0210;
      label = 28;
     } else {
      __THREW__ = 0;
      $57 = (invoke_ii(3265,3)|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 12;
       break;
      }
      if ($57) {
       __THREW__ = 0;
       $60 = (invoke_ii(3266,3)|0);
       $61 = __THREW__; __THREW__ = 0;
       $62 = $61&1;
       if ($62) {
        label = 12;
        break;
       }
       __THREW__ = 0;
       $63 = (invoke_iiii(3267,($60|0),(159883|0),83)|0);
       $64 = __THREW__; __THREW__ = 0;
       $65 = $64&1;
       if ($65) {
        label = 12;
        break;
       }
       $66 = HEAP32[$63>>2]|0;
       $67 = ((($66)) + -12|0);
       $68 = HEAP32[$67>>2]|0;
       $69 = (($63) + ($68)|0);
       __THREW__ = 0;
       invoke_vii(3257,($7|0),($69|0));
       $70 = __THREW__; __THREW__ = 0;
       $71 = $70&1;
       if ($71) {
        label = 12;
        break;
       }
       __THREW__ = 0;
       $72 = (invoke_iii(3255,($7|0),(215188|0))|0);
       $73 = __THREW__; __THREW__ = 0;
       $74 = $73&1;
       if ($74) {
        label = 22;
        break;
       }
       $75 = HEAP32[$72>>2]|0;
       $76 = ((($75)) + 28|0);
       $77 = HEAP32[$76>>2]|0;
       __THREW__ = 0;
       $78 = (invoke_iii($77|0,($72|0),10)|0);
       $79 = __THREW__; __THREW__ = 0;
       $80 = $79&1;
       if ($80) {
        label = 22;
        break;
       }
       __THREW__ = 0;
       invoke_vi(3263,($7|0));
       $87 = __THREW__; __THREW__ = 0;
       $88 = $87&1;
       if ($88) {
        label = 12;
        break;
       }
       __THREW__ = 0;
       (invoke_iii(3268,($63|0),($78|0))|0);
       $89 = __THREW__; __THREW__ = 0;
       $90 = $89&1;
       if ($90) {
        label = 12;
        break;
       }
       __THREW__ = 0;
       (invoke_ii(3269,($63|0))|0);
       $91 = __THREW__; __THREW__ = 0;
       $92 = $91&1;
       if ($92) {
        label = 12;
        break;
       } else {
        $$2 = $$0210;
       }
      } else {
       $$2 = $$0210;
      }
     }
    }
    if ((label|0) == 28) {
     label = 0;
     $93 = ((($50)) + 64|0);
     $94 = HEAP32[$93>>2]|0;
     $95 = ((($50)) + 68|0);
     $96 = ($94|0)==($95|0);
     if ($96) {
      $$2 = $$1;
     } else {
      $$sroa$0184$0207 = $94;
      while(1) {
       $97 = ((($$sroa$0184$0207)) + 16|0);
       $98 = HEAP32[$46>>2]|0;
       $99 = ($98|0)==(0|0);
       do {
        if ($99) {
         $$pre$i$i = HEAP32[$97>>2]|0;
         $$015$i$i$i = $46;$$030$i$i = $46;$114 = $$pre$i$i;
        } else {
         $100 = +HEAPF32[$97>>2];
         $101 = (HEAPF32[tempDoublePtr>>2]=$100,HEAP32[tempDoublePtr>>2]|0);
         $$0$i$i$i = $98;
         while(1) {
          $102 = ((($$0$i$i$i)) + 16|0);
          $103 = +HEAPF32[$102>>2];
          $104 = $100 < $103;
          if ($104) {
           $105 = HEAP32[$$0$i$i$i>>2]|0;
           $106 = ($105|0)==(0|0);
           if ($106) {
            label = 34;
            break;
           } else {
            $$in$i$i$i = $105;
           }
          } else {
           $107 = ((($$0$i$i$i)) + 4|0);
           $108 = HEAP32[$107>>2]|0;
           $109 = ($108|0)==(0|0);
           if ($109) {
            label = 36;
            break;
           } else {
            $$in$i$i$i = $108;
           }
          }
          $$0$i$i$i = $$in$i$i$i;
         }
         if ((label|0) == 34) {
          label = 0;
          $$015$i$i$i = $$0$i$i$i;$$030$i$i = $$0$i$i$i;$114 = $101;
          break;
         }
         else if ((label|0) == 36) {
          label = 0;
          $$015$i$i$i = $107;$$030$i$i = $$0$i$i$i;$114 = $101;
          break;
         }
        }
       } while(0);
       __THREW__ = 0;
       $110 = (invoke_ii(3276,32)|0);
       $111 = __THREW__; __THREW__ = 0;
       $112 = $111&1;
       if ($112) {
        label = 49;
        break L14;
       }
       $113 = ((($110)) + 16|0);
       HEAP32[$113>>2] = $114;
       $115 = ((($110)) + 20|0);
       $116 = ((($$sroa$0184$0207)) + 20|0);
       __THREW__ = 0;
       invoke_vii(3457,($115|0),($116|0));
       $117 = __THREW__; __THREW__ = 0;
       $118 = $117&1;
       if ($118) {
        label = 40;
        break L14;
       }
       HEAP32[$110>>2] = 0;
       $121 = ((($110)) + 4|0);
       HEAP32[$121>>2] = 0;
       $122 = ((($110)) + 8|0);
       HEAP32[$122>>2] = $$030$i$i;
       HEAP32[$$015$i$i$i>>2] = $110;
       $123 = HEAP32[$9>>2]|0;
       $124 = HEAP32[$123>>2]|0;
       $125 = ($124|0)==(0|0);
       if ($125) {
        $128 = $110;
       } else {
        $126 = $124;
        HEAP32[$9>>2] = $126;
        $$pre$i$i$i = HEAP32[$$015$i$i$i>>2]|0;
        $128 = $$pre$i$i$i;
       }
       $127 = HEAP32[$44>>2]|0;
       __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($127,$128);
       $129 = HEAP32[$45>>2]|0;
       $130 = (($129) + 1)|0;
       HEAP32[$45>>2] = $130;
       $131 = ((($$sroa$0184$0207)) + 4|0);
       $132 = HEAP32[$131>>2]|0;
       $133 = ($132|0)==(0|0);
       if ($133) {
        $134 = ((($$sroa$0184$0207)) + 8|0);
        $135 = HEAP32[$134>>2]|0;
        $136 = HEAP32[$135>>2]|0;
        $137 = ($136|0)==($$sroa$0184$0207|0);
        if ($137) {
         $$sroa$0184$0$be = $135;
        } else {
         $142 = $134;
         while(1) {
          $141 = HEAP32[$142>>2]|0;
          $143 = ((($141)) + 8|0);
          $144 = HEAP32[$143>>2]|0;
          $145 = HEAP32[$144>>2]|0;
          $146 = ($145|0)==($141|0);
          if ($146) {
           $$sroa$0184$0$be = $144;
           break;
          } else {
           $142 = $143;
          }
         }
        }
       } else {
        $$0$i$i$i$i = $132;
        while(1) {
         $139 = HEAP32[$$0$i$i$i$i>>2]|0;
         $140 = ($139|0)==(0|0);
         if ($140) {
          break;
         } else {
          $$0$i$i$i$i = $139;
         }
        }
        $$sroa$0184$0$be = $$0$i$i$i$i;
       }
       $138 = ($$sroa$0184$0$be|0)==($95|0);
       if ($138) {
        $$2 = $$1;
        break;
       } else {
        $$sroa$0184$0207 = $$sroa$0184$0$be;
       }
      }
     }
    }
    $149 = ((($$sroa$0191$0209)) + 4|0);
    $150 = HEAP32[$$pre$phi227Z2D>>2]|0;
    $151 = ($149|0)==($150|0);
    if ($151) {
     label = 52;
     break;
    } else {
     $$0210 = $$2;$$sroa$0191$0209 = $149;
    }
   }
   do {
    if ((label|0) == 12) {
     $54 = ___cxa_find_matching_catch_2()|0;
     $55 = tempRet0;
     $eh$lpad$body$index2Z2D = $55;$eh$lpad$body$indexZ2D = $54;
     label = 13;
    }
    else if ((label|0) == 22) {
     $81 = ___cxa_find_matching_catch_2()|0;
     $82 = tempRet0;
     __THREW__ = 0;
     invoke_vi(3263,($7|0));
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if ($84) {
      $85 = ___cxa_find_matching_catch_3(0|0)|0;
      $86 = tempRet0;
      ___clang_call_terminate($85);
      // unreachable;
     } else {
      $eh$lpad$body$index2Z2D = $82;$eh$lpad$body$indexZ2D = $81;
      label = 13;
      break;
     }
    }
    else if ((label|0) == 40) {
     $119 = ___cxa_find_matching_catch_2()|0;
     $120 = tempRet0;
     __ZdlPv($110);
     $eh$lpad$body51$index7Z2D = $120;$eh$lpad$body51$indexZ2D = $119;
     label = 50;
    }
    else if ((label|0) == 49) {
     $147 = ___cxa_find_matching_catch_2()|0;
     $148 = tempRet0;
     $eh$lpad$body51$index7Z2D = $148;$eh$lpad$body51$indexZ2D = $147;
     label = 50;
    }
    else if ((label|0) == 52) {
     $$pre = HEAP32[$9>>2]|0;
     $$0$lcssa = $$2;$152 = $$pre;
     break L12;
    }
   } while(0);
   if ((label|0) == 13) {
    $$11 = $eh$lpad$body$indexZ2D;$$1144 = $eh$lpad$body$index2Z2D;$$pre$phiZ2D = $46;
    $510 = HEAP32[$$pre$phiZ2D>>2]|0;
    __ZNSt3__26__treeINS_12__value_typeIfNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEEENS_19__map_value_compareIfS8_NS_4lessIfEELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($9,$510);
    ___resumeException($$11|0);
    // unreachable;
   }
   else if ((label|0) == 50) {
    $$11 = $eh$lpad$body51$indexZ2D;$$1144 = $eh$lpad$body51$index7Z2D;$$pre$phiZ2D = $46;
    $510 = HEAP32[$$pre$phiZ2D>>2]|0;
    __ZNSt3__26__treeINS_12__value_typeIfNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEEENS_19__map_value_compareIfS8_NS_4lessIfEELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($9,$510);
    ___resumeException($$11|0);
    // unreachable;
   }
  }
 } while(0);
 ;HEAP32[$10>>2]=0|0;HEAP32[$10+4>>2]=0|0;HEAP32[$10+8>>2]=0|0;
 ;HEAP32[$11>>2]=0|0;HEAP32[$11+4>>2]=0|0;HEAP32[$11+8>>2]=0|0;
 ;HEAP32[$12>>2]=0|0;HEAP32[$12+4>>2]=0|0;HEAP32[$12+8>>2]=0|0;
 $153 = ($152|0)==($46|0);
 do {
  if ($153) {
   $$pre230 = ((($10)) + 11|0);
   $$pre$phi231Z2D = $$pre230;$$pre$phi233Z2D = $10;$202 = 0;$204 = 0;$207 = 0;
   label = 68;
  } else {
   $$sroa$0173$0206 = $152;
   L76: while(1) {
    $154 = ((($$sroa$0173$0206)) + 16|0);
    $155 = +HEAPF32[$154>>2];
    $156 = $155 < 0.0;
    do {
     if ($156) {
      $157 = ((($$sroa$0173$0206)) + 20|0);
      $158 = ((($157)) + 11|0);
      $159 = HEAP8[$158>>0]|0;
      $160 = ($159<<24>>24)<(0);
      $161 = HEAP32[$157>>2]|0;
      $162 = $160 ? $161 : $157;
      $163 = ((($$sroa$0173$0206)) + 24|0);
      $164 = HEAP32[$163>>2]|0;
      $165 = $159&255;
      $166 = $160 ? $164 : $165;
      __THREW__ = 0;
      (invoke_iiii(3544,($10|0),($162|0),($166|0))|0);
      $167 = __THREW__; __THREW__ = 0;
      $168 = $167&1;
      if ($168) {
       label = 66;
       break L76;
      }
     } else {
      $169 = !($155 <= 1.0);
      $170 = ((($$sroa$0173$0206)) + 20|0);
      $171 = ((($170)) + 11|0);
      $172 = HEAP8[$171>>0]|0;
      $173 = ($172<<24>>24)<(0);
      $174 = HEAP32[$170>>2]|0;
      $175 = $173 ? $174 : $170;
      $176 = ((($$sroa$0173$0206)) + 24|0);
      $177 = HEAP32[$176>>2]|0;
      $178 = $172&255;
      $179 = $173 ? $177 : $178;
      if ($169) {
       __THREW__ = 0;
       (invoke_iiii(3544,($12|0),($175|0),($179|0))|0);
       $182 = __THREW__; __THREW__ = 0;
       $183 = $182&1;
       if ($183) {
        label = 66;
        break L76;
       } else {
        break;
       }
      } else {
       __THREW__ = 0;
       (invoke_iiii(3544,($11|0),($175|0),($179|0))|0);
       $180 = __THREW__; __THREW__ = 0;
       $181 = $180&1;
       if ($181) {
        label = 66;
        break L76;
       } else {
        break;
       }
      }
     }
    } while(0);
    $184 = ((($$sroa$0173$0206)) + 4|0);
    $185 = HEAP32[$184>>2]|0;
    $186 = ($185|0)==(0|0);
    if ($186) {
     $187 = ((($$sroa$0173$0206)) + 8|0);
     $188 = HEAP32[$187>>2]|0;
     $189 = HEAP32[$188>>2]|0;
     $190 = ($189|0)==($$sroa$0173$0206|0);
     if ($190) {
      $$sroa$0173$0$be = $188;
     } else {
      $195 = $187;
      while(1) {
       $194 = HEAP32[$195>>2]|0;
       $196 = ((($194)) + 8|0);
       $197 = HEAP32[$196>>2]|0;
       $198 = HEAP32[$197>>2]|0;
       $199 = ($198|0)==($194|0);
       if ($199) {
        $$sroa$0173$0$be = $197;
        break;
       } else {
        $195 = $196;
       }
      }
     }
    } else {
     $$0$i$i$i$i63 = $185;
     while(1) {
      $192 = HEAP32[$$0$i$i$i$i63>>2]|0;
      $193 = ($192|0)==(0|0);
      if ($193) {
       break;
      } else {
       $$0$i$i$i$i63 = $192;
      }
     }
     $$sroa$0173$0$be = $$0$i$i$i$i63;
    }
    $191 = ($$sroa$0173$0$be|0)==($46|0);
    if ($191) {
     label = 67;
     break;
    } else {
     $$sroa$0173$0206 = $$sroa$0173$0$be;
    }
   }
   if ((label|0) == 66) {
    $200 = ___cxa_find_matching_catch_2()|0;
    $201 = tempRet0;
    $$8 = $200;$$841 = $201;
    break;
   }
   else if ((label|0) == 67) {
    $$phi$trans$insert218 = ((($10)) + 11|0);
    $$pre219 = HEAP8[$$phi$trans$insert218>>0]|0;
    $$pre221 = HEAP32[$10>>2]|0;
    $$phi$trans$insert222 = ((($10)) + 4|0);
    $$pre223 = HEAP32[$$phi$trans$insert222>>2]|0;
    $$pre$phi231Z2D = $$phi$trans$insert218;$$pre$phi233Z2D = $10;$202 = $$pre219;$204 = $$pre221;$207 = $$pre223;
    label = 68;
    break;
   }
  }
 } while(0);
 if ((label|0) == 68) {
  ;HEAP32[$13>>2]=0|0;HEAP32[$13+4>>2]=0|0;HEAP32[$13+8>>2]=0|0;
  $203 = ($202<<24>>24)<(0);
  $205 = $203 ? $204 : $10;
  $206 = $202&255;
  $208 = $203 ? $207 : $206;
  __THREW__ = 0;
  (invoke_iiii(3544,($13|0),($205|0),($208|0))|0);
  $209 = __THREW__; __THREW__ = 0;
  $210 = $209&1;
  L98: do {
   if ($210) {
    label = 95;
   } else {
    __THREW__ = 0;
    $211 = (invoke_ii(3276,32)|0);
    $212 = __THREW__; __THREW__ = 0;
    $213 = $212&1;
    if ($213) {
     $301 = ___cxa_find_matching_catch_2()|0;
     $302 = tempRet0;
     $$7 = $301;$$740 = $302;
     break;
    }
    dest=$211; src=159967; stop=dest+16|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
    $214 = ((($211)) + 16|0);
    HEAP8[$214>>0] = 0;
    __THREW__ = 0;
    (invoke_iiii(3544,($13|0),($211|0),16)|0);
    $215 = __THREW__; __THREW__ = 0;
    $216 = $215&1;
    if ($216) {
     $303 = ___cxa_find_matching_catch_2()|0;
     $304 = tempRet0;
     __ZdlPv($211);
     $$7 = $303;$$740 = $304;
     break;
    }
    __ZdlPv($211);
    ;HEAP32[$14>>2]=0|0;HEAP32[$14+4>>2]=0|0;HEAP32[$14+8>>2]=0|0;
    $217 = ((($14)) + 11|0);
    HEAP8[$217>>0] = 2;
    HEAP16[$14>>1] = 2683;
    $218 = ((($14)) + 2|0);
    HEAP8[$218>>0] = 0;
    __THREW__ = 0;
    (invoke_iiii(3544,($13|0),($14|0),2)|0);
    $219 = __THREW__; __THREW__ = 0;
    $220 = $219&1;
    if ($220) {
     $305 = ___cxa_find_matching_catch_2()|0;
     $306 = tempRet0;
     $307 = HEAP8[$217>>0]|0;
     $308 = ($307<<24>>24)<(0);
     if ($308) {
      $309 = HEAP32[$14>>2]|0;
      __ZdlPv($309);
     }
     $$7 = $305;$$740 = $306;
     break;
    }
    $221 = HEAP8[$217>>0]|0;
    $222 = ($221<<24>>24)<(0);
    if ($222) {
     $223 = HEAP32[$14>>2]|0;
     __ZdlPv($223);
    }
    $224 = ((($11)) + 11|0);
    $225 = HEAP8[$224>>0]|0;
    $226 = ($225<<24>>24)<(0);
    $227 = HEAP32[$11>>2]|0;
    $228 = $226 ? $227 : $11;
    $229 = ((($11)) + 4|0);
    $230 = HEAP32[$229>>2]|0;
    $231 = $225&255;
    $232 = $226 ? $230 : $231;
    __THREW__ = 0;
    (invoke_iiii(3544,($13|0),($228|0),($232|0))|0);
    $233 = __THREW__; __THREW__ = 0;
    $234 = $233&1;
    if ($234) {
     label = 95;
    } else {
     ;HEAP32[$15>>2]=0|0;HEAP32[$15+4>>2]=0|0;HEAP32[$15+8>>2]=0|0;
     $235 = ((($15)) + 11|0);
     HEAP8[$235>>0] = 2;
     HEAP16[$15>>1] = 2685;
     $236 = ((($15)) + 2|0);
     HEAP8[$236>>0] = 0;
     __THREW__ = 0;
     (invoke_iiii(3544,($13|0),($15|0),2)|0);
     $237 = __THREW__; __THREW__ = 0;
     $238 = $237&1;
     if ($238) {
      $310 = ___cxa_find_matching_catch_2()|0;
      $311 = tempRet0;
      $312 = HEAP8[$235>>0]|0;
      $313 = ($312<<24>>24)<(0);
      if ($313) {
       $314 = HEAP32[$15>>2]|0;
       __ZdlPv($314);
      }
      $$7 = $310;$$740 = $311;
      break;
     }
     $239 = HEAP8[$235>>0]|0;
     $240 = ($239<<24>>24)<(0);
     if ($240) {
      $241 = HEAP32[$15>>2]|0;
      __ZdlPv($241);
     }
     $242 = ((($12)) + 11|0);
     $243 = HEAP8[$242>>0]|0;
     $244 = ($243<<24>>24)<(0);
     $245 = HEAP32[$12>>2]|0;
     $246 = $244 ? $245 : $12;
     $247 = ((($12)) + 4|0);
     $248 = HEAP32[$247>>2]|0;
     $249 = $243&255;
     $250 = $244 ? $248 : $249;
     __THREW__ = 0;
     (invoke_iiii(3544,($13|0),($246|0),($250|0))|0);
     $251 = __THREW__; __THREW__ = 0;
     $252 = $251&1;
     if ($252) {
      label = 95;
     } else {
      __THREW__ = 0;
      $253 = (invoke_ii(3276,128)|0);
      $254 = __THREW__; __THREW__ = 0;
      $255 = $254&1;
      if ($255) {
       label = 95;
      } else {
       __THREW__ = 0;
       invoke_viii(3619,($253|0),($$0$lcssa|0),($13|0));
       $256 = __THREW__; __THREW__ = 0;
       $257 = $256&1;
       if ($257) {
        $315 = ___cxa_find_matching_catch_2()|0;
        $316 = tempRet0;
        __ZdlPv($253);
        $$7 = $315;$$740 = $316;
        break;
       }
       $258 = ((($253)) + 8|0);
       $259 = HEAP32[$258>>2]|0;HEAP32[$258>>2] = (($259+1)|0);
       __THREW__ = 0;
       $260 = (invoke_ii(3265,3)|0);
       $261 = __THREW__; __THREW__ = 0;
       $262 = $261&1;
       L130: do {
        if ($262) {
         label = 105;
        } else {
         L132: do {
          if ($260) {
           __THREW__ = 0;
           $263 = (invoke_ii(3266,3)|0);
           $264 = __THREW__; __THREW__ = 0;
           $265 = $264&1;
           if ($265) {
            label = 105;
            break L130;
           }
           __THREW__ = 0;
           $266 = (invoke_iiii(3267,($263|0),(159984|0),7)|0);
           $267 = __THREW__; __THREW__ = 0;
           $268 = $267&1;
           if ($268) {
            label = 105;
            break L130;
           }
           __THREW__ = 0;
           $269 = (invoke_iii(3863,($266|0),($$0$lcssa|0))|0);
           $270 = __THREW__; __THREW__ = 0;
           $271 = $270&1;
           if ($271) {
            label = 105;
            break L130;
           }
           $272 = HEAP32[$269>>2]|0;
           $273 = ((($272)) + -12|0);
           $274 = HEAP32[$273>>2]|0;
           $275 = (($269) + ($274)|0);
           __THREW__ = 0;
           invoke_vii(3257,($6|0),($275|0));
           $276 = __THREW__; __THREW__ = 0;
           $277 = $276&1;
           if ($277) {
            label = 105;
            break L130;
           }
           __THREW__ = 0;
           $278 = (invoke_iii(3255,($6|0),(215188|0))|0);
           $279 = __THREW__; __THREW__ = 0;
           $280 = $279&1;
           do {
            if (!($280)) {
             $281 = HEAP32[$278>>2]|0;
             $282 = ((($281)) + 28|0);
             $283 = HEAP32[$282>>2]|0;
             __THREW__ = 0;
             $284 = (invoke_iii($283|0,($278|0),10)|0);
             $285 = __THREW__; __THREW__ = 0;
             $286 = $285&1;
             if ($286) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3263,($6|0));
             $293 = __THREW__; __THREW__ = 0;
             $294 = $293&1;
             if ($294) {
              label = 105;
              break L130;
             }
             __THREW__ = 0;
             (invoke_iii(3268,($269|0),($284|0))|0);
             $295 = __THREW__; __THREW__ = 0;
             $296 = $295&1;
             if ($296) {
              label = 105;
              break L130;
             }
             __THREW__ = 0;
             (invoke_ii(3269,($269|0))|0);
             $297 = __THREW__; __THREW__ = 0;
             $298 = $297&1;
             if ($298) {
              label = 105;
              break L130;
             } else {
              break L132;
             }
            }
           } while(0);
           $287 = ___cxa_find_matching_catch_2()|0;
           $288 = tempRet0;
           __THREW__ = 0;
           invoke_vi(3263,($6|0));
           $289 = __THREW__; __THREW__ = 0;
           $290 = $289&1;
           if ($290) {
            $291 = ___cxa_find_matching_catch_3(0|0)|0;
            $292 = tempRet0;
            ___clang_call_terminate($291);
            // unreachable;
           } else {
            $eh$lpad$body104$index16Z2D = $288;$eh$lpad$body104$indexZ2D = $287;
            break L130;
           }
          }
         } while(0);
         __THREW__ = 0;
         $323 = (invoke_ii(3265,3)|0);
         $324 = __THREW__; __THREW__ = 0;
         $325 = $324&1;
         if ($325) {
          label = 105;
         } else {
          L149: do {
           if ($323) {
            __THREW__ = 0;
            $326 = (invoke_ii(3266,3)|0);
            $327 = __THREW__; __THREW__ = 0;
            $328 = $327&1;
            if ($328) {
             label = 105;
             break L130;
            }
            __THREW__ = 0;
            $329 = (invoke_iiii(3267,($326|0),(159992|0),15)|0);
            $330 = __THREW__; __THREW__ = 0;
            $331 = $330&1;
            if ($331) {
             label = 105;
             break L130;
            }
            $332 = HEAP32[$329>>2]|0;
            $333 = ((($332)) + -12|0);
            $334 = HEAP32[$333>>2]|0;
            $335 = (($329) + ($334)|0);
            __THREW__ = 0;
            invoke_vii(3257,($5|0),($335|0));
            $336 = __THREW__; __THREW__ = 0;
            $337 = $336&1;
            if ($337) {
             label = 105;
             break L130;
            }
            __THREW__ = 0;
            $338 = (invoke_iii(3255,($5|0),(215188|0))|0);
            $339 = __THREW__; __THREW__ = 0;
            $340 = $339&1;
            do {
             if (!($340)) {
              $341 = HEAP32[$338>>2]|0;
              $342 = ((($341)) + 28|0);
              $343 = HEAP32[$342>>2]|0;
              __THREW__ = 0;
              $344 = (invoke_iii($343|0,($338|0),10)|0);
              $345 = __THREW__; __THREW__ = 0;
              $346 = $345&1;
              if ($346) {
               break;
              }
              __THREW__ = 0;
              invoke_vi(3263,($5|0));
              $353 = __THREW__; __THREW__ = 0;
              $354 = $353&1;
              if ($354) {
               label = 105;
               break L130;
              }
              __THREW__ = 0;
              (invoke_iii(3268,($329|0),($344|0))|0);
              $355 = __THREW__; __THREW__ = 0;
              $356 = $355&1;
              if ($356) {
               label = 105;
               break L130;
              }
              __THREW__ = 0;
              (invoke_ii(3269,($329|0))|0);
              $357 = __THREW__; __THREW__ = 0;
              $358 = $357&1;
              if ($358) {
               label = 105;
               break L130;
              }
              $359 = ((($13)) + 11|0);
              $360 = HEAP8[$359>>0]|0;
              $361 = ($360<<24>>24)<(0);
              $362 = HEAP32[$13>>2]|0;
              $363 = $361 ? $362 : $13;
              $364 = ((($13)) + 4|0);
              $365 = HEAP32[$364>>2]|0;
              $366 = $360&255;
              $367 = $361 ? $365 : $366;
              __THREW__ = 0;
              $368 = (invoke_iiii(3267,($329|0),($363|0),($367|0))|0);
              $369 = __THREW__; __THREW__ = 0;
              $370 = $369&1;
              if ($370) {
               label = 105;
               break L130;
              }
              $371 = HEAP32[$368>>2]|0;
              $372 = ((($371)) + -12|0);
              $373 = HEAP32[$372>>2]|0;
              $374 = (($368) + ($373)|0);
              __THREW__ = 0;
              invoke_vii(3257,($4|0),($374|0));
              $375 = __THREW__; __THREW__ = 0;
              $376 = $375&1;
              if ($376) {
               label = 105;
               break L130;
              }
              __THREW__ = 0;
              $377 = (invoke_iii(3255,($4|0),(215188|0))|0);
              $378 = __THREW__; __THREW__ = 0;
              $379 = $378&1;
              do {
               if (!($379)) {
                $380 = HEAP32[$377>>2]|0;
                $381 = ((($380)) + 28|0);
                $382 = HEAP32[$381>>2]|0;
                __THREW__ = 0;
                $383 = (invoke_iii($382|0,($377|0),10)|0);
                $384 = __THREW__; __THREW__ = 0;
                $385 = $384&1;
                if ($385) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3263,($4|0));
                $392 = __THREW__; __THREW__ = 0;
                $393 = $392&1;
                if ($393) {
                 label = 105;
                 break L130;
                }
                __THREW__ = 0;
                (invoke_iii(3268,($368|0),($383|0))|0);
                $394 = __THREW__; __THREW__ = 0;
                $395 = $394&1;
                if ($395) {
                 label = 105;
                 break L130;
                }
                __THREW__ = 0;
                (invoke_ii(3269,($368|0))|0);
                $396 = __THREW__; __THREW__ = 0;
                $397 = $396&1;
                if ($397) {
                 label = 105;
                 break L130;
                } else {
                 break L149;
                }
               }
              } while(0);
              $386 = ___cxa_find_matching_catch_2()|0;
              $387 = tempRet0;
              __THREW__ = 0;
              invoke_vi(3263,($4|0));
              $388 = __THREW__; __THREW__ = 0;
              $389 = $388&1;
              if ($389) {
               $390 = ___cxa_find_matching_catch_3(0|0)|0;
               $391 = tempRet0;
               ___clang_call_terminate($390);
               // unreachable;
              } else {
               $eh$lpad$body104$index16Z2D = $387;$eh$lpad$body104$indexZ2D = $386;
               break L130;
              }
             }
            } while(0);
            $347 = ___cxa_find_matching_catch_2()|0;
            $348 = tempRet0;
            __THREW__ = 0;
            invoke_vi(3263,($5|0));
            $349 = __THREW__; __THREW__ = 0;
            $350 = $349&1;
            if ($350) {
             $351 = ___cxa_find_matching_catch_3(0|0)|0;
             $352 = tempRet0;
             ___clang_call_terminate($351);
             // unreachable;
            } else {
             $eh$lpad$body104$index16Z2D = $348;$eh$lpad$body104$indexZ2D = $347;
             break L130;
            }
           }
          } while(0);
          __THREW__ = 0;
          $398 = (invoke_ii(3265,3)|0);
          $399 = __THREW__; __THREW__ = 0;
          $400 = $399&1;
          if ($400) {
           label = 105;
           break;
          }
          L177: do {
           if ($398) {
            __THREW__ = 0;
            $401 = (invoke_ii(3266,3)|0);
            $402 = __THREW__; __THREW__ = 0;
            $403 = $402&1;
            if ($403) {
             label = 105;
             break L130;
            }
            __THREW__ = 0;
            $404 = (invoke_iiii(3267,($401|0),(160008|0),43)|0);
            $405 = __THREW__; __THREW__ = 0;
            $406 = $405&1;
            if ($406) {
             label = 105;
             break L130;
            }
            $407 = HEAP32[$404>>2]|0;
            $408 = ((($407)) + -12|0);
            $409 = HEAP32[$408>>2]|0;
            $410 = (($404) + ($409)|0);
            __THREW__ = 0;
            invoke_vii(3257,($3|0),($410|0));
            $411 = __THREW__; __THREW__ = 0;
            $412 = $411&1;
            if ($412) {
             label = 105;
             break L130;
            }
            __THREW__ = 0;
            $413 = (invoke_iii(3255,($3|0),(215188|0))|0);
            $414 = __THREW__; __THREW__ = 0;
            $415 = $414&1;
            do {
             if (!($415)) {
              $416 = HEAP32[$413>>2]|0;
              $417 = ((($416)) + 28|0);
              $418 = HEAP32[$417>>2]|0;
              __THREW__ = 0;
              $419 = (invoke_iii($418|0,($413|0),10)|0);
              $420 = __THREW__; __THREW__ = 0;
              $421 = $420&1;
              if ($421) {
               break;
              }
              __THREW__ = 0;
              invoke_vi(3263,($3|0));
              $428 = __THREW__; __THREW__ = 0;
              $429 = $428&1;
              if ($429) {
               label = 105;
               break L130;
              }
              __THREW__ = 0;
              (invoke_iii(3268,($404|0),($419|0))|0);
              $430 = __THREW__; __THREW__ = 0;
              $431 = $430&1;
              if ($431) {
               label = 105;
               break L130;
              }
              __THREW__ = 0;
              (invoke_ii(3269,($404|0))|0);
              $432 = __THREW__; __THREW__ = 0;
              $433 = $432&1;
              if ($433) {
               label = 105;
               break L130;
              }
              $434 = HEAP32[$404>>2]|0;
              $435 = ((($434)) + -12|0);
              $436 = HEAP32[$435>>2]|0;
              $437 = (($404) + ($436)|0);
              __THREW__ = 0;
              invoke_vii(3257,($2|0),($437|0));
              $438 = __THREW__; __THREW__ = 0;
              $439 = $438&1;
              if ($439) {
               label = 105;
               break L130;
              }
              __THREW__ = 0;
              $440 = (invoke_iii(3255,($2|0),(215188|0))|0);
              $441 = __THREW__; __THREW__ = 0;
              $442 = $441&1;
              do {
               if (!($442)) {
                $443 = HEAP32[$440>>2]|0;
                $444 = ((($443)) + 28|0);
                $445 = HEAP32[$444>>2]|0;
                __THREW__ = 0;
                $446 = (invoke_iii($445|0,($440|0),10)|0);
                $447 = __THREW__; __THREW__ = 0;
                $448 = $447&1;
                if ($448) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3263,($2|0));
                $455 = __THREW__; __THREW__ = 0;
                $456 = $455&1;
                if ($456) {
                 label = 105;
                 break L130;
                }
                __THREW__ = 0;
                (invoke_iii(3268,($404|0),($446|0))|0);
                $457 = __THREW__; __THREW__ = 0;
                $458 = $457&1;
                if ($458) {
                 label = 105;
                 break L130;
                }
                __THREW__ = 0;
                (invoke_ii(3269,($404|0))|0);
                $459 = __THREW__; __THREW__ = 0;
                $460 = $459&1;
                if ($460) {
                 label = 105;
                 break L130;
                } else {
                 break L177;
                }
               }
              } while(0);
              $449 = ___cxa_find_matching_catch_2()|0;
              $450 = tempRet0;
              __THREW__ = 0;
              invoke_vi(3263,($2|0));
              $451 = __THREW__; __THREW__ = 0;
              $452 = $451&1;
              if ($452) {
               $453 = ___cxa_find_matching_catch_3(0|0)|0;
               $454 = tempRet0;
               ___clang_call_terminate($453);
               // unreachable;
              } else {
               $eh$lpad$body104$index16Z2D = $450;$eh$lpad$body104$indexZ2D = $449;
               break L130;
              }
             }
            } while(0);
            $422 = ___cxa_find_matching_catch_2()|0;
            $423 = tempRet0;
            __THREW__ = 0;
            invoke_vi(3263,($3|0));
            $424 = __THREW__; __THREW__ = 0;
            $425 = $424&1;
            if ($425) {
             $426 = ___cxa_find_matching_catch_3(0|0)|0;
             $427 = tempRet0;
             ___clang_call_terminate($426);
             // unreachable;
            } else {
             $eh$lpad$body104$index16Z2D = $423;$eh$lpad$body104$indexZ2D = $422;
             break L130;
            }
           }
          } while(0);
          $461 = ((($0)) + 44|0);
          __THREW__ = 0;
          $462 = (invoke_iii(4030,($461|0),($1|0))|0);
          $463 = __THREW__; __THREW__ = 0;
          $464 = $463&1;
          if ($464) {
           label = 105;
           break;
          }
          $465 = HEAP32[$462>>2]|0;
          $466 = ($465|0)==($253|0);
          do {
           if (!($466)) {
            HEAP32[$462>>2] = $253;
            $467 = HEAP32[$258>>2]|0;HEAP32[$258>>2] = (($467+1)|0);
            $468 = ($465|0)==(0|0);
            if ($468) {
             break;
            }
            $469 = ((($465)) + 8|0);
            $470 = HEAP32[$469>>2]|0;HEAP32[$469>>2] = (($470-1)|0);
            $471 = ($470|0)==(1);
            if (!($471)) {
             break;
            }
            __THREW__ = 0;
            invoke_viii(3262,($465|0),1,1);
            $472 = __THREW__; __THREW__ = 0;
            $473 = $472&1;
            if ($473) {
             label = 105;
             break L130;
            }
           }
          } while(0);
          $474 = HEAP32[$258>>2]|0;HEAP32[$258>>2] = (($474-1)|0);
          $475 = ($474|0)==(1);
          do {
           if ($475) {
            __THREW__ = 0;
            invoke_viii(3262,($253|0),1,1);
            $476 = __THREW__; __THREW__ = 0;
            $477 = $476&1;
            if (!($477)) {
             break;
            }
            $492 = ___cxa_find_matching_catch_2()|0;
            $493 = tempRet0;
            $$7 = $492;$$740 = $493;
            break L98;
           }
          } while(0);
          $478 = ((($13)) + 11|0);
          $479 = HEAP8[$478>>0]|0;
          $480 = ($479<<24>>24)<(0);
          if ($480) {
           $481 = HEAP32[$13>>2]|0;
           __ZdlPv($481);
          }
          $482 = HEAP8[$242>>0]|0;
          $483 = ($482<<24>>24)<(0);
          if ($483) {
           $484 = HEAP32[$12>>2]|0;
           __ZdlPv($484);
          }
          $485 = HEAP8[$224>>0]|0;
          $486 = ($485<<24>>24)<(0);
          if ($486) {
           $487 = HEAP32[$11>>2]|0;
           __ZdlPv($487);
          }
          $488 = HEAP8[$$pre$phi231Z2D>>0]|0;
          $489 = ($488<<24>>24)<(0);
          if (!($489)) {
           $491 = HEAP32[$46>>2]|0;
           __ZNSt3__26__treeINS_12__value_typeIfNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEEENS_19__map_value_compareIfS8_NS_4lessIfEELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($9,$491);
           STACKTOP = sp;return ($253|0);
          }
          $490 = HEAP32[$$pre$phi233Z2D>>2]|0;
          __ZdlPv($490);
          $491 = HEAP32[$46>>2]|0;
          __ZNSt3__26__treeINS_12__value_typeIfNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEEENS_19__map_value_compareIfS8_NS_4lessIfEELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($9,$491);
          STACKTOP = sp;return ($253|0);
         }
        }
       } while(0);
       if ((label|0) == 105) {
        $317 = ___cxa_find_matching_catch_2()|0;
        $318 = tempRet0;
        $eh$lpad$body104$index16Z2D = $318;$eh$lpad$body104$indexZ2D = $317;
       }
       $319 = HEAP32[$258>>2]|0;HEAP32[$258>>2] = (($319-1)|0);
       $320 = ($319|0)==(1);
       if ($320) {
        __THREW__ = 0;
        invoke_viii(3262,($253|0),1,1);
        $321 = __THREW__; __THREW__ = 0;
        $322 = $321&1;
        if ($322) {
         $511 = ___cxa_find_matching_catch_3(0|0)|0;
         $512 = tempRet0;
         ___clang_call_terminate($511);
         // unreachable;
        } else {
         $$7 = $eh$lpad$body104$indexZ2D;$$740 = $eh$lpad$body104$index16Z2D;
        }
       } else {
        $$7 = $eh$lpad$body104$indexZ2D;$$740 = $eh$lpad$body104$index16Z2D;
       }
      }
     }
    }
   }
  } while(0);
  if ((label|0) == 95) {
   $299 = ___cxa_find_matching_catch_2()|0;
   $300 = tempRet0;
   $$7 = $299;$$740 = $300;
  }
  $494 = ((($13)) + 11|0);
  $495 = HEAP8[$494>>0]|0;
  $496 = ($495<<24>>24)<(0);
  if ($496) {
   $497 = HEAP32[$13>>2]|0;
   __ZdlPv($497);
  }
  $$8 = $$7;$$841 = $$740;
 }
 $498 = ((($12)) + 11|0);
 $499 = HEAP8[$498>>0]|0;
 $500 = ($499<<24>>24)<(0);
 if ($500) {
  $501 = HEAP32[$12>>2]|0;
  __ZdlPv($501);
 }
 $502 = ((($11)) + 11|0);
 $503 = HEAP8[$502>>0]|0;
 $504 = ($503<<24>>24)<(0);
 if ($504) {
  $505 = HEAP32[$11>>2]|0;
  __ZdlPv($505);
 }
 $506 = ((($10)) + 11|0);
 $507 = HEAP8[$506>>0]|0;
 $508 = ($507<<24>>24)<(0);
 if ($508) {
  $509 = HEAP32[$10>>2]|0;
  __ZdlPv($509);
 }
 $$11 = $$8;$$1144 = $$841;$$pre$phiZ2D = $46;
 $510 = HEAP32[$$pre$phiZ2D>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIfNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEEENS_19__map_value_compareIfS8_NS_4lessIfEELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($9,$510);
 ___resumeException($$11|0);
 // unreachable;
 return (0)|0;
}
function __ZN3osg14ShaderComposer18addShaderToProgramEPNS_7ProgramERKNSt3__26vectorIPKNS_6ShaderENS3_9allocatorIS7_EEEE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$ph$lcssa$i$i$i = 0, $$0$ph16$i$i$i = 0, $$07$ph15$i$i$i = 0, $$07$ph15$us$i$i$i = 0, $$0713$i$i$i = 0, $$pre = 0, $$pre$phi36Z2D = 0, $$pre$phiZ2D = 0, $$pre35 = 0, $$sroa$018$030 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 44|0);
 $4 = ((($0)) + 48|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 L1: do {
  if ($6) {
   label = 19;
  } else {
   $7 = HEAP32[$2>>2]|0;
   $8 = ((($2)) + 4|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = ($7|0)==($9|0);
   L3: do {
    if ($10) {
     $$07$ph15$us$i$i$i = $5;
     while(1) {
      $11 = HEAP32[$$07$ph15$us$i$i$i>>2]|0;
      $12 = ($11|0)==(0|0);
      if ($12) {
       break;
      } else {
       $$07$ph15$us$i$i$i = $11;
      }
     }
     $$0$ph$lcssa$i$i$i = $$07$ph15$us$i$i$i;
    } else {
     $$0$ph16$i$i$i = $4;$$07$ph15$i$i$i = $5;
     while(1) {
      $$0713$i$i$i = $$07$ph15$i$i$i;
      L9: while(1) {
       $13 = ((($$0713$i$i$i)) + 20|0);
       $14 = HEAP32[$13>>2]|0;
       $15 = ((($$0713$i$i$i)) + 16|0);
       $16 = HEAP32[$15>>2]|0;
       $17 = $16;$21 = $7;
       while(1) {
        $18 = ($17|0)==($14|0);
        if ($18) {
         break;
        }
        $19 = HEAP32[$17>>2]|0;
        $20 = HEAP32[$21>>2]|0;
        $22 = ($19>>>0)<($20>>>0);
        if ($22) {
         break;
        }
        $23 = ($20>>>0)<($19>>>0);
        if ($23) {
         break L9;
        }
        $24 = ((($17)) + 4|0);
        $25 = ((($21)) + 4|0);
        $26 = ($25|0)==($9|0);
        if ($26) {
         break L9;
        } else {
         $17 = $24;$21 = $25;
        }
       }
       $29 = ((($$0713$i$i$i)) + 4|0);
       $30 = HEAP32[$29>>2]|0;
       $31 = ($30|0)==(0|0);
       if ($31) {
        $$0$ph$lcssa$i$i$i = $$0$ph16$i$i$i;
        break L3;
       } else {
        $$0713$i$i$i = $30;
       }
      }
      $27 = HEAP32[$$0713$i$i$i>>2]|0;
      $28 = ($27|0)==(0|0);
      if ($28) {
       $$0$ph$lcssa$i$i$i = $$0713$i$i$i;
       break;
      } else {
       $$0$ph16$i$i$i = $$0713$i$i$i;$$07$ph15$i$i$i = $27;
      }
     }
    }
   } while(0);
   $32 = ($$0$ph$lcssa$i$i$i|0)==($4|0);
   if ($32) {
    label = 19;
   } else {
    $33 = ((($$0$ph$lcssa$i$i$i)) + 16|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = ((($$0$ph$lcssa$i$i$i)) + 20|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = ($34|0)==($36|0);
    L20: do {
     if (!($37)) {
      $38 = $7;$42 = $34;
      while(1) {
       $39 = ($38|0)==($9|0);
       if ($39) {
        label = 19;
        break L1;
       }
       $40 = HEAP32[$38>>2]|0;
       $41 = HEAP32[$42>>2]|0;
       $43 = ($40>>>0)<($41>>>0);
       if ($43) {
        label = 19;
        break L1;
       }
       $44 = ($41>>>0)<($40>>>0);
       if ($44) {
        break L20;
       }
       $45 = ((($38)) + 4|0);
       $46 = ((($42)) + 4|0);
       $47 = ($46|0)==($36|0);
       if ($47) {
        break;
       } else {
        $38 = $45;$42 = $46;
       }
      }
     }
    } while(0);
    $62 = ((($$0$ph$lcssa$i$i$i)) + 28|0);
    $63 = HEAP32[$62>>2]|0;
    (__ZN3osg7Program9addShaderEPNS_6ShaderE($1,$63)|0);
    $$pre$phi36Z2D = $8;$$pre$phiZ2D = $2;
   }
  }
 } while(0);
 if ((label|0) == 19) {
  $48 = HEAP32[$0>>2]|0;
  $49 = ((($48)) + 144|0);
  $50 = HEAP32[$49>>2]|0;
  $51 = (FUNCTION_TABLE_iii[$50 & 8191]($0,$2)|0);
  $52 = (__ZNSt3__23mapINS_6vectorIPKN3osg6ShaderENS_9allocatorIS5_EEEENS2_7ref_ptrIS3_EENS_4lessIS8_EENS6_INS_4pairIKS8_SA_EEEEEixERSE_($3,$2)|0);
  $53 = HEAP32[$52>>2]|0;
  $54 = ($53|0)==($51|0);
  if (!($54)) {
   HEAP32[$52>>2] = $51;
   $55 = ($51|0)==(0|0);
   if (!($55)) {
    $56 = ((($51)) + 8|0);
    $57 = HEAP32[$56>>2]|0;HEAP32[$56>>2] = (($57+1)|0);
   }
   $58 = ($53|0)==(0|0);
   if (!($58)) {
    $59 = ((($53)) + 8|0);
    $60 = HEAP32[$59>>2]|0;HEAP32[$59>>2] = (($60-1)|0);
    $61 = ($60|0)==(1);
    if ($61) {
     __ZNK3osg10Referenced24signalObserversAndDeleteEbb($53,1,1);
    }
   }
  }
  (__ZN3osg7Program9addShaderEPNS_6ShaderE($1,$51)|0);
  $$pre35 = ((($2)) + 4|0);
  $$pre$phi36Z2D = $$pre35;$$pre$phiZ2D = $2;
 }
 $64 = HEAP32[$$pre$phiZ2D>>2]|0;
 $65 = HEAP32[$$pre$phi36Z2D>>2]|0;
 $66 = ($64|0)==($65|0);
 if ($66) {
  return;
 } else {
  $$sroa$018$030 = $64;$83 = $65;
 }
 while(1) {
  $67 = HEAP32[$$sroa$018$030>>2]|0;
  $68 = ((($67)) + 48|0);
  $69 = ((($68)) + 11|0);
  $70 = HEAP8[$69>>0]|0;
  $71 = ($70<<24>>24)<(0);
  if ($71) {
   $72 = ((($67)) + 52|0);
   $73 = HEAP32[$72>>2]|0;
   $75 = $73;
  } else {
   $74 = $70&255;
   $75 = $74;
  }
  $76 = ($75|0)==(0);
  if ($76) {
   $77 = ((($67)) + 60|0);
   $78 = HEAP32[$77>>2]|0;
   $79 = ($78|0)==(0|0);
   if ($79) {
    $82 = $83;
   } else {
    label = 34;
   }
  } else {
   label = 34;
  }
  if ((label|0) == 34) {
   label = 0;
   (__ZN3osg7Program9addShaderEPNS_6ShaderE($1,$67)|0);
   $$pre = HEAP32[$$pre$phi36Z2D>>2]|0;
   $82 = $$pre;
  }
  $80 = ((($$sroa$018$030)) + 4|0);
  $81 = ($80|0)==($82|0);
  if ($81) {
   break;
  } else {
   $$sroa$018$030 = $80;$83 = $82;
  }
 }
 return;
}
function __ZNSt3__23mapINS_6vectorIPKN3osg6ShaderENS_9allocatorIS5_EEEENS2_7ref_ptrIS3_EENS_4lessIS8_EENS6_INS_4pairIKS8_SA_EEEEEixERSE_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i = 0, $$0$ph$i = 0, $$0$us$i77 = 0, $$0$us$i77$phi = 0, $$014 = 0, $$024$i = 0, $$024$lcssa$i = 0, $$024$us$i76 = 0, $$02441$i = 0, $$025$i = 0, $$025$i95 = 0, $$037$i = 0, $$055 = 0, $$05594 = 0, $$in$i = 0, $$lcssa33$i = 0, $$pre$i = 0, $10 = 0, $11 = 0, $12 = 0;
 var $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 4|0);
 $5 = ($3|0)==(0|0);
 L1: do {
  if ($5) {
   $$025$i = $2;$$055 = $2;$63 = $3;
   label = 27;
  } else {
   $6 = ((($1)) + 4|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = HEAP32[$1>>2]|0;
   $9 = ($8|0)==($7|0);
   L4: do {
    if ($9) {
     $10 = ((($3)) + 16|0);
     $11 = HEAP32[$10>>2]|0;
     $12 = ((($3)) + 20|0);
     $13 = HEAP32[$12>>2]|0;
     $14 = ($11|0)==($13|0);
     if ($14) {
      $$02441$i = $3;$$037$i = $4;$85 = $3;
      label = 25;
     } else {
      $$0$us$i77 = $4;$$024$us$i76 = $3;$25 = $13;$86 = $3;$87 = $11;
      while(1) {
       $15 = $7;$19 = $87;
       while(1) {
        $16 = ($15|0)==($7|0);
        if ($16) {
         break;
        }
        $17 = HEAP32[$15>>2]|0;
        $18 = HEAP32[$19>>2]|0;
        $20 = ($17>>>0)<($18>>>0);
        if ($20) {
         break;
        }
        $21 = ($18>>>0)<($17>>>0);
        if ($21) {
         $$02441$i = $$024$us$i76;$$037$i = $$0$us$i77;$85 = $86;
         label = 25;
         break L4;
        }
        $22 = ((($15)) + 4|0);
        $23 = ((($19)) + 4|0);
        $24 = ($23|0)==($25|0);
        if ($24) {
         $$02441$i = $$024$us$i76;$$037$i = $$0$us$i77;$85 = $86;
         label = 25;
         break L4;
        } else {
         $15 = $22;$19 = $23;
        }
       }
       $26 = HEAP32[$$024$us$i76>>2]|0;
       $27 = ($26|0)==(0|0);
       if ($27) {
        $$024$lcssa$i = $$024$us$i76;$$lcssa33$i = $$024$us$i76;
        label = 18;
        break L4;
       }
       $28 = ((($26)) + 16|0);
       $29 = HEAP32[$28>>2]|0;
       $30 = ((($26)) + 20|0);
       $31 = HEAP32[$30>>2]|0;
       $32 = ($29|0)==($31|0);
       if ($32) {
        $$02441$i = $26;$$037$i = $$024$us$i76;$85 = $26;
        label = 25;
        break;
       } else {
        $$0$us$i77$phi = $$024$us$i76;$$024$us$i76 = $26;$25 = $31;$86 = $26;$87 = $29;$$0$us$i77 = $$0$us$i77$phi;
       }
      }
     }
    } else {
     $$0$i = $4;$$024$i = $3;$84 = $3;
     while(1) {
      $33 = ((($$024$i)) + 16|0);
      $34 = HEAP32[$33>>2]|0;
      $35 = ((($$024$i)) + 20|0);
      $36 = HEAP32[$35>>2]|0;
      $37 = ($34|0)==($36|0);
      L17: do {
       if ($37) {
        $50 = $34;$54 = $8;
        label = 19;
       } else {
        $38 = $8;$42 = $34;
        while(1) {
         $39 = ($38|0)==($7|0);
         if ($39) {
          break;
         }
         $40 = HEAP32[$38>>2]|0;
         $41 = HEAP32[$42>>2]|0;
         $43 = ($40>>>0)<($41>>>0);
         if ($43) {
          break;
         }
         $44 = ($41>>>0)<($40>>>0);
         if ($44) {
          $50 = $34;$54 = $8;
          label = 19;
          break L17;
         }
         $45 = ((($38)) + 4|0);
         $46 = ((($42)) + 4|0);
         $47 = ($46|0)==($36|0);
         if ($47) {
          $50 = $34;$54 = $8;
          label = 19;
          break L17;
         } else {
          $38 = $45;$42 = $46;
         }
        }
        $48 = HEAP32[$$024$i>>2]|0;
        $49 = ($48|0)==(0|0);
        if ($49) {
         $$024$lcssa$i = $$024$i;$$lcssa33$i = $$024$i;
         label = 18;
         break L4;
        } else {
         $$0$ph$i = $$024$i;$$in$i = $48;
        }
       }
      } while(0);
      if ((label|0) == 19) {
       while(1) {
        label = 0;
        $51 = ($50|0)==($36|0);
        if ($51) {
         break;
        }
        $52 = HEAP32[$50>>2]|0;
        $53 = HEAP32[$54>>2]|0;
        $55 = ($52>>>0)<($53>>>0);
        if ($55) {
         break;
        }
        $56 = ($53>>>0)<($52>>>0);
        if ($56) {
         $$02441$i = $$024$i;$$037$i = $$0$i;$85 = $84;
         label = 25;
         break L4;
        }
        $57 = ((($50)) + 4|0);
        $58 = ((($54)) + 4|0);
        $59 = ($58|0)==($7|0);
        if ($59) {
         $$02441$i = $$024$i;$$037$i = $$0$i;$85 = $84;
         label = 25;
         break L4;
        } else {
         $50 = $57;$54 = $58;
         label = 19;
        }
       }
       $60 = ((($$024$i)) + 4|0);
       $61 = HEAP32[$60>>2]|0;
       $62 = ($61|0)==(0|0);
       if ($62) {
        break;
       } else {
        $$0$ph$i = $60;$$in$i = $61;
       }
      }
      $$0$i = $$0$ph$i;$$024$i = $$in$i;$84 = $$in$i;
     }
     $$025$i95 = $60;$$05594 = $$024$i;
     break L1;
    }
   } while(0);
   if ((label|0) == 18) {
    $$025$i95 = $$lcssa33$i;$$05594 = $$024$lcssa$i;
    break;
   }
   else if ((label|0) == 25) {
    $$025$i = $$037$i;$$055 = $$02441$i;$63 = $85;
    label = 27;
    break;
   }
  }
 } while(0);
 if ((label|0) == 27) {
  $64 = ($63|0)==(0|0);
  if ($64) {
   $$025$i95 = $$025$i;$$05594 = $$055;
  } else {
   $$014 = $63;
   $83 = ((($$014)) + 28|0);
   return ($83|0);
  }
 }
 $65 = (__Znwj(32)|0);
 $66 = ((($65)) + 16|0);
 __THREW__ = 0;
 invoke_vii(4031,($66|0),($1|0));
 $67 = __THREW__; __THREW__ = 0;
 $68 = $67&1;
 if ($68) {
  $69 = ___cxa_find_matching_catch_2()|0;
  $70 = tempRet0;
  __ZdlPv($65);
  ___resumeException($69|0);
  // unreachable;
 }
 $71 = ((($65)) + 28|0);
 HEAP32[$71>>2] = 0;
 HEAP32[$65>>2] = 0;
 $72 = ((($65)) + 4|0);
 HEAP32[$72>>2] = 0;
 $73 = ((($65)) + 8|0);
 HEAP32[$73>>2] = $$05594;
 HEAP32[$$025$i95>>2] = $65;
 $74 = HEAP32[$0>>2]|0;
 $75 = HEAP32[$74>>2]|0;
 $76 = ($75|0)==(0|0);
 if ($76) {
  $79 = $65;
 } else {
  $77 = $75;
  HEAP32[$0>>2] = $77;
  $$pre$i = HEAP32[$$025$i95>>2]|0;
  $79 = $$pre$i;
 }
 $78 = HEAP32[$4>>2]|0;
 __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($78,$79);
 $80 = ((($0)) + 8|0);
 $81 = HEAP32[$80>>2]|0;
 $82 = (($81) + 1)|0;
 HEAP32[$80>>2] = $82;
 $$014 = $65;
 $83 = ((($$014)) + 28|0);
 return ($83|0);
}
function __ZNSt3__26vectorIPKN3osg6ShaderENS_9allocatorIS4_EEEC2ERKS7_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i = 0, $scevgep5$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = 0;
 $2 = ((($0)) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = ((($0)) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$1>>2]|0;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 2;
 $9 = ($8|0)==(0);
 if ($9) {
  return;
 }
 $10 = ($8>>>0)>(1073741823);
 if ($10) {
  __THREW__ = 0;
  invoke_vi(3307,($0|0));
  $11 = __THREW__; __THREW__ = 0;
 } else {
  __THREW__ = 0;
  $12 = (invoke_ii(3276,($7|0))|0);
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if (!($14)) {
   HEAP32[$2>>2] = $12;
   HEAP32[$0>>2] = $12;
   $15 = (($12) + ($8<<2)|0);
   $16 = ((($0)) + 8|0);
   HEAP32[$16>>2] = $15;
   $17 = HEAP32[$1>>2]|0;
   $18 = HEAP32[$4>>2]|0;
   $19 = $17;
   $20 = (($18) - ($19))|0;
   $21 = ($20|0)>(0);
   if (!($21)) {
    return;
   }
   $22 = $20 >>> 2;
   _memcpy(($12|0),($17|0),($20|0))|0;
   $23 = (($12) + ($22<<2)|0);
   HEAP32[$2>>2] = $23;
   return;
  }
 }
 $24 = ___cxa_find_matching_catch_2()|0;
 $25 = tempRet0;
 $26 = HEAP32[$0>>2]|0;
 $27 = ($26|0)==(0|0);
 if ($27) {
  ___resumeException($24|0);
  // unreachable;
 }
 $28 = HEAP32[$2>>2]|0;
 $29 = ($28|0)==($26|0);
 if (!($29)) {
  $scevgep$i$i$i = ((($28)) + -4|0);
  $30 = $scevgep$i$i$i;
  $31 = $26;
  $32 = (($30) - ($31))|0;
  $33 = $32 >>> 2;
  $34 = $33 ^ -1;
  $scevgep5$i$i$i = (($28) + ($34<<2)|0);
  HEAP32[$2>>2] = $scevgep5$i$i$i;
 }
 __ZdlPv($26);
 ___resumeException($24|0);
 // unreachable;
}
function __ZNSt3__26vectorIPKN3osg6ShaderENS_9allocatorIS4_EEE21__push_back_slow_pathIKS4_EEvRT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(1073741823);
 if ($8) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $9 = ((($0)) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) - ($4))|0;
 $12 = $11 >> 2;
 $13 = ($12>>>0)<(536870911);
 $14 = $11 >> 1;
 $15 = ($14>>>0)<($7>>>0);
 $$sroa$speculated$i = $15 ? $7 : $14;
 $$sroa$speculated$$i = $13 ? $$sroa$speculated$i : 1073741823;
 $16 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($16) {
   $26 = 0;
  } else {
   $17 = ($$sroa$speculated$$i>>>0)>(1073741823);
   if (!($17)) {
    $23 = $$sroa$speculated$$i << 2;
    $24 = (__Znwj($23)|0);
    $26 = $24;
    break;
   }
   $18 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($18|0),(204840|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if ($20) {
    $21 = ___cxa_find_matching_catch_2()|0;
    $22 = tempRet0;
    ___cxa_free_exception(($18|0));
    ___resumeException($21|0);
    // unreachable;
   } else {
    HEAP32[$18>>2] = (99824);
    ___cxa_throw(($18|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $25 = (($26) + ($6<<2)|0);
 $27 = (($26) + ($$sroa$speculated$$i<<2)|0);
 $28 = $27;
 $29 = HEAP32[$1>>2]|0;
 HEAP32[$25>>2] = $29;
 $30 = ((($25)) + 4|0);
 $31 = $30;
 $32 = (0 - ($6))|0;
 $33 = (($25) + ($32<<2)|0);
 $34 = $33;
 $35 = ($5|0)>(0);
 if ($35) {
  $36 = $4;
  _memcpy(($33|0),($36|0),($5|0))|0;
 }
 HEAP32[$0>>2] = $34;
 HEAP32[$2>>2] = $31;
 HEAP32[$9>>2] = $28;
 $37 = ($4|0)==(0);
 if ($37) {
  return;
 }
 $38 = $4;
 __ZdlPv($38);
 return;
}
function __ZNSt3__23mapINS_6vectorIPN3osg15ShaderComponentENS_9allocatorIS4_EEEENS2_7ref_ptrINS2_7ProgramEEENS_4lessIS7_EENS5_INS_4pairIKS7_SA_EEEEEixERSE_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i = 0, $$0$ph$i = 0, $$0$us$i77 = 0, $$0$us$i77$phi = 0, $$014 = 0, $$024$i = 0, $$024$lcssa$i = 0, $$024$us$i76 = 0, $$02441$i = 0, $$025$i = 0, $$025$i95 = 0, $$037$i = 0, $$055 = 0, $$05594 = 0, $$in$i = 0, $$lcssa33$i = 0, $$pre$i = 0, $10 = 0, $11 = 0, $12 = 0;
 var $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 4|0);
 $5 = ($3|0)==(0|0);
 L1: do {
  if ($5) {
   $$025$i = $2;$$055 = $2;$63 = $3;
   label = 27;
  } else {
   $6 = ((($1)) + 4|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = HEAP32[$1>>2]|0;
   $9 = ($8|0)==($7|0);
   L4: do {
    if ($9) {
     $10 = ((($3)) + 16|0);
     $11 = HEAP32[$10>>2]|0;
     $12 = ((($3)) + 20|0);
     $13 = HEAP32[$12>>2]|0;
     $14 = ($11|0)==($13|0);
     if ($14) {
      $$02441$i = $3;$$037$i = $4;$85 = $3;
      label = 25;
     } else {
      $$0$us$i77 = $4;$$024$us$i76 = $3;$25 = $13;$86 = $3;$87 = $11;
      while(1) {
       $15 = $7;$19 = $87;
       while(1) {
        $16 = ($15|0)==($7|0);
        if ($16) {
         break;
        }
        $17 = HEAP32[$15>>2]|0;
        $18 = HEAP32[$19>>2]|0;
        $20 = ($17>>>0)<($18>>>0);
        if ($20) {
         break;
        }
        $21 = ($18>>>0)<($17>>>0);
        if ($21) {
         $$02441$i = $$024$us$i76;$$037$i = $$0$us$i77;$85 = $86;
         label = 25;
         break L4;
        }
        $22 = ((($15)) + 4|0);
        $23 = ((($19)) + 4|0);
        $24 = ($23|0)==($25|0);
        if ($24) {
         $$02441$i = $$024$us$i76;$$037$i = $$0$us$i77;$85 = $86;
         label = 25;
         break L4;
        } else {
         $15 = $22;$19 = $23;
        }
       }
       $26 = HEAP32[$$024$us$i76>>2]|0;
       $27 = ($26|0)==(0|0);
       if ($27) {
        $$024$lcssa$i = $$024$us$i76;$$lcssa33$i = $$024$us$i76;
        label = 18;
        break L4;
       }
       $28 = ((($26)) + 16|0);
       $29 = HEAP32[$28>>2]|0;
       $30 = ((($26)) + 20|0);
       $31 = HEAP32[$30>>2]|0;
       $32 = ($29|0)==($31|0);
       if ($32) {
        $$02441$i = $26;$$037$i = $$024$us$i76;$85 = $26;
        label = 25;
        break;
       } else {
        $$0$us$i77$phi = $$024$us$i76;$$024$us$i76 = $26;$25 = $31;$86 = $26;$87 = $29;$$0$us$i77 = $$0$us$i77$phi;
       }
      }
     }
    } else {
     $$0$i = $4;$$024$i = $3;$84 = $3;
     while(1) {
      $33 = ((($$024$i)) + 16|0);
      $34 = HEAP32[$33>>2]|0;
      $35 = ((($$024$i)) + 20|0);
      $36 = HEAP32[$35>>2]|0;
      $37 = ($34|0)==($36|0);
      L17: do {
       if ($37) {
        $50 = $34;$54 = $8;
        label = 19;
       } else {
        $38 = $8;$42 = $34;
        while(1) {
         $39 = ($38|0)==($7|0);
         if ($39) {
          break;
         }
         $40 = HEAP32[$38>>2]|0;
         $41 = HEAP32[$42>>2]|0;
         $43 = ($40>>>0)<($41>>>0);
         if ($43) {
          break;
         }
         $44 = ($41>>>0)<($40>>>0);
         if ($44) {
          $50 = $34;$54 = $8;
          label = 19;
          break L17;
         }
         $45 = ((($38)) + 4|0);
         $46 = ((($42)) + 4|0);
         $47 = ($46|0)==($36|0);
         if ($47) {
          $50 = $34;$54 = $8;
          label = 19;
          break L17;
         } else {
          $38 = $45;$42 = $46;
         }
        }
        $48 = HEAP32[$$024$i>>2]|0;
        $49 = ($48|0)==(0|0);
        if ($49) {
         $$024$lcssa$i = $$024$i;$$lcssa33$i = $$024$i;
         label = 18;
         break L4;
        } else {
         $$0$ph$i = $$024$i;$$in$i = $48;
        }
       }
      } while(0);
      if ((label|0) == 19) {
       while(1) {
        label = 0;
        $51 = ($50|0)==($36|0);
        if ($51) {
         break;
        }
        $52 = HEAP32[$50>>2]|0;
        $53 = HEAP32[$54>>2]|0;
        $55 = ($52>>>0)<($53>>>0);
        if ($55) {
         break;
        }
        $56 = ($53>>>0)<($52>>>0);
        if ($56) {
         $$02441$i = $$024$i;$$037$i = $$0$i;$85 = $84;
         label = 25;
         break L4;
        }
        $57 = ((($50)) + 4|0);
        $58 = ((($54)) + 4|0);
        $59 = ($58|0)==($7|0);
        if ($59) {
         $$02441$i = $$024$i;$$037$i = $$0$i;$85 = $84;
         label = 25;
         break L4;
        } else {
         $50 = $57;$54 = $58;
         label = 19;
        }
       }
       $60 = ((($$024$i)) + 4|0);
       $61 = HEAP32[$60>>2]|0;
       $62 = ($61|0)==(0|0);
       if ($62) {
        break;
       } else {
        $$0$ph$i = $60;$$in$i = $61;
       }
      }
      $$0$i = $$0$ph$i;$$024$i = $$in$i;$84 = $$in$i;
     }
     $$025$i95 = $60;$$05594 = $$024$i;
     break L1;
    }
   } while(0);
   if ((label|0) == 18) {
    $$025$i95 = $$lcssa33$i;$$05594 = $$024$lcssa$i;
    break;
   }
   else if ((label|0) == 25) {
    $$025$i = $$037$i;$$055 = $$02441$i;$63 = $85;
    label = 27;
    break;
   }
  }
 } while(0);
 if ((label|0) == 27) {
  $64 = ($63|0)==(0|0);
  if ($64) {
   $$025$i95 = $$025$i;$$05594 = $$055;
  } else {
   $$014 = $63;
   $83 = ((($$014)) + 28|0);
   return ($83|0);
  }
 }
 $65 = (__Znwj(32)|0);
 $66 = ((($65)) + 16|0);
 __THREW__ = 0;
 invoke_vii(4032,($66|0),($1|0));
 $67 = __THREW__; __THREW__ = 0;
 $68 = $67&1;
 if ($68) {
  $69 = ___cxa_find_matching_catch_2()|0;
  $70 = tempRet0;
  __ZdlPv($65);
  ___resumeException($69|0);
  // unreachable;
 }
 $71 = ((($65)) + 28|0);
 HEAP32[$71>>2] = 0;
 HEAP32[$65>>2] = 0;
 $72 = ((($65)) + 4|0);
 HEAP32[$72>>2] = 0;
 $73 = ((($65)) + 8|0);
 HEAP32[$73>>2] = $$05594;
 HEAP32[$$025$i95>>2] = $65;
 $74 = HEAP32[$0>>2]|0;
 $75 = HEAP32[$74>>2]|0;
 $76 = ($75|0)==(0|0);
 if ($76) {
  $79 = $65;
 } else {
  $77 = $75;
  HEAP32[$0>>2] = $77;
  $$pre$i = HEAP32[$$025$i95>>2]|0;
  $79 = $$pre$i;
 }
 $78 = HEAP32[$4>>2]|0;
 __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($78,$79);
 $80 = ((($0)) + 8|0);
 $81 = HEAP32[$80>>2]|0;
 $82 = (($81) + 1)|0;
 HEAP32[$80>>2] = $82;
 $$014 = $65;
 $83 = ((($$014)) + 28|0);
 return ($83|0);
}
function __ZNSt3__26vectorIPN3osg15ShaderComponentENS_9allocatorIS3_EEEC2ERKS6_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i = 0, $scevgep5$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = 0;
 $2 = ((($0)) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = ((($0)) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$1>>2]|0;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 2;
 $9 = ($8|0)==(0);
 if ($9) {
  return;
 }
 $10 = ($8>>>0)>(1073741823);
 if ($10) {
  __THREW__ = 0;
  invoke_vi(3307,($0|0));
  $11 = __THREW__; __THREW__ = 0;
 } else {
  __THREW__ = 0;
  $12 = (invoke_ii(3276,($7|0))|0);
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if (!($14)) {
   HEAP32[$2>>2] = $12;
   HEAP32[$0>>2] = $12;
   $15 = (($12) + ($8<<2)|0);
   $16 = ((($0)) + 8|0);
   HEAP32[$16>>2] = $15;
   $17 = HEAP32[$1>>2]|0;
   $18 = HEAP32[$4>>2]|0;
   $19 = $17;
   $20 = (($18) - ($19))|0;
   $21 = ($20|0)>(0);
   if (!($21)) {
    return;
   }
   $22 = $20 >>> 2;
   _memcpy(($12|0),($17|0),($20|0))|0;
   $23 = (($12) + ($22<<2)|0);
   HEAP32[$2>>2] = $23;
   return;
  }
 }
 $24 = ___cxa_find_matching_catch_2()|0;
 $25 = tempRet0;
 $26 = HEAP32[$0>>2]|0;
 $27 = ($26|0)==(0|0);
 if ($27) {
  ___resumeException($24|0);
  // unreachable;
 }
 $28 = HEAP32[$2>>2]|0;
 $29 = ($28|0)==($26|0);
 if (!($29)) {
  $scevgep$i$i$i = ((($28)) + -4|0);
  $30 = $scevgep$i$i$i;
  $31 = $26;
  $32 = (($30) - ($31))|0;
  $33 = $32 >>> 2;
  $34 = $33 ^ -1;
  $scevgep5$i$i$i = (($28) + ($34<<2)|0);
  HEAP32[$2>>2] = $scevgep5$i$i$i;
 }
 __ZdlPv($26);
 ___resumeException($24|0);
 // unreachable;
}
function __ZN3osg14ShaderComposerC2ERKS0_RKNS_6CopyOpE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 __ZN3osg6ObjectC2ERKS0_RKNS_6CopyOpE($0,$1,$2);
 HEAP32[$0>>2] = (70932);
 $4 = ((($0)) + 32|0);
 $5 = ((($0)) + 36|0);
 HEAP32[$5>>2] = 0;
 $6 = ((($0)) + 40|0);
 HEAP32[$6>>2] = 0;
 $7 = ((($0)) + 36|0);
 HEAP32[$4>>2] = $7;
 $8 = ((($0)) + 44|0);
 $9 = ((($0)) + 48|0);
 HEAP32[$9>>2] = 0;
 $10 = ((($0)) + 52|0);
 HEAP32[$10>>2] = 0;
 $11 = ((($0)) + 48|0);
 HEAP32[$8>>2] = $11;
 __THREW__ = 0;
 $12 = (invoke_ii(3265,4)|0);
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 do {
  if ($14) {
   label = 15;
  } else {
   if (!($12)) {
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(3266,4)|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if ($17) {
    label = 15;
   } else {
    __THREW__ = 0;
    $18 = (invoke_iiii(3267,($15|0),(160278|0),76)|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     label = 15;
    } else {
     __THREW__ = 0;
     $21 = (invoke_iii(3275,($18|0),($0|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      label = 15;
     } else {
      $24 = HEAP32[$21>>2]|0;
      $25 = ((($24)) + -12|0);
      $26 = HEAP32[$25>>2]|0;
      $27 = (($21) + ($26)|0);
      __THREW__ = 0;
      invoke_vii(3257,($3|0),($27|0));
      $28 = __THREW__; __THREW__ = 0;
      $29 = $28&1;
      if ($29) {
       label = 15;
      } else {
       __THREW__ = 0;
       $30 = (invoke_iii(3255,($3|0),(215188|0))|0);
       $31 = __THREW__; __THREW__ = 0;
       $32 = $31&1;
       if (!($32)) {
        $33 = HEAP32[$30>>2]|0;
        $34 = ((($33)) + 28|0);
        $35 = HEAP32[$34>>2]|0;
        __THREW__ = 0;
        $36 = (invoke_iii($35|0,($30|0),10)|0);
        $37 = __THREW__; __THREW__ = 0;
        $38 = $37&1;
        if (!($38)) {
         __THREW__ = 0;
         invoke_vi(3263,($3|0));
         $45 = __THREW__; __THREW__ = 0;
         $46 = $45&1;
         if ($46) {
          label = 15;
          break;
         }
         __THREW__ = 0;
         (invoke_iii(3268,($21|0),($36|0))|0);
         $47 = __THREW__; __THREW__ = 0;
         $48 = $47&1;
         if ($48) {
          label = 15;
          break;
         }
         __THREW__ = 0;
         (invoke_ii(3269,($21|0))|0);
         $49 = __THREW__; __THREW__ = 0;
         $50 = $49&1;
         if ($50) {
          label = 15;
          break;
         }
         STACKTOP = sp;return;
        }
       }
       $39 = ___cxa_find_matching_catch_2()|0;
       $40 = tempRet0;
       __THREW__ = 0;
       invoke_vi(3263,($3|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if ($42) {
        $43 = ___cxa_find_matching_catch_3(0|0)|0;
        $44 = tempRet0;
        ___clang_call_terminate($43);
        // unreachable;
       } else {
        $eh$lpad$body$index2Z2D = $40;$eh$lpad$body$indexZ2D = $39;
        break;
       }
      }
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 15) {
  $51 = ___cxa_find_matching_catch_2()|0;
  $52 = tempRet0;
  $eh$lpad$body$index2Z2D = $52;$eh$lpad$body$indexZ2D = $51;
 }
 $53 = HEAP32[$11>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_6vectorIPKN3osg6ShaderENS_9allocatorIS6_EEEENS3_7ref_ptrIS4_EEEENS_19__map_value_compareIS9_SC_NS_4lessIS9_EELb1EEENS7_ISC_EEE7destroyEPNS_11__tree_nodeISC_PvEE($8,$53);
 $54 = HEAP32[$7>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_6vectorIPN3osg15ShaderComponentENS_9allocatorIS5_EEEENS3_7ref_ptrINS3_7ProgramEEEEENS_19__map_value_compareIS8_SC_NS_4lessIS8_EELb1EEENS6_ISC_EEE7destroyEPNS_11__tree_nodeISC_PvEE($4,$54);
 __THREW__ = 0;
 invoke_vi(388,($0|0));
 $55 = __THREW__; __THREW__ = 0;
 $56 = $55&1;
 if ($56) {
  $57 = ___cxa_find_matching_catch_3(0|0)|0;
  $58 = tempRet0;
  ___clang_call_terminate($57);
  // unreachable;
 } else {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
}
function __ZNSt3__26__treeINS_12__value_typeINS_6vectorIPKN3osg6ShaderENS_9allocatorIS6_EEEENS3_7ref_ptrIS4_EEEENS_19__map_value_compareIS9_SC_NS_4lessIS9_EELb1EEENS7_ISC_EEE7destroyEPNS_11__tree_nodeISC_PvEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i$i$i = 0, $scevgep$i$i$i2$i$i$i = 0, $scevgep5$i$i$i$i$i$i = 0, $scevgep5$i$i$i3$i$i$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 }
 $3 = HEAP32[$1>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_6vectorIPKN3osg6ShaderENS_9allocatorIS6_EEEENS3_7ref_ptrIS4_EEEENS_19__map_value_compareIS9_SC_NS_4lessIS9_EELb1EEENS7_ISC_EEE7destroyEPNS_11__tree_nodeISC_PvEE($0,$3);
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_6vectorIPKN3osg6ShaderENS_9allocatorIS6_EEEENS3_7ref_ptrIS4_EEEENS_19__map_value_compareIS9_SC_NS_4lessIS9_EELb1EEENS7_ISC_EEE7destroyEPNS_11__tree_nodeISC_PvEE($0,$5);
 $6 = ((($1)) + 16|0);
 $7 = ((($1)) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if (!($9)) {
  $10 = ((($8)) + 8|0);
  $11 = HEAP32[$10>>2]|0;HEAP32[$10>>2] = (($11-1)|0);
  $12 = ($11|0)==(1);
  if ($12) {
   __THREW__ = 0;
   invoke_viii(3262,($8|0),1,1);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if ($14) {
    $25 = ___cxa_find_matching_catch_2()|0;
    $26 = tempRet0;
    $27 = HEAP32[$6>>2]|0;
    $28 = ($27|0)==(0|0);
    if ($28) {
     ___cxa_call_unexpected(($25|0));
     // unreachable;
    }
    $29 = ((($1)) + 20|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = ($30|0)==($27|0);
    if (!($31)) {
     $scevgep$i$i$i2$i$i$i = ((($30)) + -4|0);
     $32 = $scevgep$i$i$i2$i$i$i;
     $33 = $27;
     $34 = (($32) - ($33))|0;
     $35 = $34 >>> 2;
     $36 = $35 ^ -1;
     $scevgep5$i$i$i3$i$i$i = (($30) + ($36<<2)|0);
     HEAP32[$29>>2] = $scevgep5$i$i$i3$i$i$i;
    }
    __ZdlPv($27);
    ___cxa_call_unexpected(($25|0));
    // unreachable;
   }
  }
 }
 HEAP32[$7>>2] = 0;
 $15 = HEAP32[$6>>2]|0;
 $16 = ($15|0)==(0|0);
 if (!($16)) {
  $17 = ((($1)) + 20|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = ($18|0)==($15|0);
  if (!($19)) {
   $scevgep$i$i$i$i$i$i = ((($18)) + -4|0);
   $20 = $scevgep$i$i$i$i$i$i;
   $21 = $15;
   $22 = (($20) - ($21))|0;
   $23 = $22 >>> 2;
   $24 = $23 ^ -1;
   $scevgep5$i$i$i$i$i$i = (($18) + ($24<<2)|0);
   HEAP32[$17>>2] = $scevgep5$i$i$i$i$i$i;
  }
  __ZdlPv($15);
 }
 __ZdlPv($1);
 return;
}
function __ZNSt3__26__treeINS_12__value_typeINS_6vectorIPN3osg15ShaderComponentENS_9allocatorIS5_EEEENS3_7ref_ptrINS3_7ProgramEEEEENS_19__map_value_compareIS8_SC_NS_4lessIS8_EELb1EEENS6_ISC_EEE7destroyEPNS_11__tree_nodeISC_PvEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i$i$i = 0, $scevgep$i$i$i2$i$i$i = 0, $scevgep5$i$i$i$i$i$i = 0, $scevgep5$i$i$i3$i$i$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 }
 $3 = HEAP32[$1>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_6vectorIPN3osg15ShaderComponentENS_9allocatorIS5_EEEENS3_7ref_ptrINS3_7ProgramEEEEENS_19__map_value_compareIS8_SC_NS_4lessIS8_EELb1EEENS6_ISC_EEE7destroyEPNS_11__tree_nodeISC_PvEE($0,$3);
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_6vectorIPN3osg15ShaderComponentENS_9allocatorIS5_EEEENS3_7ref_ptrINS3_7ProgramEEEEENS_19__map_value_compareIS8_SC_NS_4lessIS8_EELb1EEENS6_ISC_EEE7destroyEPNS_11__tree_nodeISC_PvEE($0,$5);
 $6 = ((($1)) + 16|0);
 $7 = ((($1)) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if (!($9)) {
  $10 = ((($8)) + 8|0);
  $11 = HEAP32[$10>>2]|0;HEAP32[$10>>2] = (($11-1)|0);
  $12 = ($11|0)==(1);
  if ($12) {
   __THREW__ = 0;
   invoke_viii(3262,($8|0),1,1);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if ($14) {
    $25 = ___cxa_find_matching_catch_2()|0;
    $26 = tempRet0;
    $27 = HEAP32[$6>>2]|0;
    $28 = ($27|0)==(0|0);
    if ($28) {
     ___cxa_call_unexpected(($25|0));
     // unreachable;
    }
    $29 = ((($1)) + 20|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = ($30|0)==($27|0);
    if (!($31)) {
     $scevgep$i$i$i2$i$i$i = ((($30)) + -4|0);
     $32 = $scevgep$i$i$i2$i$i$i;
     $33 = $27;
     $34 = (($32) - ($33))|0;
     $35 = $34 >>> 2;
     $36 = $35 ^ -1;
     $scevgep5$i$i$i3$i$i$i = (($30) + ($36<<2)|0);
     HEAP32[$29>>2] = $scevgep5$i$i$i3$i$i$i;
    }
    __ZdlPv($27);
    ___cxa_call_unexpected(($25|0));
    // unreachable;
   }
  }
 }
 HEAP32[$7>>2] = 0;
 $15 = HEAP32[$6>>2]|0;
 $16 = ($15|0)==(0|0);
 if (!($16)) {
  $17 = ((($1)) + 20|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = ($18|0)==($15|0);
  if (!($19)) {
   $scevgep$i$i$i$i$i$i = ((($18)) + -4|0);
   $20 = $scevgep$i$i$i$i$i$i;
   $21 = $15;
   $22 = (($20) - ($21))|0;
   $23 = $22 >>> 2;
   $24 = $23 ^ -1;
   $scevgep5$i$i$i$i$i$i = (($18) + ($24<<2)|0);
   HEAP32[$17>>2] = $scevgep5$i$i$i$i$i$i;
  }
  __ZdlPv($15);
 }
 __ZdlPv($1);
 return;
}
function __ZN3osg14ShaderComposerC2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0;
 var $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 __ZN3osg10ReferencedC2Ev($0);
 $2 = ((($0)) + 12|0);
 ;HEAP32[$2>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;
 $3 = ((($0)) + 24|0);
 HEAP32[$3>>2] = 2;
 $4 = ((($0)) + 28|0);
 HEAP32[$4>>2] = 0;
 HEAP32[$0>>2] = (70932);
 $5 = ((($0)) + 32|0);
 $6 = ((($0)) + 36|0);
 HEAP32[$6>>2] = 0;
 $7 = ((($0)) + 40|0);
 HEAP32[$7>>2] = 0;
 $8 = ((($0)) + 36|0);
 HEAP32[$5>>2] = $8;
 $9 = ((($0)) + 44|0);
 $10 = ((($0)) + 48|0);
 HEAP32[$10>>2] = 0;
 $11 = ((($0)) + 52|0);
 HEAP32[$11>>2] = 0;
 $12 = ((($0)) + 48|0);
 HEAP32[$9>>2] = $12;
 __THREW__ = 0;
 $13 = (invoke_ii(3265,4)|0);
 $14 = __THREW__; __THREW__ = 0;
 $15 = $14&1;
 do {
  if ($15) {
   label = 15;
  } else {
   if (!($13)) {
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   $16 = (invoke_ii(3266,4)|0);
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if ($18) {
    label = 15;
   } else {
    __THREW__ = 0;
    $19 = (invoke_iiii(3267,($16|0),(160355|0),33)|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     label = 15;
    } else {
     __THREW__ = 0;
     $22 = (invoke_iii(3275,($19|0),($0|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      label = 15;
     } else {
      $25 = HEAP32[$22>>2]|0;
      $26 = ((($25)) + -12|0);
      $27 = HEAP32[$26>>2]|0;
      $28 = (($22) + ($27)|0);
      __THREW__ = 0;
      invoke_vii(3257,($1|0),($28|0));
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if ($30) {
       label = 15;
      } else {
       __THREW__ = 0;
       $31 = (invoke_iii(3255,($1|0),(215188|0))|0);
       $32 = __THREW__; __THREW__ = 0;
       $33 = $32&1;
       if (!($33)) {
        $34 = HEAP32[$31>>2]|0;
        $35 = ((($34)) + 28|0);
        $36 = HEAP32[$35>>2]|0;
        __THREW__ = 0;
        $37 = (invoke_iii($36|0,($31|0),10)|0);
        $38 = __THREW__; __THREW__ = 0;
        $39 = $38&1;
        if (!($39)) {
         __THREW__ = 0;
         invoke_vi(3263,($1|0));
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          label = 15;
          break;
         }
         __THREW__ = 0;
         (invoke_iii(3268,($22|0),($37|0))|0);
         $48 = __THREW__; __THREW__ = 0;
         $49 = $48&1;
         if ($49) {
          label = 15;
          break;
         }
         __THREW__ = 0;
         (invoke_ii(3269,($22|0))|0);
         $50 = __THREW__; __THREW__ = 0;
         $51 = $50&1;
         if ($51) {
          label = 15;
          break;
         }
         STACKTOP = sp;return;
        }
       }
       $42 = ___cxa_find_matching_catch_2()|0;
       $43 = tempRet0;
       __THREW__ = 0;
       invoke_vi(3263,($1|0));
       $44 = __THREW__; __THREW__ = 0;
       $45 = $44&1;
       if ($45) {
        $46 = ___cxa_find_matching_catch_3(0|0)|0;
        $47 = tempRet0;
        ___clang_call_terminate($46);
        // unreachable;
       } else {
        $eh$lpad$body$index2Z2D = $43;$eh$lpad$body$indexZ2D = $42;
        break;
       }
      }
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 15) {
  $52 = ___cxa_find_matching_catch_2()|0;
  $53 = tempRet0;
  $eh$lpad$body$index2Z2D = $53;$eh$lpad$body$indexZ2D = $52;
 }
 $54 = HEAP32[$12>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_6vectorIPKN3osg6ShaderENS_9allocatorIS6_EEEENS3_7ref_ptrIS4_EEEENS_19__map_value_compareIS9_SC_NS_4lessIS9_EELb1EEENS7_ISC_EEE7destroyEPNS_11__tree_nodeISC_PvEE($9,$54);
 $55 = HEAP32[$8>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_6vectorIPN3osg15ShaderComponentENS_9allocatorIS5_EEEENS3_7ref_ptrINS3_7ProgramEEEEENS_19__map_value_compareIS8_SC_NS_4lessIS8_EELb1EEENS6_ISC_EEE7destroyEPNS_11__tree_nodeISC_PvEE($5,$55);
 __THREW__ = 0;
 invoke_vi(388,($0|0));
 $56 = __THREW__; __THREW__ = 0;
 $57 = $56&1;
 if ($57) {
  $58 = ___cxa_find_matching_catch_3(0|0)|0;
  $59 = tempRet0;
  ___clang_call_terminate($58);
  // unreachable;
 } else {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
}
function __ZN11OpenThreads6ThreadD2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp + 4|0;
 $2 = sp;
 HEAP32[$0>>2] = (71092);
 $3 = ((($0)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 /* fence */;
 $5 = ((($4)) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 do {
  if (!($7)) {
   $8 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j(214316,160447,14)|0);
   $9 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEPKv($8,$0)|0);
   $10 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($9,160462,28)|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = ((($11)) + -12|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($10) + ($13)|0);
   __ZNKSt3__28ios_base6getlocEv($1,$14);
   __THREW__ = 0;
   $15 = (invoke_iii(3255,($1|0),(215188|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = HEAP32[$15>>2]|0;
    $19 = ((($18)) + 28|0);
    $20 = HEAP32[$19>>2]|0;
    __THREW__ = 0;
    $21 = (invoke_iii($20|0,($15|0),10)|0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if (!($23)) {
     __ZNSt3__26localeD2Ev($1);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($10,$21)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($10)|0);
     $30 = HEAP32[$0>>2]|0;
     $31 = ((($30)) + 8|0);
     $32 = HEAP32[$31>>2]|0;
     (FUNCTION_TABLE_ii[$32 & 8191]($0)|0);
     HEAP32[$2>>2] = 0;
     $33 = HEAP32[$3>>2]|0;
     $34 = ((($33)) + 52|0);
     $35 = HEAP32[$34>>2]|0;
     (_pthread_join(($35|0),($2|0))|0);
     break;
    }
   }
   $24 = ___cxa_find_matching_catch_2()|0;
   $25 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($1|0));
   $26 = __THREW__; __THREW__ = 0;
   $27 = $26&1;
   if ($27) {
    $28 = ___cxa_find_matching_catch_3(0|0)|0;
    $29 = tempRet0;
    ___clang_call_terminate($28);
    // unreachable;
   } else {
    ___resumeException($24|0);
    // unreachable;
   }
  }
 } while(0);
 $36 = ($4|0)==(0|0);
 if ($36) {
  HEAP32[$3>>2] = 0;
  STACKTOP = sp;return;
 }
 $37 = HEAP32[$4>>2]|0;
 $38 = ((($37)) + 4|0);
 $39 = HEAP32[$38>>2]|0;
 FUNCTION_TABLE_vi[$39 & 8191]($4);
 HEAP32[$3>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN11OpenThreads6ThreadD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(2489,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZN11OpenThreads6Thread6cancelEv($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 /* fence */;
 $3 = ((($2)) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 if ($5) {
  $$0 = 0;
  return ($$0|0);
 }
 $6 = ((($2)) + 40|0);
 HEAP8[$6>>0] = 1;
 $7 = ((($2)) + 52|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (_pthread_cancel(($8|0))|0);
 $$0 = $9;
 return ($$0|0);
}
function __Z22thread_cleanup_handlerPv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vi[$4 & 8191]($1);
 $5 = ((($0)) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$6>>2]|0;HEAP32[$6>>2] = 0;
 return;
}
function __ZN11OpenThreads6ThreadC2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, $vararg_buffer = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 HEAP32[$0>>2] = (71092);
 $1 = HEAP8[217118]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $3 = (_pthread_key_create((208804|0),(0|0))|0);
  $4 = ($3|0)==(0);
  if (!($4)) {
   HEAP32[$vararg_buffer>>2] = $3;
   (_printf(160514,$vararg_buffer)|0);
  }
  HEAP8[217118] = 1;
 }
 $5 = (__Znwj(72)|0);
 HEAP32[$5>>2] = (71120);
 $6 = ((($5)) + 12|0);
 HEAP32[$6>>2] = 0;
 $7 = ((($5)) + 16|0);
 __THREW__ = 0;
 invoke_vii(3507,($7|0),0);
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $35 = ___cxa_find_matching_catch_2()|0;
  $36 = tempRet0;
  $eh$lpad$body$index2Z2D = $36;$eh$lpad$body$indexZ2D = $35;
  __ZdlPv($5);
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 $10 = ((($5)) + 28|0);
 __THREW__ = 0;
 invoke_vi(3508,($10|0));
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if (!($12)) {
  $19 = ((($5)) + 36|0);
  HEAP8[$19>>0] = 0;
  $20 = ((($5)) + 64|0);
  HEAP32[$20>>2] = 0;
  $21 = ((($5)) + 68|0);
  HEAP32[$21>>2] = 0;
  $22 = ((($5)) + 60|0);
  HEAP32[$22>>2] = $20;
  $23 = ((($5)) + 4|0);
  HEAP32[$23>>2] = 0;
  $24 = ((($5)) + 8|0);
  HEAP8[$24>>0] = 0;
  $25 = ((($5)) + 41|0);
  HEAP8[$25>>0] = 0;
  $26 = HEAP32[$6>>2]|0;HEAP32[$6>>2] = 0;
  $27 = ((($5)) + 40|0);
  HEAP8[$27>>0] = 0;
  $28 = ((($5)) + 52|0);
  HEAP32[$28>>2] = 0;
  $29 = HEAP32[52200]|0;
  $30 = ((($5)) + 56|0);
  HEAP32[$30>>2] = $29;
  $31 = (($29) + 1)|0;
  HEAP32[52200] = $31;
  $32 = ((($5)) + 44|0);
  HEAP32[$32>>2] = 5;
  $33 = ((($5)) + 48|0);
  HEAP32[$33>>2] = 3;
  $34 = ((($0)) + 4|0);
  HEAP32[$34>>2] = $5;
  STACKTOP = sp;return;
 }
 $13 = ___cxa_find_matching_catch_2()|0;
 $14 = tempRet0;
 __THREW__ = 0;
 invoke_vi(707,($7|0));
 $15 = __THREW__; __THREW__ = 0;
 $16 = $15&1;
 if ($16) {
  $17 = ___cxa_find_matching_catch_3(0|0)|0;
  $18 = tempRet0;
  ___clang_call_terminate($17);
  // unreachable;
 } else {
  $eh$lpad$body$index2Z2D = $14;$eh$lpad$body$indexZ2D = $13;
  __ZdlPv($5);
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
}
function __ZN11OpenThreads18PThreadPrivateDataD2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (71120);
 $1 = ((($0)) + 60|0);
 $2 = ((($0)) + 64|0);
 $3 = HEAP32[$2>>2]|0;
 __ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEE7destroyEPNS_11__tree_nodeIjPvEE($1,$3);
 $4 = ((($0)) + 16|0);
 __ZN11OpenThreads5BlockD2Ev($4);
 return;
}
function __ZN11OpenThreads18PThreadPrivateDataD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (71120);
 $1 = ((($0)) + 60|0);
 $2 = ((($0)) + 64|0);
 $3 = HEAP32[$2>>2]|0;
 __ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEE7destroyEPNS_11__tree_nodeIjPvEE($1,$3);
 $4 = ((($0)) + 16|0);
 __THREW__ = 0;
 invoke_vi(3805,($4|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $7 = ___cxa_find_matching_catch_2()|0;
  $8 = tempRet0;
  __ZdlPv($0);
  ___resumeException($7|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZN11OpenThreads6Thread4joinEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 HEAP32[$1>>2] = 0;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + 52|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (_pthread_join(($5|0),($1|0))|0);
 STACKTOP = sp;return ($6|0);
}
function __ZN11OpenThreads6Thread13CurrentThreadEv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $0 = HEAP8[217118]|0;
 $1 = ($0<<24>>24)==(0);
 if ($1) {
  $2 = (_pthread_key_create((208804|0),(0|0))|0);
  $3 = ($2|0)==(0);
  if (!($3)) {
   HEAP32[$vararg_buffer>>2] = $2;
   (_printf(160514,$vararg_buffer)|0);
  }
  HEAP8[217118] = 1;
 }
 $4 = HEAP32[52201]|0;
 $5 = (_pthread_getspecific(($4|0))|0);
 STACKTOP = sp;return ($5|0);
}
function __ZN11OpenThreads35SetProcessorAffinityOfCurrentThreadERKNS_8AffinityE($0) {
 $0 = $0|0;
 var $$byval_copy = 0, $$byval_copy4 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $$byval_copy4 = sp + 24|0;
 $$byval_copy = sp + 20|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $1 = sp + 16|0;
 $2 = sp + 12|0;
 $3 = HEAP8[217118]|0;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  $5 = (_pthread_key_create((208804|0),(0|0))|0);
  $6 = ($5|0)==(0);
  if (!($6)) {
   HEAP32[$vararg_buffer>>2] = $5;
   (_printf(160514,$vararg_buffer)|0);
  }
  HEAP8[217118] = 1;
 }
 $7 = HEAP32[52201]|0;
 $8 = (_pthread_getspecific(($7|0))|0);
 $9 = ($8|0)==(0|0);
 if ($9) {
  STACKTOP = sp;return -1;
 }
 $10 = ((($8)) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11)) + 60|0);
 $13 = ($12|0)==($0|0);
 if (!($13)) {
  $14 = HEAP32[$0>>2]|0;
  HEAP32[$1>>2] = $14;
  $15 = ((($0)) + 4|0);
  HEAP32[$2>>2] = $15;
  ;HEAP32[$$byval_copy>>2]=HEAP32[$1>>2]|0;
  ;HEAP32[$$byval_copy4>>2]=HEAP32[$2>>2]|0;
  __ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEE14__assign_multiINS_21__tree_const_iteratorIjPNS_11__tree_nodeIjPvEEiEEEEvT_SD_($12,$$byval_copy,$$byval_copy4);
 }
 /* fence */;
 $16 = ((($11)) + 12|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==(0);
 if ($18) {
  STACKTOP = sp;return -1;
 }
 $19 = HEAP8[217118]|0;
 $20 = ($19<<24>>24)==(0);
 if ($20) {
  $21 = (_pthread_key_create((208804|0),(0|0))|0);
  $22 = ($21|0)==(0);
  if (!($22)) {
   HEAP32[$vararg_buffer1>>2] = $21;
   (_printf(160514,$vararg_buffer1)|0);
  }
  HEAP8[217118] = 1;
 }
 $23 = HEAP32[52201]|0;
 (_pthread_getspecific(($23|0))|0);
 STACKTOP = sp;return -1;
}
function __ZN11OpenThreads6Thread20setProcessorAffinityERKNS_8AffinityE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $$byval_copy1 = sp + 16|0;
 $$byval_copy = sp + 12|0;
 $vararg_buffer = sp;
 $2 = sp + 8|0;
 $3 = sp + 4|0;
 $4 = ((($0)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($5)) + 60|0);
 $7 = ($6|0)==($1|0);
 if (!($7)) {
  $8 = HEAP32[$1>>2]|0;
  HEAP32[$2>>2] = $8;
  $9 = ((($1)) + 4|0);
  HEAP32[$3>>2] = $9;
  ;HEAP32[$$byval_copy>>2]=HEAP32[$2>>2]|0;
  ;HEAP32[$$byval_copy1>>2]=HEAP32[$3>>2]|0;
  __ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEE14__assign_multiINS_21__tree_const_iteratorIjPNS_11__tree_nodeIjPvEEiEEEEvT_SD_($6,$$byval_copy,$$byval_copy1);
 }
 /* fence */;
 $10 = ((($5)) + 12|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0);
 if ($12) {
  STACKTOP = sp;return -1;
 }
 $13 = HEAP8[217118]|0;
 $14 = ($13<<24>>24)==(0);
 if ($14) {
  $15 = (_pthread_key_create((208804|0),(0|0))|0);
  $16 = ($15|0)==(0);
  if (!($16)) {
   HEAP32[$vararg_buffer>>2] = $15;
   (_printf(160514,$vararg_buffer)|0);
  }
  HEAP8[217118] = 1;
 }
 $17 = HEAP32[52201]|0;
 (_pthread_getspecific(($17|0))|0);
 STACKTOP = sp;return -1;
}
function __ZN11OpenThreads6Thread9isRunningEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 /* fence */;
 $3 = ((($2)) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)!=(0);
 return ($5|0);
}
function __ZN11OpenThreads6Thread5startEv($0) {
 $0 = $0|0;
 var $$0 = 0, $$2 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $1 = sp + 4|0;
 $2 = sp;
 $3 = (_pthread_attr_init(($1|0))|0);
 $4 = ($3|0)==(0);
 if (!($4)) {
  $$2 = $3;
  STACKTOP = sp;return ($$2|0);
 }
 $5 = ((($0)) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($6)) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0);
 if (!($9)) {
  $10 = HEAP32[$7>>2]|0;
  $11 = ($10>>>0)<(2048);
  if ($11) {
   HEAP32[$7>>2] = 2048;
  }
  $12 = HEAP32[$7>>2]|0;
  $13 = (_pthread_attr_setstacksize(($1|0),($12|0))|0);
  $14 = ($13|0)==(0);
  if (!($14)) {
   $$2 = $13;
   STACKTOP = sp;return ($$2|0);
  }
 }
 $15 = (_pthread_attr_getstacksize(($1|0),($2|0))|0);
 $16 = ($15|0)==(0);
 if ($16) {
  $17 = HEAP32[$2>>2]|0;
  HEAP32[$7>>2] = $17;
  $18 = ((($6)) + 8|0);
  HEAP8[$18>>0] = 1;
  $19 = ((($6)) + 16|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = ((($20)) + 8|0);
  $22 = HEAP32[$21>>2]|0;
  (FUNCTION_TABLE_ii[$22 & 8191]($19)|0);
  $23 = ((($6)) + 36|0);
  HEAP8[$23>>0] = 0;
  $24 = HEAP32[$19>>2]|0;
  $25 = ((($24)) + 12|0);
  $26 = HEAP32[$25>>2]|0;
  (FUNCTION_TABLE_ii[$26 & 8191]($19)|0);
  $27 = ((($6)) + 52|0);
  $28 = (_pthread_create(($27|0),($1|0),(4033|0),($0|0))|0);
  $29 = ($28|0)==(0);
  if ($29) {
   $30 = HEAP32[$19>>2]|0;
   $31 = ((($30)) + 8|0);
   $32 = HEAP32[$31>>2]|0;
   (FUNCTION_TABLE_ii[$32 & 8191]($19)|0);
   $33 = HEAP8[$23>>0]|0;
   $34 = ($33<<24>>24)==(0);
   if ($34) {
    $35 = ((($6)) + 28|0);
    __THREW__ = 0;
    (invoke_iii(2501,($35|0),($19|0))|0);
    $36 = __THREW__; __THREW__ = 0;
    $37 = $36&1;
    if ($37) {
     $38 = ___cxa_find_matching_catch_2()|0;
     $39 = tempRet0;
     $40 = HEAP32[$19>>2]|0;
     $41 = ((($40)) + 12|0);
     $42 = HEAP32[$41>>2]|0;
     __THREW__ = 0;
     (invoke_ii($42|0,($19|0))|0);
     $43 = __THREW__; __THREW__ = 0;
     $44 = $43&1;
     if ($44) {
      $45 = ___cxa_find_matching_catch_3(0|0)|0;
      $46 = tempRet0;
      ___clang_call_terminate($45);
      // unreachable;
     } else {
      ___resumeException($38|0);
      // unreachable;
     }
    }
   }
   $47 = HEAP32[$19>>2]|0;
   $48 = ((($47)) + 12|0);
   $49 = HEAP32[$48>>2]|0;
   (FUNCTION_TABLE_ii[$49 & 8191]($19)|0);
   $50 = ((($6)) + 41|0);
   HEAP8[$50>>0] = 1;
   $$0 = 0;
  } else {
   $$0 = $28;
  }
 } else {
  $$0 = $15;
 }
 $$2 = $$0;
 STACKTOP = sp;return ($$2|0);
}
function __ZN11OpenThreads20ThreadPrivateActions11StartThreadEPv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $1 = sp + 8|0;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 HEAP32[$1>>2] = $0;
 $4 = ((($3)) + 12|0);
 $5 = ((($1)) + 4|0);
 HEAP32[$5>>2] = $4;
 $6 = HEAP32[52201]|0;
 $7 = (_pthread_setspecific(($6|0),($0|0))|0);
 $8 = ($7|0)==(0);
 if (!($8)) {
  HEAP32[$vararg_buffer>>2] = $7;
  (_printf(160615,$vararg_buffer)|0);
 }
 _pthread_cleanup_push((4034|0),($1|0));
 $9 = ((($3)) + 12|0);
 $10 = HEAP32[$9>>2]|0;HEAP32[$9>>2] = 1;
 $11 = ((($3)) + 16|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ((($12)) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 (FUNCTION_TABLE_ii[$14 & 8191]($11)|0);
 $15 = ((($3)) + 36|0);
 $16 = HEAP8[$15>>0]|0;
 $17 = ($16<<24>>24)==(0);
 if ($17) {
  HEAP8[$15>>0] = 1;
  $18 = ((($3)) + 28|0);
  __THREW__ = 0;
  (invoke_ii(2504,($18|0))|0);
  $19 = __THREW__; __THREW__ = 0;
  $20 = $19&1;
  if ($20) {
   $21 = ___cxa_find_matching_catch_2()|0;
   $22 = tempRet0;
   $23 = HEAP32[$11>>2]|0;
   $24 = ((($23)) + 12|0);
   $25 = HEAP32[$24>>2]|0;
   __THREW__ = 0;
   (invoke_ii($25|0,($11|0))|0);
   $26 = __THREW__; __THREW__ = 0;
   $27 = $26&1;
   if ($27) {
    $28 = ___cxa_find_matching_catch_3(0|0)|0;
    $29 = tempRet0;
    ___clang_call_terminate($28);
    // unreachable;
   } else {
    ___resumeException($21|0);
    // unreachable;
   }
  }
 }
 $30 = HEAP32[$11>>2]|0;
 $31 = ((($30)) + 12|0);
 $32 = HEAP32[$31>>2]|0;
 (FUNCTION_TABLE_ii[$32 & 8191]($11)|0);
 $33 = HEAP32[$0>>2]|0;
 $34 = ((($33)) + 12|0);
 $35 = HEAP32[$34>>2]|0;
 FUNCTION_TABLE_vi[$35 & 8191]($0);
 $36 = HEAP32[$9>>2]|0;HEAP32[$9>>2] = 0;
 _pthread_cleanup_pop(0);
 STACKTOP = sp;return (0|0);
}
function __ZN11OpenThreads6Thread11startThreadEv($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  $$0 = 0;
  return ($$0|0);
 }
 $4 = (__ZN11OpenThreads6Thread5startEv($0)|0);
 $$0 = $4;
 return ($$0|0);
}
function __ZN11OpenThreads6Thread10testCancelEv($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (_pthread_self()|0);
 $4 = ((($2)) + 52|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if (!($6)) {
  $$0 = -1;
  return ($$0|0);
 }
 _pthread_testcancel();
 $$0 = 0;
 return ($$0|0);
}
function __ZN11OpenThreads6Thread19setSchedulePriorityENS0_14ThreadPriorityE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return -1;
}
function __ZN11OpenThreads6Thread18YieldCurrentThreadEv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_sched_yield()|0);
 return ($0|0);
}
function __ZN11OpenThreads6Thread10microSleepEj($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (_usleep(($0|0))|0);
 return ($1|0);
}
function __ZN11OpenThreads21GetNumberOfProcessorsEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 1;
}
function __ZN11OpenThreads7BarrierD2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (71136);
 $1 = ((($0)) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 52|0);
 (_pthread_mutex_destroy(($3|0))|0);
 $4 = ((($2)) + 4|0);
 (_pthread_cond_destroy(($4|0))|0);
 $5 = ($2|0)==(0|0);
 if ($5) {
  return;
 }
 $6 = HEAP32[$2>>2]|0;
 $7 = ((($6)) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 FUNCTION_TABLE_vi[$8 & 8191]($2);
 return;
}
function __ZN11OpenThreads7BarrierD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (71136);
 $1 = ((($0)) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 52|0);
 __THREW__ = 0;
 (invoke_ii(4035,($3|0))|0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = ((($2)) + 4|0);
  __THREW__ = 0;
  (invoke_ii(4036,($6|0))|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   $9 = ($2|0)==(0|0);
   if ($9) {
    __ZdlPv($0);
    return;
   }
   $10 = HEAP32[$2>>2]|0;
   $11 = ((($10)) + 4|0);
   $12 = HEAP32[$11>>2]|0;
   __THREW__ = 0;
   invoke_vi($12|0,($2|0));
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if (!($14)) {
    __ZdlPv($0);
    return;
   }
  }
 }
 $15 = ___cxa_find_matching_catch_2()|0;
 $16 = tempRet0;
 __ZdlPv($0);
 ___resumeException($15|0);
 // unreachable;
}
function __ZN11OpenThreads7Barrier5resetEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 84|0);
 HEAP32[$3>>2] = 0;
 $4 = ((($2)) + 88|0);
 HEAP32[$4>>2] = 0;
 return;
}
function __ZN11OpenThreads7Barrier5blockEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)==(0);
 if (!($4)) {
  $5 = ((($3)) + 80|0);
  HEAP32[$5>>2] = $1;
 }
 $6 = ((($3)) + 52|0);
 (_pthread_mutex_lock(($6|0))|0);
 $7 = ((($0)) + 8|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = ($8<<24>>24)==(0);
 if ($9) {
  (_pthread_mutex_unlock(($6|0))|0);
  return;
 }
 $10 = ((($3)) + 88|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($3)) + 84|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($13) + 1)|0;
 HEAP32[$12>>2] = $14;
 $15 = HEAP32[$12>>2]|0;
 $16 = ((($3)) + 80|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($15|0)==($17|0);
 if ($18) {
  HEAP32[$12>>2] = 0;
  $22 = (1 - ($11))|0;
  HEAP32[$10>>2] = $22;
  $23 = ((($3)) + 4|0);
  (_pthread_cond_broadcast(($23|0))|0);
  (_pthread_mutex_unlock(($6|0))|0);
  return;
 }
 $19 = HEAP32[$10>>2]|0;
 $20 = ($19|0)==($11|0);
 if (!($20)) {
  (_pthread_mutex_unlock(($6|0))|0);
  return;
 }
 $21 = ((($3)) + 4|0);
 while(1) {
  _pthread_cleanup_push((4037|0),($6|0));
  (_pthread_cond_wait(($21|0),($6|0))|0);
  _pthread_cleanup_pop(0);
  $24 = HEAP32[$10>>2]|0;
  $25 = ($24|0)==($11|0);
  if (!($25)) {
   break;
  }
 }
 (_pthread_mutex_unlock(($6|0))|0);
 return;
}
function __ZN11OpenThreads7Barrier7releaseEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 52|0);
 (_pthread_mutex_lock(($3|0))|0);
 $4 = ((($2)) + 88|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($2)) + 84|0);
 HEAP32[$6>>2] = 0;
 $7 = (1 - ($5))|0;
 HEAP32[$4>>2] = $7;
 $8 = ((($2)) + 4|0);
 (_pthread_cond_broadcast(($8|0))|0);
 (_pthread_mutex_unlock(($3|0))|0);
 return;
}
function __ZN11OpenThreads7Barrier26numThreadsCurrentlyBlockedEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 52|0);
 (_pthread_mutex_lock(($3|0))|0);
 $4 = ((($2)) + 84|0);
 $5 = HEAP32[$4>>2]|0;
 (_pthread_mutex_unlock(($3|0))|0);
 return ($5|0);
}
function __Z23barrier_cleanup_handlerPv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (_pthread_mutex_unlock(($0|0))|0);
 return;
}
function __ZN11OpenThreads7BarrierC2Ei($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 HEAP32[$0>>2] = (71136);
 $3 = (__Znwj(92)|0);
 HEAP32[$3>>2] = (71168);
 $4 = ((($3)) + 84|0);
 HEAP32[$4>>2] = 0;
 $5 = ((($3)) + 88|0);
 HEAP32[$5>>2] = 0;
 $6 = ((($3)) + 80|0);
 HEAP32[$6>>2] = $1;
 $7 = ((($0)) + 8|0);
 HEAP8[$7>>0] = 1;
 (_pthread_mutexattr_init(($2|0))|0);
 (_pthread_mutexattr_settype(($2|0),2)|0);
 $8 = ((($3)) + 52|0);
 (_pthread_mutex_init(($8|0),($2|0))|0);
 $9 = ((($3)) + 4|0);
 (_pthread_cond_init(($9|0),(0|0))|0);
 $10 = ((($0)) + 4|0);
 HEAP32[$10>>2] = $3;
 STACKTOP = sp;return;
}
function __ZN11OpenThreads25PThreadBarrierPrivateDataD2Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN11OpenThreads25PThreadBarrierPrivateDataD0Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($0);
 return;
}
function __ZN11OpenThreads9ConditionD2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 HEAP32[$0>>2] = (71184);
 $1 = ((($0)) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 4|0);
 $4 = (_pthread_cond_destroy(($3|0))|0);
 $5 = ($4|0)==(0);
 if (!($5)) {
  HEAP32[$vararg_buffer>>2] = $4;
  (_printf(160748,$vararg_buffer)|0);
 }
 $6 = ($2|0)==(0|0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = HEAP32[$2>>2]|0;
 $8 = ((($7)) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 FUNCTION_TABLE_vi[$9 & 8191]($2);
 STACKTOP = sp;return;
}
function __ZN11OpenThreads9ConditionD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 HEAP32[$0>>2] = (71184);
 $1 = ((($0)) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 4|0);
 __THREW__ = 0;
 $4 = (invoke_ii(4036,($3|0))|0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $14 = ___cxa_find_matching_catch_2()|0;
  $15 = tempRet0;
  __ZdlPv($0);
  ___resumeException($14|0);
  // unreachable;
 }
 $7 = ($4|0)==(0);
 if (!($7)) {
  HEAP32[$vararg_buffer>>2] = $4;
  (_printf(160748,$vararg_buffer)|0);
 }
 $8 = ($2|0)==(0|0);
 if ($8) {
  __ZdlPv($0);
  STACKTOP = sp;return;
 }
 $9 = HEAP32[$2>>2]|0;
 $10 = ((($9)) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 __THREW__ = 0;
 invoke_vi($11|0,($2|0));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $14 = ___cxa_find_matching_catch_2()|0;
  $15 = tempRet0;
  __ZdlPv($0);
  ___resumeException($14|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  STACKTOP = sp;return;
 }
}
function __ZN11OpenThreads9Condition4waitEPNS_5MutexE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($5)) + 4|0);
 _pthread_cleanup_push((4038|0),($6|0));
 $7 = ((($3)) + 4|0);
 $8 = (_pthread_cond_wait(($7|0),($6|0))|0);
 _pthread_cleanup_pop(0);
 return ($8|0);
}
function __ZN11OpenThreads9Condition4waitEPNS_5MutexEm($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp + 8|0;
 $4 = sp;
 $5 = ((($0)) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($1)) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($2>>>0) / 1000)&-1;
 $10 = (($2>>>0) % 1000)&-1;
 $11 = ($10*1000000)|0;
 (_gettimeofday(($3|0),(0|0))|0);
 $12 = HEAP32[$3>>2]|0;
 $13 = (($12) + ($9))|0;
 $14 = ((($3)) + 4|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15*1000)|0;
 $17 = (($16) + ($11))|0;
 $18 = (($17>>>0) / 1000000000)&-1;
 $19 = (($13) + ($18))|0;
 $20 = (($17>>>0) % 1000000000)&-1;
 HEAP32[$4>>2] = $19;
 $21 = ((($4)) + 4|0);
 HEAP32[$21>>2] = $20;
 $22 = ((($8)) + 4|0);
 _pthread_cleanup_push((4038|0),($22|0));
 $23 = ((($6)) + 4|0);
 $24 = (_pthread_cond_timedwait(($23|0),($22|0),($4|0))|0);
 _pthread_cleanup_pop(0);
 STACKTOP = sp;return ($24|0);
}
function __ZN11OpenThreads9Condition6signalEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 4|0);
 $4 = (_pthread_cond_signal(($3|0))|0);
 return ($4|0);
}
function __ZN11OpenThreads9Condition9broadcastEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 4|0);
 $4 = (_pthread_cond_broadcast(($3|0))|0);
 return ($4|0);
}
function __Z25condition_cleanup_handlerPv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (_pthread_mutex_unlock(($0|0))|0);
 return;
}
function __ZN11OpenThreads9ConditionC2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 HEAP32[$0>>2] = (71184);
 $1 = (__Znwj(52)|0);
 HEAP32[$1>>2] = (71216);
 $2 = ((($1)) + 4|0);
 $3 = (_pthread_cond_init(($2|0),(0|0))|0);
 $4 = ($3|0)==(0);
 if (!($4)) {
  HEAP32[$vararg_buffer>>2] = $3;
  (_printf(160841,$vararg_buffer)|0);
 }
 $5 = ((($0)) + 4|0);
 HEAP32[$5>>2] = $1;
 STACKTOP = sp;return;
}
function __ZN11OpenThreads27PThreadConditionPrivateDataD2Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN11OpenThreads27PThreadConditionPrivateDataD0Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($0);
 return;
}
function __ZN11OpenThreads5MutexD2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (71232);
 $1 = ((($0)) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 4|0);
 (_pthread_mutex_destroy(($3|0))|0);
 $4 = ($2|0)==(0|0);
 if ($4) {
  return;
 }
 $5 = HEAP32[$2>>2]|0;
 $6 = ((($5)) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 FUNCTION_TABLE_vi[$7 & 8191]($2);
 return;
}
function __ZN11OpenThreads5MutexD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (71232);
 $1 = ((($0)) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 4|0);
 __THREW__ = 0;
 (invoke_ii(4035,($3|0))|0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = ($2|0)==(0|0);
  if ($6) {
   __ZdlPv($0);
   return;
  }
  $7 = HEAP32[$2>>2]|0;
  $8 = ((($7)) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  __THREW__ = 0;
  invoke_vi($9|0,($2|0));
  $10 = __THREW__; __THREW__ = 0;
  $11 = $10&1;
  if (!($11)) {
   __ZdlPv($0);
   return;
  }
 }
 $12 = ___cxa_find_matching_catch_2()|0;
 $13 = tempRet0;
 __ZdlPv($0);
 ___resumeException($12|0);
 // unreachable;
}
function __ZN11OpenThreads5Mutex4lockEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 4|0);
 $4 = (_pthread_mutex_lock(($3|0))|0);
 return ($4|0);
}
function __ZN11OpenThreads5Mutex6unlockEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 4|0);
 $4 = (_pthread_mutex_unlock(($3|0))|0);
 return ($4|0);
}
function __ZN11OpenThreads5Mutex7trylockEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 4|0);
 $4 = (_pthread_mutex_trylock(($3|0))|0);
 return ($4|0);
}
function __ZN11OpenThreads5MutexC2ENS0_9MutexTypeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 HEAP32[$0>>2] = (71232);
 $3 = ((($0)) + 8|0);
 HEAP32[$3>>2] = $1;
 (_pthread_mutexattr_init(($2|0))|0);
 $4 = (__Znwj(32)|0);
 HEAP32[$4>>2] = (71260);
 $5 = ($1|0)==(1);
 if ($5) {
  (_pthread_mutexattr_settype(($2|0),1)|0);
 } else {
  (_pthread_mutexattr_settype(($2|0),2)|0);
 }
 $6 = ((($4)) + 4|0);
 (_pthread_mutex_init(($6|0),($2|0))|0);
 $7 = ((($0)) + 4|0);
 HEAP32[$7>>2] = $4;
 STACKTOP = sp;return;
}
function __ZN11OpenThreads23PThreadMutexPrivateDataD2Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN11OpenThreads23PThreadMutexPrivateDataD0Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($0);
 return;
}
function __GLOBAL__sub_I_application_cpp() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 ___cxx_global_var_init_4242();
 ___cxx_global_var_init_1_4243();
 ___cxx_global_var_init_2_4244();
 return;
}
function ___cxx_global_var_init_4242() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg5Vec3fC2Efff(208832,1.0,0.0,0.0);
 return;
}
function ___cxx_global_var_init_1_4243() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg5Vec3fC2Efff(208820,0.0,1.0,0.0);
 return;
}
function ___cxx_global_var_init_2_4244() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg5Vec3fC2Efff(208808,0.0,0.0,1.0);
 return;
}
function __ZN4mjin11application5setupEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN4mjin11application6memory12setupLoggingEv();
 return;
}
function __ZN4mjin11application8tearDownEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN4mjin11application6memory15tearDownLoggingEv();
 return;
}
function __ZN4mjin11application5frameEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN4mjin11application6memory5frameEv();
 return;
}
function __ZN4mjin11application11setupViewerEPN9osgViewer6ViewerEii($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = $0;
 $4 = $1;
 $5 = $2;
 $6 = $3;
 HEAP32[52211] = $6;
 $7 = $3;
 $8 = $4;
 $9 = $5;
 __ZN4mjin11application6memory14setupRenderingEPN9osgViewer6ViewerEii($7,$8,$9);
 $10 = $3;
 __ZN4mjin11application6memory10setupSceneEPN9osgViewer6ViewerE($10);
 STACKTOP = sp;return;
}
function __ZN4mjin11application14tearDownViewerEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN4mjin11application6memory13tearDownSceneEv();
 __ZN4mjin11application6memory17tearDownRenderingEv();
 return;
}
function __GLOBAL__sub_I_memory_cpp() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 ___cxx_global_var_init_4261();
 ___cxx_global_var_init_1_4262();
 ___cxx_global_var_init_2_4263();
 return;
}
function ___cxx_global_var_init_4261() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg5Vec3fC2Efff(208876,1.0,0.0,0.0);
 return;
}
function ___cxx_global_var_init_1_4262() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg5Vec3fC2Efff(208864,0.0,1.0,0.0);
 return;
}
function ___cxx_global_var_init_2_4263() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg5Vec3fC2Efff(208852,0.0,0.0,1.0);
 return;
}
function __ZN4mjin11application6memory12setupLoggingEv() {
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = (__Znwj(12)|0);
 __THREW__ = 0;
 invoke_vi(4039,($3|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $7 = ___cxa_find_matching_catch_2()|0;
  $8 = tempRet0;
  $1 = $7;
  $2 = $8;
  __ZdlPv($3);
  $9 = $1;
  $10 = $2;
  ___resumeException($9|0);
  // unreachable;
 } else {
  $0 = $3;
  $6 = $0;
  __ZN3osg16setNotifyHandlerEPNS_13NotifyHandlerE($6);
  __ZN3osg14setNotifyLevelENS_14NotifySeverityE(2);
  STACKTOP = sp;return;
 }
}
function __ZN4mjin11application6memory15tearDownLoggingEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg16setNotifyHandlerEPNS_13NotifyHandlerE(0);
 return;
}
function __ZN4mjin11application6memory14setupRenderingEPN9osgViewer6ViewerEii($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0.0, $18 = 0.0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0.0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $3 = $0;
 $4 = $1;
 $5 = $2;
 $9 = $3;
 $10 = ((($9)) + 104|0);
 $11 = (__Znwj(288)|0);
 __THREW__ = 0;
 invoke_vii(3390,($11|0),5);
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $25 = ___cxa_find_matching_catch_2()|0;
  $26 = tempRet0;
  $6 = $25;
  $7 = $26;
  __ZdlPv($11);
  $27 = $6;
  $28 = $7;
  ___resumeException($27|0);
  // unreachable;
 } else {
  __ZN9osgViewer4View20setCameraManipulatorEPN5osgGA17CameraManipulatorEb($10,$11,1);
  $8 = 30.0;
  $14 = $3;
  $15 = ((($14)) + 104|0);
  $16 = (__ZN3osg4View9getCameraEv($15)|0);
  $17 = $8;
  $18 = $17;
  $19 = $4;
  $20 = $5;
  __ZN4mjin6render11setupCameraEPN3osg6CameraEdii($16,$18,$19,$20);
  $21 = $3;
  $22 = HEAP32[$21>>2]|0;
  $23 = ((($22)) + 32|0);
  $24 = HEAP32[$23>>2]|0;
  FUNCTION_TABLE_vii[$24 & 8191]($21,0);
  STACKTOP = sp;return;
 }
}
function __ZN4mjin11application6memory17tearDownRenderingEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN4mjin11application6memory10setupSceneEPN9osgViewer6ViewerE($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $4 = (__Znwj(20)|0);
 $5 = $1;
 __THREW__ = 0;
 invoke_vii(4040,($4|0),($5|0));
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if ($7) {
  $8 = ___cxa_find_matching_catch_2()|0;
  $9 = tempRet0;
  $2 = $8;
  $3 = $9;
  __ZdlPv($4);
  $10 = $2;
  $11 = $3;
  ___resumeException($10|0);
  // unreachable;
 } else {
  HEAP32[52212] = $4;
  STACKTOP = sp;return;
 }
}
function __ZN4mjin11application6memory13tearDownSceneEv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[52211]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + 164|0);
 $3 = HEAP32[$2>>2]|0;
 FUNCTION_TABLE_vii[$3 & 8191]($0,0);
 $4 = HEAP32[52212]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  return;
 }
 __ZN4mjin11application6memory11CoordinatorD2Ev($4);
 __ZdlPv($4);
 return;
}
function __ZN4mjin11application6memory5frameEv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[161013]|0;
 $1 = $0&1;
 if ($1) {
  HEAP8[161013] = 0;
  $2 = HEAP32[52212]|0;
  __ZN4mjin11application6memory11Coordinator16renderFirstFrameEv($2);
 }
 $3 = HEAP32[52211]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($4)) + 64|0);
 $6 = HEAP32[$5>>2]|0;
 FUNCTION_TABLE_vid[$6 & 8191]($3,1.7976931348623157E+308);
 $7 = HEAP32[52212]|0;
 __ZN4mjin11application6memory11Coordinator4tickEv($7);
 return;
}
function __GLOBAL__sub_I_Coordinator_cpp() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 ___cxx_global_var_init_4282();
 ___cxx_global_var_init_1_4283();
 ___cxx_global_var_init_2_4284();
 return;
}
function ___cxx_global_var_init_4282() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg5Vec3fC2Efff(208912,1.0,0.0,0.0);
 return;
}
function ___cxx_global_var_init_1_4283() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg5Vec3fC2Efff(208900,0.0,1.0,0.0);
 return;
}
function ___cxx_global_var_init_2_4284() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg5Vec3fC2Efff(208888,0.0,0.0,1.0);
 return;
}
function __ZN4mjin11application6memory11CoordinatorC2EPN9osgViewer6ViewerE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = $0;
 $3 = $1;
 $6 = $2;
 __ZN3osg7ref_ptrINS_4NodeEEC2Ev($6);
 $7 = ((($6)) + 12|0);
 $8 = $3;
 HEAP32[$7>>2] = $8;
 __THREW__ = 0;
 $9 = (invoke_ii(3276,24)|0);
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 do {
  if (!($11)) {
   __THREW__ = 0;
   invoke_vi(4041,($9|0));
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if ($13) {
    $40 = ___cxa_find_matching_catch_2()|0;
    $41 = tempRet0;
    $4 = $40;
    $5 = $41;
    __ZdlPv($9);
    __ZN3osg7ref_ptrINS_4NodeEED2Ev($6);
    $44 = $4;
    $45 = $5;
    ___resumeException($44|0);
    // unreachable;
   }
   $14 = ((($6)) + 16|0);
   HEAP32[$14>>2] = $9;
   __THREW__ = 0;
   $15 = (invoke_ii(3276,80)|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = $3;
    $19 = ((($18)) + 104|0);
    __THREW__ = 0;
    $20 = (invoke_ii(4042,($19|0))|0);
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if (!($22)) {
     $23 = ((($6)) + 16|0);
     $24 = HEAP32[$23>>2]|0;
     __THREW__ = 0;
     invoke_viii(4043,($15|0),($20|0),($24|0));
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if (!($26)) {
      $27 = ((($6)) + 8|0);
      HEAP32[$27>>2] = $15;
      $28 = ((($6)) + 8|0);
      $29 = HEAP32[$28>>2]|0;
      __THREW__ = 0;
      (invoke_iii(4044,($6|0),($29|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       break;
      }
      $32 = ((($6)) + 8|0);
      $33 = HEAP32[$32>>2]|0;
      __THREW__ = 0;
      invoke_vi(4045,($33|0));
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(4046,($6|0));
      $36 = __THREW__; __THREW__ = 0;
      $37 = $36&1;
      if ($37) {
       break;
      }
      STACKTOP = sp;return;
     }
    }
    $42 = ___cxa_find_matching_catch_2()|0;
    $43 = tempRet0;
    $4 = $42;
    $5 = $43;
    __ZdlPv($15);
    __ZN3osg7ref_ptrINS_4NodeEED2Ev($6);
    $44 = $4;
    $45 = $5;
    ___resumeException($44|0);
    // unreachable;
   }
  }
 } while(0);
 $38 = ___cxa_find_matching_catch_2()|0;
 $39 = tempRet0;
 $4 = $38;
 $5 = $39;
 __ZN3osg7ref_ptrINS_4NodeEED2Ev($6);
 $44 = $4;
 $45 = $5;
 ___resumeException($44|0);
 // unreachable;
}
function __ZN3osg7ref_ptrINS_4NodeEEC2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN3osg7ref_ptrINS_4NodeEEaSINS_5GroupEEERS2_RKNS0_IT_EE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = $0;
 $3 = $1;
 $4 = $2;
 $5 = $3;
 __ZN3osg7ref_ptrINS_4NodeEE6assignINS_5GroupEEEvRKNS0_IT_EE($4,$5);
 STACKTOP = sp;return ($4|0);
}
function __ZN4mjin11application6memory11Coordinator14setupSelectionEv($0) {
 $0 = $0|0;
 var $$byval_copy = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(80|0);
 $$byval_copy = sp + 64|0;
 $4 = sp + 24|0;
 $5 = sp;
 $6 = sp + 48|0;
 $1 = $0;
 $7 = $1;
 $8 = (__Znwj(124)|0);
 __THREW__ = 0;
 invoke_vi(4047,($8|0));
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if ($10) {
  $24 = ___cxa_find_matching_catch_2()|0;
  $25 = tempRet0;
  $2 = $24;
  $3 = $25;
  __ZdlPv($8);
  $30 = $2;
  $31 = $3;
  ___resumeException($30|0);
  // unreachable;
 }
 $11 = ((($7)) + 4|0);
 HEAP32[$11>>2] = $8;
 $12 = ((($7)) + 12|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($13)) + 104|0);
 $15 = ((($7)) + 4|0);
 $16 = HEAP32[$15>>2]|0;
 __ZN9osgViewer4View15addEventHandlerEPN5osgGA12EventHandlerE($14,$16);
 $17 = ((($7)) + 4|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ((($18)) + 56|0);
 HEAP32[$6>>2] = $7;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$6>>2]|0;
 __ZNSt3__28functionIFvRKbEEC2IZN4mjin11application6memory11Coordinator14setupSelectionEvE3__0vEET_($5,$$byval_copy);
 __THREW__ = 0;
 invoke_vii(4048,($4|0),($5|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 do {
  if ($21) {
   $26 = ___cxa_find_matching_catch_2()|0;
   $27 = tempRet0;
   $2 = $26;
   $3 = $27;
  } else {
   __THREW__ = 0;
   invoke_vii(4049,($19|0),($4|0));
   $22 = __THREW__; __THREW__ = 0;
   $23 = $22&1;
   if ($23) {
    $28 = ___cxa_find_matching_catch_2()|0;
    $29 = tempRet0;
    $2 = $28;
    $3 = $29;
    __ZN4mjin11application6memory10observable16VariableCallbackIbED2Ev($4);
    break;
   } else {
    __ZN4mjin11application6memory10observable16VariableCallbackIbED2Ev($4);
    __ZNSt3__28functionIFvRKbEED2Ev($5);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 __ZNSt3__28functionIFvRKbEED2Ev($5);
 $30 = $2;
 $31 = $3;
 ___resumeException($30|0);
 // unreachable;
}
function __ZN3osg7ref_ptrINS_4NodeEED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)!=(0|0);
 if (!($4)) {
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 $5 = HEAP32[$2>>2]|0;
 __THREW__ = 0;
 (invoke_ii(4050,($5|0))|0);
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if ($7) {
  $8 = ___cxa_find_matching_catch_3(0|0)|0;
  $9 = tempRet0;
  ___clang_call_terminate($8);
  // unreachable;
 } else {
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
}
function __ZNK3osg10Referenced5unrefEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $4 = $1;
 $5 = ((($4)) + 8|0);
 $6 = (__ZN11OpenThreads6AtomicmmEv($5)|0);
 $2 = $6;
 $7 = $2;
 $8 = ($7|0)==(0);
 $9 = $8&1;
 $3 = $9;
 $10 = $3;
 $11 = $10&1;
 if (!($11)) {
  $12 = $2;
  STACKTOP = sp;return ($12|0);
 }
 __ZNK3osg10Referenced24signalObserversAndDeleteEbb($4,1,1);
 $12 = $2;
 STACKTOP = sp;return ($12|0);
}
function __ZN11OpenThreads6AtomicmmEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;HEAP32[$2>>2] = (($3-1)|0);
 $4 = (($3) - 1)|0;
 STACKTOP = sp;return ($4|0);
}
function __ZNSt3__28functionIFvRKbEEC2IZN4mjin11application6memory11Coordinator14setupSelectionEvE3__0vEET_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(224|0);
 $10 = sp + 88|0;
 $11 = sp + 80|0;
 $12 = sp + 72|0;
 $13 = sp + 64|0;
 $17 = sp + 222|0;
 $18 = sp + 221|0;
 $19 = sp + 220|0;
 $20 = sp + 219|0;
 $22 = sp + 160|0;
 $25 = sp + 218|0;
 $32 = sp + 56|0;
 $33 = sp + 48|0;
 $34 = sp + 40|0;
 $35 = sp + 32|0;
 $36 = sp + 24|0;
 $39 = sp + 217|0;
 $40 = sp + 116|0;
 $41 = sp + 216|0;
 $42 = sp + 215|0;
 $43 = sp + 214|0;
 $44 = sp + 16|0;
 $45 = sp + 8|0;
 $46 = sp;
 $50 = sp + 213|0;
 $51 = sp + 100|0;
 $52 = sp + 212|0;
 $54 = $0;
 $55 = $54;
 $56 = ((($55)) + 16|0);
 HEAP32[$56>>2] = 0;
 $53 = $1;
 $2 = $1;
 $57 = $2;
 $48 = $55;
 $49 = $57;
 $58 = $48;
 $47 = $58;
 $59 = $47;
 HEAP32[$59>>2] = (71296);
 HEAP32[$58>>2] = (71340);
 $60 = ((($58)) + 4|0);
 $61 = $49;
 $3 = $61;
 $62 = $3;
 $23 = $62;
 $63 = $23;
 $21 = $63;
 $64 = $21;
 $15 = $22;
 $16 = $64;
 $65 = $15;
 $66 = $16;
 $14 = $66;
 $67 = $14;
 ;HEAP8[$10>>0]=HEAP8[$20>>0]|0;
 ;HEAP8[$11>>0]=HEAP8[$19>>0]|0;
 ;HEAP8[$12>>0]=HEAP8[$18>>0]|0;
 ;HEAP8[$13>>0]=HEAP8[$17>>0]|0;
 $8 = $65;
 $9 = $67;
 $68 = $8;
 $69 = $9;
 $7 = $69;
 $70 = $7;
 $5 = $68;
 $6 = $70;
 $71 = $5;
 $72 = $6;
 $4 = $72;
 $73 = $4;
 HEAP32[$71>>2] = $73;
 $74 = HEAP32[$22>>2]|0;
 HEAP32[$51>>2] = $74;
 $24 = $25;
 ;HEAP8[$44>>0]=HEAP8[$52>>0]|0;
 ;HEAP8[$45>>0]=HEAP8[$51>>0]|0;HEAP8[$45+1>>0]=HEAP8[$51+1>>0]|0;HEAP8[$45+2>>0]=HEAP8[$51+2>>0]|0;HEAP8[$45+3>>0]=HEAP8[$51+3>>0]|0;
 ;HEAP8[$46>>0]=HEAP8[$50>>0]|0;
 $38 = $60;
 $75 = $38;
 $37 = $45;
 $76 = $37;
 ;HEAP32[$40>>2]=HEAP32[$76>>2]|0;
 $26 = $44;
 ;HEAP8[$32>>0]=HEAP8[$43>>0]|0;
 ;HEAP8[$33>>0]=HEAP8[$42>>0]|0;
 ;HEAP8[$34>>0]=HEAP8[$41>>0]|0;
 ;HEAP8[$35>>0]=HEAP8[$40>>0]|0;HEAP8[$35+1>>0]=HEAP8[$40+1>>0]|0;HEAP8[$35+2>>0]=HEAP8[$40+2>>0]|0;HEAP8[$35+3>>0]=HEAP8[$40+3>>0]|0;
 ;HEAP8[$36>>0]=HEAP8[$39>>0]|0;
 $31 = $75;
 $77 = $31;
 $30 = $77;
 $28 = $35;
 $78 = $28;
 $27 = $78;
 $79 = $27;
 $80 = HEAP32[$79>>2]|0;
 $29 = $80;
 $81 = $29;
 ;HEAP32[$77>>2]=HEAP32[$81>>2]|0;
 $82 = ((($55)) + 16|0);
 HEAP32[$82>>2] = $55;
 STACKTOP = sp;return;
}
function __ZN4mjin11application6memory10observable16VariableCallbackIbEC2ENSt3__28functionIFvRKbEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = $0;
 $3 = $2;
 __ZNSt3__28functionIFvRKbEEC2ERKS4_($3,$1);
 STACKTOP = sp;return;
}
function __ZN4mjin11application6memory10observable8VariableIbE9subscribeENS2_16VariableCallbackIbEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(112|0);
 $14 = sp;
 $19 = sp + 109|0;
 $29 = sp + 108|0;
 $30 = $0;
 $31 = $30;
 $32 = ((($31)) + 4|0);
 $27 = $32;
 $28 = $1;
 $33 = $27;
 $34 = ((($33)) + 4|0);
 $35 = HEAP32[$34>>2]|0;
 $26 = $33;
 $36 = $26;
 $37 = ((($36)) + 8|0);
 $25 = $37;
 $38 = $25;
 $24 = $38;
 $39 = $24;
 $40 = HEAP32[$39>>2]|0;
 $41 = ($35|0)!=($40|0);
 if ($41) {
  $21 = $29;
  $22 = $33;
  $23 = 1;
  $5 = $33;
  $42 = $5;
  $43 = ((($42)) + 8|0);
  $4 = $43;
  $44 = $4;
  $3 = $44;
  $45 = $3;
  $46 = ((($33)) + 4|0);
  $47 = HEAP32[$46>>2]|0;
  $2 = $47;
  $48 = $2;
  $49 = $28;
  $16 = $45;
  $17 = $48;
  $18 = $49;
  $50 = $16;
  $51 = $17;
  $52 = $18;
  $15 = $52;
  $53 = $15;
  ;HEAP8[$14>>0]=HEAP8[$19>>0]|0;
  $11 = $50;
  $12 = $51;
  $13 = $53;
  $54 = $11;
  $55 = $12;
  $56 = $13;
  $10 = $56;
  $57 = $10;
  $7 = $54;
  $8 = $55;
  $9 = $57;
  $58 = $8;
  $59 = $9;
  $6 = $59;
  $60 = $6;
  __ZN4mjin11application6memory10observable16VariableCallbackIbEC2ERKS4_($58,$60);
  $20 = $29;
  $61 = ((($33)) + 4|0);
  $62 = HEAP32[$61>>2]|0;
  $63 = ((($62)) + 24|0);
  HEAP32[$61>>2] = $63;
  __ZNKSt3__28functionIFvRKbEEclES2_($1,$31);
  STACKTOP = sp;return;
 } else {
  $64 = $28;
  __ZNSt3__26vectorIN4mjin11application6memory10observable16VariableCallbackIbEENS_9allocatorIS6_EEE21__push_back_slow_pathIRKS6_EEvOT_($33,$64);
  __ZNKSt3__28functionIFvRKbEEclES2_($1,$31);
  STACKTOP = sp;return;
 }
}
function __ZN4mjin11application6memory10observable16VariableCallbackIbED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 __ZNSt3__28functionIFvRKbEED2Ev($2);
 STACKTOP = sp;return;
}
function __ZNSt3__28functionIFvRKbEED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 $3 = ((($2)) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==($2|0);
 $6 = ((($2)) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 if ($5) {
  $8 = HEAP32[$7>>2]|0;
  $9 = ((($8)) + 16|0);
  $10 = HEAP32[$9>>2]|0;
  FUNCTION_TABLE_vi[$10 & 8191]($7);
  STACKTOP = sp;return;
 }
 $11 = ($7|0)!=(0|0);
 if (!($11)) {
  STACKTOP = sp;return;
 }
 $12 = ((($2)) + 16|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = HEAP32[$13>>2]|0;
 $15 = ((($14)) + 20|0);
 $16 = HEAP32[$15>>2]|0;
 FUNCTION_TABLE_vi[$16 & 8191]($13);
 STACKTOP = sp;return;
}
function __ZN4mjin11application6memory10observable16VariableCallbackIbEC2ERKS4_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = $0;
 $3 = $1;
 $4 = $2;
 $5 = $3;
 __ZNSt3__28functionIFvRKbEEC2ERKS4_($4,$5);
 STACKTOP = sp;return;
}
function __ZNSt3__26vectorIN4mjin11application6memory10observable16VariableCallbackIbEENS_9allocatorIS6_EEE21__push_back_slow_pathIRKS6_EEvOT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0;
 var $136 = 0, $137 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 208|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(208|0);
 $10 = sp + 8|0;
 $15 = sp + 201|0;
 $24 = sp;
 $27 = sp + 200|0;
 $35 = sp + 80|0;
 $38 = sp + 68|0;
 $46 = sp + 20|0;
 $43 = $0;
 $44 = $1;
 $49 = $43;
 $42 = $49;
 $50 = $42;
 $51 = ((($50)) + 8|0);
 $41 = $51;
 $52 = $41;
 $40 = $52;
 $53 = $40;
 $45 = $53;
 $39 = $49;
 $54 = $39;
 $55 = ((($54)) + 4|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = HEAP32[$54>>2]|0;
 $58 = $56;
 $59 = $57;
 $60 = (($58) - ($59))|0;
 $61 = (($60|0) / 24)&-1;
 $62 = (($61) + 1)|0;
 $34 = $49;
 HEAP32[$35>>2] = $62;
 $63 = $34;
 $64 = (__ZNKSt3__26vectorIN4mjin11application6memory10observable16VariableCallbackIbEENS_9allocatorIS6_EEE8max_sizeEv($63)|0);
 $36 = $64;
 $65 = HEAP32[$35>>2]|0;
 $66 = $36;
 $67 = ($65>>>0)>($66>>>0);
 if ($67) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($63);
  // unreachable;
 }
 $32 = $63;
 $68 = $32;
 $31 = $68;
 $69 = $31;
 $30 = $69;
 $70 = $30;
 $71 = ((($70)) + 8|0);
 $29 = $71;
 $72 = $29;
 $28 = $72;
 $73 = $28;
 $74 = HEAP32[$73>>2]|0;
 $75 = HEAP32[$69>>2]|0;
 $76 = $74;
 $77 = $75;
 $78 = (($76) - ($77))|0;
 $79 = (($78|0) / 24)&-1;
 $37 = $79;
 $80 = $37;
 $81 = $36;
 $82 = (($81>>>0) / 2)&-1;
 $83 = ($80>>>0)>=($82>>>0);
 if ($83) {
  $84 = $36;
  $33 = $84;
 } else {
  $85 = $37;
  $86 = $85<<1;
  HEAP32[$38>>2] = $86;
  $25 = $38;
  $26 = $35;
  $87 = $25;
  $88 = $26;
  ;HEAP8[$24>>0]=HEAP8[$27>>0]|0;
  $22 = $87;
  $23 = $88;
  $89 = $22;
  $90 = $23;
  $19 = $24;
  $20 = $89;
  $21 = $90;
  $91 = $20;
  $92 = HEAP32[$91>>2]|0;
  $93 = $21;
  $94 = HEAP32[$93>>2]|0;
  $95 = ($92>>>0)<($94>>>0);
  $96 = $23;
  $97 = $22;
  $98 = $95 ? $96 : $97;
  $99 = HEAP32[$98>>2]|0;
  $33 = $99;
 }
 $100 = $33;
 $18 = $49;
 $101 = $18;
 $102 = ((($101)) + 4|0);
 $103 = HEAP32[$102>>2]|0;
 $104 = HEAP32[$101>>2]|0;
 $105 = $103;
 $106 = $104;
 $107 = (($105) - ($106))|0;
 $108 = (($107|0) / 24)&-1;
 $109 = $45;
 __ZNSt3__214__split_bufferIN4mjin11application6memory10observable16VariableCallbackIbEERNS_9allocatorIS6_EEEC2EjjS9_($46,$100,$108,$109);
 $110 = $45;
 $111 = ((($46)) + 8|0);
 $112 = HEAP32[$111>>2]|0;
 $17 = $112;
 $113 = $17;
 $114 = $44;
 $16 = $114;
 $115 = $16;
 $12 = $110;
 $13 = $113;
 $14 = $115;
 $116 = $12;
 $117 = $13;
 $118 = $14;
 $11 = $118;
 $119 = $11;
 ;HEAP8[$10>>0]=HEAP8[$15>>0]|0;
 $7 = $116;
 $8 = $117;
 $9 = $119;
 $120 = $7;
 $121 = $8;
 $122 = $9;
 $6 = $122;
 $123 = $6;
 $3 = $120;
 $4 = $121;
 $5 = $123;
 $124 = $4;
 $125 = $5;
 $2 = $125;
 $126 = $2;
 __THREW__ = 0;
 invoke_vii(4051,($124|0),($126|0));
 $127 = __THREW__; __THREW__ = 0;
 $128 = $127&1;
 if ($128) {
  $134 = ___cxa_find_matching_catch_2()|0;
  $135 = tempRet0;
  $47 = $134;
  $48 = $135;
  __ZNSt3__214__split_bufferIN4mjin11application6memory10observable16VariableCallbackIbEERNS_9allocatorIS6_EEED2Ev($46);
  $136 = $47;
  $137 = $48;
  ___resumeException($136|0);
  // unreachable;
 }
 $129 = ((($46)) + 8|0);
 $130 = HEAP32[$129>>2]|0;
 $131 = ((($130)) + 24|0);
 HEAP32[$129>>2] = $131;
 __THREW__ = 0;
 invoke_vii(4052,($49|0),($46|0));
 $132 = __THREW__; __THREW__ = 0;
 $133 = $132&1;
 if ($133) {
  $134 = ___cxa_find_matching_catch_2()|0;
  $135 = tempRet0;
  $47 = $134;
  $48 = $135;
  __ZNSt3__214__split_bufferIN4mjin11application6memory10observable16VariableCallbackIbEERNS_9allocatorIS6_EEED2Ev($46);
  $136 = $47;
  $137 = $48;
  ___resumeException($136|0);
  // unreachable;
 } else {
  __ZNSt3__214__split_bufferIN4mjin11application6memory10observable16VariableCallbackIbEERNS_9allocatorIS6_EEED2Ev($46);
  STACKTOP = sp;return;
 }
}
function __ZNKSt3__28functionIFvRKbEEclES2_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = $0;
 $4 = $1;
 $5 = $3;
 $6 = ((($5)) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if ($8) {
  $9 = (___cxa_allocate_exception(4)|0);
  ;HEAP32[$9>>2]=0|0;
  __ZNSt3__217bad_function_callC2Ev($9);
  ___cxa_throw(($9|0),(27280|0),(2510|0));
  // unreachable;
 } else {
  $10 = ((($5)) + 16|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = HEAP32[$11>>2]|0;
  $13 = ((($12)) + 24|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = $4;
  $2 = $15;
  $16 = $2;
  FUNCTION_TABLE_vii[$14 & 8191]($11,$16);
  STACKTOP = sp;return;
 }
}
function __ZNSt3__217bad_function_callC2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = $0;
 $3 = $2;
 $1 = $3;
 $4 = $1;
 HEAP32[$4>>2] = (99744);
 HEAP32[$3>>2] = (71276);
 STACKTOP = sp;return;
}
function __ZNSt3__217bad_function_callD2Ev($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 STACKTOP = sp;return;
}
function __ZNSt3__217bad_function_callD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 __ZNSt3__217bad_function_callD2Ev($2);
 __ZdlPv($2);
 STACKTOP = sp;return;
}
function __ZNKSt3__26vectorIN4mjin11application6memory10observable16VariableCallbackIbEENS_9allocatorIS6_EEE8max_sizeEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(80|0);
 $6 = sp + 8|0;
 $9 = sp + 77|0;
 $12 = sp;
 $14 = sp + 76|0;
 $19 = sp + 16|0;
 $20 = sp + 12|0;
 $18 = $0;
 $21 = $18;
 $17 = $21;
 $22 = $17;
 $23 = ((($22)) + 8|0);
 $16 = $23;
 $24 = $16;
 $15 = $24;
 $25 = $15;
 $13 = $25;
 $26 = $13;
 ;HEAP8[$12>>0]=HEAP8[$14>>0]|0;
 $11 = $26;
 $27 = $11;
 $10 = $27;
 HEAP32[$19>>2] = 178956970;
 HEAP32[$20>>2] = 2147483647;
 $7 = $19;
 $8 = $20;
 $28 = $7;
 $29 = $8;
 ;HEAP8[$6>>0]=HEAP8[$9>>0]|0;
 $4 = $28;
 $5 = $29;
 $30 = $5;
 $31 = $4;
 $1 = $6;
 $2 = $30;
 $3 = $31;
 $32 = $2;
 $33 = HEAP32[$32>>2]|0;
 $34 = $3;
 $35 = HEAP32[$34>>2]|0;
 $36 = ($33>>>0)<($35>>>0);
 $37 = $5;
 $38 = $4;
 $39 = $36 ? $37 : $38;
 $40 = HEAP32[$39>>2]|0;
 STACKTOP = sp;return ($40|0);
}
function __ZNSt3__214__split_bufferIN4mjin11application6memory10observable16VariableCallbackIbEERNS_9allocatorIS6_EEEC2EjjS9_($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(128|0);
 $26 = sp + 36|0;
 $30 = sp + 20|0;
 $32 = $0;
 $33 = $1;
 $34 = $2;
 $35 = $3;
 $36 = $32;
 $37 = ((($36)) + 12|0);
 $38 = $35;
 $29 = $37;
 HEAP32[$30>>2] = 0;
 $31 = $38;
 $39 = $29;
 $28 = $30;
 $40 = $28;
 $41 = HEAP32[$40>>2]|0;
 $42 = $31;
 $22 = $42;
 $43 = $22;
 $25 = $39;
 HEAP32[$26>>2] = $41;
 $27 = $43;
 $44 = $25;
 $24 = $26;
 $45 = $24;
 $46 = HEAP32[$45>>2]|0;
 HEAP32[$44>>2] = $46;
 $47 = ((($44)) + 4|0);
 $48 = $27;
 $23 = $48;
 $49 = $23;
 HEAP32[$47>>2] = $49;
 $50 = $33;
 $51 = ($50|0)!=(0);
 do {
  if ($51) {
   $6 = $36;
   $52 = $6;
   $53 = ((($52)) + 12|0);
   $5 = $53;
   $54 = $5;
   $4 = $54;
   $55 = $4;
   $56 = ((($55)) + 4|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = $33;
   $17 = $57;
   $18 = $58;
   $59 = $17;
   $60 = $18;
   $14 = $59;
   $15 = $60;
   $16 = 0;
   $61 = $14;
   $62 = $15;
   $13 = $61;
   $63 = ($62>>>0)>(178956970);
   if (!($63)) {
    $74 = $15;
    $75 = ($74*24)|0;
    $12 = $75;
    $76 = $12;
    $77 = (__Znwj($76)|0);
    $78 = $77;
    break;
   }
   $9 = 204840;
   $64 = (___cxa_allocate_exception(8)|0);
   $65 = $9;
   $7 = $64;
   $8 = $65;
   $66 = $7;
   $67 = $8;
   __THREW__ = 0;
   invoke_vii(3366,($66|0),($67|0));
   $68 = __THREW__; __THREW__ = 0;
   $69 = $68&1;
   if ($69) {
    $70 = ___cxa_find_matching_catch_2()|0;
    $71 = tempRet0;
    $10 = $70;
    $11 = $71;
    ___cxa_free_exception(($64|0));
    $72 = $10;
    $73 = $11;
    ___resumeException($72|0);
    // unreachable;
   } else {
    HEAP32[$66>>2] = (99824);
    ___cxa_throw(($64|0),(34608|0),(3230|0));
    // unreachable;
   }
  } else {
   $78 = 0;
  }
 } while(0);
 HEAP32[$36>>2] = $78;
 $79 = HEAP32[$36>>2]|0;
 $80 = $34;
 $81 = (($79) + (($80*24)|0)|0);
 $82 = ((($36)) + 8|0);
 HEAP32[$82>>2] = $81;
 $83 = ((($36)) + 4|0);
 HEAP32[$83>>2] = $81;
 $84 = HEAP32[$36>>2]|0;
 $85 = $33;
 $86 = (($84) + (($85*24)|0)|0);
 $21 = $36;
 $87 = $21;
 $88 = ((($87)) + 12|0);
 $20 = $88;
 $89 = $20;
 $19 = $89;
 $90 = $19;
 HEAP32[$90>>2] = $86;
 STACKTOP = sp;return;
}
function __ZNSt3__26vectorIN4mjin11application6memory10observable16VariableCallbackIbEENS_9allocatorIS6_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS6_RS8_EE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0;
 var $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0;
 var $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0;
 var $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0;
 var $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0;
 var $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0;
 var $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0;
 var $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0;
 var $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0;
 var $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 416|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(416|0);
 $15 = sp;
 $20 = sp + 404|0;
 $31 = sp + 292|0;
 $37 = sp + 268|0;
 $49 = sp + 220|0;
 $102 = $0;
 $103 = $1;
 $104 = $102;
 $101 = $104;
 $105 = $101;
 $100 = $105;
 $106 = $100;
 $107 = HEAP32[$106>>2]|0;
 $99 = $107;
 $108 = $99;
 $78 = $105;
 $109 = $78;
 $110 = HEAP32[$109>>2]|0;
 $77 = $110;
 $111 = $77;
 $83 = $105;
 $112 = $83;
 $82 = $112;
 $113 = $82;
 $81 = $113;
 $114 = $81;
 $115 = ((($114)) + 8|0);
 $80 = $115;
 $116 = $80;
 $79 = $116;
 $117 = $79;
 $118 = HEAP32[$117>>2]|0;
 $119 = HEAP32[$113>>2]|0;
 $120 = $118;
 $121 = $119;
 $122 = (($120) - ($121))|0;
 $123 = (($122|0) / 24)&-1;
 $124 = (($111) + (($123*24)|0)|0);
 $85 = $105;
 $125 = $85;
 $126 = HEAP32[$125>>2]|0;
 $84 = $126;
 $127 = $84;
 $86 = $105;
 $128 = $86;
 $129 = ((($128)) + 4|0);
 $130 = HEAP32[$129>>2]|0;
 $131 = HEAP32[$128>>2]|0;
 $132 = $130;
 $133 = $131;
 $134 = (($132) - ($133))|0;
 $135 = (($134|0) / 24)&-1;
 $136 = (($127) + (($135*24)|0)|0);
 $88 = $105;
 $137 = $88;
 $138 = HEAP32[$137>>2]|0;
 $87 = $138;
 $139 = $87;
 $93 = $105;
 $140 = $93;
 $92 = $140;
 $141 = $92;
 $91 = $141;
 $142 = $91;
 $143 = ((($142)) + 8|0);
 $90 = $143;
 $144 = $90;
 $89 = $144;
 $145 = $89;
 $146 = HEAP32[$145>>2]|0;
 $147 = HEAP32[$141>>2]|0;
 $148 = $146;
 $149 = $147;
 $150 = (($148) - ($149))|0;
 $151 = (($150|0) / 24)&-1;
 $152 = (($139) + (($151*24)|0)|0);
 $94 = $105;
 $95 = $108;
 $96 = $124;
 $97 = $136;
 $98 = $152;
 $4 = $104;
 $153 = $4;
 $154 = ((($153)) + 8|0);
 $3 = $154;
 $155 = $3;
 $2 = $155;
 $156 = $2;
 $157 = HEAP32[$104>>2]|0;
 $158 = ((($104)) + 4|0);
 $159 = HEAP32[$158>>2]|0;
 $160 = $103;
 $161 = ((($160)) + 4|0);
 $22 = $156;
 $23 = $157;
 $24 = $159;
 $25 = $161;
 while(1) {
  $162 = $24;
  $163 = $23;
  $164 = ($162|0)!=($163|0);
  if (!($164)) {
   break;
  }
  $165 = $22;
  $166 = $25;
  $167 = HEAP32[$166>>2]|0;
  $168 = ((($167)) + -24|0);
  $21 = $168;
  $169 = $21;
  $170 = $24;
  $171 = ((($170)) + -24|0);
  $24 = $171;
  $6 = $171;
  $172 = $6;
  $5 = $172;
  $173 = $5;
  $17 = $165;
  $18 = $169;
  $19 = $173;
  $174 = $17;
  $175 = $18;
  $176 = $19;
  $16 = $176;
  $177 = $16;
  ;HEAP8[$15>>0]=HEAP8[$20>>0]|0;
  $12 = $174;
  $13 = $175;
  $14 = $177;
  $178 = $12;
  $179 = $13;
  $180 = $14;
  $11 = $180;
  $181 = $11;
  $8 = $178;
  $9 = $179;
  $10 = $181;
  $182 = $9;
  $183 = $10;
  $7 = $183;
  $184 = $7;
  __ZN4mjin11application6memory10observable16VariableCallbackIbEC2EOS4_($182,$184);
  $185 = $25;
  $186 = HEAP32[$185>>2]|0;
  $187 = ((($186)) + -24|0);
  HEAP32[$185>>2] = $187;
 }
 $188 = $103;
 $189 = ((($188)) + 4|0);
 $29 = $104;
 $30 = $189;
 $190 = $29;
 $28 = $190;
 $191 = $28;
 $192 = HEAP32[$191>>2]|0;
 HEAP32[$31>>2] = $192;
 $193 = $30;
 $26 = $193;
 $194 = $26;
 $195 = HEAP32[$194>>2]|0;
 $196 = $29;
 HEAP32[$196>>2] = $195;
 $27 = $31;
 $197 = $27;
 $198 = HEAP32[$197>>2]|0;
 $199 = $30;
 HEAP32[$199>>2] = $198;
 $200 = ((($104)) + 4|0);
 $201 = $103;
 $202 = ((($201)) + 8|0);
 $35 = $200;
 $36 = $202;
 $203 = $35;
 $34 = $203;
 $204 = $34;
 $205 = HEAP32[$204>>2]|0;
 HEAP32[$37>>2] = $205;
 $206 = $36;
 $32 = $206;
 $207 = $32;
 $208 = HEAP32[$207>>2]|0;
 $209 = $35;
 HEAP32[$209>>2] = $208;
 $33 = $37;
 $210 = $33;
 $211 = HEAP32[$210>>2]|0;
 $212 = $36;
 HEAP32[$212>>2] = $211;
 $40 = $104;
 $213 = $40;
 $214 = ((($213)) + 8|0);
 $39 = $214;
 $215 = $39;
 $38 = $215;
 $216 = $38;
 $217 = $103;
 $43 = $217;
 $218 = $43;
 $219 = ((($218)) + 12|0);
 $42 = $219;
 $220 = $42;
 $41 = $220;
 $221 = $41;
 $47 = $216;
 $48 = $221;
 $222 = $47;
 $46 = $222;
 $223 = $46;
 $224 = HEAP32[$223>>2]|0;
 HEAP32[$49>>2] = $224;
 $225 = $48;
 $44 = $225;
 $226 = $44;
 $227 = HEAP32[$226>>2]|0;
 $228 = $47;
 HEAP32[$228>>2] = $227;
 $45 = $49;
 $229 = $45;
 $230 = HEAP32[$229>>2]|0;
 $231 = $48;
 HEAP32[$231>>2] = $230;
 $232 = $103;
 $233 = ((($232)) + 4|0);
 $234 = HEAP32[$233>>2]|0;
 $235 = $103;
 HEAP32[$235>>2] = $234;
 $50 = $104;
 $236 = $50;
 $237 = ((($236)) + 4|0);
 $238 = HEAP32[$237>>2]|0;
 $239 = HEAP32[$236>>2]|0;
 $240 = $238;
 $241 = $239;
 $242 = (($240) - ($241))|0;
 $243 = (($242|0) / 24)&-1;
 $74 = $104;
 $75 = $243;
 $244 = $74;
 $73 = $244;
 $245 = $73;
 $246 = HEAP32[$245>>2]|0;
 $72 = $246;
 $247 = $72;
 $52 = $244;
 $248 = $52;
 $249 = HEAP32[$248>>2]|0;
 $51 = $249;
 $250 = $51;
 $57 = $244;
 $251 = $57;
 $56 = $251;
 $252 = $56;
 $55 = $252;
 $253 = $55;
 $254 = ((($253)) + 8|0);
 $54 = $254;
 $255 = $54;
 $53 = $255;
 $256 = $53;
 $257 = HEAP32[$256>>2]|0;
 $258 = HEAP32[$252>>2]|0;
 $259 = $257;
 $260 = $258;
 $261 = (($259) - ($260))|0;
 $262 = (($261|0) / 24)&-1;
 $263 = (($250) + (($262*24)|0)|0);
 $59 = $244;
 $264 = $59;
 $265 = HEAP32[$264>>2]|0;
 $58 = $265;
 $266 = $58;
 $64 = $244;
 $267 = $64;
 $63 = $267;
 $268 = $63;
 $62 = $268;
 $269 = $62;
 $270 = ((($269)) + 8|0);
 $61 = $270;
 $271 = $61;
 $60 = $271;
 $272 = $60;
 $273 = HEAP32[$272>>2]|0;
 $274 = HEAP32[$268>>2]|0;
 $275 = $273;
 $276 = $274;
 $277 = (($275) - ($276))|0;
 $278 = (($277|0) / 24)&-1;
 $279 = (($266) + (($278*24)|0)|0);
 $66 = $244;
 $280 = $66;
 $281 = HEAP32[$280>>2]|0;
 $65 = $281;
 $282 = $65;
 $283 = $75;
 $284 = (($282) + (($283*24)|0)|0);
 $67 = $244;
 $68 = $247;
 $69 = $263;
 $70 = $279;
 $71 = $284;
 $76 = $104;
 STACKTOP = sp;return;
}
function __ZNSt3__214__split_bufferIN4mjin11application6memory10observable16VariableCallbackIbEERNS_9allocatorIS6_EEED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(144|0);
 $19 = sp + 8|0;
 $22 = sp + 133|0;
 $29 = sp;
 $32 = sp + 132|0;
 $34 = $0;
 $35 = $34;
 $33 = $35;
 $36 = $33;
 $37 = ((($36)) + 4|0);
 $38 = HEAP32[$37>>2]|0;
 $30 = $36;
 $31 = $38;
 $39 = $30;
 $40 = $31;
 ;HEAP8[$29>>0]=HEAP8[$32>>0]|0;
 $27 = $39;
 $28 = $40;
 $41 = $27;
 while(1) {
  $42 = $28;
  $43 = ((($41)) + 8|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = ($42|0)!=($44|0);
  if (!($45)) {
   break;
  }
  $26 = $41;
  $46 = $26;
  $47 = ((($46)) + 12|0);
  $25 = $47;
  $48 = $25;
  $24 = $48;
  $49 = $24;
  $50 = ((($49)) + 4|0);
  $51 = HEAP32[$50>>2]|0;
  $52 = ((($41)) + 8|0);
  $53 = HEAP32[$52>>2]|0;
  $54 = ((($53)) + -24|0);
  HEAP32[$52>>2] = $54;
  $23 = $54;
  $55 = $23;
  $20 = $51;
  $21 = $55;
  $56 = $20;
  $57 = $21;
  ;HEAP8[$19>>0]=HEAP8[$22>>0]|0;
  $17 = $56;
  $18 = $57;
  $58 = $17;
  $59 = $18;
  $15 = $58;
  $16 = $59;
  $60 = $16;
  __ZN4mjin11application6memory10observable16VariableCallbackIbED2Ev($60);
 }
 $61 = HEAP32[$35>>2]|0;
 $62 = ($61|0)!=(0|0);
 if (!($62)) {
  STACKTOP = sp;return;
 }
 $14 = $35;
 $63 = $14;
 $64 = ((($63)) + 12|0);
 $13 = $64;
 $65 = $13;
 $12 = $65;
 $66 = $12;
 $67 = ((($66)) + 4|0);
 $68 = HEAP32[$67>>2]|0;
 $69 = HEAP32[$35>>2]|0;
 $11 = $35;
 $70 = $11;
 $10 = $70;
 $71 = $10;
 $72 = ((($71)) + 12|0);
 $9 = $72;
 $73 = $9;
 $8 = $73;
 $74 = $8;
 $75 = HEAP32[$74>>2]|0;
 $76 = HEAP32[$70>>2]|0;
 $77 = $75;
 $78 = $76;
 $79 = (($77) - ($78))|0;
 $80 = (($79|0) / 24)&-1;
 $5 = $68;
 $6 = $69;
 $7 = $80;
 $81 = $5;
 $82 = $6;
 $83 = $7;
 $2 = $81;
 $3 = $82;
 $4 = $83;
 $84 = $3;
 $1 = $84;
 $85 = $1;
 __ZdlPv($85);
 STACKTOP = sp;return;
}
function __ZN4mjin11application6memory10observable16VariableCallbackIbEC2EOS4_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = $0;
 $3 = $1;
 $4 = $2;
 $5 = $3;
 __ZNSt3__28functionIFvRKbEEC2EOS4_($4,$5);
 STACKTOP = sp;return;
}
function __ZNSt3__28functionIFvRKbEEC2EOS4_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$sink1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = $0;
 $3 = $1;
 $4 = $2;
 $5 = $3;
 $6 = ((($5)) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 do {
  if ($8) {
   $$sink1 = $4;
  } else {
   $9 = $3;
   $10 = ((($9)) + 16|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = $3;
   $13 = ($11|0)==($12|0);
   if (!($13)) {
    $28 = $3;
    $29 = ((($28)) + 16|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = ((($4)) + 16|0);
    HEAP32[$31>>2] = $30;
    $32 = $3;
    $$sink1 = $32;
    break;
   }
   __THREW__ = 0;
   $14 = (invoke_ii(4053,($4|0))|0);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if ($16) {
    $34 = ___cxa_find_matching_catch_3(0|0)|0;
    $35 = tempRet0;
    ___clang_call_terminate($34);
    // unreachable;
   }
   $17 = ((($4)) + 16|0);
   HEAP32[$17>>2] = $14;
   $18 = $3;
   $19 = ((($18)) + 16|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = HEAP32[$20>>2]|0;
   $22 = ((($21)) + 12|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = ((($4)) + 16|0);
   $25 = HEAP32[$24>>2]|0;
   __THREW__ = 0;
   invoke_vii($23|0,($20|0),($25|0));
   $26 = __THREW__; __THREW__ = 0;
   $27 = $26&1;
   if ($27) {
    $34 = ___cxa_find_matching_catch_3(0|0)|0;
    $35 = tempRet0;
    ___clang_call_terminate($34);
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $33 = ((($$sink1)) + 16|0);
 HEAP32[$33>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNSt3__28functionIFvRKbEE9__as_baseEPv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 STACKTOP = sp;return ($2|0);
}
function __ZNSt3__28functionIFvRKbEEC2ERKS4_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = $0;
 $3 = $1;
 $4 = $2;
 $5 = $3;
 $6 = ((($5)) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if ($8) {
  $9 = ((($4)) + 16|0);
  HEAP32[$9>>2] = 0;
  STACKTOP = sp;return;
 }
 $10 = $3;
 $11 = ((($10)) + 16|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = $3;
 $14 = ($12|0)==($13|0);
 if ($14) {
  $15 = (__ZNSt3__28functionIFvRKbEE9__as_baseEPv($4)|0);
  $16 = ((($4)) + 16|0);
  HEAP32[$16>>2] = $15;
  $17 = $3;
  $18 = ((($17)) + 16|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = HEAP32[$19>>2]|0;
  $21 = ((($20)) + 12|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = ((($4)) + 16|0);
  $24 = HEAP32[$23>>2]|0;
  FUNCTION_TABLE_vii[$22 & 8191]($19,$24);
  STACKTOP = sp;return;
 } else {
  $25 = $3;
  $26 = ((($25)) + 16|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = HEAP32[$27>>2]|0;
  $29 = ((($28)) + 8|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (FUNCTION_TABLE_ii[$30 & 8191]($27)|0);
  $32 = ((($4)) + 16|0);
  HEAP32[$32>>2] = $31;
  STACKTOP = sp;return;
 }
}
function __ZNSt3__210__function6__funcIZN4mjin11application6memory11Coordinator14setupSelectionEvE3__0NS_9allocatorIS6_EEFvRKbEED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = $0;
 $3 = $2;
 $1 = $3;
 STACKTOP = sp;return;
}
function __ZNSt3__210__function6__funcIZN4mjin11application6memory11Coordinator14setupSelectionEvE3__0NS_9allocatorIS6_EEFvRKbEED0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 __ZNSt3__210__function6__funcIZN4mjin11application6memory11Coordinator14setupSelectionEvE3__0NS_9allocatorIS6_EEFvRKbEED2Ev($2);
 __ZdlPv($2);
 STACKTOP = sp;return;
}
function __ZNKSt3__210__function6__funcIZN4mjin11application6memory11Coordinator14setupSelectionEvE3__0NS_9allocatorIS6_EEFvRKbEE7__cloneEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0;
 var $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0;
 var $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0;
 var $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0;
 var $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0;
 var $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0;
 var $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0;
 var $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0;
 var $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 624|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(624|0);
 $7 = sp + 136|0;
 $8 = sp + 128|0;
 $9 = sp + 120|0;
 $10 = sp + 112|0;
 $13 = sp + 609|0;
 $14 = sp + 608|0;
 $15 = sp + 607|0;
 $16 = sp + 606|0;
 $18 = sp + 556|0;
 $27 = sp + 104|0;
 $28 = sp + 96|0;
 $29 = sp + 88|0;
 $30 = sp + 80|0;
 $34 = sp + 605|0;
 $35 = sp + 604|0;
 $36 = sp + 603|0;
 $37 = sp + 602|0;
 $39 = sp + 504|0;
 $49 = sp + 72|0;
 $50 = sp + 64|0;
 $51 = sp + 56|0;
 $52 = sp + 48|0;
 $53 = sp + 40|0;
 $56 = sp + 601|0;
 $57 = sp + 456|0;
 $58 = sp + 452|0;
 $59 = sp + 600|0;
 $60 = sp + 599|0;
 $61 = sp + 32|0;
 $62 = sp + 24|0;
 $63 = sp + 16|0;
 $68 = sp + 598|0;
 $69 = sp + 432|0;
 $70 = sp + 428|0;
 $88 = sp + 356|0;
 $89 = sp + 8|0;
 $92 = sp + 344|0;
 $93 = sp + 336|0;
 $94 = sp;
 $99 = sp + 312|0;
 $137 = sp + 597|0;
 $138 = sp + 152|0;
 $139 = sp + 144|0;
 $140 = sp + 596|0;
 $136 = $0;
 $141 = $136;
 $142 = ((($141)) + 4|0);
 $135 = $142;
 $143 = $135;
 $134 = $143;
 $144 = $134;
 $132 = $137;
 $133 = $144;
 $110 = $137;
 $111 = 1;
 $112 = 0;
 $145 = $110;
 $146 = $111;
 $109 = $145;
 $147 = ($146>>>0)>(536870911);
 if ($147) {
  $105 = 204840;
  $148 = (___cxa_allocate_exception(8)|0);
  $149 = $105;
  $103 = $148;
  $104 = $149;
  $150 = $103;
  $151 = $104;
  __THREW__ = 0;
  invoke_vii(3366,($150|0),($151|0));
  $152 = __THREW__; __THREW__ = 0;
  $153 = $152&1;
  if ($153) {
   $154 = ___cxa_find_matching_catch_2()|0;
   $155 = tempRet0;
   $106 = $154;
   $107 = $155;
   ___cxa_free_exception(($148|0));
   $156 = $106;
   $157 = $107;
   ___resumeException($156|0);
   // unreachable;
  } else {
   HEAP32[$150>>2] = (99824);
   ___cxa_throw(($148|0),(34608|0),(3230|0));
   // unreachable;
  }
 }
 $158 = $111;
 $159 = $158<<3;
 $108 = $159;
 $160 = $108;
 $161 = (__Znwj($160)|0);
 $100 = $139;
 $101 = $137;
 $102 = 1;
 $162 = $100;
 $163 = $101;
 HEAP32[$162>>2] = $163;
 $164 = ((($162)) + 4|0);
 $165 = $102;
 HEAP32[$164>>2] = $165;
 $96 = $138;
 $97 = $161;
 $98 = $139;
 $166 = $96;
 $167 = $97;
 $168 = $98;
 $95 = $168;
 $169 = $95;
 ;HEAP32[$99>>2]=HEAP32[$169>>2]|0;HEAP32[$99+4>>2]=HEAP32[$169+4>>2]|0;
 ;HEAP8[$94>>0]=HEAP8[$99>>0]|0;HEAP8[$94+1>>0]=HEAP8[$99+1>>0]|0;HEAP8[$94+2>>0]=HEAP8[$99+2>>0]|0;HEAP8[$94+3>>0]=HEAP8[$99+3>>0]|0;HEAP8[$94+4>>0]=HEAP8[$99+4>>0]|0;HEAP8[$94+5>>0]=HEAP8[$99+5>>0]|0;HEAP8[$94+6>>0]=HEAP8[$99+6>>0]|0;HEAP8[$94+7>>0]=HEAP8[$99+7>>0]|0;
 $91 = $166;
 HEAP32[$92>>2] = $167;
 $170 = $91;
 $90 = $92;
 $171 = $90;
 $172 = HEAP32[$171>>2]|0;
 $84 = $94;
 $173 = $84;
 ;HEAP32[$93>>2]=HEAP32[$173>>2]|0;HEAP32[$93+4>>2]=HEAP32[$173+4>>2]|0;
 ;HEAP8[$89>>0]=HEAP8[$93>>0]|0;HEAP8[$89+1>>0]=HEAP8[$93+1>>0]|0;HEAP8[$89+2>>0]=HEAP8[$93+2>>0]|0;HEAP8[$89+3>>0]=HEAP8[$93+3>>0]|0;HEAP8[$89+4>>0]=HEAP8[$93+4>>0]|0;HEAP8[$89+5>>0]=HEAP8[$93+5>>0]|0;HEAP8[$89+6>>0]=HEAP8[$93+6>>0]|0;HEAP8[$89+7>>0]=HEAP8[$93+7>>0]|0;
 $87 = $170;
 HEAP32[$88>>2] = $172;
 $174 = $87;
 $86 = $88;
 $175 = $86;
 $176 = HEAP32[$175>>2]|0;
 HEAP32[$174>>2] = $176;
 $177 = ((($174)) + 4|0);
 $85 = $89;
 $178 = $85;
 ;HEAP32[$177>>2]=HEAP32[$178>>2]|0;HEAP32[$177+4>>2]=HEAP32[$178+4>>2]|0;
 $83 = $138;
 $179 = $83;
 $82 = $179;
 $180 = $82;
 $81 = $180;
 $181 = $81;
 $182 = HEAP32[$181>>2]|0;
 $183 = ((($141)) + 4|0);
 $80 = $183;
 $184 = $80;
 $79 = $184;
 $185 = $79;
 $77 = $140;
 $78 = $137;
 $65 = $182;
 $66 = $185;
 $67 = $140;
 $186 = $65;
 $64 = $186;
 $187 = $64;
 HEAP32[$187>>2] = (71296);
 HEAP32[$186>>2] = (71340);
 $188 = ((($186)) + 4|0);
 $189 = $66;
 $19 = $189;
 $190 = $19;
 $17 = $190;
 $191 = $17;
 $11 = $18;
 $12 = $191;
 $192 = $11;
 $193 = $12;
 ;HEAP8[$7>>0]=HEAP8[$16>>0]|0;
 ;HEAP8[$8>>0]=HEAP8[$15>>0]|0;
 ;HEAP8[$9>>0]=HEAP8[$14>>0]|0;
 ;HEAP8[$10>>0]=HEAP8[$13>>0]|0;
 $5 = $192;
 $6 = $193;
 $194 = $5;
 $195 = $6;
 $4 = $195;
 $196 = $4;
 $2 = $194;
 $3 = $196;
 $197 = $2;
 $198 = $3;
 $1 = $198;
 $199 = $1;
 HEAP32[$197>>2] = $199;
 $200 = HEAP32[$18>>2]|0;
 HEAP32[$69>>2] = $200;
 $201 = $67;
 $20 = $201;
 $202 = $20;
 $40 = $202;
 $203 = $40;
 $38 = $203;
 $204 = $38;
 $32 = $39;
 $33 = $204;
 $205 = $32;
 $206 = $33;
 $31 = $206;
 $207 = $31;
 ;HEAP8[$27>>0]=HEAP8[$37>>0]|0;
 ;HEAP8[$28>>0]=HEAP8[$36>>0]|0;
 ;HEAP8[$29>>0]=HEAP8[$35>>0]|0;
 ;HEAP8[$30>>0]=HEAP8[$34>>0]|0;
 $25 = $205;
 $26 = $207;
 $208 = $25;
 $209 = $26;
 $24 = $209;
 $210 = $24;
 $22 = $208;
 $23 = $210;
 $211 = $22;
 $212 = $23;
 $21 = $212;
 $213 = $21;
 HEAP32[$211>>2] = $213;
 $214 = HEAP32[$39>>2]|0;
 HEAP32[$70>>2] = $214;
 ;HEAP8[$61>>0]=HEAP8[$70>>0]|0;HEAP8[$61+1>>0]=HEAP8[$70+1>>0]|0;HEAP8[$61+2>>0]=HEAP8[$70+2>>0]|0;HEAP8[$61+3>>0]=HEAP8[$70+3>>0]|0;
 ;HEAP8[$62>>0]=HEAP8[$69>>0]|0;HEAP8[$62+1>>0]=HEAP8[$69+1>>0]|0;HEAP8[$62+2>>0]=HEAP8[$69+2>>0]|0;HEAP8[$62+3>>0]=HEAP8[$69+3>>0]|0;
 ;HEAP8[$63>>0]=HEAP8[$68>>0]|0;
 $55 = $188;
 $215 = $55;
 $54 = $62;
 $216 = $54;
 ;HEAP32[$57>>2]=HEAP32[$216>>2]|0;
 $41 = $61;
 $217 = $41;
 ;HEAP32[$58>>2]=HEAP32[$217>>2]|0;
 ;HEAP8[$49>>0]=HEAP8[$60>>0]|0;
 ;HEAP8[$50>>0]=HEAP8[$59>>0]|0;
 ;HEAP8[$51>>0]=HEAP8[$58>>0]|0;HEAP8[$51+1>>0]=HEAP8[$58+1>>0]|0;HEAP8[$51+2>>0]=HEAP8[$58+2>>0]|0;HEAP8[$51+3>>0]=HEAP8[$58+3>>0]|0;
 ;HEAP8[$52>>0]=HEAP8[$57>>0]|0;HEAP8[$52+1>>0]=HEAP8[$57+1>>0]|0;HEAP8[$52+2>>0]=HEAP8[$57+2>>0]|0;HEAP8[$52+3>>0]=HEAP8[$57+3>>0]|0;
 ;HEAP8[$53>>0]=HEAP8[$56>>0]|0;
 $48 = $215;
 $218 = $48;
 $47 = $51;
 $219 = $47;
 $46 = $219;
 $220 = $46;
 $221 = HEAP32[$220>>2]|0;
 $42 = $221;
 $44 = $52;
 $222 = $44;
 $43 = $222;
 $223 = $43;
 $224 = HEAP32[$223>>2]|0;
 $45 = $224;
 $225 = $45;
 ;HEAP32[$218>>2]=HEAP32[$225>>2]|0;
 $75 = $138;
 $226 = $75;
 $74 = $226;
 $227 = $74;
 $73 = $227;
 $228 = $73;
 $229 = HEAP32[$228>>2]|0;
 $76 = $229;
 $72 = $226;
 $230 = $72;
 $71 = $230;
 $231 = $71;
 HEAP32[$231>>2] = 0;
 $232 = $76;
 $131 = $138;
 $233 = $131;
 $128 = $233;
 $129 = 0;
 $234 = $128;
 $127 = $234;
 $235 = $127;
 $126 = $235;
 $236 = $126;
 $237 = HEAP32[$236>>2]|0;
 $130 = $237;
 $238 = $129;
 $116 = $234;
 $239 = $116;
 $115 = $239;
 $240 = $115;
 HEAP32[$240>>2] = $238;
 $241 = $130;
 $242 = ($241|0)!=(0|0);
 if (!($242)) {
  STACKTOP = sp;return ($232|0);
 }
 $114 = $234;
 $243 = $114;
 $113 = $243;
 $244 = $113;
 $245 = ((($244)) + 4|0);
 $246 = $130;
 $124 = $245;
 $125 = $246;
 $247 = $124;
 $248 = HEAP32[$247>>2]|0;
 $249 = $125;
 $250 = ((($247)) + 4|0);
 $251 = HEAP32[$250>>2]|0;
 $121 = $248;
 $122 = $249;
 $123 = $251;
 $252 = $121;
 $253 = $122;
 $254 = $123;
 $118 = $252;
 $119 = $253;
 $120 = $254;
 $255 = $119;
 $117 = $255;
 $256 = $117;
 __ZdlPv($256);
 STACKTOP = sp;return ($232|0);
}
function __ZNKSt3__210__function6__funcIZN4mjin11application6memory11Coordinator14setupSelectionEvE3__0NS_9allocatorIS6_EEFvRKbEE7__cloneEPNS0_6__baseISB_EE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 320|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(320|0);
 $10 = sp + 120|0;
 $11 = sp + 112|0;
 $12 = sp + 104|0;
 $13 = sp + 96|0;
 $16 = sp + 319|0;
 $17 = sp + 318|0;
 $18 = sp + 317|0;
 $19 = sp + 316|0;
 $21 = sp + 260|0;
 $29 = sp + 88|0;
 $30 = sp + 80|0;
 $31 = sp + 72|0;
 $32 = sp + 64|0;
 $35 = sp + 315|0;
 $36 = sp + 314|0;
 $37 = sp + 313|0;
 $38 = sp + 312|0;
 $40 = sp + 216|0;
 $50 = sp + 56|0;
 $51 = sp + 48|0;
 $52 = sp + 40|0;
 $53 = sp + 32|0;
 $54 = sp + 24|0;
 $57 = sp + 311|0;
 $58 = sp + 168|0;
 $59 = sp + 164|0;
 $60 = sp + 310|0;
 $61 = sp + 309|0;
 $62 = sp + 16|0;
 $63 = sp + 8|0;
 $64 = sp;
 $69 = sp + 308|0;
 $70 = sp + 144|0;
 $71 = sp + 140|0;
 $74 = $0;
 $75 = $1;
 $76 = $74;
 $77 = $75;
 $78 = ((($76)) + 4|0);
 $73 = $78;
 $79 = $73;
 $72 = $79;
 $80 = $72;
 $81 = ((($76)) + 4|0);
 $3 = $81;
 $82 = $3;
 $2 = $82;
 $83 = $2;
 $66 = $77;
 $67 = $80;
 $68 = $83;
 $84 = $66;
 $65 = $84;
 $85 = $65;
 HEAP32[$85>>2] = (71296);
 HEAP32[$84>>2] = (71340);
 $86 = ((($84)) + 4|0);
 $87 = $67;
 $22 = $87;
 $88 = $22;
 $20 = $88;
 $89 = $20;
 $14 = $21;
 $15 = $89;
 $90 = $14;
 $91 = $15;
 ;HEAP8[$10>>0]=HEAP8[$19>>0]|0;
 ;HEAP8[$11>>0]=HEAP8[$18>>0]|0;
 ;HEAP8[$12>>0]=HEAP8[$17>>0]|0;
 ;HEAP8[$13>>0]=HEAP8[$16>>0]|0;
 $8 = $90;
 $9 = $91;
 $92 = $8;
 $93 = $9;
 $7 = $93;
 $94 = $7;
 $5 = $92;
 $6 = $94;
 $95 = $5;
 $96 = $6;
 $4 = $96;
 $97 = $4;
 HEAP32[$95>>2] = $97;
 $98 = HEAP32[$21>>2]|0;
 HEAP32[$70>>2] = $98;
 $99 = $68;
 $41 = $99;
 $100 = $41;
 $39 = $100;
 $101 = $39;
 $33 = $40;
 $34 = $101;
 $102 = $33;
 $103 = $34;
 ;HEAP8[$29>>0]=HEAP8[$38>>0]|0;
 ;HEAP8[$30>>0]=HEAP8[$37>>0]|0;
 ;HEAP8[$31>>0]=HEAP8[$36>>0]|0;
 ;HEAP8[$32>>0]=HEAP8[$35>>0]|0;
 $27 = $102;
 $28 = $103;
 $104 = $27;
 $105 = $28;
 $26 = $105;
 $106 = $26;
 $24 = $104;
 $25 = $106;
 $107 = $24;
 $108 = $25;
 $23 = $108;
 $109 = $23;
 HEAP32[$107>>2] = $109;
 $110 = HEAP32[$40>>2]|0;
 HEAP32[$71>>2] = $110;
 ;HEAP8[$62>>0]=HEAP8[$71>>0]|0;HEAP8[$62+1>>0]=HEAP8[$71+1>>0]|0;HEAP8[$62+2>>0]=HEAP8[$71+2>>0]|0;HEAP8[$62+3>>0]=HEAP8[$71+3>>0]|0;
 ;HEAP8[$63>>0]=HEAP8[$70>>0]|0;HEAP8[$63+1>>0]=HEAP8[$70+1>>0]|0;HEAP8[$63+2>>0]=HEAP8[$70+2>>0]|0;HEAP8[$63+3>>0]=HEAP8[$70+3>>0]|0;
 ;HEAP8[$64>>0]=HEAP8[$69>>0]|0;
 $56 = $86;
 $111 = $56;
 $55 = $63;
 $112 = $55;
 ;HEAP32[$58>>2]=HEAP32[$112>>2]|0;
 $42 = $62;
 $113 = $42;
 ;HEAP32[$59>>2]=HEAP32[$113>>2]|0;
 ;HEAP8[$50>>0]=HEAP8[$61>>0]|0;
 ;HEAP8[$51>>0]=HEAP8[$60>>0]|0;
 ;HEAP8[$52>>0]=HEAP8[$59>>0]|0;HEAP8[$52+1>>0]=HEAP8[$59+1>>0]|0;HEAP8[$52+2>>0]=HEAP8[$59+2>>0]|0;HEAP8[$52+3>>0]=HEAP8[$59+3>>0]|0;
 ;HEAP8[$53>>0]=HEAP8[$58>>0]|0;HEAP8[$53+1>>0]=HEAP8[$58+1>>0]|0;HEAP8[$53+2>>0]=HEAP8[$58+2>>0]|0;HEAP8[$53+3>>0]=HEAP8[$58+3>>0]|0;
 ;HEAP8[$54>>0]=HEAP8[$57>>0]|0;
 $49 = $111;
 $114 = $49;
 $48 = $52;
 $115 = $48;
 $47 = $115;
 $116 = $47;
 $117 = HEAP32[$116>>2]|0;
 $43 = $117;
 $45 = $53;
 $118 = $45;
 $44 = $118;
 $119 = $44;
 $120 = HEAP32[$119>>2]|0;
 $46 = $120;
 $121 = $46;
 ;HEAP32[$114>>2]=HEAP32[$121>>2]|0;
 STACKTOP = sp;return;
}
function __ZNSt3__210__function6__funcIZN4mjin11application6memory11Coordinator14setupSelectionEvE3__0NS_9allocatorIS6_EEFvRKbEE7destroyEv($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 STACKTOP = sp;return;
}
function __ZNSt3__210__function6__funcIZN4mjin11application6memory11Coordinator14setupSelectionEvE3__0NS_9allocatorIS6_EEFvRKbEE18destroy_deallocateEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $10 = sp + 36|0;
 $9 = $0;
 $11 = $9;
 $12 = ((($11)) + 4|0);
 $8 = $12;
 $13 = $8;
 $7 = $13;
 $14 = $7;
 $1 = $10;
 $2 = $14;
 $4 = $10;
 $5 = $11;
 $6 = 1;
 $15 = $5;
 $3 = $15;
 $16 = $3;
 __ZdlPv($16);
 STACKTOP = sp;return;
}
function __ZNSt3__210__function6__funcIZN4mjin11application6memory11Coordinator14setupSelectionEvE3__0NS_9allocatorIS6_EEFvRKbEEclESA_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $5 = $0;
 $6 = $1;
 $7 = $5;
 $8 = ((($7)) + 4|0);
 $4 = $8;
 $9 = $4;
 $3 = $9;
 $10 = $3;
 $11 = $6;
 $2 = $11;
 $12 = $2;
 __ZNSt3__228__invoke_void_return_wrapperIvE6__callIJRZN4mjin11application6memory11Coordinator14setupSelectionEvE3__0RKbEEEvDpOT_($10,$12);
 STACKTOP = sp;return;
}
function __ZNKSt3__210__function6__funcIZN4mjin11application6memory11Coordinator14setupSelectionEvE3__0NS_9allocatorIS6_EEFvRKbEE6targetERKSt9type_info($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $7 = $0;
 $8 = $1;
 $9 = $7;
 $10 = $8;
 $4 = $10;
 $5 = 27312;
 $11 = $4;
 $12 = ((($11)) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $5;
 $15 = ((($14)) + 4|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($13|0)==($16|0);
 if ($17) {
  $18 = ((($9)) + 4|0);
  $3 = $18;
  $19 = $3;
  $2 = $19;
  $20 = $2;
  $6 = $20;
  $21 = $6;
  STACKTOP = sp;return ($21|0);
 } else {
  $6 = 0;
  $21 = $6;
  STACKTOP = sp;return ($21|0);
 }
 return (0)|0;
}
function __ZNKSt3__210__function6__funcIZN4mjin11application6memory11Coordinator14setupSelectionEvE3__0NS_9allocatorIS6_EEFvRKbEE11target_typeEv($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 STACKTOP = sp;return (27312|0);
}
function __ZNSt3__228__invoke_void_return_wrapperIvE6__callIJRZN4mjin11application6memory11Coordinator14setupSelectionEvE3__0RKbEEEvDpOT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $8 = $0;
 $9 = $1;
 $10 = $8;
 $7 = $10;
 $11 = $7;
 $12 = $9;
 $2 = $12;
 $13 = $2;
 $5 = $11;
 $6 = $13;
 $14 = $5;
 $4 = $14;
 $15 = $4;
 $16 = $6;
 $3 = $16;
 $17 = $3;
 __ZZN4mjin11application6memory11Coordinator14setupSelectionEvENK3__0clERKb($15,$17);
 STACKTOP = sp;return;
}
function __ZZN4mjin11application6memory11Coordinator14setupSelectionEvENK3__0clERKb($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $12 = 0, $13 = 0, $14 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 192|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(192|0);
 $4 = sp + 180|0;
 $7 = sp + 168|0;
 $17 = sp + 128|0;
 $19 = sp + 8|0;
 $20 = sp;
 $23 = sp + 112|0;
 $26 = sp + 100|0;
 $36 = sp + 60|0;
 $39 = sp + 48|0;
 $44 = sp + 28|0;
 $45 = sp + 24|0;
 $46 = sp + 20|0;
 $47 = sp + 16|0;
 $48 = sp + 12|0;
 $41 = $0;
 $42 = $1;
 $49 = $41;
 $50 = HEAP32[$49>>2]|0;
 $51 = ((($50)) + 4|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = ((($52)) + 44|0);
 $43 = $53;
 $54 = $43;
 $40 = $54;
 $55 = $40;
 $56 = HEAP32[$55>>2]|0;
 $37 = $55;
 $38 = $56;
 $57 = $38;
 $34 = $36;
 $35 = $57;
 $58 = $34;
 $59 = $35;
 HEAP32[$58>>2] = $59;
 $60 = HEAP32[$36>>2]|0;
 HEAP32[$39>>2] = $60;
 $61 = HEAP32[$39>>2]|0;
 HEAP32[$45>>2] = $61;
 $62 = $43;
 $8 = $62;
 $63 = $8;
 $64 = ((($63)) + 4|0);
 $65 = HEAP32[$64>>2]|0;
 $5 = $63;
 $6 = $65;
 $66 = $6;
 $2 = $4;
 $3 = $66;
 $67 = $2;
 $68 = $3;
 HEAP32[$67>>2] = $68;
 $69 = HEAP32[$4>>2]|0;
 HEAP32[$7>>2] = $69;
 $70 = HEAP32[$7>>2]|0;
 HEAP32[$46>>2] = $70;
 HEAP32[$47>>2] = 1;
 ;HEAP8[$19>>0]=HEAP8[$46>>0]|0;HEAP8[$19+1>>0]=HEAP8[$46+1>>0]|0;HEAP8[$19+2>>0]=HEAP8[$46+2>>0]|0;HEAP8[$19+3>>0]=HEAP8[$46+3>>0]|0;
 ;HEAP8[$20>>0]=HEAP8[$45>>0]|0;HEAP8[$20+1>>0]=HEAP8[$45+1>>0]|0;HEAP8[$20+2>>0]=HEAP8[$45+2>>0]|0;HEAP8[$20+3>>0]=HEAP8[$45+3>>0]|0;
 $18 = $47;
 while(1) {
  $15 = $20;
  $16 = $19;
  $71 = $15;
  $72 = $16;
  $13 = $71;
  $14 = $72;
  $73 = $13;
  $12 = $73;
  $74 = $12;
  $75 = HEAP32[$74>>2]|0;
  $76 = $14;
  $11 = $76;
  $77 = $11;
  $78 = HEAP32[$77>>2]|0;
  $79 = ($75|0)==($78|0);
  $80 = $79 ^ 1;
  if (!($80)) {
   break;
  }
  $9 = $20;
  $81 = $9;
  $82 = HEAP32[$81>>2]|0;
  $83 = HEAP32[$82>>2]|0;
  $84 = $18;
  $85 = HEAP32[$84>>2]|0;
  $86 = ($83|0)==($85|0);
  if ($86) {
   break;
  }
  $10 = $20;
  $87 = $10;
  $88 = HEAP32[$87>>2]|0;
  $89 = ((($88)) + 4|0);
  HEAP32[$87>>2] = $89;
 }
 ;HEAP32[$17>>2]=HEAP32[$20>>2]|0;
 $90 = HEAP32[$17>>2]|0;
 HEAP32[$44>>2] = $90;
 $91 = $43;
 $27 = $91;
 $92 = $27;
 $93 = ((($92)) + 4|0);
 $94 = HEAP32[$93>>2]|0;
 $24 = $92;
 $25 = $94;
 $95 = $25;
 $21 = $23;
 $22 = $95;
 $96 = $21;
 $97 = $22;
 HEAP32[$96>>2] = $97;
 $98 = HEAP32[$23>>2]|0;
 HEAP32[$26>>2] = $98;
 $99 = HEAP32[$26>>2]|0;
 HEAP32[$48>>2] = $99;
 $32 = $44;
 $33 = $48;
 $100 = $32;
 $101 = $33;
 $30 = $100;
 $31 = $101;
 $102 = $30;
 $29 = $102;
 $103 = $29;
 $104 = HEAP32[$103>>2]|0;
 $105 = $31;
 $28 = $105;
 $106 = $28;
 $107 = HEAP32[$106>>2]|0;
 $108 = ($104|0)==($107|0);
 $109 = $108 ^ 1;
 if (!($109)) {
  STACKTOP = sp;return;
 }
 $110 = ((($50)) + 8|0);
 $111 = HEAP32[$110>>2]|0;
 $112 = ((($50)) + 4|0);
 $113 = HEAP32[$112>>2]|0;
 $114 = ((($113)) + 8|0);
 __ZN4mjin11application6memory4Game10selectItemERKN3osg5Vec2fE($111,$114);
 STACKTOP = sp;return;
}
function __ZNSt3__210__function6__baseIFvRKbEED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 STACKTOP = sp;return;
}
function __ZNSt3__210__function6__baseIFvRKbEED0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = $0;
 $3 = $2;
 $1 = $3;
 __ZdlPv($3);
 STACKTOP = sp;return;
}
function __ZN3osg7ref_ptrINS_4NodeEE6assignINS_5GroupEEEvRKNS0_IT_EE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = $0;
 $3 = $1;
 $5 = $2;
 $6 = HEAP32[$5>>2]|0;
 $7 = $3;
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6|0)==($8|0);
 if ($9) {
  STACKTOP = sp;return;
 }
 $10 = HEAP32[$5>>2]|0;
 $4 = $10;
 $11 = $3;
 $12 = HEAP32[$11>>2]|0;
 HEAP32[$5>>2] = $12;
 $13 = HEAP32[$5>>2]|0;
 $14 = ($13|0)!=(0|0);
 if ($14) {
  $15 = HEAP32[$5>>2]|0;
  (__ZNK3osg10Referenced3refEv($15)|0);
 }
 $16 = $4;
 $17 = ($16|0)!=(0|0);
 if (!($17)) {
  STACKTOP = sp;return;
 }
 $18 = $4;
 (__ZNK3osg10Referenced5unrefEv($18)|0);
 STACKTOP = sp;return;
}
function __ZNK3osg10Referenced3refEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 $3 = ((($2)) + 8|0);
 $4 = (__ZN11OpenThreads6AtomicppEv($3)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN11OpenThreads6AtomicppEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;HEAP32[$2>>2] = (($3+1)|0);
 $4 = (($3) + 1)|0;
 STACKTOP = sp;return ($4|0);
}
function __ZN4mjin11application6memory11CoordinatorD2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $4 = $1;
 $5 = ((($4)) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if (!($7)) {
  __ZN4mjin11application6memory4GameD2Ev($6);
  __ZdlPv($6);
 }
 $8 = ((($4)) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if (!($10)) {
  __ZN4mjin11application6memory8material4PoolD2Ev($9);
  __ZdlPv($9);
 }
 $11 = ((($4)) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ((($12)) + 104|0);
 $14 = ((($4)) + 4|0);
 $15 = HEAP32[$14>>2]|0;
 __THREW__ = 0;
 invoke_vii(4054,($13|0),($15|0));
 $16 = __THREW__; __THREW__ = 0;
 $17 = $16&1;
 if ($17) {
  $18 = ___cxa_find_matching_catch_3(0|0)|0;
  $19 = tempRet0;
  $2 = $18;
  $3 = $19;
  __ZN3osg7ref_ptrINS_4NodeEED2Ev($4);
  $20 = $2;
  ___clang_call_terminate($20);
  // unreachable;
 } else {
  __ZN3osg7ref_ptrINS_4NodeEED2Ev($4);
  STACKTOP = sp;return;
 }
}
function __ZN4mjin11application6memory11Coordinator16renderFirstFrameEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 __ZN4mjin11application6memory11Coordinator16reserveMaterialsEv($2);
 $3 = (__ZNK3osg7ref_ptrINS_4NodeEEcvPS1_Ev($2)|0);
 __ZN4mjin6render6useVBOEPN3osg4NodeE($3);
 $4 = ((($2)) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($5)) + 104|0);
 __ZN9osgViewer4View12setSceneDataIN3osg4NodeEEEvRKNS2_7ref_ptrIT_EE($6,$2);
 STACKTOP = sp;return;
}
function __ZN4mjin11application6memory11Coordinator16reserveMaterialsEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(64|0);
 $3 = sp + 52|0;
 $8 = sp + 24|0;
 $10 = sp + 8|0;
 $1 = $0;
 $13 = $1;
 $2 = 2;
 $14 = (__Znwj(136)|0);
 __THREW__ = 0;
 invoke_vi(3763,($14|0));
 $15 = __THREW__; __THREW__ = 0;
 $16 = $15&1;
 if ($16) {
  $47 = ___cxa_find_matching_catch_2()|0;
  $48 = tempRet0;
  $4 = $47;
  $5 = $48;
  __ZdlPv($14);
  $79 = $4;
  $80 = $5;
  ___resumeException($79|0);
  // unreachable;
 }
 __ZN3osg7ref_ptrINS_5GroupEEC2EPS1_($3,$14);
 $6 = 0;
 while(1) {
  $17 = $6;
  $18 = ($17|0)<(2);
  if (!($18)) {
   label = 14;
   break;
  }
  __THREW__ = 0;
  invoke_viddd(4055,($8|0),0.0,0.0,0.0);
  $19 = __THREW__; __THREW__ = 0;
  $20 = $19&1;
  if ($20) {
   break;
  }
  __THREW__ = 0;
  $21 = (invoke_iid(4056,($8|0),1.0)|0);
  $22 = __THREW__; __THREW__ = 0;
  $23 = $22&1;
  if ($23) {
   break;
  }
  $7 = $21;
  $24 = ((($13)) + 16|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = $7;
  __THREW__ = 0;
  invoke_viddd(4057,($10|0),0.0,0.0,0.0);
  $27 = __THREW__; __THREW__ = 0;
  $28 = $27&1;
  if ($28) {
   break;
  }
  __THREW__ = 0;
  $29 = (invoke_iiii(4058,($25|0),($26|0),($10|0))|0);
  $30 = __THREW__; __THREW__ = 0;
  $31 = $30&1;
  if ($31) {
   break;
  }
  $9 = $29;
  $32 = $7;
  $33 = $9;
  __THREW__ = 0;
  invoke_vii(3726,($32|0),($33|0));
  $34 = __THREW__; __THREW__ = 0;
  $35 = $34&1;
  if ($35) {
   break;
  }
  __THREW__ = 0;
  $36 = (invoke_ii(4059,($3|0))|0);
  $37 = __THREW__; __THREW__ = 0;
  $38 = $37&1;
  if ($38) {
   break;
  }
  $39 = HEAP32[$36>>2]|0;
  $40 = ((($39)) + 204|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = $7;
  __THREW__ = 0;
  (invoke_iii($41|0,($36|0),($42|0))|0);
  $43 = __THREW__; __THREW__ = 0;
  $44 = $43&1;
  if ($44) {
   break;
  }
  $45 = $6;
  $46 = (($45) + 1)|0;
  $6 = $46;
 }
 L15: do {
  if ((label|0) == 14) {
   $51 = ((($13)) + 12|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = ((($52)) + 104|0);
   __THREW__ = 0;
   invoke_vii(4060,($53|0),($3|0));
   $54 = __THREW__; __THREW__ = 0;
   $55 = $54&1;
   if (!($55)) {
    $56 = ((($13)) + 12|0);
    $57 = HEAP32[$56>>2]|0;
    $58 = HEAP32[$57>>2]|0;
    $59 = ((($58)) + 64|0);
    $60 = HEAP32[$59>>2]|0;
    __THREW__ = 0;
    invoke_vid($60|0,($57|0),1.7976931348623157E+308);
    $61 = __THREW__; __THREW__ = 0;
    $62 = $61&1;
    if (!($62)) {
     $11 = 0;
     while(1) {
      $63 = $11;
      $64 = ($63|0)<(2);
      if (!($64)) {
       break;
      }
      __THREW__ = 0;
      $65 = (invoke_ii(4059,($3|0))|0);
      $66 = __THREW__; __THREW__ = 0;
      $67 = $66&1;
      if ($67) {
       break L15;
      }
      $68 = $11;
      __THREW__ = 0;
      $69 = (invoke_iii(4061,($65|0),($68|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       break L15;
      }
      $12 = $69;
      $72 = ((($13)) + 16|0);
      $73 = HEAP32[$72>>2]|0;
      $74 = $12;
      __THREW__ = 0;
      invoke_vii(4062,($73|0),($74|0));
      $75 = __THREW__; __THREW__ = 0;
      $76 = $75&1;
      if ($76) {
       break L15;
      }
      $77 = $11;
      $78 = (($77) + 1)|0;
      $11 = $78;
     }
     __ZN3osg7ref_ptrINS_5GroupEED2Ev($3);
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $49 = ___cxa_find_matching_catch_2()|0;
 $50 = tempRet0;
 $4 = $49;
 $5 = $50;
 __ZN3osg7ref_ptrINS_5GroupEED2Ev($3);
 $79 = $4;
 $80 = $5;
 ___resumeException($79|0);
 // unreachable;
}
function __ZNK3osg7ref_ptrINS_4NodeEEcvPS1_Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 STACKTOP = sp;return ($3|0);
}
function __ZN9osgViewer4View12setSceneDataIN3osg4NodeEEEvRKNS2_7ref_ptrIT_EE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = $0;
 $3 = $1;
 $4 = $2;
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($5)) + 44|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $3;
 $9 = (__ZNK3osg7ref_ptrINS_4NodeEE3getEv($8)|0);
 FUNCTION_TABLE_vii[$7 & 8191]($4,$9);
 STACKTOP = sp;return;
}
function __ZNK3osg7ref_ptrINS_4NodeEE3getEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 STACKTOP = sp;return ($3|0);
}
function __ZN3osg7ref_ptrINS_5GroupEEC2EPS1_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = $0;
 $3 = $1;
 $4 = $2;
 $5 = $3;
 HEAP32[$4>>2] = $5;
 $6 = HEAP32[$4>>2]|0;
 $7 = ($6|0)!=(0|0);
 if (!($7)) {
  STACKTOP = sp;return;
 }
 $8 = HEAP32[$4>>2]|0;
 (__ZNK3osg10Referenced3refEv($8)|0);
 STACKTOP = sp;return;
}
function __ZNK3osg7ref_ptrINS_5GroupEEptEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 STACKTOP = sp;return ($3|0);
}
function __ZN3osg7ref_ptrINS_5GroupEED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)!=(0|0);
 if (!($4)) {
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 $5 = HEAP32[$2>>2]|0;
 __THREW__ = 0;
 (invoke_ii(4050,($5|0))|0);
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if ($7) {
  $8 = ___cxa_find_matching_catch_3(0|0)|0;
  $9 = tempRet0;
  ___clang_call_terminate($8);
  // unreachable;
 } else {
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
}
function __ZN9osgViewer4View12setSceneDataIN3osg5GroupEEEvRKNS2_7ref_ptrIT_EE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = $0;
 $3 = $1;
 $4 = $2;
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($5)) + 44|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $3;
 $9 = (__ZNK3osg7ref_ptrINS_5GroupEE3getEv($8)|0);
 FUNCTION_TABLE_vii[$7 & 8191]($4,$9);
 STACKTOP = sp;return;
}
function __ZN3osg5Group8getChildEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $4 = $0;
 $5 = $1;
 $6 = $4;
 $7 = ((($6)) + 124|0);
 $8 = $5;
 $2 = $7;
 $3 = $8;
 $9 = $2;
 $10 = HEAP32[$9>>2]|0;
 $11 = $3;
 $12 = (($10) + ($11<<2)|0);
 $13 = (__ZNK3osg7ref_ptrINS_4NodeEE3getEv($12)|0);
 STACKTOP = sp;return ($13|0);
}
function __ZNK3osg7ref_ptrINS_5GroupEE3getEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 STACKTOP = sp;return ($3|0);
}
function __ZN4mjin11application6memory11Coordinator4tickEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 $3 = ((($2)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 __ZN4mjin11application6memory4Game4tickEv($4);
 STACKTOP = sp;return;
}
function __GLOBAL__sub_I_Game_cpp() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 ___cxx_global_var_init_4298();
 ___cxx_global_var_init_1_4299();
 ___cxx_global_var_init_2_4300();
 ___cxx_global_var_init_3();
 ___cxx_global_var_init_4();
 ___cxx_global_var_init_5();
 return;
}
function ___cxx_global_var_init_4298() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg5Vec3fC2Efff(208996,1.0,0.0,0.0);
 return;
}
function ___cxx_global_var_init_1_4299() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg5Vec3fC2Efff(208984,0.0,1.0,0.0);
 return;
}
function ___cxx_global_var_init_2_4300() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg5Vec3fC2Efff(208972,0.0,0.0,1.0);
 return;
}
function ___cxx_global_var_init_3() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg5Vec4fC2Effff(208956,0.20000000298023224,0.20000000298023224,0.40000000596046448,0.0);
 return;
}
function ___cxx_global_var_init_4() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg5Vec4fC2Effff(208940,0.20000000298023224,1.0,0.20000000298023224,0.0);
 return;
}
function ___cxx_global_var_init_5() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg5Vec4fC2Effff(208924,1.0,0.20000000298023224,0.20000000298023224,0.0);
 return;
}
function __ZN3osg5Vec4fC2Effff($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = +$1;
 $2 = +$2;
 $3 = +$3;
 $4 = +$4;
 var $10 = 0, $11 = 0.0, $12 = 0.0, $13 = 0, $14 = 0.0, $15 = 0, $16 = 0.0, $17 = 0, $5 = 0, $6 = 0.0, $7 = 0.0, $8 = 0.0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $5 = $0;
 $6 = $1;
 $7 = $2;
 $8 = $3;
 $9 = $4;
 $10 = $5;
 $11 = $6;
 HEAPF32[$10>>2] = $11;
 $12 = $7;
 $13 = ((($10)) + 4|0);
 HEAPF32[$13>>2] = $12;
 $14 = $8;
 $15 = ((($10)) + 8|0);
 HEAPF32[$15>>2] = $14;
 $16 = $9;
 $17 = ((($10)) + 12|0);
 HEAPF32[$17>>2] = $16;
 STACKTOP = sp;return;
}
function __ZN4mjin11application6memory4GameC2EPN3osg6CameraEPNS1_8material4PoolE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(128|0);
 $7 = sp + 100|0;
 $10 = sp + 88|0;
 $17 = sp + 60|0;
 $20 = sp + 48|0;
 $30 = sp;
 $24 = $0;
 $25 = $1;
 $26 = $2;
 $31 = $24;
 __ZN3osg7ref_ptrINS_5GroupEEC2Ev($31);
 $32 = ((($31)) + 4|0);
 $23 = $32;
 $33 = $23;
 $22 = $33;
 $34 = $22;
 $21 = $34;
 HEAP32[$34>>2] = 0;
 $35 = ((($34)) + 4|0);
 HEAP32[$35>>2] = 0;
 $36 = ((($34)) + 8|0);
 $19 = $36;
 HEAP32[$20>>2] = 0;
 $37 = $19;
 $18 = $20;
 $38 = $18;
 $39 = HEAP32[$38>>2]|0;
 $16 = $37;
 HEAP32[$17>>2] = $39;
 $40 = $16;
 $15 = $40;
 $14 = $17;
 $41 = $14;
 $42 = HEAP32[$41>>2]|0;
 HEAP32[$40>>2] = $42;
 $43 = ((($31)) + 16|0);
 $13 = $43;
 $44 = $13;
 $12 = $44;
 $45 = $12;
 $11 = $45;
 HEAP32[$45>>2] = 0;
 $46 = ((($45)) + 4|0);
 HEAP32[$46>>2] = 0;
 $47 = ((($45)) + 8|0);
 $9 = $47;
 HEAP32[$10>>2] = 0;
 $48 = $9;
 $8 = $10;
 $49 = $8;
 $50 = HEAP32[$49>>2]|0;
 $6 = $48;
 HEAP32[$7>>2] = $50;
 $51 = $6;
 $5 = $51;
 $4 = $7;
 $52 = $4;
 $53 = HEAP32[$52>>2]|0;
 HEAP32[$51>>2] = $53;
 $54 = ((($31)) + 28|0);
 $55 = $25;
 HEAP32[$54>>2] = $55;
 $56 = ((($31)) + 32|0);
 $3 = $56;
 $57 = $3;
 $58 = ((($57)) + 16|0);
 HEAP32[$58>>2] = 0;
 $59 = ((($31)) + 56|0);
 __THREW__ = 0;
 invoke_vi(4063,($59|0));
 $60 = __THREW__; __THREW__ = 0;
 $61 = $60&1;
 if ($61) {
  $87 = ___cxa_find_matching_catch_2()|0;
  $88 = tempRet0;
  $27 = $87;
  $28 = $88;
  __ZNSt3__28functionIFbdEED2Ev($56);
  __ZNSt3__26vectorIiNS_9allocatorIiEEED2Ev($43);
  __ZNSt3__26vectorIN4mjin11application6memory4ItemENS_9allocatorIS4_EEED2Ev($32);
  __ZN3osg7ref_ptrINS_5GroupEED2Ev($31);
  $93 = $27;
  $94 = $28;
  ___resumeException($93|0);
  // unreachable;
 }
 $62 = ((($31)) + 72|0);
 $63 = $26;
 HEAP32[$62>>2] = $63;
 __THREW__ = 0;
 $64 = (invoke_ii(3276,136)|0);
 $65 = __THREW__; __THREW__ = 0;
 $66 = $65&1;
 do {
  if ($66) {
   label = 12;
  } else {
   __THREW__ = 0;
   invoke_vi(3763,($64|0));
   $67 = __THREW__; __THREW__ = 0;
   $68 = $67&1;
   if ($68) {
    $91 = ___cxa_find_matching_catch_2()|0;
    $92 = tempRet0;
    $27 = $91;
    $28 = $92;
    __ZdlPv($64);
    break;
   }
   __THREW__ = 0;
   (invoke_iii(4064,($31|0),($64|0))|0);
   $69 = __THREW__; __THREW__ = 0;
   $70 = $69&1;
   if ($70) {
    label = 12;
   } else {
    $71 = ((($31)) + 72|0);
    $72 = HEAP32[$71>>2]|0;
    __THREW__ = 0;
    $73 = (invoke_ii(4065,($31|0))|0);
    $74 = __THREW__; __THREW__ = 0;
    $75 = $74&1;
    if ($75) {
     label = 12;
    } else {
     __THREW__ = 0;
     invoke_viddd(4057,($30|0),0.5,0.5,0.5);
     $76 = __THREW__; __THREW__ = 0;
     $77 = $76&1;
     if ($77) {
      label = 12;
     } else {
      __THREW__ = 0;
      $78 = (invoke_iiii(4058,($72|0),($73|0),($30|0))|0);
      $79 = __THREW__; __THREW__ = 0;
      $80 = $79&1;
      if ($80) {
       label = 12;
      } else {
       $29 = $78;
       __THREW__ = 0;
       $81 = (invoke_ii(4059,($31|0))|0);
       $82 = __THREW__; __THREW__ = 0;
       $83 = $82&1;
       if ($83) {
        label = 12;
       } else {
        $84 = $29;
        __THREW__ = 0;
        invoke_vii(3726,($81|0),($84|0));
        $85 = __THREW__; __THREW__ = 0;
        $86 = $85&1;
        if ($86) {
         label = 12;
        } else {
         STACKTOP = sp;return;
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 12) {
  $89 = ___cxa_find_matching_catch_2()|0;
  $90 = tempRet0;
  $27 = $89;
  $28 = $90;
 }
 __ZN3osg5TimerD2Ev($59);
 __ZNSt3__28functionIFbdEED2Ev($56);
 __ZNSt3__26vectorIiNS_9allocatorIiEEED2Ev($43);
 __ZNSt3__26vectorIN4mjin11application6memory4ItemENS_9allocatorIS4_EEED2Ev($32);
 __ZN3osg7ref_ptrINS_5GroupEED2Ev($31);
 $93 = $27;
 $94 = $28;
 ___resumeException($93|0);
 // unreachable;
}
function __ZN3osg7ref_ptrINS_5GroupEEC2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN3osg7ref_ptrINS_5GroupEEaSEPS1_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = $0;
 $4 = $1;
 $6 = $3;
 $7 = HEAP32[$6>>2]|0;
 $8 = $4;
 $9 = ($7|0)==($8|0);
 if ($9) {
  $2 = $6;
  $18 = $2;
  STACKTOP = sp;return ($18|0);
 }
 $10 = HEAP32[$6>>2]|0;
 $5 = $10;
 $11 = $4;
 HEAP32[$6>>2] = $11;
 $12 = HEAP32[$6>>2]|0;
 $13 = ($12|0)!=(0|0);
 if ($13) {
  $14 = HEAP32[$6>>2]|0;
  (__ZNK3osg10Referenced3refEv($14)|0);
 }
 $15 = $5;
 $16 = ($15|0)!=(0|0);
 if ($16) {
  $17 = $5;
  (__ZNK3osg10Referenced5unrefEv($17)|0);
 }
 $2 = $6;
 $18 = $2;
 STACKTOP = sp;return ($18|0);
}
function __ZNK3osg7ref_ptrINS_5GroupEEcvPS1_Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 STACKTOP = sp;return ($3|0);
}
function __ZN3osg5TimerD2Ev($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 STACKTOP = sp;return;
}
function __ZNSt3__28functionIFbdEED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 $3 = ((($2)) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==($2|0);
 $6 = ((($2)) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 if ($5) {
  $8 = HEAP32[$7>>2]|0;
  $9 = ((($8)) + 16|0);
  $10 = HEAP32[$9>>2]|0;
  FUNCTION_TABLE_vi[$10 & 8191]($7);
  STACKTOP = sp;return;
 }
 $11 = ($7|0)!=(0|0);
 if (!($11)) {
  STACKTOP = sp;return;
 }
 $12 = ((($2)) + 16|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = HEAP32[$13>>2]|0;
 $15 = ((($14)) + 20|0);
 $16 = HEAP32[$15>>2]|0;
 FUNCTION_TABLE_vi[$16 & 8191]($13);
 STACKTOP = sp;return;
}
function __ZNSt3__26vectorIiNS_9allocatorIiEEED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 __ZNSt3__213__vector_baseIiNS_9allocatorIiEEED2Ev($2);
 STACKTOP = sp;return;
}
function __ZNSt3__26vectorIN4mjin11application6memory4ItemENS_9allocatorIS4_EEED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 __ZNSt3__213__vector_baseIN4mjin11application6memory4ItemENS_9allocatorIS4_EEED2Ev($2);
 STACKTOP = sp;return;
}
function __ZNSt3__213__vector_baseIN4mjin11application6memory4ItemENS_9allocatorIS4_EEED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(128|0);
 $19 = sp;
 $22 = sp + 116|0;
 $30 = $0;
 $31 = $30;
 $32 = HEAP32[$31>>2]|0;
 $33 = ($32|0)!=(0|0);
 if (!($33)) {
  STACKTOP = sp;return;
 }
 $29 = $31;
 $34 = $29;
 $35 = HEAP32[$34>>2]|0;
 $27 = $34;
 $28 = $35;
 $36 = $27;
 while(1) {
  $37 = $28;
  $38 = ((($36)) + 4|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = ($37|0)!=($39|0);
  if (!($40)) {
   break;
  }
  $26 = $36;
  $41 = $26;
  $42 = ((($41)) + 8|0);
  $25 = $42;
  $43 = $25;
  $24 = $43;
  $44 = $24;
  $45 = ((($36)) + 4|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = ((($46)) + -12|0);
  HEAP32[$45>>2] = $47;
  $23 = $47;
  $48 = $23;
  $20 = $44;
  $21 = $48;
  $49 = $20;
  $50 = $21;
  ;HEAP8[$19>>0]=HEAP8[$22>>0]|0;
  $17 = $49;
  $18 = $50;
  $51 = $17;
  $52 = $18;
  $15 = $51;
  $16 = $52;
 }
 $7 = $31;
 $53 = $7;
 $54 = ((($53)) + 8|0);
 $6 = $54;
 $55 = $6;
 $5 = $55;
 $56 = $5;
 $57 = HEAP32[$31>>2]|0;
 $4 = $31;
 $58 = $4;
 $3 = $58;
 $59 = $3;
 $60 = ((($59)) + 8|0);
 $2 = $60;
 $61 = $2;
 $1 = $61;
 $62 = $1;
 $63 = HEAP32[$62>>2]|0;
 $64 = HEAP32[$58>>2]|0;
 $65 = $63;
 $66 = $64;
 $67 = (($65) - ($66))|0;
 $68 = (($67|0) / 12)&-1;
 $12 = $56;
 $13 = $57;
 $14 = $68;
 $69 = $12;
 $70 = $13;
 $71 = $14;
 $9 = $69;
 $10 = $70;
 $11 = $71;
 $72 = $10;
 $8 = $72;
 $73 = $8;
 __ZdlPv($73);
 STACKTOP = sp;return;
}
function __ZNSt3__213__vector_baseIiNS_9allocatorIiEEED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(128|0);
 $19 = sp;
 $22 = sp + 116|0;
 $30 = $0;
 $31 = $30;
 $32 = HEAP32[$31>>2]|0;
 $33 = ($32|0)!=(0|0);
 if (!($33)) {
  STACKTOP = sp;return;
 }
 $29 = $31;
 $34 = $29;
 $35 = HEAP32[$34>>2]|0;
 $27 = $34;
 $28 = $35;
 $36 = $27;
 while(1) {
  $37 = $28;
  $38 = ((($36)) + 4|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = ($37|0)!=($39|0);
  if (!($40)) {
   break;
  }
  $26 = $36;
  $41 = $26;
  $42 = ((($41)) + 8|0);
  $25 = $42;
  $43 = $25;
  $24 = $43;
  $44 = $24;
  $45 = ((($36)) + 4|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = ((($46)) + -4|0);
  HEAP32[$45>>2] = $47;
  $23 = $47;
  $48 = $23;
  $20 = $44;
  $21 = $48;
  $49 = $20;
  $50 = $21;
  ;HEAP8[$19>>0]=HEAP8[$22>>0]|0;
  $17 = $49;
  $18 = $50;
  $51 = $17;
  $52 = $18;
  $15 = $51;
  $16 = $52;
 }
 $7 = $31;
 $53 = $7;
 $54 = ((($53)) + 8|0);
 $6 = $54;
 $55 = $6;
 $5 = $55;
 $56 = $5;
 $57 = HEAP32[$31>>2]|0;
 $4 = $31;
 $58 = $4;
 $3 = $58;
 $59 = $3;
 $60 = ((($59)) + 8|0);
 $2 = $60;
 $61 = $2;
 $1 = $61;
 $62 = $1;
 $63 = HEAP32[$62>>2]|0;
 $64 = HEAP32[$58>>2]|0;
 $65 = $63;
 $66 = $64;
 $67 = (($65) - ($66))|0;
 $68 = (($67|0) / 4)&-1;
 $12 = $56;
 $13 = $57;
 $14 = $68;
 $69 = $12;
 $70 = $13;
 $71 = $14;
 $9 = $69;
 $10 = $70;
 $11 = $71;
 $72 = $10;
 $8 = $72;
 $73 = $8;
 __ZdlPv($73);
 STACKTOP = sp;return;
}
function __ZN4mjin11application6memory4GameD2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 $3 = ((($2)) + 56|0);
 __ZN3osg5TimerD2Ev($3);
 $4 = ((($2)) + 32|0);
 __ZNSt3__28functionIFbdEED2Ev($4);
 $5 = ((($2)) + 16|0);
 __ZNSt3__26vectorIiNS_9allocatorIiEEED2Ev($5);
 $6 = ((($2)) + 4|0);
 __ZNSt3__26vectorIN4mjin11application6memory4ItemENS_9allocatorIS4_EEED2Ev($6);
 __ZN3osg7ref_ptrINS_5GroupEED2Ev($2);
 STACKTOP = sp;return;
}
function __ZN4mjin11application6memory4Game5startEv($0) {
 $0 = $0|0;
 var $$byval_copy = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $$byval_copy = sp + 25|0;
 $3 = sp + 24|0;
 $5 = sp;
 $4 = $0;
 $6 = $4;
 __ZN4mjin11application6memory16createRandomGridEi($5,4);
 $7 = ((($6)) + 4|0);
 $1 = $7;
 $2 = $5;
 $8 = $1;
 $9 = $2;
 ;HEAP8[$$byval_copy>>0]=HEAP8[$3>>0]|0;
 __ZNSt3__26vectorIN4mjin11application6memory4ItemENS_9allocatorIS4_EEE13__move_assignERS7_NS_17integral_constantIbLb1EEE($8,$9,$$byval_copy);
 __ZNSt3__26vectorIN4mjin11application6memory4ItemENS_9allocatorIS4_EEED2Ev($5);
 __ZN4mjin11application6memory4Game11createNodesEv($6);
 __ZN4mjin11application6memory4Game10indexNodesEv($6);
 $10 = ((($6)) + 28|0);
 $11 = HEAP32[$10>>2]|0;
 __ZN3osg6Camera13setClearColorERKNS_5Vec4fE($11,208956);
 STACKTOP = sp;return;
}
function __ZNSt3__26vectorIN4mjin11application6memory4ItemENS_9allocatorIS4_EEE13__move_assignERS7_NS_17integral_constantIbLb1EEE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(96|0);
 $21 = sp;
 $24 = sp + 92|0;
 $25 = $0;
 $26 = $1;
 $27 = $25;
 __ZNSt3__26vectorIN4mjin11application6memory4ItemENS_9allocatorIS4_EEE10deallocateEv($27);
 $28 = $26;
 $22 = $27;
 $23 = $28;
 $29 = $22;
 $30 = $23;
 ;HEAP8[$21>>0]=HEAP8[$24>>0]|0;
 $19 = $29;
 $20 = $30;
 $31 = $19;
 $32 = $20;
 $18 = $32;
 $33 = $18;
 $34 = ((($33)) + 8|0);
 $17 = $34;
 $35 = $17;
 $16 = $35;
 $36 = $16;
 $12 = $36;
 $15 = $31;
 $37 = $15;
 $38 = ((($37)) + 8|0);
 $14 = $38;
 $39 = $14;
 $13 = $39;
 $40 = $26;
 $41 = HEAP32[$40>>2]|0;
 HEAP32[$27>>2] = $41;
 $42 = $26;
 $43 = ((($42)) + 4|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = ((($27)) + 4|0);
 HEAP32[$45>>2] = $44;
 $46 = $26;
 $5 = $46;
 $47 = $5;
 $48 = ((($47)) + 8|0);
 $4 = $48;
 $49 = $4;
 $3 = $49;
 $50 = $3;
 $51 = HEAP32[$50>>2]|0;
 $8 = $27;
 $52 = $8;
 $53 = ((($52)) + 8|0);
 $7 = $53;
 $54 = $7;
 $6 = $54;
 $55 = $6;
 HEAP32[$55>>2] = $51;
 $56 = $26;
 $11 = $56;
 $57 = $11;
 $58 = ((($57)) + 8|0);
 $10 = $58;
 $59 = $10;
 $9 = $59;
 $60 = $9;
 HEAP32[$60>>2] = 0;
 $61 = $26;
 $62 = ((($61)) + 4|0);
 HEAP32[$62>>2] = 0;
 $63 = $26;
 HEAP32[$63>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN4mjin11application6memory4Game11createNodesEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0.0, $25 = 0.0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0.0, $66 = 0, $67 = 0.0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(144|0);
 $10 = sp + 100|0;
 $13 = sp + 88|0;
 $18 = sp + 68|0;
 $21 = sp + 56|0;
 $27 = sp + 32|0;
 $28 = sp + 28|0;
 $29 = sp + 16|0;
 $31 = sp;
 $23 = $0;
 $32 = $23;
 $24 = 0.0;
 $25 = 0.30000001192092896;
 $33 = ((($32)) + 4|0);
 $26 = $33;
 $34 = $26;
 $22 = $34;
 $35 = $22;
 $36 = HEAP32[$35>>2]|0;
 $19 = $35;
 $20 = $36;
 $37 = $20;
 $16 = $18;
 $17 = $37;
 $38 = $16;
 $39 = $17;
 HEAP32[$38>>2] = $39;
 $40 = HEAP32[$18>>2]|0;
 HEAP32[$21>>2] = $40;
 $41 = HEAP32[$21>>2]|0;
 HEAP32[$27>>2] = $41;
 $42 = $26;
 $14 = $42;
 $43 = $14;
 $44 = ((($43)) + 4|0);
 $45 = HEAP32[$44>>2]|0;
 $11 = $43;
 $12 = $45;
 $46 = $12;
 $8 = $10;
 $9 = $46;
 $47 = $8;
 $48 = $9;
 HEAP32[$47>>2] = $48;
 $49 = HEAP32[$10>>2]|0;
 HEAP32[$13>>2] = $49;
 $50 = HEAP32[$13>>2]|0;
 HEAP32[$28>>2] = $50;
 while(1) {
  $6 = $27;
  $7 = $28;
  $51 = $6;
  $52 = $7;
  $4 = $51;
  $5 = $52;
  $53 = $4;
  $3 = $53;
  $54 = $3;
  $55 = HEAP32[$54>>2]|0;
  $56 = $5;
  $2 = $56;
  $57 = $2;
  $58 = HEAP32[$57>>2]|0;
  $59 = ($55|0)==($58|0);
  $60 = $59 ^ 1;
  if (!($60)) {
   break;
  }
  $1 = $27;
  $61 = $1;
  $62 = HEAP32[$61>>2]|0;
  ;HEAP32[$29>>2]=HEAP32[$62>>2]|0;HEAP32[$29+4>>2]=HEAP32[$62+4>>2]|0;HEAP32[$29+8>>2]=HEAP32[$62+8>>2]|0;
  $63 = ((($29)) + 4|0);
  $64 = HEAP32[$63>>2]|0;
  $65 = (+($64|0));
  $66 = HEAP32[$29>>2]|0;
  $67 = (+($66|0));
  __ZN3osg5Vec3fC2Efff($31,$65,0.0,$67);
  $68 = (__ZN4mjin11application6memory6render12createSphereERKN3osg5Vec3fEf($31,0.30000001192092896)|0);
  $30 = $68;
  $69 = (__ZNK3osg7ref_ptrINS_5GroupEEptEv($32)|0);
  $70 = HEAP32[$69>>2]|0;
  $71 = ((($70)) + 204|0);
  $72 = HEAP32[$71>>2]|0;
  $73 = $30;
  (FUNCTION_TABLE_iii[$72 & 8191]($69,$73)|0);
  $74 = $30;
  $75 = $30;
  $76 = (__ZNK3osg4Node11getNodeMaskEv($75)|0);
  $77 = $76 & -5;
  __ZN3osg4Node11setNodeMaskEj($74,$77);
  $15 = $27;
  $78 = $15;
  $79 = HEAP32[$78>>2]|0;
  $80 = ((($79)) + 12|0);
  HEAP32[$78>>2] = $80;
 }
 STACKTOP = sp;return;
}
function __ZN4mjin11application6memory4Game10indexNodesEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $5 = sp + 8|0;
 $1 = $0;
 $8 = $1;
 $9 = (__ZNK3osg7ref_ptrINS_5GroupEEptEv($8)|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ((($10)) + 224|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (FUNCTION_TABLE_ii[$12 & 8191]($9)|0);
 $2 = $13;
 $3 = 0;
 while(1) {
  $14 = $3;
  $15 = $2;
  $16 = ($14>>>0)<($15>>>0);
  if (!($16)) {
   label = 6;
   break;
  }
  $17 = (__ZNK3osg7ref_ptrINS_5GroupEEptEv($8)|0);
  $18 = $3;
  $19 = (__ZN3osg5Group8getChildEj($17,$18)|0);
  $4 = $19;
  $20 = $4;
  $21 = $3;
  __ZNSt3__29to_stringEj($5,$21);
  __THREW__ = 0;
  invoke_vii(4066,($20|0),($5|0));
  $22 = __THREW__; __THREW__ = 0;
  $23 = $22&1;
  if ($23) {
   label = 5;
   break;
  }
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($5);
  $24 = $3;
  $25 = (($24) + 1)|0;
  $3 = $25;
 }
 if ((label|0) == 5) {
  $26 = ___cxa_find_matching_catch_2()|0;
  $27 = tempRet0;
  $6 = $26;
  $7 = $27;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($5);
  $28 = $6;
  $29 = $7;
  ___resumeException($28|0);
  // unreachable;
 }
 else if ((label|0) == 6) {
  STACKTOP = sp;return;
 }
}
function __ZN3osg6Camera13setClearColorERKNS_5Vec4fE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = $0;
 $3 = $1;
 $4 = $2;
 $5 = $3;
 $6 = ((($4)) + 240|0);
 ;HEAP32[$6>>2]=HEAP32[$5>>2]|0;HEAP32[$6+4>>2]=HEAP32[$5+4>>2]|0;HEAP32[$6+8>>2]=HEAP32[$5+8>>2]|0;HEAP32[$6+12>>2]=HEAP32[$5+12>>2]|0;
 $7 = ((($4)) + 144|0);
 __ZN3osg12CullSettings15applyMaskActionEj($7,8192);
 STACKTOP = sp;return;
}
function __ZN3osg12CullSettings15applyMaskActionEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = $0;
 $3 = $1;
 $4 = $2;
 $5 = ((($4)) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if (!($7)) {
  STACKTOP = sp;return;
 }
 $8 = ((($4)) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $3;
 $11 = $10 ^ -1;
 $12 = $9 & $11;
 $13 = ((($4)) + 4|0);
 HEAP32[$13>>2] = $12;
 STACKTOP = sp;return;
}
function __ZNK3osg4Node11getNodeMaskEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 $3 = ((($2)) + 116|0);
 $4 = HEAP32[$3>>2]|0;
 STACKTOP = sp;return ($4|0);
}
function __ZN3osg4Node11setNodeMaskEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = $0;
 $3 = $1;
 $4 = $2;
 $5 = $3;
 $6 = ((($4)) + 116|0);
 HEAP32[$6>>2] = $5;
 STACKTOP = sp;return;
}
function __ZNSt3__26vectorIN4mjin11application6memory4ItemENS_9allocatorIS4_EEE10deallocateEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0;
 var $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0;
 var $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0;
 var $153 = 0, $154 = 0, $155 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 240|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(240|0);
 $45 = sp;
 $48 = sp + 232|0;
 $59 = $0;
 $60 = $59;
 $61 = HEAP32[$60>>2]|0;
 $62 = ($61|0)!=(0|0);
 if (!($62)) {
  STACKTOP = sp;return;
 }
 $57 = $60;
 $63 = $57;
 $56 = $63;
 $64 = $56;
 $65 = ((($64)) + 4|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = HEAP32[$64>>2]|0;
 $68 = $66;
 $69 = $67;
 $70 = (($68) - ($69))|0;
 $71 = (($70|0) / 12)&-1;
 $58 = $71;
 $55 = $63;
 $72 = $55;
 $73 = HEAP32[$72>>2]|0;
 $53 = $72;
 $54 = $73;
 $74 = $53;
 while(1) {
  $75 = $54;
  $76 = ((($74)) + 4|0);
  $77 = HEAP32[$76>>2]|0;
  $78 = ($75|0)!=($77|0);
  if (!($78)) {
   break;
  }
  $52 = $74;
  $79 = $52;
  $80 = ((($79)) + 8|0);
  $51 = $80;
  $81 = $51;
  $50 = $81;
  $82 = $50;
  $83 = ((($74)) + 4|0);
  $84 = HEAP32[$83>>2]|0;
  $85 = ((($84)) + -12|0);
  HEAP32[$83>>2] = $85;
  $49 = $85;
  $86 = $49;
  $46 = $82;
  $47 = $86;
  $87 = $46;
  $88 = $47;
  ;HEAP8[$45>>0]=HEAP8[$48>>0]|0;
  $43 = $87;
  $44 = $88;
  $89 = $43;
  $90 = $44;
  $41 = $89;
  $42 = $90;
 }
 $91 = $58;
 $38 = $63;
 $39 = $91;
 $92 = $38;
 $37 = $92;
 $93 = $37;
 $94 = HEAP32[$93>>2]|0;
 $36 = $94;
 $95 = $36;
 $20 = $92;
 $96 = $20;
 $97 = HEAP32[$96>>2]|0;
 $19 = $97;
 $98 = $19;
 $25 = $92;
 $99 = $25;
 $24 = $99;
 $100 = $24;
 $23 = $100;
 $101 = $23;
 $102 = ((($101)) + 8|0);
 $22 = $102;
 $103 = $22;
 $21 = $103;
 $104 = $21;
 $105 = HEAP32[$104>>2]|0;
 $106 = HEAP32[$100>>2]|0;
 $107 = $105;
 $108 = $106;
 $109 = (($107) - ($108))|0;
 $110 = (($109|0) / 12)&-1;
 $111 = (($98) + (($110*12)|0)|0);
 $27 = $92;
 $112 = $27;
 $113 = HEAP32[$112>>2]|0;
 $26 = $113;
 $114 = $26;
 $115 = $39;
 $116 = (($114) + (($115*12)|0)|0);
 $29 = $92;
 $117 = $29;
 $118 = HEAP32[$117>>2]|0;
 $28 = $118;
 $119 = $28;
 $30 = $92;
 $120 = $30;
 $121 = ((($120)) + 4|0);
 $122 = HEAP32[$121>>2]|0;
 $123 = HEAP32[$120>>2]|0;
 $124 = $122;
 $125 = $123;
 $126 = (($124) - ($125))|0;
 $127 = (($126|0) / 12)&-1;
 $128 = (($119) + (($127*12)|0)|0);
 $31 = $92;
 $32 = $95;
 $33 = $111;
 $34 = $116;
 $35 = $128;
 $40 = $63;
 $8 = $60;
 $129 = $8;
 $130 = ((($129)) + 8|0);
 $7 = $130;
 $131 = $7;
 $6 = $131;
 $132 = $6;
 $133 = HEAP32[$60>>2]|0;
 $5 = $60;
 $134 = $5;
 $4 = $134;
 $135 = $4;
 $3 = $135;
 $136 = $3;
 $137 = ((($136)) + 8|0);
 $2 = $137;
 $138 = $2;
 $1 = $138;
 $139 = $1;
 $140 = HEAP32[$139>>2]|0;
 $141 = HEAP32[$135>>2]|0;
 $142 = $140;
 $143 = $141;
 $144 = (($142) - ($143))|0;
 $145 = (($144|0) / 12)&-1;
 $13 = $132;
 $14 = $133;
 $15 = $145;
 $146 = $13;
 $147 = $14;
 $148 = $15;
 $10 = $146;
 $11 = $147;
 $12 = $148;
 $149 = $11;
 $9 = $149;
 $150 = $9;
 __ZdlPv($150);
 $18 = $60;
 $151 = $18;
 $152 = ((($151)) + 8|0);
 $17 = $152;
 $153 = $17;
 $16 = $153;
 $154 = $16;
 HEAP32[$154>>2] = 0;
 $155 = ((($60)) + 4|0);
 HEAP32[$155>>2] = 0;
 HEAP32[$60>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN4mjin11application6memory4Game10selectItemERKN3osg5Vec2fE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $$byval_copy2 = 0, $$byval_copy3 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0;
 var $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0;
 var $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0;
 var $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0;
 var $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 512|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(512|0);
 $$byval_copy3 = sp + 496|0;
 $$byval_copy2 = sp + 492|0;
 $$byval_copy1 = sp + 488|0;
 $$byval_copy = sp + 484|0;
 $4 = sp + 472|0;
 $7 = sp + 460|0;
 $11 = sp + 444|0;
 $14 = sp + 432|0;
 $22 = sp + 400|0;
 $25 = sp + 388|0;
 $39 = sp + 332|0;
 $42 = sp + 320|0;
 $52 = sp + 280|0;
 $54 = sp + 16|0;
 $55 = sp + 8|0;
 $68 = sp;
 $73 = sp + 501|0;
 $83 = sp + 500|0;
 $86 = sp + 164|0;
 $89 = sp + 152|0;
 $94 = sp + 132|0;
 $97 = sp + 120|0;
 $105 = sp + 88|0;
 $106 = sp + 76|0;
 $110 = sp + 60|0;
 $111 = sp + 56|0;
 $112 = sp + 52|0;
 $113 = sp + 48|0;
 $114 = sp + 44|0;
 $115 = sp + 40|0;
 $116 = sp + 36|0;
 $117 = sp + 32|0;
 $118 = sp + 28|0;
 $119 = sp + 24|0;
 $120 = sp + 20|0;
 $102 = $0;
 $103 = $1;
 $121 = $102;
 $122 = ((($121)) + 32|0);
 $100 = $122;
 $101 = 0;
 $123 = $100;
 $99 = $123;
 $124 = $99;
 $125 = ((($124)) + 16|0);
 $126 = HEAP32[$125>>2]|0;
 $127 = ($126|0)!=(0|0);
 if ($127) {
  STACKTOP = sp;return;
 }
 $128 = $103;
 $129 = ((($121)) + 28|0);
 $130 = HEAP32[$129>>2]|0;
 $131 = (__ZN4mjin11application6memory9selection6nodeAtERKN3osg5Vec2fEPNS3_6CameraEj($128,$130,4)|0);
 $104 = $131;
 $132 = $104;
 $133 = ($132|0)!=(0|0);
 if (!($133)) {
  STACKTOP = sp;return;
 }
 $134 = $104;
 __ZN4mjin11application6memory8objectIdEPN3osg6ObjectE($106,$134);
 __THREW__ = 0;
 $135 = (invoke_iiii(4067,($106|0),(0|0),10)|0);
 $136 = __THREW__; __THREW__ = 0;
 $137 = $136&1;
 if ($137) {
  $233 = ___cxa_find_matching_catch_2()|0;
  $234 = tempRet0;
  $107 = $233;
  $108 = $234;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($106);
  $235 = $107;
  $236 = $108;
  ___resumeException($235|0);
  // unreachable;
 }
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($106);
 HEAP32[$105>>2] = $135;
 $138 = ((($121)) + 16|0);
 $109 = $138;
 $139 = $109;
 $98 = $139;
 $140 = $98;
 $141 = HEAP32[$140>>2]|0;
 $95 = $140;
 $96 = $141;
 $142 = $96;
 $92 = $94;
 $93 = $142;
 $143 = $92;
 $144 = $93;
 HEAP32[$143>>2] = $144;
 $145 = HEAP32[$94>>2]|0;
 HEAP32[$97>>2] = $145;
 $146 = HEAP32[$97>>2]|0;
 HEAP32[$111>>2] = $146;
 $147 = $109;
 $90 = $147;
 $148 = $90;
 $149 = ((($148)) + 4|0);
 $150 = HEAP32[$149>>2]|0;
 $87 = $148;
 $88 = $150;
 $151 = $88;
 $84 = $86;
 $85 = $151;
 $152 = $84;
 $153 = $85;
 HEAP32[$152>>2] = $153;
 $154 = HEAP32[$86>>2]|0;
 HEAP32[$89>>2] = $154;
 $155 = HEAP32[$89>>2]|0;
 HEAP32[$112>>2] = $155;
 ;HEAP8[$54>>0]=HEAP8[$112>>0]|0;HEAP8[$54+1>>0]=HEAP8[$112+1>>0]|0;HEAP8[$54+2>>0]=HEAP8[$112+2>>0]|0;HEAP8[$54+3>>0]=HEAP8[$112+3>>0]|0;
 ;HEAP8[$55>>0]=HEAP8[$111>>0]|0;HEAP8[$55+1>>0]=HEAP8[$111+1>>0]|0;HEAP8[$55+2>>0]=HEAP8[$111+2>>0]|0;HEAP8[$55+3>>0]=HEAP8[$111+3>>0]|0;
 $53 = $105;
 while(1) {
  $50 = $55;
  $51 = $54;
  $156 = $50;
  $157 = $51;
  $48 = $156;
  $49 = $157;
  $158 = $48;
  $47 = $158;
  $159 = $47;
  $160 = HEAP32[$159>>2]|0;
  $161 = $49;
  $46 = $161;
  $162 = $46;
  $163 = HEAP32[$162>>2]|0;
  $164 = ($160|0)==($163|0);
  $165 = $164 ^ 1;
  if (!($165)) {
   break;
  }
  $44 = $55;
  $166 = $44;
  $167 = HEAP32[$166>>2]|0;
  $168 = HEAP32[$167>>2]|0;
  $169 = $53;
  $170 = HEAP32[$169>>2]|0;
  $171 = ($168|0)==($170|0);
  if ($171) {
   break;
  }
  $45 = $55;
  $172 = $45;
  $173 = HEAP32[$172>>2]|0;
  $174 = ((($173)) + 4|0);
  HEAP32[$172>>2] = $174;
 }
 ;HEAP32[$52>>2]=HEAP32[$55>>2]|0;
 $175 = HEAP32[$52>>2]|0;
 HEAP32[$110>>2] = $175;
 $176 = $109;
 $43 = $176;
 $177 = $43;
 $178 = ((($177)) + 4|0);
 $179 = HEAP32[$178>>2]|0;
 $40 = $177;
 $41 = $179;
 $180 = $41;
 $37 = $39;
 $38 = $180;
 $181 = $37;
 $182 = $38;
 HEAP32[$181>>2] = $182;
 $183 = HEAP32[$39>>2]|0;
 HEAP32[$42>>2] = $183;
 $184 = HEAP32[$42>>2]|0;
 HEAP32[$113>>2] = $184;
 $35 = $110;
 $36 = $113;
 $185 = $35;
 $186 = $36;
 $33 = $185;
 $34 = $186;
 $187 = $33;
 $32 = $187;
 $188 = $32;
 $189 = HEAP32[$188>>2]|0;
 $190 = $34;
 $31 = $190;
 $191 = $31;
 $192 = HEAP32[$191>>2]|0;
 $193 = ($189|0)==($192|0);
 $194 = $193 ^ 1;
 $195 = $109;
 if ($194) {
  $196 = $109;
  $15 = $196;
  $197 = $15;
  $198 = HEAP32[$197>>2]|0;
  $12 = $197;
  $13 = $198;
  $199 = $13;
  $9 = $11;
  $10 = $199;
  $200 = $9;
  $201 = $10;
  HEAP32[$200>>2] = $201;
  $202 = HEAP32[$11>>2]|0;
  HEAP32[$14>>2] = $202;
  $203 = HEAP32[$14>>2]|0;
  HEAP32[$116>>2] = $203;
  $204 = $109;
  $8 = $204;
  $205 = $8;
  $206 = ((($205)) + 4|0);
  $207 = HEAP32[$206>>2]|0;
  $5 = $205;
  $6 = $207;
  $208 = $6;
  $2 = $4;
  $3 = $208;
  $209 = $2;
  $210 = $3;
  HEAP32[$209>>2] = $210;
  $211 = HEAP32[$4>>2]|0;
  HEAP32[$7>>2] = $211;
  $212 = HEAP32[$7>>2]|0;
  HEAP32[$117>>2] = $212;
  ;HEAP32[$$byval_copy>>2]=HEAP32[$116>>2]|0;
  ;HEAP32[$$byval_copy1>>2]=HEAP32[$117>>2]|0;
  $213 = (__ZNSt3__26removeINS_11__wrap_iterIPiEEiEET_S4_S4_RKT0_($$byval_copy,$$byval_copy1,$105)|0);
  HEAP32[$115>>2] = $213;
  $17 = $114;
  $18 = $115;
  $19 = 0;
  $214 = $17;
  $215 = $18;
  $16 = $215;
  $216 = $16;
  $217 = HEAP32[$216>>2]|0;
  HEAP32[$214>>2] = $217;
  $218 = $109;
  $26 = $218;
  $219 = $26;
  $220 = ((($219)) + 4|0);
  $221 = HEAP32[$220>>2]|0;
  $23 = $219;
  $24 = $221;
  $222 = $24;
  $20 = $22;
  $21 = $222;
  $223 = $20;
  $224 = $21;
  HEAP32[$223>>2] = $224;
  $225 = HEAP32[$22>>2]|0;
  HEAP32[$25>>2] = $225;
  $226 = HEAP32[$25>>2]|0;
  HEAP32[$119>>2] = $226;
  $28 = $118;
  $29 = $119;
  $30 = 0;
  $227 = $28;
  $228 = $29;
  $27 = $228;
  $229 = $27;
  $230 = HEAP32[$229>>2]|0;
  HEAP32[$227>>2] = $230;
  ;HEAP32[$$byval_copy2>>2]=HEAP32[$114>>2]|0;
  ;HEAP32[$$byval_copy3>>2]=HEAP32[$118>>2]|0;
  $231 = (__ZNSt3__26vectorIiNS_9allocatorIiEEE5eraseENS_11__wrap_iterIPKiEES7_($195,$$byval_copy2,$$byval_copy3)|0);
  HEAP32[$120>>2] = $231;
  $232 = HEAP32[$105>>2]|0;
  __ZN4mjin11application6memory4Game10selectNodeEib($121,$232,0);
 } else {
  $81 = $195;
  $82 = $105;
  $237 = $81;
  $238 = ((($237)) + 4|0);
  $239 = HEAP32[$238>>2]|0;
  $80 = $237;
  $240 = $80;
  $241 = ((($240)) + 8|0);
  $79 = $241;
  $242 = $79;
  $78 = $242;
  $243 = $78;
  $244 = HEAP32[$243>>2]|0;
  $245 = ($239|0)!=($244|0);
  if ($245) {
   $75 = $83;
   $76 = $237;
   $77 = 1;
   $58 = $237;
   $246 = $58;
   $247 = ((($246)) + 8|0);
   $57 = $247;
   $248 = $57;
   $56 = $248;
   $249 = $56;
   $250 = ((($237)) + 4|0);
   $251 = HEAP32[$250>>2]|0;
   $59 = $251;
   $252 = $59;
   $253 = $82;
   $70 = $249;
   $71 = $252;
   $72 = $253;
   $254 = $70;
   $255 = $71;
   $256 = $72;
   $69 = $256;
   $257 = $69;
   ;HEAP8[$68>>0]=HEAP8[$73>>0]|0;
   $65 = $254;
   $66 = $255;
   $67 = $257;
   $258 = $65;
   $259 = $66;
   $260 = $67;
   $64 = $260;
   $261 = $64;
   $61 = $258;
   $62 = $259;
   $63 = $261;
   $262 = $62;
   $263 = $63;
   $60 = $263;
   $264 = $60;
   $265 = HEAP32[$264>>2]|0;
   HEAP32[$262>>2] = $265;
   $74 = $83;
   $266 = ((($237)) + 4|0);
   $267 = HEAP32[$266>>2]|0;
   $268 = ((($267)) + 4|0);
   HEAP32[$266>>2] = $268;
  } else {
   $269 = $82;
   __ZNSt3__26vectorIiNS_9allocatorIiEEE21__push_back_slow_pathIRKiEEvOT_($237,$269);
  }
  $270 = HEAP32[$105>>2]|0;
  __ZN4mjin11application6memory4Game10selectNodeEib($121,$270,1);
 }
 $271 = $109;
 $91 = $271;
 $272 = $91;
 $273 = ((($272)) + 4|0);
 $274 = HEAP32[$273>>2]|0;
 $275 = HEAP32[$272>>2]|0;
 $276 = $274;
 $277 = $275;
 $278 = (($276) - ($277))|0;
 $279 = (($278|0) / 4)&-1;
 $280 = ($279|0)==(2);
 if (!($280)) {
  STACKTOP = sp;return;
 }
 __ZN4mjin11application6memory4Game18matchSelectedItemsEv($121);
 STACKTOP = sp;return;
}
function __ZNSt3__26removeINS_11__wrap_iterIPiEEiEET_S4_S4_RKT0_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(160|0);
 $29 = sp + 40|0;
 $31 = sp + 8|0;
 $32 = sp;
 $33 = sp + 32|0;
 $35 = sp + 24|0;
 $36 = sp + 20|0;
 $37 = sp + 16|0;
 $38 = sp + 12|0;
 $34 = $2;
 ;HEAP32[$36>>2]=HEAP32[$0>>2]|0;
 ;HEAP32[$37>>2]=HEAP32[$1>>2]|0;
 $39 = $34;
 ;HEAP8[$31>>0]=HEAP8[$37>>0]|0;HEAP8[$31+1>>0]=HEAP8[$37+1>>0]|0;HEAP8[$31+2>>0]=HEAP8[$37+2>>0]|0;HEAP8[$31+3>>0]=HEAP8[$37+3>>0]|0;
 ;HEAP8[$32>>0]=HEAP8[$36>>0]|0;HEAP8[$32+1>>0]=HEAP8[$36+1>>0]|0;HEAP8[$32+2>>0]=HEAP8[$36+2>>0]|0;HEAP8[$32+3>>0]=HEAP8[$36+3>>0]|0;
 $30 = $39;
 while(1) {
  $27 = $32;
  $28 = $31;
  $40 = $27;
  $41 = $28;
  $25 = $40;
  $26 = $41;
  $42 = $25;
  $24 = $42;
  $43 = $24;
  $44 = HEAP32[$43>>2]|0;
  $45 = $26;
  $23 = $45;
  $46 = $23;
  $47 = HEAP32[$46>>2]|0;
  $48 = ($44|0)==($47|0);
  $49 = $48 ^ 1;
  if (!($49)) {
   break;
  }
  $21 = $32;
  $50 = $21;
  $51 = HEAP32[$50>>2]|0;
  $52 = HEAP32[$51>>2]|0;
  $53 = $30;
  $54 = HEAP32[$53>>2]|0;
  $55 = ($52|0)==($54|0);
  if ($55) {
   break;
  }
  $22 = $32;
  $56 = $22;
  $57 = HEAP32[$56>>2]|0;
  $58 = ((($57)) + 4|0);
  HEAP32[$56>>2] = $58;
 }
 ;HEAP32[$29>>2]=HEAP32[$32>>2]|0;
 $59 = HEAP32[$29>>2]|0;
 HEAP32[$35>>2] = $59;
 ;HEAP32[$0>>2]=HEAP32[$35>>2]|0;
 $7 = $0;
 $8 = $1;
 $60 = $7;
 $61 = $8;
 $5 = $60;
 $6 = $61;
 $62 = $5;
 $4 = $62;
 $63 = $4;
 $64 = HEAP32[$63>>2]|0;
 $65 = $6;
 $3 = $65;
 $66 = $3;
 $67 = HEAP32[$66>>2]|0;
 $68 = ($64|0)==($67|0);
 $69 = $68 ^ 1;
 if (!($69)) {
  ;HEAP32[$33>>2]=HEAP32[$0>>2]|0;
  $98 = HEAP32[$33>>2]|0;
  STACKTOP = sp;return ($98|0);
 }
 ;HEAP32[$38>>2]=HEAP32[$0>>2]|0;
 while(1) {
  $9 = $38;
  $70 = $9;
  $71 = HEAP32[$70>>2]|0;
  $72 = ((($71)) + 4|0);
  HEAP32[$70>>2] = $72;
  $14 = $70;
  $15 = $1;
  $73 = $14;
  $74 = $15;
  $12 = $73;
  $13 = $74;
  $75 = $12;
  $11 = $75;
  $76 = $11;
  $77 = HEAP32[$76>>2]|0;
  $78 = $13;
  $10 = $78;
  $79 = $10;
  $80 = HEAP32[$79>>2]|0;
  $81 = ($77|0)==($80|0);
  $82 = $81 ^ 1;
  if (!($82)) {
   break;
  }
  $16 = $38;
  $83 = $16;
  $84 = HEAP32[$83>>2]|0;
  $85 = HEAP32[$84>>2]|0;
  $86 = $34;
  $87 = HEAP32[$86>>2]|0;
  $88 = ($85|0)==($87|0);
  if ($88) {
   continue;
  }
  $17 = $38;
  $89 = $17;
  $90 = HEAP32[$89>>2]|0;
  $18 = $90;
  $91 = $18;
  $92 = HEAP32[$91>>2]|0;
  $19 = $0;
  $93 = $19;
  $94 = HEAP32[$93>>2]|0;
  HEAP32[$94>>2] = $92;
  $20 = $0;
  $95 = $20;
  $96 = HEAP32[$95>>2]|0;
  $97 = ((($96)) + 4|0);
  HEAP32[$95>>2] = $97;
 }
 ;HEAP32[$33>>2]=HEAP32[$0>>2]|0;
 $98 = HEAP32[$33>>2]|0;
 STACKTOP = sp;return ($98|0);
}
function __ZNSt3__26vectorIiNS_9allocatorIiEEE5eraseENS_11__wrap_iterIPKiEES7_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0;
 var $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0;
 var $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0;
 var $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0;
 var $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0;
 var $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 336|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(336|0);
 $31 = sp;
 $34 = sp + 328|0;
 $72 = sp + 56|0;
 $77 = sp + 36|0;
 $80 = sp + 24|0;
 $82 = sp + 16|0;
 $85 = sp + 4|0;
 $83 = $0;
 $86 = $83;
 $87 = HEAP32[$86>>2]|0;
 $81 = $86;
 $88 = $81;
 $89 = HEAP32[$88>>2]|0;
 $78 = $88;
 $79 = $89;
 $90 = $79;
 $75 = $77;
 $76 = $90;
 $91 = $75;
 $92 = $76;
 HEAP32[$91>>2] = $92;
 $93 = HEAP32[$77>>2]|0;
 HEAP32[$80>>2] = $93;
 $94 = HEAP32[$80>>2]|0;
 HEAP32[$85>>2] = $94;
 $5 = $1;
 $6 = $85;
 $95 = $5;
 $4 = $95;
 $96 = $4;
 $97 = HEAP32[$96>>2]|0;
 $98 = $6;
 $3 = $98;
 $99 = $3;
 $100 = HEAP32[$99>>2]|0;
 $101 = $97;
 $102 = $100;
 $103 = (($101) - ($102))|0;
 $104 = (($103|0) / 4)&-1;
 $105 = (($87) + ($104<<2)|0);
 $84 = $105;
 $11 = $1;
 $12 = $2;
 $106 = $11;
 $107 = $12;
 $9 = $106;
 $10 = $107;
 $108 = $9;
 $8 = $108;
 $109 = $8;
 $110 = HEAP32[$109>>2]|0;
 $111 = $10;
 $7 = $111;
 $112 = $7;
 $113 = HEAP32[$112>>2]|0;
 $114 = ($110|0)==($113|0);
 $115 = $114 ^ 1;
 if (!($115)) {
  $220 = $84;
  $73 = $86;
  $74 = $220;
  $221 = $74;
  $70 = $72;
  $71 = $221;
  $222 = $70;
  $223 = $71;
  HEAP32[$222>>2] = $223;
  $224 = HEAP32[$72>>2]|0;
  HEAP32[$82>>2] = $224;
  $225 = HEAP32[$82>>2]|0;
  STACKTOP = sp;return ($225|0);
 }
 $116 = $84;
 $15 = $2;
 $16 = $1;
 $117 = $15;
 $14 = $117;
 $118 = $14;
 $119 = HEAP32[$118>>2]|0;
 $120 = $16;
 $13 = $120;
 $121 = $13;
 $122 = HEAP32[$121>>2]|0;
 $123 = $119;
 $124 = $122;
 $125 = (($123) - ($124))|0;
 $126 = (($125|0) / 4)&-1;
 $127 = (($116) + ($126<<2)|0);
 $128 = ((($86)) + 4|0);
 $129 = HEAP32[$128>>2]|0;
 $130 = $84;
 $24 = $127;
 $25 = $129;
 $26 = $130;
 $131 = $24;
 $23 = $131;
 $132 = $23;
 $133 = $25;
 $17 = $133;
 $134 = $17;
 $135 = $26;
 $18 = $135;
 $136 = $18;
 $19 = $132;
 $20 = $134;
 $21 = $136;
 $137 = $20;
 $138 = $19;
 $139 = $137;
 $140 = $138;
 $141 = (($139) - ($140))|0;
 $142 = (($141|0) / 4)&-1;
 $22 = $142;
 $143 = $22;
 $144 = ($143>>>0)>(0);
 if ($144) {
  $145 = $21;
  $146 = $19;
  $147 = $22;
  $148 = $147<<2;
  _memmove(($145|0),($146|0),($148|0))|0;
 }
 $149 = $21;
 $150 = $22;
 $151 = (($149) + ($150<<2)|0);
 $65 = $86;
 $66 = $151;
 $152 = $65;
 $153 = $66;
 $63 = $152;
 $64 = $153;
 $62 = $152;
 $154 = $62;
 $155 = ((($154)) + 4|0);
 $156 = HEAP32[$155>>2]|0;
 $157 = HEAP32[$154>>2]|0;
 $158 = $156;
 $159 = $157;
 $160 = (($158) - ($159))|0;
 $161 = (($160|0) / 4)&-1;
 $67 = $161;
 $162 = $66;
 $39 = $152;
 $40 = $162;
 $163 = $39;
 while(1) {
  $164 = $40;
  $165 = ((($163)) + 4|0);
  $166 = HEAP32[$165>>2]|0;
  $167 = ($164|0)!=($166|0);
  if (!($167)) {
   break;
  }
  $38 = $163;
  $168 = $38;
  $169 = ((($168)) + 8|0);
  $37 = $169;
  $170 = $37;
  $36 = $170;
  $171 = $36;
  $172 = ((($163)) + 4|0);
  $173 = HEAP32[$172>>2]|0;
  $174 = ((($173)) + -4|0);
  HEAP32[$172>>2] = $174;
  $35 = $174;
  $175 = $35;
  $32 = $171;
  $33 = $175;
  $176 = $32;
  $177 = $33;
  ;HEAP8[$31>>0]=HEAP8[$34>>0]|0;
  $29 = $176;
  $30 = $177;
  $178 = $29;
  $179 = $30;
  $27 = $178;
  $28 = $179;
 }
 $180 = $67;
 $60 = $152;
 $61 = $180;
 $181 = $60;
 $59 = $181;
 $182 = $59;
 $183 = HEAP32[$182>>2]|0;
 $58 = $183;
 $184 = $58;
 $42 = $181;
 $185 = $42;
 $186 = HEAP32[$185>>2]|0;
 $41 = $186;
 $187 = $41;
 $47 = $181;
 $188 = $47;
 $46 = $188;
 $189 = $46;
 $45 = $189;
 $190 = $45;
 $191 = ((($190)) + 8|0);
 $44 = $191;
 $192 = $44;
 $43 = $192;
 $193 = $43;
 $194 = HEAP32[$193>>2]|0;
 $195 = HEAP32[$189>>2]|0;
 $196 = $194;
 $197 = $195;
 $198 = (($196) - ($197))|0;
 $199 = (($198|0) / 4)&-1;
 $200 = (($187) + ($199<<2)|0);
 $49 = $181;
 $201 = $49;
 $202 = HEAP32[$201>>2]|0;
 $48 = $202;
 $203 = $48;
 $204 = $61;
 $205 = (($203) + ($204<<2)|0);
 $51 = $181;
 $206 = $51;
 $207 = HEAP32[$206>>2]|0;
 $50 = $207;
 $208 = $50;
 $52 = $181;
 $209 = $52;
 $210 = ((($209)) + 4|0);
 $211 = HEAP32[$210>>2]|0;
 $212 = HEAP32[$209>>2]|0;
 $213 = $211;
 $214 = $212;
 $215 = (($213) - ($214))|0;
 $216 = (($215|0) / 4)&-1;
 $217 = (($208) + ($216<<2)|0);
 $53 = $181;
 $54 = $184;
 $55 = $200;
 $56 = $205;
 $57 = $217;
 $218 = $84;
 $219 = ((($218)) + -4|0);
 $68 = $86;
 $69 = $219;
 $220 = $84;
 $73 = $86;
 $74 = $220;
 $221 = $74;
 $70 = $72;
 $71 = $221;
 $222 = $70;
 $223 = $71;
 HEAP32[$222>>2] = $223;
 $224 = HEAP32[$72>>2]|0;
 HEAP32[$82>>2] = $224;
 $225 = HEAP32[$82>>2]|0;
 STACKTOP = sp;return ($225|0);
}
function __ZN4mjin11application6memory4Game10selectNodeEib($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $11 = sp;
 $5 = $0;
 $6 = $1;
 $12 = $2&1;
 $7 = $12;
 $13 = $5;
 $14 = (__ZNK3osg7ref_ptrINS_5GroupEEptEv($13)|0);
 $15 = $6;
 $16 = (__ZN3osg5Group8getChildEj($14,$15)|0);
 $8 = $16;
 $9 = 0;
 $17 = $7;
 $18 = $17&1;
 if ($18) {
  $19 = ((($13)) + 4|0);
  $20 = $6;
  $3 = $19;
  $4 = $20;
  $21 = $3;
  $22 = HEAP32[$21>>2]|0;
  $23 = $4;
  $24 = (($22) + (($23*12)|0)|0);
  $25 = ((($24)) + 8|0);
  $26 = HEAP32[$25>>2]|0;
  $10 = $26;
  $27 = ((($13)) + 72|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = $8;
  $30 = $10;
  $31 = (($30) + 4)|0;
  __ZN4mjin11application6memory8material11typeIdToRGBEi($11,$31);
  $32 = (__ZN4mjin11application6memory8material4Pool17referenceMaterialEPvRKNS2_3RGBE($28,$29,$11)|0);
  $9 = $32;
  $36 = $8;
  $37 = $9;
  __ZN3osg4Node11setStateSetEPNS_8StateSetE($36,$37);
  STACKTOP = sp;return;
 } else {
  $33 = ((($13)) + 72|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = $8;
  __ZN4mjin11application6memory8material4Pool15releaseMaterialEPv($34,$35);
  $36 = $8;
  $37 = $9;
  __ZN3osg4Node11setStateSetEPNS_8StateSetE($36,$37);
  STACKTOP = sp;return;
 }
}
function __ZNSt3__26vectorIiNS_9allocatorIiEEE21__push_back_slow_pathIRKiEEvOT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0;
 var $136 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 208|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(208|0);
 $10 = sp + 8|0;
 $15 = sp + 201|0;
 $24 = sp;
 $27 = sp + 200|0;
 $35 = sp + 80|0;
 $38 = sp + 68|0;
 $46 = sp + 20|0;
 $43 = $0;
 $44 = $1;
 $49 = $43;
 $42 = $49;
 $50 = $42;
 $51 = ((($50)) + 8|0);
 $41 = $51;
 $52 = $41;
 $40 = $52;
 $53 = $40;
 $45 = $53;
 $39 = $49;
 $54 = $39;
 $55 = ((($54)) + 4|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = HEAP32[$54>>2]|0;
 $58 = $56;
 $59 = $57;
 $60 = (($58) - ($59))|0;
 $61 = (($60|0) / 4)&-1;
 $62 = (($61) + 1)|0;
 $34 = $49;
 HEAP32[$35>>2] = $62;
 $63 = $34;
 $64 = (__ZNKSt3__26vectorIiNS_9allocatorIiEEE8max_sizeEv($63)|0);
 $36 = $64;
 $65 = HEAP32[$35>>2]|0;
 $66 = $36;
 $67 = ($65>>>0)>($66>>>0);
 if ($67) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($63);
  // unreachable;
 }
 $32 = $63;
 $68 = $32;
 $31 = $68;
 $69 = $31;
 $30 = $69;
 $70 = $30;
 $71 = ((($70)) + 8|0);
 $29 = $71;
 $72 = $29;
 $28 = $72;
 $73 = $28;
 $74 = HEAP32[$73>>2]|0;
 $75 = HEAP32[$69>>2]|0;
 $76 = $74;
 $77 = $75;
 $78 = (($76) - ($77))|0;
 $79 = (($78|0) / 4)&-1;
 $37 = $79;
 $80 = $37;
 $81 = $36;
 $82 = (($81>>>0) / 2)&-1;
 $83 = ($80>>>0)>=($82>>>0);
 if ($83) {
  $84 = $36;
  $33 = $84;
 } else {
  $85 = $37;
  $86 = $85<<1;
  HEAP32[$38>>2] = $86;
  $25 = $38;
  $26 = $35;
  $87 = $25;
  $88 = $26;
  ;HEAP8[$24>>0]=HEAP8[$27>>0]|0;
  $22 = $87;
  $23 = $88;
  $89 = $22;
  $90 = $23;
  $19 = $24;
  $20 = $89;
  $21 = $90;
  $91 = $20;
  $92 = HEAP32[$91>>2]|0;
  $93 = $21;
  $94 = HEAP32[$93>>2]|0;
  $95 = ($92>>>0)<($94>>>0);
  $96 = $23;
  $97 = $22;
  $98 = $95 ? $96 : $97;
  $99 = HEAP32[$98>>2]|0;
  $33 = $99;
 }
 $100 = $33;
 $18 = $49;
 $101 = $18;
 $102 = ((($101)) + 4|0);
 $103 = HEAP32[$102>>2]|0;
 $104 = HEAP32[$101>>2]|0;
 $105 = $103;
 $106 = $104;
 $107 = (($105) - ($106))|0;
 $108 = (($107|0) / 4)&-1;
 $109 = $45;
 __ZNSt3__214__split_bufferIiRNS_9allocatorIiEEEC2EjjS3_($46,$100,$108,$109);
 $110 = $45;
 $111 = ((($46)) + 8|0);
 $112 = HEAP32[$111>>2]|0;
 $17 = $112;
 $113 = $17;
 $114 = $44;
 $16 = $114;
 $115 = $16;
 $12 = $110;
 $13 = $113;
 $14 = $115;
 $116 = $12;
 $117 = $13;
 $118 = $14;
 $11 = $118;
 $119 = $11;
 ;HEAP8[$10>>0]=HEAP8[$15>>0]|0;
 $7 = $116;
 $8 = $117;
 $9 = $119;
 $120 = $7;
 $121 = $8;
 $122 = $9;
 $6 = $122;
 $123 = $6;
 $3 = $120;
 $4 = $121;
 $5 = $123;
 $124 = $4;
 $125 = $5;
 $2 = $125;
 $126 = $2;
 $127 = HEAP32[$126>>2]|0;
 HEAP32[$124>>2] = $127;
 $128 = ((($46)) + 8|0);
 $129 = HEAP32[$128>>2]|0;
 $130 = ((($129)) + 4|0);
 HEAP32[$128>>2] = $130;
 __THREW__ = 0;
 invoke_vii(4068,($49|0),($46|0));
 $131 = __THREW__; __THREW__ = 0;
 $132 = $131&1;
 if ($132) {
  $133 = ___cxa_find_matching_catch_2()|0;
  $134 = tempRet0;
  $47 = $133;
  $48 = $134;
  __ZNSt3__214__split_bufferIiRNS_9allocatorIiEEED2Ev($46);
  $135 = $47;
  $136 = $48;
  ___resumeException($135|0);
  // unreachable;
 } else {
  __ZNSt3__214__split_bufferIiRNS_9allocatorIiEEED2Ev($46);
  STACKTOP = sp;return;
 }
}
function __ZN4mjin11application6memory4Game18matchSelectedItemsEv($0) {
 $0 = $0|0;
 var $$byval_copy = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 240|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(240|0);
 $$byval_copy = sp + 232|0;
 $12 = sp + 64|0;
 $15 = sp + 236|0;
 $17 = sp + 56|0;
 $18 = sp + 48|0;
 $21 = sp + 164|0;
 $24 = sp + 152|0;
 $28 = sp + 136|0;
 $31 = sp + 124|0;
 $35 = sp + 108|0;
 $36 = sp + 104|0;
 $39 = sp + 24|0;
 $40 = sp + 80|0;
 $43 = sp;
 $44 = sp + 68|0;
 $33 = $0;
 $45 = $33;
 $46 = ((($45)) + 16|0);
 $34 = $46;
 $47 = $34;
 $32 = $47;
 $48 = $32;
 $49 = HEAP32[$48>>2]|0;
 $29 = $48;
 $30 = $49;
 $50 = $30;
 $26 = $28;
 $27 = $50;
 $51 = $26;
 $52 = $27;
 HEAP32[$51>>2] = $52;
 $53 = HEAP32[$28>>2]|0;
 HEAP32[$31>>2] = $53;
 $54 = HEAP32[$31>>2]|0;
 HEAP32[$35>>2] = $54;
 $55 = $34;
 $25 = $55;
 $56 = $25;
 $57 = ((($56)) + 4|0);
 $58 = HEAP32[$57>>2]|0;
 $22 = $56;
 $23 = $58;
 $59 = $23;
 $19 = $21;
 $20 = $59;
 $60 = $19;
 $61 = $20;
 HEAP32[$60>>2] = $61;
 $62 = HEAP32[$21>>2]|0;
 HEAP32[$24>>2] = $62;
 $63 = HEAP32[$24>>2]|0;
 HEAP32[$36>>2] = $63;
 ;HEAP8[$17>>0]=HEAP8[$36>>0]|0;HEAP8[$17+1>>0]=HEAP8[$36+1>>0]|0;HEAP8[$17+2>>0]=HEAP8[$36+2>>0]|0;HEAP8[$17+3>>0]=HEAP8[$36+3>>0]|0;
 ;HEAP8[$18>>0]=HEAP8[$35>>0]|0;HEAP8[$18+1>>0]=HEAP8[$35+1>>0]|0;HEAP8[$18+2>>0]=HEAP8[$35+2>>0]|0;HEAP8[$18+3>>0]=HEAP8[$35+3>>0]|0;
 $16 = $18;
 $64 = $16;
 $65 = HEAP32[$64>>2]|0;
 $9 = $17;
 $66 = $9;
 $67 = HEAP32[$66>>2]|0;
 $13 = $65;
 $14 = $67;
 $68 = $13;
 $69 = $14;
 ;HEAP8[$12>>0]=HEAP8[$15>>0]|0;
 $10 = $68;
 $11 = $69;
 $70 = $10;
 $71 = $11;
 __ZNSt3__26__sortIRNS_6__lessIiiEEPiEEvT0_S5_T_($70,$71,$12);
 $72 = ((($45)) + 4|0);
 $73 = $34;
 $7 = $73;
 $8 = 0;
 $74 = $7;
 $75 = HEAP32[$74>>2]|0;
 $76 = $8;
 $77 = (($75) + ($76<<2)|0);
 $78 = HEAP32[$77>>2]|0;
 $5 = $72;
 $6 = $78;
 $79 = $5;
 $80 = HEAP32[$79>>2]|0;
 $81 = $6;
 $82 = (($80) + (($81*12)|0)|0);
 $37 = $82;
 $83 = ((($45)) + 4|0);
 $84 = $34;
 $3 = $84;
 $4 = 1;
 $85 = $3;
 $86 = HEAP32[$85>>2]|0;
 $87 = $4;
 $88 = (($86) + ($87<<2)|0);
 $89 = HEAP32[$88>>2]|0;
 $1 = $83;
 $2 = $89;
 $90 = $1;
 $91 = HEAP32[$90>>2]|0;
 $92 = $2;
 $93 = (($91) + (($92*12)|0)|0);
 $38 = $93;
 $94 = $37;
 $95 = ((($94)) + 8|0);
 $96 = HEAP32[$95>>2]|0;
 $97 = $38;
 $98 = ((($97)) + 8|0);
 $99 = HEAP32[$98>>2]|0;
 $100 = ($96|0)==($99|0);
 if (!($100)) {
  HEAP32[$44>>2] = $45;
  ;HEAP32[$$byval_copy>>2]=HEAP32[$44>>2]|0;
  __ZNSt3__28functionIFvvEEC2IZN4mjin11application6memory4Game18matchSelectedItemsEvE3__1vEET_($43,$$byval_copy);
  __THREW__ = 0;
  invoke_viii(4070,($45|0),0,($43|0));
  $111 = __THREW__; __THREW__ = 0;
  $112 = $111&1;
  if ($112) {
   $113 = ___cxa_find_matching_catch_2()|0;
   $114 = tempRet0;
   $41 = $113;
   $42 = $114;
   __ZNSt3__28functionIFvvEED2Ev($43);
   $115 = $41;
   $116 = $42;
   ___resumeException($115|0);
   // unreachable;
  } else {
   __ZNSt3__28functionIFvvEED2Ev($43);
   STACKTOP = sp;return;
  }
 }
 HEAP32[$40>>2] = $45;
 $101 = ((($40)) + 4|0);
 $102 = $34;
 __ZNSt3__26vectorIiNS_9allocatorIiEEEC2ERKS3_($101,$102);
 __THREW__ = 0;
 invoke_vii(4069,($39|0),($40|0));
 $103 = __THREW__; __THREW__ = 0;
 $104 = $103&1;
 do {
  if ($104) {
   $107 = ___cxa_find_matching_catch_2()|0;
   $108 = tempRet0;
   $41 = $107;
   $42 = $108;
  } else {
   __THREW__ = 0;
   invoke_viii(4070,($45|0),1,($39|0));
   $105 = __THREW__; __THREW__ = 0;
   $106 = $105&1;
   if ($106) {
    $109 = ___cxa_find_matching_catch_2()|0;
    $110 = tempRet0;
    $41 = $109;
    $42 = $110;
    __ZNSt3__28functionIFvvEED2Ev($39);
    break;
   }
   __ZNSt3__28functionIFvvEED2Ev($39);
   __ZZN4mjin11application6memory4Game18matchSelectedItemsEvEN3__0D2Ev($40);
   STACKTOP = sp;return;
  }
 } while(0);
 __ZZN4mjin11application6memory4Game18matchSelectedItemsEvEN3__0D2Ev($40);
 $115 = $41;
 $116 = $42;
 ___resumeException($115|0);
 // unreachable;
}
function __ZNSt3__28functionIFvvEEC2IZN4mjin11application6memory4Game18matchSelectedItemsEvE3__0vEET_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0;
 var $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0;
 var $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0;
 var $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0;
 var $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0;
 var $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0;
 var $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0;
 var $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 608|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(608|0);
 $8 = sp + 136|0;
 $9 = sp + 128|0;
 $10 = sp + 120|0;
 $11 = sp + 112|0;
 $15 = sp + 605|0;
 $16 = sp + 604|0;
 $17 = sp + 603|0;
 $18 = sp + 602|0;
 $20 = sp + 548|0;
 $29 = sp + 104|0;
 $30 = sp + 96|0;
 $31 = sp + 88|0;
 $32 = sp + 80|0;
 $36 = sp + 601|0;
 $37 = sp + 600|0;
 $38 = sp + 599|0;
 $39 = sp + 598|0;
 $41 = sp + 496|0;
 $52 = sp + 72|0;
 $53 = sp + 64|0;
 $54 = sp + 56|0;
 $55 = sp + 48|0;
 $56 = sp + 40|0;
 $59 = sp + 597|0;
 $60 = sp + 444|0;
 $61 = sp + 440|0;
 $62 = sp + 596|0;
 $63 = sp + 595|0;
 $64 = sp + 32|0;
 $65 = sp + 24|0;
 $66 = sp + 16|0;
 $71 = sp + 594|0;
 $72 = sp + 420|0;
 $73 = sp + 416|0;
 $90 = sp + 348|0;
 $91 = sp + 8|0;
 $94 = sp + 336|0;
 $95 = sp + 328|0;
 $96 = sp;
 $101 = sp + 304|0;
 $137 = sp + 593|0;
 $138 = sp + 152|0;
 $139 = sp + 144|0;
 $140 = sp + 592|0;
 $136 = $0;
 $141 = $136;
 $142 = ((($141)) + 16|0);
 HEAP32[$142>>2] = 0;
 $135 = $1;
 $134 = $137;
 $112 = $137;
 $113 = 1;
 $114 = 0;
 $143 = $112;
 $144 = $113;
 $111 = $143;
 $145 = ($144>>>0)>(214748364);
 if ($145) {
  $107 = 204840;
  $146 = (___cxa_allocate_exception(8)|0);
  $147 = $107;
  $105 = $146;
  $106 = $147;
  $148 = $105;
  $149 = $106;
  __THREW__ = 0;
  invoke_vii(3366,($148|0),($149|0));
  $150 = __THREW__; __THREW__ = 0;
  $151 = $150&1;
  if ($151) {
   $152 = ___cxa_find_matching_catch_2()|0;
   $153 = tempRet0;
   $108 = $152;
   $109 = $153;
   ___cxa_free_exception(($146|0));
   $154 = $108;
   $155 = $109;
   ___resumeException($154|0);
   // unreachable;
  } else {
   HEAP32[$148>>2] = (99824);
   ___cxa_throw(($146|0),(34608|0),(3230|0));
   // unreachable;
  }
 }
 $156 = $113;
 $157 = ($156*20)|0;
 $110 = $157;
 $158 = $110;
 $159 = (__Znwj($158)|0);
 $102 = $139;
 $103 = $137;
 $104 = 1;
 $160 = $102;
 $161 = $103;
 HEAP32[$160>>2] = $161;
 $162 = ((($160)) + 4|0);
 $163 = $104;
 HEAP32[$162>>2] = $163;
 $98 = $138;
 $99 = $159;
 $100 = $139;
 $164 = $98;
 $165 = $99;
 $166 = $100;
 $97 = $166;
 $167 = $97;
 ;HEAP32[$101>>2]=HEAP32[$167>>2]|0;HEAP32[$101+4>>2]=HEAP32[$167+4>>2]|0;
 ;HEAP8[$96>>0]=HEAP8[$101>>0]|0;HEAP8[$96+1>>0]=HEAP8[$101+1>>0]|0;HEAP8[$96+2>>0]=HEAP8[$101+2>>0]|0;HEAP8[$96+3>>0]=HEAP8[$101+3>>0]|0;HEAP8[$96+4>>0]=HEAP8[$101+4>>0]|0;HEAP8[$96+5>>0]=HEAP8[$101+5>>0]|0;HEAP8[$96+6>>0]=HEAP8[$101+6>>0]|0;HEAP8[$96+7>>0]=HEAP8[$101+7>>0]|0;
 $93 = $164;
 HEAP32[$94>>2] = $165;
 $168 = $93;
 $92 = $94;
 $169 = $92;
 $170 = HEAP32[$169>>2]|0;
 $86 = $96;
 $171 = $86;
 ;HEAP32[$95>>2]=HEAP32[$171>>2]|0;HEAP32[$95+4>>2]=HEAP32[$171+4>>2]|0;
 ;HEAP8[$91>>0]=HEAP8[$95>>0]|0;HEAP8[$91+1>>0]=HEAP8[$95+1>>0]|0;HEAP8[$91+2>>0]=HEAP8[$95+2>>0]|0;HEAP8[$91+3>>0]=HEAP8[$95+3>>0]|0;HEAP8[$91+4>>0]=HEAP8[$95+4>>0]|0;HEAP8[$91+5>>0]=HEAP8[$95+5>>0]|0;HEAP8[$91+6>>0]=HEAP8[$95+6>>0]|0;HEAP8[$91+7>>0]=HEAP8[$95+7>>0]|0;
 $89 = $168;
 HEAP32[$90>>2] = $170;
 $172 = $89;
 $88 = $90;
 $173 = $88;
 $174 = HEAP32[$173>>2]|0;
 HEAP32[$172>>2] = $174;
 $175 = ((($172)) + 4|0);
 $87 = $91;
 $176 = $87;
 ;HEAP32[$175>>2]=HEAP32[$176>>2]|0;HEAP32[$175+4>>2]=HEAP32[$176+4>>2]|0;
 $85 = $138;
 $177 = $85;
 $84 = $177;
 $178 = $84;
 $83 = $178;
 $179 = $83;
 $180 = HEAP32[$179>>2]|0;
 $82 = $1;
 $181 = $82;
 $80 = $140;
 $81 = $137;
 $68 = $180;
 $69 = $181;
 $70 = $140;
 $182 = $68;
 $67 = $182;
 $183 = $67;
 HEAP32[$183>>2] = (71384);
 HEAP32[$182>>2] = (71560);
 $184 = ((($182)) + 4|0);
 $185 = $69;
 $43 = $185;
 $186 = $43;
 $21 = $186;
 $187 = $21;
 $19 = $187;
 $188 = $19;
 $13 = $20;
 $14 = $188;
 $189 = $13;
 $190 = $14;
 $12 = $190;
 $191 = $12;
 ;HEAP8[$8>>0]=HEAP8[$18>>0]|0;
 ;HEAP8[$9>>0]=HEAP8[$17>>0]|0;
 ;HEAP8[$10>>0]=HEAP8[$16>>0]|0;
 ;HEAP8[$11>>0]=HEAP8[$15>>0]|0;
 $6 = $189;
 $7 = $191;
 $192 = $6;
 $193 = $7;
 $5 = $193;
 $194 = $5;
 $3 = $192;
 $4 = $194;
 $195 = $3;
 $196 = $4;
 $2 = $196;
 $197 = $2;
 HEAP32[$195>>2] = $197;
 $198 = HEAP32[$20>>2]|0;
 HEAP32[$72>>2] = $198;
 $199 = $70;
 $22 = $199;
 $200 = $22;
 $42 = $200;
 $201 = $42;
 $40 = $201;
 $202 = $40;
 $34 = $41;
 $35 = $202;
 $203 = $34;
 $204 = $35;
 $33 = $204;
 $205 = $33;
 ;HEAP8[$29>>0]=HEAP8[$39>>0]|0;
 ;HEAP8[$30>>0]=HEAP8[$38>>0]|0;
 ;HEAP8[$31>>0]=HEAP8[$37>>0]|0;
 ;HEAP8[$32>>0]=HEAP8[$36>>0]|0;
 $27 = $203;
 $28 = $205;
 $206 = $27;
 $207 = $28;
 $26 = $207;
 $208 = $26;
 $24 = $206;
 $25 = $208;
 $209 = $24;
 $210 = $25;
 $23 = $210;
 $211 = $23;
 HEAP32[$209>>2] = $211;
 $212 = HEAP32[$41>>2]|0;
 HEAP32[$73>>2] = $212;
 ;HEAP8[$64>>0]=HEAP8[$73>>0]|0;HEAP8[$64+1>>0]=HEAP8[$73+1>>0]|0;HEAP8[$64+2>>0]=HEAP8[$73+2>>0]|0;HEAP8[$64+3>>0]=HEAP8[$73+3>>0]|0;
 ;HEAP8[$65>>0]=HEAP8[$72>>0]|0;HEAP8[$65+1>>0]=HEAP8[$72+1>>0]|0;HEAP8[$65+2>>0]=HEAP8[$72+2>>0]|0;HEAP8[$65+3>>0]=HEAP8[$72+3>>0]|0;
 ;HEAP8[$66>>0]=HEAP8[$71>>0]|0;
 $58 = $184;
 $213 = $58;
 $57 = $65;
 $214 = $57;
 ;HEAP32[$60>>2]=HEAP32[$214>>2]|0;
 $44 = $64;
 $215 = $44;
 ;HEAP32[$61>>2]=HEAP32[$215>>2]|0;
 ;HEAP8[$52>>0]=HEAP8[$63>>0]|0;
 ;HEAP8[$53>>0]=HEAP8[$62>>0]|0;
 ;HEAP8[$54>>0]=HEAP8[$61>>0]|0;HEAP8[$54+1>>0]=HEAP8[$61+1>>0]|0;HEAP8[$54+2>>0]=HEAP8[$61+2>>0]|0;HEAP8[$54+3>>0]=HEAP8[$61+3>>0]|0;
 ;HEAP8[$55>>0]=HEAP8[$60>>0]|0;HEAP8[$55+1>>0]=HEAP8[$60+1>>0]|0;HEAP8[$55+2>>0]=HEAP8[$60+2>>0]|0;HEAP8[$55+3>>0]=HEAP8[$60+3>>0]|0;
 ;HEAP8[$56>>0]=HEAP8[$59>>0]|0;
 $51 = $213;
 $216 = $51;
 $50 = $54;
 $217 = $50;
 $49 = $217;
 $218 = $49;
 $219 = HEAP32[$218>>2]|0;
 $48 = $219;
 $46 = $55;
 $220 = $46;
 $45 = $220;
 $221 = $45;
 $222 = HEAP32[$221>>2]|0;
 $47 = $222;
 $223 = $47;
 __ZZN4mjin11application6memory4Game18matchSelectedItemsEvEN3__0C2EOS3_($216,$223);
 $78 = $138;
 $224 = $78;
 $77 = $224;
 $225 = $77;
 $76 = $225;
 $226 = $76;
 $227 = HEAP32[$226>>2]|0;
 $79 = $227;
 $75 = $224;
 $228 = $75;
 $74 = $228;
 $229 = $74;
 HEAP32[$229>>2] = 0;
 $230 = $79;
 $231 = ((($141)) + 16|0);
 HEAP32[$231>>2] = $230;
 $133 = $138;
 $232 = $133;
 $130 = $232;
 $131 = 0;
 $233 = $130;
 $129 = $233;
 $234 = $129;
 $128 = $234;
 $235 = $128;
 $236 = HEAP32[$235>>2]|0;
 $132 = $236;
 $237 = $131;
 $118 = $233;
 $238 = $118;
 $117 = $238;
 $239 = $117;
 HEAP32[$239>>2] = $237;
 $240 = $132;
 $241 = ($240|0)!=(0|0);
 if (!($241)) {
  STACKTOP = sp;return;
 }
 $116 = $233;
 $242 = $116;
 $115 = $242;
 $243 = $115;
 $244 = ((($243)) + 4|0);
 $245 = $132;
 $126 = $244;
 $127 = $245;
 $246 = $126;
 $247 = HEAP32[$246>>2]|0;
 $248 = $127;
 $249 = ((($246)) + 4|0);
 $250 = HEAP32[$249>>2]|0;
 $123 = $247;
 $124 = $248;
 $125 = $250;
 $251 = $123;
 $252 = $124;
 $253 = $125;
 $120 = $251;
 $121 = $252;
 $122 = $253;
 $254 = $121;
 $119 = $254;
 $255 = $119;
 __ZdlPv($255);
 STACKTOP = sp;return;
}
function __ZN4mjin11application6memory4Game18animateMatchOrMissEbNSt3__28functionIFvvEEE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $5 = sp;
 $3 = $0;
 $8 = $1&1;
 $4 = $8;
 $9 = $3;
 $10 = ((($9)) + 56|0);
 __ZN3osg5Timer12setStartTickEv($10);
 $11 = $4;
 $12 = $11&1;
 $13 = $12&1;
 HEAP8[$5>>0] = $13;
 $14 = ((($5)) + 4|0);
 HEAP32[$14>>2] = $9;
 $15 = ((($5)) + 8|0);
 __ZNSt3__28functionIFvvEEC2ERKS2_($15,$2);
 $16 = ((($9)) + 32|0);
 __THREW__ = 0;
 (invoke_iii(4071,($16|0),($5|0))|0);
 $17 = __THREW__; __THREW__ = 0;
 $18 = $17&1;
 if ($18) {
  $19 = ___cxa_find_matching_catch_2()|0;
  $20 = tempRet0;
  $6 = $19;
  $7 = $20;
  __ZZN4mjin11application6memory4Game18animateMatchOrMissEbNSt3__28functionIFvvEEEEN3__2D2Ev($5);
  $21 = $6;
  $22 = $7;
  ___resumeException($21|0);
  // unreachable;
 } else {
  __ZZN4mjin11application6memory4Game18animateMatchOrMissEbNSt3__28functionIFvvEEEEN3__2D2Ev($5);
  STACKTOP = sp;return;
 }
}
function __ZNSt3__28functionIFvvEED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 $3 = ((($2)) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==($2|0);
 $6 = ((($2)) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 if ($5) {
  $8 = HEAP32[$7>>2]|0;
  $9 = ((($8)) + 16|0);
  $10 = HEAP32[$9>>2]|0;
  FUNCTION_TABLE_vi[$10 & 8191]($7);
  STACKTOP = sp;return;
 }
 $11 = ($7|0)!=(0|0);
 if (!($11)) {
  STACKTOP = sp;return;
 }
 $12 = ((($2)) + 16|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = HEAP32[$13>>2]|0;
 $15 = ((($14)) + 20|0);
 $16 = HEAP32[$15>>2]|0;
 FUNCTION_TABLE_vi[$16 & 8191]($13);
 STACKTOP = sp;return;
}
function __ZZN4mjin11application6memory4Game18matchSelectedItemsEvEN3__0D2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 $3 = ((($2)) + 4|0);
 __ZNSt3__26vectorIiNS_9allocatorIiEEED2Ev($3);
 STACKTOP = sp;return;
}
function __ZNSt3__28functionIFvvEEC2IZN4mjin11application6memory4Game18matchSelectedItemsEvE3__1vEET_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(224|0);
 $10 = sp + 88|0;
 $11 = sp + 80|0;
 $12 = sp + 72|0;
 $13 = sp + 64|0;
 $17 = sp + 222|0;
 $18 = sp + 221|0;
 $19 = sp + 220|0;
 $20 = sp + 219|0;
 $22 = sp + 160|0;
 $25 = sp + 218|0;
 $32 = sp + 56|0;
 $33 = sp + 48|0;
 $34 = sp + 40|0;
 $35 = sp + 32|0;
 $36 = sp + 24|0;
 $39 = sp + 217|0;
 $40 = sp + 116|0;
 $41 = sp + 216|0;
 $42 = sp + 215|0;
 $43 = sp + 214|0;
 $44 = sp + 16|0;
 $45 = sp + 8|0;
 $46 = sp;
 $50 = sp + 213|0;
 $51 = sp + 100|0;
 $52 = sp + 212|0;
 $54 = $0;
 $55 = $54;
 $56 = ((($55)) + 16|0);
 HEAP32[$56>>2] = 0;
 $53 = $1;
 $2 = $1;
 $57 = $2;
 $48 = $55;
 $49 = $57;
 $58 = $48;
 $47 = $58;
 $59 = $47;
 HEAP32[$59>>2] = (71384);
 HEAP32[$58>>2] = (71428);
 $60 = ((($58)) + 4|0);
 $61 = $49;
 $3 = $61;
 $62 = $3;
 $23 = $62;
 $63 = $23;
 $21 = $63;
 $64 = $21;
 $15 = $22;
 $16 = $64;
 $65 = $15;
 $66 = $16;
 $14 = $66;
 $67 = $14;
 ;HEAP8[$10>>0]=HEAP8[$20>>0]|0;
 ;HEAP8[$11>>0]=HEAP8[$19>>0]|0;
 ;HEAP8[$12>>0]=HEAP8[$18>>0]|0;
 ;HEAP8[$13>>0]=HEAP8[$17>>0]|0;
 $8 = $65;
 $9 = $67;
 $68 = $8;
 $69 = $9;
 $7 = $69;
 $70 = $7;
 $5 = $68;
 $6 = $70;
 $71 = $5;
 $72 = $6;
 $4 = $72;
 $73 = $4;
 HEAP32[$71>>2] = $73;
 $74 = HEAP32[$22>>2]|0;
 HEAP32[$51>>2] = $74;
 $24 = $25;
 ;HEAP8[$44>>0]=HEAP8[$52>>0]|0;
 ;HEAP8[$45>>0]=HEAP8[$51>>0]|0;HEAP8[$45+1>>0]=HEAP8[$51+1>>0]|0;HEAP8[$45+2>>0]=HEAP8[$51+2>>0]|0;HEAP8[$45+3>>0]=HEAP8[$51+3>>0]|0;
 ;HEAP8[$46>>0]=HEAP8[$50>>0]|0;
 $38 = $60;
 $75 = $38;
 $37 = $45;
 $76 = $37;
 ;HEAP32[$40>>2]=HEAP32[$76>>2]|0;
 $26 = $44;
 ;HEAP8[$32>>0]=HEAP8[$43>>0]|0;
 ;HEAP8[$33>>0]=HEAP8[$42>>0]|0;
 ;HEAP8[$34>>0]=HEAP8[$41>>0]|0;
 ;HEAP8[$35>>0]=HEAP8[$40>>0]|0;HEAP8[$35+1>>0]=HEAP8[$40+1>>0]|0;HEAP8[$35+2>>0]=HEAP8[$40+2>>0]|0;HEAP8[$35+3>>0]=HEAP8[$40+3>>0]|0;
 ;HEAP8[$36>>0]=HEAP8[$39>>0]|0;
 $31 = $75;
 $77 = $31;
 $30 = $77;
 $28 = $35;
 $78 = $28;
 $27 = $78;
 $79 = $27;
 $80 = HEAP32[$79>>2]|0;
 $29 = $80;
 $81 = $29;
 ;HEAP32[$77>>2]=HEAP32[$81>>2]|0;
 $82 = ((($55)) + 16|0);
 HEAP32[$82>>2] = $55;
 STACKTOP = sp;return;
}
function __ZNSt3__210__function6__funcIZN4mjin11application6memory4Game18matchSelectedItemsEvE3__1NS_9allocatorIS6_EEFvvEED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = $0;
 $3 = $2;
 $1 = $3;
 STACKTOP = sp;return;
}
function __ZNSt3__210__function6__funcIZN4mjin11application6memory4Game18matchSelectedItemsEvE3__1NS_9allocatorIS6_EEFvvEED0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 __ZNSt3__210__function6__funcIZN4mjin11application6memory4Game18matchSelectedItemsEvE3__1NS_9allocatorIS6_EEFvvEED2Ev($2);
 __ZdlPv($2);
 STACKTOP = sp;return;
}
function __ZNKSt3__210__function6__funcIZN4mjin11application6memory4Game18matchSelectedItemsEvE3__1NS_9allocatorIS6_EEFvvEE7__cloneEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0;
 var $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0;
 var $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0;
 var $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0;
 var $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0;
 var $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0;
 var $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0;
 var $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0;
 var $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 624|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(624|0);
 $7 = sp + 136|0;
 $8 = sp + 128|0;
 $9 = sp + 120|0;
 $10 = sp + 112|0;
 $13 = sp + 609|0;
 $14 = sp + 608|0;
 $15 = sp + 607|0;
 $16 = sp + 606|0;
 $18 = sp + 556|0;
 $27 = sp + 104|0;
 $28 = sp + 96|0;
 $29 = sp + 88|0;
 $30 = sp + 80|0;
 $34 = sp + 605|0;
 $35 = sp + 604|0;
 $36 = sp + 603|0;
 $37 = sp + 602|0;
 $39 = sp + 504|0;
 $49 = sp + 72|0;
 $50 = sp + 64|0;
 $51 = sp + 56|0;
 $52 = sp + 48|0;
 $53 = sp + 40|0;
 $56 = sp + 601|0;
 $57 = sp + 456|0;
 $58 = sp + 452|0;
 $59 = sp + 600|0;
 $60 = sp + 599|0;
 $61 = sp + 32|0;
 $62 = sp + 24|0;
 $63 = sp + 16|0;
 $68 = sp + 598|0;
 $69 = sp + 432|0;
 $70 = sp + 428|0;
 $88 = sp + 356|0;
 $89 = sp + 8|0;
 $92 = sp + 344|0;
 $93 = sp + 336|0;
 $94 = sp;
 $99 = sp + 312|0;
 $137 = sp + 597|0;
 $138 = sp + 152|0;
 $139 = sp + 144|0;
 $140 = sp + 596|0;
 $136 = $0;
 $141 = $136;
 $142 = ((($141)) + 4|0);
 $135 = $142;
 $143 = $135;
 $134 = $143;
 $144 = $134;
 $132 = $137;
 $133 = $144;
 $110 = $137;
 $111 = 1;
 $112 = 0;
 $145 = $110;
 $146 = $111;
 $109 = $145;
 $147 = ($146>>>0)>(536870911);
 if ($147) {
  $105 = 204840;
  $148 = (___cxa_allocate_exception(8)|0);
  $149 = $105;
  $103 = $148;
  $104 = $149;
  $150 = $103;
  $151 = $104;
  __THREW__ = 0;
  invoke_vii(3366,($150|0),($151|0));
  $152 = __THREW__; __THREW__ = 0;
  $153 = $152&1;
  if ($153) {
   $154 = ___cxa_find_matching_catch_2()|0;
   $155 = tempRet0;
   $106 = $154;
   $107 = $155;
   ___cxa_free_exception(($148|0));
   $156 = $106;
   $157 = $107;
   ___resumeException($156|0);
   // unreachable;
  } else {
   HEAP32[$150>>2] = (99824);
   ___cxa_throw(($148|0),(34608|0),(3230|0));
   // unreachable;
  }
 }
 $158 = $111;
 $159 = $158<<3;
 $108 = $159;
 $160 = $108;
 $161 = (__Znwj($160)|0);
 $100 = $139;
 $101 = $137;
 $102 = 1;
 $162 = $100;
 $163 = $101;
 HEAP32[$162>>2] = $163;
 $164 = ((($162)) + 4|0);
 $165 = $102;
 HEAP32[$164>>2] = $165;
 $96 = $138;
 $97 = $161;
 $98 = $139;
 $166 = $96;
 $167 = $97;
 $168 = $98;
 $95 = $168;
 $169 = $95;
 ;HEAP32[$99>>2]=HEAP32[$169>>2]|0;HEAP32[$99+4>>2]=HEAP32[$169+4>>2]|0;
 ;HEAP8[$94>>0]=HEAP8[$99>>0]|0;HEAP8[$94+1>>0]=HEAP8[$99+1>>0]|0;HEAP8[$94+2>>0]=HEAP8[$99+2>>0]|0;HEAP8[$94+3>>0]=HEAP8[$99+3>>0]|0;HEAP8[$94+4>>0]=HEAP8[$99+4>>0]|0;HEAP8[$94+5>>0]=HEAP8[$99+5>>0]|0;HEAP8[$94+6>>0]=HEAP8[$99+6>>0]|0;HEAP8[$94+7>>0]=HEAP8[$99+7>>0]|0;
 $91 = $166;
 HEAP32[$92>>2] = $167;
 $170 = $91;
 $90 = $92;
 $171 = $90;
 $172 = HEAP32[$171>>2]|0;
 $84 = $94;
 $173 = $84;
 ;HEAP32[$93>>2]=HEAP32[$173>>2]|0;HEAP32[$93+4>>2]=HEAP32[$173+4>>2]|0;
 ;HEAP8[$89>>0]=HEAP8[$93>>0]|0;HEAP8[$89+1>>0]=HEAP8[$93+1>>0]|0;HEAP8[$89+2>>0]=HEAP8[$93+2>>0]|0;HEAP8[$89+3>>0]=HEAP8[$93+3>>0]|0;HEAP8[$89+4>>0]=HEAP8[$93+4>>0]|0;HEAP8[$89+5>>0]=HEAP8[$93+5>>0]|0;HEAP8[$89+6>>0]=HEAP8[$93+6>>0]|0;HEAP8[$89+7>>0]=HEAP8[$93+7>>0]|0;
 $87 = $170;
 HEAP32[$88>>2] = $172;
 $174 = $87;
 $86 = $88;
 $175 = $86;
 $176 = HEAP32[$175>>2]|0;
 HEAP32[$174>>2] = $176;
 $177 = ((($174)) + 4|0);
 $85 = $89;
 $178 = $85;
 ;HEAP32[$177>>2]=HEAP32[$178>>2]|0;HEAP32[$177+4>>2]=HEAP32[$178+4>>2]|0;
 $83 = $138;
 $179 = $83;
 $82 = $179;
 $180 = $82;
 $81 = $180;
 $181 = $81;
 $182 = HEAP32[$181>>2]|0;
 $183 = ((($141)) + 4|0);
 $80 = $183;
 $184 = $80;
 $79 = $184;
 $185 = $79;
 $77 = $140;
 $78 = $137;
 $65 = $182;
 $66 = $185;
 $67 = $140;
 $186 = $65;
 $64 = $186;
 $187 = $64;
 HEAP32[$187>>2] = (71384);
 HEAP32[$186>>2] = (71428);
 $188 = ((($186)) + 4|0);
 $189 = $66;
 $19 = $189;
 $190 = $19;
 $17 = $190;
 $191 = $17;
 $11 = $18;
 $12 = $191;
 $192 = $11;
 $193 = $12;
 ;HEAP8[$7>>0]=HEAP8[$16>>0]|0;
 ;HEAP8[$8>>0]=HEAP8[$15>>0]|0;
 ;HEAP8[$9>>0]=HEAP8[$14>>0]|0;
 ;HEAP8[$10>>0]=HEAP8[$13>>0]|0;
 $5 = $192;
 $6 = $193;
 $194 = $5;
 $195 = $6;
 $4 = $195;
 $196 = $4;
 $2 = $194;
 $3 = $196;
 $197 = $2;
 $198 = $3;
 $1 = $198;
 $199 = $1;
 HEAP32[$197>>2] = $199;
 $200 = HEAP32[$18>>2]|0;
 HEAP32[$69>>2] = $200;
 $201 = $67;
 $20 = $201;
 $202 = $20;
 $40 = $202;
 $203 = $40;
 $38 = $203;
 $204 = $38;
 $32 = $39;
 $33 = $204;
 $205 = $32;
 $206 = $33;
 $31 = $206;
 $207 = $31;
 ;HEAP8[$27>>0]=HEAP8[$37>>0]|0;
 ;HEAP8[$28>>0]=HEAP8[$36>>0]|0;
 ;HEAP8[$29>>0]=HEAP8[$35>>0]|0;
 ;HEAP8[$30>>0]=HEAP8[$34>>0]|0;
 $25 = $205;
 $26 = $207;
 $208 = $25;
 $209 = $26;
 $24 = $209;
 $210 = $24;
 $22 = $208;
 $23 = $210;
 $211 = $22;
 $212 = $23;
 $21 = $212;
 $213 = $21;
 HEAP32[$211>>2] = $213;
 $214 = HEAP32[$39>>2]|0;
 HEAP32[$70>>2] = $214;
 ;HEAP8[$61>>0]=HEAP8[$70>>0]|0;HEAP8[$61+1>>0]=HEAP8[$70+1>>0]|0;HEAP8[$61+2>>0]=HEAP8[$70+2>>0]|0;HEAP8[$61+3>>0]=HEAP8[$70+3>>0]|0;
 ;HEAP8[$62>>0]=HEAP8[$69>>0]|0;HEAP8[$62+1>>0]=HEAP8[$69+1>>0]|0;HEAP8[$62+2>>0]=HEAP8[$69+2>>0]|0;HEAP8[$62+3>>0]=HEAP8[$69+3>>0]|0;
 ;HEAP8[$63>>0]=HEAP8[$68>>0]|0;
 $55 = $188;
 $215 = $55;
 $54 = $62;
 $216 = $54;
 ;HEAP32[$57>>2]=HEAP32[$216>>2]|0;
 $41 = $61;
 $217 = $41;
 ;HEAP32[$58>>2]=HEAP32[$217>>2]|0;
 ;HEAP8[$49>>0]=HEAP8[$60>>0]|0;
 ;HEAP8[$50>>0]=HEAP8[$59>>0]|0;
 ;HEAP8[$51>>0]=HEAP8[$58>>0]|0;HEAP8[$51+1>>0]=HEAP8[$58+1>>0]|0;HEAP8[$51+2>>0]=HEAP8[$58+2>>0]|0;HEAP8[$51+3>>0]=HEAP8[$58+3>>0]|0;
 ;HEAP8[$52>>0]=HEAP8[$57>>0]|0;HEAP8[$52+1>>0]=HEAP8[$57+1>>0]|0;HEAP8[$52+2>>0]=HEAP8[$57+2>>0]|0;HEAP8[$52+3>>0]=HEAP8[$57+3>>0]|0;
 ;HEAP8[$53>>0]=HEAP8[$56>>0]|0;
 $48 = $215;
 $218 = $48;
 $47 = $51;
 $219 = $47;
 $46 = $219;
 $220 = $46;
 $221 = HEAP32[$220>>2]|0;
 $42 = $221;
 $44 = $52;
 $222 = $44;
 $43 = $222;
 $223 = $43;
 $224 = HEAP32[$223>>2]|0;
 $45 = $224;
 $225 = $45;
 ;HEAP32[$218>>2]=HEAP32[$225>>2]|0;
 $75 = $138;
 $226 = $75;
 $74 = $226;
 $227 = $74;
 $73 = $227;
 $228 = $73;
 $229 = HEAP32[$228>>2]|0;
 $76 = $229;
 $72 = $226;
 $230 = $72;
 $71 = $230;
 $231 = $71;
 HEAP32[$231>>2] = 0;
 $232 = $76;
 $131 = $138;
 $233 = $131;
 $128 = $233;
 $129 = 0;
 $234 = $128;
 $127 = $234;
 $235 = $127;
 $126 = $235;
 $236 = $126;
 $237 = HEAP32[$236>>2]|0;
 $130 = $237;
 $238 = $129;
 $116 = $234;
 $239 = $116;
 $115 = $239;
 $240 = $115;
 HEAP32[$240>>2] = $238;
 $241 = $130;
 $242 = ($241|0)!=(0|0);
 if (!($242)) {
  STACKTOP = sp;return ($232|0);
 }
 $114 = $234;
 $243 = $114;
 $113 = $243;
 $244 = $113;
 $245 = ((($244)) + 4|0);
 $246 = $130;
 $124 = $245;
 $125 = $246;
 $247 = $124;
 $248 = HEAP32[$247>>2]|0;
 $249 = $125;
 $250 = ((($247)) + 4|0);
 $251 = HEAP32[$250>>2]|0;
 $121 = $248;
 $122 = $249;
 $123 = $251;
 $252 = $121;
 $253 = $122;
 $254 = $123;
 $118 = $252;
 $119 = $253;
 $120 = $254;
 $255 = $119;
 $117 = $255;
 $256 = $117;
 __ZdlPv($256);
 STACKTOP = sp;return ($232|0);
}
function __ZNKSt3__210__function6__funcIZN4mjin11application6memory4Game18matchSelectedItemsEvE3__1NS_9allocatorIS6_EEFvvEE7__cloneEPNS0_6__baseIS9_EE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 320|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(320|0);
 $10 = sp + 120|0;
 $11 = sp + 112|0;
 $12 = sp + 104|0;
 $13 = sp + 96|0;
 $16 = sp + 319|0;
 $17 = sp + 318|0;
 $18 = sp + 317|0;
 $19 = sp + 316|0;
 $21 = sp + 260|0;
 $29 = sp + 88|0;
 $30 = sp + 80|0;
 $31 = sp + 72|0;
 $32 = sp + 64|0;
 $35 = sp + 315|0;
 $36 = sp + 314|0;
 $37 = sp + 313|0;
 $38 = sp + 312|0;
 $40 = sp + 216|0;
 $50 = sp + 56|0;
 $51 = sp + 48|0;
 $52 = sp + 40|0;
 $53 = sp + 32|0;
 $54 = sp + 24|0;
 $57 = sp + 311|0;
 $58 = sp + 168|0;
 $59 = sp + 164|0;
 $60 = sp + 310|0;
 $61 = sp + 309|0;
 $62 = sp + 16|0;
 $63 = sp + 8|0;
 $64 = sp;
 $69 = sp + 308|0;
 $70 = sp + 144|0;
 $71 = sp + 140|0;
 $74 = $0;
 $75 = $1;
 $76 = $74;
 $77 = $75;
 $78 = ((($76)) + 4|0);
 $73 = $78;
 $79 = $73;
 $72 = $79;
 $80 = $72;
 $81 = ((($76)) + 4|0);
 $3 = $81;
 $82 = $3;
 $2 = $82;
 $83 = $2;
 $66 = $77;
 $67 = $80;
 $68 = $83;
 $84 = $66;
 $65 = $84;
 $85 = $65;
 HEAP32[$85>>2] = (71384);
 HEAP32[$84>>2] = (71428);
 $86 = ((($84)) + 4|0);
 $87 = $67;
 $22 = $87;
 $88 = $22;
 $20 = $88;
 $89 = $20;
 $14 = $21;
 $15 = $89;
 $90 = $14;
 $91 = $15;
 ;HEAP8[$10>>0]=HEAP8[$19>>0]|0;
 ;HEAP8[$11>>0]=HEAP8[$18>>0]|0;
 ;HEAP8[$12>>0]=HEAP8[$17>>0]|0;
 ;HEAP8[$13>>0]=HEAP8[$16>>0]|0;
 $8 = $90;
 $9 = $91;
 $92 = $8;
 $93 = $9;
 $7 = $93;
 $94 = $7;
 $5 = $92;
 $6 = $94;
 $95 = $5;
 $96 = $6;
 $4 = $96;
 $97 = $4;
 HEAP32[$95>>2] = $97;
 $98 = HEAP32[$21>>2]|0;
 HEAP32[$70>>2] = $98;
 $99 = $68;
 $41 = $99;
 $100 = $41;
 $39 = $100;
 $101 = $39;
 $33 = $40;
 $34 = $101;
 $102 = $33;
 $103 = $34;
 ;HEAP8[$29>>0]=HEAP8[$38>>0]|0;
 ;HEAP8[$30>>0]=HEAP8[$37>>0]|0;
 ;HEAP8[$31>>0]=HEAP8[$36>>0]|0;
 ;HEAP8[$32>>0]=HEAP8[$35>>0]|0;
 $27 = $102;
 $28 = $103;
 $104 = $27;
 $105 = $28;
 $26 = $105;
 $106 = $26;
 $24 = $104;
 $25 = $106;
 $107 = $24;
 $108 = $25;
 $23 = $108;
 $109 = $23;
 HEAP32[$107>>2] = $109;
 $110 = HEAP32[$40>>2]|0;
 HEAP32[$71>>2] = $110;
 ;HEAP8[$62>>0]=HEAP8[$71>>0]|0;HEAP8[$62+1>>0]=HEAP8[$71+1>>0]|0;HEAP8[$62+2>>0]=HEAP8[$71+2>>0]|0;HEAP8[$62+3>>0]=HEAP8[$71+3>>0]|0;
 ;HEAP8[$63>>0]=HEAP8[$70>>0]|0;HEAP8[$63+1>>0]=HEAP8[$70+1>>0]|0;HEAP8[$63+2>>0]=HEAP8[$70+2>>0]|0;HEAP8[$63+3>>0]=HEAP8[$70+3>>0]|0;
 ;HEAP8[$64>>0]=HEAP8[$69>>0]|0;
 $56 = $86;
 $111 = $56;
 $55 = $63;
 $112 = $55;
 ;HEAP32[$58>>2]=HEAP32[$112>>2]|0;
 $42 = $62;
 $113 = $42;
 ;HEAP32[$59>>2]=HEAP32[$113>>2]|0;
 ;HEAP8[$50>>0]=HEAP8[$61>>0]|0;
 ;HEAP8[$51>>0]=HEAP8[$60>>0]|0;
 ;HEAP8[$52>>0]=HEAP8[$59>>0]|0;HEAP8[$52+1>>0]=HEAP8[$59+1>>0]|0;HEAP8[$52+2>>0]=HEAP8[$59+2>>0]|0;HEAP8[$52+3>>0]=HEAP8[$59+3>>0]|0;
 ;HEAP8[$53>>0]=HEAP8[$58>>0]|0;HEAP8[$53+1>>0]=HEAP8[$58+1>>0]|0;HEAP8[$53+2>>0]=HEAP8[$58+2>>0]|0;HEAP8[$53+3>>0]=HEAP8[$58+3>>0]|0;
 ;HEAP8[$54>>0]=HEAP8[$57>>0]|0;
 $49 = $111;
 $114 = $49;
 $48 = $52;
 $115 = $48;
 $47 = $115;
 $116 = $47;
 $117 = HEAP32[$116>>2]|0;
 $43 = $117;
 $45 = $53;
 $118 = $45;
 $44 = $118;
 $119 = $44;
 $120 = HEAP32[$119>>2]|0;
 $46 = $120;
 $121 = $46;
 ;HEAP32[$114>>2]=HEAP32[$121>>2]|0;
 STACKTOP = sp;return;
}
function __ZNSt3__210__function6__funcIZN4mjin11application6memory4Game18matchSelectedItemsEvE3__1NS_9allocatorIS6_EEFvvEE7destroyEv($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 STACKTOP = sp;return;
}
function __ZNSt3__210__function6__funcIZN4mjin11application6memory4Game18matchSelectedItemsEvE3__1NS_9allocatorIS6_EEFvvEE18destroy_deallocateEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $10 = sp + 36|0;
 $9 = $0;
 $11 = $9;
 $12 = ((($11)) + 4|0);
 $8 = $12;
 $13 = $8;
 $7 = $13;
 $14 = $7;
 $1 = $10;
 $2 = $14;
 $4 = $10;
 $5 = $11;
 $6 = 1;
 $15 = $5;
 $3 = $15;
 $16 = $3;
 __ZdlPv($16);
 STACKTOP = sp;return;
}
function __ZNSt3__210__function6__funcIZN4mjin11application6memory4Game18matchSelectedItemsEvE3__1NS_9allocatorIS6_EEFvvEEclEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = $0;
 $4 = $3;
 $5 = ((($4)) + 4|0);
 $2 = $5;
 $6 = $2;
 $1 = $6;
 $7 = $1;
 __ZNSt3__228__invoke_void_return_wrapperIvE6__callIJRZN4mjin11application6memory4Game18matchSelectedItemsEvE3__1EEEvDpOT_($7);
 STACKTOP = sp;return;
}
function __ZNKSt3__210__function6__funcIZN4mjin11application6memory4Game18matchSelectedItemsEvE3__1NS_9allocatorIS6_EEFvvEE6targetERKSt9type_info($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $7 = $0;
 $8 = $1;
 $9 = $7;
 $10 = $8;
 $4 = $10;
 $5 = 27344;
 $11 = $4;
 $12 = ((($11)) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $5;
 $15 = ((($14)) + 4|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($13|0)==($16|0);
 if ($17) {
  $18 = ((($9)) + 4|0);
  $3 = $18;
  $19 = $3;
  $2 = $19;
  $20 = $2;
  $6 = $20;
  $21 = $6;
  STACKTOP = sp;return ($21|0);
 } else {
  $6 = 0;
  $21 = $6;
  STACKTOP = sp;return ($21|0);
 }
 return (0)|0;
}
function __ZNKSt3__210__function6__funcIZN4mjin11application6memory4Game18matchSelectedItemsEvE3__1NS_9allocatorIS6_EEFvvEE11target_typeEv($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 STACKTOP = sp;return (27344|0);
}
function __ZNSt3__228__invoke_void_return_wrapperIvE6__callIJRZN4mjin11application6memory4Game18matchSelectedItemsEvE3__1EEEvDpOT_($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $4 = $0;
 $5 = $4;
 $3 = $5;
 $6 = $3;
 $2 = $6;
 $7 = $2;
 $1 = $7;
 $8 = $1;
 __ZZN4mjin11application6memory4Game18matchSelectedItemsEvENK3__1clEv($8);
 STACKTOP = sp;return;
}
function __ZZN4mjin11application6memory4Game18matchSelectedItemsEvENK3__1clEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 __ZN4mjin11application6memory4Game21deselectSelectedNodesEv($3);
 STACKTOP = sp;return;
}
function __ZN4mjin11application6memory4Game21deselectSelectedNodesEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0;
 var $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0;
 var $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0;
 var $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 272|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(272|0);
 $10 = sp + 224|0;
 $13 = sp + 212|0;
 $42 = sp;
 $45 = sp + 264|0;
 $58 = sp + 40|0;
 $61 = sp + 28|0;
 $65 = sp + 12|0;
 $66 = sp + 8|0;
 $63 = $0;
 $68 = $63;
 $69 = ((($68)) + 16|0);
 $64 = $69;
 $70 = $64;
 $62 = $70;
 $71 = $62;
 $72 = HEAP32[$71>>2]|0;
 $59 = $71;
 $60 = $72;
 $73 = $60;
 $56 = $58;
 $57 = $73;
 $74 = $56;
 $75 = $57;
 HEAP32[$74>>2] = $75;
 $76 = HEAP32[$58>>2]|0;
 HEAP32[$61>>2] = $76;
 $77 = HEAP32[$61>>2]|0;
 HEAP32[$65>>2] = $77;
 $78 = $64;
 $14 = $78;
 $79 = $14;
 $80 = ((($79)) + 4|0);
 $81 = HEAP32[$80>>2]|0;
 $11 = $79;
 $12 = $81;
 $82 = $12;
 $8 = $10;
 $9 = $82;
 $83 = $8;
 $84 = $9;
 HEAP32[$83>>2] = $84;
 $85 = HEAP32[$10>>2]|0;
 HEAP32[$13>>2] = $85;
 $86 = HEAP32[$13>>2]|0;
 HEAP32[$66>>2] = $86;
 while(1) {
  $5 = $65;
  $6 = $66;
  $87 = $5;
  $88 = $6;
  $3 = $87;
  $4 = $88;
  $89 = $3;
  $2 = $89;
  $90 = $2;
  $91 = HEAP32[$90>>2]|0;
  $92 = $4;
  $1 = $92;
  $93 = $1;
  $94 = HEAP32[$93>>2]|0;
  $95 = ($91|0)==($94|0);
  $96 = $95 ^ 1;
  if (!($96)) {
   break;
  }
  $7 = $65;
  $97 = $7;
  $98 = HEAP32[$97>>2]|0;
  $99 = HEAP32[$98>>2]|0;
  $67 = $99;
  $100 = $67;
  __ZN4mjin11application6memory4Game10selectNodeEib($68,$100,0);
  $15 = $65;
  $101 = $15;
  $102 = HEAP32[$101>>2]|0;
  $103 = ((($102)) + 4|0);
  HEAP32[$101>>2] = $103;
 }
 $104 = ((($68)) + 16|0);
 $54 = $104;
 $105 = $54;
 $53 = $105;
 $106 = $53;
 $107 = ((($106)) + 4|0);
 $108 = HEAP32[$107>>2]|0;
 $109 = HEAP32[$106>>2]|0;
 $110 = $108;
 $111 = $109;
 $112 = (($110) - ($111))|0;
 $113 = (($112|0) / 4)&-1;
 $55 = $113;
 $52 = $105;
 $114 = $52;
 $115 = HEAP32[$114>>2]|0;
 $50 = $114;
 $51 = $115;
 $116 = $50;
 while(1) {
  $117 = $51;
  $118 = ((($116)) + 4|0);
  $119 = HEAP32[$118>>2]|0;
  $120 = ($117|0)!=($119|0);
  if (!($120)) {
   break;
  }
  $49 = $116;
  $121 = $49;
  $122 = ((($121)) + 8|0);
  $48 = $122;
  $123 = $48;
  $47 = $123;
  $124 = $47;
  $125 = ((($116)) + 4|0);
  $126 = HEAP32[$125>>2]|0;
  $127 = ((($126)) + -4|0);
  HEAP32[$125>>2] = $127;
  $46 = $127;
  $128 = $46;
  $43 = $124;
  $44 = $128;
  $129 = $43;
  $130 = $44;
  ;HEAP8[$42>>0]=HEAP8[$45>>0]|0;
  $40 = $129;
  $41 = $130;
  $131 = $40;
  $132 = $41;
  $38 = $131;
  $39 = $132;
 }
 $133 = $55;
 $35 = $105;
 $36 = $133;
 $134 = $35;
 $34 = $134;
 $135 = $34;
 $136 = HEAP32[$135>>2]|0;
 $33 = $136;
 $137 = $33;
 $17 = $134;
 $138 = $17;
 $139 = HEAP32[$138>>2]|0;
 $16 = $139;
 $140 = $16;
 $22 = $134;
 $141 = $22;
 $21 = $141;
 $142 = $21;
 $20 = $142;
 $143 = $20;
 $144 = ((($143)) + 8|0);
 $19 = $144;
 $145 = $19;
 $18 = $145;
 $146 = $18;
 $147 = HEAP32[$146>>2]|0;
 $148 = HEAP32[$142>>2]|0;
 $149 = $147;
 $150 = $148;
 $151 = (($149) - ($150))|0;
 $152 = (($151|0) / 4)&-1;
 $153 = (($140) + ($152<<2)|0);
 $24 = $134;
 $154 = $24;
 $155 = HEAP32[$154>>2]|0;
 $23 = $155;
 $156 = $23;
 $157 = $36;
 $158 = (($156) + ($157<<2)|0);
 $26 = $134;
 $159 = $26;
 $160 = HEAP32[$159>>2]|0;
 $25 = $160;
 $161 = $25;
 $27 = $134;
 $162 = $27;
 $163 = ((($162)) + 4|0);
 $164 = HEAP32[$163>>2]|0;
 $165 = HEAP32[$162>>2]|0;
 $166 = $164;
 $167 = $165;
 $168 = (($166) - ($167))|0;
 $169 = (($168|0) / 4)&-1;
 $170 = (($161) + ($169<<2)|0);
 $28 = $134;
 $29 = $137;
 $30 = $153;
 $31 = $158;
 $32 = $170;
 $37 = $105;
 STACKTOP = sp;return;
}
function __ZNSt3__210__function6__baseIFvvEED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 STACKTOP = sp;return;
}
function __ZNSt3__210__function6__baseIFvvEED0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = $0;
 $3 = $2;
 $1 = $3;
 __ZdlPv($3);
 STACKTOP = sp;return;
}
function __ZN3osg5Timer12setStartTickEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 $3 = (__ZNK3osg5Timer4tickEv($2)|0);
 $4 = tempRet0;
 $5 = $2;
 $6 = $5;
 HEAP32[$6>>2] = $3;
 $7 = (($5) + 4)|0;
 $8 = $7;
 HEAP32[$8>>2] = $4;
 STACKTOP = sp;return;
}
function __ZNSt3__28functionIFvvEEC2ERKS2_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = $0;
 $3 = $1;
 $4 = $2;
 $5 = $3;
 $6 = ((($5)) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if ($8) {
  $9 = ((($4)) + 16|0);
  HEAP32[$9>>2] = 0;
  STACKTOP = sp;return;
 }
 $10 = $3;
 $11 = ((($10)) + 16|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = $3;
 $14 = ($12|0)==($13|0);
 if ($14) {
  $15 = (__ZNSt3__28functionIFvvEE9__as_baseEPv($4)|0);
  $16 = ((($4)) + 16|0);
  HEAP32[$16>>2] = $15;
  $17 = $3;
  $18 = ((($17)) + 16|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = HEAP32[$19>>2]|0;
  $21 = ((($20)) + 12|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = ((($4)) + 16|0);
  $24 = HEAP32[$23>>2]|0;
  FUNCTION_TABLE_vii[$22 & 8191]($19,$24);
  STACKTOP = sp;return;
 } else {
  $25 = $3;
  $26 = ((($25)) + 16|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = HEAP32[$27>>2]|0;
  $29 = ((($28)) + 8|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (FUNCTION_TABLE_ii[$30 & 8191]($27)|0);
  $32 = ((($4)) + 16|0);
  HEAP32[$32>>2] = $31;
  STACKTOP = sp;return;
 }
}
function __ZNSt3__28functionIFbdEEaSIZN4mjin11application6memory4Game18animateMatchOrMissEbNS0_IFvvEEEE3__2EENS_9enable_ifIXaasr10__callableINS_5decayIT_E4typeEEE5valuentsr7is_sameINS_16remove_referenceISD_E4typeES2_EE5valueERS2_E4typeEOSD_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(80|0);
 $5 = sp + 32|0;
 $6 = sp;
 $3 = $0;
 $4 = $1;
 $9 = $3;
 $10 = $4;
 $2 = $10;
 $11 = $2;
 __ZZN4mjin11application6memory4Game18animateMatchOrMissEbNSt3__28functionIFvvEEEEN3__2C2EOS7_($6,$11);
 __THREW__ = 0;
 invoke_vii(4072,($5|0),($6|0));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $14 = ___cxa_find_matching_catch_2()|0;
  $15 = tempRet0;
  $7 = $14;
  $8 = $15;
  __ZZN4mjin11application6memory4Game18animateMatchOrMissEbNSt3__28functionIFvvEEEEN3__2D2Ev($6);
  $16 = $7;
  $17 = $8;
  ___resumeException($16|0);
  // unreachable;
 } else {
  __ZNSt3__28functionIFbdEE4swapERS2_($5,$9);
  __ZNSt3__28functionIFbdEED2Ev($5);
  __ZZN4mjin11application6memory4Game18animateMatchOrMissEbNSt3__28functionIFvvEEEEN3__2D2Ev($6);
  STACKTOP = sp;return ($9|0);
 }
 return (0)|0;
}
function __ZZN4mjin11application6memory4Game18animateMatchOrMissEbNSt3__28functionIFvvEEEEN3__2D2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 $3 = ((($2)) + 8|0);
 __ZNSt3__28functionIFvvEED2Ev($3);
 STACKTOP = sp;return;
}
function __ZZN4mjin11application6memory4Game18animateMatchOrMissEbNSt3__28functionIFvvEEEEN3__2C2EOS7_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = $0;
 $3 = $1;
 $4 = $2;
 $5 = $3;
 ;HEAP32[$4>>2]=HEAP32[$5>>2]|0;HEAP32[$4+4>>2]=HEAP32[$5+4>>2]|0;
 $6 = ((($4)) + 8|0);
 $7 = $3;
 $8 = ((($7)) + 8|0);
 __ZNSt3__28functionIFvvEEC2EOS2_($6,$8);
 STACKTOP = sp;return;
}
function __ZNSt3__28functionIFbdEEC2IZN4mjin11application6memory4Game18animateMatchOrMissEbNS0_IFvvEEEE3__2vEET_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0;
 var $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0;
 var $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0;
 var $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0;
 var $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0;
 var $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0;
 var $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0;
 var $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 608|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(608|0);
 $8 = sp + 136|0;
 $9 = sp + 128|0;
 $10 = sp + 120|0;
 $11 = sp + 112|0;
 $15 = sp + 605|0;
 $16 = sp + 604|0;
 $17 = sp + 603|0;
 $18 = sp + 602|0;
 $20 = sp + 548|0;
 $29 = sp + 104|0;
 $30 = sp + 96|0;
 $31 = sp + 88|0;
 $32 = sp + 80|0;
 $36 = sp + 601|0;
 $37 = sp + 600|0;
 $38 = sp + 599|0;
 $39 = sp + 598|0;
 $41 = sp + 496|0;
 $52 = sp + 72|0;
 $53 = sp + 64|0;
 $54 = sp + 56|0;
 $55 = sp + 48|0;
 $56 = sp + 40|0;
 $59 = sp + 597|0;
 $60 = sp + 444|0;
 $61 = sp + 440|0;
 $62 = sp + 596|0;
 $63 = sp + 595|0;
 $64 = sp + 32|0;
 $65 = sp + 24|0;
 $66 = sp + 16|0;
 $71 = sp + 594|0;
 $72 = sp + 420|0;
 $73 = sp + 416|0;
 $90 = sp + 348|0;
 $91 = sp + 8|0;
 $94 = sp + 336|0;
 $95 = sp + 328|0;
 $96 = sp;
 $101 = sp + 304|0;
 $137 = sp + 593|0;
 $138 = sp + 152|0;
 $139 = sp + 144|0;
 $140 = sp + 592|0;
 $136 = $0;
 $141 = $136;
 $142 = ((($141)) + 16|0);
 HEAP32[$142>>2] = 0;
 $135 = $1;
 $134 = $137;
 $112 = $137;
 $113 = 1;
 $114 = 0;
 $143 = $112;
 $144 = $113;
 $111 = $143;
 $145 = ($144>>>0)>(107374182);
 if ($145) {
  $107 = 204840;
  $146 = (___cxa_allocate_exception(8)|0);
  $147 = $107;
  $105 = $146;
  $106 = $147;
  $148 = $105;
  $149 = $106;
  __THREW__ = 0;
  invoke_vii(3366,($148|0),($149|0));
  $150 = __THREW__; __THREW__ = 0;
  $151 = $150&1;
  if ($151) {
   $152 = ___cxa_find_matching_catch_2()|0;
   $153 = tempRet0;
   $108 = $152;
   $109 = $153;
   ___cxa_free_exception(($146|0));
   $154 = $108;
   $155 = $109;
   ___resumeException($154|0);
   // unreachable;
  } else {
   HEAP32[$148>>2] = (99824);
   ___cxa_throw(($146|0),(34608|0),(3230|0));
   // unreachable;
  }
 }
 $156 = $113;
 $157 = ($156*40)|0;
 $110 = $157;
 $158 = $110;
 $159 = (__Znwj($158)|0);
 $102 = $139;
 $103 = $137;
 $104 = 1;
 $160 = $102;
 $161 = $103;
 HEAP32[$160>>2] = $161;
 $162 = ((($160)) + 4|0);
 $163 = $104;
 HEAP32[$162>>2] = $163;
 $98 = $138;
 $99 = $159;
 $100 = $139;
 $164 = $98;
 $165 = $99;
 $166 = $100;
 $97 = $166;
 $167 = $97;
 ;HEAP32[$101>>2]=HEAP32[$167>>2]|0;HEAP32[$101+4>>2]=HEAP32[$167+4>>2]|0;
 ;HEAP8[$96>>0]=HEAP8[$101>>0]|0;HEAP8[$96+1>>0]=HEAP8[$101+1>>0]|0;HEAP8[$96+2>>0]=HEAP8[$101+2>>0]|0;HEAP8[$96+3>>0]=HEAP8[$101+3>>0]|0;HEAP8[$96+4>>0]=HEAP8[$101+4>>0]|0;HEAP8[$96+5>>0]=HEAP8[$101+5>>0]|0;HEAP8[$96+6>>0]=HEAP8[$101+6>>0]|0;HEAP8[$96+7>>0]=HEAP8[$101+7>>0]|0;
 $93 = $164;
 HEAP32[$94>>2] = $165;
 $168 = $93;
 $92 = $94;
 $169 = $92;
 $170 = HEAP32[$169>>2]|0;
 $86 = $96;
 $171 = $86;
 ;HEAP32[$95>>2]=HEAP32[$171>>2]|0;HEAP32[$95+4>>2]=HEAP32[$171+4>>2]|0;
 ;HEAP8[$91>>0]=HEAP8[$95>>0]|0;HEAP8[$91+1>>0]=HEAP8[$95+1>>0]|0;HEAP8[$91+2>>0]=HEAP8[$95+2>>0]|0;HEAP8[$91+3>>0]=HEAP8[$95+3>>0]|0;HEAP8[$91+4>>0]=HEAP8[$95+4>>0]|0;HEAP8[$91+5>>0]=HEAP8[$95+5>>0]|0;HEAP8[$91+6>>0]=HEAP8[$95+6>>0]|0;HEAP8[$91+7>>0]=HEAP8[$95+7>>0]|0;
 $89 = $168;
 HEAP32[$90>>2] = $170;
 $172 = $89;
 $88 = $90;
 $173 = $88;
 $174 = HEAP32[$173>>2]|0;
 HEAP32[$172>>2] = $174;
 $175 = ((($172)) + 4|0);
 $87 = $91;
 $176 = $87;
 ;HEAP32[$175>>2]=HEAP32[$176>>2]|0;HEAP32[$175+4>>2]=HEAP32[$176+4>>2]|0;
 $85 = $138;
 $177 = $85;
 $84 = $177;
 $178 = $84;
 $83 = $178;
 $179 = $83;
 $180 = HEAP32[$179>>2]|0;
 $82 = $1;
 $181 = $82;
 $80 = $140;
 $81 = $137;
 $68 = $180;
 $69 = $181;
 $70 = $140;
 $182 = $68;
 $67 = $182;
 $183 = $67;
 HEAP32[$183>>2] = (71472);
 HEAP32[$182>>2] = (71516);
 $184 = ((($182)) + 8|0);
 $185 = $69;
 $43 = $185;
 $186 = $43;
 $21 = $186;
 $187 = $21;
 $19 = $187;
 $188 = $19;
 $13 = $20;
 $14 = $188;
 $189 = $13;
 $190 = $14;
 $12 = $190;
 $191 = $12;
 ;HEAP8[$8>>0]=HEAP8[$18>>0]|0;
 ;HEAP8[$9>>0]=HEAP8[$17>>0]|0;
 ;HEAP8[$10>>0]=HEAP8[$16>>0]|0;
 ;HEAP8[$11>>0]=HEAP8[$15>>0]|0;
 $6 = $189;
 $7 = $191;
 $192 = $6;
 $193 = $7;
 $5 = $193;
 $194 = $5;
 $3 = $192;
 $4 = $194;
 $195 = $3;
 $196 = $4;
 $2 = $196;
 $197 = $2;
 HEAP32[$195>>2] = $197;
 $198 = HEAP32[$20>>2]|0;
 HEAP32[$72>>2] = $198;
 $199 = $70;
 $22 = $199;
 $200 = $22;
 $42 = $200;
 $201 = $42;
 $40 = $201;
 $202 = $40;
 $34 = $41;
 $35 = $202;
 $203 = $34;
 $204 = $35;
 $33 = $204;
 $205 = $33;
 ;HEAP8[$29>>0]=HEAP8[$39>>0]|0;
 ;HEAP8[$30>>0]=HEAP8[$38>>0]|0;
 ;HEAP8[$31>>0]=HEAP8[$37>>0]|0;
 ;HEAP8[$32>>0]=HEAP8[$36>>0]|0;
 $27 = $203;
 $28 = $205;
 $206 = $27;
 $207 = $28;
 $26 = $207;
 $208 = $26;
 $24 = $206;
 $25 = $208;
 $209 = $24;
 $210 = $25;
 $23 = $210;
 $211 = $23;
 HEAP32[$209>>2] = $211;
 $212 = HEAP32[$41>>2]|0;
 HEAP32[$73>>2] = $212;
 ;HEAP8[$64>>0]=HEAP8[$73>>0]|0;HEAP8[$64+1>>0]=HEAP8[$73+1>>0]|0;HEAP8[$64+2>>0]=HEAP8[$73+2>>0]|0;HEAP8[$64+3>>0]=HEAP8[$73+3>>0]|0;
 ;HEAP8[$65>>0]=HEAP8[$72>>0]|0;HEAP8[$65+1>>0]=HEAP8[$72+1>>0]|0;HEAP8[$65+2>>0]=HEAP8[$72+2>>0]|0;HEAP8[$65+3>>0]=HEAP8[$72+3>>0]|0;
 ;HEAP8[$66>>0]=HEAP8[$71>>0]|0;
 $58 = $184;
 $213 = $58;
 $57 = $65;
 $214 = $57;
 ;HEAP32[$60>>2]=HEAP32[$214>>2]|0;
 $44 = $64;
 $215 = $44;
 ;HEAP32[$61>>2]=HEAP32[$215>>2]|0;
 ;HEAP8[$52>>0]=HEAP8[$63>>0]|0;
 ;HEAP8[$53>>0]=HEAP8[$62>>0]|0;
 ;HEAP8[$54>>0]=HEAP8[$61>>0]|0;HEAP8[$54+1>>0]=HEAP8[$61+1>>0]|0;HEAP8[$54+2>>0]=HEAP8[$61+2>>0]|0;HEAP8[$54+3>>0]=HEAP8[$61+3>>0]|0;
 ;HEAP8[$55>>0]=HEAP8[$60>>0]|0;HEAP8[$55+1>>0]=HEAP8[$60+1>>0]|0;HEAP8[$55+2>>0]=HEAP8[$60+2>>0]|0;HEAP8[$55+3>>0]=HEAP8[$60+3>>0]|0;
 ;HEAP8[$56>>0]=HEAP8[$59>>0]|0;
 $51 = $213;
 $216 = $51;
 $50 = $54;
 $217 = $50;
 $49 = $217;
 $218 = $49;
 $219 = HEAP32[$218>>2]|0;
 $48 = $219;
 $46 = $55;
 $220 = $46;
 $45 = $220;
 $221 = $45;
 $222 = HEAP32[$221>>2]|0;
 $47 = $222;
 $223 = $47;
 __ZZN4mjin11application6memory4Game18animateMatchOrMissEbNSt3__28functionIFvvEEEEN3__2C2EOS7_($216,$223);
 $78 = $138;
 $224 = $78;
 $77 = $224;
 $225 = $77;
 $76 = $225;
 $226 = $76;
 $227 = HEAP32[$226>>2]|0;
 $79 = $227;
 $75 = $224;
 $228 = $75;
 $74 = $228;
 $229 = $74;
 HEAP32[$229>>2] = 0;
 $230 = $79;
 $231 = ((($141)) + 16|0);
 HEAP32[$231>>2] = $230;
 $133 = $138;
 $232 = $133;
 $130 = $232;
 $131 = 0;
 $233 = $130;
 $129 = $233;
 $234 = $129;
 $128 = $234;
 $235 = $128;
 $236 = HEAP32[$235>>2]|0;
 $132 = $236;
 $237 = $131;
 $118 = $233;
 $238 = $118;
 $117 = $238;
 $239 = $117;
 HEAP32[$239>>2] = $237;
 $240 = $132;
 $241 = ($240|0)!=(0|0);
 if (!($241)) {
  STACKTOP = sp;return;
 }
 $116 = $233;
 $242 = $116;
 $115 = $242;
 $243 = $115;
 $244 = ((($243)) + 4|0);
 $245 = $132;
 $126 = $244;
 $127 = $245;
 $246 = $126;
 $247 = HEAP32[$246>>2]|0;
 $248 = $127;
 $249 = ((($246)) + 4|0);
 $250 = HEAP32[$249>>2]|0;
 $123 = $247;
 $124 = $248;
 $125 = $250;
 $251 = $123;
 $252 = $124;
 $253 = $125;
 $120 = $251;
 $121 = $252;
 $122 = $253;
 $254 = $121;
 $119 = $254;
 $255 = $119;
 __ZdlPv($255);
 STACKTOP = sp;return;
}
function __ZNSt3__28functionIFbdEE4swapERS2_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0;
 var $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0;
 var $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(64|0);
 $7 = sp + 32|0;
 $11 = sp;
 $9 = $0;
 $10 = $1;
 $13 = $9;
 $14 = $10;
 $8 = $14;
 $15 = $8;
 $16 = ($15|0)==($13|0);
 if ($16) {
  STACKTOP = sp;return;
 }
 $17 = ((($13)) + 16|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ($18|0)==($13|0);
 if ($19) {
  $20 = $10;
  $21 = ((($20)) + 16|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = $10;
  $24 = ($22|0)==($23|0);
  if ($24) {
   __THREW__ = 0;
   $25 = (invoke_ii(4073,($11|0))|0);
   $26 = __THREW__; __THREW__ = 0;
   $27 = $26&1;
   if (!($27)) {
    $12 = $25;
    $28 = ((($13)) + 16|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = HEAP32[$29>>2]|0;
    $31 = ((($30)) + 12|0);
    $32 = HEAP32[$31>>2]|0;
    $33 = $12;
    __THREW__ = 0;
    invoke_vii($32|0,($29|0),($33|0));
    $34 = __THREW__; __THREW__ = 0;
    $35 = $34&1;
    if (!($35)) {
     $36 = ((($13)) + 16|0);
     $37 = HEAP32[$36>>2]|0;
     $38 = HEAP32[$37>>2]|0;
     $39 = ((($38)) + 16|0);
     $40 = HEAP32[$39>>2]|0;
     FUNCTION_TABLE_vi[$40 & 8191]($37);
     $41 = ((($13)) + 16|0);
     HEAP32[$41>>2] = 0;
     $42 = $10;
     $43 = ((($42)) + 16|0);
     $44 = HEAP32[$43>>2]|0;
     $45 = HEAP32[$44>>2]|0;
     $46 = ((($45)) + 12|0);
     $47 = HEAP32[$46>>2]|0;
     __THREW__ = 0;
     $48 = (invoke_ii(4073,($13|0))|0);
     $49 = __THREW__; __THREW__ = 0;
     $50 = $49&1;
     if (!($50)) {
      __THREW__ = 0;
      invoke_vii($47|0,($44|0),($48|0));
      $51 = __THREW__; __THREW__ = 0;
      $52 = $51&1;
      if (!($52)) {
       $53 = $10;
       $54 = ((($53)) + 16|0);
       $55 = HEAP32[$54>>2]|0;
       $56 = HEAP32[$55>>2]|0;
       $57 = ((($56)) + 16|0);
       $58 = HEAP32[$57>>2]|0;
       FUNCTION_TABLE_vi[$58 & 8191]($55);
       $59 = $10;
       $60 = ((($59)) + 16|0);
       HEAP32[$60>>2] = 0;
       __THREW__ = 0;
       $61 = (invoke_ii(4073,($13|0))|0);
       $62 = __THREW__; __THREW__ = 0;
       $63 = $62&1;
       if (!($63)) {
        $64 = ((($13)) + 16|0);
        HEAP32[$64>>2] = $61;
        $65 = $12;
        $66 = HEAP32[$65>>2]|0;
        $67 = ((($66)) + 12|0);
        $68 = HEAP32[$67>>2]|0;
        $69 = $10;
        __THREW__ = 0;
        $70 = (invoke_ii(4073,($69|0))|0);
        $71 = __THREW__; __THREW__ = 0;
        $72 = $71&1;
        if (!($72)) {
         __THREW__ = 0;
         invoke_vii($68|0,($65|0),($70|0));
         $73 = __THREW__; __THREW__ = 0;
         $74 = $73&1;
         if (!($74)) {
          $75 = $12;
          $76 = HEAP32[$75>>2]|0;
          $77 = ((($76)) + 16|0);
          $78 = HEAP32[$77>>2]|0;
          FUNCTION_TABLE_vi[$78 & 8191]($75);
          $79 = $10;
          __THREW__ = 0;
          $80 = (invoke_ii(4073,($79|0))|0);
          $81 = __THREW__; __THREW__ = 0;
          $82 = $81&1;
          if (!($82)) {
           $83 = $10;
           $84 = ((($83)) + 16|0);
           HEAP32[$84>>2] = $80;
           STACKTOP = sp;return;
          }
         }
        }
       }
      }
     }
    }
   }
  } else {
   label = 13;
  }
 } else {
  label = 13;
 }
 do {
  if ((label|0) == 13) {
   $85 = ((($13)) + 16|0);
   $86 = HEAP32[$85>>2]|0;
   $87 = ($86|0)==($13|0);
   if ($87) {
    $88 = ((($13)) + 16|0);
    $89 = HEAP32[$88>>2]|0;
    $90 = HEAP32[$89>>2]|0;
    $91 = ((($90)) + 12|0);
    $92 = HEAP32[$91>>2]|0;
    $93 = $10;
    __THREW__ = 0;
    $94 = (invoke_ii(4073,($93|0))|0);
    $95 = __THREW__; __THREW__ = 0;
    $96 = $95&1;
    if ($96) {
     break;
    }
    __THREW__ = 0;
    invoke_vii($92|0,($89|0),($94|0));
    $97 = __THREW__; __THREW__ = 0;
    $98 = $97&1;
    if ($98) {
     break;
    }
    $99 = ((($13)) + 16|0);
    $100 = HEAP32[$99>>2]|0;
    $101 = HEAP32[$100>>2]|0;
    $102 = ((($101)) + 16|0);
    $103 = HEAP32[$102>>2]|0;
    FUNCTION_TABLE_vi[$103 & 8191]($100);
    $104 = $10;
    $105 = ((($104)) + 16|0);
    $106 = HEAP32[$105>>2]|0;
    $107 = ((($13)) + 16|0);
    HEAP32[$107>>2] = $106;
    $108 = $10;
    __THREW__ = 0;
    $109 = (invoke_ii(4073,($108|0))|0);
    $110 = __THREW__; __THREW__ = 0;
    $111 = $110&1;
    if ($111) {
     break;
    }
    $112 = $10;
    $113 = ((($112)) + 16|0);
    HEAP32[$113>>2] = $109;
    STACKTOP = sp;return;
   }
   $114 = $10;
   $115 = ((($114)) + 16|0);
   $116 = HEAP32[$115>>2]|0;
   $117 = $10;
   $118 = ($116|0)==($117|0);
   if (!($118)) {
    $144 = ((($13)) + 16|0);
    $145 = $10;
    $146 = ((($145)) + 16|0);
    $5 = $144;
    $6 = $146;
    $147 = $5;
    $4 = $147;
    $148 = $4;
    $149 = HEAP32[$148>>2]|0;
    HEAP32[$7>>2] = $149;
    $150 = $6;
    $2 = $150;
    $151 = $2;
    $152 = HEAP32[$151>>2]|0;
    $153 = $5;
    HEAP32[$153>>2] = $152;
    $3 = $7;
    $154 = $3;
    $155 = HEAP32[$154>>2]|0;
    $156 = $6;
    HEAP32[$156>>2] = $155;
    STACKTOP = sp;return;
   }
   $119 = $10;
   $120 = ((($119)) + 16|0);
   $121 = HEAP32[$120>>2]|0;
   $122 = HEAP32[$121>>2]|0;
   $123 = ((($122)) + 12|0);
   $124 = HEAP32[$123>>2]|0;
   __THREW__ = 0;
   $125 = (invoke_ii(4073,($13|0))|0);
   $126 = __THREW__; __THREW__ = 0;
   $127 = $126&1;
   if (!($127)) {
    __THREW__ = 0;
    invoke_vii($124|0,($121|0),($125|0));
    $128 = __THREW__; __THREW__ = 0;
    $129 = $128&1;
    if (!($129)) {
     $130 = $10;
     $131 = ((($130)) + 16|0);
     $132 = HEAP32[$131>>2]|0;
     $133 = HEAP32[$132>>2]|0;
     $134 = ((($133)) + 16|0);
     $135 = HEAP32[$134>>2]|0;
     FUNCTION_TABLE_vi[$135 & 8191]($132);
     $136 = ((($13)) + 16|0);
     $137 = HEAP32[$136>>2]|0;
     $138 = $10;
     $139 = ((($138)) + 16|0);
     HEAP32[$139>>2] = $137;
     __THREW__ = 0;
     $140 = (invoke_ii(4073,($13|0))|0);
     $141 = __THREW__; __THREW__ = 0;
     $142 = $141&1;
     if (!($142)) {
      $143 = ((($13)) + 16|0);
      HEAP32[$143>>2] = $140;
      STACKTOP = sp;return;
     }
    }
   }
  }
 } while(0);
 $157 = ___cxa_find_matching_catch_3(0|0)|0;
 $158 = tempRet0;
 ___clang_call_terminate($157);
 // unreachable;
}
function __ZNSt3__28functionIFbdEE9__as_baseEPv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 STACKTOP = sp;return ($2|0);
}
function __ZNSt3__210__function6__funcIZN4mjin11application6memory4Game18animateMatchOrMissEbNS_8functionIFvvEEEE3__2NS_9allocatorIS9_EEFbdEED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = $0;
 $3 = $2;
 HEAP32[$3>>2] = (71516);
 $4 = ((($3)) + 8|0);
 __ZNSt3__217__compressed_pairIZN4mjin11application6memory4Game18animateMatchOrMissEbNS_8functionIFvvEEEE3__2NS_9allocatorIS8_EEED2Ev($4);
 $1 = $3;
 STACKTOP = sp;return;
}
function __ZNSt3__210__function6__funcIZN4mjin11application6memory4Game18animateMatchOrMissEbNS_8functionIFvvEEEE3__2NS_9allocatorIS9_EEFbdEED0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 __ZNSt3__210__function6__funcIZN4mjin11application6memory4Game18animateMatchOrMissEbNS_8functionIFvvEEEE3__2NS_9allocatorIS9_EEFbdEED2Ev($2);
 __ZdlPv($2);
 STACKTOP = sp;return;
}
function __ZNKSt3__210__function6__funcIZN4mjin11application6memory4Game18animateMatchOrMissEbNS_8functionIFvvEEEE3__2NS_9allocatorIS9_EEFbdEE7__cloneEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0;
 var $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0;
 var $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0;
 var $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0;
 var $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0;
 var $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0;
 var $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0;
 var $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0;
 var $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0;
 var $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0;
 var $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0;
 var $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 720|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(720|0);
 $8 = sp + 136|0;
 $9 = sp + 128|0;
 $10 = sp + 120|0;
 $11 = sp + 112|0;
 $15 = sp + 709|0;
 $16 = sp + 708|0;
 $17 = sp + 707|0;
 $18 = sp + 706|0;
 $20 = sp + 648|0;
 $28 = sp + 104|0;
 $29 = sp + 96|0;
 $30 = sp + 88|0;
 $31 = sp + 80|0;
 $34 = sp + 705|0;
 $35 = sp + 704|0;
 $36 = sp + 703|0;
 $37 = sp + 702|0;
 $39 = sp + 604|0;
 $49 = sp + 72|0;
 $50 = sp + 64|0;
 $51 = sp + 56|0;
 $52 = sp + 48|0;
 $53 = sp + 40|0;
 $56 = sp + 701|0;
 $57 = sp + 556|0;
 $58 = sp + 552|0;
 $59 = sp + 700|0;
 $60 = sp + 699|0;
 $61 = sp + 32|0;
 $62 = sp + 24|0;
 $63 = sp + 16|0;
 $69 = sp + 698|0;
 $70 = sp + 528|0;
 $71 = sp + 524|0;
 $91 = sp + 444|0;
 $92 = sp + 8|0;
 $95 = sp + 432|0;
 $96 = sp + 424|0;
 $97 = sp;
 $102 = sp + 400|0;
 $159 = sp + 697|0;
 $160 = sp + 160|0;
 $161 = sp + 152|0;
 $162 = sp + 696|0;
 $158 = $0;
 $165 = $158;
 $166 = ((($165)) + 8|0);
 $157 = $166;
 $167 = $157;
 $156 = $167;
 $168 = $156;
 $135 = $159;
 $136 = $168;
 $113 = $159;
 $114 = 1;
 $115 = 0;
 $169 = $113;
 $170 = $114;
 $112 = $169;
 $171 = ($170>>>0)>(107374182);
 if ($171) {
  $108 = 204840;
  $172 = (___cxa_allocate_exception(8)|0);
  $173 = $108;
  $106 = $172;
  $107 = $173;
  $174 = $106;
  $175 = $107;
  __THREW__ = 0;
  invoke_vii(3366,($174|0),($175|0));
  $176 = __THREW__; __THREW__ = 0;
  $177 = $176&1;
  if ($177) {
   $178 = ___cxa_find_matching_catch_2()|0;
   $179 = tempRet0;
   $109 = $178;
   $110 = $179;
   ___cxa_free_exception(($172|0));
   $180 = $109;
   $181 = $110;
   ___resumeException($180|0);
   // unreachable;
  } else {
   HEAP32[$174>>2] = (99824);
   ___cxa_throw(($172|0),(34608|0),(3230|0));
   // unreachable;
  }
 }
 $182 = $114;
 $183 = ($182*40)|0;
 $111 = $183;
 $184 = $111;
 $185 = (__Znwj($184)|0);
 $103 = $161;
 $104 = $159;
 $105 = 1;
 $186 = $103;
 $187 = $104;
 HEAP32[$186>>2] = $187;
 $188 = ((($186)) + 4|0);
 $189 = $105;
 HEAP32[$188>>2] = $189;
 $99 = $160;
 $100 = $185;
 $101 = $161;
 $190 = $99;
 $191 = $100;
 $192 = $101;
 $98 = $192;
 $193 = $98;
 ;HEAP32[$102>>2]=HEAP32[$193>>2]|0;HEAP32[$102+4>>2]=HEAP32[$193+4>>2]|0;
 ;HEAP8[$97>>0]=HEAP8[$102>>0]|0;HEAP8[$97+1>>0]=HEAP8[$102+1>>0]|0;HEAP8[$97+2>>0]=HEAP8[$102+2>>0]|0;HEAP8[$97+3>>0]=HEAP8[$102+3>>0]|0;HEAP8[$97+4>>0]=HEAP8[$102+4>>0]|0;HEAP8[$97+5>>0]=HEAP8[$102+5>>0]|0;HEAP8[$97+6>>0]=HEAP8[$102+6>>0]|0;HEAP8[$97+7>>0]=HEAP8[$102+7>>0]|0;
 $94 = $190;
 HEAP32[$95>>2] = $191;
 $194 = $94;
 $93 = $95;
 $195 = $93;
 $196 = HEAP32[$195>>2]|0;
 $87 = $97;
 $197 = $87;
 ;HEAP32[$96>>2]=HEAP32[$197>>2]|0;HEAP32[$96+4>>2]=HEAP32[$197+4>>2]|0;
 ;HEAP8[$92>>0]=HEAP8[$96>>0]|0;HEAP8[$92+1>>0]=HEAP8[$96+1>>0]|0;HEAP8[$92+2>>0]=HEAP8[$96+2>>0]|0;HEAP8[$92+3>>0]=HEAP8[$96+3>>0]|0;HEAP8[$92+4>>0]=HEAP8[$96+4>>0]|0;HEAP8[$92+5>>0]=HEAP8[$96+5>>0]|0;HEAP8[$92+6>>0]=HEAP8[$96+6>>0]|0;HEAP8[$92+7>>0]=HEAP8[$96+7>>0]|0;
 $90 = $194;
 HEAP32[$91>>2] = $196;
 $198 = $90;
 $89 = $91;
 $199 = $89;
 $200 = HEAP32[$199>>2]|0;
 HEAP32[$198>>2] = $200;
 $201 = ((($198)) + 4|0);
 $88 = $92;
 $202 = $88;
 ;HEAP32[$201>>2]=HEAP32[$202>>2]|0;HEAP32[$201+4>>2]=HEAP32[$202+4>>2]|0;
 $86 = $160;
 $203 = $86;
 $85 = $203;
 $204 = $85;
 $84 = $204;
 $205 = $84;
 $206 = HEAP32[$205>>2]|0;
 $207 = ((($165)) + 8|0);
 $83 = $207;
 $208 = $83;
 $82 = $208;
 $209 = $82;
 $80 = $162;
 $81 = $159;
 $66 = $206;
 $67 = $209;
 $68 = $162;
 $210 = $66;
 $65 = $210;
 $211 = $65;
 HEAP32[$211>>2] = (71472);
 HEAP32[$210>>2] = (71516);
 $212 = ((($210)) + 8|0);
 $213 = $67;
 $40 = $213;
 $214 = $40;
 $38 = $214;
 $215 = $38;
 $32 = $39;
 $33 = $215;
 $216 = $32;
 $217 = $33;
 ;HEAP8[$28>>0]=HEAP8[$37>>0]|0;
 ;HEAP8[$29>>0]=HEAP8[$36>>0]|0;
 ;HEAP8[$30>>0]=HEAP8[$35>>0]|0;
 ;HEAP8[$31>>0]=HEAP8[$34>>0]|0;
 $26 = $216;
 $27 = $217;
 $218 = $26;
 $219 = $27;
 $25 = $219;
 $220 = $25;
 $23 = $218;
 $24 = $220;
 $221 = $23;
 $222 = $24;
 $22 = $222;
 $223 = $22;
 HEAP32[$221>>2] = $223;
 $224 = HEAP32[$39>>2]|0;
 HEAP32[$70>>2] = $224;
 $225 = $68;
 $1 = $225;
 $226 = $1;
 $21 = $226;
 $227 = $21;
 $19 = $227;
 $228 = $19;
 $13 = $20;
 $14 = $228;
 $229 = $13;
 $230 = $14;
 $12 = $230;
 $231 = $12;
 ;HEAP8[$8>>0]=HEAP8[$18>>0]|0;
 ;HEAP8[$9>>0]=HEAP8[$17>>0]|0;
 ;HEAP8[$10>>0]=HEAP8[$16>>0]|0;
 ;HEAP8[$11>>0]=HEAP8[$15>>0]|0;
 $6 = $229;
 $7 = $231;
 $232 = $6;
 $233 = $7;
 $5 = $233;
 $234 = $5;
 $3 = $232;
 $4 = $234;
 $235 = $3;
 $236 = $4;
 $2 = $236;
 $237 = $2;
 HEAP32[$235>>2] = $237;
 $238 = HEAP32[$20>>2]|0;
 HEAP32[$71>>2] = $238;
 ;HEAP8[$61>>0]=HEAP8[$71>>0]|0;HEAP8[$61+1>>0]=HEAP8[$71+1>>0]|0;HEAP8[$61+2>>0]=HEAP8[$71+2>>0]|0;HEAP8[$61+3>>0]=HEAP8[$71+3>>0]|0;
 ;HEAP8[$62>>0]=HEAP8[$70>>0]|0;HEAP8[$62+1>>0]=HEAP8[$70+1>>0]|0;HEAP8[$62+2>>0]=HEAP8[$70+2>>0]|0;HEAP8[$62+3>>0]=HEAP8[$70+3>>0]|0;
 ;HEAP8[$63>>0]=HEAP8[$69>>0]|0;
 $55 = $212;
 $239 = $55;
 $54 = $62;
 $240 = $54;
 ;HEAP32[$57>>2]=HEAP32[$240>>2]|0;
 $41 = $61;
 $241 = $41;
 ;HEAP32[$58>>2]=HEAP32[$241>>2]|0;
 ;HEAP8[$49>>0]=HEAP8[$60>>0]|0;
 ;HEAP8[$50>>0]=HEAP8[$59>>0]|0;
 ;HEAP8[$51>>0]=HEAP8[$58>>0]|0;HEAP8[$51+1>>0]=HEAP8[$58+1>>0]|0;HEAP8[$51+2>>0]=HEAP8[$58+2>>0]|0;HEAP8[$51+3>>0]=HEAP8[$58+3>>0]|0;
 ;HEAP8[$52>>0]=HEAP8[$57>>0]|0;HEAP8[$52+1>>0]=HEAP8[$57+1>>0]|0;HEAP8[$52+2>>0]=HEAP8[$57+2>>0]|0;HEAP8[$52+3>>0]=HEAP8[$57+3>>0]|0;
 ;HEAP8[$53>>0]=HEAP8[$56>>0]|0;
 $48 = $239;
 $242 = $48;
 $47 = $51;
 $243 = $47;
 $46 = $243;
 $244 = $46;
 $245 = HEAP32[$244>>2]|0;
 $45 = $245;
 $43 = $52;
 $246 = $43;
 $42 = $246;
 $247 = $42;
 $248 = HEAP32[$247>>2]|0;
 $44 = $248;
 $249 = $44;
 __THREW__ = 0;
 invoke_vii(4074,($242|0),($249|0));
 $250 = __THREW__; __THREW__ = 0;
 $251 = $250&1;
 if ($251) {
  $252 = ___cxa_find_matching_catch_2()|0;
  $253 = tempRet0;
  $72 = $252;
  $73 = $253;
  $64 = $210;
  $254 = $72;
  $255 = $73;
  $163 = $254;
  $164 = $255;
  $155 = $160;
  $256 = $155;
  $152 = $256;
  $153 = 0;
  $257 = $152;
  $151 = $257;
  $258 = $151;
  $150 = $258;
  $259 = $150;
  $260 = HEAP32[$259>>2]|0;
  $154 = $260;
  $261 = $153;
  $140 = $257;
  $262 = $140;
  $139 = $262;
  $263 = $139;
  HEAP32[$263>>2] = $261;
  $264 = $154;
  $265 = ($264|0)!=(0|0);
  if (!($265)) {
   $311 = $163;
   $312 = $164;
   ___resumeException($311|0);
   // unreachable;
  }
  $138 = $257;
  $297 = $138;
  $137 = $297;
  $298 = $137;
  $299 = ((($298)) + 4|0);
  $300 = $154;
  $148 = $299;
  $149 = $300;
  $301 = $148;
  $302 = HEAP32[$301>>2]|0;
  $303 = $149;
  $304 = ((($301)) + 4|0);
  $305 = HEAP32[$304>>2]|0;
  $145 = $302;
  $146 = $303;
  $147 = $305;
  $306 = $145;
  $307 = $146;
  $308 = $147;
  $142 = $306;
  $143 = $307;
  $144 = $308;
  $309 = $143;
  $141 = $309;
  $310 = $141;
  __ZdlPv($310);
  $311 = $163;
  $312 = $164;
  ___resumeException($311|0);
  // unreachable;
 } else {
  $78 = $160;
  $266 = $78;
  $77 = $266;
  $267 = $77;
  $76 = $267;
  $268 = $76;
  $269 = HEAP32[$268>>2]|0;
  $79 = $269;
  $75 = $266;
  $270 = $75;
  $74 = $270;
  $271 = $74;
  HEAP32[$271>>2] = 0;
  $272 = $79;
  $134 = $160;
  $273 = $134;
  $131 = $273;
  $132 = 0;
  $274 = $131;
  $130 = $274;
  $275 = $130;
  $129 = $275;
  $276 = $129;
  $277 = HEAP32[$276>>2]|0;
  $133 = $277;
  $278 = $132;
  $119 = $274;
  $279 = $119;
  $118 = $279;
  $280 = $118;
  HEAP32[$280>>2] = $278;
  $281 = $133;
  $282 = ($281|0)!=(0|0);
  if (!($282)) {
   STACKTOP = sp;return ($272|0);
  }
  $117 = $274;
  $283 = $117;
  $116 = $283;
  $284 = $116;
  $285 = ((($284)) + 4|0);
  $286 = $133;
  $127 = $285;
  $128 = $286;
  $287 = $127;
  $288 = HEAP32[$287>>2]|0;
  $289 = $128;
  $290 = ((($287)) + 4|0);
  $291 = HEAP32[$290>>2]|0;
  $124 = $288;
  $125 = $289;
  $126 = $291;
  $292 = $124;
  $293 = $125;
  $294 = $126;
  $121 = $292;
  $122 = $293;
  $123 = $294;
  $295 = $122;
  $120 = $295;
  $296 = $120;
  __ZdlPv($296);
  STACKTOP = sp;return ($272|0);
 }
 return (0)|0;
}
function __ZNKSt3__210__function6__funcIZN4mjin11application6memory4Game18animateMatchOrMissEbNS_8functionIFvvEEEE3__2NS_9allocatorIS9_EEFbdEE7__cloneEPNS0_6__baseISC_EE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 336|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(336|0);
 $10 = sp + 120|0;
 $11 = sp + 112|0;
 $12 = sp + 104|0;
 $13 = sp + 96|0;
 $16 = sp + 331|0;
 $17 = sp + 330|0;
 $18 = sp + 329|0;
 $19 = sp + 328|0;
 $21 = sp + 272|0;
 $29 = sp + 88|0;
 $30 = sp + 80|0;
 $31 = sp + 72|0;
 $32 = sp + 64|0;
 $35 = sp + 327|0;
 $36 = sp + 326|0;
 $37 = sp + 325|0;
 $38 = sp + 324|0;
 $40 = sp + 228|0;
 $50 = sp + 56|0;
 $51 = sp + 48|0;
 $52 = sp + 40|0;
 $53 = sp + 32|0;
 $54 = sp + 24|0;
 $57 = sp + 323|0;
 $58 = sp + 180|0;
 $59 = sp + 176|0;
 $60 = sp + 322|0;
 $61 = sp + 321|0;
 $62 = sp + 16|0;
 $63 = sp + 8|0;
 $64 = sp;
 $70 = sp + 320|0;
 $71 = sp + 152|0;
 $72 = sp + 148|0;
 $77 = $0;
 $78 = $1;
 $79 = $77;
 $80 = $78;
 $81 = ((($79)) + 8|0);
 $76 = $81;
 $82 = $76;
 $75 = $82;
 $83 = $75;
 $84 = ((($79)) + 8|0);
 $3 = $84;
 $85 = $3;
 $2 = $85;
 $86 = $2;
 $67 = $80;
 $68 = $83;
 $69 = $86;
 $87 = $67;
 $66 = $87;
 $88 = $66;
 HEAP32[$88>>2] = (71472);
 HEAP32[$87>>2] = (71516);
 $89 = ((($87)) + 8|0);
 $90 = $68;
 $41 = $90;
 $91 = $41;
 $39 = $91;
 $92 = $39;
 $33 = $40;
 $34 = $92;
 $93 = $33;
 $94 = $34;
 ;HEAP8[$29>>0]=HEAP8[$38>>0]|0;
 ;HEAP8[$30>>0]=HEAP8[$37>>0]|0;
 ;HEAP8[$31>>0]=HEAP8[$36>>0]|0;
 ;HEAP8[$32>>0]=HEAP8[$35>>0]|0;
 $27 = $93;
 $28 = $94;
 $95 = $27;
 $96 = $28;
 $26 = $96;
 $97 = $26;
 $24 = $95;
 $25 = $97;
 $98 = $24;
 $99 = $25;
 $23 = $99;
 $100 = $23;
 HEAP32[$98>>2] = $100;
 $101 = HEAP32[$40>>2]|0;
 HEAP32[$71>>2] = $101;
 $102 = $69;
 $22 = $102;
 $103 = $22;
 $20 = $103;
 $104 = $20;
 $14 = $21;
 $15 = $104;
 $105 = $14;
 $106 = $15;
 ;HEAP8[$10>>0]=HEAP8[$19>>0]|0;
 ;HEAP8[$11>>0]=HEAP8[$18>>0]|0;
 ;HEAP8[$12>>0]=HEAP8[$17>>0]|0;
 ;HEAP8[$13>>0]=HEAP8[$16>>0]|0;
 $8 = $105;
 $9 = $106;
 $107 = $8;
 $108 = $9;
 $7 = $108;
 $109 = $7;
 $5 = $107;
 $6 = $109;
 $110 = $5;
 $111 = $6;
 $4 = $111;
 $112 = $4;
 HEAP32[$110>>2] = $112;
 $113 = HEAP32[$21>>2]|0;
 HEAP32[$72>>2] = $113;
 ;HEAP8[$62>>0]=HEAP8[$72>>0]|0;HEAP8[$62+1>>0]=HEAP8[$72+1>>0]|0;HEAP8[$62+2>>0]=HEAP8[$72+2>>0]|0;HEAP8[$62+3>>0]=HEAP8[$72+3>>0]|0;
 ;HEAP8[$63>>0]=HEAP8[$71>>0]|0;HEAP8[$63+1>>0]=HEAP8[$71+1>>0]|0;HEAP8[$63+2>>0]=HEAP8[$71+2>>0]|0;HEAP8[$63+3>>0]=HEAP8[$71+3>>0]|0;
 ;HEAP8[$64>>0]=HEAP8[$70>>0]|0;
 $56 = $89;
 $114 = $56;
 $55 = $63;
 $115 = $55;
 ;HEAP32[$58>>2]=HEAP32[$115>>2]|0;
 $42 = $62;
 $116 = $42;
 ;HEAP32[$59>>2]=HEAP32[$116>>2]|0;
 ;HEAP8[$50>>0]=HEAP8[$61>>0]|0;
 ;HEAP8[$51>>0]=HEAP8[$60>>0]|0;
 ;HEAP8[$52>>0]=HEAP8[$59>>0]|0;HEAP8[$52+1>>0]=HEAP8[$59+1>>0]|0;HEAP8[$52+2>>0]=HEAP8[$59+2>>0]|0;HEAP8[$52+3>>0]=HEAP8[$59+3>>0]|0;
 ;HEAP8[$53>>0]=HEAP8[$58>>0]|0;HEAP8[$53+1>>0]=HEAP8[$58+1>>0]|0;HEAP8[$53+2>>0]=HEAP8[$58+2>>0]|0;HEAP8[$53+3>>0]=HEAP8[$58+3>>0]|0;
 ;HEAP8[$54>>0]=HEAP8[$57>>0]|0;
 $49 = $114;
 $117 = $49;
 $48 = $52;
 $118 = $48;
 $47 = $118;
 $119 = $47;
 $120 = HEAP32[$119>>2]|0;
 $46 = $120;
 $44 = $53;
 $121 = $44;
 $43 = $121;
 $122 = $43;
 $123 = HEAP32[$122>>2]|0;
 $45 = $123;
 $124 = $45;
 __THREW__ = 0;
 invoke_vii(4074,($117|0),($124|0));
 $125 = __THREW__; __THREW__ = 0;
 $126 = $125&1;
 if ($126) {
  $127 = ___cxa_find_matching_catch_2()|0;
  $128 = tempRet0;
  $73 = $127;
  $74 = $128;
  $65 = $87;
  $129 = $73;
  $130 = $74;
  ___resumeException($129|0);
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__210__function6__funcIZN4mjin11application6memory4Game18animateMatchOrMissEbNS_8functionIFvvEEEE3__2NS_9allocatorIS9_EEFbdEE7destroyEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 $3 = ((($2)) + 8|0);
 __ZNSt3__217__compressed_pairIZN4mjin11application6memory4Game18animateMatchOrMissEbNS_8functionIFvvEEEE3__2NS_9allocatorIS8_EEED2Ev($3);
 STACKTOP = sp;return;
}
function __ZNSt3__210__function6__funcIZN4mjin11application6memory4Game18animateMatchOrMissEbNS_8functionIFvvEEEE3__2NS_9allocatorIS9_EEFbdEE18destroy_deallocateEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $10 = sp + 36|0;
 $9 = $0;
 $11 = $9;
 $12 = ((($11)) + 8|0);
 $8 = $12;
 $13 = $8;
 $7 = $13;
 $14 = $7;
 $1 = $10;
 $2 = $14;
 $15 = ((($11)) + 8|0);
 __ZNSt3__217__compressed_pairIZN4mjin11application6memory4Game18animateMatchOrMissEbNS_8functionIFvvEEEE3__2NS_9allocatorIS8_EEED2Ev($15);
 $4 = $10;
 $5 = $11;
 $6 = 1;
 $16 = $5;
 $3 = $16;
 $17 = $3;
 __ZdlPv($17);
 STACKTOP = sp;return;
}
function __ZNSt3__210__function6__funcIZN4mjin11application6memory4Game18animateMatchOrMissEbNS_8functionIFvvEEEE3__2NS_9allocatorIS9_EEFbdEEclEOd($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $5 = $0;
 $6 = $1;
 $7 = $5;
 $8 = ((($7)) + 8|0);
 $4 = $8;
 $9 = $4;
 $3 = $9;
 $10 = $3;
 $11 = $6;
 $2 = $11;
 $12 = $2;
 $13 = (__ZNSt3__228__invoke_void_return_wrapperIbE6__callIJRZN4mjin11application6memory4Game18animateMatchOrMissEbNS_8functionIFvvEEEE3__2dEEEbDpOT_($10,$12)|0);
 STACKTOP = sp;return ($13|0);
}
function __ZNKSt3__210__function6__funcIZN4mjin11application6memory4Game18animateMatchOrMissEbNS_8functionIFvvEEEE3__2NS_9allocatorIS9_EEFbdEE6targetERKSt9type_info($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $7 = $0;
 $8 = $1;
 $9 = $7;
 $10 = $8;
 $4 = $10;
 $5 = 27376;
 $11 = $4;
 $12 = ((($11)) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $5;
 $15 = ((($14)) + 4|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($13|0)==($16|0);
 if ($17) {
  $18 = ((($9)) + 8|0);
  $3 = $18;
  $19 = $3;
  $2 = $19;
  $20 = $2;
  $6 = $20;
  $21 = $6;
  STACKTOP = sp;return ($21|0);
 } else {
  $6 = 0;
  $21 = $6;
  STACKTOP = sp;return ($21|0);
 }
 return (0)|0;
}
function __ZNKSt3__210__function6__funcIZN4mjin11application6memory4Game18animateMatchOrMissEbNS_8functionIFvvEEEE3__2NS_9allocatorIS9_EEFbdEE11target_typeEv($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 STACKTOP = sp;return (27376|0);
}
function __ZNSt3__228__invoke_void_return_wrapperIbE6__callIJRZN4mjin11application6memory4Game18animateMatchOrMissEbNS_8functionIFvvEEEE3__2dEEEbDpOT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0.0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $8 = $0;
 $9 = $1;
 $10 = $8;
 $7 = $10;
 $11 = $7;
 $12 = $9;
 $2 = $12;
 $13 = $2;
 $5 = $11;
 $6 = $13;
 $14 = $5;
 $4 = $14;
 $15 = $4;
 $16 = $6;
 $3 = $16;
 $17 = $3;
 $18 = +HEAPF64[$17>>3];
 $19 = (__ZZN4mjin11application6memory4Game18animateMatchOrMissEbNSt3__28functionIFvvEEEENK3__2clEd($15,$18)|0);
 STACKTOP = sp;return ($19|0);
}
function __ZZN4mjin11application6memory4Game18animateMatchOrMissEbNSt3__28functionIFvvEEEENK3__2clEd($0,$1) {
 $0 = $0|0;
 $1 = +$1;
 var $$expand_i1_val = 0, $$expand_i1_val2 = 0, $$pre_trunc = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0.0, $2 = 0, $20 = 0, $21 = 0.0, $22 = 0.0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0.0, $27 = 0.0, $28 = 0.0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0, $7 = 0.0;
 var $8 = 0.0, $9 = 0.0, $_ZN4mjin11application6memoryL11COLOR_MATCHE$_ZN4mjin11application6memoryL10COLOR_MISSE = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(112|0);
 $5 = sp + 104|0;
 $10 = sp + 72|0;
 $11 = sp + 56|0;
 $12 = sp + 40|0;
 $13 = sp + 24|0;
 $6 = $0;
 $7 = $1;
 $14 = $6;
 $15 = ((($14)) + 4|0);
 $16 = HEAP32[$15>>2]|0;
 $8 = 0.29999999999999999;
 $9 = 0.59999999999999998;
 $17 = HEAP8[$14>>0]|0;
 $18 = $17&1;
 $_ZN4mjin11application6memoryL11COLOR_MATCHE$_ZN4mjin11application6memoryL10COLOR_MISSE = $18 ? 208940 : 208924;
 ;HEAP32[$10>>2]=HEAP32[$_ZN4mjin11application6memoryL11COLOR_MATCHE$_ZN4mjin11application6memoryL10COLOR_MISSE>>2]|0;HEAP32[$10+4>>2]=HEAP32[$_ZN4mjin11application6memoryL11COLOR_MATCHE$_ZN4mjin11application6memoryL10COLOR_MISSE+4>>2]|0;HEAP32[$10+8>>2]=HEAP32[$_ZN4mjin11application6memoryL11COLOR_MATCHE$_ZN4mjin11application6memoryL10COLOR_MISSE+8>>2]|0;HEAP32[$10+12>>2]=HEAP32[$_ZN4mjin11application6memoryL11COLOR_MATCHE$_ZN4mjin11application6memoryL10COLOR_MISSE+12>>2]|0;
 __ZNK3osg5Vec4fmiERKS0_($11,$10,208956);
 $19 = $7;
 $20 = $19 < 0.29999999999999999;
 $21 = $7;
 do {
  if ($20) {
   $22 = $21;
   (__ZN3osg5Vec4fmLEf($11,$22)|0);
   $23 = ((($16)) + 28|0);
   $24 = HEAP32[$23>>2]|0;
   __ZNK3osg5Vec4fplERKS0_($12,208956,$11);
   __ZN3osg6Camera13setClearColorERKNS_5Vec4fE($24,$12);
  } else {
   $25 = $21 < 0.59999999999999998;
   if ($25) {
    $26 = $7;
    $27 = 0.59999999999999998 - $26;
    $28 = $27;
    (__ZN3osg5Vec4fmLEf($11,$28)|0);
    $29 = ((($16)) + 28|0);
    $30 = HEAP32[$29>>2]|0;
    __ZNK3osg5Vec4fplERKS0_($13,208956,$11);
    __ZN3osg6Camera13setClearColorERKNS_5Vec4fE($30,$13);
    break;
   }
   $31 = ((($16)) + 28|0);
   $32 = HEAP32[$31>>2]|0;
   __ZN3osg6Camera13setClearColorERKNS_5Vec4fE($32,208956);
   $33 = ((($14)) + 8|0);
   $3 = $33;
   $4 = 0;
   $34 = $3;
   $2 = $34;
   $35 = $2;
   $36 = ((($35)) + 16|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = ($37|0)!=(0|0);
   if ($38) {
    $39 = ((($14)) + 8|0);
    __ZNKSt3__28functionIFvvEEclEv($39);
   }
   $$expand_i1_val = 0;
   HEAP8[$5>>0] = $$expand_i1_val;
   $$pre_trunc = HEAP8[$5>>0]|0;
   $40 = $$pre_trunc&1;
   STACKTOP = sp;return ($40|0);
  }
 } while(0);
 $$expand_i1_val2 = 1;
 HEAP8[$5>>0] = $$expand_i1_val2;
 $$pre_trunc = HEAP8[$5>>0]|0;
 $40 = $$pre_trunc&1;
 STACKTOP = sp;return ($40|0);
}
function __ZNK3osg5Vec4fmiERKS0_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0.0, $12 = 0, $13 = 0, $14 = 0.0, $15 = 0.0, $16 = 0, $17 = 0.0, $18 = 0, $19 = 0, $20 = 0.0, $21 = 0.0, $22 = 0, $23 = 0.0, $24 = 0, $25 = 0, $26 = 0.0, $27 = 0.0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0.0, $7 = 0, $8 = 0.0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = $1;
 $4 = $2;
 $5 = $3;
 $6 = +HEAPF32[$5>>2];
 $7 = $4;
 $8 = +HEAPF32[$7>>2];
 $9 = $6 - $8;
 $10 = ((($5)) + 4|0);
 $11 = +HEAPF32[$10>>2];
 $12 = $4;
 $13 = ((($12)) + 4|0);
 $14 = +HEAPF32[$13>>2];
 $15 = $11 - $14;
 $16 = ((($5)) + 8|0);
 $17 = +HEAPF32[$16>>2];
 $18 = $4;
 $19 = ((($18)) + 8|0);
 $20 = +HEAPF32[$19>>2];
 $21 = $17 - $20;
 $22 = ((($5)) + 12|0);
 $23 = +HEAPF32[$22>>2];
 $24 = $4;
 $25 = ((($24)) + 12|0);
 $26 = +HEAPF32[$25>>2];
 $27 = $23 - $26;
 __ZN3osg5Vec4fC2Effff($0,$9,$15,$21,$27);
 STACKTOP = sp;return;
}
function __ZN3osg5Vec4fmLEf($0,$1) {
 $0 = $0|0;
 $1 = +$1;
 var $10 = 0.0, $11 = 0.0, $12 = 0.0, $13 = 0, $14 = 0.0, $15 = 0.0, $16 = 0.0, $17 = 0, $18 = 0.0, $19 = 0.0, $2 = 0, $3 = 0.0, $4 = 0, $5 = 0.0, $6 = 0.0, $7 = 0.0, $8 = 0.0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = $0;
 $3 = $1;
 $4 = $2;
 $5 = $3;
 $6 = +HEAPF32[$4>>2];
 $7 = $6 * $5;
 HEAPF32[$4>>2] = $7;
 $8 = $3;
 $9 = ((($4)) + 4|0);
 $10 = +HEAPF32[$9>>2];
 $11 = $10 * $8;
 HEAPF32[$9>>2] = $11;
 $12 = $3;
 $13 = ((($4)) + 8|0);
 $14 = +HEAPF32[$13>>2];
 $15 = $14 * $12;
 HEAPF32[$13>>2] = $15;
 $16 = $3;
 $17 = ((($4)) + 12|0);
 $18 = +HEAPF32[$17>>2];
 $19 = $18 * $16;
 HEAPF32[$17>>2] = $19;
 STACKTOP = sp;return ($4|0);
}
function __ZNK3osg5Vec4fplERKS0_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0.0, $12 = 0, $13 = 0, $14 = 0.0, $15 = 0.0, $16 = 0, $17 = 0.0, $18 = 0, $19 = 0, $20 = 0.0, $21 = 0.0, $22 = 0, $23 = 0.0, $24 = 0, $25 = 0, $26 = 0.0, $27 = 0.0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0.0, $7 = 0, $8 = 0.0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = $1;
 $4 = $2;
 $5 = $3;
 $6 = +HEAPF32[$5>>2];
 $7 = $4;
 $8 = +HEAPF32[$7>>2];
 $9 = $6 + $8;
 $10 = ((($5)) + 4|0);
 $11 = +HEAPF32[$10>>2];
 $12 = $4;
 $13 = ((($12)) + 4|0);
 $14 = +HEAPF32[$13>>2];
 $15 = $11 + $14;
 $16 = ((($5)) + 8|0);
 $17 = +HEAPF32[$16>>2];
 $18 = $4;
 $19 = ((($18)) + 8|0);
 $20 = +HEAPF32[$19>>2];
 $21 = $17 + $20;
 $22 = ((($5)) + 12|0);
 $23 = +HEAPF32[$22>>2];
 $24 = $4;
 $25 = ((($24)) + 12|0);
 $26 = +HEAPF32[$25>>2];
 $27 = $23 + $26;
 __ZN3osg5Vec4fC2Effff($0,$9,$15,$21,$27);
 STACKTOP = sp;return;
}
function __ZNKSt3__28functionIFvvEEclEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 $3 = ((($2)) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  $6 = (___cxa_allocate_exception(4)|0);
  ;HEAP32[$6>>2]=0|0;
  __ZNSt3__217bad_function_callC2Ev($6);
  ___cxa_throw(($6|0),(27280|0),(2510|0));
  // unreachable;
 } else {
  $7 = ((($2)) + 16|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = HEAP32[$8>>2]|0;
  $10 = ((($9)) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  FUNCTION_TABLE_vi[$11 & 8191]($8);
  STACKTOP = sp;return;
 }
}
function __ZNSt3__217__compressed_pairIZN4mjin11application6memory4Game18animateMatchOrMissEbNS_8functionIFvvEEEE3__2NS_9allocatorIS8_EEED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 __ZNSt3__228__libcpp_compressed_pair_impIZN4mjin11application6memory4Game18animateMatchOrMissEbNS_8functionIFvvEEEE3__2NS_9allocatorIS8_EELj2EED2Ev($2);
 STACKTOP = sp;return;
}
function __ZNSt3__228__libcpp_compressed_pair_impIZN4mjin11application6memory4Game18animateMatchOrMissEbNS_8functionIFvvEEEE3__2NS_9allocatorIS8_EELj2EED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 __ZZN4mjin11application6memory4Game18animateMatchOrMissEbNSt3__28functionIFvvEEEEN3__2D2Ev($2);
 STACKTOP = sp;return;
}
function __ZZN4mjin11application6memory4Game18animateMatchOrMissEbNSt3__28functionIFvvEEEEN3__2C2ERKS7_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = $0;
 $3 = $1;
 $4 = $2;
 $5 = $3;
 ;HEAP32[$4>>2]=HEAP32[$5>>2]|0;HEAP32[$4+4>>2]=HEAP32[$5+4>>2]|0;
 $6 = ((($4)) + 8|0);
 $7 = $3;
 $8 = ((($7)) + 8|0);
 __ZNSt3__28functionIFvvEEC2ERKS2_($6,$8);
 STACKTOP = sp;return;
}
function __ZNSt3__210__function6__baseIFbdEED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 STACKTOP = sp;return;
}
function __ZNSt3__210__function6__baseIFbdEED0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = $0;
 $3 = $2;
 $1 = $3;
 __ZdlPv($3);
 STACKTOP = sp;return;
}
function __ZNSt3__28functionIFvvEEC2EOS2_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$sink1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = $0;
 $3 = $1;
 $4 = $2;
 $5 = $3;
 $6 = ((($5)) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 do {
  if ($8) {
   $$sink1 = $4;
  } else {
   $9 = $3;
   $10 = ((($9)) + 16|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = $3;
   $13 = ($11|0)==($12|0);
   if (!($13)) {
    $28 = $3;
    $29 = ((($28)) + 16|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = ((($4)) + 16|0);
    HEAP32[$31>>2] = $30;
    $32 = $3;
    $$sink1 = $32;
    break;
   }
   __THREW__ = 0;
   $14 = (invoke_ii(4075,($4|0))|0);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if ($16) {
    $34 = ___cxa_find_matching_catch_3(0|0)|0;
    $35 = tempRet0;
    ___clang_call_terminate($34);
    // unreachable;
   }
   $17 = ((($4)) + 16|0);
   HEAP32[$17>>2] = $14;
   $18 = $3;
   $19 = ((($18)) + 16|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = HEAP32[$20>>2]|0;
   $22 = ((($21)) + 12|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = ((($4)) + 16|0);
   $25 = HEAP32[$24>>2]|0;
   __THREW__ = 0;
   invoke_vii($23|0,($20|0),($25|0));
   $26 = __THREW__; __THREW__ = 0;
   $27 = $26&1;
   if ($27) {
    $34 = ___cxa_find_matching_catch_3(0|0)|0;
    $35 = tempRet0;
    ___clang_call_terminate($34);
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $33 = ((($$sink1)) + 16|0);
 HEAP32[$33>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNSt3__28functionIFvvEE9__as_baseEPv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 STACKTOP = sp;return ($2|0);
}
function __ZZN4mjin11application6memory4Game18matchSelectedItemsEvEN3__0C2EOS3_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(128|0);
 $6 = sp + 104|0;
 $7 = sp + 8|0;
 $10 = sp + 92|0;
 $11 = sp + 125|0;
 $12 = sp;
 $16 = sp + 124|0;
 $32 = $0;
 $33 = $1;
 $34 = $32;
 $35 = $33;
 $36 = HEAP32[$35>>2]|0;
 HEAP32[$34>>2] = $36;
 $37 = ((($34)) + 4|0);
 $38 = $33;
 $39 = ((($38)) + 4|0);
 $30 = $37;
 $31 = $39;
 $40 = $30;
 $41 = $31;
 $29 = $41;
 $42 = $29;
 $43 = ((($42)) + 8|0);
 $28 = $43;
 $44 = $28;
 $27 = $44;
 $45 = $27;
 $26 = $45;
 $46 = $26;
 $14 = $40;
 $15 = $46;
 $47 = $14;
 $13 = $47;
 HEAP32[$47>>2] = 0;
 $48 = ((($47)) + 4|0);
 HEAP32[$48>>2] = 0;
 $49 = ((($47)) + 8|0);
 ;HEAP8[$12>>0]=HEAP8[$16>>0]|0;
 $9 = $49;
 HEAP32[$10>>2] = 0;
 $50 = $9;
 $8 = $10;
 $51 = $8;
 $52 = HEAP32[$51>>2]|0;
 $2 = $12;
 ;HEAP8[$7>>0]=HEAP8[$11>>0]|0;
 $5 = $50;
 HEAP32[$6>>2] = $52;
 $53 = $5;
 $4 = $7;
 $3 = $6;
 $54 = $3;
 $55 = HEAP32[$54>>2]|0;
 HEAP32[$53>>2] = $55;
 $56 = $31;
 $57 = HEAP32[$56>>2]|0;
 HEAP32[$40>>2] = $57;
 $58 = $31;
 $59 = ((($58)) + 4|0);
 $60 = HEAP32[$59>>2]|0;
 $61 = ((($40)) + 4|0);
 HEAP32[$61>>2] = $60;
 $62 = $31;
 $19 = $62;
 $63 = $19;
 $64 = ((($63)) + 8|0);
 $18 = $64;
 $65 = $18;
 $17 = $65;
 $66 = $17;
 $67 = HEAP32[$66>>2]|0;
 $22 = $40;
 $68 = $22;
 $69 = ((($68)) + 8|0);
 $21 = $69;
 $70 = $21;
 $20 = $70;
 $71 = $20;
 HEAP32[$71>>2] = $67;
 $72 = $31;
 $25 = $72;
 $73 = $25;
 $74 = ((($73)) + 8|0);
 $24 = $74;
 $75 = $24;
 $23 = $75;
 $76 = $23;
 HEAP32[$76>>2] = 0;
 $77 = $31;
 $78 = ((($77)) + 4|0);
 HEAP32[$78>>2] = 0;
 $79 = $31;
 HEAP32[$79>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNSt3__210__function6__funcIZN4mjin11application6memory4Game18matchSelectedItemsEvE3__0NS_9allocatorIS6_EEFvvEED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = $0;
 $3 = $2;
 HEAP32[$3>>2] = (71560);
 $4 = ((($3)) + 4|0);
 __ZNSt3__217__compressed_pairIZN4mjin11application6memory4Game18matchSelectedItemsEvE3__0NS_9allocatorIS5_EEED2Ev($4);
 $1 = $3;
 STACKTOP = sp;return;
}
function __ZNSt3__210__function6__funcIZN4mjin11application6memory4Game18matchSelectedItemsEvE3__0NS_9allocatorIS6_EEFvvEED0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 __ZNSt3__210__function6__funcIZN4mjin11application6memory4Game18matchSelectedItemsEvE3__0NS_9allocatorIS6_EEFvvEED2Ev($2);
 __ZdlPv($2);
 STACKTOP = sp;return;
}
function __ZNKSt3__210__function6__funcIZN4mjin11application6memory4Game18matchSelectedItemsEvE3__0NS_9allocatorIS6_EEFvvEE7__cloneEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0;
 var $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0;
 var $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0;
 var $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0;
 var $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0;
 var $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0;
 var $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0;
 var $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0;
 var $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0;
 var $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0;
 var $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0;
 var $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 720|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(720|0);
 $8 = sp + 136|0;
 $9 = sp + 128|0;
 $10 = sp + 120|0;
 $11 = sp + 112|0;
 $15 = sp + 709|0;
 $16 = sp + 708|0;
 $17 = sp + 707|0;
 $18 = sp + 706|0;
 $20 = sp + 648|0;
 $28 = sp + 104|0;
 $29 = sp + 96|0;
 $30 = sp + 88|0;
 $31 = sp + 80|0;
 $34 = sp + 705|0;
 $35 = sp + 704|0;
 $36 = sp + 703|0;
 $37 = sp + 702|0;
 $39 = sp + 604|0;
 $49 = sp + 72|0;
 $50 = sp + 64|0;
 $51 = sp + 56|0;
 $52 = sp + 48|0;
 $53 = sp + 40|0;
 $56 = sp + 701|0;
 $57 = sp + 556|0;
 $58 = sp + 552|0;
 $59 = sp + 700|0;
 $60 = sp + 699|0;
 $61 = sp + 32|0;
 $62 = sp + 24|0;
 $63 = sp + 16|0;
 $69 = sp + 698|0;
 $70 = sp + 528|0;
 $71 = sp + 524|0;
 $91 = sp + 444|0;
 $92 = sp + 8|0;
 $95 = sp + 432|0;
 $96 = sp + 424|0;
 $97 = sp;
 $102 = sp + 400|0;
 $159 = sp + 697|0;
 $160 = sp + 160|0;
 $161 = sp + 152|0;
 $162 = sp + 696|0;
 $158 = $0;
 $165 = $158;
 $166 = ((($165)) + 4|0);
 $157 = $166;
 $167 = $157;
 $156 = $167;
 $168 = $156;
 $135 = $159;
 $136 = $168;
 $113 = $159;
 $114 = 1;
 $115 = 0;
 $169 = $113;
 $170 = $114;
 $112 = $169;
 $171 = ($170>>>0)>(214748364);
 if ($171) {
  $108 = 204840;
  $172 = (___cxa_allocate_exception(8)|0);
  $173 = $108;
  $106 = $172;
  $107 = $173;
  $174 = $106;
  $175 = $107;
  __THREW__ = 0;
  invoke_vii(3366,($174|0),($175|0));
  $176 = __THREW__; __THREW__ = 0;
  $177 = $176&1;
  if ($177) {
   $178 = ___cxa_find_matching_catch_2()|0;
   $179 = tempRet0;
   $109 = $178;
   $110 = $179;
   ___cxa_free_exception(($172|0));
   $180 = $109;
   $181 = $110;
   ___resumeException($180|0);
   // unreachable;
  } else {
   HEAP32[$174>>2] = (99824);
   ___cxa_throw(($172|0),(34608|0),(3230|0));
   // unreachable;
  }
 }
 $182 = $114;
 $183 = ($182*20)|0;
 $111 = $183;
 $184 = $111;
 $185 = (__Znwj($184)|0);
 $103 = $161;
 $104 = $159;
 $105 = 1;
 $186 = $103;
 $187 = $104;
 HEAP32[$186>>2] = $187;
 $188 = ((($186)) + 4|0);
 $189 = $105;
 HEAP32[$188>>2] = $189;
 $99 = $160;
 $100 = $185;
 $101 = $161;
 $190 = $99;
 $191 = $100;
 $192 = $101;
 $98 = $192;
 $193 = $98;
 ;HEAP32[$102>>2]=HEAP32[$193>>2]|0;HEAP32[$102+4>>2]=HEAP32[$193+4>>2]|0;
 ;HEAP8[$97>>0]=HEAP8[$102>>0]|0;HEAP8[$97+1>>0]=HEAP8[$102+1>>0]|0;HEAP8[$97+2>>0]=HEAP8[$102+2>>0]|0;HEAP8[$97+3>>0]=HEAP8[$102+3>>0]|0;HEAP8[$97+4>>0]=HEAP8[$102+4>>0]|0;HEAP8[$97+5>>0]=HEAP8[$102+5>>0]|0;HEAP8[$97+6>>0]=HEAP8[$102+6>>0]|0;HEAP8[$97+7>>0]=HEAP8[$102+7>>0]|0;
 $94 = $190;
 HEAP32[$95>>2] = $191;
 $194 = $94;
 $93 = $95;
 $195 = $93;
 $196 = HEAP32[$195>>2]|0;
 $87 = $97;
 $197 = $87;
 ;HEAP32[$96>>2]=HEAP32[$197>>2]|0;HEAP32[$96+4>>2]=HEAP32[$197+4>>2]|0;
 ;HEAP8[$92>>0]=HEAP8[$96>>0]|0;HEAP8[$92+1>>0]=HEAP8[$96+1>>0]|0;HEAP8[$92+2>>0]=HEAP8[$96+2>>0]|0;HEAP8[$92+3>>0]=HEAP8[$96+3>>0]|0;HEAP8[$92+4>>0]=HEAP8[$96+4>>0]|0;HEAP8[$92+5>>0]=HEAP8[$96+5>>0]|0;HEAP8[$92+6>>0]=HEAP8[$96+6>>0]|0;HEAP8[$92+7>>0]=HEAP8[$96+7>>0]|0;
 $90 = $194;
 HEAP32[$91>>2] = $196;
 $198 = $90;
 $89 = $91;
 $199 = $89;
 $200 = HEAP32[$199>>2]|0;
 HEAP32[$198>>2] = $200;
 $201 = ((($198)) + 4|0);
 $88 = $92;
 $202 = $88;
 ;HEAP32[$201>>2]=HEAP32[$202>>2]|0;HEAP32[$201+4>>2]=HEAP32[$202+4>>2]|0;
 $86 = $160;
 $203 = $86;
 $85 = $203;
 $204 = $85;
 $84 = $204;
 $205 = $84;
 $206 = HEAP32[$205>>2]|0;
 $207 = ((($165)) + 4|0);
 $83 = $207;
 $208 = $83;
 $82 = $208;
 $209 = $82;
 $80 = $162;
 $81 = $159;
 $66 = $206;
 $67 = $209;
 $68 = $162;
 $210 = $66;
 $65 = $210;
 $211 = $65;
 HEAP32[$211>>2] = (71384);
 HEAP32[$210>>2] = (71560);
 $212 = ((($210)) + 4|0);
 $213 = $67;
 $40 = $213;
 $214 = $40;
 $38 = $214;
 $215 = $38;
 $32 = $39;
 $33 = $215;
 $216 = $32;
 $217 = $33;
 ;HEAP8[$28>>0]=HEAP8[$37>>0]|0;
 ;HEAP8[$29>>0]=HEAP8[$36>>0]|0;
 ;HEAP8[$30>>0]=HEAP8[$35>>0]|0;
 ;HEAP8[$31>>0]=HEAP8[$34>>0]|0;
 $26 = $216;
 $27 = $217;
 $218 = $26;
 $219 = $27;
 $25 = $219;
 $220 = $25;
 $23 = $218;
 $24 = $220;
 $221 = $23;
 $222 = $24;
 $22 = $222;
 $223 = $22;
 HEAP32[$221>>2] = $223;
 $224 = HEAP32[$39>>2]|0;
 HEAP32[$70>>2] = $224;
 $225 = $68;
 $1 = $225;
 $226 = $1;
 $21 = $226;
 $227 = $21;
 $19 = $227;
 $228 = $19;
 $13 = $20;
 $14 = $228;
 $229 = $13;
 $230 = $14;
 $12 = $230;
 $231 = $12;
 ;HEAP8[$8>>0]=HEAP8[$18>>0]|0;
 ;HEAP8[$9>>0]=HEAP8[$17>>0]|0;
 ;HEAP8[$10>>0]=HEAP8[$16>>0]|0;
 ;HEAP8[$11>>0]=HEAP8[$15>>0]|0;
 $6 = $229;
 $7 = $231;
 $232 = $6;
 $233 = $7;
 $5 = $233;
 $234 = $5;
 $3 = $232;
 $4 = $234;
 $235 = $3;
 $236 = $4;
 $2 = $236;
 $237 = $2;
 HEAP32[$235>>2] = $237;
 $238 = HEAP32[$20>>2]|0;
 HEAP32[$71>>2] = $238;
 ;HEAP8[$61>>0]=HEAP8[$71>>0]|0;HEAP8[$61+1>>0]=HEAP8[$71+1>>0]|0;HEAP8[$61+2>>0]=HEAP8[$71+2>>0]|0;HEAP8[$61+3>>0]=HEAP8[$71+3>>0]|0;
 ;HEAP8[$62>>0]=HEAP8[$70>>0]|0;HEAP8[$62+1>>0]=HEAP8[$70+1>>0]|0;HEAP8[$62+2>>0]=HEAP8[$70+2>>0]|0;HEAP8[$62+3>>0]=HEAP8[$70+3>>0]|0;
 ;HEAP8[$63>>0]=HEAP8[$69>>0]|0;
 $55 = $212;
 $239 = $55;
 $54 = $62;
 $240 = $54;
 ;HEAP32[$57>>2]=HEAP32[$240>>2]|0;
 $41 = $61;
 $241 = $41;
 ;HEAP32[$58>>2]=HEAP32[$241>>2]|0;
 ;HEAP8[$49>>0]=HEAP8[$60>>0]|0;
 ;HEAP8[$50>>0]=HEAP8[$59>>0]|0;
 ;HEAP8[$51>>0]=HEAP8[$58>>0]|0;HEAP8[$51+1>>0]=HEAP8[$58+1>>0]|0;HEAP8[$51+2>>0]=HEAP8[$58+2>>0]|0;HEAP8[$51+3>>0]=HEAP8[$58+3>>0]|0;
 ;HEAP8[$52>>0]=HEAP8[$57>>0]|0;HEAP8[$52+1>>0]=HEAP8[$57+1>>0]|0;HEAP8[$52+2>>0]=HEAP8[$57+2>>0]|0;HEAP8[$52+3>>0]=HEAP8[$57+3>>0]|0;
 ;HEAP8[$53>>0]=HEAP8[$56>>0]|0;
 $48 = $239;
 $242 = $48;
 $47 = $51;
 $243 = $47;
 $46 = $243;
 $244 = $46;
 $245 = HEAP32[$244>>2]|0;
 $45 = $245;
 $43 = $52;
 $246 = $43;
 $42 = $246;
 $247 = $42;
 $248 = HEAP32[$247>>2]|0;
 $44 = $248;
 $249 = $44;
 __THREW__ = 0;
 invoke_vii(4076,($242|0),($249|0));
 $250 = __THREW__; __THREW__ = 0;
 $251 = $250&1;
 if ($251) {
  $252 = ___cxa_find_matching_catch_2()|0;
  $253 = tempRet0;
  $72 = $252;
  $73 = $253;
  $64 = $210;
  $254 = $72;
  $255 = $73;
  $163 = $254;
  $164 = $255;
  $155 = $160;
  $256 = $155;
  $152 = $256;
  $153 = 0;
  $257 = $152;
  $151 = $257;
  $258 = $151;
  $150 = $258;
  $259 = $150;
  $260 = HEAP32[$259>>2]|0;
  $154 = $260;
  $261 = $153;
  $140 = $257;
  $262 = $140;
  $139 = $262;
  $263 = $139;
  HEAP32[$263>>2] = $261;
  $264 = $154;
  $265 = ($264|0)!=(0|0);
  if (!($265)) {
   $311 = $163;
   $312 = $164;
   ___resumeException($311|0);
   // unreachable;
  }
  $138 = $257;
  $297 = $138;
  $137 = $297;
  $298 = $137;
  $299 = ((($298)) + 4|0);
  $300 = $154;
  $148 = $299;
  $149 = $300;
  $301 = $148;
  $302 = HEAP32[$301>>2]|0;
  $303 = $149;
  $304 = ((($301)) + 4|0);
  $305 = HEAP32[$304>>2]|0;
  $145 = $302;
  $146 = $303;
  $147 = $305;
  $306 = $145;
  $307 = $146;
  $308 = $147;
  $142 = $306;
  $143 = $307;
  $144 = $308;
  $309 = $143;
  $141 = $309;
  $310 = $141;
  __ZdlPv($310);
  $311 = $163;
  $312 = $164;
  ___resumeException($311|0);
  // unreachable;
 } else {
  $78 = $160;
  $266 = $78;
  $77 = $266;
  $267 = $77;
  $76 = $267;
  $268 = $76;
  $269 = HEAP32[$268>>2]|0;
  $79 = $269;
  $75 = $266;
  $270 = $75;
  $74 = $270;
  $271 = $74;
  HEAP32[$271>>2] = 0;
  $272 = $79;
  $134 = $160;
  $273 = $134;
  $131 = $273;
  $132 = 0;
  $274 = $131;
  $130 = $274;
  $275 = $130;
  $129 = $275;
  $276 = $129;
  $277 = HEAP32[$276>>2]|0;
  $133 = $277;
  $278 = $132;
  $119 = $274;
  $279 = $119;
  $118 = $279;
  $280 = $118;
  HEAP32[$280>>2] = $278;
  $281 = $133;
  $282 = ($281|0)!=(0|0);
  if (!($282)) {
   STACKTOP = sp;return ($272|0);
  }
  $117 = $274;
  $283 = $117;
  $116 = $283;
  $284 = $116;
  $285 = ((($284)) + 4|0);
  $286 = $133;
  $127 = $285;
  $128 = $286;
  $287 = $127;
  $288 = HEAP32[$287>>2]|0;
  $289 = $128;
  $290 = ((($287)) + 4|0);
  $291 = HEAP32[$290>>2]|0;
  $124 = $288;
  $125 = $289;
  $126 = $291;
  $292 = $124;
  $293 = $125;
  $294 = $126;
  $121 = $292;
  $122 = $293;
  $123 = $294;
  $295 = $122;
  $120 = $295;
  $296 = $120;
  __ZdlPv($296);
  STACKTOP = sp;return ($272|0);
 }
 return (0)|0;
}
function __ZNKSt3__210__function6__funcIZN4mjin11application6memory4Game18matchSelectedItemsEvE3__0NS_9allocatorIS6_EEFvvEE7__cloneEPNS0_6__baseIS9_EE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 336|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(336|0);
 $10 = sp + 120|0;
 $11 = sp + 112|0;
 $12 = sp + 104|0;
 $13 = sp + 96|0;
 $16 = sp + 331|0;
 $17 = sp + 330|0;
 $18 = sp + 329|0;
 $19 = sp + 328|0;
 $21 = sp + 272|0;
 $29 = sp + 88|0;
 $30 = sp + 80|0;
 $31 = sp + 72|0;
 $32 = sp + 64|0;
 $35 = sp + 327|0;
 $36 = sp + 326|0;
 $37 = sp + 325|0;
 $38 = sp + 324|0;
 $40 = sp + 228|0;
 $50 = sp + 56|0;
 $51 = sp + 48|0;
 $52 = sp + 40|0;
 $53 = sp + 32|0;
 $54 = sp + 24|0;
 $57 = sp + 323|0;
 $58 = sp + 180|0;
 $59 = sp + 176|0;
 $60 = sp + 322|0;
 $61 = sp + 321|0;
 $62 = sp + 16|0;
 $63 = sp + 8|0;
 $64 = sp;
 $70 = sp + 320|0;
 $71 = sp + 152|0;
 $72 = sp + 148|0;
 $77 = $0;
 $78 = $1;
 $79 = $77;
 $80 = $78;
 $81 = ((($79)) + 4|0);
 $76 = $81;
 $82 = $76;
 $75 = $82;
 $83 = $75;
 $84 = ((($79)) + 4|0);
 $3 = $84;
 $85 = $3;
 $2 = $85;
 $86 = $2;
 $67 = $80;
 $68 = $83;
 $69 = $86;
 $87 = $67;
 $66 = $87;
 $88 = $66;
 HEAP32[$88>>2] = (71384);
 HEAP32[$87>>2] = (71560);
 $89 = ((($87)) + 4|0);
 $90 = $68;
 $41 = $90;
 $91 = $41;
 $39 = $91;
 $92 = $39;
 $33 = $40;
 $34 = $92;
 $93 = $33;
 $94 = $34;
 ;HEAP8[$29>>0]=HEAP8[$38>>0]|0;
 ;HEAP8[$30>>0]=HEAP8[$37>>0]|0;
 ;HEAP8[$31>>0]=HEAP8[$36>>0]|0;
 ;HEAP8[$32>>0]=HEAP8[$35>>0]|0;
 $27 = $93;
 $28 = $94;
 $95 = $27;
 $96 = $28;
 $26 = $96;
 $97 = $26;
 $24 = $95;
 $25 = $97;
 $98 = $24;
 $99 = $25;
 $23 = $99;
 $100 = $23;
 HEAP32[$98>>2] = $100;
 $101 = HEAP32[$40>>2]|0;
 HEAP32[$71>>2] = $101;
 $102 = $69;
 $22 = $102;
 $103 = $22;
 $20 = $103;
 $104 = $20;
 $14 = $21;
 $15 = $104;
 $105 = $14;
 $106 = $15;
 ;HEAP8[$10>>0]=HEAP8[$19>>0]|0;
 ;HEAP8[$11>>0]=HEAP8[$18>>0]|0;
 ;HEAP8[$12>>0]=HEAP8[$17>>0]|0;
 ;HEAP8[$13>>0]=HEAP8[$16>>0]|0;
 $8 = $105;
 $9 = $106;
 $107 = $8;
 $108 = $9;
 $7 = $108;
 $109 = $7;
 $5 = $107;
 $6 = $109;
 $110 = $5;
 $111 = $6;
 $4 = $111;
 $112 = $4;
 HEAP32[$110>>2] = $112;
 $113 = HEAP32[$21>>2]|0;
 HEAP32[$72>>2] = $113;
 ;HEAP8[$62>>0]=HEAP8[$72>>0]|0;HEAP8[$62+1>>0]=HEAP8[$72+1>>0]|0;HEAP8[$62+2>>0]=HEAP8[$72+2>>0]|0;HEAP8[$62+3>>0]=HEAP8[$72+3>>0]|0;
 ;HEAP8[$63>>0]=HEAP8[$71>>0]|0;HEAP8[$63+1>>0]=HEAP8[$71+1>>0]|0;HEAP8[$63+2>>0]=HEAP8[$71+2>>0]|0;HEAP8[$63+3>>0]=HEAP8[$71+3>>0]|0;
 ;HEAP8[$64>>0]=HEAP8[$70>>0]|0;
 $56 = $89;
 $114 = $56;
 $55 = $63;
 $115 = $55;
 ;HEAP32[$58>>2]=HEAP32[$115>>2]|0;
 $42 = $62;
 $116 = $42;
 ;HEAP32[$59>>2]=HEAP32[$116>>2]|0;
 ;HEAP8[$50>>0]=HEAP8[$61>>0]|0;
 ;HEAP8[$51>>0]=HEAP8[$60>>0]|0;
 ;HEAP8[$52>>0]=HEAP8[$59>>0]|0;HEAP8[$52+1>>0]=HEAP8[$59+1>>0]|0;HEAP8[$52+2>>0]=HEAP8[$59+2>>0]|0;HEAP8[$52+3>>0]=HEAP8[$59+3>>0]|0;
 ;HEAP8[$53>>0]=HEAP8[$58>>0]|0;HEAP8[$53+1>>0]=HEAP8[$58+1>>0]|0;HEAP8[$53+2>>0]=HEAP8[$58+2>>0]|0;HEAP8[$53+3>>0]=HEAP8[$58+3>>0]|0;
 ;HEAP8[$54>>0]=HEAP8[$57>>0]|0;
 $49 = $114;
 $117 = $49;
 $48 = $52;
 $118 = $48;
 $47 = $118;
 $119 = $47;
 $120 = HEAP32[$119>>2]|0;
 $46 = $120;
 $44 = $53;
 $121 = $44;
 $43 = $121;
 $122 = $43;
 $123 = HEAP32[$122>>2]|0;
 $45 = $123;
 $124 = $45;
 __THREW__ = 0;
 invoke_vii(4076,($117|0),($124|0));
 $125 = __THREW__; __THREW__ = 0;
 $126 = $125&1;
 if ($126) {
  $127 = ___cxa_find_matching_catch_2()|0;
  $128 = tempRet0;
  $73 = $127;
  $74 = $128;
  $65 = $87;
  $129 = $73;
  $130 = $74;
  ___resumeException($129|0);
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__210__function6__funcIZN4mjin11application6memory4Game18matchSelectedItemsEvE3__0NS_9allocatorIS6_EEFvvEE7destroyEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 $3 = ((($2)) + 4|0);
 __ZNSt3__217__compressed_pairIZN4mjin11application6memory4Game18matchSelectedItemsEvE3__0NS_9allocatorIS5_EEED2Ev($3);
 STACKTOP = sp;return;
}
function __ZNSt3__210__function6__funcIZN4mjin11application6memory4Game18matchSelectedItemsEvE3__0NS_9allocatorIS6_EEFvvEE18destroy_deallocateEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $10 = sp + 36|0;
 $9 = $0;
 $11 = $9;
 $12 = ((($11)) + 4|0);
 $8 = $12;
 $13 = $8;
 $7 = $13;
 $14 = $7;
 $1 = $10;
 $2 = $14;
 $15 = ((($11)) + 4|0);
 __ZNSt3__217__compressed_pairIZN4mjin11application6memory4Game18matchSelectedItemsEvE3__0NS_9allocatorIS5_EEED2Ev($15);
 $4 = $10;
 $5 = $11;
 $6 = 1;
 $16 = $5;
 $3 = $16;
 $17 = $3;
 __ZdlPv($17);
 STACKTOP = sp;return;
}
function __ZNSt3__210__function6__funcIZN4mjin11application6memory4Game18matchSelectedItemsEvE3__0NS_9allocatorIS6_EEFvvEEclEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = $0;
 $4 = $3;
 $5 = ((($4)) + 4|0);
 $2 = $5;
 $6 = $2;
 $1 = $6;
 $7 = $1;
 __ZNSt3__228__invoke_void_return_wrapperIvE6__callIJRZN4mjin11application6memory4Game18matchSelectedItemsEvE3__0EEEvDpOT_($7);
 STACKTOP = sp;return;
}
function __ZNKSt3__210__function6__funcIZN4mjin11application6memory4Game18matchSelectedItemsEvE3__0NS_9allocatorIS6_EEFvvEE6targetERKSt9type_info($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $7 = $0;
 $8 = $1;
 $9 = $7;
 $10 = $8;
 $4 = $10;
 $5 = 27408;
 $11 = $4;
 $12 = ((($11)) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $5;
 $15 = ((($14)) + 4|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($13|0)==($16|0);
 if ($17) {
  $18 = ((($9)) + 4|0);
  $3 = $18;
  $19 = $3;
  $2 = $19;
  $20 = $2;
  $6 = $20;
  $21 = $6;
  STACKTOP = sp;return ($21|0);
 } else {
  $6 = 0;
  $21 = $6;
  STACKTOP = sp;return ($21|0);
 }
 return (0)|0;
}
function __ZNKSt3__210__function6__funcIZN4mjin11application6memory4Game18matchSelectedItemsEvE3__0NS_9allocatorIS6_EEFvvEE11target_typeEv($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 STACKTOP = sp;return (27408|0);
}
function __ZNSt3__228__invoke_void_return_wrapperIvE6__callIJRZN4mjin11application6memory4Game18matchSelectedItemsEvE3__0EEEvDpOT_($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $4 = $0;
 $5 = $4;
 $3 = $5;
 $6 = $3;
 $2 = $6;
 $7 = $2;
 $1 = $7;
 $8 = $1;
 __ZZN4mjin11application6memory4Game18matchSelectedItemsEvENK3__0clEv($8);
 STACKTOP = sp;return;
}
function __ZZN4mjin11application6memory4Game18matchSelectedItemsEvENK3__0clEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0;
 var $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0;
 var $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0;
 var $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0;
 var $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0;
 var $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0;
 var $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0;
 var $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0;
 var $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0;
 var $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0;
 var $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0;
 var $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0;
 var $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0;
 var $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0;
 var $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0;
 var $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0;
 var $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0;
 var $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0;
 var $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0;
 var $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0;
 var $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0;
 var $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0;
 var $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0;
 var $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 832|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(832|0);
 $5 = sp + 796|0;
 $30 = sp + 24|0;
 $33 = sp + 817|0;
 $71 = sp + 540|0;
 $76 = sp + 520|0;
 $79 = sp + 508|0;
 $81 = sp + 500|0;
 $83 = sp + 492|0;
 $86 = sp + 480|0;
 $88 = sp + 16|0;
 $91 = sp + 464|0;
 $94 = sp + 452|0;
 $116 = sp + 8|0;
 $119 = sp + 816|0;
 $157 = sp + 208|0;
 $162 = sp + 188|0;
 $165 = sp + 176|0;
 $167 = sp + 168|0;
 $169 = sp + 160|0;
 $172 = sp + 148|0;
 $174 = sp;
 $183 = sp + 108|0;
 $190 = sp + 80|0;
 $193 = sp + 68|0;
 $196 = sp + 56|0;
 $197 = sp + 52|0;
 $198 = sp + 48|0;
 $199 = sp + 44|0;
 $200 = sp + 40|0;
 $201 = sp + 36|0;
 $202 = sp + 32|0;
 $203 = sp + 28|0;
 $195 = $0;
 $204 = $195;
 $205 = HEAP32[$204>>2]|0;
 __ZN4mjin11application6memory4Game21deselectSelectedNodesEv($205);
 $206 = ((($205)) + 4|0);
 $207 = ((($205)) + 4|0);
 $194 = $207;
 $208 = $194;
 $209 = HEAP32[$208>>2]|0;
 $191 = $208;
 $192 = $209;
 $210 = $192;
 $188 = $190;
 $189 = $210;
 $211 = $188;
 $212 = $189;
 HEAP32[$211>>2] = $212;
 $213 = HEAP32[$190>>2]|0;
 HEAP32[$193>>2] = $213;
 $214 = HEAP32[$193>>2]|0;
 HEAP32[$198>>2] = $214;
 $215 = ((($204)) + 4|0);
 $186 = $215;
 $187 = 1;
 $216 = $186;
 $217 = HEAP32[$216>>2]|0;
 $218 = $187;
 $219 = (($217) + ($218<<2)|0);
 $220 = HEAP32[$219>>2]|0;
 $184 = $198;
 $185 = $220;
 $221 = $184;
 ;HEAP32[$183>>2]=HEAP32[$221>>2]|0;
 $222 = $185;
 $181 = $183;
 $182 = $222;
 $223 = $181;
 $224 = $182;
 $225 = HEAP32[$223>>2]|0;
 $226 = (($225) + (($224*12)|0)|0);
 HEAP32[$223>>2] = $226;
 $227 = HEAP32[$183>>2]|0;
 HEAP32[$197>>2] = $227;
 $176 = $196;
 $177 = $197;
 $178 = 0;
 $228 = $176;
 $229 = $177;
 $175 = $229;
 $230 = $175;
 $231 = HEAP32[$230>>2]|0;
 HEAP32[$228>>2] = $231;
 ;HEAP8[$174>>0]=HEAP8[$196>>0]|0;HEAP8[$174+1>>0]=HEAP8[$196+1>>0]|0;HEAP8[$174+2>>0]=HEAP8[$196+2>>0]|0;HEAP8[$174+3>>0]=HEAP8[$196+3>>0]|0;
 $170 = $206;
 $232 = $170;
 $168 = $232;
 $233 = $168;
 $166 = $233;
 $234 = $166;
 $235 = HEAP32[$234>>2]|0;
 $163 = $234;
 $164 = $235;
 $236 = $164;
 $160 = $162;
 $161 = $236;
 $237 = $160;
 $238 = $161;
 HEAP32[$237>>2] = $238;
 $239 = HEAP32[$162>>2]|0;
 HEAP32[$165>>2] = $239;
 $240 = HEAP32[$165>>2]|0;
 HEAP32[$167>>2] = $240;
 $241 = HEAP32[$167>>2]|0;
 HEAP32[$172>>2] = $241;
 $100 = $174;
 $101 = $172;
 $242 = $100;
 $99 = $242;
 $243 = $99;
 $244 = HEAP32[$243>>2]|0;
 $245 = $101;
 $98 = $245;
 $246 = $98;
 $247 = HEAP32[$246>>2]|0;
 $248 = $244;
 $249 = $247;
 $250 = (($248) - ($249))|0;
 $251 = (($250|0) / 12)&-1;
 $171 = $251;
 $252 = HEAP32[$232>>2]|0;
 $253 = $171;
 $254 = (($252) + (($253*12)|0)|0);
 $173 = $254;
 $255 = $173;
 $256 = ((($255)) + 12|0);
 $257 = ((($232)) + 4|0);
 $258 = HEAP32[$257>>2]|0;
 $259 = $173;
 $109 = $256;
 $110 = $258;
 $111 = $259;
 $260 = $109;
 $108 = $260;
 $261 = $108;
 $262 = $110;
 $102 = $262;
 $263 = $102;
 $264 = $111;
 $103 = $264;
 $265 = $103;
 $104 = $261;
 $105 = $263;
 $106 = $265;
 $266 = $105;
 $267 = $104;
 $268 = $266;
 $269 = $267;
 $270 = (($268) - ($269))|0;
 $271 = (($270|0) / 12)&-1;
 $107 = $271;
 $272 = $107;
 $273 = ($272>>>0)>(0);
 if ($273) {
  $274 = $106;
  $275 = $104;
  $276 = $107;
  $277 = ($276*12)|0;
  _memmove(($274|0),($275|0),($277|0))|0;
 }
 $278 = $106;
 $279 = $107;
 $280 = (($278) + (($279*12)|0)|0);
 $150 = $232;
 $151 = $280;
 $281 = $150;
 $282 = $151;
 $148 = $281;
 $149 = $282;
 $147 = $281;
 $283 = $147;
 $284 = ((($283)) + 4|0);
 $285 = HEAP32[$284>>2]|0;
 $286 = HEAP32[$283>>2]|0;
 $287 = $285;
 $288 = $286;
 $289 = (($287) - ($288))|0;
 $290 = (($289|0) / 12)&-1;
 $152 = $290;
 $291 = $151;
 $124 = $281;
 $125 = $291;
 $292 = $124;
 while(1) {
  $293 = $125;
  $294 = ((($292)) + 4|0);
  $295 = HEAP32[$294>>2]|0;
  $296 = ($293|0)!=($295|0);
  if (!($296)) {
   break;
  }
  $123 = $292;
  $297 = $123;
  $298 = ((($297)) + 8|0);
  $122 = $298;
  $299 = $122;
  $121 = $299;
  $300 = $121;
  $301 = ((($292)) + 4|0);
  $302 = HEAP32[$301>>2]|0;
  $303 = ((($302)) + -12|0);
  HEAP32[$301>>2] = $303;
  $120 = $303;
  $304 = $120;
  $117 = $300;
  $118 = $304;
  $305 = $117;
  $306 = $118;
  ;HEAP8[$116>>0]=HEAP8[$119>>0]|0;
  $114 = $305;
  $115 = $306;
  $307 = $114;
  $308 = $115;
  $112 = $307;
  $113 = $308;
 }
 $309 = $152;
 $145 = $281;
 $146 = $309;
 $310 = $145;
 $144 = $310;
 $311 = $144;
 $312 = HEAP32[$311>>2]|0;
 $143 = $312;
 $313 = $143;
 $127 = $310;
 $314 = $127;
 $315 = HEAP32[$314>>2]|0;
 $126 = $315;
 $316 = $126;
 $132 = $310;
 $317 = $132;
 $131 = $317;
 $318 = $131;
 $130 = $318;
 $319 = $130;
 $320 = ((($319)) + 8|0);
 $129 = $320;
 $321 = $129;
 $128 = $321;
 $322 = $128;
 $323 = HEAP32[$322>>2]|0;
 $324 = HEAP32[$318>>2]|0;
 $325 = $323;
 $326 = $324;
 $327 = (($325) - ($326))|0;
 $328 = (($327|0) / 12)&-1;
 $329 = (($316) + (($328*12)|0)|0);
 $134 = $310;
 $330 = $134;
 $331 = HEAP32[$330>>2]|0;
 $133 = $331;
 $332 = $133;
 $333 = $146;
 $334 = (($332) + (($333*12)|0)|0);
 $136 = $310;
 $335 = $136;
 $336 = HEAP32[$335>>2]|0;
 $135 = $336;
 $337 = $135;
 $137 = $310;
 $338 = $137;
 $339 = ((($338)) + 4|0);
 $340 = HEAP32[$339>>2]|0;
 $341 = HEAP32[$338>>2]|0;
 $342 = $340;
 $343 = $341;
 $344 = (($342) - ($343))|0;
 $345 = (($344|0) / 12)&-1;
 $346 = (($337) + (($345*12)|0)|0);
 $138 = $310;
 $139 = $313;
 $140 = $329;
 $141 = $334;
 $142 = $346;
 $347 = $173;
 $348 = ((($347)) + -12|0);
 $153 = $232;
 $154 = $348;
 $349 = $173;
 $158 = $232;
 $159 = $349;
 $350 = $159;
 $155 = $157;
 $156 = $350;
 $351 = $155;
 $352 = $156;
 HEAP32[$351>>2] = $352;
 $353 = HEAP32[$157>>2]|0;
 HEAP32[$169>>2] = $353;
 $354 = HEAP32[$169>>2]|0;
 HEAP32[$199>>2] = $354;
 $355 = ((($205)) + 4|0);
 $356 = ((($205)) + 4|0);
 $95 = $356;
 $357 = $95;
 $358 = HEAP32[$357>>2]|0;
 $92 = $357;
 $93 = $358;
 $359 = $93;
 $89 = $91;
 $90 = $359;
 $360 = $89;
 $361 = $90;
 HEAP32[$360>>2] = $361;
 $362 = HEAP32[$91>>2]|0;
 HEAP32[$94>>2] = $362;
 $363 = HEAP32[$94>>2]|0;
 HEAP32[$202>>2] = $363;
 $364 = ((($204)) + 4|0);
 $1 = $364;
 $2 = 0;
 $365 = $1;
 $366 = HEAP32[$365>>2]|0;
 $367 = $2;
 $368 = (($366) + ($367<<2)|0);
 $369 = HEAP32[$368>>2]|0;
 $6 = $202;
 $7 = $369;
 $370 = $6;
 ;HEAP32[$5>>2]=HEAP32[$370>>2]|0;
 $371 = $7;
 $3 = $5;
 $4 = $371;
 $372 = $3;
 $373 = $4;
 $374 = HEAP32[$372>>2]|0;
 $375 = (($374) + (($373*12)|0)|0);
 HEAP32[$372>>2] = $375;
 $376 = HEAP32[$5>>2]|0;
 HEAP32[$201>>2] = $376;
 $9 = $200;
 $10 = $201;
 $11 = 0;
 $377 = $9;
 $378 = $10;
 $8 = $378;
 $379 = $8;
 $380 = HEAP32[$379>>2]|0;
 HEAP32[$377>>2] = $380;
 ;HEAP8[$88>>0]=HEAP8[$200>>0]|0;HEAP8[$88+1>>0]=HEAP8[$200+1>>0]|0;HEAP8[$88+2>>0]=HEAP8[$200+2>>0]|0;HEAP8[$88+3>>0]=HEAP8[$200+3>>0]|0;
 $84 = $355;
 $381 = $84;
 $82 = $381;
 $382 = $82;
 $80 = $382;
 $383 = $80;
 $384 = HEAP32[$383>>2]|0;
 $77 = $383;
 $78 = $384;
 $385 = $78;
 $74 = $76;
 $75 = $385;
 $386 = $74;
 $387 = $75;
 HEAP32[$386>>2] = $387;
 $388 = HEAP32[$76>>2]|0;
 HEAP32[$79>>2] = $388;
 $389 = HEAP32[$79>>2]|0;
 HEAP32[$81>>2] = $389;
 $390 = HEAP32[$81>>2]|0;
 HEAP32[$86>>2] = $390;
 $14 = $88;
 $15 = $86;
 $391 = $14;
 $13 = $391;
 $392 = $13;
 $393 = HEAP32[$392>>2]|0;
 $394 = $15;
 $12 = $394;
 $395 = $12;
 $396 = HEAP32[$395>>2]|0;
 $397 = $393;
 $398 = $396;
 $399 = (($397) - ($398))|0;
 $400 = (($399|0) / 12)&-1;
 $85 = $400;
 $401 = HEAP32[$381>>2]|0;
 $402 = $85;
 $403 = (($401) + (($402*12)|0)|0);
 $87 = $403;
 $404 = $87;
 $405 = ((($404)) + 12|0);
 $406 = ((($381)) + 4|0);
 $407 = HEAP32[$406>>2]|0;
 $408 = $87;
 $23 = $405;
 $24 = $407;
 $25 = $408;
 $409 = $23;
 $22 = $409;
 $410 = $22;
 $411 = $24;
 $16 = $411;
 $412 = $16;
 $413 = $25;
 $17 = $413;
 $414 = $17;
 $18 = $410;
 $19 = $412;
 $20 = $414;
 $415 = $19;
 $416 = $18;
 $417 = $415;
 $418 = $416;
 $419 = (($417) - ($418))|0;
 $420 = (($419|0) / 12)&-1;
 $21 = $420;
 $421 = $21;
 $422 = ($421>>>0)>(0);
 if ($422) {
  $423 = $20;
  $424 = $18;
  $425 = $21;
  $426 = ($425*12)|0;
  _memmove(($423|0),($424|0),($426|0))|0;
 }
 $427 = $20;
 $428 = $21;
 $429 = (($427) + (($428*12)|0)|0);
 $64 = $381;
 $65 = $429;
 $430 = $64;
 $431 = $65;
 $62 = $430;
 $63 = $431;
 $61 = $430;
 $432 = $61;
 $433 = ((($432)) + 4|0);
 $434 = HEAP32[$433>>2]|0;
 $435 = HEAP32[$432>>2]|0;
 $436 = $434;
 $437 = $435;
 $438 = (($436) - ($437))|0;
 $439 = (($438|0) / 12)&-1;
 $66 = $439;
 $440 = $65;
 $38 = $430;
 $39 = $440;
 $441 = $38;
 while(1) {
  $442 = $39;
  $443 = ((($441)) + 4|0);
  $444 = HEAP32[$443>>2]|0;
  $445 = ($442|0)!=($444|0);
  if (!($445)) {
   break;
  }
  $37 = $441;
  $446 = $37;
  $447 = ((($446)) + 8|0);
  $36 = $447;
  $448 = $36;
  $35 = $448;
  $449 = $35;
  $450 = ((($441)) + 4|0);
  $451 = HEAP32[$450>>2]|0;
  $452 = ((($451)) + -12|0);
  HEAP32[$450>>2] = $452;
  $34 = $452;
  $453 = $34;
  $31 = $449;
  $32 = $453;
  $454 = $31;
  $455 = $32;
  ;HEAP8[$30>>0]=HEAP8[$33>>0]|0;
  $28 = $454;
  $29 = $455;
  $456 = $28;
  $457 = $29;
  $26 = $456;
  $27 = $457;
 }
 $458 = $66;
 $59 = $430;
 $60 = $458;
 $459 = $59;
 $58 = $459;
 $460 = $58;
 $461 = HEAP32[$460>>2]|0;
 $57 = $461;
 $462 = $57;
 $41 = $459;
 $463 = $41;
 $464 = HEAP32[$463>>2]|0;
 $40 = $464;
 $465 = $40;
 $46 = $459;
 $466 = $46;
 $45 = $466;
 $467 = $45;
 $44 = $467;
 $468 = $44;
 $469 = ((($468)) + 8|0);
 $43 = $469;
 $470 = $43;
 $42 = $470;
 $471 = $42;
 $472 = HEAP32[$471>>2]|0;
 $473 = HEAP32[$467>>2]|0;
 $474 = $472;
 $475 = $473;
 $476 = (($474) - ($475))|0;
 $477 = (($476|0) / 12)&-1;
 $478 = (($465) + (($477*12)|0)|0);
 $48 = $459;
 $479 = $48;
 $480 = HEAP32[$479>>2]|0;
 $47 = $480;
 $481 = $47;
 $482 = $60;
 $483 = (($481) + (($482*12)|0)|0);
 $50 = $459;
 $484 = $50;
 $485 = HEAP32[$484>>2]|0;
 $49 = $485;
 $486 = $49;
 $51 = $459;
 $487 = $51;
 $488 = ((($487)) + 4|0);
 $489 = HEAP32[$488>>2]|0;
 $490 = HEAP32[$487>>2]|0;
 $491 = $489;
 $492 = $490;
 $493 = (($491) - ($492))|0;
 $494 = (($493|0) / 12)&-1;
 $495 = (($486) + (($494*12)|0)|0);
 $52 = $459;
 $53 = $462;
 $54 = $478;
 $55 = $483;
 $56 = $495;
 $496 = $87;
 $497 = ((($496)) + -12|0);
 $67 = $381;
 $68 = $497;
 $498 = $87;
 $72 = $381;
 $73 = $498;
 $499 = $73;
 $69 = $71;
 $70 = $499;
 $500 = $69;
 $501 = $70;
 HEAP32[$500>>2] = $501;
 $502 = HEAP32[$71>>2]|0;
 HEAP32[$83>>2] = $502;
 $503 = HEAP32[$83>>2]|0;
 HEAP32[$203>>2] = $503;
 $504 = (__ZNK3osg7ref_ptrINS_5GroupEEptEv($205)|0);
 $505 = ((($204)) + 4|0);
 $96 = $505;
 $97 = 1;
 $506 = $96;
 $507 = HEAP32[$506>>2]|0;
 $508 = $97;
 $509 = (($507) + ($508<<2)|0);
 $510 = HEAP32[$509>>2]|0;
 (__ZN3osg5Group11removeChildEjj($504,$510,1)|0);
 $511 = (__ZNK3osg7ref_ptrINS_5GroupEEptEv($205)|0);
 $512 = ((($204)) + 4|0);
 $179 = $512;
 $180 = 0;
 $513 = $179;
 $514 = HEAP32[$513>>2]|0;
 $515 = $180;
 $516 = (($514) + ($515<<2)|0);
 $517 = HEAP32[$516>>2]|0;
 (__ZN3osg5Group11removeChildEjj($511,$517,1)|0);
 __ZN4mjin11application6memory4Game10indexNodesEv($205);
 STACKTOP = sp;return;
}
function __ZN3osg5Group11removeChildEjj($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$expand_i1_val = 0, $$expand_i1_val2 = 0, $$pre_trunc = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $4 = sp + 16|0;
 $5 = $0;
 $6 = $1;
 $7 = $2;
 $8 = $5;
 $9 = $6;
 $10 = ((($8)) + 124|0);
 $3 = $10;
 $11 = $3;
 $12 = ((($11)) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = HEAP32[$11>>2]|0;
 $15 = $13;
 $16 = $14;
 $17 = (($15) - ($16))|0;
 $18 = (($17|0) / 4)&-1;
 $19 = ($9>>>0)<($18>>>0);
 if ($19) {
  $20 = HEAP32[$8>>2]|0;
  $21 = ((($20)) + 216|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = $6;
  $24 = $7;
  $25 = (FUNCTION_TABLE_iiii[$22 & 8191]($8,$23,$24)|0);
  $$expand_i1_val = $25&1;
  HEAP8[$4>>0] = $$expand_i1_val;
  $$pre_trunc = HEAP8[$4>>0]|0;
  $26 = $$pre_trunc&1;
  STACKTOP = sp;return ($26|0);
 } else {
  $$expand_i1_val2 = 0;
  HEAP8[$4>>0] = $$expand_i1_val2;
  $$pre_trunc = HEAP8[$4>>0]|0;
  $26 = $$pre_trunc&1;
  STACKTOP = sp;return ($26|0);
 }
 return (0)|0;
}
function __ZNSt3__217__compressed_pairIZN4mjin11application6memory4Game18matchSelectedItemsEvE3__0NS_9allocatorIS5_EEED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 __ZNSt3__228__libcpp_compressed_pair_impIZN4mjin11application6memory4Game18matchSelectedItemsEvE3__0NS_9allocatorIS5_EELj2EED2Ev($2);
 STACKTOP = sp;return;
}
function __ZNSt3__228__libcpp_compressed_pair_impIZN4mjin11application6memory4Game18matchSelectedItemsEvE3__0NS_9allocatorIS5_EELj2EED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 __ZZN4mjin11application6memory4Game18matchSelectedItemsEvEN3__0D2Ev($2);
 STACKTOP = sp;return;
}
function __ZZN4mjin11application6memory4Game18matchSelectedItemsEvEN3__0C2ERKS3_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = $0;
 $3 = $1;
 $4 = $2;
 $5 = $3;
 $6 = HEAP32[$5>>2]|0;
 HEAP32[$4>>2] = $6;
 $7 = ((($4)) + 4|0);
 $8 = $3;
 $9 = ((($8)) + 4|0);
 __ZNSt3__26vectorIiNS_9allocatorIiEEEC2ERKS3_($7,$9);
 STACKTOP = sp;return;
}
function __ZNKSt3__26vectorIiNS_9allocatorIiEEE8max_sizeEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(80|0);
 $6 = sp + 8|0;
 $9 = sp + 77|0;
 $12 = sp;
 $14 = sp + 76|0;
 $19 = sp + 16|0;
 $20 = sp + 12|0;
 $18 = $0;
 $21 = $18;
 $17 = $21;
 $22 = $17;
 $23 = ((($22)) + 8|0);
 $16 = $23;
 $24 = $16;
 $15 = $24;
 $25 = $15;
 $13 = $25;
 $26 = $13;
 ;HEAP8[$12>>0]=HEAP8[$14>>0]|0;
 $11 = $26;
 $27 = $11;
 $10 = $27;
 HEAP32[$19>>2] = 1073741823;
 HEAP32[$20>>2] = 2147483647;
 $7 = $19;
 $8 = $20;
 $28 = $7;
 $29 = $8;
 ;HEAP8[$6>>0]=HEAP8[$9>>0]|0;
 $4 = $28;
 $5 = $29;
 $30 = $5;
 $31 = $4;
 $1 = $6;
 $2 = $30;
 $3 = $31;
 $32 = $2;
 $33 = HEAP32[$32>>2]|0;
 $34 = $3;
 $35 = HEAP32[$34>>2]|0;
 $36 = ($33>>>0)<($35>>>0);
 $37 = $5;
 $38 = $4;
 $39 = $36 ? $37 : $38;
 $40 = HEAP32[$39>>2]|0;
 STACKTOP = sp;return ($40|0);
}
function __ZNSt3__214__split_bufferIiRNS_9allocatorIiEEEC2EjjS3_($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(128|0);
 $26 = sp + 36|0;
 $30 = sp + 20|0;
 $32 = $0;
 $33 = $1;
 $34 = $2;
 $35 = $3;
 $36 = $32;
 $37 = ((($36)) + 12|0);
 $38 = $35;
 $29 = $37;
 HEAP32[$30>>2] = 0;
 $31 = $38;
 $39 = $29;
 $28 = $30;
 $40 = $28;
 $41 = HEAP32[$40>>2]|0;
 $42 = $31;
 $22 = $42;
 $43 = $22;
 $25 = $39;
 HEAP32[$26>>2] = $41;
 $27 = $43;
 $44 = $25;
 $24 = $26;
 $45 = $24;
 $46 = HEAP32[$45>>2]|0;
 HEAP32[$44>>2] = $46;
 $47 = ((($44)) + 4|0);
 $48 = $27;
 $23 = $48;
 $49 = $23;
 HEAP32[$47>>2] = $49;
 $50 = $33;
 $51 = ($50|0)!=(0);
 do {
  if ($51) {
   $6 = $36;
   $52 = $6;
   $53 = ((($52)) + 12|0);
   $5 = $53;
   $54 = $5;
   $4 = $54;
   $55 = $4;
   $56 = ((($55)) + 4|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = $33;
   $17 = $57;
   $18 = $58;
   $59 = $17;
   $60 = $18;
   $14 = $59;
   $15 = $60;
   $16 = 0;
   $61 = $14;
   $62 = $15;
   $13 = $61;
   $63 = ($62>>>0)>(1073741823);
   if (!($63)) {
    $74 = $15;
    $75 = $74<<2;
    $12 = $75;
    $76 = $12;
    $77 = (__Znwj($76)|0);
    $78 = $77;
    break;
   }
   $9 = 204840;
   $64 = (___cxa_allocate_exception(8)|0);
   $65 = $9;
   $7 = $64;
   $8 = $65;
   $66 = $7;
   $67 = $8;
   __THREW__ = 0;
   invoke_vii(3366,($66|0),($67|0));
   $68 = __THREW__; __THREW__ = 0;
   $69 = $68&1;
   if ($69) {
    $70 = ___cxa_find_matching_catch_2()|0;
    $71 = tempRet0;
    $10 = $70;
    $11 = $71;
    ___cxa_free_exception(($64|0));
    $72 = $10;
    $73 = $11;
    ___resumeException($72|0);
    // unreachable;
   } else {
    HEAP32[$66>>2] = (99824);
    ___cxa_throw(($64|0),(34608|0),(3230|0));
    // unreachable;
   }
  } else {
   $78 = 0;
  }
 } while(0);
 HEAP32[$36>>2] = $78;
 $79 = HEAP32[$36>>2]|0;
 $80 = $34;
 $81 = (($79) + ($80<<2)|0);
 $82 = ((($36)) + 8|0);
 HEAP32[$82>>2] = $81;
 $83 = ((($36)) + 4|0);
 HEAP32[$83>>2] = $81;
 $84 = HEAP32[$36>>2]|0;
 $85 = $33;
 $86 = (($84) + ($85<<2)|0);
 $21 = $36;
 $87 = $21;
 $88 = ((($87)) + 12|0);
 $20 = $88;
 $89 = $20;
 $19 = $89;
 $90 = $19;
 HEAP32[$90>>2] = $86;
 STACKTOP = sp;return;
}
function __ZNSt3__26vectorIiNS_9allocatorIiEEE26__swap_out_circular_bufferERNS_14__split_bufferIiRS2_EE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0;
 var $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0;
 var $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0;
 var $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0;
 var $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0;
 var $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0;
 var $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0;
 var $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 352|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(352|0);
 $15 = sp + 288|0;
 $21 = sp + 264|0;
 $33 = sp + 216|0;
 $86 = $0;
 $87 = $1;
 $88 = $86;
 $85 = $88;
 $89 = $85;
 $84 = $89;
 $90 = $84;
 $91 = HEAP32[$90>>2]|0;
 $83 = $91;
 $92 = $83;
 $62 = $89;
 $93 = $62;
 $94 = HEAP32[$93>>2]|0;
 $61 = $94;
 $95 = $61;
 $67 = $89;
 $96 = $67;
 $66 = $96;
 $97 = $66;
 $65 = $97;
 $98 = $65;
 $99 = ((($98)) + 8|0);
 $64 = $99;
 $100 = $64;
 $63 = $100;
 $101 = $63;
 $102 = HEAP32[$101>>2]|0;
 $103 = HEAP32[$97>>2]|0;
 $104 = $102;
 $105 = $103;
 $106 = (($104) - ($105))|0;
 $107 = (($106|0) / 4)&-1;
 $108 = (($95) + ($107<<2)|0);
 $69 = $89;
 $109 = $69;
 $110 = HEAP32[$109>>2]|0;
 $68 = $110;
 $111 = $68;
 $70 = $89;
 $112 = $70;
 $113 = ((($112)) + 4|0);
 $114 = HEAP32[$113>>2]|0;
 $115 = HEAP32[$112>>2]|0;
 $116 = $114;
 $117 = $115;
 $118 = (($116) - ($117))|0;
 $119 = (($118|0) / 4)&-1;
 $120 = (($111) + ($119<<2)|0);
 $72 = $89;
 $121 = $72;
 $122 = HEAP32[$121>>2]|0;
 $71 = $122;
 $123 = $71;
 $77 = $89;
 $124 = $77;
 $76 = $124;
 $125 = $76;
 $75 = $125;
 $126 = $75;
 $127 = ((($126)) + 8|0);
 $74 = $127;
 $128 = $74;
 $73 = $128;
 $129 = $73;
 $130 = HEAP32[$129>>2]|0;
 $131 = HEAP32[$125>>2]|0;
 $132 = $130;
 $133 = $131;
 $134 = (($132) - ($133))|0;
 $135 = (($134|0) / 4)&-1;
 $136 = (($123) + ($135<<2)|0);
 $78 = $89;
 $79 = $92;
 $80 = $108;
 $81 = $120;
 $82 = $136;
 $4 = $88;
 $137 = $4;
 $138 = ((($137)) + 8|0);
 $3 = $138;
 $139 = $3;
 $2 = $139;
 $140 = $2;
 $141 = HEAP32[$88>>2]|0;
 $142 = ((($88)) + 4|0);
 $143 = HEAP32[$142>>2]|0;
 $144 = $87;
 $145 = ((($144)) + 4|0);
 $5 = $140;
 $6 = $141;
 $7 = $143;
 $8 = $145;
 $146 = $7;
 $147 = $6;
 $148 = $146;
 $149 = $147;
 $150 = (($148) - ($149))|0;
 $151 = (($150|0) / 4)&-1;
 $9 = $151;
 $152 = $9;
 $153 = $8;
 $154 = HEAP32[$153>>2]|0;
 $155 = (0 - ($152))|0;
 $156 = (($154) + ($155<<2)|0);
 HEAP32[$153>>2] = $156;
 $157 = $9;
 $158 = ($157|0)>(0);
 if ($158) {
  $159 = $8;
  $160 = HEAP32[$159>>2]|0;
  $161 = $6;
  $162 = $9;
  $163 = $162<<2;
  _memcpy(($160|0),($161|0),($163|0))|0;
 }
 $164 = $87;
 $165 = ((($164)) + 4|0);
 $13 = $88;
 $14 = $165;
 $166 = $13;
 $12 = $166;
 $167 = $12;
 $168 = HEAP32[$167>>2]|0;
 HEAP32[$15>>2] = $168;
 $169 = $14;
 $10 = $169;
 $170 = $10;
 $171 = HEAP32[$170>>2]|0;
 $172 = $13;
 HEAP32[$172>>2] = $171;
 $11 = $15;
 $173 = $11;
 $174 = HEAP32[$173>>2]|0;
 $175 = $14;
 HEAP32[$175>>2] = $174;
 $176 = ((($88)) + 4|0);
 $177 = $87;
 $178 = ((($177)) + 8|0);
 $19 = $176;
 $20 = $178;
 $179 = $19;
 $18 = $179;
 $180 = $18;
 $181 = HEAP32[$180>>2]|0;
 HEAP32[$21>>2] = $181;
 $182 = $20;
 $16 = $182;
 $183 = $16;
 $184 = HEAP32[$183>>2]|0;
 $185 = $19;
 HEAP32[$185>>2] = $184;
 $17 = $21;
 $186 = $17;
 $187 = HEAP32[$186>>2]|0;
 $188 = $20;
 HEAP32[$188>>2] = $187;
 $24 = $88;
 $189 = $24;
 $190 = ((($189)) + 8|0);
 $23 = $190;
 $191 = $23;
 $22 = $191;
 $192 = $22;
 $193 = $87;
 $27 = $193;
 $194 = $27;
 $195 = ((($194)) + 12|0);
 $26 = $195;
 $196 = $26;
 $25 = $196;
 $197 = $25;
 $31 = $192;
 $32 = $197;
 $198 = $31;
 $30 = $198;
 $199 = $30;
 $200 = HEAP32[$199>>2]|0;
 HEAP32[$33>>2] = $200;
 $201 = $32;
 $28 = $201;
 $202 = $28;
 $203 = HEAP32[$202>>2]|0;
 $204 = $31;
 HEAP32[$204>>2] = $203;
 $29 = $33;
 $205 = $29;
 $206 = HEAP32[$205>>2]|0;
 $207 = $32;
 HEAP32[$207>>2] = $206;
 $208 = $87;
 $209 = ((($208)) + 4|0);
 $210 = HEAP32[$209>>2]|0;
 $211 = $87;
 HEAP32[$211>>2] = $210;
 $34 = $88;
 $212 = $34;
 $213 = ((($212)) + 4|0);
 $214 = HEAP32[$213>>2]|0;
 $215 = HEAP32[$212>>2]|0;
 $216 = $214;
 $217 = $215;
 $218 = (($216) - ($217))|0;
 $219 = (($218|0) / 4)&-1;
 $58 = $88;
 $59 = $219;
 $220 = $58;
 $57 = $220;
 $221 = $57;
 $222 = HEAP32[$221>>2]|0;
 $56 = $222;
 $223 = $56;
 $36 = $220;
 $224 = $36;
 $225 = HEAP32[$224>>2]|0;
 $35 = $225;
 $226 = $35;
 $41 = $220;
 $227 = $41;
 $40 = $227;
 $228 = $40;
 $39 = $228;
 $229 = $39;
 $230 = ((($229)) + 8|0);
 $38 = $230;
 $231 = $38;
 $37 = $231;
 $232 = $37;
 $233 = HEAP32[$232>>2]|0;
 $234 = HEAP32[$228>>2]|0;
 $235 = $233;
 $236 = $234;
 $237 = (($235) - ($236))|0;
 $238 = (($237|0) / 4)&-1;
 $239 = (($226) + ($238<<2)|0);
 $43 = $220;
 $240 = $43;
 $241 = HEAP32[$240>>2]|0;
 $42 = $241;
 $242 = $42;
 $48 = $220;
 $243 = $48;
 $47 = $243;
 $244 = $47;
 $46 = $244;
 $245 = $46;
 $246 = ((($245)) + 8|0);
 $45 = $246;
 $247 = $45;
 $44 = $247;
 $248 = $44;
 $249 = HEAP32[$248>>2]|0;
 $250 = HEAP32[$244>>2]|0;
 $251 = $249;
 $252 = $250;
 $253 = (($251) - ($252))|0;
 $254 = (($253|0) / 4)&-1;
 $255 = (($242) + ($254<<2)|0);
 $50 = $220;
 $256 = $50;
 $257 = HEAP32[$256>>2]|0;
 $49 = $257;
 $258 = $49;
 $259 = $59;
 $260 = (($258) + ($259<<2)|0);
 $51 = $220;
 $52 = $223;
 $53 = $239;
 $54 = $255;
 $55 = $260;
 $60 = $88;
 STACKTOP = sp;return;
}
function __ZNSt3__214__split_bufferIiRNS_9allocatorIiEEED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(144|0);
 $19 = sp + 8|0;
 $22 = sp + 133|0;
 $29 = sp;
 $32 = sp + 132|0;
 $34 = $0;
 $35 = $34;
 $33 = $35;
 $36 = $33;
 $37 = ((($36)) + 4|0);
 $38 = HEAP32[$37>>2]|0;
 $30 = $36;
 $31 = $38;
 $39 = $30;
 $40 = $31;
 ;HEAP8[$29>>0]=HEAP8[$32>>0]|0;
 $27 = $39;
 $28 = $40;
 $41 = $27;
 while(1) {
  $42 = $28;
  $43 = ((($41)) + 8|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = ($42|0)!=($44|0);
  if (!($45)) {
   break;
  }
  $26 = $41;
  $46 = $26;
  $47 = ((($46)) + 12|0);
  $25 = $47;
  $48 = $25;
  $24 = $48;
  $49 = $24;
  $50 = ((($49)) + 4|0);
  $51 = HEAP32[$50>>2]|0;
  $52 = ((($41)) + 8|0);
  $53 = HEAP32[$52>>2]|0;
  $54 = ((($53)) + -4|0);
  HEAP32[$52>>2] = $54;
  $23 = $54;
  $55 = $23;
  $20 = $51;
  $21 = $55;
  $56 = $20;
  $57 = $21;
  ;HEAP8[$19>>0]=HEAP8[$22>>0]|0;
  $17 = $56;
  $18 = $57;
  $58 = $17;
  $59 = $18;
  $15 = $58;
  $16 = $59;
 }
 $60 = HEAP32[$35>>2]|0;
 $61 = ($60|0)!=(0|0);
 if (!($61)) {
  STACKTOP = sp;return;
 }
 $14 = $35;
 $62 = $14;
 $63 = ((($62)) + 12|0);
 $13 = $63;
 $64 = $13;
 $12 = $64;
 $65 = $12;
 $66 = ((($65)) + 4|0);
 $67 = HEAP32[$66>>2]|0;
 $68 = HEAP32[$35>>2]|0;
 $4 = $35;
 $69 = $4;
 $3 = $69;
 $70 = $3;
 $71 = ((($70)) + 12|0);
 $2 = $71;
 $72 = $2;
 $1 = $72;
 $73 = $1;
 $74 = HEAP32[$73>>2]|0;
 $75 = HEAP32[$69>>2]|0;
 $76 = $74;
 $77 = $75;
 $78 = (($76) - ($77))|0;
 $79 = (($78|0) / 4)&-1;
 $9 = $67;
 $10 = $68;
 $11 = $79;
 $80 = $9;
 $81 = $10;
 $82 = $11;
 $6 = $80;
 $7 = $81;
 $8 = $82;
 $83 = $7;
 $5 = $83;
 $84 = $5;
 __ZdlPv($84);
 STACKTOP = sp;return;
}
function __ZN4mjin11application6memory4Game4tickEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0.0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $4 = $0;
 $5 = $4;
 $6 = ((($5)) + 32|0);
 $2 = $6;
 $3 = 0;
 $7 = $2;
 $1 = $7;
 $8 = $1;
 $9 = ((($8)) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)!=(0|0);
 if (!($11)) {
  STACKTOP = sp;return;
 }
 $12 = ((($5)) + 32|0);
 $13 = ((($5)) + 56|0);
 $14 = (+__ZNK3osg5Timer6time_sEv($13));
 $15 = (__ZNKSt3__28functionIFbdEEclEd($12,$14)|0);
 if ($15) {
  STACKTOP = sp;return;
 }
 $16 = ((($5)) + 32|0);
 (__ZNSt3__28functionIFbdEEaSEDn($16,0)|0);
 STACKTOP = sp;return;
}
function __ZNK3osg5Timer6time_sEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0.0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 $3 = $2;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 4)|0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = (__ZNK3osg5Timer4tickEv($2)|0);
 $10 = tempRet0;
 $11 = (+__ZNK3osg5Timer7delta_sEyy($2,$5,$8,$9,$10));
 STACKTOP = sp;return (+$11);
}
function __ZNKSt3__28functionIFbdEEclEd($0,$1) {
 $0 = $0|0;
 $1 = +$1;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $4 = sp;
 $3 = $0;
 HEAPF64[$4>>3] = $1;
 $5 = $3;
 $6 = ((($5)) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if ($8) {
  $9 = (___cxa_allocate_exception(4)|0);
  ;HEAP32[$9>>2]=0|0;
  __ZNSt3__217bad_function_callC2Ev($9);
  ___cxa_throw(($9|0),(27280|0),(2510|0));
  // unreachable;
 } else {
  $10 = ((($5)) + 16|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = HEAP32[$11>>2]|0;
  $13 = ((($12)) + 24|0);
  $14 = HEAP32[$13>>2]|0;
  $2 = $4;
  $15 = $2;
  $16 = (FUNCTION_TABLE_iii[$14 & 8191]($11,$15)|0);
  STACKTOP = sp;return ($16|0);
 }
 return (0)|0;
}
function __ZNSt3__28functionIFbdEEaSEDn($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = $0;
 $3 = $1;
 $4 = $2;
 $5 = ((($4)) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==($4|0);
 $8 = ((($4)) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 if ($7) {
  $10 = HEAP32[$9>>2]|0;
  $11 = ((($10)) + 16|0);
  $12 = HEAP32[$11>>2]|0;
  FUNCTION_TABLE_vi[$12 & 8191]($9);
 } else {
  $13 = ($9|0)!=(0|0);
  if ($13) {
   $14 = ((($4)) + 16|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = HEAP32[$15>>2]|0;
   $17 = ((($16)) + 20|0);
   $18 = HEAP32[$17>>2]|0;
   FUNCTION_TABLE_vi[$18 & 8191]($15);
  }
 }
 $19 = ((($4)) + 16|0);
 HEAP32[$19>>2] = 0;
 STACKTOP = sp;return ($4|0);
}
function __GLOBAL__sub_I_common_cpp() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 ___cxx_global_var_init_4316();
 ___cxx_global_var_init_1_4317();
 ___cxx_global_var_init_2_4318();
 return;
}
function ___cxx_global_var_init_4316() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg5Vec3fC2Efff(209032,1.0,0.0,0.0);
 return;
}
function ___cxx_global_var_init_1_4317() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg5Vec3fC2Efff(209020,0.0,1.0,0.0);
 return;
}
function ___cxx_global_var_init_2_4318() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg5Vec3fC2Efff(209008,0.0,0.0,1.0);
 return;
}
function __ZN4mjin11application6memory8material3RGBC2Efff($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = +$1;
 $2 = +$2;
 $3 = +$3;
 var $10 = 0, $11 = 0.0, $12 = 0, $13 = 0.0, $4 = 0, $5 = 0.0, $6 = 0.0, $7 = 0.0, $8 = 0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $4 = $0;
 $5 = $1;
 $6 = $2;
 $7 = $3;
 $8 = $4;
 $9 = $5;
 HEAPF32[$8>>2] = $9;
 $10 = ((($8)) + 4|0);
 $11 = $6;
 HEAPF32[$10>>2] = $11;
 $12 = ((($8)) + 8|0);
 $13 = $7;
 HEAPF32[$12>>2] = $13;
 STACKTOP = sp;return;
}
function __ZN4mjin11application6memory8material11typeIdToRGBEi($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = $1;
 $3 = $2;
 do {
  switch ($3|0) {
  case 0:  {
   __ZN4mjin11application6memory8material3RGBC2Efff($0,0.0,0.0,0.0);
   break;
  }
  case 1:  {
   __ZN4mjin11application6memory8material3RGBC2Efff($0,0.75,0.75,0.75);
   break;
  }
  case 2:  {
   __ZN4mjin11application6memory8material3RGBC2Efff($0,0.5,0.5,0.5);
   break;
  }
  case 3:  {
   __ZN4mjin11application6memory8material3RGBC2Efff($0,1.0,1.0,1.0);
   break;
  }
  case 4:  {
   __ZN4mjin11application6memory8material3RGBC2Efff($0,0.5,0.0,0.0);
   break;
  }
  case 5:  {
   __ZN4mjin11application6memory8material3RGBC2Efff($0,1.0,0.0,0.0);
   break;
  }
  case 6:  {
   __ZN4mjin11application6memory8material3RGBC2Efff($0,0.5,0.0,0.5);
   break;
  }
  case 7:  {
   __ZN4mjin11application6memory8material3RGBC2Efff($0,1.0,0.0,1.0);
   break;
  }
  case 8:  {
   __ZN4mjin11application6memory8material3RGBC2Efff($0,0.0,0.5,0.0);
   break;
  }
  case 9:  {
   __ZN4mjin11application6memory8material3RGBC2Efff($0,0.0,1.0,0.0);
   break;
  }
  case 10:  {
   __ZN4mjin11application6memory8material3RGBC2Efff($0,0.5,0.5,0.0);
   break;
  }
  case 11:  {
   __ZN4mjin11application6memory8material3RGBC2Efff($0,1.0,1.0,0.0);
   break;
  }
  case 12:  {
   __ZN4mjin11application6memory8material3RGBC2Efff($0,0.0,0.0,0.5);
   break;
  }
  case 13:  {
   __ZN4mjin11application6memory8material3RGBC2Efff($0,0.0,0.0,1.0);
   break;
  }
  case 14:  {
   __ZN4mjin11application6memory8material3RGBC2Efff($0,0.0,0.5,0.5);
   break;
  }
  default: {
   __ZN4mjin11application6memory8material3RGBC2Efff($0,0.0,1.0,1.0);
  }
  }
 } while(0);
 STACKTOP = sp;return;
}
function __ZN4mjin11application6memory8material11singleColorEv() {
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0;
 var $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0;
 var $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0;
 var $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0;
 var $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0;
 var $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 512|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(512|0);
 $36 = sp + 8|0;
 $38 = sp + 503|0;
 $49 = sp + 502|0;
 $91 = sp;
 $93 = sp + 501|0;
 $104 = sp + 500|0;
 $110 = sp + 72|0;
 $111 = sp + 60|0;
 $115 = sp + 36|0;
 $116 = sp + 24|0;
 $117 = sp + 12|0;
 $108 = $110;
 $109 = 161886;
 $118 = $108;
 $107 = $118;
 $119 = $107;
 $106 = $119;
 $120 = $106;
 $105 = $120;
 ;HEAP32[$120>>2]=0|0;HEAP32[$120+4>>2]=0|0;HEAP32[$120+8>>2]=0|0;
 $121 = $109;
 $122 = $109;
 $123 = (__ZNSt3__211char_traitsIcE6lengthEPKc($122)|0);
 $99 = $118;
 $100 = $121;
 $101 = $123;
 $124 = $99;
 $125 = $101;
 $97 = $124;
 $126 = $97;
 $96 = $126;
 $127 = $96;
 $95 = $127;
 $128 = $95;
 $94 = $128;
 $129 = $94;
 $92 = $129;
 $130 = $92;
 ;HEAP8[$91>>0]=HEAP8[$93>>0]|0;
 $90 = $130;
 $131 = $90;
 $89 = $131;
 $98 = -1;
 $132 = $98;
 $133 = (($132) - 16)|0;
 $134 = ($125>>>0)>($133>>>0);
 if ($134) {
  __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv($124);
  // unreachable;
 }
 $135 = $101;
 $136 = ($135>>>0)<(11);
 $137 = $101;
 if ($136) {
  $87 = $124;
  $88 = $137;
  $138 = $87;
  $139 = $88;
  $140 = $139&255;
  $86 = $138;
  $141 = $86;
  $85 = $141;
  $142 = $85;
  $143 = ((($142)) + 11|0);
  HEAP8[$143>>0] = $140;
  $84 = $124;
  $144 = $84;
  $83 = $144;
  $145 = $83;
  $82 = $145;
  $146 = $82;
  $81 = $146;
  $147 = $81;
  $80 = $147;
  $148 = $80;
  $102 = $148;
 } else {
  $59 = $137;
  $149 = $59;
  $150 = ($149>>>0)<(11);
  if ($150) {
   $157 = 11;
  } else {
   $151 = $59;
   $152 = (($151) + 1)|0;
   $58 = $152;
   $153 = $58;
   $154 = (($153) + 15)|0;
   $155 = $154 & -16;
   $157 = $155;
  }
  $156 = (($157) - 1)|0;
  $103 = $156;
  $57 = $124;
  $158 = $57;
  $56 = $158;
  $159 = $56;
  $55 = $159;
  $160 = $55;
  $161 = $103;
  $162 = (($161) + 1)|0;
  $65 = $160;
  $66 = $162;
  $163 = $65;
  $164 = $66;
  $62 = $163;
  $63 = $164;
  $64 = 0;
  $165 = $62;
  $61 = $165;
  $166 = $63;
  $60 = $166;
  $167 = $60;
  $168 = (__Znwj($167)|0);
  $102 = $168;
  $169 = $102;
  $69 = $124;
  $70 = $169;
  $170 = $69;
  $171 = $70;
  $68 = $170;
  $172 = $68;
  $67 = $172;
  $173 = $67;
  HEAP32[$173>>2] = $171;
  $174 = $103;
  $175 = (($174) + 1)|0;
  $73 = $124;
  $74 = $175;
  $176 = $73;
  $177 = $74;
  $178 = -2147483648 | $177;
  $72 = $176;
  $179 = $72;
  $71 = $179;
  $180 = $71;
  $181 = ((($180)) + 8|0);
  HEAP32[$181>>2] = $178;
  $182 = $101;
  $77 = $124;
  $78 = $182;
  $183 = $77;
  $184 = $78;
  $76 = $183;
  $185 = $76;
  $75 = $185;
  $186 = $75;
  $187 = ((($186)) + 4|0);
  HEAP32[$187>>2] = $184;
 }
 $188 = $102;
 $79 = $188;
 $189 = $79;
 $190 = $100;
 $191 = $101;
 (__ZNSt3__211char_traitsIcE4copyEPcPKcj($189,$190,$191)|0);
 $192 = $102;
 $193 = $101;
 $194 = (($192) + ($193)|0);
 HEAP8[$104>>0] = 0;
 __ZNSt3__211char_traitsIcE6assignERcRKc($194,$104);
 $53 = $111;
 $54 = 162006;
 $195 = $53;
 $52 = $195;
 $196 = $52;
 $51 = $196;
 $197 = $51;
 $50 = $197;
 ;HEAP32[$197>>2]=0|0;HEAP32[$197+4>>2]=0|0;HEAP32[$197+8>>2]=0|0;
 $198 = $54;
 $199 = $54;
 $200 = (__ZNSt3__211char_traitsIcE6lengthEPKc($199)|0);
 $44 = $195;
 $45 = $198;
 $46 = $200;
 $201 = $44;
 $202 = $46;
 $42 = $201;
 $203 = $42;
 $41 = $203;
 $204 = $41;
 $40 = $204;
 $205 = $40;
 $39 = $205;
 $206 = $39;
 $37 = $206;
 $207 = $37;
 ;HEAP8[$36>>0]=HEAP8[$38>>0]|0;
 $35 = $207;
 $208 = $35;
 $34 = $208;
 $43 = -1;
 $209 = $43;
 $210 = (($209) - 16)|0;
 $211 = ($202>>>0)>($210>>>0);
 do {
  if ($211) {
   __THREW__ = 0;
   invoke_vi(3367,($201|0));
   $212 = __THREW__; __THREW__ = 0;
  } else {
   $213 = $46;
   $214 = ($213>>>0)<(11);
   $215 = $46;
   if ($214) {
    $32 = $201;
    $33 = $215;
    $216 = $32;
    $217 = $33;
    $218 = $217&255;
    $31 = $216;
    $219 = $31;
    $30 = $219;
    $220 = $30;
    $221 = ((($220)) + 11|0);
    HEAP8[$221>>0] = $218;
    $29 = $201;
    $222 = $29;
    $28 = $222;
    $223 = $28;
    $27 = $223;
    $224 = $27;
    $26 = $224;
    $225 = $26;
    $25 = $225;
    $226 = $25;
    $47 = $226;
   } else {
    $4 = $215;
    $227 = $4;
    $228 = ($227>>>0)<(11);
    if ($228) {
     $235 = 11;
    } else {
     $229 = $4;
     $230 = (($229) + 1)|0;
     $3 = $230;
     $231 = $3;
     $232 = (($231) + 15)|0;
     $233 = $232 & -16;
     $235 = $233;
    }
    $234 = (($235) - 1)|0;
    $48 = $234;
    $2 = $201;
    $236 = $2;
    $1 = $236;
    $237 = $1;
    $0 = $237;
    $238 = $0;
    $239 = $48;
    $240 = (($239) + 1)|0;
    $10 = $238;
    $11 = $240;
    $241 = $10;
    $242 = $11;
    $7 = $241;
    $8 = $242;
    $9 = 0;
    $243 = $7;
    $6 = $243;
    $244 = $8;
    $5 = $244;
    $245 = $5;
    __THREW__ = 0;
    $246 = (invoke_ii(3276,($245|0))|0);
    $247 = __THREW__; __THREW__ = 0;
    $248 = $247&1;
    if ($248) {
     break;
    }
    $47 = $246;
    $249 = $47;
    $14 = $201;
    $15 = $249;
    $250 = $14;
    $251 = $15;
    $13 = $250;
    $252 = $13;
    $12 = $252;
    $253 = $12;
    HEAP32[$253>>2] = $251;
    $254 = $48;
    $255 = (($254) + 1)|0;
    $18 = $201;
    $19 = $255;
    $256 = $18;
    $257 = $19;
    $258 = -2147483648 | $257;
    $17 = $256;
    $259 = $17;
    $16 = $259;
    $260 = $16;
    $261 = ((($260)) + 8|0);
    HEAP32[$261>>2] = $258;
    $262 = $46;
    $22 = $201;
    $23 = $262;
    $263 = $22;
    $264 = $23;
    $21 = $263;
    $265 = $21;
    $20 = $265;
    $266 = $20;
    $267 = ((($266)) + 4|0);
    HEAP32[$267>>2] = $264;
   }
   $268 = $47;
   $24 = $268;
   $269 = $24;
   $270 = $45;
   $271 = $46;
   (__ZNSt3__211char_traitsIcE4copyEPcPKcj($269,$270,$271)|0);
   $272 = $47;
   $273 = $46;
   $274 = (($272) + ($273)|0);
   HEAP8[$49>>0] = 0;
   __ZNSt3__211char_traitsIcE6assignERcRKc($274,$49);
   __THREW__ = 0;
   invoke_vii(3457,($115|0),($111|0));
   $275 = __THREW__; __THREW__ = 0;
   $276 = $275&1;
   L22: do {
    if ($276) {
     label = 25;
    } else {
     __THREW__ = 0;
     invoke_vii(3457,($116|0),($110|0));
     $277 = __THREW__; __THREW__ = 0;
     $278 = $277&1;
     do {
      if ($278) {
       $297 = ___cxa_find_matching_catch_2()|0;
       $298 = tempRet0;
       $112 = $297;
       $113 = $298;
      } else {
       __THREW__ = 0;
       $279 = (invoke_iii(4077,($115|0),($116|0))|0);
       $280 = __THREW__; __THREW__ = 0;
       $281 = $280&1;
       if ($281) {
        $299 = ___cxa_find_matching_catch_2()|0;
        $300 = tempRet0;
        $112 = $299;
        $113 = $300;
        __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($116);
        break;
       }
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($116);
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($115);
       $114 = $279;
       $282 = $114;
       __THREW__ = 0;
       $283 = (invoke_ii(3276,92)|0);
       $284 = __THREW__; __THREW__ = 0;
       $285 = $284&1;
       if ($285) {
        label = 25;
        break L22;
       }
       __THREW__ = 0;
       invoke_viddd(4055,($117|0),0.0,0.0,0.0);
       $286 = __THREW__; __THREW__ = 0;
       $287 = $286&1;
       if (!($287)) {
        __THREW__ = 0;
        invoke_viii(4078,($283|0),(162226|0),($117|0));
        $288 = __THREW__; __THREW__ = 0;
        $289 = $288&1;
        if (!($289)) {
         __THREW__ = 0;
         invoke_viii(3617,($282|0),($283|0),1);
         $290 = __THREW__; __THREW__ = 0;
         $291 = $290&1;
         if ($291) {
          label = 25;
          break L22;
         }
         $292 = $114;
         __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($111);
         __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($110);
         STACKTOP = sp;return ($292|0);
        }
       }
       $301 = ___cxa_find_matching_catch_2()|0;
       $302 = tempRet0;
       $112 = $301;
       $113 = $302;
       __ZdlPv($283);
       break L22;
      }
     } while(0);
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($115);
    }
   } while(0);
   if ((label|0) == 25) {
    $295 = ___cxa_find_matching_catch_2()|0;
    $296 = tempRet0;
    $112 = $295;
    $113 = $296;
   }
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($111);
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($110);
   $303 = $112;
   $304 = $113;
   ___resumeException($303|0);
   // unreachable;
  }
 } while(0);
 $293 = ___cxa_find_matching_catch_2()|0;
 $294 = tempRet0;
 $112 = $293;
 $113 = $294;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($110);
 $303 = $112;
 $304 = $113;
 ___resumeException($303|0);
 // unreachable;
 return (0)|0;
}
function __GLOBAL__sub_I_Pool_cpp() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 ___cxx_global_var_init_4330();
 ___cxx_global_var_init_1_4331();
 ___cxx_global_var_init_2_4332();
 return;
}
function ___cxx_global_var_init_4330() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg5Vec3fC2Efff(209068,1.0,0.0,0.0);
 return;
}
function ___cxx_global_var_init_1_4331() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg5Vec3fC2Efff(209056,0.0,1.0,0.0);
 return;
}
function ___cxx_global_var_init_2_4332() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg5Vec3fC2Efff(209044,0.0,0.0,1.0);
 return;
}
function __ZN4mjin11application6memory8material4PoolC2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $2 = sp + 8|0;
 $4 = sp + 35|0;
 $5 = sp + 34|0;
 $7 = sp;
 $9 = sp + 33|0;
 $10 = sp + 32|0;
 $11 = $0;
 $12 = $11;
 $8 = $12;
 $13 = $8;
 ;HEAP8[$7>>0]=HEAP8[$10>>0]|0;
 $6 = $9;
 __ZNSt3__26__treeINS_12__value_typeIPvPN3osg8StateSetEEENS_19__map_value_compareIS2_S6_NS_4lessIS2_EELb1EEENS_9allocatorIS6_EEEC2ERKSA_($13,$9);
 $14 = ((($12)) + 12|0);
 $3 = $14;
 $15 = $3;
 ;HEAP8[$2>>0]=HEAP8[$5>>0]|0;
 $1 = $4;
 __ZNSt3__26__treeINS_12__value_typeIPN3osg8StateSetEbEENS_19__map_value_compareIS4_S5_NS_4lessIS4_EELb1EEENS_9allocatorIS5_EEEC2ERKS9_($15,$4);
 STACKTOP = sp;return;
}
function __ZNSt3__26__treeINS_12__value_typeIPvPN3osg8StateSetEEENS_19__map_value_compareIS2_S6_NS_4lessIS2_EELb1EEENS_9allocatorIS6_EEEC2ERKSA_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(96|0);
 $12 = sp + 48|0;
 $13 = sp + 8|0;
 $16 = sp + 36|0;
 $17 = sp + 93|0;
 $18 = sp;
 $25 = sp + 92|0;
 $23 = $0;
 $24 = $1;
 $26 = $23;
 $27 = ((($26)) + 4|0);
 $22 = $27;
 $28 = $22;
 $21 = $28;
 $29 = $21;
 $20 = $29;
 $19 = $29;
 $30 = $19;
 HEAP32[$30>>2] = 0;
 $31 = ((($26)) + 8|0);
 ;HEAP8[$18>>0]=HEAP8[$25>>0]|0;
 $15 = $31;
 HEAP32[$16>>2] = 0;
 $32 = $15;
 $14 = $16;
 $33 = $14;
 $34 = HEAP32[$33>>2]|0;
 $8 = $18;
 ;HEAP8[$13>>0]=HEAP8[$17>>0]|0;
 $11 = $32;
 HEAP32[$12>>2] = $34;
 $35 = $11;
 $10 = $13;
 $9 = $12;
 $36 = $9;
 $37 = HEAP32[$36>>2]|0;
 HEAP32[$35>>2] = $37;
 $6 = $26;
 $38 = $6;
 $39 = ((($38)) + 4|0);
 $5 = $39;
 $40 = $5;
 $4 = $40;
 $41 = $4;
 $3 = $41;
 $42 = $3;
 $2 = $42;
 $43 = $2;
 $7 = $26;
 $44 = $7;
 HEAP32[$44>>2] = $43;
 STACKTOP = sp;return;
}
function __ZNSt3__26__treeINS_12__value_typeIPN3osg8StateSetEbEENS_19__map_value_compareIS4_S5_NS_4lessIS4_EELb1EEENS_9allocatorIS5_EEEC2ERKS9_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(96|0);
 $12 = sp + 48|0;
 $13 = sp + 8|0;
 $16 = sp + 36|0;
 $17 = sp + 93|0;
 $18 = sp;
 $25 = sp + 92|0;
 $23 = $0;
 $24 = $1;
 $26 = $23;
 $27 = ((($26)) + 4|0);
 $22 = $27;
 $28 = $22;
 $21 = $28;
 $29 = $21;
 $20 = $29;
 $19 = $29;
 $30 = $19;
 HEAP32[$30>>2] = 0;
 $31 = ((($26)) + 8|0);
 ;HEAP8[$18>>0]=HEAP8[$25>>0]|0;
 $15 = $31;
 HEAP32[$16>>2] = 0;
 $32 = $15;
 $14 = $16;
 $33 = $14;
 $34 = HEAP32[$33>>2]|0;
 $8 = $18;
 ;HEAP8[$13>>0]=HEAP8[$17>>0]|0;
 $11 = $32;
 HEAP32[$12>>2] = $34;
 $35 = $11;
 $10 = $13;
 $9 = $12;
 $36 = $9;
 $37 = HEAP32[$36>>2]|0;
 HEAP32[$35>>2] = $37;
 $6 = $26;
 $38 = $6;
 $39 = ((($38)) + 4|0);
 $5 = $39;
 $40 = $5;
 $4 = $40;
 $41 = $4;
 $3 = $41;
 $42 = $3;
 $2 = $42;
 $43 = $2;
 $7 = $26;
 $44 = $7;
 HEAP32[$44>>2] = $43;
 STACKTOP = sp;return;
}
function __ZN4mjin11application6memory8material4PoolD2Ev($0) {
 $0 = $0|0;
 var $$sink = 0, $$sink2 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(224|0);
 $vararg_buffer = sp + 16|0;
 $20 = sp + 8|0;
 $28 = sp + 108|0;
 $30 = sp + 100|0;
 $32 = sp + 92|0;
 $34 = sp;
 $38 = sp + 72|0;
 $40 = sp + 64|0;
 $42 = sp + 56|0;
 $47 = sp + 36|0;
 $48 = sp + 32|0;
 $49 = sp + 24|0;
 $43 = $0;
 $50 = $43;
 __THREW__ = 0;
 invoke_vii(3251,(162082|0),($vararg_buffer|0));
 $51 = __THREW__; __THREW__ = 0;
 $52 = $51&1;
 if ($52) {
  $125 = ___cxa_find_matching_catch_3(0|0)|0;
  $126 = tempRet0;
  $44 = $125;
  $45 = $126;
  $127 = ((($50)) + 12|0);
  __ZNSt3__23mapIPN3osg8StateSetEbNS_4lessIS3_EENS_9allocatorINS_4pairIKS3_bEEEEED2Ev($127);
  __ZNSt3__23mapIPvPN3osg8StateSetENS_4lessIS1_EENS_9allocatorINS_4pairIKS1_S4_EEEEED2Ev($50);
  $128 = $44;
  ___clang_call_terminate($128);
  // unreachable;
 }
 $53 = ((($50)) + 12|0);
 $46 = $53;
 $54 = $46;
 $41 = $54;
 $55 = $41;
 $39 = $55;
 $56 = $39;
 $37 = $56;
 $57 = $37;
 $58 = HEAP32[$57>>2]|0;
 $35 = $38;
 $36 = $58;
 $59 = $35;
 $60 = $36;
 HEAP32[$59>>2] = $60;
 $61 = HEAP32[$38>>2]|0;
 HEAP32[$42>>2] = $61;
 ;HEAP8[$34>>0]=HEAP8[$42>>0]|0;HEAP8[$34+1>>0]=HEAP8[$42+1>>0]|0;HEAP8[$34+2>>0]=HEAP8[$42+2>>0]|0;HEAP8[$34+3>>0]=HEAP8[$42+3>>0]|0;
 $33 = $40;
 $62 = $33;
 ;HEAP32[$62>>2]=HEAP32[$34>>2]|0;
 $63 = HEAP32[$40>>2]|0;
 HEAP32[$47>>2] = $63;
 $64 = $46;
 $31 = $64;
 $65 = $31;
 $29 = $65;
 $66 = $29;
 $27 = $66;
 $67 = $27;
 $68 = ((($67)) + 4|0);
 $26 = $68;
 $69 = $26;
 $25 = $69;
 $70 = $25;
 $24 = $70;
 $71 = $24;
 $23 = $71;
 $72 = $23;
 $21 = $28;
 $22 = $72;
 $73 = $21;
 $74 = $22;
 HEAP32[$73>>2] = $74;
 $75 = HEAP32[$28>>2]|0;
 HEAP32[$32>>2] = $75;
 ;HEAP8[$20>>0]=HEAP8[$32>>0]|0;HEAP8[$20+1>>0]=HEAP8[$32+1>>0]|0;HEAP8[$20+2>>0]=HEAP8[$32+2>>0]|0;HEAP8[$20+3>>0]=HEAP8[$32+3>>0]|0;
 $19 = $30;
 $76 = $19;
 ;HEAP32[$76>>2]=HEAP32[$20>>2]|0;
 $77 = HEAP32[$30>>2]|0;
 $$sink = $77;$$sink2 = $48;
 while(1) {
  HEAP32[$$sink2>>2] = $$sink;
  $17 = $47;
  $18 = $48;
  $78 = $17;
  $79 = $18;
  $15 = $78;
  $16 = $79;
  $80 = $15;
  $81 = $16;
  $13 = $80;
  $14 = $81;
  $82 = $13;
  $83 = HEAP32[$82>>2]|0;
  $84 = $14;
  $85 = HEAP32[$84>>2]|0;
  $86 = ($83|0)==($85|0);
  $87 = $86 ^ 1;
  if (!($87)) {
   break;
  }
  $12 = $47;
  $88 = $12;
  $11 = $88;
  $89 = $11;
  $10 = $89;
  $90 = $10;
  $91 = HEAP32[$90>>2]|0;
  $92 = ((($91)) + 16|0);
  $9 = $92;
  $93 = $9;
  $8 = $93;
  $94 = $8;
  ;HEAP32[$49>>2]=HEAP32[$94>>2]|0;HEAP32[$49+4>>2]=HEAP32[$94+4>>2]|0;
  $7 = $47;
  $95 = $7;
  $6 = $95;
  $96 = $6;
  $97 = HEAP32[$96>>2]|0;
  $5 = $97;
  $98 = $5;
  $99 = ((($98)) + 4|0);
  $100 = HEAP32[$99>>2]|0;
  $101 = ($100|0)!=(0|0);
  if ($101) {
   $102 = $5;
   $103 = ((($102)) + 4|0);
   $104 = HEAP32[$103>>2]|0;
   $3 = $104;
   while(1) {
    $105 = $3;
    $106 = HEAP32[$105>>2]|0;
    $107 = ($106|0)!=(0|0);
    $108 = $3;
    if (!($107)) {
     break;
    }
    $109 = HEAP32[$108>>2]|0;
    $3 = $109;
   }
   $4 = $108;
  } else {
   while(1) {
    $110 = $5;
    $2 = $110;
    $111 = $2;
    $112 = $2;
    $113 = ((($112)) + 8|0);
    $114 = HEAP32[$113>>2]|0;
    $115 = HEAP32[$114>>2]|0;
    $116 = ($111|0)==($115|0);
    $117 = $116 ^ 1;
    $118 = $5;
    if (!($117)) {
     break;
    }
    $1 = $118;
    $119 = $1;
    $120 = ((($119)) + 8|0);
    $121 = HEAP32[$120>>2]|0;
    $5 = $121;
   }
   $122 = ((($118)) + 8|0);
   $123 = HEAP32[$122>>2]|0;
   $4 = $123;
  }
  $124 = $4;
  $$sink = $124;$$sink2 = $96;
 }
 $129 = ((($50)) + 12|0);
 __ZNSt3__23mapIPN3osg8StateSetEbNS_4lessIS3_EENS_9allocatorINS_4pairIKS3_bEEEEED2Ev($129);
 __ZNSt3__23mapIPvPN3osg8StateSetENS_4lessIS1_EENS_9allocatorINS_4pairIKS1_S4_EEEEED2Ev($50);
 STACKTOP = sp;return;
}
function __ZNSt3__23mapIPN3osg8StateSetEbNS_4lessIS3_EENS_9allocatorINS_4pairIKS3_bEEEEED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 __ZNSt3__26__treeINS_12__value_typeIPN3osg8StateSetEbEENS_19__map_value_compareIS4_S5_NS_4lessIS4_EELb1EEENS_9allocatorIS5_EEED2Ev($2);
 STACKTOP = sp;return;
}
function __ZNSt3__23mapIPvPN3osg8StateSetENS_4lessIS1_EENS_9allocatorINS_4pairIKS1_S4_EEEEED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 __ZNSt3__26__treeINS_12__value_typeIPvPN3osg8StateSetEEENS_19__map_value_compareIS2_S6_NS_4lessIS2_EELb1EEENS_9allocatorIS6_EEED2Ev($2);
 STACKTOP = sp;return;
}
function __ZNSt3__26__treeINS_12__value_typeIPvPN3osg8StateSetEEENS_19__map_value_compareIS2_S6_NS_4lessIS2_EELb1EEENS_9allocatorIS6_EEED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $7 = $0;
 $8 = $7;
 $6 = $8;
 $9 = $6;
 $5 = $9;
 $10 = $5;
 $11 = ((($10)) + 4|0);
 $4 = $11;
 $12 = $4;
 $3 = $12;
 $13 = $3;
 $2 = $13;
 $14 = $2;
 $1 = $14;
 $15 = $1;
 $16 = HEAP32[$15>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIPvPN3osg8StateSetEEENS_19__map_value_compareIS2_S6_NS_4lessIS2_EELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_S2_EE($8,$16);
 STACKTOP = sp;return;
}
function __ZNSt3__26__treeINS_12__value_typeIPvPN3osg8StateSetEEENS_19__map_value_compareIS2_S6_NS_4lessIS2_EELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_S2_EE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(96|0);
 $4 = sp;
 $7 = sp + 80|0;
 $20 = $0;
 $21 = $1;
 $23 = $20;
 $24 = $21;
 $25 = ($24|0)!=(0|0);
 if (!($25)) {
  STACKTOP = sp;return;
 }
 $26 = $21;
 $27 = HEAP32[$26>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIPvPN3osg8StateSetEEENS_19__map_value_compareIS2_S6_NS_4lessIS2_EELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_S2_EE($23,$27);
 $28 = $21;
 $29 = ((($28)) + 4|0);
 $30 = HEAP32[$29>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIPvPN3osg8StateSetEEENS_19__map_value_compareIS2_S6_NS_4lessIS2_EELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_S2_EE($23,$30);
 $12 = $23;
 $31 = $12;
 $32 = ((($31)) + 4|0);
 $11 = $32;
 $33 = $11;
 $10 = $33;
 $34 = $10;
 $22 = $34;
 $35 = $22;
 $36 = $21;
 $37 = ((($36)) + 16|0);
 $9 = $37;
 $38 = $9;
 $8 = $38;
 $39 = $8;
 $5 = $35;
 $6 = $39;
 $40 = $5;
 $41 = $6;
 ;HEAP8[$4>>0]=HEAP8[$7>>0]|0;
 $2 = $40;
 $3 = $41;
 $42 = $22;
 $43 = $21;
 $17 = $42;
 $18 = $43;
 $19 = 1;
 $44 = $17;
 $45 = $18;
 $46 = $19;
 $14 = $44;
 $15 = $45;
 $16 = $46;
 $47 = $15;
 $13 = $47;
 $48 = $13;
 __ZdlPv($48);
 STACKTOP = sp;return;
}
function __ZNSt3__26__treeINS_12__value_typeIPN3osg8StateSetEbEENS_19__map_value_compareIS4_S5_NS_4lessIS4_EELb1EEENS_9allocatorIS5_EEED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $7 = $0;
 $8 = $7;
 $6 = $8;
 $9 = $6;
 $5 = $9;
 $10 = $5;
 $11 = ((($10)) + 4|0);
 $4 = $11;
 $12 = $4;
 $3 = $12;
 $13 = $3;
 $2 = $13;
 $14 = $2;
 $1 = $14;
 $15 = $1;
 $16 = HEAP32[$15>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIPN3osg8StateSetEbEENS_19__map_value_compareIS4_S5_NS_4lessIS4_EELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($8,$16);
 STACKTOP = sp;return;
}
function __ZNSt3__26__treeINS_12__value_typeIPN3osg8StateSetEbEENS_19__map_value_compareIS4_S5_NS_4lessIS4_EELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(96|0);
 $4 = sp;
 $7 = sp + 80|0;
 $20 = $0;
 $21 = $1;
 $23 = $20;
 $24 = $21;
 $25 = ($24|0)!=(0|0);
 if (!($25)) {
  STACKTOP = sp;return;
 }
 $26 = $21;
 $27 = HEAP32[$26>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIPN3osg8StateSetEbEENS_19__map_value_compareIS4_S5_NS_4lessIS4_EELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($23,$27);
 $28 = $21;
 $29 = ((($28)) + 4|0);
 $30 = HEAP32[$29>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIPN3osg8StateSetEbEENS_19__map_value_compareIS4_S5_NS_4lessIS4_EELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($23,$30);
 $12 = $23;
 $31 = $12;
 $32 = ((($31)) + 4|0);
 $11 = $32;
 $33 = $11;
 $10 = $33;
 $34 = $10;
 $22 = $34;
 $35 = $22;
 $36 = $21;
 $37 = ((($36)) + 16|0);
 $9 = $37;
 $38 = $9;
 $8 = $38;
 $39 = $8;
 $5 = $35;
 $6 = $39;
 $40 = $5;
 $41 = $6;
 ;HEAP8[$4>>0]=HEAP8[$7>>0]|0;
 $2 = $40;
 $3 = $41;
 $42 = $22;
 $43 = $21;
 $17 = $42;
 $18 = $43;
 $19 = 1;
 $44 = $17;
 $45 = $18;
 $46 = $19;
 $14 = $44;
 $15 = $45;
 $16 = $46;
 $47 = $15;
 $13 = $47;
 $48 = $13;
 __ZdlPv($48);
 STACKTOP = sp;return;
}
function __ZN4mjin11application6memory8material4Pool17referenceMaterialEPvRKNS2_3RGBE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$sink = 0, $$sink2 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 352|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(352|0);
 $vararg_buffer = sp + 32|0;
 $15 = sp + 24|0;
 $23 = sp + 264|0;
 $25 = sp + 256|0;
 $27 = sp + 248|0;
 $36 = sp + 16|0;
 $40 = sp + 200|0;
 $42 = sp + 192|0;
 $44 = sp + 184|0;
 $52 = sp + 8|0;
 $60 = sp + 124|0;
 $62 = sp + 116|0;
 $64 = sp + 108|0;
 $66 = sp;
 $67 = sp + 100|0;
 $70 = sp + 88|0;
 $73 = sp + 76|0;
 $75 = sp + 68|0;
 $76 = sp + 64|0;
 $79 = sp + 52|0;
 $80 = sp + 48|0;
 $81 = sp + 40|0;
 $72 = $0;
 HEAP32[$73>>2] = $1;
 $74 = $2;
 $82 = $72;
 $68 = $82;
 $69 = $73;
 $83 = $68;
 $84 = $69;
 $85 = (__ZNSt3__26__treeINS_12__value_typeIPvPN3osg8StateSetEEENS_19__map_value_compareIS2_S6_NS_4lessIS2_EELb1EEENS_9allocatorIS6_EEE4findIS2_EENS_15__tree_iteratorIS6_PNS_11__tree_nodeIS6_S2_EEiEERKT_($83,$84)|0);
 HEAP32[$70>>2] = $85;
 ;HEAP8[$66>>0]=HEAP8[$70>>0]|0;HEAP8[$66+1>>0]=HEAP8[$70+1>>0]|0;HEAP8[$66+2>>0]=HEAP8[$70+2>>0]|0;HEAP8[$66+3>>0]=HEAP8[$70+3>>0]|0;
 $65 = $67;
 $86 = $65;
 ;HEAP32[$86>>2]=HEAP32[$66>>2]|0;
 $87 = HEAP32[$67>>2]|0;
 HEAP32[$75>>2] = $87;
 $63 = $82;
 $88 = $63;
 $61 = $88;
 $89 = $61;
 $59 = $89;
 $90 = $59;
 $91 = ((($90)) + 4|0);
 $58 = $91;
 $92 = $58;
 $57 = $92;
 $93 = $57;
 $56 = $93;
 $94 = $56;
 $55 = $94;
 $95 = $55;
 $53 = $60;
 $54 = $95;
 $96 = $53;
 $97 = $54;
 HEAP32[$96>>2] = $97;
 $98 = HEAP32[$60>>2]|0;
 HEAP32[$64>>2] = $98;
 ;HEAP8[$52>>0]=HEAP8[$64>>0]|0;HEAP8[$52+1>>0]=HEAP8[$64+1>>0]|0;HEAP8[$52+2>>0]=HEAP8[$64+2>>0]|0;HEAP8[$52+3>>0]=HEAP8[$64+3>>0]|0;
 $51 = $62;
 $99 = $51;
 ;HEAP32[$99>>2]=HEAP32[$52>>2]|0;
 $100 = HEAP32[$62>>2]|0;
 HEAP32[$76>>2] = $100;
 $49 = $75;
 $50 = $76;
 $101 = $49;
 $102 = $50;
 $47 = $101;
 $48 = $102;
 $103 = $47;
 $104 = $48;
 $45 = $103;
 $46 = $104;
 $105 = $45;
 $106 = HEAP32[$105>>2]|0;
 $107 = $46;
 $108 = HEAP32[$107>>2]|0;
 $109 = ($106|0)==($108|0);
 $110 = $109 ^ 1;
 if ($110) {
  $111 = HEAP32[$73>>2]|0;
  HEAP32[$vararg_buffer>>2] = $111;
  __ZN4mjin3log9logprintfEPKcz(162109,$vararg_buffer);
  $71 = 0;
  $196 = $71;
  STACKTOP = sp;return ($196|0);
 }
 $77 = 0;
 $112 = ((($82)) + 12|0);
 $78 = $112;
 $113 = $78;
 $43 = $113;
 $114 = $43;
 $41 = $114;
 $115 = $41;
 $39 = $115;
 $116 = $39;
 $117 = HEAP32[$116>>2]|0;
 $37 = $40;
 $38 = $117;
 $118 = $37;
 $119 = $38;
 HEAP32[$118>>2] = $119;
 $120 = HEAP32[$40>>2]|0;
 HEAP32[$44>>2] = $120;
 ;HEAP8[$36>>0]=HEAP8[$44>>0]|0;HEAP8[$36+1>>0]=HEAP8[$44+1>>0]|0;HEAP8[$36+2>>0]=HEAP8[$44+2>>0]|0;HEAP8[$36+3>>0]=HEAP8[$44+3>>0]|0;
 $35 = $42;
 $121 = $35;
 ;HEAP32[$121>>2]=HEAP32[$36>>2]|0;
 $122 = HEAP32[$42>>2]|0;
 HEAP32[$79>>2] = $122;
 $123 = $78;
 $26 = $123;
 $124 = $26;
 $24 = $124;
 $125 = $24;
 $22 = $125;
 $126 = $22;
 $127 = ((($126)) + 4|0);
 $21 = $127;
 $128 = $21;
 $20 = $128;
 $129 = $20;
 $19 = $129;
 $130 = $19;
 $18 = $130;
 $131 = $18;
 $16 = $23;
 $17 = $131;
 $132 = $16;
 $133 = $17;
 HEAP32[$132>>2] = $133;
 $134 = HEAP32[$23>>2]|0;
 HEAP32[$27>>2] = $134;
 ;HEAP8[$15>>0]=HEAP8[$27>>0]|0;HEAP8[$15+1>>0]=HEAP8[$27+1>>0]|0;HEAP8[$15+2>>0]=HEAP8[$27+2>>0]|0;HEAP8[$15+3>>0]=HEAP8[$27+3>>0]|0;
 $14 = $25;
 $135 = $14;
 ;HEAP32[$135>>2]=HEAP32[$15>>2]|0;
 $136 = HEAP32[$25>>2]|0;
 $$sink = $136;$$sink2 = $80;
 while(1) {
  HEAP32[$$sink2>>2] = $$sink;
  $7 = $79;
  $8 = $80;
  $137 = $7;
  $138 = $8;
  $5 = $137;
  $6 = $138;
  $139 = $5;
  $140 = $6;
  $3 = $139;
  $4 = $140;
  $141 = $3;
  $142 = HEAP32[$141>>2]|0;
  $143 = $4;
  $144 = HEAP32[$143>>2]|0;
  $145 = ($142|0)==($144|0);
  $146 = $145 ^ 1;
  if (!($146)) {
   label = 16;
   break;
  }
  $13 = $79;
  $147 = $13;
  $12 = $147;
  $148 = $12;
  $11 = $148;
  $149 = $11;
  $150 = HEAP32[$149>>2]|0;
  $151 = ((($150)) + 16|0);
  $10 = $151;
  $152 = $10;
  $9 = $152;
  $153 = $9;
  ;HEAP32[$81>>2]=HEAP32[$153>>2]|0;HEAP32[$81+4>>2]=HEAP32[$153+4>>2]|0;
  $154 = ((($81)) + 4|0);
  $155 = HEAP8[$154>>0]|0;
  $156 = $155&1;
  if (!($156)) {
   label = 6;
   break;
  }
  $34 = $79;
  $161 = $34;
  $33 = $161;
  $162 = $33;
  $163 = HEAP32[$162>>2]|0;
  $32 = $163;
  $164 = $32;
  $165 = ((($164)) + 4|0);
  $166 = HEAP32[$165>>2]|0;
  $167 = ($166|0)!=(0|0);
  if ($167) {
   $168 = $32;
   $169 = ((($168)) + 4|0);
   $170 = HEAP32[$169>>2]|0;
   $30 = $170;
   while(1) {
    $171 = $30;
    $172 = HEAP32[$171>>2]|0;
    $173 = ($172|0)!=(0|0);
    $174 = $30;
    if (!($173)) {
     break;
    }
    $175 = HEAP32[$174>>2]|0;
    $30 = $175;
   }
   $31 = $174;
  } else {
   while(1) {
    $176 = $32;
    $29 = $176;
    $177 = $29;
    $178 = $29;
    $179 = ((($178)) + 8|0);
    $180 = HEAP32[$179>>2]|0;
    $181 = HEAP32[$180>>2]|0;
    $182 = ($177|0)==($181|0);
    $183 = $182 ^ 1;
    $184 = $32;
    if (!($183)) {
     break;
    }
    $28 = $184;
    $185 = $28;
    $186 = ((($185)) + 8|0);
    $187 = HEAP32[$186>>2]|0;
    $32 = $187;
   }
   $188 = ((($184)) + 8|0);
   $189 = HEAP32[$188>>2]|0;
   $31 = $189;
  }
  $190 = $31;
  $$sink = $190;$$sink2 = $162;
 }
 if ((label|0) == 6) {
  $157 = HEAP32[$73>>2]|0;
  $158 = HEAP32[$81>>2]|0;
  $159 = $74;
  $160 = (__ZN4mjin11application6memory8material4Pool9referenceEPvPN3osg8StateSetERKNS2_3RGBE($82,$157,$158,$159)|0);
  $71 = $160;
  $196 = $71;
  STACKTOP = sp;return ($196|0);
 }
 else if ((label|0) == 16) {
  $191 = (__ZN4mjin11application6memory8material4Pool26createUnreferencedMaterialEv($82)|0);
  $77 = $191;
  $192 = HEAP32[$73>>2]|0;
  $193 = $77;
  $194 = $74;
  $195 = (__ZN4mjin11application6memory8material4Pool9referenceEPvPN3osg8StateSetERKNS2_3RGBE($82,$192,$193,$194)|0);
  $71 = $195;
  $196 = $71;
  STACKTOP = sp;return ($196|0);
 }
 return (0)|0;
}
function __ZNSt3__26__treeINS_12__value_typeIPvPN3osg8StateSetEEENS_19__map_value_compareIS2_S6_NS_4lessIS2_EELb1EEENS_9allocatorIS6_EEE4findIS2_EENS_15__tree_iteratorIS6_PNS_11__tree_nodeIS6_S2_EEiEERKT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $12 = 0, $13 = 0, $14 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 208|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(208|0);
 $14 = sp + 144|0;
 $38 = sp + 48|0;
 $46 = sp + 16|0;
 $49 = sp + 4|0;
 $50 = sp;
 $47 = $0;
 $48 = $1;
 $51 = $47;
 $52 = $48;
 $45 = $51;
 $53 = $45;
 $44 = $53;
 $54 = $44;
 $55 = ((($54)) + 4|0);
 $43 = $55;
 $56 = $43;
 $42 = $56;
 $57 = $42;
 $41 = $57;
 $58 = $41;
 $40 = $58;
 $59 = $40;
 $60 = HEAP32[$59>>2]|0;
 $6 = $51;
 $61 = $6;
 $62 = ((($61)) + 4|0);
 $5 = $62;
 $63 = $5;
 $4 = $63;
 $64 = $4;
 $3 = $64;
 $65 = $3;
 $2 = $65;
 $66 = $2;
 $67 = (__ZNSt3__26__treeINS_12__value_typeIPvPN3osg8StateSetEEENS_19__map_value_compareIS2_S6_NS_4lessIS2_EELb1EEENS_9allocatorIS6_EEE13__lower_boundIS2_EENS_15__tree_iteratorIS6_PNS_11__tree_nodeIS6_S2_EEiEERKT_SI_PNS_15__tree_end_nodeIPNS_16__tree_node_baseIS2_EEEE($51,$52,$60,$66)|0);
 HEAP32[$49>>2] = $67;
 $15 = $51;
 $68 = $15;
 $13 = $68;
 $69 = $13;
 $70 = ((($69)) + 4|0);
 $12 = $70;
 $71 = $12;
 $11 = $71;
 $72 = $11;
 $10 = $72;
 $73 = $10;
 $9 = $73;
 $74 = $9;
 $7 = $14;
 $8 = $74;
 $75 = $7;
 $76 = $8;
 HEAP32[$75>>2] = $76;
 $77 = HEAP32[$14>>2]|0;
 HEAP32[$50>>2] = $77;
 $18 = $49;
 $19 = $50;
 $78 = $18;
 $79 = $19;
 $16 = $78;
 $17 = $79;
 $80 = $16;
 $81 = HEAP32[$80>>2]|0;
 $82 = $17;
 $83 = HEAP32[$82>>2]|0;
 $84 = ($81|0)==($83|0);
 $85 = $84 ^ 1;
 if ($85) {
  $22 = $51;
  $86 = $22;
  $87 = ((($86)) + 8|0);
  $21 = $87;
  $88 = $21;
  $20 = $88;
  $89 = $20;
  $90 = $48;
  $24 = $49;
  $91 = $24;
  $23 = $91;
  $92 = $23;
  $93 = HEAP32[$92>>2]|0;
  $94 = ((($93)) + 16|0);
  $28 = $89;
  $29 = $90;
  $30 = $94;
  $95 = $28;
  $96 = $29;
  $97 = $30;
  $25 = $95;
  $26 = $96;
  $27 = $97;
  $98 = $26;
  $99 = HEAP32[$98>>2]|0;
  $100 = $27;
  $101 = HEAP32[$100>>2]|0;
  $102 = ($99>>>0)<($101>>>0);
  $103 = $102 ^ 1;
  if ($103) {
   ;HEAP32[$46>>2]=HEAP32[$49>>2]|0;
   $114 = HEAP32[$46>>2]|0;
   STACKTOP = sp;return ($114|0);
  }
 }
 $39 = $51;
 $104 = $39;
 $37 = $104;
 $105 = $37;
 $106 = ((($105)) + 4|0);
 $36 = $106;
 $107 = $36;
 $35 = $107;
 $108 = $35;
 $34 = $108;
 $109 = $34;
 $33 = $109;
 $110 = $33;
 $31 = $38;
 $32 = $110;
 $111 = $31;
 $112 = $32;
 HEAP32[$111>>2] = $112;
 $113 = HEAP32[$38>>2]|0;
 HEAP32[$46>>2] = $113;
 $114 = HEAP32[$46>>2]|0;
 STACKTOP = sp;return ($114|0);
}
function __ZN4mjin11application6memory8material4Pool9referenceEPvPN3osg8StateSetERKNS2_3RGBE($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0;
 var $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0;
 var $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0.0, $168 = 0, $169 = 0, $17 = 0, $170 = 0.0, $171 = 0;
 var $172 = 0, $173 = 0.0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0.0, $72 = 0.0, $73 = 0, $74 = 0, $75 = 0.0, $76 = 0.0, $77 = 0, $78 = 0, $79 = 0.0, $8 = 0, $80 = 0.0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $vararg_buffer = 0;
 var $vararg_ptr1 = 0, $vararg_ptr2 = 0, $vararg_ptr3 = 0, $vararg_ptr4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 304|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(304|0);
 $vararg_buffer = sp + 8|0;
 $40 = sp;
 $42 = sp + 297|0;
 $53 = sp + 296|0;
 $60 = sp + 80|0;
 $61 = sp + 76|0;
 $63 = sp + 60|0;
 $66 = sp + 40|0;
 $59 = $0;
 HEAP32[$60>>2] = $1;
 HEAP32[$61>>2] = $2;
 $62 = $3;
 $67 = $59;
 $68 = HEAP32[$60>>2]|0;
 $69 = HEAP32[$61>>2]|0;
 $70 = $62;
 $71 = +HEAPF32[$70>>2];
 $72 = $71;
 $73 = $62;
 $74 = ((($73)) + 4|0);
 $75 = +HEAPF32[$74>>2];
 $76 = $75;
 $77 = $62;
 $78 = ((($77)) + 8|0);
 $79 = +HEAPF32[$78>>2];
 $80 = $79;
 HEAP32[$vararg_buffer>>2] = $68;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $69;
 $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
 HEAPF64[$vararg_ptr2>>3] = $72;
 $vararg_ptr3 = ((($vararg_buffer)) + 16|0);
 HEAPF64[$vararg_ptr3>>3] = $76;
 $vararg_ptr4 = ((($vararg_buffer)) + 24|0);
 HEAPF64[$vararg_ptr4>>3] = $80;
 __ZN4mjin3log9logprintfEPKcz(162186,$vararg_buffer);
 $81 = HEAP32[$61>>2]|0;
 $82 = (__ZNSt3__23mapIPvPN3osg8StateSetENS_4lessIS1_EENS_9allocatorINS_4pairIKS1_S4_EEEEEixERS9_($67,$60)|0);
 HEAP32[$82>>2] = $81;
 $83 = ((($67)) + 12|0);
 $84 = (__ZNSt3__23mapIPN3osg8StateSetEbNS_4lessIS3_EENS_9allocatorINS_4pairIKS3_bEEEEEixERS8_($83,$61)|0);
 HEAP8[$84>>0] = 1;
 $85 = HEAP32[$61>>2]|0;
 $57 = $63;
 $58 = 162226;
 $86 = $57;
 $56 = $86;
 $87 = $56;
 $55 = $87;
 $88 = $55;
 $54 = $88;
 ;HEAP32[$88>>2]=0|0;HEAP32[$88+4>>2]=0|0;HEAP32[$88+8>>2]=0|0;
 $89 = $58;
 $90 = $58;
 $91 = (__ZNSt3__211char_traitsIcE6lengthEPKc($90)|0);
 $48 = $86;
 $49 = $89;
 $50 = $91;
 $92 = $48;
 $93 = $50;
 $46 = $92;
 $94 = $46;
 $45 = $94;
 $95 = $45;
 $44 = $95;
 $96 = $44;
 $43 = $96;
 $97 = $43;
 $41 = $97;
 $98 = $41;
 ;HEAP8[$40>>0]=HEAP8[$42>>0]|0;
 $39 = $98;
 $99 = $39;
 $38 = $99;
 $47 = -1;
 $100 = $47;
 $101 = (($100) - 16)|0;
 $102 = ($93>>>0)>($101>>>0);
 if ($102) {
  __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv($92);
  // unreachable;
 }
 $103 = $50;
 $104 = ($103>>>0)<(11);
 $105 = $50;
 if ($104) {
  $36 = $92;
  $37 = $105;
  $106 = $36;
  $107 = $37;
  $108 = $107&255;
  $35 = $106;
  $109 = $35;
  $34 = $109;
  $110 = $34;
  $111 = ((($110)) + 11|0);
  HEAP8[$111>>0] = $108;
  $33 = $92;
  $112 = $33;
  $32 = $112;
  $113 = $32;
  $31 = $113;
  $114 = $31;
  $30 = $114;
  $115 = $30;
  $29 = $115;
  $116 = $29;
  $51 = $116;
 } else {
  $8 = $105;
  $117 = $8;
  $118 = ($117>>>0)<(11);
  if ($118) {
   $125 = 11;
  } else {
   $119 = $8;
   $120 = (($119) + 1)|0;
   $7 = $120;
   $121 = $7;
   $122 = (($121) + 15)|0;
   $123 = $122 & -16;
   $125 = $123;
  }
  $124 = (($125) - 1)|0;
  $52 = $124;
  $6 = $92;
  $126 = $6;
  $5 = $126;
  $127 = $5;
  $4 = $127;
  $128 = $4;
  $129 = $52;
  $130 = (($129) + 1)|0;
  $14 = $128;
  $15 = $130;
  $131 = $14;
  $132 = $15;
  $11 = $131;
  $12 = $132;
  $13 = 0;
  $133 = $11;
  $10 = $133;
  $134 = $12;
  $9 = $134;
  $135 = $9;
  $136 = (__Znwj($135)|0);
  $51 = $136;
  $137 = $51;
  $18 = $92;
  $19 = $137;
  $138 = $18;
  $139 = $19;
  $17 = $138;
  $140 = $17;
  $16 = $140;
  $141 = $16;
  HEAP32[$141>>2] = $139;
  $142 = $52;
  $143 = (($142) + 1)|0;
  $22 = $92;
  $23 = $143;
  $144 = $22;
  $145 = $23;
  $146 = -2147483648 | $145;
  $21 = $144;
  $147 = $21;
  $20 = $147;
  $148 = $20;
  $149 = ((($148)) + 8|0);
  HEAP32[$149>>2] = $146;
  $150 = $50;
  $26 = $92;
  $27 = $150;
  $151 = $26;
  $152 = $27;
  $25 = $151;
  $153 = $25;
  $24 = $153;
  $154 = $24;
  $155 = ((($154)) + 4|0);
  HEAP32[$155>>2] = $152;
 }
 $156 = $51;
 $28 = $156;
 $157 = $28;
 $158 = $49;
 $159 = $50;
 (__ZNSt3__211char_traitsIcE4copyEPcPKcj($157,$158,$159)|0);
 $160 = $51;
 $161 = $50;
 $162 = (($160) + ($161)|0);
 HEAP8[$53>>0] = 0;
 __ZNSt3__211char_traitsIcE6assignERcRKc($162,$53);
 __THREW__ = 0;
 $163 = (invoke_iii(4079,($85|0),($63|0))|0);
 $164 = __THREW__; __THREW__ = 0;
 $165 = $164&1;
 if ($165) {
  $179 = ___cxa_find_matching_catch_2()|0;
  $180 = tempRet0;
  $64 = $179;
  $65 = $180;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($63);
  $181 = $64;
  $182 = $65;
  ___resumeException($181|0);
  // unreachable;
 }
 $166 = $62;
 $167 = +HEAPF32[$166>>2];
 $168 = $62;
 $169 = ((($168)) + 4|0);
 $170 = +HEAPF32[$169>>2];
 $171 = $62;
 $172 = ((($171)) + 8|0);
 $173 = +HEAPF32[$172>>2];
 __THREW__ = 0;
 invoke_viddd(4055,($66|0),(+$167),(+$170),(+$173));
 $174 = __THREW__; __THREW__ = 0;
 $175 = $174&1;
 if ($175) {
  $179 = ___cxa_find_matching_catch_2()|0;
  $180 = tempRet0;
  $64 = $179;
  $65 = $180;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($63);
  $181 = $64;
  $182 = $65;
  ___resumeException($181|0);
  // unreachable;
 }
 __THREW__ = 0;
 (invoke_iii(4080,($163|0),($66|0))|0);
 $176 = __THREW__; __THREW__ = 0;
 $177 = $176&1;
 if ($177) {
  $179 = ___cxa_find_matching_catch_2()|0;
  $180 = tempRet0;
  $64 = $179;
  $65 = $180;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($63);
  $181 = $64;
  $182 = $65;
  ___resumeException($181|0);
  // unreachable;
 } else {
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($63);
  __ZN4mjin11application6memory8material4Pool10printStatsEv($67);
  $178 = HEAP32[$61>>2]|0;
  STACKTOP = sp;return ($178|0);
 }
 return (0)|0;
}
function __ZN4mjin11application6memory8material4Pool26createUnreferencedMaterialEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $3 = (__ZN4mjin11application6memory8material11singleColorEv()|0);
 $2 = $3;
 $4 = $2;
 (__ZNK3osg10Referenced3refEv($4)|0);
 $5 = $2;
 STACKTOP = sp;return ($5|0);
}
function __ZNSt3__23mapIPvPN3osg8StateSetENS_4lessIS1_EENS_9allocatorINS_4pairIKS1_S4_EEEEEixERS9_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(128|0);
 $3 = sp + 117|0;
 $14 = sp + 24|0;
 $15 = sp + 16|0;
 $16 = sp + 8|0;
 $17 = sp;
 $20 = sp + 116|0;
 $21 = sp + 115|0;
 $22 = sp + 114|0;
 $23 = sp + 113|0;
 $25 = sp + 52|0;
 $29 = sp + 32|0;
 $30 = sp + 28|0;
 $31 = sp + 112|0;
 $27 = $0;
 $28 = $1;
 $32 = $27;
 $33 = $28;
 $34 = $28;
 $26 = $34;
 $35 = $26;
 $24 = $35;
 $36 = $24;
 $18 = $25;
 $19 = $36;
 $37 = $18;
 $38 = $19;
 ;HEAP8[$14>>0]=HEAP8[$23>>0]|0;
 ;HEAP8[$15>>0]=HEAP8[$22>>0]|0;
 ;HEAP8[$16>>0]=HEAP8[$21>>0]|0;
 ;HEAP8[$17>>0]=HEAP8[$20>>0]|0;
 $12 = $37;
 $13 = $38;
 $39 = $12;
 $40 = $13;
 $11 = $40;
 $41 = $11;
 $9 = $39;
 $10 = $41;
 $42 = $9;
 $43 = $10;
 $8 = $43;
 $44 = $8;
 HEAP32[$42>>2] = $44;
 $45 = HEAP32[$25>>2]|0;
 HEAP32[$30>>2] = $45;
 $2 = $3;
 __ZNSt3__26__treeINS_12__value_typeIPvPN3osg8StateSetEEENS_19__map_value_compareIS2_S6_NS_4lessIS2_EELb1EEENS_9allocatorIS6_EEE25__emplace_unique_key_argsIS2_JRKNS_21piecewise_construct_tENS_5tupleIJRKS2_EEENSI_IJEEEEEENS_4pairINS_15__tree_iteratorIS6_PNS_11__tree_nodeIS6_S2_EEiEEbEERKT_DpOT0_($29,$32,$33,217119,$30,$31);
 $7 = $29;
 $46 = $7;
 $6 = $46;
 $47 = $6;
 $48 = HEAP32[$47>>2]|0;
 $49 = ((($48)) + 16|0);
 $5 = $49;
 $50 = $5;
 $4 = $50;
 $51 = $4;
 $52 = ((($51)) + 4|0);
 STACKTOP = sp;return ($52|0);
}
function __ZNSt3__23mapIPN3osg8StateSetEbNS_4lessIS3_EENS_9allocatorINS_4pairIKS3_bEEEEEixERS8_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(128|0);
 $3 = sp + 117|0;
 $14 = sp + 24|0;
 $15 = sp + 16|0;
 $16 = sp + 8|0;
 $17 = sp;
 $20 = sp + 116|0;
 $21 = sp + 115|0;
 $22 = sp + 114|0;
 $23 = sp + 113|0;
 $25 = sp + 52|0;
 $29 = sp + 32|0;
 $30 = sp + 28|0;
 $31 = sp + 112|0;
 $27 = $0;
 $28 = $1;
 $32 = $27;
 $33 = $28;
 $34 = $28;
 $26 = $34;
 $35 = $26;
 $24 = $35;
 $36 = $24;
 $18 = $25;
 $19 = $36;
 $37 = $18;
 $38 = $19;
 ;HEAP8[$14>>0]=HEAP8[$23>>0]|0;
 ;HEAP8[$15>>0]=HEAP8[$22>>0]|0;
 ;HEAP8[$16>>0]=HEAP8[$21>>0]|0;
 ;HEAP8[$17>>0]=HEAP8[$20>>0]|0;
 $12 = $37;
 $13 = $38;
 $39 = $12;
 $40 = $13;
 $11 = $40;
 $41 = $11;
 $9 = $39;
 $10 = $41;
 $42 = $9;
 $43 = $10;
 $8 = $43;
 $44 = $8;
 HEAP32[$42>>2] = $44;
 $45 = HEAP32[$25>>2]|0;
 HEAP32[$30>>2] = $45;
 $2 = $3;
 __ZNSt3__26__treeINS_12__value_typeIPN3osg8StateSetEbEENS_19__map_value_compareIS4_S5_NS_4lessIS4_EELb1EEENS_9allocatorIS5_EEE25__emplace_unique_key_argsIS4_JRKNS_21piecewise_construct_tENS_5tupleIJRKS4_EEENSH_IJEEEEEENS_4pairINS_15__tree_iteratorIS5_PNS_11__tree_nodeIS5_PvEEiEEbEERKT_DpOT0_($29,$32,$33,217119,$30,$31);
 $7 = $29;
 $46 = $7;
 $6 = $46;
 $47 = $6;
 $48 = HEAP32[$47>>2]|0;
 $49 = ((($48)) + 16|0);
 $5 = $49;
 $50 = $5;
 $4 = $50;
 $51 = $4;
 $52 = ((($51)) + 4|0);
 STACKTOP = sp;return ($52|0);
}
function __ZN4mjin11application6memory8material4Pool10printStatsEv($0) {
 $0 = $0|0;
 var $$sink = 0, $$sink2 = 0, $$sink3 = 0, $$sink5 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0;
 var $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0;
 var $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0;
 var $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0;
 var $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0;
 var $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $vararg_buffer = 0, $vararg_buffer11 = 0, $vararg_buffer7 = 0, $vararg_ptr10 = 0, $vararg_ptr14 = 0, $vararg_ptr6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 464|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(464|0);
 $vararg_buffer11 = sp + 48|0;
 $vararg_buffer7 = sp + 40|0;
 $vararg_buffer = sp + 32|0;
 $6 = sp + 24|0;
 $10 = sp + 420|0;
 $12 = sp + 412|0;
 $14 = sp + 404|0;
 $16 = sp + 16|0;
 $24 = sp + 368|0;
 $26 = sp + 360|0;
 $28 = sp + 352|0;
 $48 = sp + 8|0;
 $52 = sp + 260|0;
 $54 = sp + 252|0;
 $56 = sp + 244|0;
 $58 = sp;
 $66 = sp + 208|0;
 $68 = sp + 200|0;
 $70 = sp + 192|0;
 $95 = sp + 92|0;
 $96 = sp + 88|0;
 $97 = sp + 80|0;
 $99 = sp + 68|0;
 $100 = sp + 64|0;
 $101 = sp + 56|0;
 $93 = $0;
 $102 = $93;
 $92 = $102;
 $103 = $92;
 $91 = $103;
 $104 = $91;
 $105 = ((($104)) + 8|0);
 $90 = $105;
 $106 = $90;
 $89 = $106;
 $107 = $89;
 $108 = HEAP32[$107>>2]|0;
 $109 = ((($102)) + 12|0);
 $4 = $109;
 $110 = $4;
 $3 = $110;
 $111 = $3;
 $112 = ((($111)) + 8|0);
 $2 = $112;
 $113 = $2;
 $1 = $113;
 $114 = $1;
 $115 = HEAP32[$114>>2]|0;
 HEAP32[$vararg_buffer>>2] = $108;
 $vararg_ptr6 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr6>>2] = $115;
 __ZN4mjin3log9logprintfEPKcz(162232,$vararg_buffer);
 $94 = $102;
 $116 = $94;
 $13 = $116;
 $117 = $13;
 $11 = $117;
 $118 = $11;
 $9 = $118;
 $119 = $9;
 $120 = HEAP32[$119>>2]|0;
 $7 = $10;
 $8 = $120;
 $121 = $7;
 $122 = $8;
 HEAP32[$121>>2] = $122;
 $123 = HEAP32[$10>>2]|0;
 HEAP32[$14>>2] = $123;
 ;HEAP8[$6>>0]=HEAP8[$14>>0]|0;HEAP8[$6+1>>0]=HEAP8[$14+1>>0]|0;HEAP8[$6+2>>0]=HEAP8[$14+2>>0]|0;HEAP8[$6+3>>0]=HEAP8[$14+3>>0]|0;
 $5 = $12;
 $124 = $5;
 ;HEAP32[$124>>2]=HEAP32[$6>>2]|0;
 $125 = HEAP32[$12>>2]|0;
 HEAP32[$95>>2] = $125;
 $126 = $94;
 $27 = $126;
 $127 = $27;
 $25 = $127;
 $128 = $25;
 $23 = $128;
 $129 = $23;
 $130 = ((($129)) + 4|0);
 $22 = $130;
 $131 = $22;
 $21 = $131;
 $132 = $21;
 $20 = $132;
 $133 = $20;
 $19 = $133;
 $134 = $19;
 $17 = $24;
 $18 = $134;
 $135 = $17;
 $136 = $18;
 HEAP32[$135>>2] = $136;
 $137 = HEAP32[$24>>2]|0;
 HEAP32[$28>>2] = $137;
 ;HEAP8[$16>>0]=HEAP8[$28>>0]|0;HEAP8[$16+1>>0]=HEAP8[$28+1>>0]|0;HEAP8[$16+2>>0]=HEAP8[$28+2>>0]|0;HEAP8[$16+3>>0]=HEAP8[$28+3>>0]|0;
 $15 = $26;
 $138 = $15;
 ;HEAP32[$138>>2]=HEAP32[$16>>2]|0;
 $139 = HEAP32[$26>>2]|0;
 $$sink = $139;$$sink2 = $96;
 while(1) {
  HEAP32[$$sink2>>2] = $$sink;
  $33 = $95;
  $34 = $96;
  $140 = $33;
  $141 = $34;
  $31 = $140;
  $32 = $141;
  $142 = $31;
  $143 = $32;
  $29 = $142;
  $30 = $143;
  $144 = $29;
  $145 = HEAP32[$144>>2]|0;
  $146 = $30;
  $147 = HEAP32[$146>>2]|0;
  $148 = ($145|0)==($147|0);
  $149 = $148 ^ 1;
  if (!($149)) {
   break;
  }
  $39 = $95;
  $150 = $39;
  $38 = $150;
  $151 = $38;
  $37 = $151;
  $152 = $37;
  $153 = HEAP32[$152>>2]|0;
  $154 = ((($153)) + 16|0);
  $36 = $154;
  $155 = $36;
  $35 = $155;
  $156 = $35;
  ;HEAP32[$97>>2]=HEAP32[$156>>2]|0;HEAP32[$97+4>>2]=HEAP32[$156+4>>2]|0;
  $157 = HEAP32[$97>>2]|0;
  $158 = ((($97)) + 4|0);
  $159 = HEAP32[$158>>2]|0;
  HEAP32[$vararg_buffer7>>2] = $157;
  $vararg_ptr10 = ((($vararg_buffer7)) + 4|0);
  HEAP32[$vararg_ptr10>>2] = $159;
  __ZN4mjin3log9logprintfEPKcz(162285,$vararg_buffer7);
  $46 = $95;
  $160 = $46;
  $45 = $160;
  $161 = $45;
  $162 = HEAP32[$161>>2]|0;
  $44 = $162;
  $163 = $44;
  $164 = ((($163)) + 4|0);
  $165 = HEAP32[$164>>2]|0;
  $166 = ($165|0)!=(0|0);
  if ($166) {
   $167 = $44;
   $168 = ((($167)) + 4|0);
   $169 = HEAP32[$168>>2]|0;
   $42 = $169;
   while(1) {
    $170 = $42;
    $171 = HEAP32[$170>>2]|0;
    $172 = ($171|0)!=(0|0);
    $173 = $42;
    if (!($172)) {
     break;
    }
    $174 = HEAP32[$173>>2]|0;
    $42 = $174;
   }
   $43 = $173;
  } else {
   while(1) {
    $175 = $44;
    $41 = $175;
    $176 = $41;
    $177 = $41;
    $178 = ((($177)) + 8|0);
    $179 = HEAP32[$178>>2]|0;
    $180 = HEAP32[$179>>2]|0;
    $181 = ($176|0)==($180|0);
    $182 = $181 ^ 1;
    $183 = $44;
    if (!($182)) {
     break;
    }
    $40 = $183;
    $184 = $40;
    $185 = ((($184)) + 8|0);
    $186 = HEAP32[$185>>2]|0;
    $44 = $186;
   }
   $187 = ((($183)) + 8|0);
   $188 = HEAP32[$187>>2]|0;
   $43 = $188;
  }
  $189 = $43;
  $$sink = $189;$$sink2 = $161;
 }
 $190 = ((($102)) + 12|0);
 $98 = $190;
 $191 = $98;
 $55 = $191;
 $192 = $55;
 $53 = $192;
 $193 = $53;
 $51 = $193;
 $194 = $51;
 $195 = HEAP32[$194>>2]|0;
 $49 = $52;
 $50 = $195;
 $196 = $49;
 $197 = $50;
 HEAP32[$196>>2] = $197;
 $198 = HEAP32[$52>>2]|0;
 HEAP32[$56>>2] = $198;
 ;HEAP8[$48>>0]=HEAP8[$56>>0]|0;HEAP8[$48+1>>0]=HEAP8[$56+1>>0]|0;HEAP8[$48+2>>0]=HEAP8[$56+2>>0]|0;HEAP8[$48+3>>0]=HEAP8[$56+3>>0]|0;
 $47 = $54;
 $199 = $47;
 ;HEAP32[$199>>2]=HEAP32[$48>>2]|0;
 $200 = HEAP32[$54>>2]|0;
 HEAP32[$99>>2] = $200;
 $201 = $98;
 $69 = $201;
 $202 = $69;
 $67 = $202;
 $203 = $67;
 $65 = $203;
 $204 = $65;
 $205 = ((($204)) + 4|0);
 $64 = $205;
 $206 = $64;
 $63 = $206;
 $207 = $63;
 $62 = $207;
 $208 = $62;
 $61 = $208;
 $209 = $61;
 $59 = $66;
 $60 = $209;
 $210 = $59;
 $211 = $60;
 HEAP32[$210>>2] = $211;
 $212 = HEAP32[$66>>2]|0;
 HEAP32[$70>>2] = $212;
 ;HEAP8[$58>>0]=HEAP8[$70>>0]|0;HEAP8[$58+1>>0]=HEAP8[$70+1>>0]|0;HEAP8[$58+2>>0]=HEAP8[$70+2>>0]|0;HEAP8[$58+3>>0]=HEAP8[$70+3>>0]|0;
 $57 = $68;
 $213 = $57;
 ;HEAP32[$213>>2]=HEAP32[$58>>2]|0;
 $214 = HEAP32[$68>>2]|0;
 $$sink3 = $214;$$sink5 = $100;
 while(1) {
  HEAP32[$$sink5>>2] = $$sink3;
  $75 = $99;
  $76 = $100;
  $215 = $75;
  $216 = $76;
  $73 = $215;
  $74 = $216;
  $217 = $73;
  $218 = $74;
  $71 = $217;
  $72 = $218;
  $219 = $71;
  $220 = HEAP32[$219>>2]|0;
  $221 = $72;
  $222 = HEAP32[$221>>2]|0;
  $223 = ($220|0)==($222|0);
  $224 = $223 ^ 1;
  if (!($224)) {
   break;
  }
  $81 = $99;
  $225 = $81;
  $80 = $225;
  $226 = $80;
  $79 = $226;
  $227 = $79;
  $228 = HEAP32[$227>>2]|0;
  $229 = ((($228)) + 16|0);
  $78 = $229;
  $230 = $78;
  $77 = $230;
  $231 = $77;
  ;HEAP32[$101>>2]=HEAP32[$231>>2]|0;HEAP32[$101+4>>2]=HEAP32[$231+4>>2]|0;
  $232 = HEAP32[$101>>2]|0;
  $233 = ((($101)) + 4|0);
  $234 = HEAP8[$233>>0]|0;
  $235 = $234&1;
  $236 = $235&1;
  HEAP32[$vararg_buffer11>>2] = $232;
  $vararg_ptr14 = ((($vararg_buffer11)) + 4|0);
  HEAP32[$vararg_ptr14>>2] = $236;
  __ZN4mjin3log9logprintfEPKcz(162335,$vararg_buffer11);
  $88 = $99;
  $237 = $88;
  $87 = $237;
  $238 = $87;
  $239 = HEAP32[$238>>2]|0;
  $86 = $239;
  $240 = $86;
  $241 = ((($240)) + 4|0);
  $242 = HEAP32[$241>>2]|0;
  $243 = ($242|0)!=(0|0);
  if ($243) {
   $244 = $86;
   $245 = ((($244)) + 4|0);
   $246 = HEAP32[$245>>2]|0;
   $84 = $246;
   while(1) {
    $247 = $84;
    $248 = HEAP32[$247>>2]|0;
    $249 = ($248|0)!=(0|0);
    $250 = $84;
    if (!($249)) {
     break;
    }
    $251 = HEAP32[$250>>2]|0;
    $84 = $251;
   }
   $85 = $250;
  } else {
   while(1) {
    $252 = $86;
    $83 = $252;
    $253 = $83;
    $254 = $83;
    $255 = ((($254)) + 8|0);
    $256 = HEAP32[$255>>2]|0;
    $257 = HEAP32[$256>>2]|0;
    $258 = ($253|0)==($257|0);
    $259 = $258 ^ 1;
    $260 = $86;
    if (!($259)) {
     break;
    }
    $82 = $260;
    $261 = $82;
    $262 = ((($261)) + 8|0);
    $263 = HEAP32[$262>>2]|0;
    $86 = $263;
   }
   $264 = ((($260)) + 8|0);
   $265 = HEAP32[$264>>2]|0;
   $85 = $265;
  }
  $266 = $85;
  $$sink3 = $266;$$sink5 = $238;
 }
 STACKTOP = sp;return;
}
function __ZNSt3__26__treeINS_12__value_typeIPN3osg8StateSetEbEENS_19__map_value_compareIS4_S5_NS_4lessIS4_EELb1EEENS_9allocatorIS5_EEE25__emplace_unique_key_argsIS4_JRKNS_21piecewise_construct_tENS_5tupleIJRKS4_EEENSH_IJEEEEEENS_4pairINS_15__tree_iteratorIS5_PNS_11__tree_nodeIS5_PvEEiEEbEERKT_DpOT0_($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0;
 var $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0;
 var $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0;
 var $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0;
 var $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 352|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(352|0);
 $29 = sp + 8|0;
 $32 = sp + 346|0;
 $57 = sp;
 $60 = sp + 345|0;
 $84 = sp + 44|0;
 $87 = sp + 344|0;
 $88 = sp + 24|0;
 $91 = sp + 12|0;
 $79 = $1;
 $80 = $2;
 $81 = $3;
 $82 = $4;
 $83 = $5;
 $92 = $79;
 $93 = $80;
 $94 = (__ZNSt3__26__treeINS_12__value_typeIPN3osg8StateSetEbEENS_19__map_value_compareIS4_S5_NS_4lessIS4_EELb1EEENS_9allocatorIS5_EEE12__find_equalIS4_EERPNS_16__tree_node_baseIPvEERPNS_15__tree_end_nodeISH_EERKT_($92,$84,$93)|0);
 $85 = $94;
 $95 = $85;
 $96 = HEAP32[$95>>2]|0;
 $86 = $96;
 HEAP8[$87>>0] = 0;
 $97 = $85;
 $98 = HEAP32[$97>>2]|0;
 $99 = ($98|0)==(0|0);
 do {
  if ($99) {
   $100 = $81;
   $78 = $100;
   $101 = $78;
   $102 = $82;
   $43 = $102;
   $103 = $43;
   $104 = $83;
   $15 = $104;
   $105 = $15;
   __ZNSt3__26__treeINS_12__value_typeIPN3osg8StateSetEbEENS_19__map_value_compareIS4_S5_NS_4lessIS4_EELb1EEENS_9allocatorIS5_EEE16__construct_nodeIJRKNS_21piecewise_construct_tENS_5tupleIJRKS4_EEENSH_IJEEEEEENS_10unique_ptrINS_11__tree_nodeIS5_PvEENS_22__tree_node_destructorINSA_ISP_EEEEEEDpOT_($88,$92,$101,$103,$105);
   $106 = HEAP32[$84>>2]|0;
   $107 = $85;
   $8 = $88;
   $108 = $8;
   $7 = $108;
   $109 = $7;
   $6 = $109;
   $110 = $6;
   $111 = HEAP32[$110>>2]|0;
   __THREW__ = 0;
   invoke_viiii(4081,($92|0),($106|0),($107|0),($111|0));
   $112 = __THREW__; __THREW__ = 0;
   $113 = $112&1;
   if (!($113)) {
    $13 = $88;
    $114 = $13;
    $12 = $114;
    $115 = $12;
    $11 = $115;
    $116 = $11;
    $117 = HEAP32[$116>>2]|0;
    $14 = $117;
    $10 = $114;
    $118 = $10;
    $9 = $118;
    $119 = $9;
    HEAP32[$119>>2] = 0;
    $120 = $14;
    $86 = $120;
    HEAP8[$87>>0] = 1;
    $42 = $88;
    $121 = $42;
    $39 = $121;
    $40 = 0;
    $122 = $39;
    $38 = $122;
    $123 = $38;
    $37 = $123;
    $124 = $37;
    $125 = HEAP32[$124>>2]|0;
    $41 = $125;
    $126 = $40;
    $19 = $122;
    $127 = $19;
    $18 = $127;
    $128 = $18;
    HEAP32[$128>>2] = $126;
    $129 = $41;
    $130 = ($129|0)!=(0|0);
    if (!($130)) {
     break;
    }
    $17 = $122;
    $131 = $17;
    $16 = $131;
    $132 = $16;
    $133 = ((($132)) + 4|0);
    $134 = $41;
    $35 = $133;
    $36 = $134;
    $135 = $35;
    $136 = ((($135)) + 4|0);
    $137 = HEAP8[$136>>0]|0;
    $138 = $137&1;
    if ($138) {
     $139 = HEAP32[$135>>2]|0;
     $140 = $36;
     $141 = ((($140)) + 16|0);
     $34 = $141;
     $142 = $34;
     $33 = $142;
     $143 = $33;
     $30 = $139;
     $31 = $143;
     $144 = $30;
     $145 = $31;
     ;HEAP8[$29>>0]=HEAP8[$32>>0]|0;
     $27 = $144;
     $28 = $145;
    }
    $146 = $36;
    $147 = ($146|0)!=(0|0);
    if (!($147)) {
     break;
    }
    $148 = HEAP32[$135>>2]|0;
    $149 = $36;
    $24 = $148;
    $25 = $149;
    $26 = 1;
    $150 = $24;
    $151 = $25;
    $152 = $26;
    $21 = $150;
    $22 = $151;
    $23 = $152;
    $153 = $22;
    $20 = $153;
    $154 = $20;
    __ZdlPv($154);
    break;
   }
   $155 = ___cxa_find_matching_catch_2()|0;
   $156 = tempRet0;
   $89 = $155;
   $90 = $156;
   $70 = $88;
   $157 = $70;
   $67 = $157;
   $68 = 0;
   $158 = $67;
   $66 = $158;
   $159 = $66;
   $65 = $159;
   $160 = $65;
   $161 = HEAP32[$160>>2]|0;
   $69 = $161;
   $162 = $68;
   $47 = $158;
   $163 = $47;
   $46 = $163;
   $164 = $46;
   HEAP32[$164>>2] = $162;
   $165 = $69;
   $166 = ($165|0)!=(0|0);
   if (!($166)) {
    $203 = $89;
    $204 = $90;
    ___resumeException($203|0);
    // unreachable;
   }
   $45 = $158;
   $167 = $45;
   $44 = $167;
   $168 = $44;
   $169 = ((($168)) + 4|0);
   $170 = $69;
   $63 = $169;
   $64 = $170;
   $171 = $63;
   $172 = ((($171)) + 4|0);
   $173 = HEAP8[$172>>0]|0;
   $174 = $173&1;
   if ($174) {
    $175 = HEAP32[$171>>2]|0;
    $176 = $64;
    $177 = ((($176)) + 16|0);
    $62 = $177;
    $178 = $62;
    $61 = $178;
    $179 = $61;
    $58 = $175;
    $59 = $179;
    $180 = $58;
    $181 = $59;
    ;HEAP8[$57>>0]=HEAP8[$60>>0]|0;
    $55 = $180;
    $56 = $181;
   }
   $182 = $64;
   $183 = ($182|0)!=(0|0);
   if (!($183)) {
    $203 = $89;
    $204 = $90;
    ___resumeException($203|0);
    // unreachable;
   }
   $184 = HEAP32[$171>>2]|0;
   $185 = $64;
   $52 = $184;
   $53 = $185;
   $54 = 1;
   $186 = $52;
   $187 = $53;
   $188 = $54;
   $49 = $186;
   $50 = $187;
   $51 = $188;
   $189 = $50;
   $48 = $189;
   $190 = $48;
   __ZdlPv($190);
   $203 = $89;
   $204 = $90;
   ___resumeException($203|0);
   // unreachable;
  }
 } while(0);
 $191 = $86;
 $71 = $91;
 $72 = $191;
 $192 = $71;
 $193 = $72;
 HEAP32[$192>>2] = $193;
 $75 = $0;
 $76 = $91;
 $77 = $87;
 $194 = $75;
 $195 = $76;
 $74 = $195;
 $196 = $74;
 ;HEAP32[$194>>2]=HEAP32[$196>>2]|0;
 $197 = ((($194)) + 4|0);
 $198 = $77;
 $73 = $198;
 $199 = $73;
 $200 = HEAP8[$199>>0]|0;
 $201 = $200&1;
 $202 = $201&1;
 HEAP8[$197>>0] = $202;
 STACKTOP = sp;return;
}
function __ZNSt3__26__treeINS_12__value_typeIPN3osg8StateSetEbEENS_19__map_value_compareIS4_S5_NS_4lessIS4_EELb1EEENS_9allocatorIS5_EEE12__find_equalIS4_EERPNS_16__tree_node_baseIPvEERPNS_15__tree_end_nodeISH_EERKT_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $12 = 0;
 var $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(160|0);
 $35 = $0;
 $36 = $1;
 $37 = $2;
 $40 = $35;
 $33 = $40;
 $41 = $33;
 $32 = $41;
 $42 = $32;
 $43 = ((($42)) + 4|0);
 $31 = $43;
 $44 = $31;
 $30 = $44;
 $45 = $30;
 $29 = $45;
 $46 = $29;
 $28 = $46;
 $47 = $28;
 $48 = HEAP32[$47>>2]|0;
 $38 = $48;
 $49 = (__ZNKSt3__26__treeINS_12__value_typeIPN3osg8StateSetEbEENS_19__map_value_compareIS4_S5_NS_4lessIS4_EELb1EEENS_9allocatorIS5_EEE10__root_ptrEv($40)|0);
 $39 = $49;
 $50 = $38;
 $51 = ($50|0)!=(0|0);
 if (!($51)) {
  $27 = $40;
  $107 = $27;
  $108 = ((($107)) + 4|0);
  $26 = $108;
  $109 = $26;
  $25 = $109;
  $110 = $25;
  $24 = $110;
  $111 = $24;
  $23 = $111;
  $112 = $23;
  $113 = $36;
  HEAP32[$113>>2] = $112;
  $114 = $36;
  $115 = HEAP32[$114>>2]|0;
  $34 = $115;
  $116 = $34;
  STACKTOP = sp;return ($116|0);
 }
 while(1) {
  $5 = $40;
  $52 = $5;
  $53 = ((($52)) + 8|0);
  $4 = $53;
  $54 = $4;
  $3 = $54;
  $55 = $3;
  $56 = $37;
  $57 = $38;
  $58 = ((($57)) + 16|0);
  $9 = $55;
  $10 = $56;
  $11 = $58;
  $59 = $9;
  $60 = $10;
  $61 = $11;
  $6 = $59;
  $7 = $60;
  $8 = $61;
  $62 = $7;
  $63 = HEAP32[$62>>2]|0;
  $64 = $8;
  $65 = HEAP32[$64>>2]|0;
  $66 = ($63>>>0)<($65>>>0);
  if ($66) {
   $67 = $38;
   $68 = HEAP32[$67>>2]|0;
   $69 = ($68|0)!=(0|0);
   $70 = $38;
   if (!($69)) {
    label = 5;
    break;
   }
   $12 = $70;
   $71 = $12;
   $39 = $71;
   $72 = $38;
   $73 = HEAP32[$72>>2]|0;
   $38 = $73;
   continue;
  }
  $15 = $40;
  $77 = $15;
  $78 = ((($77)) + 8|0);
  $14 = $78;
  $79 = $14;
  $13 = $79;
  $80 = $13;
  $81 = $38;
  $82 = ((($81)) + 16|0);
  $83 = $37;
  $19 = $80;
  $20 = $82;
  $21 = $83;
  $84 = $19;
  $85 = $20;
  $86 = $21;
  $16 = $84;
  $17 = $85;
  $18 = $86;
  $87 = $17;
  $88 = HEAP32[$87>>2]|0;
  $89 = $18;
  $90 = HEAP32[$89>>2]|0;
  $91 = ($88>>>0)<($90>>>0);
  $92 = $38;
  if (!($91)) {
   label = 10;
   break;
  }
  $93 = ((($92)) + 4|0);
  $94 = HEAP32[$93>>2]|0;
  $95 = ($94|0)!=(0|0);
  $96 = $38;
  if (!($95)) {
   label = 9;
   break;
  }
  $97 = ((($96)) + 4|0);
  $22 = $97;
  $98 = $22;
  $39 = $98;
  $99 = $38;
  $100 = ((($99)) + 4|0);
  $101 = HEAP32[$100>>2]|0;
  $38 = $101;
 }
 if ((label|0) == 5) {
  $74 = $36;
  HEAP32[$74>>2] = $70;
  $75 = $36;
  $76 = HEAP32[$75>>2]|0;
  $34 = $76;
  $116 = $34;
  STACKTOP = sp;return ($116|0);
 }
 else if ((label|0) == 9) {
  $102 = $36;
  HEAP32[$102>>2] = $96;
  $103 = $38;
  $104 = ((($103)) + 4|0);
  $34 = $104;
  $116 = $34;
  STACKTOP = sp;return ($116|0);
 }
 else if ((label|0) == 10) {
  $105 = $36;
  HEAP32[$105>>2] = $92;
  $106 = $39;
  $34 = $106;
  $116 = $34;
  STACKTOP = sp;return ($116|0);
 }
 return (0)|0;
}
function __ZNSt3__26__treeINS_12__value_typeIPN3osg8StateSetEbEENS_19__map_value_compareIS4_S5_NS_4lessIS4_EELb1EEENS_9allocatorIS5_EEE16__construct_nodeIJRKNS_21piecewise_construct_tENS_5tupleIJRKS4_EEENSH_IJEEEEEENS_10unique_ptrINS_11__tree_nodeIS5_PvEENS_22__tree_node_destructorINSA_ISP_EEEEEEDpOT_($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$expand_i1_val = 0, $$expand_i1_val2 = 0, $$pre_trunc = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0;
 var $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0;
 var $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 528|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(528|0);
 $18 = sp + 72|0;
 $19 = sp + 64|0;
 $20 = sp + 56|0;
 $22 = sp + 524|0;
 $23 = sp + 523|0;
 $24 = sp + 522|0;
 $25 = sp + 48|0;
 $26 = sp + 40|0;
 $27 = sp + 32|0;
 $34 = sp + 521|0;
 $35 = sp + 432|0;
 $36 = sp + 520|0;
 $43 = sp + 24|0;
 $50 = sp + 519|0;
 $65 = sp + 324|0;
 $66 = sp + 16|0;
 $69 = sp + 312|0;
 $70 = sp + 304|0;
 $71 = sp + 8|0;
 $76 = sp + 280|0;
 $105 = sp;
 $108 = sp + 517|0;
 $127 = sp + 516|0;
 $128 = sp + 80|0;
 $122 = $1;
 $123 = $2;
 $124 = $3;
 $125 = $4;
 $129 = $122;
 $121 = $129;
 $130 = $121;
 $131 = ((($130)) + 4|0);
 $120 = $131;
 $132 = $120;
 $119 = $132;
 $133 = $119;
 $126 = $133;
 $$expand_i1_val = 0;
 HEAP8[$127>>0] = $$expand_i1_val;
 $134 = $126;
 $90 = $134;
 $91 = 1;
 $135 = $90;
 $136 = $91;
 $87 = $135;
 $88 = $136;
 $89 = 0;
 $137 = $87;
 $138 = $88;
 $86 = $137;
 $139 = ($138>>>0)>(178956970);
 if ($139) {
  $82 = 204840;
  $140 = (___cxa_allocate_exception(8)|0);
  $141 = $82;
  $80 = $140;
  $81 = $141;
  $142 = $80;
  $143 = $81;
  __THREW__ = 0;
  invoke_vii(3366,($142|0),($143|0));
  $144 = __THREW__; __THREW__ = 0;
  $145 = $144&1;
  if ($145) {
   $146 = ___cxa_find_matching_catch_2()|0;
   $147 = tempRet0;
   $83 = $146;
   $84 = $147;
   ___cxa_free_exception(($140|0));
   $148 = $83;
   $149 = $84;
   ___resumeException($148|0);
   // unreachable;
  } else {
   HEAP32[$142>>2] = (99824);
   ___cxa_throw(($140|0),(34608|0),(3230|0));
   // unreachable;
  }
 }
 $150 = $88;
 $151 = ($150*24)|0;
 $85 = $151;
 $152 = $85;
 $153 = (__Znwj($152)|0);
 $154 = $126;
 $77 = $128;
 $78 = $154;
 $79 = 0;
 $155 = $77;
 $156 = $78;
 HEAP32[$155>>2] = $156;
 $157 = ((($155)) + 4|0);
 $158 = $79;
 $159 = $158&1;
 $160 = $159&1;
 HEAP8[$157>>0] = $160;
 $73 = $0;
 $74 = $153;
 $75 = $128;
 $161 = $73;
 $162 = $74;
 $163 = $75;
 $72 = $163;
 $164 = $72;
 ;HEAP32[$76>>2]=HEAP32[$164>>2]|0;HEAP32[$76+4>>2]=HEAP32[$164+4>>2]|0;
 ;HEAP8[$71>>0]=HEAP8[$76>>0]|0;HEAP8[$71+1>>0]=HEAP8[$76+1>>0]|0;HEAP8[$71+2>>0]=HEAP8[$76+2>>0]|0;HEAP8[$71+3>>0]=HEAP8[$76+3>>0]|0;HEAP8[$71+4>>0]=HEAP8[$76+4>>0]|0;HEAP8[$71+5>>0]=HEAP8[$76+5>>0]|0;HEAP8[$71+6>>0]=HEAP8[$76+6>>0]|0;HEAP8[$71+7>>0]=HEAP8[$76+7>>0]|0;
 $68 = $161;
 HEAP32[$69>>2] = $162;
 $165 = $68;
 $67 = $69;
 $166 = $67;
 $167 = HEAP32[$166>>2]|0;
 $61 = $71;
 $168 = $61;
 ;HEAP32[$70>>2]=HEAP32[$168>>2]|0;HEAP32[$70+4>>2]=HEAP32[$168+4>>2]|0;
 ;HEAP8[$66>>0]=HEAP8[$70>>0]|0;HEAP8[$66+1>>0]=HEAP8[$70+1>>0]|0;HEAP8[$66+2>>0]=HEAP8[$70+2>>0]|0;HEAP8[$66+3>>0]=HEAP8[$70+3>>0]|0;HEAP8[$66+4>>0]=HEAP8[$70+4>>0]|0;HEAP8[$66+5>>0]=HEAP8[$70+5>>0]|0;HEAP8[$66+6>>0]=HEAP8[$70+6>>0]|0;HEAP8[$66+7>>0]=HEAP8[$70+7>>0]|0;
 $64 = $165;
 HEAP32[$65>>2] = $167;
 $169 = $64;
 $63 = $65;
 $170 = $63;
 $171 = HEAP32[$170>>2]|0;
 HEAP32[$169>>2] = $171;
 $172 = ((($169)) + 4|0);
 $62 = $66;
 $173 = $62;
 ;HEAP32[$172>>2]=HEAP32[$173>>2]|0;HEAP32[$172+4>>2]=HEAP32[$173+4>>2]|0;
 $174 = $126;
 $60 = $0;
 $175 = $60;
 $59 = $175;
 $176 = $59;
 $58 = $176;
 $177 = $58;
 $178 = HEAP32[$177>>2]|0;
 $179 = ((($178)) + 16|0);
 $57 = $179;
 $180 = $57;
 $56 = $180;
 $181 = $56;
 $182 = $123;
 $55 = $182;
 $183 = $55;
 $184 = $124;
 $54 = $184;
 $185 = $54;
 $186 = $125;
 $5 = $186;
 $187 = $5;
 $45 = $174;
 $46 = $181;
 $47 = $183;
 $48 = $185;
 $49 = $187;
 $188 = $45;
 $189 = $46;
 $190 = $47;
 $44 = $190;
 $191 = $44;
 $192 = $48;
 $6 = $192;
 $193 = $6;
 $194 = $49;
 $7 = $194;
 $195 = $7;
 ;HEAP8[$43>>0]=HEAP8[$50>>0]|0;
 $38 = $188;
 $39 = $189;
 $40 = $191;
 $41 = $193;
 $42 = $195;
 $196 = $38;
 $197 = $39;
 $198 = $40;
 $37 = $198;
 $199 = $37;
 $200 = $41;
 $8 = $200;
 $201 = $8;
 $202 = $42;
 $9 = $202;
 $203 = $9;
 $29 = $196;
 $30 = $197;
 $31 = $199;
 $32 = $201;
 $33 = $203;
 $204 = $30;
 $205 = $31;
 $28 = $205;
 $206 = $32;
 $10 = $206;
 $207 = $10;
 ;HEAP32[$35>>2]=HEAP32[$207>>2]|0;
 $208 = $33;
 $11 = $208;
 ;HEAP8[$25>>0]=HEAP8[$36>>0]|0;
 ;HEAP8[$26>>0]=HEAP8[$35>>0]|0;HEAP8[$26+1>>0]=HEAP8[$35+1>>0]|0;HEAP8[$26+2>>0]=HEAP8[$35+2>>0]|0;HEAP8[$26+3>>0]=HEAP8[$35+3>>0]|0;
 ;HEAP8[$27>>0]=HEAP8[$34>>0]|0;
 $21 = $204;
 $209 = $21;
 ;HEAP8[$18>>0]=HEAP8[$24>>0]|0;
 ;HEAP8[$19>>0]=HEAP8[$23>>0]|0;
 ;HEAP8[$20>>0]=HEAP8[$22>>0]|0;
 $15 = $209;
 $16 = $26;
 $17 = $25;
 $210 = $15;
 $211 = $16;
 $14 = $211;
 $212 = $14;
 $13 = $212;
 $213 = $13;
 $214 = HEAP32[$213>>2]|0;
 $12 = $214;
 $215 = $12;
 $216 = HEAP32[$215>>2]|0;
 HEAP32[$210>>2] = $216;
 $217 = ((($210)) + 4|0);
 HEAP8[$217>>0] = 0;
 $53 = $0;
 $218 = $53;
 $52 = $218;
 $219 = $52;
 $51 = $219;
 $220 = $51;
 $221 = ((($220)) + 4|0);
 $222 = ((($221)) + 4|0);
 HEAP8[$222>>0] = 1;
 $$expand_i1_val2 = 1;
 HEAP8[$127>>0] = $$expand_i1_val2;
 $$pre_trunc = HEAP8[$127>>0]|0;
 $223 = $$pre_trunc&1;
 if ($223) {
  STACKTOP = sp;return;
 }
 $118 = $0;
 $224 = $118;
 $115 = $224;
 $116 = 0;
 $225 = $115;
 $114 = $225;
 $226 = $114;
 $113 = $226;
 $227 = $113;
 $228 = HEAP32[$227>>2]|0;
 $117 = $228;
 $229 = $116;
 $95 = $225;
 $230 = $95;
 $94 = $230;
 $231 = $94;
 HEAP32[$231>>2] = $229;
 $232 = $117;
 $233 = ($232|0)!=(0|0);
 if (!($233)) {
  STACKTOP = sp;return;
 }
 $93 = $225;
 $234 = $93;
 $92 = $234;
 $235 = $92;
 $236 = ((($235)) + 4|0);
 $237 = $117;
 $111 = $236;
 $112 = $237;
 $238 = $111;
 $239 = ((($238)) + 4|0);
 $240 = HEAP8[$239>>0]|0;
 $241 = $240&1;
 if ($241) {
  $242 = HEAP32[$238>>2]|0;
  $243 = $112;
  $244 = ((($243)) + 16|0);
  $110 = $244;
  $245 = $110;
  $109 = $245;
  $246 = $109;
  $106 = $242;
  $107 = $246;
  $247 = $106;
  $248 = $107;
  ;HEAP8[$105>>0]=HEAP8[$108>>0]|0;
  $103 = $247;
  $104 = $248;
 }
 $249 = $112;
 $250 = ($249|0)!=(0|0);
 if (!($250)) {
  STACKTOP = sp;return;
 }
 $251 = HEAP32[$238>>2]|0;
 $252 = $112;
 $100 = $251;
 $101 = $252;
 $102 = 1;
 $253 = $100;
 $254 = $101;
 $255 = $102;
 $97 = $253;
 $98 = $254;
 $99 = $255;
 $256 = $98;
 $96 = $256;
 $257 = $96;
 __ZdlPv($257);
 STACKTOP = sp;return;
}
function __ZNSt3__26__treeINS_12__value_typeIPN3osg8StateSetEbEENS_19__map_value_compareIS4_S5_NS_4lessIS4_EELb1EEENS_9allocatorIS5_EEE16__insert_node_atEPNS_15__tree_end_nodeIPNS_16__tree_node_baseIPvEEEERSH_SH_($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(64|0);
 $15 = $0;
 $16 = $1;
 $17 = $2;
 $18 = $3;
 $19 = $15;
 $20 = $18;
 HEAP32[$20>>2] = 0;
 $21 = $18;
 $22 = ((($21)) + 4|0);
 HEAP32[$22>>2] = 0;
 $23 = $16;
 $24 = $18;
 $25 = ((($24)) + 8|0);
 HEAP32[$25>>2] = $23;
 $26 = $18;
 $27 = $17;
 HEAP32[$27>>2] = $26;
 $14 = $19;
 $28 = $14;
 $29 = HEAP32[$28>>2]|0;
 $30 = HEAP32[$29>>2]|0;
 $31 = ($30|0)!=(0|0);
 if ($31) {
  $10 = $19;
  $32 = $10;
  $33 = HEAP32[$32>>2]|0;
  $34 = HEAP32[$33>>2]|0;
  $4 = $19;
  $35 = $4;
  HEAP32[$35>>2] = $34;
 }
 $9 = $19;
 $36 = $9;
 $37 = ((($36)) + 4|0);
 $8 = $37;
 $38 = $8;
 $7 = $38;
 $39 = $7;
 $6 = $39;
 $40 = $6;
 $5 = $40;
 $41 = $5;
 $42 = HEAP32[$41>>2]|0;
 $43 = $17;
 $44 = HEAP32[$43>>2]|0;
 __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($42,$44);
 $13 = $19;
 $45 = $13;
 $46 = ((($45)) + 8|0);
 $12 = $46;
 $47 = $12;
 $11 = $47;
 $48 = $11;
 $49 = HEAP32[$48>>2]|0;
 $50 = (($49) + 1)|0;
 HEAP32[$48>>2] = $50;
 STACKTOP = sp;return;
}
function __ZNKSt3__26__treeINS_12__value_typeIPN3osg8StateSetEbEENS_19__map_value_compareIS4_S5_NS_4lessIS4_EELb1EEENS_9allocatorIS5_EEE10__root_ptrEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $7 = $0;
 $8 = $7;
 $6 = $8;
 $9 = $6;
 $10 = ((($9)) + 4|0);
 $5 = $10;
 $11 = $5;
 $4 = $11;
 $12 = $4;
 $3 = $12;
 $13 = $3;
 $2 = $13;
 $14 = $2;
 $1 = $14;
 $15 = $1;
 STACKTOP = sp;return ($15|0);
}
function __ZNSt3__26__treeINS_12__value_typeIPvPN3osg8StateSetEEENS_19__map_value_compareIS2_S6_NS_4lessIS2_EELb1EEENS_9allocatorIS6_EEE25__emplace_unique_key_argsIS2_JRKNS_21piecewise_construct_tENS_5tupleIJRKS2_EEENSI_IJEEEEEENS_4pairINS_15__tree_iteratorIS6_PNS_11__tree_nodeIS6_S2_EEiEEbEERKT_DpOT0_($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0;
 var $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0;
 var $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0;
 var $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0;
 var $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 352|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(352|0);
 $29 = sp + 8|0;
 $32 = sp + 346|0;
 $57 = sp;
 $60 = sp + 345|0;
 $84 = sp + 44|0;
 $87 = sp + 344|0;
 $88 = sp + 24|0;
 $91 = sp + 12|0;
 $79 = $1;
 $80 = $2;
 $81 = $3;
 $82 = $4;
 $83 = $5;
 $92 = $79;
 $93 = $80;
 $94 = (__ZNSt3__26__treeINS_12__value_typeIPvPN3osg8StateSetEEENS_19__map_value_compareIS2_S6_NS_4lessIS2_EELb1EEENS_9allocatorIS6_EEE12__find_equalIS2_EERPNS_16__tree_node_baseIS2_EERPNS_15__tree_end_nodeISH_EERKT_($92,$84,$93)|0);
 $85 = $94;
 $95 = $85;
 $96 = HEAP32[$95>>2]|0;
 $86 = $96;
 HEAP8[$87>>0] = 0;
 $97 = $85;
 $98 = HEAP32[$97>>2]|0;
 $99 = ($98|0)==(0|0);
 do {
  if ($99) {
   $100 = $81;
   $78 = $100;
   $101 = $78;
   $102 = $82;
   $43 = $102;
   $103 = $43;
   $104 = $83;
   $15 = $104;
   $105 = $15;
   __ZNSt3__26__treeINS_12__value_typeIPvPN3osg8StateSetEEENS_19__map_value_compareIS2_S6_NS_4lessIS2_EELb1EEENS_9allocatorIS6_EEE16__construct_nodeIJRKNS_21piecewise_construct_tENS_5tupleIJRKS2_EEENSI_IJEEEEEENS_10unique_ptrINS_11__tree_nodeIS6_S2_EENS_22__tree_node_destructorINSB_ISP_EEEEEEDpOT_($88,$92,$101,$103,$105);
   $106 = HEAP32[$84>>2]|0;
   $107 = $85;
   $8 = $88;
   $108 = $8;
   $7 = $108;
   $109 = $7;
   $6 = $109;
   $110 = $6;
   $111 = HEAP32[$110>>2]|0;
   __THREW__ = 0;
   invoke_viiii(4082,($92|0),($106|0),($107|0),($111|0));
   $112 = __THREW__; __THREW__ = 0;
   $113 = $112&1;
   if (!($113)) {
    $13 = $88;
    $114 = $13;
    $12 = $114;
    $115 = $12;
    $11 = $115;
    $116 = $11;
    $117 = HEAP32[$116>>2]|0;
    $14 = $117;
    $10 = $114;
    $118 = $10;
    $9 = $118;
    $119 = $9;
    HEAP32[$119>>2] = 0;
    $120 = $14;
    $86 = $120;
    HEAP8[$87>>0] = 1;
    $42 = $88;
    $121 = $42;
    $39 = $121;
    $40 = 0;
    $122 = $39;
    $38 = $122;
    $123 = $38;
    $37 = $123;
    $124 = $37;
    $125 = HEAP32[$124>>2]|0;
    $41 = $125;
    $126 = $40;
    $19 = $122;
    $127 = $19;
    $18 = $127;
    $128 = $18;
    HEAP32[$128>>2] = $126;
    $129 = $41;
    $130 = ($129|0)!=(0|0);
    if (!($130)) {
     break;
    }
    $17 = $122;
    $131 = $17;
    $16 = $131;
    $132 = $16;
    $133 = ((($132)) + 4|0);
    $134 = $41;
    $35 = $133;
    $36 = $134;
    $135 = $35;
    $136 = ((($135)) + 4|0);
    $137 = HEAP8[$136>>0]|0;
    $138 = $137&1;
    if ($138) {
     $139 = HEAP32[$135>>2]|0;
     $140 = $36;
     $141 = ((($140)) + 16|0);
     $34 = $141;
     $142 = $34;
     $33 = $142;
     $143 = $33;
     $30 = $139;
     $31 = $143;
     $144 = $30;
     $145 = $31;
     ;HEAP8[$29>>0]=HEAP8[$32>>0]|0;
     $27 = $144;
     $28 = $145;
    }
    $146 = $36;
    $147 = ($146|0)!=(0|0);
    if (!($147)) {
     break;
    }
    $148 = HEAP32[$135>>2]|0;
    $149 = $36;
    $24 = $148;
    $25 = $149;
    $26 = 1;
    $150 = $24;
    $151 = $25;
    $152 = $26;
    $21 = $150;
    $22 = $151;
    $23 = $152;
    $153 = $22;
    $20 = $153;
    $154 = $20;
    __ZdlPv($154);
    break;
   }
   $155 = ___cxa_find_matching_catch_2()|0;
   $156 = tempRet0;
   $89 = $155;
   $90 = $156;
   $70 = $88;
   $157 = $70;
   $67 = $157;
   $68 = 0;
   $158 = $67;
   $66 = $158;
   $159 = $66;
   $65 = $159;
   $160 = $65;
   $161 = HEAP32[$160>>2]|0;
   $69 = $161;
   $162 = $68;
   $47 = $158;
   $163 = $47;
   $46 = $163;
   $164 = $46;
   HEAP32[$164>>2] = $162;
   $165 = $69;
   $166 = ($165|0)!=(0|0);
   if (!($166)) {
    $203 = $89;
    $204 = $90;
    ___resumeException($203|0);
    // unreachable;
   }
   $45 = $158;
   $167 = $45;
   $44 = $167;
   $168 = $44;
   $169 = ((($168)) + 4|0);
   $170 = $69;
   $63 = $169;
   $64 = $170;
   $171 = $63;
   $172 = ((($171)) + 4|0);
   $173 = HEAP8[$172>>0]|0;
   $174 = $173&1;
   if ($174) {
    $175 = HEAP32[$171>>2]|0;
    $176 = $64;
    $177 = ((($176)) + 16|0);
    $62 = $177;
    $178 = $62;
    $61 = $178;
    $179 = $61;
    $58 = $175;
    $59 = $179;
    $180 = $58;
    $181 = $59;
    ;HEAP8[$57>>0]=HEAP8[$60>>0]|0;
    $55 = $180;
    $56 = $181;
   }
   $182 = $64;
   $183 = ($182|0)!=(0|0);
   if (!($183)) {
    $203 = $89;
    $204 = $90;
    ___resumeException($203|0);
    // unreachable;
   }
   $184 = HEAP32[$171>>2]|0;
   $185 = $64;
   $52 = $184;
   $53 = $185;
   $54 = 1;
   $186 = $52;
   $187 = $53;
   $188 = $54;
   $49 = $186;
   $50 = $187;
   $51 = $188;
   $189 = $50;
   $48 = $189;
   $190 = $48;
   __ZdlPv($190);
   $203 = $89;
   $204 = $90;
   ___resumeException($203|0);
   // unreachable;
  }
 } while(0);
 $191 = $86;
 $71 = $91;
 $72 = $191;
 $192 = $71;
 $193 = $72;
 HEAP32[$192>>2] = $193;
 $75 = $0;
 $76 = $91;
 $77 = $87;
 $194 = $75;
 $195 = $76;
 $74 = $195;
 $196 = $74;
 ;HEAP32[$194>>2]=HEAP32[$196>>2]|0;
 $197 = ((($194)) + 4|0);
 $198 = $77;
 $73 = $198;
 $199 = $73;
 $200 = HEAP8[$199>>0]|0;
 $201 = $200&1;
 $202 = $201&1;
 HEAP8[$197>>0] = $202;
 STACKTOP = sp;return;
}
function __ZNSt3__26__treeINS_12__value_typeIPvPN3osg8StateSetEEENS_19__map_value_compareIS2_S6_NS_4lessIS2_EELb1EEENS_9allocatorIS6_EEE12__find_equalIS2_EERPNS_16__tree_node_baseIS2_EERPNS_15__tree_end_nodeISH_EERKT_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $12 = 0;
 var $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(160|0);
 $35 = $0;
 $36 = $1;
 $37 = $2;
 $40 = $35;
 $33 = $40;
 $41 = $33;
 $32 = $41;
 $42 = $32;
 $43 = ((($42)) + 4|0);
 $31 = $43;
 $44 = $31;
 $30 = $44;
 $45 = $30;
 $29 = $45;
 $46 = $29;
 $28 = $46;
 $47 = $28;
 $48 = HEAP32[$47>>2]|0;
 $38 = $48;
 $49 = (__ZNKSt3__26__treeINS_12__value_typeIPvPN3osg8StateSetEEENS_19__map_value_compareIS2_S6_NS_4lessIS2_EELb1EEENS_9allocatorIS6_EEE10__root_ptrEv($40)|0);
 $39 = $49;
 $50 = $38;
 $51 = ($50|0)!=(0|0);
 if (!($51)) {
  $27 = $40;
  $107 = $27;
  $108 = ((($107)) + 4|0);
  $26 = $108;
  $109 = $26;
  $25 = $109;
  $110 = $25;
  $24 = $110;
  $111 = $24;
  $23 = $111;
  $112 = $23;
  $113 = $36;
  HEAP32[$113>>2] = $112;
  $114 = $36;
  $115 = HEAP32[$114>>2]|0;
  $34 = $115;
  $116 = $34;
  STACKTOP = sp;return ($116|0);
 }
 while(1) {
  $5 = $40;
  $52 = $5;
  $53 = ((($52)) + 8|0);
  $4 = $53;
  $54 = $4;
  $3 = $54;
  $55 = $3;
  $56 = $37;
  $57 = $38;
  $58 = ((($57)) + 16|0);
  $9 = $55;
  $10 = $56;
  $11 = $58;
  $59 = $9;
  $60 = $10;
  $61 = $11;
  $6 = $59;
  $7 = $60;
  $8 = $61;
  $62 = $7;
  $63 = HEAP32[$62>>2]|0;
  $64 = $8;
  $65 = HEAP32[$64>>2]|0;
  $66 = ($63>>>0)<($65>>>0);
  if ($66) {
   $67 = $38;
   $68 = HEAP32[$67>>2]|0;
   $69 = ($68|0)!=(0|0);
   $70 = $38;
   if (!($69)) {
    label = 5;
    break;
   }
   $12 = $70;
   $71 = $12;
   $39 = $71;
   $72 = $38;
   $73 = HEAP32[$72>>2]|0;
   $38 = $73;
   continue;
  }
  $15 = $40;
  $77 = $15;
  $78 = ((($77)) + 8|0);
  $14 = $78;
  $79 = $14;
  $13 = $79;
  $80 = $13;
  $81 = $38;
  $82 = ((($81)) + 16|0);
  $83 = $37;
  $19 = $80;
  $20 = $82;
  $21 = $83;
  $84 = $19;
  $85 = $20;
  $86 = $21;
  $16 = $84;
  $17 = $85;
  $18 = $86;
  $87 = $17;
  $88 = HEAP32[$87>>2]|0;
  $89 = $18;
  $90 = HEAP32[$89>>2]|0;
  $91 = ($88>>>0)<($90>>>0);
  $92 = $38;
  if (!($91)) {
   label = 10;
   break;
  }
  $93 = ((($92)) + 4|0);
  $94 = HEAP32[$93>>2]|0;
  $95 = ($94|0)!=(0|0);
  $96 = $38;
  if (!($95)) {
   label = 9;
   break;
  }
  $97 = ((($96)) + 4|0);
  $22 = $97;
  $98 = $22;
  $39 = $98;
  $99 = $38;
  $100 = ((($99)) + 4|0);
  $101 = HEAP32[$100>>2]|0;
  $38 = $101;
 }
 if ((label|0) == 5) {
  $74 = $36;
  HEAP32[$74>>2] = $70;
  $75 = $36;
  $76 = HEAP32[$75>>2]|0;
  $34 = $76;
  $116 = $34;
  STACKTOP = sp;return ($116|0);
 }
 else if ((label|0) == 9) {
  $102 = $36;
  HEAP32[$102>>2] = $96;
  $103 = $38;
  $104 = ((($103)) + 4|0);
  $34 = $104;
  $116 = $34;
  STACKTOP = sp;return ($116|0);
 }
 else if ((label|0) == 10) {
  $105 = $36;
  HEAP32[$105>>2] = $92;
  $106 = $39;
  $34 = $106;
  $116 = $34;
  STACKTOP = sp;return ($116|0);
 }
 return (0)|0;
}
function __ZNSt3__26__treeINS_12__value_typeIPvPN3osg8StateSetEEENS_19__map_value_compareIS2_S6_NS_4lessIS2_EELb1EEENS_9allocatorIS6_EEE16__construct_nodeIJRKNS_21piecewise_construct_tENS_5tupleIJRKS2_EEENSI_IJEEEEEENS_10unique_ptrINS_11__tree_nodeIS6_S2_EENS_22__tree_node_destructorINSB_ISP_EEEEEEDpOT_($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$expand_i1_val = 0, $$expand_i1_val2 = 0, $$pre_trunc = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0;
 var $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0;
 var $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 528|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(528|0);
 $18 = sp + 72|0;
 $19 = sp + 64|0;
 $20 = sp + 56|0;
 $22 = sp + 524|0;
 $23 = sp + 523|0;
 $24 = sp + 522|0;
 $25 = sp + 48|0;
 $26 = sp + 40|0;
 $27 = sp + 32|0;
 $34 = sp + 521|0;
 $35 = sp + 432|0;
 $36 = sp + 520|0;
 $43 = sp + 24|0;
 $50 = sp + 519|0;
 $65 = sp + 324|0;
 $66 = sp + 16|0;
 $69 = sp + 312|0;
 $70 = sp + 304|0;
 $71 = sp + 8|0;
 $76 = sp + 280|0;
 $105 = sp;
 $108 = sp + 517|0;
 $127 = sp + 516|0;
 $128 = sp + 80|0;
 $122 = $1;
 $123 = $2;
 $124 = $3;
 $125 = $4;
 $129 = $122;
 $121 = $129;
 $130 = $121;
 $131 = ((($130)) + 4|0);
 $120 = $131;
 $132 = $120;
 $119 = $132;
 $133 = $119;
 $126 = $133;
 $$expand_i1_val = 0;
 HEAP8[$127>>0] = $$expand_i1_val;
 $134 = $126;
 $90 = $134;
 $91 = 1;
 $135 = $90;
 $136 = $91;
 $87 = $135;
 $88 = $136;
 $89 = 0;
 $137 = $87;
 $138 = $88;
 $86 = $137;
 $139 = ($138>>>0)>(178956970);
 if ($139) {
  $82 = 204840;
  $140 = (___cxa_allocate_exception(8)|0);
  $141 = $82;
  $80 = $140;
  $81 = $141;
  $142 = $80;
  $143 = $81;
  __THREW__ = 0;
  invoke_vii(3366,($142|0),($143|0));
  $144 = __THREW__; __THREW__ = 0;
  $145 = $144&1;
  if ($145) {
   $146 = ___cxa_find_matching_catch_2()|0;
   $147 = tempRet0;
   $83 = $146;
   $84 = $147;
   ___cxa_free_exception(($140|0));
   $148 = $83;
   $149 = $84;
   ___resumeException($148|0);
   // unreachable;
  } else {
   HEAP32[$142>>2] = (99824);
   ___cxa_throw(($140|0),(34608|0),(3230|0));
   // unreachable;
  }
 }
 $150 = $88;
 $151 = ($150*24)|0;
 $85 = $151;
 $152 = $85;
 $153 = (__Znwj($152)|0);
 $154 = $126;
 $77 = $128;
 $78 = $154;
 $79 = 0;
 $155 = $77;
 $156 = $78;
 HEAP32[$155>>2] = $156;
 $157 = ((($155)) + 4|0);
 $158 = $79;
 $159 = $158&1;
 $160 = $159&1;
 HEAP8[$157>>0] = $160;
 $73 = $0;
 $74 = $153;
 $75 = $128;
 $161 = $73;
 $162 = $74;
 $163 = $75;
 $72 = $163;
 $164 = $72;
 ;HEAP32[$76>>2]=HEAP32[$164>>2]|0;HEAP32[$76+4>>2]=HEAP32[$164+4>>2]|0;
 ;HEAP8[$71>>0]=HEAP8[$76>>0]|0;HEAP8[$71+1>>0]=HEAP8[$76+1>>0]|0;HEAP8[$71+2>>0]=HEAP8[$76+2>>0]|0;HEAP8[$71+3>>0]=HEAP8[$76+3>>0]|0;HEAP8[$71+4>>0]=HEAP8[$76+4>>0]|0;HEAP8[$71+5>>0]=HEAP8[$76+5>>0]|0;HEAP8[$71+6>>0]=HEAP8[$76+6>>0]|0;HEAP8[$71+7>>0]=HEAP8[$76+7>>0]|0;
 $68 = $161;
 HEAP32[$69>>2] = $162;
 $165 = $68;
 $67 = $69;
 $166 = $67;
 $167 = HEAP32[$166>>2]|0;
 $61 = $71;
 $168 = $61;
 ;HEAP32[$70>>2]=HEAP32[$168>>2]|0;HEAP32[$70+4>>2]=HEAP32[$168+4>>2]|0;
 ;HEAP8[$66>>0]=HEAP8[$70>>0]|0;HEAP8[$66+1>>0]=HEAP8[$70+1>>0]|0;HEAP8[$66+2>>0]=HEAP8[$70+2>>0]|0;HEAP8[$66+3>>0]=HEAP8[$70+3>>0]|0;HEAP8[$66+4>>0]=HEAP8[$70+4>>0]|0;HEAP8[$66+5>>0]=HEAP8[$70+5>>0]|0;HEAP8[$66+6>>0]=HEAP8[$70+6>>0]|0;HEAP8[$66+7>>0]=HEAP8[$70+7>>0]|0;
 $64 = $165;
 HEAP32[$65>>2] = $167;
 $169 = $64;
 $63 = $65;
 $170 = $63;
 $171 = HEAP32[$170>>2]|0;
 HEAP32[$169>>2] = $171;
 $172 = ((($169)) + 4|0);
 $62 = $66;
 $173 = $62;
 ;HEAP32[$172>>2]=HEAP32[$173>>2]|0;HEAP32[$172+4>>2]=HEAP32[$173+4>>2]|0;
 $174 = $126;
 $60 = $0;
 $175 = $60;
 $59 = $175;
 $176 = $59;
 $58 = $176;
 $177 = $58;
 $178 = HEAP32[$177>>2]|0;
 $179 = ((($178)) + 16|0);
 $57 = $179;
 $180 = $57;
 $56 = $180;
 $181 = $56;
 $182 = $123;
 $55 = $182;
 $183 = $55;
 $184 = $124;
 $54 = $184;
 $185 = $54;
 $186 = $125;
 $5 = $186;
 $187 = $5;
 $45 = $174;
 $46 = $181;
 $47 = $183;
 $48 = $185;
 $49 = $187;
 $188 = $45;
 $189 = $46;
 $190 = $47;
 $44 = $190;
 $191 = $44;
 $192 = $48;
 $6 = $192;
 $193 = $6;
 $194 = $49;
 $7 = $194;
 $195 = $7;
 ;HEAP8[$43>>0]=HEAP8[$50>>0]|0;
 $38 = $188;
 $39 = $189;
 $40 = $191;
 $41 = $193;
 $42 = $195;
 $196 = $38;
 $197 = $39;
 $198 = $40;
 $37 = $198;
 $199 = $37;
 $200 = $41;
 $8 = $200;
 $201 = $8;
 $202 = $42;
 $9 = $202;
 $203 = $9;
 $29 = $196;
 $30 = $197;
 $31 = $199;
 $32 = $201;
 $33 = $203;
 $204 = $30;
 $205 = $31;
 $28 = $205;
 $206 = $32;
 $10 = $206;
 $207 = $10;
 ;HEAP32[$35>>2]=HEAP32[$207>>2]|0;
 $208 = $33;
 $11 = $208;
 ;HEAP8[$25>>0]=HEAP8[$36>>0]|0;
 ;HEAP8[$26>>0]=HEAP8[$35>>0]|0;HEAP8[$26+1>>0]=HEAP8[$35+1>>0]|0;HEAP8[$26+2>>0]=HEAP8[$35+2>>0]|0;HEAP8[$26+3>>0]=HEAP8[$35+3>>0]|0;
 ;HEAP8[$27>>0]=HEAP8[$34>>0]|0;
 $21 = $204;
 $209 = $21;
 ;HEAP8[$18>>0]=HEAP8[$24>>0]|0;
 ;HEAP8[$19>>0]=HEAP8[$23>>0]|0;
 ;HEAP8[$20>>0]=HEAP8[$22>>0]|0;
 $15 = $209;
 $16 = $26;
 $17 = $25;
 $210 = $15;
 $211 = $16;
 $14 = $211;
 $212 = $14;
 $13 = $212;
 $213 = $13;
 $214 = HEAP32[$213>>2]|0;
 $12 = $214;
 $215 = $12;
 $216 = HEAP32[$215>>2]|0;
 HEAP32[$210>>2] = $216;
 $217 = ((($210)) + 4|0);
 HEAP32[$217>>2] = 0;
 $53 = $0;
 $218 = $53;
 $52 = $218;
 $219 = $52;
 $51 = $219;
 $220 = $51;
 $221 = ((($220)) + 4|0);
 $222 = ((($221)) + 4|0);
 HEAP8[$222>>0] = 1;
 $$expand_i1_val2 = 1;
 HEAP8[$127>>0] = $$expand_i1_val2;
 $$pre_trunc = HEAP8[$127>>0]|0;
 $223 = $$pre_trunc&1;
 if ($223) {
  STACKTOP = sp;return;
 }
 $118 = $0;
 $224 = $118;
 $115 = $224;
 $116 = 0;
 $225 = $115;
 $114 = $225;
 $226 = $114;
 $113 = $226;
 $227 = $113;
 $228 = HEAP32[$227>>2]|0;
 $117 = $228;
 $229 = $116;
 $95 = $225;
 $230 = $95;
 $94 = $230;
 $231 = $94;
 HEAP32[$231>>2] = $229;
 $232 = $117;
 $233 = ($232|0)!=(0|0);
 if (!($233)) {
  STACKTOP = sp;return;
 }
 $93 = $225;
 $234 = $93;
 $92 = $234;
 $235 = $92;
 $236 = ((($235)) + 4|0);
 $237 = $117;
 $111 = $236;
 $112 = $237;
 $238 = $111;
 $239 = ((($238)) + 4|0);
 $240 = HEAP8[$239>>0]|0;
 $241 = $240&1;
 if ($241) {
  $242 = HEAP32[$238>>2]|0;
  $243 = $112;
  $244 = ((($243)) + 16|0);
  $110 = $244;
  $245 = $110;
  $109 = $245;
  $246 = $109;
  $106 = $242;
  $107 = $246;
  $247 = $106;
  $248 = $107;
  ;HEAP8[$105>>0]=HEAP8[$108>>0]|0;
  $103 = $247;
  $104 = $248;
 }
 $249 = $112;
 $250 = ($249|0)!=(0|0);
 if (!($250)) {
  STACKTOP = sp;return;
 }
 $251 = HEAP32[$238>>2]|0;
 $252 = $112;
 $100 = $251;
 $101 = $252;
 $102 = 1;
 $253 = $100;
 $254 = $101;
 $255 = $102;
 $97 = $253;
 $98 = $254;
 $99 = $255;
 $256 = $98;
 $96 = $256;
 $257 = $96;
 __ZdlPv($257);
 STACKTOP = sp;return;
}
function __ZNSt3__26__treeINS_12__value_typeIPvPN3osg8StateSetEEENS_19__map_value_compareIS2_S6_NS_4lessIS2_EELb1EEENS_9allocatorIS6_EEE16__insert_node_atEPNS_15__tree_end_nodeIPNS_16__tree_node_baseIS2_EEEERSH_SH_($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(64|0);
 $15 = $0;
 $16 = $1;
 $17 = $2;
 $18 = $3;
 $19 = $15;
 $20 = $18;
 HEAP32[$20>>2] = 0;
 $21 = $18;
 $22 = ((($21)) + 4|0);
 HEAP32[$22>>2] = 0;
 $23 = $16;
 $24 = $18;
 $25 = ((($24)) + 8|0);
 HEAP32[$25>>2] = $23;
 $26 = $18;
 $27 = $17;
 HEAP32[$27>>2] = $26;
 $14 = $19;
 $28 = $14;
 $29 = HEAP32[$28>>2]|0;
 $30 = HEAP32[$29>>2]|0;
 $31 = ($30|0)!=(0|0);
 if ($31) {
  $10 = $19;
  $32 = $10;
  $33 = HEAP32[$32>>2]|0;
  $34 = HEAP32[$33>>2]|0;
  $4 = $19;
  $35 = $4;
  HEAP32[$35>>2] = $34;
 }
 $9 = $19;
 $36 = $9;
 $37 = ((($36)) + 4|0);
 $8 = $37;
 $38 = $8;
 $7 = $38;
 $39 = $7;
 $6 = $39;
 $40 = $6;
 $5 = $40;
 $41 = $5;
 $42 = HEAP32[$41>>2]|0;
 $43 = $17;
 $44 = HEAP32[$43>>2]|0;
 __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($42,$44);
 $13 = $19;
 $45 = $13;
 $46 = ((($45)) + 8|0);
 $12 = $46;
 $47 = $12;
 $11 = $47;
 $48 = $11;
 $49 = HEAP32[$48>>2]|0;
 $50 = (($49) + 1)|0;
 HEAP32[$48>>2] = $50;
 STACKTOP = sp;return;
}
function __ZNKSt3__26__treeINS_12__value_typeIPvPN3osg8StateSetEEENS_19__map_value_compareIS2_S6_NS_4lessIS2_EELb1EEENS_9allocatorIS6_EEE10__root_ptrEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $7 = $0;
 $8 = $7;
 $6 = $8;
 $9 = $6;
 $10 = ((($9)) + 4|0);
 $5 = $10;
 $11 = $5;
 $4 = $11;
 $12 = $4;
 $3 = $12;
 $13 = $3;
 $2 = $13;
 $14 = $2;
 $1 = $14;
 $15 = $1;
 STACKTOP = sp;return ($15|0);
}
function __ZNSt3__26__treeINS_12__value_typeIPvPN3osg8StateSetEEENS_19__map_value_compareIS2_S6_NS_4lessIS2_EELb1EEENS_9allocatorIS6_EEE13__lower_boundIS2_EENS_15__tree_iteratorIS6_PNS_11__tree_nodeIS6_S2_EEiEERKT_SI_PNS_15__tree_end_nodeIPNS_16__tree_node_baseIS2_EEEE($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(64|0);
 $15 = sp + 16|0;
 $16 = $0;
 $17 = $1;
 $18 = $2;
 $19 = $3;
 $20 = $16;
 while(1) {
  $21 = $18;
  $22 = ($21|0)!=(0|0);
  if (!($22)) {
   break;
  }
  $14 = $20;
  $23 = $14;
  $24 = ((($23)) + 8|0);
  $13 = $24;
  $25 = $13;
  $12 = $25;
  $26 = $12;
  $27 = $18;
  $28 = ((($27)) + 16|0);
  $29 = $17;
  $7 = $26;
  $8 = $28;
  $9 = $29;
  $30 = $7;
  $31 = $8;
  $32 = $9;
  $4 = $30;
  $5 = $31;
  $6 = $32;
  $33 = $5;
  $34 = HEAP32[$33>>2]|0;
  $35 = $6;
  $36 = HEAP32[$35>>2]|0;
  $37 = ($34>>>0)<($36>>>0);
  $38 = $18;
  if ($37) {
   $41 = ((($38)) + 4|0);
   $42 = HEAP32[$41>>2]|0;
   $18 = $42;
   continue;
  } else {
   $19 = $38;
   $39 = $18;
   $40 = HEAP32[$39>>2]|0;
   $18 = $40;
   continue;
  }
 }
 $43 = $19;
 $10 = $15;
 $11 = $43;
 $44 = $10;
 $45 = $11;
 HEAP32[$44>>2] = $45;
 $46 = HEAP32[$15>>2]|0;
 STACKTOP = sp;return ($46|0);
}
function __ZN4mjin11application6memory8material4Pool15releaseMaterialEPv($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$byval_copy = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(224|0);
 $$byval_copy = sp + 212|0;
 $vararg_buffer = sp + 40|0;
 $10 = sp + 32|0;
 $12 = sp + 24|0;
 $13 = sp + 172|0;
 $15 = sp + 164|0;
 $16 = sp + 160|0;
 $17 = sp + 156|0;
 $18 = sp + 16|0;
 $24 = sp + 8|0;
 $32 = sp + 104|0;
 $34 = sp + 96|0;
 $36 = sp + 88|0;
 $38 = sp;
 $39 = sp + 80|0;
 $42 = sp + 68|0;
 $44 = sp + 60|0;
 $45 = sp + 56|0;
 $46 = sp + 52|0;
 $47 = sp + 48|0;
 $48 = sp + 44|0;
 $43 = $0;
 HEAP32[$44>>2] = $1;
 $49 = $43;
 $40 = $49;
 $41 = $44;
 $50 = $40;
 $51 = $41;
 $52 = (__ZNSt3__26__treeINS_12__value_typeIPvPN3osg8StateSetEEENS_19__map_value_compareIS2_S6_NS_4lessIS2_EELb1EEENS_9allocatorIS6_EEE4findIS2_EENS_15__tree_iteratorIS6_PNS_11__tree_nodeIS6_S2_EEiEERKT_($50,$51)|0);
 HEAP32[$42>>2] = $52;
 ;HEAP8[$38>>0]=HEAP8[$42>>0]|0;HEAP8[$38+1>>0]=HEAP8[$42+1>>0]|0;HEAP8[$38+2>>0]=HEAP8[$42+2>>0]|0;HEAP8[$38+3>>0]=HEAP8[$42+3>>0]|0;
 $37 = $39;
 $53 = $37;
 ;HEAP32[$53>>2]=HEAP32[$38>>2]|0;
 $54 = HEAP32[$39>>2]|0;
 HEAP32[$45>>2] = $54;
 $35 = $49;
 $55 = $35;
 $33 = $55;
 $56 = $33;
 $31 = $56;
 $57 = $31;
 $58 = ((($57)) + 4|0);
 $30 = $58;
 $59 = $30;
 $29 = $59;
 $60 = $29;
 $28 = $60;
 $61 = $28;
 $27 = $61;
 $62 = $27;
 $25 = $32;
 $26 = $62;
 $63 = $25;
 $64 = $26;
 HEAP32[$63>>2] = $64;
 $65 = HEAP32[$32>>2]|0;
 HEAP32[$36>>2] = $65;
 ;HEAP8[$24>>0]=HEAP8[$36>>0]|0;HEAP8[$24+1>>0]=HEAP8[$36+1>>0]|0;HEAP8[$24+2>>0]=HEAP8[$36+2>>0]|0;HEAP8[$24+3>>0]=HEAP8[$36+3>>0]|0;
 $23 = $34;
 $66 = $23;
 ;HEAP32[$66>>2]=HEAP32[$24>>2]|0;
 $67 = HEAP32[$34>>2]|0;
 HEAP32[$46>>2] = $67;
 $21 = $45;
 $22 = $46;
 $68 = $21;
 $69 = $22;
 $19 = $68;
 $20 = $69;
 $70 = $19;
 $71 = HEAP32[$70>>2]|0;
 $72 = $20;
 $73 = HEAP32[$72>>2]|0;
 $74 = ($71|0)==($73|0);
 if ($74) {
  $75 = HEAP32[$44>>2]|0;
  HEAP32[$vararg_buffer>>2] = $75;
  __ZN4mjin3log9logprintfEPKcz(162391,$vararg_buffer);
  STACKTOP = sp;return;
 } else {
  $76 = ((($49)) + 12|0);
  $8 = $45;
  $77 = $8;
  $7 = $77;
  $78 = $7;
  $6 = $78;
  $79 = $6;
  $80 = HEAP32[$79>>2]|0;
  $81 = ((($80)) + 16|0);
  $5 = $81;
  $82 = $5;
  $4 = $82;
  $83 = $4;
  $3 = $83;
  $84 = $3;
  $2 = $84;
  $85 = $2;
  $86 = ((($85)) + 4|0);
  $87 = (__ZNSt3__23mapIPN3osg8StateSetEbNS_4lessIS3_EENS_9allocatorINS_4pairIKS3_bEEEEEixERS8_($76,$86)|0);
  HEAP8[$87>>0] = 0;
  ;HEAP32[$47>>2]=HEAP32[$45>>2]|0;
  ;HEAP8[$18>>0]=HEAP8[$47>>0]|0;HEAP8[$18+1>>0]=HEAP8[$47+1>>0]|0;HEAP8[$18+2>>0]=HEAP8[$47+2>>0]|0;HEAP8[$18+3>>0]=HEAP8[$47+3>>0]|0;
  $14 = $49;
  $88 = $14;
  ;HEAP32[$17>>2]=HEAP32[$18>>2]|0;
  ;HEAP8[$12>>0]=HEAP8[$17>>0]|0;HEAP8[$12+1>>0]=HEAP8[$17+1>>0]|0;HEAP8[$12+2>>0]=HEAP8[$17+2>>0]|0;HEAP8[$12+3>>0]=HEAP8[$17+3>>0]|0;
  $11 = $16;
  $89 = $11;
  $90 = HEAP32[$12>>2]|0;
  HEAP32[$89>>2] = $90;
  ;HEAP32[$$byval_copy>>2]=HEAP32[$16>>2]|0;
  $91 = (__ZNSt3__26__treeINS_12__value_typeIPvPN3osg8StateSetEEENS_19__map_value_compareIS2_S6_NS_4lessIS2_EELb1EEENS_9allocatorIS6_EEE5eraseENS_21__tree_const_iteratorIS6_PNS_11__tree_nodeIS6_S2_EEiEE($88,$$byval_copy)|0);
  HEAP32[$15>>2] = $91;
  ;HEAP8[$10>>0]=HEAP8[$15>>0]|0;HEAP8[$10+1>>0]=HEAP8[$15+1>>0]|0;HEAP8[$10+2>>0]=HEAP8[$15+2>>0]|0;HEAP8[$10+3>>0]=HEAP8[$15+3>>0]|0;
  $9 = $13;
  $92 = $9;
  ;HEAP32[$92>>2]=HEAP32[$10>>2]|0;
  $93 = HEAP32[$13>>2]|0;
  HEAP32[$48>>2] = $93;
  __ZN4mjin11application6memory8material4Pool10printStatsEv($49);
  STACKTOP = sp;return;
 }
}
function __ZNSt3__26__treeINS_12__value_typeIPvPN3osg8StateSetEEENS_19__map_value_compareIS2_S6_NS_4lessIS2_EELb1EEENS_9allocatorIS6_EEE5eraseENS_21__tree_const_iteratorIS6_PNS_11__tree_nodeIS6_S2_EEiEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(176|0);
 $27 = sp;
 $30 = sp + 168|0;
 $41 = sp + 16|0;
 $42 = $0;
 $45 = $42;
 $40 = $1;
 $46 = $40;
 $47 = HEAP32[$46>>2]|0;
 $43 = $47;
 $48 = HEAP32[$1>>2]|0;
 $31 = $41;
 $32 = $48;
 $49 = $31;
 $50 = $32;
 HEAP32[$49>>2] = $50;
 $20 = $41;
 $51 = $20;
 $52 = HEAP32[$51>>2]|0;
 $19 = $52;
 $53 = $19;
 $54 = ((($53)) + 4|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = ($55|0)!=(0|0);
 if ($56) {
  $57 = $19;
  $58 = ((($57)) + 4|0);
  $59 = HEAP32[$58>>2]|0;
  $17 = $59;
  while(1) {
   $60 = $17;
   $61 = HEAP32[$60>>2]|0;
   $62 = ($61|0)!=(0|0);
   $63 = $17;
   if (!($62)) {
    break;
   }
   $64 = HEAP32[$63>>2]|0;
   $17 = $64;
  }
  $18 = $63;
 } else {
  while(1) {
   $65 = $19;
   $16 = $65;
   $66 = $16;
   $67 = $16;
   $68 = ((($67)) + 8|0);
   $69 = HEAP32[$68>>2]|0;
   $70 = HEAP32[$69>>2]|0;
   $71 = ($66|0)==($70|0);
   $72 = $71 ^ 1;
   $73 = $19;
   if (!($72)) {
    break;
   }
   $15 = $73;
   $74 = $15;
   $75 = ((($74)) + 8|0);
   $76 = HEAP32[$75>>2]|0;
   $19 = $76;
  }
  $77 = ((($73)) + 8|0);
  $78 = HEAP32[$77>>2]|0;
  $18 = $78;
 }
 $79 = $18;
 HEAP32[$51>>2] = $79;
 $2 = $45;
 $80 = $2;
 $81 = HEAP32[$80>>2]|0;
 $82 = HEAP32[$1>>2]|0;
 $83 = ($81|0)==($82|0);
 if ($83) {
  $84 = HEAP32[$41>>2]|0;
  $3 = $45;
  $85 = $3;
  HEAP32[$85>>2] = $84;
 }
 $6 = $45;
 $86 = $6;
 $87 = ((($86)) + 8|0);
 $5 = $87;
 $88 = $5;
 $4 = $88;
 $89 = $4;
 $90 = HEAP32[$89>>2]|0;
 $91 = (($90) + -1)|0;
 HEAP32[$89>>2] = $91;
 $9 = $45;
 $92 = $9;
 $93 = ((($92)) + 4|0);
 $8 = $93;
 $94 = $8;
 $7 = $94;
 $95 = $7;
 $44 = $95;
 $14 = $45;
 $96 = $14;
 $97 = ((($96)) + 4|0);
 $13 = $97;
 $98 = $13;
 $12 = $98;
 $99 = $12;
 $11 = $99;
 $100 = $11;
 $10 = $100;
 $101 = $10;
 $102 = HEAP32[$101>>2]|0;
 $103 = $43;
 __ZNSt3__213__tree_removeIPNS_16__tree_node_baseIPvEEEEvT_S5_($102,$103);
 $104 = $44;
 $22 = $1;
 $105 = $22;
 $21 = $105;
 $106 = $21;
 $107 = HEAP32[$106>>2]|0;
 $108 = ((($107)) + 16|0);
 $24 = $108;
 $109 = $24;
 $23 = $109;
 $110 = $23;
 $28 = $104;
 $29 = $110;
 $111 = $28;
 $112 = $29;
 ;HEAP8[$27>>0]=HEAP8[$30>>0]|0;
 $25 = $111;
 $26 = $112;
 $113 = $44;
 $114 = $43;
 $37 = $113;
 $38 = $114;
 $39 = 1;
 $115 = $37;
 $116 = $38;
 $117 = $39;
 $34 = $115;
 $35 = $116;
 $36 = $117;
 $118 = $35;
 $33 = $118;
 $119 = $33;
 __ZdlPv($119);
 $120 = HEAP32[$41>>2]|0;
 STACKTOP = sp;return ($120|0);
}
function __GLOBAL__sub_I_render_cpp() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 ___cxx_global_var_init_4354();
 ___cxx_global_var_init_1_4355();
 ___cxx_global_var_init_2_4356();
 return;
}
function ___cxx_global_var_init_4354() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg5Vec3fC2Efff(209104,1.0,0.0,0.0);
 return;
}
function ___cxx_global_var_init_1_4355() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg5Vec3fC2Efff(209092,0.0,1.0,0.0);
 return;
}
function ___cxx_global_var_init_2_4356() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg5Vec3fC2Efff(209080,0.0,0.0,1.0);
 return;
}
function __ZN4mjin11application6memory6render12createSphereERKN3osg5Vec3fEf($0,$1) {
 $0 = $0|0;
 $1 = +$1;
 var $10 = 0, $11 = 0.0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0.0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $8 = sp;
 $2 = $0;
 $3 = $1;
 $9 = (__Znwj(48)|0);
 $10 = $2;
 $11 = $3;
 __THREW__ = 0;
 invoke_viid(4083,($9|0),($10|0),(+$11));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $39 = ___cxa_find_matching_catch_2()|0;
  $40 = tempRet0;
  $5 = $39;
  $6 = $40;
  __ZdlPv($9);
  $49 = $5;
  $50 = $6;
  ___resumeException($49|0);
  // unreachable;
 }
 $4 = $9;
 $14 = (__Znwj(52)|0);
 __THREW__ = 0;
 invoke_vi(4084,($14|0));
 $15 = __THREW__; __THREW__ = 0;
 $16 = $15&1;
 if ($16) {
  $41 = ___cxa_find_matching_catch_2()|0;
  $42 = tempRet0;
  $5 = $41;
  $6 = $42;
  __ZdlPv($14);
  $49 = $5;
  $50 = $6;
  ___resumeException($49|0);
  // unreachable;
 }
 $7 = $14;
 $17 = $7;
 __ZN3osg17TessellationHints14setDetailRatioEf($17,0.5);
 $18 = (__Znwj(160)|0);
 __THREW__ = 0;
 invoke_vi(3360,($18|0));
 $19 = __THREW__; __THREW__ = 0;
 $20 = $19&1;
 if ($20) {
  $43 = ___cxa_find_matching_catch_2()|0;
  $44 = tempRet0;
  $5 = $43;
  $6 = $44;
  __ZdlPv($18);
  $49 = $5;
  $50 = $6;
  ___resumeException($49|0);
  // unreachable;
 }
 __ZN3osg7ref_ptrINS_5GeodeEEC2EPS1_($8,$18);
 __THREW__ = 0;
 $21 = (invoke_ii(4085,($8|0))|0);
 $22 = __THREW__; __THREW__ = 0;
 $23 = $22&1;
 do {
  if ($23) {
   label = 13;
  } else {
   $24 = HEAP32[$21>>2]|0;
   $25 = ((($24)) + 240|0);
   $26 = HEAP32[$25>>2]|0;
   __THREW__ = 0;
   $27 = (invoke_ii(3276,296)|0);
   $28 = __THREW__; __THREW__ = 0;
   $29 = $28&1;
   if ($29) {
    label = 13;
   } else {
    $30 = $4;
    $31 = $7;
    __THREW__ = 0;
    invoke_viii(4086,($27|0),($30|0),($31|0));
    $32 = __THREW__; __THREW__ = 0;
    $33 = $32&1;
    if ($33) {
     $47 = ___cxa_find_matching_catch_2()|0;
     $48 = tempRet0;
     $5 = $47;
     $6 = $48;
     __ZdlPv($27);
     break;
    }
    __THREW__ = 0;
    (invoke_iii($26|0,($21|0),($27|0))|0);
    $34 = __THREW__; __THREW__ = 0;
    $35 = $34&1;
    if ($35) {
     label = 13;
    } else {
     __THREW__ = 0;
     $36 = (invoke_ii(4087,($8|0))|0);
     $37 = __THREW__; __THREW__ = 0;
     $38 = $37&1;
     if ($38) {
      label = 13;
     } else {
      __ZN3osg7ref_ptrINS_5GeodeEED2Ev($8);
      STACKTOP = sp;return ($36|0);
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 13) {
  $45 = ___cxa_find_matching_catch_2()|0;
  $46 = tempRet0;
  $5 = $45;
  $6 = $46;
 }
 __ZN3osg7ref_ptrINS_5GeodeEED2Ev($8);
 $49 = $5;
 $50 = $6;
 ___resumeException($49|0);
 // unreachable;
 return (0)|0;
}
function __ZN3osg6SphereC2ERKNS_5Vec3fEf($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = +$2;
 var $10 = 0.0, $3 = 0, $4 = 0, $5 = 0.0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = $0;
 $4 = $1;
 $5 = $2;
 $6 = $3;
 __ZN3osg5ShapeC2Ev($6);
 HEAP32[$6>>2] = (66016);
 $7 = ((($6)) + 32|0);
 $8 = $4;
 ;HEAP32[$7>>2]=HEAP32[$8>>2]|0;HEAP32[$7+4>>2]=HEAP32[$8+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[$8+8>>2]|0;
 $9 = ((($6)) + 44|0);
 $10 = $5;
 HEAPF32[$9>>2] = $10;
 STACKTOP = sp;return;
}
function __ZN3osg17TessellationHintsC2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 __ZN3osg6ObjectC2Ev($2);
 HEAP32[$2>>2] = (71604);
 $3 = ((($2)) + 32|0);
 HEAP32[$3>>2] = 0;
 $4 = ((($2)) + 36|0);
 HEAPF32[$4>>2] = 1.0;
 $5 = ((($2)) + 40|0);
 HEAP32[$5>>2] = 100;
 $6 = ((($2)) + 44|0);
 HEAP8[$6>>0] = 1;
 $7 = ((($2)) + 45|0);
 HEAP8[$7>>0] = 0;
 $8 = ((($2)) + 46|0);
 HEAP8[$8>>0] = 1;
 $9 = ((($2)) + 47|0);
 HEAP8[$9>>0] = 0;
 $10 = ((($2)) + 48|0);
 HEAP8[$10>>0] = 1;
 $11 = ((($2)) + 49|0);
 HEAP8[$11>>0] = 1;
 $12 = ((($2)) + 50|0);
 HEAP8[$12>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN3osg17TessellationHints14setDetailRatioEf($0,$1) {
 $0 = $0|0;
 $1 = +$1;
 var $2 = 0, $3 = 0.0, $4 = 0, $5 = 0.0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = $0;
 $3 = $1;
 $4 = $2;
 $5 = $3;
 $6 = ((($4)) + 36|0);
 HEAPF32[$6>>2] = $5;
 STACKTOP = sp;return;
}
function __ZN3osg7ref_ptrINS_5GeodeEEC2EPS1_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = $0;
 $3 = $1;
 $4 = $2;
 $5 = $3;
 HEAP32[$4>>2] = $5;
 $6 = HEAP32[$4>>2]|0;
 $7 = ($6|0)!=(0|0);
 if (!($7)) {
  STACKTOP = sp;return;
 }
 $8 = HEAP32[$4>>2]|0;
 (__ZNK3osg10Referenced3refEv($8)|0);
 STACKTOP = sp;return;
}
function __ZNK3osg7ref_ptrINS_5GeodeEEptEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 STACKTOP = sp;return ($3|0);
}
function __ZN3osg7ref_ptrINS_5GeodeEE7releaseEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $3 = $1;
 $4 = HEAP32[$3>>2]|0;
 $2 = $4;
 $5 = HEAP32[$3>>2]|0;
 $6 = ($5|0)!=(0|0);
 if ($6) {
  $7 = HEAP32[$3>>2]|0;
  (__ZNK3osg10Referenced14unref_nodeleteEv($7)|0);
 }
 HEAP32[$3>>2] = 0;
 $8 = $2;
 STACKTOP = sp;return ($8|0);
}
function __ZN3osg7ref_ptrINS_5GeodeEED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)!=(0|0);
 if (!($4)) {
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 $5 = HEAP32[$2>>2]|0;
 __THREW__ = 0;
 (invoke_ii(4050,($5|0))|0);
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if ($7) {
  $8 = ___cxa_find_matching_catch_3(0|0)|0;
  $9 = tempRet0;
  ___clang_call_terminate($8);
  // unreachable;
 } else {
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
}
function __ZN3osg6ObjectC2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $10 = $0;
 $11 = $10;
 __ZN3osg10ReferencedC2Ev($11);
 HEAP32[$11>>2] = (63412);
 $12 = ((($11)) + 12|0);
 $9 = $12;
 $13 = $9;
 $8 = $13;
 $14 = $8;
 $7 = $14;
 $15 = $7;
 $6 = $15;
 ;HEAP32[$15>>2]=0|0;HEAP32[$15+4>>2]=0|0;HEAP32[$15+8>>2]=0|0;
 $3 = $13;
 $16 = $3;
 $2 = $16;
 $17 = $2;
 $1 = $17;
 $18 = $1;
 $4 = $18;
 $5 = 0;
 while(1) {
  $19 = $5;
  $20 = ($19>>>0)<(3);
  if (!($20)) {
   break;
  }
  $21 = $4;
  $22 = $5;
  $23 = (($21) + ($22<<2)|0);
  HEAP32[$23>>2] = 0;
  $24 = $5;
  $25 = (($24) + 1)|0;
  $5 = $25;
 }
 $26 = ((($11)) + 24|0);
 HEAP32[$26>>2] = 2;
 $27 = ((($11)) + 28|0);
 HEAP32[$27>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN3osg17TessellationHintsD2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 __ZN3osg6ObjectD2Ev($2);
 STACKTOP = sp;return;
}
function __ZN3osg17TessellationHintsD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 __ZN3osg17TessellationHintsD2Ev($2);
 __ZdlPv($2);
 STACKTOP = sp;return;
}
function __ZNK3osg17TessellationHints9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $4 = (__Znwj(52)|0);
 __THREW__ = 0;
 invoke_vi(4084,($4|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $7 = ___cxa_find_matching_catch_2()|0;
  $8 = tempRet0;
  $2 = $7;
  $3 = $8;
  __ZdlPv($4);
  $9 = $2;
  $10 = $3;
  ___resumeException($9|0);
  // unreachable;
 } else {
  STACKTOP = sp;return ($4|0);
 }
 return (0)|0;
}
function __ZNK3osg17TessellationHints5cloneERKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = $0;
 $3 = $1;
 $6 = $2;
 $7 = (__Znwj(52)|0);
 $8 = $3;
 __THREW__ = 0;
 invoke_viii(4088,($7|0),($6|0),($8|0));
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if ($10) {
  $11 = ___cxa_find_matching_catch_2()|0;
  $12 = tempRet0;
  $4 = $11;
  $5 = $12;
  __ZdlPv($7);
  $13 = $4;
  $14 = $5;
  ___resumeException($13|0);
  // unreachable;
 } else {
  STACKTOP = sp;return ($7|0);
 }
 return (0)|0;
}
function __ZNK3osg17TessellationHints12isSameKindAsEPKNS_6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = $0;
 $3 = $1;
 $4 = $3;
 $5 = ($4|0)==(0|0);
 if ($5) {
  $7 = 0;
 } else {
  $6 = (___dynamic_cast($4,26112,27416,0)|0);
  $7 = $6;
 }
 $8 = ($7|0)!=(0|0);
 STACKTOP = sp;return ($8|0);
}
function __ZNK3osg17TessellationHints11libraryNameEv($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 STACKTOP = sp;return (175113|0);
}
function __ZNK3osg17TessellationHints9classNameEv($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 STACKTOP = sp;return (162455|0);
}
function __ZN3osg17TessellationHintsC2ERKS0_RKNS_6CopyOpE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0.0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = $0;
 $4 = $1;
 $5 = $2;
 $6 = $3;
 $7 = $4;
 $8 = $5;
 __ZN3osg6ObjectC2ERKS0_RKNS_6CopyOpE($6,$7,$8);
 HEAP32[$6>>2] = (71604);
 $9 = ((($6)) + 32|0);
 $10 = $4;
 $11 = ((($10)) + 32|0);
 $12 = HEAP32[$11>>2]|0;
 HEAP32[$9>>2] = $12;
 $13 = ((($6)) + 36|0);
 $14 = $4;
 $15 = ((($14)) + 36|0);
 $16 = +HEAPF32[$15>>2];
 HEAPF32[$13>>2] = $16;
 $17 = ((($6)) + 40|0);
 $18 = $4;
 $19 = ((($18)) + 40|0);
 $20 = HEAP32[$19>>2]|0;
 HEAP32[$17>>2] = $20;
 $21 = ((($6)) + 44|0);
 $22 = $4;
 $23 = ((($22)) + 44|0);
 $24 = HEAP8[$23>>0]|0;
 $25 = $24&1;
 $26 = $25&1;
 HEAP8[$21>>0] = $26;
 $27 = ((($6)) + 45|0);
 $28 = $4;
 $29 = ((($28)) + 45|0);
 $30 = HEAP8[$29>>0]|0;
 $31 = $30&1;
 $32 = $31&1;
 HEAP8[$27>>0] = $32;
 $33 = ((($6)) + 46|0);
 $34 = $4;
 $35 = ((($34)) + 46|0);
 $36 = HEAP8[$35>>0]|0;
 $37 = $36&1;
 $38 = $37&1;
 HEAP8[$33>>0] = $38;
 $39 = ((($6)) + 47|0);
 $40 = $4;
 $41 = ((($40)) + 47|0);
 $42 = HEAP8[$41>>0]|0;
 $43 = $42&1;
 $44 = $43&1;
 HEAP8[$39>>0] = $44;
 $45 = ((($6)) + 48|0);
 $46 = $4;
 $47 = ((($46)) + 48|0);
 $48 = HEAP8[$47>>0]|0;
 $49 = $48&1;
 $50 = $49&1;
 HEAP8[$45>>0] = $50;
 $51 = ((($6)) + 49|0);
 $52 = $4;
 $53 = ((($52)) + 49|0);
 $54 = HEAP8[$53>>0]|0;
 $55 = $54&1;
 $56 = $55&1;
 HEAP8[$51>>0] = $56;
 $57 = ((($6)) + 50|0);
 $58 = $4;
 $59 = ((($58)) + 50|0);
 $60 = HEAP8[$59>>0]|0;
 $61 = $60&1;
 $62 = $61&1;
 HEAP8[$57>>0] = $62;
 STACKTOP = sp;return;
}
function __ZN3osg5ShapeC2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 __ZN3osg6ObjectC2Ev($2);
 HEAP32[$2>>2] = (65860);
 STACKTOP = sp;return;
}
function __ZN4mjin11application6memory6render14createMaterialENSt3__212basic_stringIcNS3_11char_traitsIcEENS3_9allocatorIcEEEES9_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $7 = sp;
 $8 = (__Znwj(128)|0);
 __THREW__ = 0;
 invoke_viii(3619,($8|0),35633,($0|0));
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if ($10) {
  $33 = ___cxa_find_matching_catch_2()|0;
  $34 = tempRet0;
  $3 = $33;
  $4 = $34;
  __ZdlPv($8);
  $43 = $3;
  $44 = $4;
  ___resumeException($43|0);
  // unreachable;
 }
 $2 = $8;
 $11 = (__Znwj(128)|0);
 __THREW__ = 0;
 invoke_viii(3619,($11|0),35632,($1|0));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $35 = ___cxa_find_matching_catch_2()|0;
  $36 = tempRet0;
  $3 = $35;
  $4 = $36;
  __ZdlPv($11);
  $43 = $3;
  $44 = $4;
  ___resumeException($43|0);
  // unreachable;
 }
 $5 = $11;
 $14 = (__Znwj(172)|0);
 __THREW__ = 0;
 invoke_vi(3613,($14|0));
 $15 = __THREW__; __THREW__ = 0;
 $16 = $15&1;
 if ($16) {
  $37 = ___cxa_find_matching_catch_2()|0;
  $38 = tempRet0;
  $3 = $37;
  $4 = $38;
  __ZdlPv($14);
  $43 = $3;
  $44 = $4;
  ___resumeException($43|0);
  // unreachable;
 }
 $6 = $14;
 $17 = $6;
 $18 = $2;
 (__ZN3osg7Program9addShaderEPNS_6ShaderE($17,$18)|0);
 $19 = $6;
 $20 = $5;
 (__ZN3osg7Program9addShaderEPNS_6ShaderE($19,$20)|0);
 $21 = (__Znwj(160)|0);
 __THREW__ = 0;
 invoke_vi(3572,($21|0));
 $22 = __THREW__; __THREW__ = 0;
 $23 = $22&1;
 if ($23) {
  $39 = ___cxa_find_matching_catch_2()|0;
  $40 = tempRet0;
  $3 = $39;
  $4 = $40;
  __ZdlPv($21);
  $43 = $3;
  $44 = $4;
  ___resumeException($43|0);
  // unreachable;
 }
 __ZN3osg7ref_ptrINS_8StateSetEEC2EPS1_($7,$21);
 __THREW__ = 0;
 $24 = (invoke_ii(4089,($7|0))|0);
 $25 = __THREW__; __THREW__ = 0;
 $26 = $25&1;
 if (!($26)) {
  $27 = $6;
  __THREW__ = 0;
  invoke_viii(3357,($24|0),($27|0),0);
  $28 = __THREW__; __THREW__ = 0;
  $29 = $28&1;
  if (!($29)) {
   __THREW__ = 0;
   $30 = (invoke_ii(4090,($7|0))|0);
   $31 = __THREW__; __THREW__ = 0;
   $32 = $31&1;
   if (!($32)) {
    __ZN3osg7ref_ptrINS_8StateSetEED2Ev($7);
    STACKTOP = sp;return ($30|0);
   }
  }
 }
 $41 = ___cxa_find_matching_catch_2()|0;
 $42 = tempRet0;
 $3 = $41;
 $4 = $42;
 __ZN3osg7ref_ptrINS_8StateSetEED2Ev($7);
 $43 = $3;
 $44 = $4;
 ___resumeException($43|0);
 // unreachable;
 return (0)|0;
}
function __ZN3osg7ref_ptrINS_8StateSetEEC2EPS1_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = $0;
 $3 = $1;
 $4 = $2;
 $5 = $3;
 HEAP32[$4>>2] = $5;
 $6 = HEAP32[$4>>2]|0;
 $7 = ($6|0)!=(0|0);
 if (!($7)) {
  STACKTOP = sp;return;
 }
 $8 = HEAP32[$4>>2]|0;
 (__ZNK3osg10Referenced3refEv($8)|0);
 STACKTOP = sp;return;
}
function __ZNK3osg7ref_ptrINS_8StateSetEEptEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 STACKTOP = sp;return ($3|0);
}
function __ZN3osg7ref_ptrINS_8StateSetEE7releaseEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $3 = $1;
 $4 = HEAP32[$3>>2]|0;
 $2 = $4;
 $5 = HEAP32[$3>>2]|0;
 $6 = ($5|0)!=(0|0);
 if ($6) {
  $7 = HEAP32[$3>>2]|0;
  (__ZNK3osg10Referenced14unref_nodeleteEv($7)|0);
 }
 HEAP32[$3>>2] = 0;
 $8 = $2;
 STACKTOP = sp;return ($8|0);
}
function __ZN3osg7ref_ptrINS_8StateSetEED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)!=(0|0);
 if (!($4)) {
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 $5 = HEAP32[$2>>2]|0;
 __THREW__ = 0;
 (invoke_ii(4050,($5|0))|0);
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if ($7) {
  $8 = ___cxa_find_matching_catch_3(0|0)|0;
  $9 = tempRet0;
  ___clang_call_terminate($8);
  // unreachable;
 } else {
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
}
function __GLOBAL__sub_I_selection_cpp() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 ___cxx_global_var_init_4367();
 ___cxx_global_var_init_1_4368();
 ___cxx_global_var_init_2_4369();
 return;
}
function ___cxx_global_var_init_4367() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg5Vec3fC2Efff(209140,1.0,0.0,0.0);
 return;
}
function ___cxx_global_var_init_1_4368() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg5Vec3fC2Efff(209128,0.0,1.0,0.0);
 return;
}
function ___cxx_global_var_init_2_4369() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg5Vec3fC2Efff(209116,0.0,0.0,1.0);
 return;
}
function __ZN4mjin11application6memory9selection6nodeAtERKN3osg5Vec2fEPNS3_6CameraEj($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0.0, $42 = 0, $43 = 0, $44 = 0.0, $45 = 0, $46 = 0.0, $47 = 0, $48 = 0, $49 = 0.0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 432|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(432|0);
 $vararg_buffer = sp + 96|0;
 $13 = sp + 384|0;
 $16 = sp + 372|0;
 $20 = sp + 356|0;
 $23 = sp + 344|0;
 $29 = sp + 320|0;
 $32 = sp + 120|0;
 $34 = sp;
 $36 = sp + 108|0;
 $37 = sp + 104|0;
 $26 = $0;
 $27 = $1;
 $28 = $2;
 $39 = (__Znwj(96)|0);
 $40 = $26;
 __THREW__ = 0;
 $41 = (+invoke_di(4091,($40|0)));
 $42 = __THREW__; __THREW__ = 0;
 $43 = $42&1;
 if (!($43)) {
  $44 = $41;
  $45 = $26;
  __THREW__ = 0;
  $46 = (+invoke_di(4092,($45|0)));
  $47 = __THREW__; __THREW__ = 0;
  $48 = $47&1;
  if (!($48)) {
   $49 = $46;
   __THREW__ = 0;
   invoke_viidd(3319,($39|0),0,(+$44),(+$49));
   $50 = __THREW__; __THREW__ = 0;
   $51 = $50&1;
   if (!($51)) {
    __ZN3osg7ref_ptrIN7osgUtil22LineSegmentIntersectorEEC2EPS2_($29,$39);
    __THREW__ = 0;
    $52 = (invoke_ii(4093,($29|0))|0);
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if ($54) {
     label = 12;
    } else {
     __THREW__ = 0;
     invoke_viii(3310,($32|0),($52|0),(0|0));
     $55 = __THREW__; __THREW__ = 0;
     $56 = $55&1;
     if ($56) {
      label = 12;
     } else {
      $57 = $27;
      $58 = HEAP32[$57>>2]|0;
      $59 = ((($58)) + 188|0);
      $60 = HEAP32[$59>>2]|0;
      __THREW__ = 0;
      invoke_vii($60|0,($57|0),($32|0));
      $61 = __THREW__; __THREW__ = 0;
      $62 = $61&1;
      do {
       if ($62) {
        label = 13;
       } else {
        __THREW__ = 0;
        $63 = (invoke_ii(4094,($29|0))|0);
        $64 = __THREW__; __THREW__ = 0;
        $65 = $64&1;
        if ($65) {
         label = 13;
        } else {
         $66 = HEAP32[$63>>2]|0;
         $67 = ((($66)) + 32|0);
         $68 = HEAP32[$67>>2]|0;
         __THREW__ = 0;
         $69 = (invoke_ii($68|0,($63|0))|0);
         $70 = __THREW__; __THREW__ = 0;
         $71 = $70&1;
         if ($71) {
          label = 13;
         } else {
          if (!($69)) {
           $25 = 0;
           $33 = 1;
           __ZN7osgUtil19IntersectionVisitorD1Ev($32);
           __ZN3osg7ref_ptrIN7osgUtil22LineSegmentIntersectorEED2Ev($29);
           $130 = $25;
           STACKTOP = sp;return ($130|0);
          }
          __THREW__ = 0;
          $78 = (invoke_ii(4094,($29|0))|0);
          $79 = __THREW__; __THREW__ = 0;
          $80 = $79&1;
          if ($80) {
           label = 13;
          } else {
           __THREW__ = 0;
           invoke_vii(4095,($34|0),($78|0));
           $81 = __THREW__; __THREW__ = 0;
           $82 = $81&1;
           if ($82) {
            label = 13;
           } else {
            $83 = ((($34)) + 8|0);
            $35 = $83;
            $84 = $35;
            $24 = $84;
            $85 = $24;
            $86 = HEAP32[$85>>2]|0;
            $21 = $85;
            $22 = $86;
            $87 = $22;
            $18 = $20;
            $19 = $87;
            $88 = $18;
            $89 = $19;
            HEAP32[$88>>2] = $89;
            $90 = HEAP32[$20>>2]|0;
            HEAP32[$23>>2] = $90;
            $91 = HEAP32[$23>>2]|0;
            HEAP32[$36>>2] = $91;
            $92 = $35;
            $17 = $92;
            $93 = $17;
            $94 = ((($93)) + 4|0);
            $95 = HEAP32[$94>>2]|0;
            $14 = $93;
            $15 = $95;
            $96 = $15;
            $11 = $13;
            $12 = $96;
            $97 = $11;
            $98 = $12;
            HEAP32[$97>>2] = $98;
            $99 = HEAP32[$13>>2]|0;
            HEAP32[$16>>2] = $99;
            $100 = HEAP32[$16>>2]|0;
            HEAP32[$37>>2] = $100;
            while(1) {
             $9 = $36;
             $10 = $37;
             $101 = $9;
             $102 = $10;
             $7 = $101;
             $8 = $102;
             $103 = $7;
             $6 = $103;
             $104 = $6;
             $105 = HEAP32[$104>>2]|0;
             $106 = $8;
             $5 = $106;
             $107 = $5;
             $108 = HEAP32[$107>>2]|0;
             $109 = ($105|0)==($108|0);
             $110 = $109 ^ 1;
             if (!($110)) {
              label = 23;
              break;
             }
             $4 = $36;
             $111 = $4;
             $112 = HEAP32[$111>>2]|0;
             $113 = HEAP32[$112>>2]|0;
             $38 = $113;
             $114 = $38;
             __THREW__ = 0;
             $115 = (invoke_ii(4096,($114|0))|0);
             $116 = __THREW__; __THREW__ = 0;
             $117 = $116&1;
             if ($117) {
              label = 21;
              break;
             }
             $118 = $28;
             $119 = $115 & $118;
             $120 = $28;
             $121 = ($119|0)!=($120|0);
             if ($121) {
              label = 20;
              break;
             }
             $3 = $36;
             $125 = $3;
             $126 = HEAP32[$125>>2]|0;
             $127 = ((($126)) + 4|0);
             HEAP32[$125>>2] = $127;
            }
            if ((label|0) == 20) {
             $122 = $38;
             $25 = $122;
             $33 = 1;
            }
            else if ((label|0) == 23) {
             __THREW__ = 0;
             invoke_vii(3251,(162499|0),($vararg_buffer|0));
             $128 = __THREW__; __THREW__ = 0;
             $129 = $128&1;
             if ($129) {
              label = 21;
             } else {
              $25 = 0;
              $33 = 1;
             }
            }
            if ((label|0) == 21) {
             $123 = ___cxa_find_matching_catch_2()|0;
             $124 = tempRet0;
             $30 = $123;
             $31 = $124;
             __ZN7osgUtil22LineSegmentIntersector12IntersectionD2Ev($34);
             break;
            }
            __ZN7osgUtil22LineSegmentIntersector12IntersectionD2Ev($34);
            __ZN7osgUtil19IntersectionVisitorD1Ev($32);
            __ZN3osg7ref_ptrIN7osgUtil22LineSegmentIntersectorEED2Ev($29);
            $130 = $25;
            STACKTOP = sp;return ($130|0);
           }
          }
         }
        }
       }
      } while(0);
      if ((label|0) == 13) {
       $76 = ___cxa_find_matching_catch_2()|0;
       $77 = tempRet0;
       $30 = $76;
       $31 = $77;
      }
      __ZN7osgUtil19IntersectionVisitorD1Ev($32);
     }
    }
    if ((label|0) == 12) {
     $74 = ___cxa_find_matching_catch_2()|0;
     $75 = tempRet0;
     $30 = $74;
     $31 = $75;
    }
    __ZN3osg7ref_ptrIN7osgUtil22LineSegmentIntersectorEED2Ev($29);
    $131 = $30;
    $132 = $31;
    ___resumeException($131|0);
    // unreachable;
   }
  }
 }
 $72 = ___cxa_find_matching_catch_2()|0;
 $73 = tempRet0;
 $30 = $72;
 $31 = $73;
 __ZdlPv($39);
 $131 = $30;
 $132 = $31;
 ___resumeException($131|0);
 // unreachable;
 return (0)|0;
}
function __ZNK3osg5Vec2f1xEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 $3 = +HEAPF32[$2>>2];
 STACKTOP = sp;return (+$3);
}
function __ZNK3osg5Vec2f1yEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 $3 = ((($2)) + 4|0);
 $4 = +HEAPF32[$3>>2];
 STACKTOP = sp;return (+$4);
}
function __ZN3osg7ref_ptrIN7osgUtil22LineSegmentIntersectorEEC2EPS2_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = $0;
 $3 = $1;
 $4 = $2;
 $5 = $3;
 HEAP32[$4>>2] = $5;
 $6 = HEAP32[$4>>2]|0;
 $7 = ($6|0)!=(0|0);
 if (!($7)) {
  STACKTOP = sp;return;
 }
 $8 = HEAP32[$4>>2]|0;
 (__ZNK3osg10Referenced3refEv($8)|0);
 STACKTOP = sp;return;
}
function __ZNK3osg7ref_ptrIN7osgUtil22LineSegmentIntersectorEE3getEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 STACKTOP = sp;return ($3|0);
}
function __ZNK3osg7ref_ptrIN7osgUtil22LineSegmentIntersectorEEptEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 STACKTOP = sp;return ($3|0);
}
function __ZN7osgUtil22LineSegmentIntersector20getFirstIntersectionEv($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(80|0);
 $5 = sp;
 $9 = sp + 48|0;
 $11 = sp + 40|0;
 $13 = sp + 32|0;
 $20 = sp + 4|0;
 $18 = $1;
 $21 = $18;
 $22 = (__ZN7osgUtil22LineSegmentIntersector16getIntersectionsEv($21)|0);
 $19 = $22;
 $23 = $19;
 $17 = $23;
 $24 = $17;
 $16 = $24;
 $25 = $16;
 $26 = ((($25)) + 8|0);
 $15 = $26;
 $27 = $15;
 $14 = $27;
 $28 = $14;
 $29 = HEAP32[$28>>2]|0;
 $30 = ($29|0)==(0);
 if ($30) {
  __ZN7osgUtil22LineSegmentIntersector12IntersectionC2Ev($0);
  STACKTOP = sp;return;
 } else {
  $31 = $19;
  $12 = $31;
  $32 = $12;
  $10 = $32;
  $33 = $10;
  $8 = $33;
  $34 = $8;
  $35 = HEAP32[$34>>2]|0;
  $6 = $9;
  $7 = $35;
  $36 = $6;
  $37 = $7;
  HEAP32[$36>>2] = $37;
  $38 = HEAP32[$9>>2]|0;
  HEAP32[$13>>2] = $38;
  ;HEAP8[$5>>0]=HEAP8[$13>>0]|0;HEAP8[$5+1>>0]=HEAP8[$13+1>>0]|0;HEAP8[$5+2>>0]=HEAP8[$13+2>>0]|0;HEAP8[$5+3>>0]=HEAP8[$13+3>>0]|0;
  $4 = $11;
  $39 = $4;
  $40 = HEAP32[$5>>2]|0;
  HEAP32[$39>>2] = $40;
  $41 = HEAP32[$11>>2]|0;
  HEAP32[$20>>2] = $41;
  $3 = $20;
  $42 = $3;
  $2 = $42;
  $43 = $2;
  $44 = HEAP32[$43>>2]|0;
  $45 = ((($44)) + 16|0);
  __ZN7osgUtil22LineSegmentIntersector12IntersectionC2ERKS1_($0,$45);
  STACKTOP = sp;return;
 }
}
function __ZN3osg7ref_ptrIN7osgUtil22LineSegmentIntersectorEED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)!=(0|0);
 if (!($4)) {
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 $5 = HEAP32[$2>>2]|0;
 __THREW__ = 0;
 (invoke_ii(4050,($5|0))|0);
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if ($7) {
  $8 = ___cxa_find_matching_catch_3(0|0)|0;
  $9 = tempRet0;
  ___clang_call_terminate($8);
  // unreachable;
 } else {
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
}
function __ZN7osgUtil22LineSegmentIntersector16getIntersectionsEv($0) {
 $0 = $0|0;
 var $$sink = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 $3 = ((($2)) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)!=(0|0);
 if ($5) {
  $6 = ((($2)) + 28|0);
  $7 = HEAP32[$6>>2]|0;
  $$sink = $7;
 } else {
  $$sink = $2;
 }
 $8 = ((($$sink)) + 80|0);
 STACKTOP = sp;return ($8|0);
}
function __ZN7osgUtil22LineSegmentIntersector12IntersectionC2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(144|0);
 $4 = sp + 116|0;
 $7 = sp + 104|0;
 $14 = sp + 76|0;
 $17 = sp + 64|0;
 $24 = sp + 36|0;
 $27 = sp + 24|0;
 $31 = $0;
 $34 = $31;
 HEAPF64[$34>>3] = -1.0;
 $35 = ((($34)) + 8|0);
 $30 = $35;
 $36 = $30;
 $29 = $36;
 $37 = $29;
 $28 = $37;
 HEAP32[$37>>2] = 0;
 $38 = ((($37)) + 4|0);
 HEAP32[$38>>2] = 0;
 $39 = ((($37)) + 8|0);
 $26 = $39;
 HEAP32[$27>>2] = 0;
 $40 = $26;
 $25 = $27;
 $41 = $25;
 $42 = HEAP32[$41>>2]|0;
 $23 = $40;
 HEAP32[$24>>2] = $42;
 $43 = $23;
 $22 = $43;
 $21 = $24;
 $44 = $21;
 $45 = HEAP32[$44>>2]|0;
 HEAP32[$43>>2] = $45;
 $46 = ((($34)) + 20|0);
 __THREW__ = 0;
 invoke_vi(4097,($46|0));
 $47 = __THREW__; __THREW__ = 0;
 $48 = $47&1;
 if ($48) {
  $81 = ___cxa_find_matching_catch_2()|0;
  $82 = tempRet0;
  $32 = $81;
  $33 = $82;
  __ZNSt3__26vectorIPN3osg4NodeENS_9allocatorIS3_EEED2Ev($35);
  $87 = $32;
  $88 = $33;
  ___resumeException($87|0);
  // unreachable;
 }
 $49 = ((($34)) + 24|0);
 __THREW__ = 0;
 invoke_vi(4098,($49|0));
 $50 = __THREW__; __THREW__ = 0;
 $51 = $50&1;
 if ($51) {
  $83 = ___cxa_find_matching_catch_2()|0;
  $84 = tempRet0;
  $32 = $83;
  $33 = $84;
 } else {
  $52 = ((($34)) + 32|0);
  __THREW__ = 0;
  invoke_vi(4099,($52|0));
  $53 = __THREW__; __THREW__ = 0;
  $54 = $53&1;
  if (!($54)) {
   $55 = ((($34)) + 56|0);
   __THREW__ = 0;
   invoke_vi(4100,($55|0));
   $56 = __THREW__; __THREW__ = 0;
   $57 = $56&1;
   if (!($57)) {
    $58 = ((($34)) + 68|0);
    $20 = $58;
    $59 = $20;
    $19 = $59;
    $60 = $19;
    $18 = $60;
    HEAP32[$60>>2] = 0;
    $61 = ((($60)) + 4|0);
    HEAP32[$61>>2] = 0;
    $62 = ((($60)) + 8|0);
    $16 = $62;
    HEAP32[$17>>2] = 0;
    $63 = $16;
    $15 = $17;
    $64 = $15;
    $65 = HEAP32[$64>>2]|0;
    $13 = $63;
    HEAP32[$14>>2] = $65;
    $66 = $13;
    $12 = $66;
    $11 = $14;
    $67 = $11;
    $68 = HEAP32[$67>>2]|0;
    HEAP32[$66>>2] = $68;
    $69 = ((($34)) + 80|0);
    $10 = $69;
    $70 = $10;
    $9 = $70;
    $71 = $9;
    $8 = $71;
    HEAP32[$71>>2] = 0;
    $72 = ((($71)) + 4|0);
    HEAP32[$72>>2] = 0;
    $73 = ((($71)) + 8|0);
    $6 = $73;
    HEAP32[$7>>2] = 0;
    $74 = $6;
    $5 = $7;
    $75 = $5;
    $76 = HEAP32[$75>>2]|0;
    $3 = $74;
    HEAP32[$4>>2] = $76;
    $77 = $3;
    $2 = $77;
    $1 = $4;
    $78 = $1;
    $79 = HEAP32[$78>>2]|0;
    HEAP32[$77>>2] = $79;
    $80 = ((($34)) + 92|0);
    HEAP32[$80>>2] = 0;
    STACKTOP = sp;return;
   }
  }
  $85 = ___cxa_find_matching_catch_2()|0;
  $86 = tempRet0;
  $32 = $85;
  $33 = $86;
  __ZN3osg7ref_ptrINS_10RefMatrixdEED2Ev($49);
 }
 __ZN3osg7ref_ptrINS_8DrawableEED2Ev($46);
 __ZNSt3__26vectorIPN3osg4NodeENS_9allocatorIS3_EEED2Ev($35);
 $87 = $32;
 $88 = $33;
 ___resumeException($87|0);
 // unreachable;
}
function __ZN3osg7ref_ptrINS_8DrawableEEC2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN3osg7ref_ptrINS_10RefMatrixdEEC2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN3osg5Vec3dC2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 HEAPF64[$2>>3] = 0.0;
 $3 = ((($2)) + 8|0);
 HEAPF64[$3>>3] = 0.0;
 $4 = ((($2)) + 16|0);
 HEAPF64[$4>>3] = 0.0;
 STACKTOP = sp;return;
}
function __ZN3osg5Vec3fC2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 HEAPF32[$2>>2] = 0.0;
 $3 = ((($2)) + 4|0);
 HEAPF32[$3>>2] = 0.0;
 $4 = ((($2)) + 8|0);
 HEAPF32[$4>>2] = 0.0;
 STACKTOP = sp;return;
}
function __ZN3osg7ref_ptrINS_10RefMatrixdEED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)!=(0|0);
 if (!($4)) {
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 $5 = HEAP32[$2>>2]|0;
 __THREW__ = 0;
 (invoke_ii(4050,($5|0))|0);
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if ($7) {
  $8 = ___cxa_find_matching_catch_3(0|0)|0;
  $9 = tempRet0;
  ___clang_call_terminate($8);
  // unreachable;
 } else {
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
}
function __ZN3osg7ref_ptrINS_8DrawableEED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)!=(0|0);
 if (!($4)) {
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 $5 = HEAP32[$2>>2]|0;
 __THREW__ = 0;
 (invoke_ii(4050,($5|0))|0);
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if ($7) {
  $8 = ___cxa_find_matching_catch_3(0|0)|0;
  $9 = tempRet0;
  ___clang_call_terminate($8);
  // unreachable;
 } else {
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
}
function __ZNSt3__26vectorIPN3osg4NodeENS_9allocatorIS3_EEED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 __ZNSt3__213__vector_baseIPN3osg4NodeENS_9allocatorIS3_EEED2Ev($2);
 STACKTOP = sp;return;
}
function __ZNSt3__213__vector_baseIPN3osg4NodeENS_9allocatorIS3_EEED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(128|0);
 $19 = sp;
 $22 = sp + 116|0;
 $30 = $0;
 $31 = $30;
 $32 = HEAP32[$31>>2]|0;
 $33 = ($32|0)!=(0|0);
 if (!($33)) {
  STACKTOP = sp;return;
 }
 $29 = $31;
 $34 = $29;
 $35 = HEAP32[$34>>2]|0;
 $27 = $34;
 $28 = $35;
 $36 = $27;
 while(1) {
  $37 = $28;
  $38 = ((($36)) + 4|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = ($37|0)!=($39|0);
  if (!($40)) {
   break;
  }
  $26 = $36;
  $41 = $26;
  $42 = ((($41)) + 8|0);
  $25 = $42;
  $43 = $25;
  $24 = $43;
  $44 = $24;
  $45 = ((($36)) + 4|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = ((($46)) + -4|0);
  HEAP32[$45>>2] = $47;
  $23 = $47;
  $48 = $23;
  $20 = $44;
  $21 = $48;
  $49 = $20;
  $50 = $21;
  ;HEAP8[$19>>0]=HEAP8[$22>>0]|0;
  $17 = $49;
  $18 = $50;
  $51 = $17;
  $52 = $18;
  $15 = $51;
  $16 = $52;
 }
 $7 = $31;
 $53 = $7;
 $54 = ((($53)) + 8|0);
 $6 = $54;
 $55 = $6;
 $5 = $55;
 $56 = $5;
 $57 = HEAP32[$31>>2]|0;
 $4 = $31;
 $58 = $4;
 $3 = $58;
 $59 = $3;
 $60 = ((($59)) + 8|0);
 $2 = $60;
 $61 = $2;
 $1 = $61;
 $62 = $1;
 $63 = HEAP32[$62>>2]|0;
 $64 = HEAP32[$58>>2]|0;
 $65 = $63;
 $66 = $64;
 $67 = (($65) - ($66))|0;
 $68 = (($67|0) / 4)&-1;
 $12 = $56;
 $13 = $57;
 $14 = $68;
 $69 = $12;
 $70 = $13;
 $71 = $14;
 $9 = $69;
 $10 = $70;
 $11 = $71;
 $72 = $10;
 $8 = $72;
 $73 = $8;
 __ZdlPv($73);
 STACKTOP = sp;return;
}
function __ZN4mjin11application6memory5input5MouseD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 __ZN4mjin11application6memory5input5MouseD2Ev($2,72400);
 $3 = ((($2)) + 84|0);
 $4 = 72472;
 __ZN3osg8CallbackD2Ev($3,$4);
 $5 = ((($2)) + 92|0);
 __ZN3osg6ObjectD2Ev($5);
 STACKTOP = sp;return;
}
function __ZN4mjin11application6memory5input5MouseD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 __ZN4mjin11application6memory5input5MouseD1Ev($2);
 __ZdlPv($2);
 STACKTOP = sp;return;
}
function __ZN4mjin11application6memory5input5Mouse6handleERKN5osgGA15GUIEventAdapterERNS4_16GUIActionAdapterEPN3osg6ObjectEPNSA_11NodeVisitorE($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$expand_i1_val = 0, $$expand_i1_val2 = 0, $$pre_trunc = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0.0, $18 = 0, $19 = 0.0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $5 = sp + 38|0;
 $11 = sp + 8|0;
 $12 = sp + 37|0;
 $6 = $0;
 $7 = $1;
 $8 = $2;
 $9 = $3;
 $10 = $4;
 $15 = $6;
 $16 = $7;
 $17 = (+__ZNK5osgGA15GUIEventAdapter4getXEv($16));
 $18 = $7;
 $19 = (+__ZNK5osgGA15GUIEventAdapter4getYEv($18));
 __ZN3osg5Vec2fC2Eff($11,$17,$19);
 $20 = ((($15)) + 8|0);
 $21 = (__ZNK3osg5Vec2fneERKS0_($20,$11)|0);
 if ($21) {
  $22 = ((($15)) + 8|0);
  ;HEAP32[$22>>2]=HEAP32[$11>>2]|0;HEAP32[$22+4>>2]=HEAP32[$11+4>>2]|0;
  HEAP8[$12>>0] = 1;
  $23 = ((($15)) + 16|0);
  __ZN4mjin11application6memory10observable8VariableIbEaSERKb($23,$12);
 }
 $13 = 0;
 $24 = $7;
 $25 = HEAP32[$24>>2]|0;
 $26 = ((($25)) + 148|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (FUNCTION_TABLE_ii[$27 & 8191]($24)|0);
 $29 = ($28|0)==(1);
 if ($29) {
  $13 = 1;
 } else {
  $30 = $7;
  $31 = HEAP32[$30>>2]|0;
  $32 = ((($31)) + 148|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = (FUNCTION_TABLE_ii[$33 & 8191]($30)|0);
  $35 = ($34|0)==(2);
  if (!($35)) {
   $$expand_i1_val = 1;
   HEAP8[$5>>0] = $$expand_i1_val;
   $$pre_trunc = HEAP8[$5>>0]|0;
   $42 = $$pre_trunc&1;
   STACKTOP = sp;return ($42|0);
  }
 }
 $36 = $7;
 $37 = (__ZNK5osgGA15GUIEventAdapter9getButtonEv($36)|0);
 $38 = (__ZN4mjin11application6memory5input18indexToMouseButtonEi($37)|0);
 $14 = $38;
 $39 = $14;
 $40 = $13;
 $41 = $40&1;
 __ZN4mjin11application6memory5input5Mouse14setButtonStateENS2_12MOUSE_BUTTONEb($15,$39,$41);
 $$expand_i1_val2 = 1;
 HEAP8[$5>>0] = $$expand_i1_val2;
 $$pre_trunc = HEAP8[$5>>0]|0;
 $42 = $$pre_trunc&1;
 STACKTOP = sp;return ($42|0);
}
function __ZThn4_N4mjin11application6memory5input5MouseD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 $3 = ((($2)) + -4|0);
 __ZN4mjin11application6memory5input5MouseD1Ev($3);
 STACKTOP = sp;return;
}
function __ZThn4_N4mjin11application6memory5input5MouseD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 $3 = ((($2)) + -4|0);
 __ZN4mjin11application6memory5input5MouseD0Ev($3);
 STACKTOP = sp;return;
}
function __ZTv0_n112_N4mjin11application6memory5input5MouseD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + -112|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($2) + ($5)|0);
 __ZN4mjin11application6memory5input5MouseD1Ev($6);
 STACKTOP = sp;return;
}
function __ZTv0_n112_N4mjin11application6memory5input5MouseD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + -112|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($2) + ($5)|0);
 __ZN4mjin11application6memory5input5MouseD0Ev($6);
 STACKTOP = sp;return;
}
function __ZTv0_n16_N4mjin11application6memory5input5MouseD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + -16|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($2) + ($5)|0);
 __ZN4mjin11application6memory5input5MouseD1Ev($6);
 STACKTOP = sp;return;
}
function __ZTv0_n16_N4mjin11application6memory5input5MouseD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + -16|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($2) + ($5)|0);
 __ZN4mjin11application6memory5input5MouseD0Ev($6);
 STACKTOP = sp;return;
}
function __ZNK5osgGA15GUIEventAdapter4getXEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 $3 = ((($2)) + 104|0);
 $4 = +HEAPF32[$3>>2];
 STACKTOP = sp;return (+$4);
}
function __ZNK5osgGA15GUIEventAdapter4getYEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 $3 = ((($2)) + 108|0);
 $4 = +HEAPF32[$3>>2];
 STACKTOP = sp;return (+$4);
}
function __ZN3osg5Vec2fC2Eff($0,$1,$2) {
 $0 = $0|0;
 $1 = +$1;
 $2 = +$2;
 var $3 = 0, $4 = 0.0, $5 = 0.0, $6 = 0, $7 = 0.0, $8 = 0.0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = $0;
 $4 = $1;
 $5 = $2;
 $6 = $3;
 $7 = $4;
 HEAPF32[$6>>2] = $7;
 $8 = $5;
 $9 = ((($6)) + 4|0);
 HEAPF32[$9>>2] = $8;
 STACKTOP = sp;return;
}
function __ZNK3osg5Vec2fneERKS0_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0.0, $11 = 0, $12 = 0, $13 = 0.0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0.0, $6 = 0, $7 = 0.0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = $0;
 $3 = $1;
 $4 = $2;
 $5 = +HEAPF32[$4>>2];
 $6 = $3;
 $7 = +HEAPF32[$6>>2];
 $8 = $5 != $7;
 if ($8) {
  $15 = 1;
  STACKTOP = sp;return ($15|0);
 }
 $9 = ((($4)) + 4|0);
 $10 = +HEAPF32[$9>>2];
 $11 = $3;
 $12 = ((($11)) + 4|0);
 $13 = +HEAPF32[$12>>2];
 $14 = $10 != $13;
 $15 = $14;
 STACKTOP = sp;return ($15|0);
}
function __ZN4mjin11application6memory10observable8VariableIbEaSERKb($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = $0;
 $3 = $1;
 $4 = $2;
 $5 = $3;
 $6 = HEAP8[$5>>0]|0;
 $7 = $6&1;
 $8 = $7&1;
 HEAP8[$4>>0] = $8;
 __ZN4mjin11application6memory10observable8VariableIbE6reportEv($4);
 STACKTOP = sp;return;
}
function __ZNK5osgGA15GUIEventAdapter9getButtonEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 $3 = ((($2)) + 84|0);
 $4 = HEAP32[$3>>2]|0;
 STACKTOP = sp;return ($4|0);
}
function __ZN4mjin11application6memory5input18indexToMouseButtonEi($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = $0;
 $3 = $2;
 switch ($3|0) {
 case 1:  {
  $1 = 1;
  break;
 }
 case 2:  {
  $1 = 3;
  break;
 }
 case 4:  {
  $1 = 2;
  break;
 }
 default: {
  $1 = 0;
 }
 }
 $4 = $1;
 STACKTOP = sp;return ($4|0);
}
function __ZN4mjin11application6memory5input5Mouse14setButtonStateENS2_12MOUSE_BUTTONEb($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $$byval_copy2 = 0, $$byval_copy3 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0;
 var $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0;
 var $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0;
 var $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 464|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(464|0);
 $$byval_copy3 = sp + 452|0;
 $$byval_copy2 = sp + 448|0;
 $$byval_copy1 = sp + 444|0;
 $$byval_copy = sp + 440|0;
 $5 = sp + 428|0;
 $8 = sp + 416|0;
 $12 = sp + 400|0;
 $15 = sp + 388|0;
 $23 = sp + 356|0;
 $26 = sp + 344|0;
 $40 = sp + 288|0;
 $43 = sp + 276|0;
 $53 = sp + 236|0;
 $55 = sp + 16|0;
 $56 = sp + 8|0;
 $69 = sp;
 $74 = sp + 460|0;
 $84 = sp + 459|0;
 $87 = sp + 120|0;
 $90 = sp + 108|0;
 $94 = sp + 92|0;
 $97 = sp + 80|0;
 $100 = sp + 68|0;
 $103 = sp + 60|0;
 $104 = sp + 56|0;
 $105 = sp + 52|0;
 $106 = sp + 48|0;
 $107 = sp + 44|0;
 $108 = sp + 40|0;
 $109 = sp + 36|0;
 $110 = sp + 32|0;
 $111 = sp + 28|0;
 $112 = sp + 24|0;
 $113 = sp + 20|0;
 $114 = sp + 457|0;
 $115 = sp + 456|0;
 $99 = $0;
 HEAP32[$100>>2] = $1;
 $116 = $2&1;
 $101 = $116;
 $117 = $99;
 $118 = ((($117)) + 44|0);
 $102 = $118;
 $119 = $102;
 $98 = $119;
 $120 = $98;
 $121 = HEAP32[$120>>2]|0;
 $95 = $120;
 $96 = $121;
 $122 = $96;
 $92 = $94;
 $93 = $122;
 $123 = $92;
 $124 = $93;
 HEAP32[$123>>2] = $124;
 $125 = HEAP32[$94>>2]|0;
 HEAP32[$97>>2] = $125;
 $126 = HEAP32[$97>>2]|0;
 HEAP32[$104>>2] = $126;
 $127 = $102;
 $91 = $127;
 $128 = $91;
 $129 = ((($128)) + 4|0);
 $130 = HEAP32[$129>>2]|0;
 $88 = $128;
 $89 = $130;
 $131 = $89;
 $85 = $87;
 $86 = $131;
 $132 = $85;
 $133 = $86;
 HEAP32[$132>>2] = $133;
 $134 = HEAP32[$87>>2]|0;
 HEAP32[$90>>2] = $134;
 $135 = HEAP32[$90>>2]|0;
 HEAP32[$105>>2] = $135;
 ;HEAP8[$55>>0]=HEAP8[$105>>0]|0;HEAP8[$55+1>>0]=HEAP8[$105+1>>0]|0;HEAP8[$55+2>>0]=HEAP8[$105+2>>0]|0;HEAP8[$55+3>>0]=HEAP8[$105+3>>0]|0;
 ;HEAP8[$56>>0]=HEAP8[$104>>0]|0;HEAP8[$56+1>>0]=HEAP8[$104+1>>0]|0;HEAP8[$56+2>>0]=HEAP8[$104+2>>0]|0;HEAP8[$56+3>>0]=HEAP8[$104+3>>0]|0;
 $54 = $100;
 while(1) {
  $51 = $56;
  $52 = $55;
  $136 = $51;
  $137 = $52;
  $49 = $136;
  $50 = $137;
  $138 = $49;
  $48 = $138;
  $139 = $48;
  $140 = HEAP32[$139>>2]|0;
  $141 = $50;
  $47 = $141;
  $142 = $47;
  $143 = HEAP32[$142>>2]|0;
  $144 = ($140|0)==($143|0);
  $145 = $144 ^ 1;
  if (!($145)) {
   break;
  }
  $45 = $56;
  $146 = $45;
  $147 = HEAP32[$146>>2]|0;
  $148 = HEAP32[$147>>2]|0;
  $149 = $54;
  $150 = HEAP32[$149>>2]|0;
  $151 = ($148|0)==($150|0);
  if ($151) {
   break;
  }
  $46 = $56;
  $152 = $46;
  $153 = HEAP32[$152>>2]|0;
  $154 = ((($153)) + 4|0);
  HEAP32[$152>>2] = $154;
 }
 ;HEAP32[$53>>2]=HEAP32[$56>>2]|0;
 $155 = HEAP32[$53>>2]|0;
 HEAP32[$103>>2] = $155;
 $156 = $102;
 $44 = $156;
 $157 = $44;
 $158 = ((($157)) + 4|0);
 $159 = HEAP32[$158>>2]|0;
 $41 = $157;
 $42 = $159;
 $160 = $42;
 $38 = $40;
 $39 = $160;
 $161 = $38;
 $162 = $39;
 HEAP32[$161>>2] = $162;
 $163 = HEAP32[$40>>2]|0;
 HEAP32[$43>>2] = $163;
 $164 = HEAP32[$43>>2]|0;
 HEAP32[$106>>2] = $164;
 $36 = $103;
 $37 = $106;
 $165 = $36;
 $166 = $37;
 $34 = $165;
 $35 = $166;
 $167 = $34;
 $33 = $167;
 $168 = $33;
 $169 = HEAP32[$168>>2]|0;
 $170 = $35;
 $32 = $170;
 $171 = $32;
 $172 = HEAP32[$171>>2]|0;
 $173 = ($169|0)==($172|0);
 $174 = $173 ^ 1;
 $175 = $101;
 $176 = $175&1;
 if ($174) {
  if ($176) {
   STACKTOP = sp;return;
  }
  $177 = $102;
  $178 = $102;
  $16 = $178;
  $179 = $16;
  $180 = HEAP32[$179>>2]|0;
  $13 = $179;
  $14 = $180;
  $181 = $14;
  $10 = $12;
  $11 = $181;
  $182 = $10;
  $183 = $11;
  HEAP32[$182>>2] = $183;
  $184 = HEAP32[$12>>2]|0;
  HEAP32[$15>>2] = $184;
  $185 = HEAP32[$15>>2]|0;
  HEAP32[$109>>2] = $185;
  $186 = $102;
  $9 = $186;
  $187 = $9;
  $188 = ((($187)) + 4|0);
  $189 = HEAP32[$188>>2]|0;
  $6 = $187;
  $7 = $189;
  $190 = $7;
  $3 = $5;
  $4 = $190;
  $191 = $3;
  $192 = $4;
  HEAP32[$191>>2] = $192;
  $193 = HEAP32[$5>>2]|0;
  HEAP32[$8>>2] = $193;
  $194 = HEAP32[$8>>2]|0;
  HEAP32[$110>>2] = $194;
  ;HEAP32[$$byval_copy>>2]=HEAP32[$109>>2]|0;
  ;HEAP32[$$byval_copy1>>2]=HEAP32[$110>>2]|0;
  $195 = (__ZNSt3__26removeINS_11__wrap_iterIPN4mjin11application6memory5input12MOUSE_BUTTONEEES6_EET_S9_S9_RKT0_($$byval_copy,$$byval_copy1,$100)|0);
  HEAP32[$108>>2] = $195;
  $18 = $107;
  $19 = $108;
  $20 = 0;
  $196 = $18;
  $197 = $19;
  $17 = $197;
  $198 = $17;
  $199 = HEAP32[$198>>2]|0;
  HEAP32[$196>>2] = $199;
  $200 = $102;
  $27 = $200;
  $201 = $27;
  $202 = ((($201)) + 4|0);
  $203 = HEAP32[$202>>2]|0;
  $24 = $201;
  $25 = $203;
  $204 = $25;
  $21 = $23;
  $22 = $204;
  $205 = $21;
  $206 = $22;
  HEAP32[$205>>2] = $206;
  $207 = HEAP32[$23>>2]|0;
  HEAP32[$26>>2] = $207;
  $208 = HEAP32[$26>>2]|0;
  HEAP32[$112>>2] = $208;
  $29 = $111;
  $30 = $112;
  $31 = 0;
  $209 = $29;
  $210 = $30;
  $28 = $210;
  $211 = $28;
  $212 = HEAP32[$211>>2]|0;
  HEAP32[$209>>2] = $212;
  ;HEAP32[$$byval_copy2>>2]=HEAP32[$107>>2]|0;
  ;HEAP32[$$byval_copy3>>2]=HEAP32[$111>>2]|0;
  $213 = (__ZNSt3__26vectorIN4mjin11application6memory5input12MOUSE_BUTTONENS_9allocatorIS5_EEE5eraseENS_11__wrap_iterIPKS5_EESC_($177,$$byval_copy2,$$byval_copy3)|0);
  HEAP32[$113>>2] = $213;
  HEAP8[$114>>0] = 1;
  $214 = ((($117)) + 56|0);
  __ZN4mjin11application6memory10observable8VariableIbEaSERKb($214,$114);
  STACKTOP = sp;return;
 }
 if (!($176)) {
  STACKTOP = sp;return;
 }
 $215 = $102;
 $82 = $215;
 $83 = $100;
 $216 = $82;
 $217 = ((($216)) + 4|0);
 $218 = HEAP32[$217>>2]|0;
 $81 = $216;
 $219 = $81;
 $220 = ((($219)) + 8|0);
 $80 = $220;
 $221 = $80;
 $79 = $221;
 $222 = $79;
 $223 = HEAP32[$222>>2]|0;
 $224 = ($218|0)!=($223|0);
 if ($224) {
  $76 = $84;
  $77 = $216;
  $78 = 1;
  $59 = $216;
  $225 = $59;
  $226 = ((($225)) + 8|0);
  $58 = $226;
  $227 = $58;
  $57 = $227;
  $228 = $57;
  $229 = ((($216)) + 4|0);
  $230 = HEAP32[$229>>2]|0;
  $60 = $230;
  $231 = $60;
  $232 = $83;
  $71 = $228;
  $72 = $231;
  $73 = $232;
  $233 = $71;
  $234 = $72;
  $235 = $73;
  $70 = $235;
  $236 = $70;
  ;HEAP8[$69>>0]=HEAP8[$74>>0]|0;
  $66 = $233;
  $67 = $234;
  $68 = $236;
  $237 = $66;
  $238 = $67;
  $239 = $68;
  $65 = $239;
  $240 = $65;
  $62 = $237;
  $63 = $238;
  $64 = $240;
  $241 = $63;
  $242 = $64;
  $61 = $242;
  $243 = $61;
  $244 = HEAP32[$243>>2]|0;
  HEAP32[$241>>2] = $244;
  $75 = $84;
  $245 = ((($216)) + 4|0);
  $246 = HEAP32[$245>>2]|0;
  $247 = ((($246)) + 4|0);
  HEAP32[$245>>2] = $247;
 } else {
  $248 = $83;
  __ZNSt3__26vectorIN4mjin11application6memory5input12MOUSE_BUTTONENS_9allocatorIS5_EEE21__push_back_slow_pathIRKS5_EEvOT_($216,$248);
 }
 HEAP8[$115>>0] = 1;
 $249 = ((($117)) + 56|0);
 __ZN4mjin11application6memory10observable8VariableIbEaSERKb($249,$115);
 STACKTOP = sp;return;
}
function __ZNSt3__26removeINS_11__wrap_iterIPN4mjin11application6memory5input12MOUSE_BUTTONEEES6_EET_S9_S9_RKT0_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(160|0);
 $29 = sp + 40|0;
 $31 = sp + 8|0;
 $32 = sp;
 $33 = sp + 32|0;
 $35 = sp + 24|0;
 $36 = sp + 20|0;
 $37 = sp + 16|0;
 $38 = sp + 12|0;
 $34 = $2;
 ;HEAP32[$36>>2]=HEAP32[$0>>2]|0;
 ;HEAP32[$37>>2]=HEAP32[$1>>2]|0;
 $39 = $34;
 ;HEAP8[$31>>0]=HEAP8[$37>>0]|0;HEAP8[$31+1>>0]=HEAP8[$37+1>>0]|0;HEAP8[$31+2>>0]=HEAP8[$37+2>>0]|0;HEAP8[$31+3>>0]=HEAP8[$37+3>>0]|0;
 ;HEAP8[$32>>0]=HEAP8[$36>>0]|0;HEAP8[$32+1>>0]=HEAP8[$36+1>>0]|0;HEAP8[$32+2>>0]=HEAP8[$36+2>>0]|0;HEAP8[$32+3>>0]=HEAP8[$36+3>>0]|0;
 $30 = $39;
 while(1) {
  $27 = $32;
  $28 = $31;
  $40 = $27;
  $41 = $28;
  $25 = $40;
  $26 = $41;
  $42 = $25;
  $24 = $42;
  $43 = $24;
  $44 = HEAP32[$43>>2]|0;
  $45 = $26;
  $23 = $45;
  $46 = $23;
  $47 = HEAP32[$46>>2]|0;
  $48 = ($44|0)==($47|0);
  $49 = $48 ^ 1;
  if (!($49)) {
   break;
  }
  $21 = $32;
  $50 = $21;
  $51 = HEAP32[$50>>2]|0;
  $52 = HEAP32[$51>>2]|0;
  $53 = $30;
  $54 = HEAP32[$53>>2]|0;
  $55 = ($52|0)==($54|0);
  if ($55) {
   break;
  }
  $22 = $32;
  $56 = $22;
  $57 = HEAP32[$56>>2]|0;
  $58 = ((($57)) + 4|0);
  HEAP32[$56>>2] = $58;
 }
 ;HEAP32[$29>>2]=HEAP32[$32>>2]|0;
 $59 = HEAP32[$29>>2]|0;
 HEAP32[$35>>2] = $59;
 ;HEAP32[$0>>2]=HEAP32[$35>>2]|0;
 $7 = $0;
 $8 = $1;
 $60 = $7;
 $61 = $8;
 $5 = $60;
 $6 = $61;
 $62 = $5;
 $4 = $62;
 $63 = $4;
 $64 = HEAP32[$63>>2]|0;
 $65 = $6;
 $3 = $65;
 $66 = $3;
 $67 = HEAP32[$66>>2]|0;
 $68 = ($64|0)==($67|0);
 $69 = $68 ^ 1;
 if (!($69)) {
  ;HEAP32[$33>>2]=HEAP32[$0>>2]|0;
  $98 = HEAP32[$33>>2]|0;
  STACKTOP = sp;return ($98|0);
 }
 ;HEAP32[$38>>2]=HEAP32[$0>>2]|0;
 while(1) {
  $9 = $38;
  $70 = $9;
  $71 = HEAP32[$70>>2]|0;
  $72 = ((($71)) + 4|0);
  HEAP32[$70>>2] = $72;
  $14 = $70;
  $15 = $1;
  $73 = $14;
  $74 = $15;
  $12 = $73;
  $13 = $74;
  $75 = $12;
  $11 = $75;
  $76 = $11;
  $77 = HEAP32[$76>>2]|0;
  $78 = $13;
  $10 = $78;
  $79 = $10;
  $80 = HEAP32[$79>>2]|0;
  $81 = ($77|0)==($80|0);
  $82 = $81 ^ 1;
  if (!($82)) {
   break;
  }
  $16 = $38;
  $83 = $16;
  $84 = HEAP32[$83>>2]|0;
  $85 = HEAP32[$84>>2]|0;
  $86 = $34;
  $87 = HEAP32[$86>>2]|0;
  $88 = ($85|0)==($87|0);
  if ($88) {
   continue;
  }
  $17 = $38;
  $89 = $17;
  $90 = HEAP32[$89>>2]|0;
  $18 = $90;
  $91 = $18;
  $92 = HEAP32[$91>>2]|0;
  $19 = $0;
  $93 = $19;
  $94 = HEAP32[$93>>2]|0;
  HEAP32[$94>>2] = $92;
  $20 = $0;
  $95 = $20;
  $96 = HEAP32[$95>>2]|0;
  $97 = ((($96)) + 4|0);
  HEAP32[$95>>2] = $97;
 }
 ;HEAP32[$33>>2]=HEAP32[$0>>2]|0;
 $98 = HEAP32[$33>>2]|0;
 STACKTOP = sp;return ($98|0);
}
function __ZNSt3__26vectorIN4mjin11application6memory5input12MOUSE_BUTTONENS_9allocatorIS5_EEE5eraseENS_11__wrap_iterIPKS5_EESC_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0;
 var $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0;
 var $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0;
 var $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0;
 var $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0;
 var $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 336|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(336|0);
 $31 = sp;
 $34 = sp + 328|0;
 $72 = sp + 56|0;
 $77 = sp + 36|0;
 $80 = sp + 24|0;
 $82 = sp + 16|0;
 $85 = sp + 4|0;
 $83 = $0;
 $86 = $83;
 $87 = HEAP32[$86>>2]|0;
 $81 = $86;
 $88 = $81;
 $89 = HEAP32[$88>>2]|0;
 $78 = $88;
 $79 = $89;
 $90 = $79;
 $75 = $77;
 $76 = $90;
 $91 = $75;
 $92 = $76;
 HEAP32[$91>>2] = $92;
 $93 = HEAP32[$77>>2]|0;
 HEAP32[$80>>2] = $93;
 $94 = HEAP32[$80>>2]|0;
 HEAP32[$85>>2] = $94;
 $5 = $1;
 $6 = $85;
 $95 = $5;
 $4 = $95;
 $96 = $4;
 $97 = HEAP32[$96>>2]|0;
 $98 = $6;
 $3 = $98;
 $99 = $3;
 $100 = HEAP32[$99>>2]|0;
 $101 = $97;
 $102 = $100;
 $103 = (($101) - ($102))|0;
 $104 = (($103|0) / 4)&-1;
 $105 = (($87) + ($104<<2)|0);
 $84 = $105;
 $11 = $1;
 $12 = $2;
 $106 = $11;
 $107 = $12;
 $9 = $106;
 $10 = $107;
 $108 = $9;
 $8 = $108;
 $109 = $8;
 $110 = HEAP32[$109>>2]|0;
 $111 = $10;
 $7 = $111;
 $112 = $7;
 $113 = HEAP32[$112>>2]|0;
 $114 = ($110|0)==($113|0);
 $115 = $114 ^ 1;
 if (!($115)) {
  $220 = $84;
  $73 = $86;
  $74 = $220;
  $221 = $74;
  $70 = $72;
  $71 = $221;
  $222 = $70;
  $223 = $71;
  HEAP32[$222>>2] = $223;
  $224 = HEAP32[$72>>2]|0;
  HEAP32[$82>>2] = $224;
  $225 = HEAP32[$82>>2]|0;
  STACKTOP = sp;return ($225|0);
 }
 $116 = $84;
 $15 = $2;
 $16 = $1;
 $117 = $15;
 $14 = $117;
 $118 = $14;
 $119 = HEAP32[$118>>2]|0;
 $120 = $16;
 $13 = $120;
 $121 = $13;
 $122 = HEAP32[$121>>2]|0;
 $123 = $119;
 $124 = $122;
 $125 = (($123) - ($124))|0;
 $126 = (($125|0) / 4)&-1;
 $127 = (($116) + ($126<<2)|0);
 $128 = ((($86)) + 4|0);
 $129 = HEAP32[$128>>2]|0;
 $130 = $84;
 $24 = $127;
 $25 = $129;
 $26 = $130;
 $131 = $24;
 $23 = $131;
 $132 = $23;
 $133 = $25;
 $17 = $133;
 $134 = $17;
 $135 = $26;
 $18 = $135;
 $136 = $18;
 $19 = $132;
 $20 = $134;
 $21 = $136;
 $137 = $20;
 $138 = $19;
 $139 = $137;
 $140 = $138;
 $141 = (($139) - ($140))|0;
 $142 = (($141|0) / 4)&-1;
 $22 = $142;
 $143 = $22;
 $144 = ($143>>>0)>(0);
 if ($144) {
  $145 = $21;
  $146 = $19;
  $147 = $22;
  $148 = $147<<2;
  _memmove(($145|0),($146|0),($148|0))|0;
 }
 $149 = $21;
 $150 = $22;
 $151 = (($149) + ($150<<2)|0);
 $65 = $86;
 $66 = $151;
 $152 = $65;
 $153 = $66;
 $63 = $152;
 $64 = $153;
 $62 = $152;
 $154 = $62;
 $155 = ((($154)) + 4|0);
 $156 = HEAP32[$155>>2]|0;
 $157 = HEAP32[$154>>2]|0;
 $158 = $156;
 $159 = $157;
 $160 = (($158) - ($159))|0;
 $161 = (($160|0) / 4)&-1;
 $67 = $161;
 $162 = $66;
 $39 = $152;
 $40 = $162;
 $163 = $39;
 while(1) {
  $164 = $40;
  $165 = ((($163)) + 4|0);
  $166 = HEAP32[$165>>2]|0;
  $167 = ($164|0)!=($166|0);
  if (!($167)) {
   break;
  }
  $38 = $163;
  $168 = $38;
  $169 = ((($168)) + 8|0);
  $37 = $169;
  $170 = $37;
  $36 = $170;
  $171 = $36;
  $172 = ((($163)) + 4|0);
  $173 = HEAP32[$172>>2]|0;
  $174 = ((($173)) + -4|0);
  HEAP32[$172>>2] = $174;
  $35 = $174;
  $175 = $35;
  $32 = $171;
  $33 = $175;
  $176 = $32;
  $177 = $33;
  ;HEAP8[$31>>0]=HEAP8[$34>>0]|0;
  $29 = $176;
  $30 = $177;
  $178 = $29;
  $179 = $30;
  $27 = $178;
  $28 = $179;
 }
 $180 = $67;
 $60 = $152;
 $61 = $180;
 $181 = $60;
 $59 = $181;
 $182 = $59;
 $183 = HEAP32[$182>>2]|0;
 $58 = $183;
 $184 = $58;
 $42 = $181;
 $185 = $42;
 $186 = HEAP32[$185>>2]|0;
 $41 = $186;
 $187 = $41;
 $47 = $181;
 $188 = $47;
 $46 = $188;
 $189 = $46;
 $45 = $189;
 $190 = $45;
 $191 = ((($190)) + 8|0);
 $44 = $191;
 $192 = $44;
 $43 = $192;
 $193 = $43;
 $194 = HEAP32[$193>>2]|0;
 $195 = HEAP32[$189>>2]|0;
 $196 = $194;
 $197 = $195;
 $198 = (($196) - ($197))|0;
 $199 = (($198|0) / 4)&-1;
 $200 = (($187) + ($199<<2)|0);
 $49 = $181;
 $201 = $49;
 $202 = HEAP32[$201>>2]|0;
 $48 = $202;
 $203 = $48;
 $204 = $61;
 $205 = (($203) + ($204<<2)|0);
 $51 = $181;
 $206 = $51;
 $207 = HEAP32[$206>>2]|0;
 $50 = $207;
 $208 = $50;
 $52 = $181;
 $209 = $52;
 $210 = ((($209)) + 4|0);
 $211 = HEAP32[$210>>2]|0;
 $212 = HEAP32[$209>>2]|0;
 $213 = $211;
 $214 = $212;
 $215 = (($213) - ($214))|0;
 $216 = (($215|0) / 4)&-1;
 $217 = (($208) + ($216<<2)|0);
 $53 = $181;
 $54 = $184;
 $55 = $200;
 $56 = $205;
 $57 = $217;
 $218 = $84;
 $219 = ((($218)) + -4|0);
 $68 = $86;
 $69 = $219;
 $220 = $84;
 $73 = $86;
 $74 = $220;
 $221 = $74;
 $70 = $72;
 $71 = $221;
 $222 = $70;
 $223 = $71;
 HEAP32[$222>>2] = $223;
 $224 = HEAP32[$72>>2]|0;
 HEAP32[$82>>2] = $224;
 $225 = HEAP32[$82>>2]|0;
 STACKTOP = sp;return ($225|0);
}
function __ZNSt3__26vectorIN4mjin11application6memory5input12MOUSE_BUTTONENS_9allocatorIS5_EEE21__push_back_slow_pathIRKS5_EEvOT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0;
 var $136 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 208|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(208|0);
 $10 = sp + 8|0;
 $15 = sp + 201|0;
 $24 = sp;
 $27 = sp + 200|0;
 $35 = sp + 80|0;
 $38 = sp + 68|0;
 $46 = sp + 20|0;
 $43 = $0;
 $44 = $1;
 $49 = $43;
 $42 = $49;
 $50 = $42;
 $51 = ((($50)) + 8|0);
 $41 = $51;
 $52 = $41;
 $40 = $52;
 $53 = $40;
 $45 = $53;
 $39 = $49;
 $54 = $39;
 $55 = ((($54)) + 4|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = HEAP32[$54>>2]|0;
 $58 = $56;
 $59 = $57;
 $60 = (($58) - ($59))|0;
 $61 = (($60|0) / 4)&-1;
 $62 = (($61) + 1)|0;
 $34 = $49;
 HEAP32[$35>>2] = $62;
 $63 = $34;
 $64 = (__ZNKSt3__26vectorIN4mjin11application6memory5input12MOUSE_BUTTONENS_9allocatorIS5_EEE8max_sizeEv($63)|0);
 $36 = $64;
 $65 = HEAP32[$35>>2]|0;
 $66 = $36;
 $67 = ($65>>>0)>($66>>>0);
 if ($67) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($63);
  // unreachable;
 }
 $32 = $63;
 $68 = $32;
 $31 = $68;
 $69 = $31;
 $30 = $69;
 $70 = $30;
 $71 = ((($70)) + 8|0);
 $29 = $71;
 $72 = $29;
 $28 = $72;
 $73 = $28;
 $74 = HEAP32[$73>>2]|0;
 $75 = HEAP32[$69>>2]|0;
 $76 = $74;
 $77 = $75;
 $78 = (($76) - ($77))|0;
 $79 = (($78|0) / 4)&-1;
 $37 = $79;
 $80 = $37;
 $81 = $36;
 $82 = (($81>>>0) / 2)&-1;
 $83 = ($80>>>0)>=($82>>>0);
 if ($83) {
  $84 = $36;
  $33 = $84;
 } else {
  $85 = $37;
  $86 = $85<<1;
  HEAP32[$38>>2] = $86;
  $25 = $38;
  $26 = $35;
  $87 = $25;
  $88 = $26;
  ;HEAP8[$24>>0]=HEAP8[$27>>0]|0;
  $22 = $87;
  $23 = $88;
  $89 = $22;
  $90 = $23;
  $19 = $24;
  $20 = $89;
  $21 = $90;
  $91 = $20;
  $92 = HEAP32[$91>>2]|0;
  $93 = $21;
  $94 = HEAP32[$93>>2]|0;
  $95 = ($92>>>0)<($94>>>0);
  $96 = $23;
  $97 = $22;
  $98 = $95 ? $96 : $97;
  $99 = HEAP32[$98>>2]|0;
  $33 = $99;
 }
 $100 = $33;
 $18 = $49;
 $101 = $18;
 $102 = ((($101)) + 4|0);
 $103 = HEAP32[$102>>2]|0;
 $104 = HEAP32[$101>>2]|0;
 $105 = $103;
 $106 = $104;
 $107 = (($105) - ($106))|0;
 $108 = (($107|0) / 4)&-1;
 $109 = $45;
 __ZNSt3__214__split_bufferIN4mjin11application6memory5input12MOUSE_BUTTONERNS_9allocatorIS5_EEEC2EjjS8_($46,$100,$108,$109);
 $110 = $45;
 $111 = ((($46)) + 8|0);
 $112 = HEAP32[$111>>2]|0;
 $17 = $112;
 $113 = $17;
 $114 = $44;
 $16 = $114;
 $115 = $16;
 $12 = $110;
 $13 = $113;
 $14 = $115;
 $116 = $12;
 $117 = $13;
 $118 = $14;
 $11 = $118;
 $119 = $11;
 ;HEAP8[$10>>0]=HEAP8[$15>>0]|0;
 $7 = $116;
 $8 = $117;
 $9 = $119;
 $120 = $7;
 $121 = $8;
 $122 = $9;
 $6 = $122;
 $123 = $6;
 $3 = $120;
 $4 = $121;
 $5 = $123;
 $124 = $4;
 $125 = $5;
 $2 = $125;
 $126 = $2;
 $127 = HEAP32[$126>>2]|0;
 HEAP32[$124>>2] = $127;
 $128 = ((($46)) + 8|0);
 $129 = HEAP32[$128>>2]|0;
 $130 = ((($129)) + 4|0);
 HEAP32[$128>>2] = $130;
 __THREW__ = 0;
 invoke_vii(4101,($49|0),($46|0));
 $131 = __THREW__; __THREW__ = 0;
 $132 = $131&1;
 if ($132) {
  $133 = ___cxa_find_matching_catch_2()|0;
  $134 = tempRet0;
  $47 = $133;
  $48 = $134;
  __ZNSt3__214__split_bufferIN4mjin11application6memory5input12MOUSE_BUTTONERNS_9allocatorIS5_EEED2Ev($46);
  $135 = $47;
  $136 = $48;
  ___resumeException($135|0);
  // unreachable;
 } else {
  __ZNSt3__214__split_bufferIN4mjin11application6memory5input12MOUSE_BUTTONERNS_9allocatorIS5_EEED2Ev($46);
  STACKTOP = sp;return;
 }
}
function __ZNKSt3__26vectorIN4mjin11application6memory5input12MOUSE_BUTTONENS_9allocatorIS5_EEE8max_sizeEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(80|0);
 $6 = sp + 8|0;
 $9 = sp + 77|0;
 $12 = sp;
 $14 = sp + 76|0;
 $19 = sp + 16|0;
 $20 = sp + 12|0;
 $18 = $0;
 $21 = $18;
 $17 = $21;
 $22 = $17;
 $23 = ((($22)) + 8|0);
 $16 = $23;
 $24 = $16;
 $15 = $24;
 $25 = $15;
 $13 = $25;
 $26 = $13;
 ;HEAP8[$12>>0]=HEAP8[$14>>0]|0;
 $11 = $26;
 $27 = $11;
 $10 = $27;
 HEAP32[$19>>2] = 1073741823;
 HEAP32[$20>>2] = 2147483647;
 $7 = $19;
 $8 = $20;
 $28 = $7;
 $29 = $8;
 ;HEAP8[$6>>0]=HEAP8[$9>>0]|0;
 $4 = $28;
 $5 = $29;
 $30 = $5;
 $31 = $4;
 $1 = $6;
 $2 = $30;
 $3 = $31;
 $32 = $2;
 $33 = HEAP32[$32>>2]|0;
 $34 = $3;
 $35 = HEAP32[$34>>2]|0;
 $36 = ($33>>>0)<($35>>>0);
 $37 = $5;
 $38 = $4;
 $39 = $36 ? $37 : $38;
 $40 = HEAP32[$39>>2]|0;
 STACKTOP = sp;return ($40|0);
}
function __ZNSt3__214__split_bufferIN4mjin11application6memory5input12MOUSE_BUTTONERNS_9allocatorIS5_EEEC2EjjS8_($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(128|0);
 $26 = sp + 36|0;
 $30 = sp + 20|0;
 $32 = $0;
 $33 = $1;
 $34 = $2;
 $35 = $3;
 $36 = $32;
 $37 = ((($36)) + 12|0);
 $38 = $35;
 $29 = $37;
 HEAP32[$30>>2] = 0;
 $31 = $38;
 $39 = $29;
 $28 = $30;
 $40 = $28;
 $41 = HEAP32[$40>>2]|0;
 $42 = $31;
 $22 = $42;
 $43 = $22;
 $25 = $39;
 HEAP32[$26>>2] = $41;
 $27 = $43;
 $44 = $25;
 $24 = $26;
 $45 = $24;
 $46 = HEAP32[$45>>2]|0;
 HEAP32[$44>>2] = $46;
 $47 = ((($44)) + 4|0);
 $48 = $27;
 $23 = $48;
 $49 = $23;
 HEAP32[$47>>2] = $49;
 $50 = $33;
 $51 = ($50|0)!=(0);
 do {
  if ($51) {
   $6 = $36;
   $52 = $6;
   $53 = ((($52)) + 12|0);
   $5 = $53;
   $54 = $5;
   $4 = $54;
   $55 = $4;
   $56 = ((($55)) + 4|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = $33;
   $17 = $57;
   $18 = $58;
   $59 = $17;
   $60 = $18;
   $14 = $59;
   $15 = $60;
   $16 = 0;
   $61 = $14;
   $62 = $15;
   $13 = $61;
   $63 = ($62>>>0)>(1073741823);
   if (!($63)) {
    $74 = $15;
    $75 = $74<<2;
    $12 = $75;
    $76 = $12;
    $77 = (__Znwj($76)|0);
    $78 = $77;
    break;
   }
   $9 = 204840;
   $64 = (___cxa_allocate_exception(8)|0);
   $65 = $9;
   $7 = $64;
   $8 = $65;
   $66 = $7;
   $67 = $8;
   __THREW__ = 0;
   invoke_vii(3366,($66|0),($67|0));
   $68 = __THREW__; __THREW__ = 0;
   $69 = $68&1;
   if ($69) {
    $70 = ___cxa_find_matching_catch_2()|0;
    $71 = tempRet0;
    $10 = $70;
    $11 = $71;
    ___cxa_free_exception(($64|0));
    $72 = $10;
    $73 = $11;
    ___resumeException($72|0);
    // unreachable;
   } else {
    HEAP32[$66>>2] = (99824);
    ___cxa_throw(($64|0),(34608|0),(3230|0));
    // unreachable;
   }
  } else {
   $78 = 0;
  }
 } while(0);
 HEAP32[$36>>2] = $78;
 $79 = HEAP32[$36>>2]|0;
 $80 = $34;
 $81 = (($79) + ($80<<2)|0);
 $82 = ((($36)) + 8|0);
 HEAP32[$82>>2] = $81;
 $83 = ((($36)) + 4|0);
 HEAP32[$83>>2] = $81;
 $84 = HEAP32[$36>>2]|0;
 $85 = $33;
 $86 = (($84) + ($85<<2)|0);
 $21 = $36;
 $87 = $21;
 $88 = ((($87)) + 12|0);
 $20 = $88;
 $89 = $20;
 $19 = $89;
 $90 = $19;
 HEAP32[$90>>2] = $86;
 STACKTOP = sp;return;
}
function __ZNSt3__26vectorIN4mjin11application6memory5input12MOUSE_BUTTONENS_9allocatorIS5_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS5_RS7_EE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0;
 var $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0;
 var $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0;
 var $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0;
 var $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0;
 var $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0;
 var $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0;
 var $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 352|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(352|0);
 $15 = sp + 288|0;
 $21 = sp + 264|0;
 $33 = sp + 216|0;
 $86 = $0;
 $87 = $1;
 $88 = $86;
 $85 = $88;
 $89 = $85;
 $84 = $89;
 $90 = $84;
 $91 = HEAP32[$90>>2]|0;
 $83 = $91;
 $92 = $83;
 $62 = $89;
 $93 = $62;
 $94 = HEAP32[$93>>2]|0;
 $61 = $94;
 $95 = $61;
 $67 = $89;
 $96 = $67;
 $66 = $96;
 $97 = $66;
 $65 = $97;
 $98 = $65;
 $99 = ((($98)) + 8|0);
 $64 = $99;
 $100 = $64;
 $63 = $100;
 $101 = $63;
 $102 = HEAP32[$101>>2]|0;
 $103 = HEAP32[$97>>2]|0;
 $104 = $102;
 $105 = $103;
 $106 = (($104) - ($105))|0;
 $107 = (($106|0) / 4)&-1;
 $108 = (($95) + ($107<<2)|0);
 $69 = $89;
 $109 = $69;
 $110 = HEAP32[$109>>2]|0;
 $68 = $110;
 $111 = $68;
 $70 = $89;
 $112 = $70;
 $113 = ((($112)) + 4|0);
 $114 = HEAP32[$113>>2]|0;
 $115 = HEAP32[$112>>2]|0;
 $116 = $114;
 $117 = $115;
 $118 = (($116) - ($117))|0;
 $119 = (($118|0) / 4)&-1;
 $120 = (($111) + ($119<<2)|0);
 $72 = $89;
 $121 = $72;
 $122 = HEAP32[$121>>2]|0;
 $71 = $122;
 $123 = $71;
 $77 = $89;
 $124 = $77;
 $76 = $124;
 $125 = $76;
 $75 = $125;
 $126 = $75;
 $127 = ((($126)) + 8|0);
 $74 = $127;
 $128 = $74;
 $73 = $128;
 $129 = $73;
 $130 = HEAP32[$129>>2]|0;
 $131 = HEAP32[$125>>2]|0;
 $132 = $130;
 $133 = $131;
 $134 = (($132) - ($133))|0;
 $135 = (($134|0) / 4)&-1;
 $136 = (($123) + ($135<<2)|0);
 $78 = $89;
 $79 = $92;
 $80 = $108;
 $81 = $120;
 $82 = $136;
 $4 = $88;
 $137 = $4;
 $138 = ((($137)) + 8|0);
 $3 = $138;
 $139 = $3;
 $2 = $139;
 $140 = $2;
 $141 = HEAP32[$88>>2]|0;
 $142 = ((($88)) + 4|0);
 $143 = HEAP32[$142>>2]|0;
 $144 = $87;
 $145 = ((($144)) + 4|0);
 $5 = $140;
 $6 = $141;
 $7 = $143;
 $8 = $145;
 $146 = $7;
 $147 = $6;
 $148 = $146;
 $149 = $147;
 $150 = (($148) - ($149))|0;
 $151 = (($150|0) / 4)&-1;
 $9 = $151;
 $152 = $9;
 $153 = $8;
 $154 = HEAP32[$153>>2]|0;
 $155 = (0 - ($152))|0;
 $156 = (($154) + ($155<<2)|0);
 HEAP32[$153>>2] = $156;
 $157 = $9;
 $158 = ($157|0)>(0);
 if ($158) {
  $159 = $8;
  $160 = HEAP32[$159>>2]|0;
  $161 = $6;
  $162 = $9;
  $163 = $162<<2;
  _memcpy(($160|0),($161|0),($163|0))|0;
 }
 $164 = $87;
 $165 = ((($164)) + 4|0);
 $13 = $88;
 $14 = $165;
 $166 = $13;
 $12 = $166;
 $167 = $12;
 $168 = HEAP32[$167>>2]|0;
 HEAP32[$15>>2] = $168;
 $169 = $14;
 $10 = $169;
 $170 = $10;
 $171 = HEAP32[$170>>2]|0;
 $172 = $13;
 HEAP32[$172>>2] = $171;
 $11 = $15;
 $173 = $11;
 $174 = HEAP32[$173>>2]|0;
 $175 = $14;
 HEAP32[$175>>2] = $174;
 $176 = ((($88)) + 4|0);
 $177 = $87;
 $178 = ((($177)) + 8|0);
 $19 = $176;
 $20 = $178;
 $179 = $19;
 $18 = $179;
 $180 = $18;
 $181 = HEAP32[$180>>2]|0;
 HEAP32[$21>>2] = $181;
 $182 = $20;
 $16 = $182;
 $183 = $16;
 $184 = HEAP32[$183>>2]|0;
 $185 = $19;
 HEAP32[$185>>2] = $184;
 $17 = $21;
 $186 = $17;
 $187 = HEAP32[$186>>2]|0;
 $188 = $20;
 HEAP32[$188>>2] = $187;
 $24 = $88;
 $189 = $24;
 $190 = ((($189)) + 8|0);
 $23 = $190;
 $191 = $23;
 $22 = $191;
 $192 = $22;
 $193 = $87;
 $27 = $193;
 $194 = $27;
 $195 = ((($194)) + 12|0);
 $26 = $195;
 $196 = $26;
 $25 = $196;
 $197 = $25;
 $31 = $192;
 $32 = $197;
 $198 = $31;
 $30 = $198;
 $199 = $30;
 $200 = HEAP32[$199>>2]|0;
 HEAP32[$33>>2] = $200;
 $201 = $32;
 $28 = $201;
 $202 = $28;
 $203 = HEAP32[$202>>2]|0;
 $204 = $31;
 HEAP32[$204>>2] = $203;
 $29 = $33;
 $205 = $29;
 $206 = HEAP32[$205>>2]|0;
 $207 = $32;
 HEAP32[$207>>2] = $206;
 $208 = $87;
 $209 = ((($208)) + 4|0);
 $210 = HEAP32[$209>>2]|0;
 $211 = $87;
 HEAP32[$211>>2] = $210;
 $34 = $88;
 $212 = $34;
 $213 = ((($212)) + 4|0);
 $214 = HEAP32[$213>>2]|0;
 $215 = HEAP32[$212>>2]|0;
 $216 = $214;
 $217 = $215;
 $218 = (($216) - ($217))|0;
 $219 = (($218|0) / 4)&-1;
 $58 = $88;
 $59 = $219;
 $220 = $58;
 $57 = $220;
 $221 = $57;
 $222 = HEAP32[$221>>2]|0;
 $56 = $222;
 $223 = $56;
 $36 = $220;
 $224 = $36;
 $225 = HEAP32[$224>>2]|0;
 $35 = $225;
 $226 = $35;
 $41 = $220;
 $227 = $41;
 $40 = $227;
 $228 = $40;
 $39 = $228;
 $229 = $39;
 $230 = ((($229)) + 8|0);
 $38 = $230;
 $231 = $38;
 $37 = $231;
 $232 = $37;
 $233 = HEAP32[$232>>2]|0;
 $234 = HEAP32[$228>>2]|0;
 $235 = $233;
 $236 = $234;
 $237 = (($235) - ($236))|0;
 $238 = (($237|0) / 4)&-1;
 $239 = (($226) + ($238<<2)|0);
 $43 = $220;
 $240 = $43;
 $241 = HEAP32[$240>>2]|0;
 $42 = $241;
 $242 = $42;
 $48 = $220;
 $243 = $48;
 $47 = $243;
 $244 = $47;
 $46 = $244;
 $245 = $46;
 $246 = ((($245)) + 8|0);
 $45 = $246;
 $247 = $45;
 $44 = $247;
 $248 = $44;
 $249 = HEAP32[$248>>2]|0;
 $250 = HEAP32[$244>>2]|0;
 $251 = $249;
 $252 = $250;
 $253 = (($251) - ($252))|0;
 $254 = (($253|0) / 4)&-1;
 $255 = (($242) + ($254<<2)|0);
 $50 = $220;
 $256 = $50;
 $257 = HEAP32[$256>>2]|0;
 $49 = $257;
 $258 = $49;
 $259 = $59;
 $260 = (($258) + ($259<<2)|0);
 $51 = $220;
 $52 = $223;
 $53 = $239;
 $54 = $255;
 $55 = $260;
 $60 = $88;
 STACKTOP = sp;return;
}
function __ZNSt3__214__split_bufferIN4mjin11application6memory5input12MOUSE_BUTTONERNS_9allocatorIS5_EEED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(144|0);
 $19 = sp + 8|0;
 $22 = sp + 133|0;
 $29 = sp;
 $32 = sp + 132|0;
 $34 = $0;
 $35 = $34;
 $33 = $35;
 $36 = $33;
 $37 = ((($36)) + 4|0);
 $38 = HEAP32[$37>>2]|0;
 $30 = $36;
 $31 = $38;
 $39 = $30;
 $40 = $31;
 ;HEAP8[$29>>0]=HEAP8[$32>>0]|0;
 $27 = $39;
 $28 = $40;
 $41 = $27;
 while(1) {
  $42 = $28;
  $43 = ((($41)) + 8|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = ($42|0)!=($44|0);
  if (!($45)) {
   break;
  }
  $26 = $41;
  $46 = $26;
  $47 = ((($46)) + 12|0);
  $25 = $47;
  $48 = $25;
  $24 = $48;
  $49 = $24;
  $50 = ((($49)) + 4|0);
  $51 = HEAP32[$50>>2]|0;
  $52 = ((($41)) + 8|0);
  $53 = HEAP32[$52>>2]|0;
  $54 = ((($53)) + -4|0);
  HEAP32[$52>>2] = $54;
  $23 = $54;
  $55 = $23;
  $20 = $51;
  $21 = $55;
  $56 = $20;
  $57 = $21;
  ;HEAP8[$19>>0]=HEAP8[$22>>0]|0;
  $17 = $56;
  $18 = $57;
  $58 = $17;
  $59 = $18;
  $15 = $58;
  $16 = $59;
 }
 $60 = HEAP32[$35>>2]|0;
 $61 = ($60|0)!=(0|0);
 if (!($61)) {
  STACKTOP = sp;return;
 }
 $14 = $35;
 $62 = $14;
 $63 = ((($62)) + 12|0);
 $13 = $63;
 $64 = $13;
 $12 = $64;
 $65 = $12;
 $66 = ((($65)) + 4|0);
 $67 = HEAP32[$66>>2]|0;
 $68 = HEAP32[$35>>2]|0;
 $4 = $35;
 $69 = $4;
 $3 = $69;
 $70 = $3;
 $71 = ((($70)) + 12|0);
 $2 = $71;
 $72 = $2;
 $1 = $72;
 $73 = $1;
 $74 = HEAP32[$73>>2]|0;
 $75 = HEAP32[$69>>2]|0;
 $76 = $74;
 $77 = $75;
 $78 = (($76) - ($77))|0;
 $79 = (($78|0) / 4)&-1;
 $9 = $67;
 $10 = $68;
 $11 = $79;
 $80 = $9;
 $81 = $10;
 $82 = $11;
 $6 = $80;
 $7 = $81;
 $8 = $82;
 $83 = $7;
 $5 = $83;
 $84 = $5;
 __ZdlPv($84);
 STACKTOP = sp;return;
}
function __ZN4mjin11application6memory10observable8VariableIbE6reportEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0;
 var $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 240|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(240|0);
 $11 = sp + 196|0;
 $14 = sp + 184|0;
 $18 = sp + 168|0;
 $21 = sp + 156|0;
 $33 = sp + 108|0;
 $36 = sp + 96|0;
 $40 = sp + 80|0;
 $43 = sp + 68|0;
 $47 = sp + 52|0;
 $48 = sp + 48|0;
 $49 = sp;
 $53 = sp + 32|0;
 $54 = sp + 28|0;
 $45 = $0;
 $56 = $45;
 $57 = ((($56)) + 4|0);
 $46 = $57;
 $58 = $46;
 $44 = $58;
 $59 = $44;
 $60 = HEAP32[$59>>2]|0;
 $41 = $59;
 $42 = $60;
 $61 = $42;
 $38 = $40;
 $39 = $61;
 $62 = $38;
 $63 = $39;
 HEAP32[$62>>2] = $63;
 $64 = HEAP32[$40>>2]|0;
 HEAP32[$43>>2] = $64;
 $65 = HEAP32[$43>>2]|0;
 HEAP32[$47>>2] = $65;
 $66 = $46;
 $37 = $66;
 $67 = $37;
 $68 = ((($67)) + 4|0);
 $69 = HEAP32[$68>>2]|0;
 $34 = $67;
 $35 = $69;
 $70 = $35;
 $31 = $33;
 $32 = $70;
 $71 = $31;
 $72 = $32;
 HEAP32[$71>>2] = $72;
 $73 = HEAP32[$33>>2]|0;
 HEAP32[$36>>2] = $73;
 $74 = HEAP32[$36>>2]|0;
 HEAP32[$48>>2] = $74;
 while(1) {
  $29 = $47;
  $30 = $48;
  $75 = $29;
  $76 = $30;
  $27 = $75;
  $28 = $76;
  $77 = $27;
  $26 = $77;
  $78 = $26;
  $79 = HEAP32[$78>>2]|0;
  $80 = $28;
  $25 = $80;
  $81 = $25;
  $82 = HEAP32[$81>>2]|0;
  $83 = ($79|0)==($82|0);
  $84 = $83 ^ 1;
  if (!($84)) {
   break;
  }
  $24 = $47;
  $85 = $24;
  $86 = HEAP32[$85>>2]|0;
  __ZN4mjin11application6memory10observable16VariableCallbackIbEC2ERKS4_($49,$86);
  __THREW__ = 0;
  invoke_vii(4102,($49|0),($56|0));
  $87 = __THREW__; __THREW__ = 0;
  $88 = $87&1;
  if ($88) {
   label = 5;
   break;
  }
  __ZN4mjin11application6memory10observable16VariableCallbackIbED2Ev($49);
  $23 = $47;
  $89 = $23;
  $90 = HEAP32[$89>>2]|0;
  $91 = ((($90)) + 24|0);
  HEAP32[$89>>2] = $91;
 }
 if ((label|0) == 5) {
  $92 = ___cxa_find_matching_catch_2()|0;
  $93 = tempRet0;
  $50 = $92;
  $51 = $93;
  __ZN4mjin11application6memory10observable16VariableCallbackIbED2Ev($49);
  $94 = $50;
  $95 = $51;
  ___resumeException($94|0);
  // unreachable;
 }
 $96 = ((($56)) + 16|0);
 $52 = $96;
 $97 = $52;
 $22 = $97;
 $98 = $22;
 $99 = HEAP32[$98>>2]|0;
 $19 = $98;
 $20 = $99;
 $100 = $20;
 $16 = $18;
 $17 = $100;
 $101 = $16;
 $102 = $17;
 HEAP32[$101>>2] = $102;
 $103 = HEAP32[$18>>2]|0;
 HEAP32[$21>>2] = $103;
 $104 = HEAP32[$21>>2]|0;
 HEAP32[$53>>2] = $104;
 $105 = $52;
 $15 = $105;
 $106 = $15;
 $107 = ((($106)) + 4|0);
 $108 = HEAP32[$107>>2]|0;
 $12 = $106;
 $13 = $108;
 $109 = $13;
 $9 = $11;
 $10 = $109;
 $110 = $9;
 $111 = $10;
 HEAP32[$110>>2] = $111;
 $112 = HEAP32[$11>>2]|0;
 HEAP32[$14>>2] = $112;
 $113 = HEAP32[$14>>2]|0;
 HEAP32[$54>>2] = $113;
 while(1) {
  $7 = $53;
  $8 = $54;
  $114 = $7;
  $115 = $8;
  $5 = $114;
  $6 = $115;
  $116 = $5;
  $4 = $116;
  $117 = $4;
  $118 = HEAP32[$117>>2]|0;
  $119 = $6;
  $3 = $119;
  $120 = $3;
  $121 = HEAP32[$120>>2]|0;
  $122 = ($118|0)==($121|0);
  $123 = $122 ^ 1;
  if (!($123)) {
   break;
  }
  $2 = $53;
  $124 = $2;
  $125 = HEAP32[$124>>2]|0;
  $126 = HEAP32[$125>>2]|0;
  $55 = $126;
  $127 = $55;
  __ZN4mjin11application6memory10observable8VariableIbEaSERKb($127,$56);
  $1 = $53;
  $128 = $1;
  $129 = HEAP32[$128>>2]|0;
  $130 = ((($129)) + 4|0);
  HEAP32[$128>>2] = $130;
 }
 STACKTOP = sp;return;
}
function __ZN4mjin11application6memory5input5MouseD2Ev($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = $0;
 $3 = $1;
 $4 = $2;
 $5 = $3;
 $6 = HEAP32[$5>>2]|0;
 HEAP32[$4>>2] = $6;
 $7 = ((($5)) + 60|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$4>>2]|0;
 $10 = ((($9)) + -12|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($4) + ($11)|0);
 HEAP32[$12>>2] = $8;
 $13 = ((($5)) + 64|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP32[$4>>2]|0;
 $16 = ((($15)) + -16|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($4) + ($17)|0);
 HEAP32[$18>>2] = $14;
 $19 = ((($5)) + 68|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ((($4)) + 4|0);
 HEAP32[$21>>2] = $20;
 $22 = ((($4)) + 56|0);
 __ZN4mjin11application6memory10observable8VariableIbED2Ev($22);
 $23 = ((($4)) + 44|0);
 __ZNSt3__26vectorIN4mjin11application6memory5input12MOUSE_BUTTONENS_9allocatorIS5_EEED2Ev($23);
 $24 = ((($4)) + 16|0);
 __ZN4mjin11application6memory10observable8VariableIbED2Ev($24);
 STACKTOP = sp;return;
}
function __ZN3osg8CallbackD2Ev($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = $0;
 $3 = $1;
 $4 = $2;
 $5 = $3;
 $6 = HEAP32[$5>>2]|0;
 HEAP32[$4>>2] = $6;
 $7 = ((($5)) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$4>>2]|0;
 $10 = ((($9)) + -12|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($4) + ($11)|0);
 HEAP32[$12>>2] = $8;
 $13 = ((($4)) + 4|0);
 __ZN3osg7ref_ptrINS_8CallbackEED2Ev($13);
 STACKTOP = sp;return;
}
function __ZN3osg7ref_ptrINS_8CallbackEED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)!=(0|0);
 if (!($4)) {
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 $5 = HEAP32[$2>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($6)) + -12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($5) + ($8)|0);
 __THREW__ = 0;
 (invoke_ii(4050,($9|0))|0);
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if ($11) {
  $12 = ___cxa_find_matching_catch_3(0|0)|0;
  $13 = tempRet0;
  ___clang_call_terminate($12);
  // unreachable;
 } else {
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
}
function __ZN4mjin11application6memory10observable8VariableIbED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 $3 = ((($2)) + 16|0);
 __ZNSt3__26vectorIPN4mjin11application6memory10observable8VariableIbEENS_9allocatorIS7_EEED2Ev($3);
 $4 = ((($2)) + 4|0);
 __ZNSt3__26vectorIN4mjin11application6memory10observable16VariableCallbackIbEENS_9allocatorIS6_EEED2Ev($4);
 STACKTOP = sp;return;
}
function __ZNSt3__26vectorIN4mjin11application6memory5input12MOUSE_BUTTONENS_9allocatorIS5_EEED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 __ZNSt3__213__vector_baseIN4mjin11application6memory5input12MOUSE_BUTTONENS_9allocatorIS5_EEED2Ev($2);
 STACKTOP = sp;return;
}
function __ZNSt3__213__vector_baseIN4mjin11application6memory5input12MOUSE_BUTTONENS_9allocatorIS5_EEED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(128|0);
 $19 = sp;
 $22 = sp + 116|0;
 $30 = $0;
 $31 = $30;
 $32 = HEAP32[$31>>2]|0;
 $33 = ($32|0)!=(0|0);
 if (!($33)) {
  STACKTOP = sp;return;
 }
 $29 = $31;
 $34 = $29;
 $35 = HEAP32[$34>>2]|0;
 $27 = $34;
 $28 = $35;
 $36 = $27;
 while(1) {
  $37 = $28;
  $38 = ((($36)) + 4|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = ($37|0)!=($39|0);
  if (!($40)) {
   break;
  }
  $26 = $36;
  $41 = $26;
  $42 = ((($41)) + 8|0);
  $25 = $42;
  $43 = $25;
  $24 = $43;
  $44 = $24;
  $45 = ((($36)) + 4|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = ((($46)) + -4|0);
  HEAP32[$45>>2] = $47;
  $23 = $47;
  $48 = $23;
  $20 = $44;
  $21 = $48;
  $49 = $20;
  $50 = $21;
  ;HEAP8[$19>>0]=HEAP8[$22>>0]|0;
  $17 = $49;
  $18 = $50;
  $51 = $17;
  $52 = $18;
  $15 = $51;
  $16 = $52;
 }
 $7 = $31;
 $53 = $7;
 $54 = ((($53)) + 8|0);
 $6 = $54;
 $55 = $6;
 $5 = $55;
 $56 = $5;
 $57 = HEAP32[$31>>2]|0;
 $4 = $31;
 $58 = $4;
 $3 = $58;
 $59 = $3;
 $60 = ((($59)) + 8|0);
 $2 = $60;
 $61 = $2;
 $1 = $61;
 $62 = $1;
 $63 = HEAP32[$62>>2]|0;
 $64 = HEAP32[$58>>2]|0;
 $65 = $63;
 $66 = $64;
 $67 = (($65) - ($66))|0;
 $68 = (($67|0) / 4)&-1;
 $12 = $56;
 $13 = $57;
 $14 = $68;
 $69 = $12;
 $70 = $13;
 $71 = $14;
 $9 = $69;
 $10 = $70;
 $11 = $71;
 $72 = $10;
 $8 = $72;
 $73 = $8;
 __ZdlPv($73);
 STACKTOP = sp;return;
}
function __ZNSt3__26vectorIPN4mjin11application6memory10observable8VariableIbEENS_9allocatorIS7_EEED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 __ZNSt3__213__vector_baseIPN4mjin11application6memory10observable8VariableIbEENS_9allocatorIS7_EEED2Ev($2);
 STACKTOP = sp;return;
}
function __ZNSt3__26vectorIN4mjin11application6memory10observable16VariableCallbackIbEENS_9allocatorIS6_EEED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 __ZNSt3__213__vector_baseIN4mjin11application6memory10observable16VariableCallbackIbEENS_9allocatorIS6_EEED2Ev($2);
 STACKTOP = sp;return;
}
function __ZNSt3__213__vector_baseIN4mjin11application6memory10observable16VariableCallbackIbEENS_9allocatorIS6_EEED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(128|0);
 $19 = sp;
 $22 = sp + 116|0;
 $30 = $0;
 $31 = $30;
 $32 = HEAP32[$31>>2]|0;
 $33 = ($32|0)!=(0|0);
 if (!($33)) {
  STACKTOP = sp;return;
 }
 $29 = $31;
 $34 = $29;
 $35 = HEAP32[$34>>2]|0;
 $27 = $34;
 $28 = $35;
 $36 = $27;
 while(1) {
  $37 = $28;
  $38 = ((($36)) + 4|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = ($37|0)!=($39|0);
  if (!($40)) {
   break;
  }
  $26 = $36;
  $41 = $26;
  $42 = ((($41)) + 8|0);
  $25 = $42;
  $43 = $25;
  $24 = $43;
  $44 = $24;
  $45 = ((($36)) + 4|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = ((($46)) + -24|0);
  HEAP32[$45>>2] = $47;
  $23 = $47;
  $48 = $23;
  $20 = $44;
  $21 = $48;
  $49 = $20;
  $50 = $21;
  ;HEAP8[$19>>0]=HEAP8[$22>>0]|0;
  $17 = $49;
  $18 = $50;
  $51 = $17;
  $52 = $18;
  $15 = $51;
  $16 = $52;
  $53 = $16;
  __ZN4mjin11application6memory10observable16VariableCallbackIbED2Ev($53);
 }
 $14 = $31;
 $54 = $14;
 $55 = ((($54)) + 8|0);
 $13 = $55;
 $56 = $13;
 $12 = $56;
 $57 = $12;
 $58 = HEAP32[$31>>2]|0;
 $4 = $31;
 $59 = $4;
 $3 = $59;
 $60 = $3;
 $61 = ((($60)) + 8|0);
 $2 = $61;
 $62 = $2;
 $1 = $62;
 $63 = $1;
 $64 = HEAP32[$63>>2]|0;
 $65 = HEAP32[$59>>2]|0;
 $66 = $64;
 $67 = $65;
 $68 = (($66) - ($67))|0;
 $69 = (($68|0) / 24)&-1;
 $9 = $57;
 $10 = $58;
 $11 = $69;
 $70 = $9;
 $71 = $10;
 $72 = $11;
 $6 = $70;
 $7 = $71;
 $8 = $72;
 $73 = $7;
 $5 = $73;
 $74 = $5;
 __ZdlPv($74);
 STACKTOP = sp;return;
}
function __ZNSt3__213__vector_baseIPN4mjin11application6memory10observable8VariableIbEENS_9allocatorIS7_EEED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(128|0);
 $19 = sp;
 $22 = sp + 116|0;
 $30 = $0;
 $31 = $30;
 $32 = HEAP32[$31>>2]|0;
 $33 = ($32|0)!=(0|0);
 if (!($33)) {
  STACKTOP = sp;return;
 }
 $29 = $31;
 $34 = $29;
 $35 = HEAP32[$34>>2]|0;
 $27 = $34;
 $28 = $35;
 $36 = $27;
 while(1) {
  $37 = $28;
  $38 = ((($36)) + 4|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = ($37|0)!=($39|0);
  if (!($40)) {
   break;
  }
  $26 = $36;
  $41 = $26;
  $42 = ((($41)) + 8|0);
  $25 = $42;
  $43 = $25;
  $24 = $43;
  $44 = $24;
  $45 = ((($36)) + 4|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = ((($46)) + -4|0);
  HEAP32[$45>>2] = $47;
  $23 = $47;
  $48 = $23;
  $20 = $44;
  $21 = $48;
  $49 = $20;
  $50 = $21;
  ;HEAP8[$19>>0]=HEAP8[$22>>0]|0;
  $17 = $49;
  $18 = $50;
  $51 = $17;
  $52 = $18;
  $15 = $51;
  $16 = $52;
 }
 $7 = $31;
 $53 = $7;
 $54 = ((($53)) + 8|0);
 $6 = $54;
 $55 = $6;
 $5 = $55;
 $56 = $5;
 $57 = HEAP32[$31>>2]|0;
 $4 = $31;
 $58 = $4;
 $3 = $58;
 $59 = $3;
 $60 = ((($59)) + 8|0);
 $2 = $60;
 $61 = $2;
 $1 = $61;
 $62 = $1;
 $63 = HEAP32[$62>>2]|0;
 $64 = HEAP32[$58>>2]|0;
 $65 = $63;
 $66 = $64;
 $67 = (($65) - ($66))|0;
 $68 = (($67|0) / 4)&-1;
 $12 = $56;
 $13 = $57;
 $14 = $68;
 $69 = $12;
 $70 = $13;
 $71 = $14;
 $9 = $69;
 $10 = $70;
 $11 = $71;
 $72 = $10;
 $8 = $72;
 $73 = $8;
 __ZdlPv($73);
 STACKTOP = sp;return;
}
function __GLOBAL__sub_I_Mouse_cpp() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 ___cxx_global_var_init_4378();
 ___cxx_global_var_init_1_4379();
 ___cxx_global_var_init_2_4380();
 return;
}
function ___cxx_global_var_init_4378() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg5Vec3fC2Efff(209176,1.0,0.0,0.0);
 return;
}
function ___cxx_global_var_init_1_4379() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg5Vec3fC2Efff(209164,0.0,1.0,0.0);
 return;
}
function ___cxx_global_var_init_2_4380() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg5Vec3fC2Efff(209152,0.0,0.0,1.0);
 return;
}
function __ZN5osgGA15GUIEventHandlerC2Ev($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = $0;
 $3 = $1;
 $4 = $2;
 $5 = $3;
 $6 = ((($5)) + 4|0);
 __ZN5osgGA12EventHandlerC2Ev($4,$6);
 $7 = HEAP32[$5>>2]|0;
 HEAP32[$4>>2] = $7;
 $8 = ((($5)) + 44|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$4>>2]|0;
 $11 = ((($10)) + -12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($4) + ($12)|0);
 HEAP32[$13>>2] = $9;
 $14 = ((($5)) + 48|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP32[$4>>2]|0;
 $17 = ((($16)) + -16|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($4) + ($18)|0);
 HEAP32[$19>>2] = $15;
 $20 = ((($5)) + 52|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ((($4)) + 4|0);
 HEAP32[$22>>2] = $21;
 STACKTOP = sp;return;
}
function __ZN4mjin11application6memory10observable8VariableIbEC2Eb($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(96|0);
 $5 = sp + 68|0;
 $8 = sp + 56|0;
 $15 = sp + 28|0;
 $18 = sp + 16|0;
 $22 = $0;
 $24 = $1&1;
 $23 = $24;
 $25 = $22;
 $26 = $23;
 $27 = $26&1;
 $28 = $27&1;
 HEAP8[$25>>0] = $28;
 $29 = ((($25)) + 4|0);
 $21 = $29;
 $30 = $21;
 $20 = $30;
 $31 = $20;
 $19 = $31;
 HEAP32[$31>>2] = 0;
 $32 = ((($31)) + 4|0);
 HEAP32[$32>>2] = 0;
 $33 = ((($31)) + 8|0);
 $17 = $33;
 HEAP32[$18>>2] = 0;
 $34 = $17;
 $16 = $18;
 $35 = $16;
 $36 = HEAP32[$35>>2]|0;
 $14 = $34;
 HEAP32[$15>>2] = $36;
 $37 = $14;
 $13 = $37;
 $12 = $15;
 $38 = $12;
 $39 = HEAP32[$38>>2]|0;
 HEAP32[$37>>2] = $39;
 $40 = ((($25)) + 16|0);
 $11 = $40;
 $41 = $11;
 $10 = $41;
 $42 = $10;
 $9 = $42;
 HEAP32[$42>>2] = 0;
 $43 = ((($42)) + 4|0);
 HEAP32[$43>>2] = 0;
 $44 = ((($42)) + 8|0);
 $7 = $44;
 HEAP32[$8>>2] = 0;
 $45 = $7;
 $6 = $8;
 $46 = $6;
 $47 = HEAP32[$46>>2]|0;
 $4 = $45;
 HEAP32[$5>>2] = $47;
 $48 = $4;
 $3 = $48;
 $2 = $5;
 $49 = $2;
 $50 = HEAP32[$49>>2]|0;
 HEAP32[$48>>2] = $50;
 STACKTOP = sp;return;
}
function __ZN5osgGA12EventHandlerC2Ev($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = $0;
 $3 = $1;
 $6 = $2;
 $7 = $3;
 $8 = ((($7)) + 4|0);
 __ZN3osg12NodeCallbackC2Ev($6,$8);
 $9 = ((($6)) + 4|0);
 $10 = ((($7)) + 16|0);
 __THREW__ = 0;
 invoke_vii(4103,($9|0),($10|0));
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if ($12) {
  $29 = ___cxa_find_matching_catch_2()|0;
  $30 = tempRet0;
  $4 = $29;
  $5 = $30;
  $31 = ((($7)) + 4|0);
  __ZN3osg12NodeCallbackD2Ev($6,$31);
  $32 = $4;
  $33 = $5;
  ___resumeException($32|0);
  // unreachable;
 } else {
  $13 = HEAP32[$7>>2]|0;
  HEAP32[$6>>2] = $13;
  $14 = ((($7)) + 28|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = HEAP32[$6>>2]|0;
  $17 = ((($16)) + -12|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (($6) + ($18)|0);
  HEAP32[$19>>2] = $15;
  $20 = ((($7)) + 32|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = HEAP32[$6>>2]|0;
  $23 = ((($22)) + -16|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = (($6) + ($24)|0);
  HEAP32[$25>>2] = $21;
  $26 = ((($7)) + 36|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = ((($6)) + 4|0);
  HEAP32[$28>>2] = $27;
  STACKTOP = sp;return;
 }
}
function __ZN3osg12NodeCallbackC2Ev($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = $0;
 $3 = $1;
 $4 = $2;
 $5 = $3;
 $6 = HEAP32[$5>>2]|0;
 HEAP32[$4>>2] = $6;
 $7 = ((($5)) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$4>>2]|0;
 $10 = ((($9)) + -12|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($4) + ($11)|0);
 HEAP32[$12>>2] = $8;
 $13 = ((($5)) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP32[$4>>2]|0;
 $16 = ((($15)) + -16|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($4) + ($17)|0);
 HEAP32[$18>>2] = $14;
 STACKTOP = sp;return;
}
function __ZN3osg21DrawableEventCallbackC2Ev($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = $0;
 $3 = $1;
 $4 = $2;
 $5 = $3;
 $6 = HEAP32[$5>>2]|0;
 HEAP32[$4>>2] = $6;
 $7 = ((($5)) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$4>>2]|0;
 $10 = ((($9)) + -12|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($4) + ($11)|0);
 HEAP32[$12>>2] = $8;
 $13 = ((($5)) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP32[$4>>2]|0;
 $16 = ((($15)) + -16|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($4) + ($17)|0);
 HEAP32[$18>>2] = $14;
 STACKTOP = sp;return;
}
function __ZN3osg12NodeCallbackD2Ev($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = $0;
 $3 = $1;
 STACKTOP = sp;return;
}
function __ZN4mjin11application6memory5input5MouseC1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(64|0);
 $4 = sp + 36|0;
 $7 = sp + 24|0;
 $11 = $0;
 $14 = $11;
 $15 = ((($14)) + 92|0);
 __ZN3osg6ObjectC2Ev($15);
 $16 = ((($14)) + 84|0);
 __THREW__ = 0;
 $17 = 72472;
 invoke_vii(4104,($16|0),($17|0));
 $18 = __THREW__; __THREW__ = 0;
 $19 = $18&1;
 if ($19) {
  $46 = ___cxa_find_matching_catch_2()|0;
  $47 = tempRet0;
  $12 = $46;
  $13 = $47;
  $56 = ((($14)) + 92|0);
  __ZN3osg6ObjectD2Ev($56);
  $57 = $12;
  $58 = $13;
  ___resumeException($57|0);
  // unreachable;
 }
 __THREW__ = 0;
 $20 = 72404;
 invoke_vii(4105,($14|0),($20|0));
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if ($22) {
  $48 = ___cxa_find_matching_catch_2()|0;
  $49 = tempRet0;
  $12 = $48;
  $13 = $49;
 } else {
  HEAP32[$14>>2] = (71760);
  $23 = ((($14)) + 84|0);
  HEAP32[$23>>2] = (72012);
  $24 = ((($14)) + 92|0);
  HEAP32[$24>>2] = (72260);
  $25 = ((($14)) + 4|0);
  HEAP32[$25>>2] = (71856);
  $26 = ((($14)) + 8|0);
  __THREW__ = 0;
  invoke_vidd(4106,($26|0),0.0,0.0);
  $27 = __THREW__; __THREW__ = 0;
  $28 = $27&1;
  do {
   if ($28) {
    label = 9;
   } else {
    $29 = ((($14)) + 16|0);
    __THREW__ = 0;
    invoke_vii(4107,($29|0),0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     label = 9;
    } else {
     $32 = ((($14)) + 44|0);
     $10 = $32;
     $33 = $10;
     $9 = $33;
     $34 = $9;
     $8 = $34;
     HEAP32[$34>>2] = 0;
     $35 = ((($34)) + 4|0);
     HEAP32[$35>>2] = 0;
     $36 = ((($34)) + 8|0);
     $6 = $36;
     HEAP32[$7>>2] = 0;
     $37 = $6;
     $5 = $7;
     $38 = $5;
     $39 = HEAP32[$38>>2]|0;
     $3 = $37;
     HEAP32[$4>>2] = $39;
     $40 = $3;
     $2 = $40;
     $1 = $4;
     $41 = $1;
     $42 = HEAP32[$41>>2]|0;
     HEAP32[$40>>2] = $42;
     $43 = ((($14)) + 56|0);
     __THREW__ = 0;
     invoke_vii(4107,($43|0),0);
     $44 = __THREW__; __THREW__ = 0;
     $45 = $44&1;
     if ($45) {
      $52 = ___cxa_find_matching_catch_2()|0;
      $53 = tempRet0;
      $12 = $52;
      $13 = $53;
      __ZNSt3__26vectorIN4mjin11application6memory5input12MOUSE_BUTTONENS_9allocatorIS5_EEED2Ev($32);
      __ZN4mjin11application6memory10observable8VariableIbED2Ev($29);
      break;
     } else {
      STACKTOP = sp;return;
     }
    }
   }
  } while(0);
  if ((label|0) == 9) {
   $50 = ___cxa_find_matching_catch_2()|0;
   $51 = tempRet0;
   $12 = $50;
   $13 = $51;
  }
 }
 $54 = ((($14)) + 84|0);
 $55 = 72472;
 __ZN3osg8CallbackD2Ev($54,$55);
 $56 = ((($14)) + 92|0);
 __ZN3osg6ObjectD2Ev($56);
 $57 = $12;
 $58 = $13;
 ___resumeException($57|0);
 // unreachable;
}
function __ZN3osg8CallbackC2Ev($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = $0;
 $3 = $1;
 $4 = $2;
 $5 = $3;
 $6 = HEAP32[$5>>2]|0;
 HEAP32[$4>>2] = $6;
 $7 = ((($5)) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$4>>2]|0;
 $10 = ((($9)) + -12|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($4) + ($11)|0);
 HEAP32[$12>>2] = $8;
 $13 = ((($4)) + 4|0);
 __ZN3osg7ref_ptrINS_8CallbackEEC2Ev($13);
 STACKTOP = sp;return;
}
function __ZN3osg7ref_ptrINS_8CallbackEEC2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNKSt3__26vectorIN4mjin11application6memory4ItemENS_9allocatorIS4_EEE8max_sizeEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(80|0);
 $6 = sp + 8|0;
 $9 = sp + 77|0;
 $12 = sp;
 $14 = sp + 76|0;
 $19 = sp + 16|0;
 $20 = sp + 12|0;
 $18 = $0;
 $21 = $18;
 $17 = $21;
 $22 = $17;
 $23 = ((($22)) + 8|0);
 $16 = $23;
 $24 = $16;
 $15 = $24;
 $25 = $15;
 $13 = $25;
 $26 = $13;
 ;HEAP8[$12>>0]=HEAP8[$14>>0]|0;
 $11 = $26;
 $27 = $11;
 $10 = $27;
 HEAP32[$19>>2] = 357913941;
 HEAP32[$20>>2] = 2147483647;
 $7 = $19;
 $8 = $20;
 $28 = $7;
 $29 = $8;
 ;HEAP8[$6>>0]=HEAP8[$9>>0]|0;
 $4 = $28;
 $5 = $29;
 $30 = $5;
 $31 = $4;
 $1 = $6;
 $2 = $30;
 $3 = $31;
 $32 = $2;
 $33 = HEAP32[$32>>2]|0;
 $34 = $3;
 $35 = HEAP32[$34>>2]|0;
 $36 = ($33>>>0)<($35>>>0);
 $37 = $5;
 $38 = $4;
 $39 = $36 ? $37 : $38;
 $40 = HEAP32[$39>>2]|0;
 STACKTOP = sp;return ($40|0);
}
function __ZNSt3__214__split_bufferIN4mjin11application6memory4ItemERNS_9allocatorIS4_EEEC2EjjS7_($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(128|0);
 $26 = sp + 36|0;
 $30 = sp + 20|0;
 $32 = $0;
 $33 = $1;
 $34 = $2;
 $35 = $3;
 $36 = $32;
 $37 = ((($36)) + 12|0);
 $38 = $35;
 $29 = $37;
 HEAP32[$30>>2] = 0;
 $31 = $38;
 $39 = $29;
 $28 = $30;
 $40 = $28;
 $41 = HEAP32[$40>>2]|0;
 $42 = $31;
 $22 = $42;
 $43 = $22;
 $25 = $39;
 HEAP32[$26>>2] = $41;
 $27 = $43;
 $44 = $25;
 $24 = $26;
 $45 = $24;
 $46 = HEAP32[$45>>2]|0;
 HEAP32[$44>>2] = $46;
 $47 = ((($44)) + 4|0);
 $48 = $27;
 $23 = $48;
 $49 = $23;
 HEAP32[$47>>2] = $49;
 $50 = $33;
 $51 = ($50|0)!=(0);
 do {
  if ($51) {
   $6 = $36;
   $52 = $6;
   $53 = ((($52)) + 12|0);
   $5 = $53;
   $54 = $5;
   $4 = $54;
   $55 = $4;
   $56 = ((($55)) + 4|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = $33;
   $17 = $57;
   $18 = $58;
   $59 = $17;
   $60 = $18;
   $14 = $59;
   $15 = $60;
   $16 = 0;
   $61 = $14;
   $62 = $15;
   $13 = $61;
   $63 = ($62>>>0)>(357913941);
   if (!($63)) {
    $74 = $15;
    $75 = ($74*12)|0;
    $12 = $75;
    $76 = $12;
    $77 = (__Znwj($76)|0);
    $78 = $77;
    break;
   }
   $9 = 204840;
   $64 = (___cxa_allocate_exception(8)|0);
   $65 = $9;
   $7 = $64;
   $8 = $65;
   $66 = $7;
   $67 = $8;
   __THREW__ = 0;
   invoke_vii(3366,($66|0),($67|0));
   $68 = __THREW__; __THREW__ = 0;
   $69 = $68&1;
   if ($69) {
    $70 = ___cxa_find_matching_catch_2()|0;
    $71 = tempRet0;
    $10 = $70;
    $11 = $71;
    ___cxa_free_exception(($64|0));
    $72 = $10;
    $73 = $11;
    ___resumeException($72|0);
    // unreachable;
   } else {
    HEAP32[$66>>2] = (99824);
    ___cxa_throw(($64|0),(34608|0),(3230|0));
    // unreachable;
   }
  } else {
   $78 = 0;
  }
 } while(0);
 HEAP32[$36>>2] = $78;
 $79 = HEAP32[$36>>2]|0;
 $80 = $34;
 $81 = (($79) + (($80*12)|0)|0);
 $82 = ((($36)) + 8|0);
 HEAP32[$82>>2] = $81;
 $83 = ((($36)) + 4|0);
 HEAP32[$83>>2] = $81;
 $84 = HEAP32[$36>>2]|0;
 $85 = $33;
 $86 = (($84) + (($85*12)|0)|0);
 $21 = $36;
 $87 = $21;
 $88 = ((($87)) + 12|0);
 $20 = $88;
 $89 = $20;
 $19 = $89;
 $90 = $19;
 HEAP32[$90>>2] = $86;
 STACKTOP = sp;return;
}
function __ZNSt3__26vectorIN4mjin11application6memory4ItemENS_9allocatorIS4_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS4_RS6_EE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0;
 var $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0;
 var $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0;
 var $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0;
 var $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0;
 var $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0;
 var $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0;
 var $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 352|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(352|0);
 $15 = sp + 288|0;
 $21 = sp + 264|0;
 $33 = sp + 216|0;
 $86 = $0;
 $87 = $1;
 $88 = $86;
 $85 = $88;
 $89 = $85;
 $84 = $89;
 $90 = $84;
 $91 = HEAP32[$90>>2]|0;
 $83 = $91;
 $92 = $83;
 $62 = $89;
 $93 = $62;
 $94 = HEAP32[$93>>2]|0;
 $61 = $94;
 $95 = $61;
 $67 = $89;
 $96 = $67;
 $66 = $96;
 $97 = $66;
 $65 = $97;
 $98 = $65;
 $99 = ((($98)) + 8|0);
 $64 = $99;
 $100 = $64;
 $63 = $100;
 $101 = $63;
 $102 = HEAP32[$101>>2]|0;
 $103 = HEAP32[$97>>2]|0;
 $104 = $102;
 $105 = $103;
 $106 = (($104) - ($105))|0;
 $107 = (($106|0) / 12)&-1;
 $108 = (($95) + (($107*12)|0)|0);
 $69 = $89;
 $109 = $69;
 $110 = HEAP32[$109>>2]|0;
 $68 = $110;
 $111 = $68;
 $70 = $89;
 $112 = $70;
 $113 = ((($112)) + 4|0);
 $114 = HEAP32[$113>>2]|0;
 $115 = HEAP32[$112>>2]|0;
 $116 = $114;
 $117 = $115;
 $118 = (($116) - ($117))|0;
 $119 = (($118|0) / 12)&-1;
 $120 = (($111) + (($119*12)|0)|0);
 $72 = $89;
 $121 = $72;
 $122 = HEAP32[$121>>2]|0;
 $71 = $122;
 $123 = $71;
 $77 = $89;
 $124 = $77;
 $76 = $124;
 $125 = $76;
 $75 = $125;
 $126 = $75;
 $127 = ((($126)) + 8|0);
 $74 = $127;
 $128 = $74;
 $73 = $128;
 $129 = $73;
 $130 = HEAP32[$129>>2]|0;
 $131 = HEAP32[$125>>2]|0;
 $132 = $130;
 $133 = $131;
 $134 = (($132) - ($133))|0;
 $135 = (($134|0) / 12)&-1;
 $136 = (($123) + (($135*12)|0)|0);
 $78 = $89;
 $79 = $92;
 $80 = $108;
 $81 = $120;
 $82 = $136;
 $4 = $88;
 $137 = $4;
 $138 = ((($137)) + 8|0);
 $3 = $138;
 $139 = $3;
 $2 = $139;
 $140 = $2;
 $141 = HEAP32[$88>>2]|0;
 $142 = ((($88)) + 4|0);
 $143 = HEAP32[$142>>2]|0;
 $144 = $87;
 $145 = ((($144)) + 4|0);
 $5 = $140;
 $6 = $141;
 $7 = $143;
 $8 = $145;
 $146 = $7;
 $147 = $6;
 $148 = $146;
 $149 = $147;
 $150 = (($148) - ($149))|0;
 $151 = (($150|0) / 12)&-1;
 $9 = $151;
 $152 = $9;
 $153 = $8;
 $154 = HEAP32[$153>>2]|0;
 $155 = (0 - ($152))|0;
 $156 = (($154) + (($155*12)|0)|0);
 HEAP32[$153>>2] = $156;
 $157 = $9;
 $158 = ($157|0)>(0);
 if ($158) {
  $159 = $8;
  $160 = HEAP32[$159>>2]|0;
  $161 = $6;
  $162 = $9;
  $163 = ($162*12)|0;
  _memcpy(($160|0),($161|0),($163|0))|0;
 }
 $164 = $87;
 $165 = ((($164)) + 4|0);
 $13 = $88;
 $14 = $165;
 $166 = $13;
 $12 = $166;
 $167 = $12;
 $168 = HEAP32[$167>>2]|0;
 HEAP32[$15>>2] = $168;
 $169 = $14;
 $10 = $169;
 $170 = $10;
 $171 = HEAP32[$170>>2]|0;
 $172 = $13;
 HEAP32[$172>>2] = $171;
 $11 = $15;
 $173 = $11;
 $174 = HEAP32[$173>>2]|0;
 $175 = $14;
 HEAP32[$175>>2] = $174;
 $176 = ((($88)) + 4|0);
 $177 = $87;
 $178 = ((($177)) + 8|0);
 $19 = $176;
 $20 = $178;
 $179 = $19;
 $18 = $179;
 $180 = $18;
 $181 = HEAP32[$180>>2]|0;
 HEAP32[$21>>2] = $181;
 $182 = $20;
 $16 = $182;
 $183 = $16;
 $184 = HEAP32[$183>>2]|0;
 $185 = $19;
 HEAP32[$185>>2] = $184;
 $17 = $21;
 $186 = $17;
 $187 = HEAP32[$186>>2]|0;
 $188 = $20;
 HEAP32[$188>>2] = $187;
 $24 = $88;
 $189 = $24;
 $190 = ((($189)) + 8|0);
 $23 = $190;
 $191 = $23;
 $22 = $191;
 $192 = $22;
 $193 = $87;
 $27 = $193;
 $194 = $27;
 $195 = ((($194)) + 12|0);
 $26 = $195;
 $196 = $26;
 $25 = $196;
 $197 = $25;
 $31 = $192;
 $32 = $197;
 $198 = $31;
 $30 = $198;
 $199 = $30;
 $200 = HEAP32[$199>>2]|0;
 HEAP32[$33>>2] = $200;
 $201 = $32;
 $28 = $201;
 $202 = $28;
 $203 = HEAP32[$202>>2]|0;
 $204 = $31;
 HEAP32[$204>>2] = $203;
 $29 = $33;
 $205 = $29;
 $206 = HEAP32[$205>>2]|0;
 $207 = $32;
 HEAP32[$207>>2] = $206;
 $208 = $87;
 $209 = ((($208)) + 4|0);
 $210 = HEAP32[$209>>2]|0;
 $211 = $87;
 HEAP32[$211>>2] = $210;
 $34 = $88;
 $212 = $34;
 $213 = ((($212)) + 4|0);
 $214 = HEAP32[$213>>2]|0;
 $215 = HEAP32[$212>>2]|0;
 $216 = $214;
 $217 = $215;
 $218 = (($216) - ($217))|0;
 $219 = (($218|0) / 12)&-1;
 $58 = $88;
 $59 = $219;
 $220 = $58;
 $57 = $220;
 $221 = $57;
 $222 = HEAP32[$221>>2]|0;
 $56 = $222;
 $223 = $56;
 $36 = $220;
 $224 = $36;
 $225 = HEAP32[$224>>2]|0;
 $35 = $225;
 $226 = $35;
 $41 = $220;
 $227 = $41;
 $40 = $227;
 $228 = $40;
 $39 = $228;
 $229 = $39;
 $230 = ((($229)) + 8|0);
 $38 = $230;
 $231 = $38;
 $37 = $231;
 $232 = $37;
 $233 = HEAP32[$232>>2]|0;
 $234 = HEAP32[$228>>2]|0;
 $235 = $233;
 $236 = $234;
 $237 = (($235) - ($236))|0;
 $238 = (($237|0) / 12)&-1;
 $239 = (($226) + (($238*12)|0)|0);
 $43 = $220;
 $240 = $43;
 $241 = HEAP32[$240>>2]|0;
 $42 = $241;
 $242 = $42;
 $48 = $220;
 $243 = $48;
 $47 = $243;
 $244 = $47;
 $46 = $244;
 $245 = $46;
 $246 = ((($245)) + 8|0);
 $45 = $246;
 $247 = $45;
 $44 = $247;
 $248 = $44;
 $249 = HEAP32[$248>>2]|0;
 $250 = HEAP32[$244>>2]|0;
 $251 = $249;
 $252 = $250;
 $253 = (($251) - ($252))|0;
 $254 = (($253|0) / 12)&-1;
 $255 = (($242) + (($254*12)|0)|0);
 $50 = $220;
 $256 = $50;
 $257 = HEAP32[$256>>2]|0;
 $49 = $257;
 $258 = $49;
 $259 = $59;
 $260 = (($258) + (($259*12)|0)|0);
 $51 = $220;
 $52 = $223;
 $53 = $239;
 $54 = $255;
 $55 = $260;
 $60 = $88;
 STACKTOP = sp;return;
}
function __ZNSt3__214__split_bufferIN4mjin11application6memory4ItemERNS_9allocatorIS4_EEED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(144|0);
 $19 = sp + 8|0;
 $22 = sp + 133|0;
 $29 = sp;
 $32 = sp + 132|0;
 $34 = $0;
 $35 = $34;
 $33 = $35;
 $36 = $33;
 $37 = ((($36)) + 4|0);
 $38 = HEAP32[$37>>2]|0;
 $30 = $36;
 $31 = $38;
 $39 = $30;
 $40 = $31;
 ;HEAP8[$29>>0]=HEAP8[$32>>0]|0;
 $27 = $39;
 $28 = $40;
 $41 = $27;
 while(1) {
  $42 = $28;
  $43 = ((($41)) + 8|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = ($42|0)!=($44|0);
  if (!($45)) {
   break;
  }
  $26 = $41;
  $46 = $26;
  $47 = ((($46)) + 12|0);
  $25 = $47;
  $48 = $25;
  $24 = $48;
  $49 = $24;
  $50 = ((($49)) + 4|0);
  $51 = HEAP32[$50>>2]|0;
  $52 = ((($41)) + 8|0);
  $53 = HEAP32[$52>>2]|0;
  $54 = ((($53)) + -12|0);
  HEAP32[$52>>2] = $54;
  $23 = $54;
  $55 = $23;
  $20 = $51;
  $21 = $55;
  $56 = $20;
  $57 = $21;
  ;HEAP8[$19>>0]=HEAP8[$22>>0]|0;
  $17 = $56;
  $18 = $57;
  $58 = $17;
  $59 = $18;
  $15 = $58;
  $16 = $59;
 }
 $60 = HEAP32[$35>>2]|0;
 $61 = ($60|0)!=(0|0);
 if (!($61)) {
  STACKTOP = sp;return;
 }
 $14 = $35;
 $62 = $14;
 $63 = ((($62)) + 12|0);
 $13 = $63;
 $64 = $13;
 $12 = $64;
 $65 = $12;
 $66 = ((($65)) + 4|0);
 $67 = HEAP32[$66>>2]|0;
 $68 = HEAP32[$35>>2]|0;
 $4 = $35;
 $69 = $4;
 $3 = $69;
 $70 = $3;
 $71 = ((($70)) + 12|0);
 $2 = $71;
 $72 = $2;
 $1 = $72;
 $73 = $1;
 $74 = HEAP32[$73>>2]|0;
 $75 = HEAP32[$69>>2]|0;
 $76 = $74;
 $77 = $75;
 $78 = (($76) - ($77))|0;
 $79 = (($78|0) / 12)&-1;
 $9 = $67;
 $10 = $68;
 $11 = $79;
 $80 = $9;
 $81 = $10;
 $82 = $11;
 $6 = $80;
 $7 = $81;
 $8 = $82;
 $83 = $7;
 $5 = $83;
 $84 = $5;
 __ZdlPv($84);
 STACKTOP = sp;return;
}
function __ZN4mjin11application6memory16createRandomGridEi($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$expand_i1_val = 0, $$expand_i1_val2 = 0, $$pre_trunc = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0;
 var $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0;
 var $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0;
 var $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0;
 var $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0;
 var $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0;
 var $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0;
 var $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0;
 var $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0;
 var $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0;
 var $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0;
 var $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0;
 var $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0;
 var $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0;
 var $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0;
 var $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0;
 var $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 768|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(768|0);
 $24 = sp + 24|0;
 $27 = sp + 765|0;
 $65 = sp + 512|0;
 $70 = sp + 492|0;
 $73 = sp + 480|0;
 $75 = sp + 472|0;
 $77 = sp + 464|0;
 $80 = sp + 452|0;
 $82 = sp + 16|0;
 $85 = sp + 436|0;
 $100 = sp + 8|0;
 $105 = sp + 764|0;
 $115 = sp + 763|0;
 $118 = sp + 316|0;
 $121 = sp + 304|0;
 $129 = sp + 272|0;
 $132 = sp + 260|0;
 $148 = sp;
 $153 = sp + 762|0;
 $163 = sp + 761|0;
 $167 = sp + 132|0;
 $170 = sp + 120|0;
 $175 = sp + 92|0;
 $176 = sp + 88|0;
 $181 = sp + 760|0;
 $186 = sp + 52|0;
 $187 = sp + 48|0;
 $188 = sp + 44|0;
 $189 = sp + 40|0;
 $190 = sp + 28|0;
 $174 = $1;
 $173 = $175;
 $191 = $173;
 $172 = $191;
 $192 = $172;
 $171 = $192;
 HEAP32[$192>>2] = 0;
 $193 = ((($192)) + 4|0);
 HEAP32[$193>>2] = 0;
 $194 = ((($192)) + 8|0);
 $169 = $194;
 HEAP32[$170>>2] = 0;
 $195 = $169;
 $168 = $170;
 $196 = $168;
 $197 = HEAP32[$196>>2]|0;
 $166 = $195;
 HEAP32[$167>>2] = $197;
 $198 = $166;
 $165 = $198;
 $164 = $167;
 $199 = $164;
 $200 = HEAP32[$199>>2]|0;
 HEAP32[$198>>2] = $200;
 HEAP32[$176>>2] = 0;
 $201 = $174;
 $202 = $174;
 $203 = Math_imul($201, $202)|0;
 $177 = $203;
 $178 = 0;
 while(1) {
  $204 = $178;
  $205 = $177;
  $206 = ($204|0)<($205|0);
  if (!($206)) {
   label = 10;
   break;
  }
  $161 = $175;
  $162 = $176;
  $207 = $161;
  $208 = ((($207)) + 4|0);
  $209 = HEAP32[$208>>2]|0;
  $160 = $207;
  $210 = $160;
  $211 = ((($210)) + 8|0);
  $159 = $211;
  $212 = $159;
  $158 = $212;
  $213 = $158;
  $214 = HEAP32[$213>>2]|0;
  $215 = ($209|0)!=($214|0);
  if ($215) {
   $155 = $163;
   $156 = $207;
   $157 = 1;
   $138 = $207;
   $216 = $138;
   $217 = ((($216)) + 8|0);
   $137 = $217;
   $218 = $137;
   $136 = $218;
   $219 = $136;
   $220 = ((($207)) + 4|0);
   $221 = HEAP32[$220>>2]|0;
   $139 = $221;
   $222 = $139;
   $223 = $162;
   $150 = $219;
   $151 = $222;
   $152 = $223;
   $224 = $150;
   $225 = $151;
   $226 = $152;
   $149 = $226;
   $227 = $149;
   ;HEAP8[$148>>0]=HEAP8[$153>>0]|0;
   $145 = $224;
   $146 = $225;
   $147 = $227;
   $228 = $145;
   $229 = $146;
   $230 = $147;
   $144 = $230;
   $231 = $144;
   $141 = $228;
   $142 = $229;
   $143 = $231;
   $232 = $142;
   $233 = $143;
   $140 = $233;
   $234 = $140;
   $235 = HEAP32[$234>>2]|0;
   HEAP32[$232>>2] = $235;
   $154 = $163;
   $236 = ((($207)) + 4|0);
   $237 = HEAP32[$236>>2]|0;
   $238 = ((($237)) + 4|0);
   HEAP32[$236>>2] = $238;
  } else {
   $239 = $162;
   __THREW__ = 0;
   invoke_vii(4108,($207|0),($239|0));
   $240 = __THREW__; __THREW__ = 0;
   $241 = $240&1;
   if ($241) {
    break;
   }
  }
  $242 = $178;
  $243 = (($242) - 1)|0;
  $244 = (($243|0) % 2)&-1;
  $245 = ($244|0)==(0);
  if ($245) {
   $246 = HEAP32[$176>>2]|0;
   $247 = (($246) + 1)|0;
   HEAP32[$176>>2] = $247;
  }
  $250 = $178;
  $251 = (($250) + 1)|0;
  $178 = $251;
 }
 if ((label|0) == 10) {
  __THREW__ = 0;
  $252 = (invoke_ii(4109,(0|0))|0);
  $253 = __THREW__; __THREW__ = 0;
  $254 = $253&1;
  if (!($254)) {
   __THREW__ = 0;
   invoke_vi(4110,($252|0));
   $255 = __THREW__; __THREW__ = 0;
   $256 = $255&1;
   if (!($256)) {
    $$expand_i1_val = 0;
    HEAP8[$181>>0] = $$expand_i1_val;
    $135 = $0;
    $257 = $135;
    $134 = $257;
    $258 = $134;
    $133 = $258;
    HEAP32[$258>>2] = 0;
    $259 = ((($258)) + 4|0);
    HEAP32[$259>>2] = 0;
    $260 = ((($258)) + 8|0);
    $131 = $260;
    HEAP32[$132>>2] = 0;
    $261 = $131;
    $130 = $132;
    $262 = $130;
    $263 = HEAP32[$262>>2]|0;
    $128 = $261;
    HEAP32[$129>>2] = $263;
    $264 = $128;
    $127 = $264;
    $126 = $129;
    $265 = $126;
    $266 = HEAP32[$265>>2]|0;
    HEAP32[$264>>2] = $266;
    $182 = 0;
    L15: while(1) {
     $267 = $182;
     $268 = $174;
     $269 = ($267|0)<($268|0);
     if (!($269)) {
      break;
     }
     $183 = 0;
     while(1) {
      $270 = $183;
      $271 = $174;
      $272 = ($270|0)<($271|0);
      if (!($272)) {
       break;
      }
      __THREW__ = 0;
      $273 = (invoke_i(4111)|0);
      $274 = __THREW__; __THREW__ = 0;
      $275 = $274&1;
      if ($275) {
       label = 27;
       break L15;
      }
      $125 = $175;
      $276 = $125;
      $277 = ((($276)) + 4|0);
      $278 = HEAP32[$277>>2]|0;
      $279 = HEAP32[$276>>2]|0;
      $280 = $278;
      $281 = $279;
      $282 = (($280) - ($281))|0;
      $283 = (($282|0) / 4)&-1;
      $284 = (($273>>>0) % ($283>>>0))&-1;
      $184 = $284;
      $285 = $184;
      $123 = $175;
      $124 = $285;
      $286 = $123;
      $287 = HEAP32[$286>>2]|0;
      $288 = $124;
      $289 = (($287) + ($288<<2)|0);
      $290 = HEAP32[$289>>2]|0;
      $185 = $290;
      $122 = $175;
      $291 = $122;
      $292 = HEAP32[$291>>2]|0;
      $119 = $291;
      $120 = $292;
      $293 = $120;
      $116 = $118;
      $117 = $293;
      $294 = $116;
      $295 = $117;
      HEAP32[$294>>2] = $295;
      $296 = HEAP32[$118>>2]|0;
      HEAP32[$121>>2] = $296;
      $297 = HEAP32[$121>>2]|0;
      HEAP32[$188>>2] = $297;
      $298 = $184;
      $86 = $188;
      $87 = $298;
      $299 = $86;
      ;HEAP32[$85>>2]=HEAP32[$299>>2]|0;
      $300 = $87;
      $83 = $85;
      $84 = $300;
      $301 = $83;
      $302 = $84;
      $303 = HEAP32[$301>>2]|0;
      $304 = (($303) + ($302<<2)|0);
      HEAP32[$301>>2] = $304;
      $305 = HEAP32[$85>>2]|0;
      HEAP32[$187>>2] = $305;
      $3 = $186;
      $4 = $187;
      $5 = 0;
      $306 = $3;
      $307 = $4;
      $2 = $307;
      $308 = $2;
      $309 = HEAP32[$308>>2]|0;
      HEAP32[$306>>2] = $309;
      ;HEAP8[$82>>0]=HEAP8[$186>>0]|0;HEAP8[$82+1>>0]=HEAP8[$186+1>>0]|0;HEAP8[$82+2>>0]=HEAP8[$186+2>>0]|0;HEAP8[$82+3>>0]=HEAP8[$186+3>>0]|0;
      $78 = $175;
      $310 = $78;
      $76 = $310;
      $311 = $76;
      $74 = $311;
      $312 = $74;
      $313 = HEAP32[$312>>2]|0;
      $71 = $312;
      $72 = $313;
      $314 = $72;
      $68 = $70;
      $69 = $314;
      $315 = $68;
      $316 = $69;
      HEAP32[$315>>2] = $316;
      $317 = HEAP32[$70>>2]|0;
      HEAP32[$73>>2] = $317;
      $318 = HEAP32[$73>>2]|0;
      HEAP32[$75>>2] = $318;
      $319 = HEAP32[$75>>2]|0;
      HEAP32[$80>>2] = $319;
      $8 = $82;
      $9 = $80;
      $320 = $8;
      $7 = $320;
      $321 = $7;
      $322 = HEAP32[$321>>2]|0;
      $323 = $9;
      $6 = $323;
      $324 = $6;
      $325 = HEAP32[$324>>2]|0;
      $326 = $322;
      $327 = $325;
      $328 = (($326) - ($327))|0;
      $329 = (($328|0) / 4)&-1;
      $79 = $329;
      $330 = HEAP32[$310>>2]|0;
      $331 = $79;
      $332 = (($330) + ($331<<2)|0);
      $81 = $332;
      $333 = $81;
      $334 = ((($333)) + 4|0);
      $335 = ((($310)) + 4|0);
      $336 = HEAP32[$335>>2]|0;
      $337 = $81;
      $17 = $334;
      $18 = $336;
      $19 = $337;
      $338 = $17;
      $16 = $338;
      $339 = $16;
      $340 = $18;
      $10 = $340;
      $341 = $10;
      $342 = $19;
      $11 = $342;
      $343 = $11;
      $12 = $339;
      $13 = $341;
      $14 = $343;
      $344 = $13;
      $345 = $12;
      $346 = $344;
      $347 = $345;
      $348 = (($346) - ($347))|0;
      $349 = (($348|0) / 4)&-1;
      $15 = $349;
      $350 = $15;
      $351 = ($350>>>0)>(0);
      if ($351) {
       $352 = $14;
       $353 = $12;
       $354 = $15;
       $355 = $354<<2;
       _memmove(($352|0),($353|0),($355|0))|0;
      }
      $356 = $14;
      $357 = $15;
      $358 = (($356) + ($357<<2)|0);
      $58 = $310;
      $59 = $358;
      $359 = $58;
      $360 = $59;
      $56 = $359;
      $57 = $360;
      $55 = $359;
      $361 = $55;
      $362 = ((($361)) + 4|0);
      $363 = HEAP32[$362>>2]|0;
      $364 = HEAP32[$361>>2]|0;
      $365 = $363;
      $366 = $364;
      $367 = (($365) - ($366))|0;
      $368 = (($367|0) / 4)&-1;
      $60 = $368;
      $369 = $59;
      $32 = $359;
      $33 = $369;
      $370 = $32;
      while(1) {
       $371 = $33;
       $372 = ((($370)) + 4|0);
       $373 = HEAP32[$372>>2]|0;
       $374 = ($371|0)!=($373|0);
       if (!($374)) {
        break;
       }
       $31 = $370;
       $375 = $31;
       $376 = ((($375)) + 8|0);
       $30 = $376;
       $377 = $30;
       $29 = $377;
       $378 = $29;
       $379 = ((($370)) + 4|0);
       $380 = HEAP32[$379>>2]|0;
       $381 = ((($380)) + -4|0);
       HEAP32[$379>>2] = $381;
       $28 = $381;
       $382 = $28;
       $25 = $378;
       $26 = $382;
       $383 = $25;
       $384 = $26;
       ;HEAP8[$24>>0]=HEAP8[$27>>0]|0;
       $22 = $383;
       $23 = $384;
       $385 = $22;
       $386 = $23;
       $20 = $385;
       $21 = $386;
      }
      $387 = $60;
      $53 = $359;
      $54 = $387;
      $388 = $53;
      $52 = $388;
      $389 = $52;
      $390 = HEAP32[$389>>2]|0;
      $51 = $390;
      $391 = $51;
      $35 = $388;
      $392 = $35;
      $393 = HEAP32[$392>>2]|0;
      $34 = $393;
      $394 = $34;
      $40 = $388;
      $395 = $40;
      $39 = $395;
      $396 = $39;
      $38 = $396;
      $397 = $38;
      $398 = ((($397)) + 8|0);
      $37 = $398;
      $399 = $37;
      $36 = $399;
      $400 = $36;
      $401 = HEAP32[$400>>2]|0;
      $402 = HEAP32[$396>>2]|0;
      $403 = $401;
      $404 = $402;
      $405 = (($403) - ($404))|0;
      $406 = (($405|0) / 4)&-1;
      $407 = (($394) + ($406<<2)|0);
      $42 = $388;
      $408 = $42;
      $409 = HEAP32[$408>>2]|0;
      $41 = $409;
      $410 = $41;
      $411 = $54;
      $412 = (($410) + ($411<<2)|0);
      $44 = $388;
      $413 = $44;
      $414 = HEAP32[$413>>2]|0;
      $43 = $414;
      $415 = $43;
      $45 = $388;
      $416 = $45;
      $417 = ((($416)) + 4|0);
      $418 = HEAP32[$417>>2]|0;
      $419 = HEAP32[$416>>2]|0;
      $420 = $418;
      $421 = $419;
      $422 = (($420) - ($421))|0;
      $423 = (($422|0) / 4)&-1;
      $424 = (($415) + ($423<<2)|0);
      $46 = $388;
      $47 = $391;
      $48 = $407;
      $49 = $412;
      $50 = $424;
      $425 = $81;
      $426 = ((($425)) + -4|0);
      $61 = $310;
      $62 = $426;
      $427 = $81;
      $66 = $310;
      $67 = $427;
      $428 = $67;
      $63 = $65;
      $64 = $428;
      $429 = $63;
      $430 = $64;
      HEAP32[$429>>2] = $430;
      $431 = HEAP32[$65>>2]|0;
      HEAP32[$77>>2] = $431;
      $432 = HEAP32[$77>>2]|0;
      HEAP32[$189>>2] = $432;
      $433 = $182;
      $434 = $183;
      $435 = $185;
      __THREW__ = 0;
      invoke_viiii(4112,($190|0),($433|0),($434|0),($435|0));
      $436 = __THREW__; __THREW__ = 0;
      $437 = $436&1;
      if ($437) {
       label = 27;
       break L15;
      }
      $113 = $0;
      $114 = $190;
      $438 = $113;
      $439 = ((($438)) + 4|0);
      $440 = HEAP32[$439>>2]|0;
      $112 = $438;
      $441 = $112;
      $442 = ((($441)) + 8|0);
      $111 = $442;
      $443 = $111;
      $110 = $443;
      $444 = $110;
      $445 = HEAP32[$444>>2]|0;
      $446 = ($440|0)!=($445|0);
      if ($446) {
       $107 = $115;
       $108 = $438;
       $109 = 1;
       $90 = $438;
       $447 = $90;
       $448 = ((($447)) + 8|0);
       $89 = $448;
       $449 = $89;
       $88 = $449;
       $450 = $88;
       $451 = ((($438)) + 4|0);
       $452 = HEAP32[$451>>2]|0;
       $91 = $452;
       $453 = $91;
       $454 = $114;
       $102 = $450;
       $103 = $453;
       $104 = $454;
       $455 = $102;
       $456 = $103;
       $457 = $104;
       $101 = $457;
       $458 = $101;
       ;HEAP8[$100>>0]=HEAP8[$105>>0]|0;
       $97 = $455;
       $98 = $456;
       $99 = $458;
       $459 = $97;
       $460 = $98;
       $461 = $99;
       $96 = $461;
       $462 = $96;
       $93 = $459;
       $94 = $460;
       $95 = $462;
       $463 = $94;
       $464 = $95;
       $92 = $464;
       $465 = $92;
       ;HEAP32[$463>>2]=HEAP32[$465>>2]|0;HEAP32[$463+4>>2]=HEAP32[$465+4>>2]|0;HEAP32[$463+8>>2]=HEAP32[$465+8>>2]|0;
       $106 = $115;
       $466 = ((($438)) + 4|0);
       $467 = HEAP32[$466>>2]|0;
       $468 = ((($467)) + 12|0);
       HEAP32[$466>>2] = $468;
      } else {
       $469 = $114;
       __THREW__ = 0;
       invoke_vii(4113,($438|0),($469|0));
       $470 = __THREW__; __THREW__ = 0;
       $471 = $470&1;
       if ($471) {
        label = 27;
        break L15;
       }
      }
      $472 = $183;
      $473 = (($472) + 1)|0;
      $183 = $473;
     }
     $476 = $182;
     $477 = (($476) + 1)|0;
     $182 = $477;
    }
    if ((label|0) == 27) {
     $474 = ___cxa_find_matching_catch_2()|0;
     $475 = tempRet0;
     $179 = $474;
     $180 = $475;
     __ZNSt3__26vectorIN4mjin11application6memory4ItemENS_9allocatorIS4_EEED2Ev($0);
     __ZNSt3__26vectorIiNS_9allocatorIiEEED2Ev($175);
     $479 = $179;
     $480 = $180;
     ___resumeException($479|0);
     // unreachable;
    }
    $$expand_i1_val2 = 1;
    HEAP8[$181>>0] = $$expand_i1_val2;
    $$pre_trunc = HEAP8[$181>>0]|0;
    $478 = $$pre_trunc&1;
    if ($478) {
     __ZNSt3__26vectorIiNS_9allocatorIiEEED2Ev($175);
     STACKTOP = sp;return;
    }
    __ZNSt3__26vectorIN4mjin11application6memory4ItemENS_9allocatorIS4_EEED2Ev($0);
    __ZNSt3__26vectorIiNS_9allocatorIiEEED2Ev($175);
    STACKTOP = sp;return;
   }
  }
 }
 $248 = ___cxa_find_matching_catch_2()|0;
 $249 = tempRet0;
 $179 = $248;
 $180 = $249;
 __ZNSt3__26vectorIiNS_9allocatorIiEEED2Ev($175);
 $479 = $179;
 $480 = $180;
 ___resumeException($479|0);
 // unreachable;
}
function __ZNSt3__26vectorIN4mjin11application6memory4ItemENS_9allocatorIS4_EEE21__push_back_slow_pathIRKS4_EEvOT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 208|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(208|0);
 $10 = sp + 8|0;
 $15 = sp + 201|0;
 $24 = sp;
 $27 = sp + 200|0;
 $35 = sp + 80|0;
 $38 = sp + 68|0;
 $46 = sp + 20|0;
 $43 = $0;
 $44 = $1;
 $49 = $43;
 $42 = $49;
 $50 = $42;
 $51 = ((($50)) + 8|0);
 $41 = $51;
 $52 = $41;
 $40 = $52;
 $53 = $40;
 $45 = $53;
 $39 = $49;
 $54 = $39;
 $55 = ((($54)) + 4|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = HEAP32[$54>>2]|0;
 $58 = $56;
 $59 = $57;
 $60 = (($58) - ($59))|0;
 $61 = (($60|0) / 12)&-1;
 $62 = (($61) + 1)|0;
 $34 = $49;
 HEAP32[$35>>2] = $62;
 $63 = $34;
 $64 = (__ZNKSt3__26vectorIN4mjin11application6memory4ItemENS_9allocatorIS4_EEE8max_sizeEv($63)|0);
 $36 = $64;
 $65 = HEAP32[$35>>2]|0;
 $66 = $36;
 $67 = ($65>>>0)>($66>>>0);
 if ($67) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($63);
  // unreachable;
 }
 $32 = $63;
 $68 = $32;
 $31 = $68;
 $69 = $31;
 $30 = $69;
 $70 = $30;
 $71 = ((($70)) + 8|0);
 $29 = $71;
 $72 = $29;
 $28 = $72;
 $73 = $28;
 $74 = HEAP32[$73>>2]|0;
 $75 = HEAP32[$69>>2]|0;
 $76 = $74;
 $77 = $75;
 $78 = (($76) - ($77))|0;
 $79 = (($78|0) / 12)&-1;
 $37 = $79;
 $80 = $37;
 $81 = $36;
 $82 = (($81>>>0) / 2)&-1;
 $83 = ($80>>>0)>=($82>>>0);
 if ($83) {
  $84 = $36;
  $33 = $84;
 } else {
  $85 = $37;
  $86 = $85<<1;
  HEAP32[$38>>2] = $86;
  $25 = $38;
  $26 = $35;
  $87 = $25;
  $88 = $26;
  ;HEAP8[$24>>0]=HEAP8[$27>>0]|0;
  $22 = $87;
  $23 = $88;
  $89 = $22;
  $90 = $23;
  $19 = $24;
  $20 = $89;
  $21 = $90;
  $91 = $20;
  $92 = HEAP32[$91>>2]|0;
  $93 = $21;
  $94 = HEAP32[$93>>2]|0;
  $95 = ($92>>>0)<($94>>>0);
  $96 = $23;
  $97 = $22;
  $98 = $95 ? $96 : $97;
  $99 = HEAP32[$98>>2]|0;
  $33 = $99;
 }
 $100 = $33;
 $18 = $49;
 $101 = $18;
 $102 = ((($101)) + 4|0);
 $103 = HEAP32[$102>>2]|0;
 $104 = HEAP32[$101>>2]|0;
 $105 = $103;
 $106 = $104;
 $107 = (($105) - ($106))|0;
 $108 = (($107|0) / 12)&-1;
 $109 = $45;
 __ZNSt3__214__split_bufferIN4mjin11application6memory4ItemERNS_9allocatorIS4_EEEC2EjjS7_($46,$100,$108,$109);
 $110 = $45;
 $111 = ((($46)) + 8|0);
 $112 = HEAP32[$111>>2]|0;
 $17 = $112;
 $113 = $17;
 $114 = $44;
 $16 = $114;
 $115 = $16;
 $12 = $110;
 $13 = $113;
 $14 = $115;
 $116 = $12;
 $117 = $13;
 $118 = $14;
 $11 = $118;
 $119 = $11;
 ;HEAP8[$10>>0]=HEAP8[$15>>0]|0;
 $7 = $116;
 $8 = $117;
 $9 = $119;
 $120 = $7;
 $121 = $8;
 $122 = $9;
 $6 = $122;
 $123 = $6;
 $3 = $120;
 $4 = $121;
 $5 = $123;
 $124 = $4;
 $125 = $5;
 $2 = $125;
 $126 = $2;
 ;HEAP32[$124>>2]=HEAP32[$126>>2]|0;HEAP32[$124+4>>2]=HEAP32[$126+4>>2]|0;HEAP32[$124+8>>2]=HEAP32[$126+8>>2]|0;
 $127 = ((($46)) + 8|0);
 $128 = HEAP32[$127>>2]|0;
 $129 = ((($128)) + 12|0);
 HEAP32[$127>>2] = $129;
 __THREW__ = 0;
 invoke_vii(4114,($49|0),($46|0));
 $130 = __THREW__; __THREW__ = 0;
 $131 = $130&1;
 if ($131) {
  $132 = ___cxa_find_matching_catch_2()|0;
  $133 = tempRet0;
  $47 = $132;
  $48 = $133;
  __ZNSt3__214__split_bufferIN4mjin11application6memory4ItemERNS_9allocatorIS4_EEED2Ev($46);
  $134 = $47;
  $135 = $48;
  ___resumeException($134|0);
  // unreachable;
 } else {
  __ZNSt3__214__split_bufferIN4mjin11application6memory4ItemERNS_9allocatorIS4_EEED2Ev($46);
  STACKTOP = sp;return;
 }
}
function __ZN4mjin11application6memory8objectIdEPN3osg6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = $1;
 $3 = $2;
 $4 = (__ZNK3osg6Object7getNameEv($3)|0);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_($0,$4);
 STACKTOP = sp;return;
}
function __ZNK3osg6Object7getNameEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 $3 = ((($2)) + 12|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN4mjin11application6memory11setObjectIdEPN3osg6ObjectERKNSt3__212basic_stringIcNS5_11char_traitsIcEENS5_9allocatorIcEEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = $0;
 $3 = $1;
 $4 = $2;
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($5)) + 112|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $3;
 FUNCTION_TABLE_vii[$7 & 8191]($4,$8);
 STACKTOP = sp;return;
}
function __ZN4mjin11application6memory4ItemC2Eiii($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $4 = $0;
 $5 = $1;
 $6 = $2;
 $7 = $3;
 $8 = $4;
 $9 = $5;
 HEAP32[$8>>2] = $9;
 $10 = ((($8)) + 4|0);
 $11 = $6;
 HEAP32[$10>>2] = $11;
 $12 = ((($8)) + 8|0);
 $13 = $7;
 HEAP32[$12>>2] = $13;
 STACKTOP = sp;return;
}
function __GLOBAL__sub_I_render_cpp_4401() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 ___cxx_global_var_init_4402();
 ___cxx_global_var_init_1_4403();
 ___cxx_global_var_init_2_4404();
 return;
}
function ___cxx_global_var_init_4402() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg5Vec3fC2Efff(209212,1.0,0.0,0.0);
 return;
}
function ___cxx_global_var_init_1_4403() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg5Vec3fC2Efff(209200,0.0,1.0,0.0);
 return;
}
function ___cxx_global_var_init_2_4404() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg5Vec3fC2Efff(209188,0.0,0.0,1.0);
 return;
}
function __ZN4mjin6render11setupCameraEPN3osg6CameraEdii($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = +$1;
 $2 = $2|0;
 $3 = $3|0;
 var $10 = 0.0, $11 = 0, $12 = 0, $13 = 0, $14 = 0.0, $15 = 0, $16 = 0.0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0.0, $22 = 0, $23 = 0.0, $24 = 0.0, $25 = 0, $26 = 0.0, $27 = 0.0, $28 = 0.0, $29 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0.0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $4 = $0;
 $5 = $1;
 $6 = $2;
 $7 = $3;
 $11 = $4;
 $12 = (__Znwj(88)|0);
 $13 = $6;
 $14 = (+($13|0));
 $15 = $7;
 $16 = (+($15|0));
 __THREW__ = 0;
 invoke_vidddd(4115,($12|0),0.0,0.0,(+$14),(+$16));
 $17 = __THREW__; __THREW__ = 0;
 $18 = $17&1;
 if ($18) {
  $29 = ___cxa_find_matching_catch_2()|0;
  $30 = tempRet0;
  $8 = $29;
  $9 = $30;
  __ZdlPv($12);
  $31 = $8;
  $32 = $9;
  ___resumeException($31|0);
  // unreachable;
 } else {
  __ZN3osg6Camera11setViewportEPNS_8ViewportE($11,$12);
  $19 = $4;
  __ZN3osg6Camera12setClearMaskEj($19,16640);
  $20 = $6;
  $21 = (+($20|0));
  $22 = $7;
  $23 = (+($22|0));
  $24 = $21 / $23;
  $10 = $24;
  $25 = $4;
  $26 = $5;
  $27 = $10;
  $28 = $27;
  __ZN3osg6Camera32setProjectionMatrixAsPerspectiveEdddd($25,$26,$28,1.0,1000.0);
  STACKTOP = sp;return;
 }
}
function __ZN3osg8ViewportC2Edddd($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = +$1;
 $2 = +$2;
 $3 = +$3;
 $4 = +$4;
 var $10 = 0, $11 = 0, $12 = 0.0, $13 = 0, $14 = 0.0, $15 = 0, $16 = 0.0, $17 = 0, $18 = 0.0, $5 = 0, $6 = 0.0, $7 = 0.0, $8 = 0.0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $5 = $0;
 $6 = $1;
 $7 = $2;
 $8 = $3;
 $9 = $4;
 $10 = $5;
 __ZN3osg14StateAttributeC2Ev($10);
 HEAP32[$10>>2] = (70172);
 $11 = ((($10)) + 56|0);
 $12 = $6;
 HEAPF64[$11>>3] = $12;
 $13 = ((($10)) + 64|0);
 $14 = $7;
 HEAPF64[$13>>3] = $14;
 $15 = ((($10)) + 72|0);
 $16 = $8;
 HEAPF64[$15>>3] = $16;
 $17 = ((($10)) + 80|0);
 $18 = $9;
 HEAPF64[$17>>3] = $18;
 STACKTOP = sp;return;
}
function __ZN3osg6Camera12setClearMaskEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = $0;
 $3 = $1;
 $4 = $2;
 $5 = $3;
 $6 = ((($4)) + 236|0);
 HEAP32[$6>>2] = $5;
 $7 = ((($4)) + 144|0);
 __ZN3osg12CullSettings15applyMaskActionEj($7,16384);
 STACKTOP = sp;return;
}
function __GLOBAL__sub_I_render_platform_web_cpp() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 ___cxx_global_var_init_4411();
 ___cxx_global_var_init_1_4412();
 ___cxx_global_var_init_2_4413();
 return;
}
function ___cxx_global_var_init_4411() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg5Vec3fC2Efff(209248,1.0,0.0,0.0);
 return;
}
function ___cxx_global_var_init_1_4412() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg5Vec3fC2Efff(209236,0.0,1.0,0.0);
 return;
}
function ___cxx_global_var_init_2_4413() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg5Vec3fC2Efff(209224,0.0,0.0,1.0);
 return;
}
function __ZN4mjin6render6useVBOEPN3osg4NodeE($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $4 = HEAP8[206136]|0;
 $5 = ($4<<24>>24)==(0);
 do {
  if ($5) {
   $6 = (___cxa_guard_acquire(206136)|0);
   $7 = ($6|0)!=(0);
   if ($7) {
    __THREW__ = 0;
    invoke_vi(4116,(209260|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     $14 = ___cxa_find_matching_catch_2()|0;
     $15 = tempRet0;
     $2 = $14;
     $3 = $15;
     $16 = $2;
     $17 = $3;
     ___resumeException($16|0);
     // unreachable;
    } else {
     (___cxa_atexit((2571|0),(209260|0),(___dso_handle|0))|0);
     break;
    }
   }
  }
 } while(0);
 $10 = $1;
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11)) + 188|0);
 $13 = HEAP32[$12>>2]|0;
 FUNCTION_TABLE_vii[$13 & 8191]($10,209260);
 STACKTOP = sp;return;
}
function __ZN4mjin6render15VBOSetupVisitorC1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $4 = $1;
 $5 = ((($4)) + 56|0);
 __ZN3osg6ObjectC2Ev($5);
 __THREW__ = 0;
 $6 = 72484;
 invoke_viii(3283,($4|0),($6|0),2);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $10 = ___cxa_find_matching_catch_2()|0;
  $11 = tempRet0;
  $2 = $10;
  $3 = $11;
  $12 = ((($4)) + 56|0);
  __ZN3osg6ObjectD2Ev($12);
  $13 = $2;
  $14 = $3;
  ___resumeException($13|0);
  // unreachable;
 } else {
  HEAP32[$4>>2] = (72508);
  $9 = ((($4)) + 56|0);
  HEAP32[$9>>2] = (72852);
  STACKTOP = sp;return;
 }
}
function __ZN4mjin6render15VBOSetupVisitorD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 __ZN4mjin6render15VBOSetupVisitorD2Ev($2,72480);
 $3 = ((($2)) + 56|0);
 __ZN3osg6ObjectD2Ev($3);
 STACKTOP = sp;return;
}
function __ZN4mjin6render15VBOSetupVisitorD2Ev($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = $0;
 $3 = $1;
 $4 = $2;
 $5 = $3;
 $6 = ((($5)) + 4|0);
 __ZN3osg11NodeVisitorD2Ev($4,$6);
 STACKTOP = sp;return;
}
function __ZN4mjin6render15VBOSetupVisitorD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 __ZN4mjin6render15VBOSetupVisitorD1Ev($2);
 __ZdlPv($2);
 STACKTOP = sp;return;
}
function __ZN4mjin6render15VBOSetupVisitor5applyERN3osg5GeodeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = $0;
 $3 = $1;
 $6 = $2;
 $4 = 0;
 while(1) {
  $7 = $4;
  $8 = $3;
  $9 = (__ZNK3osg5Geode15getNumDrawablesEv($8)|0);
  $10 = ($7>>>0)<($9>>>0);
  if (!($10)) {
   break;
  }
  $11 = $3;
  $12 = $4;
  $13 = (__ZN3osg5Geode11getDrawableEj($11,$12)|0);
  $14 = ($13|0)==(0|0);
  if ($14) {
   $16 = 0;
  } else {
   $15 = (___dynamic_cast($13,24472,24616,0)|0);
   $16 = $15;
  }
  $5 = $16;
  $17 = $5;
  $18 = ($17|0)!=(0|0);
  if ($18) {
   $19 = $5;
   $20 = HEAP32[$19>>2]|0;
   $21 = ((($20)) + 212|0);
   $22 = HEAP32[$21>>2]|0;
   FUNCTION_TABLE_vii[$22 & 8191]($19,1);
  }
  $23 = $4;
  $24 = (($23) + 1)|0;
  $4 = $24;
 }
 $25 = $3;
 __ZN3osg11NodeVisitor5applyERNS_5GeodeE($6,$25);
 STACKTOP = sp;return;
}
function __ZTv0_n16_N4mjin6render15VBOSetupVisitorD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + -16|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($2) + ($5)|0);
 __ZN4mjin6render15VBOSetupVisitorD1Ev($6);
 STACKTOP = sp;return;
}
function __ZTv0_n16_N4mjin6render15VBOSetupVisitorD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + -16|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($2) + ($5)|0);
 __ZN4mjin6render15VBOSetupVisitorD0Ev($6);
 STACKTOP = sp;return;
}
function __ZNK3osg5Geode15getNumDrawablesEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + 224|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_ii[$5 & 8191]($2)|0);
 STACKTOP = sp;return ($6|0);
}
function __ZN3osg5Geode11getDrawableEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $6 = $0;
 $7 = $1;
 $8 = $6;
 $9 = ((($8)) + 124|0);
 $10 = $7;
 $4 = $9;
 $5 = $10;
 $11 = $4;
 $12 = HEAP32[$11>>2]|0;
 $13 = $5;
 $14 = (($12) + ($13<<2)|0);
 $15 = (__ZNK3osg7ref_ptrINS_4NodeEE5validEv($14)|0);
 if (!($15)) {
  $27 = 0;
  STACKTOP = sp;return ($27|0);
 }
 $16 = ((($8)) + 124|0);
 $17 = $7;
 $2 = $16;
 $3 = $17;
 $18 = $2;
 $19 = HEAP32[$18>>2]|0;
 $20 = $3;
 $21 = (($19) + ($20<<2)|0);
 $22 = (__ZNK3osg7ref_ptrINS_4NodeEEptEv($21)|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ((($23)) + 80|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (FUNCTION_TABLE_ii[$25 & 8191]($22)|0);
 $27 = $26;
 STACKTOP = sp;return ($27|0);
}
function __ZNK3osg7ref_ptrINS_4NodeEE5validEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)!=(0|0);
 STACKTOP = sp;return ($4|0);
}
function __ZNK3osg7ref_ptrINS_4NodeEEptEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 STACKTOP = sp;return ($3|0);
}
function __ZN5osgDB13DatabasePager12RequestQueueD2Ev($0) {
 $0 = $0|0;
 var $$023$i$i = 0, $$023$i$i9 = 0, $$2 = 0, $$24 = 0, $$sink19$index = 0, $$sink19$index3 = 0, $$sroa$014$0 = 0, $$sroa$014$021 = 0, $$sroa$014$022 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 HEAP32[$0>>2] = (73000);
 __THREW__ = 0;
 $2 = (invoke_ii(3265,4)|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 L1: do {
  if ($4) {
   label = 14;
  } else {
   do {
    if ($2) {
     __THREW__ = 0;
     $5 = (invoke_ii(3266,4)|0);
     $6 = __THREW__; __THREW__ = 0;
     $7 = $6&1;
     if ($7) {
      label = 14;
      break L1;
     }
     __THREW__ = 0;
     $8 = (invoke_iiii(3267,($5|0),(162633|0),63)|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      label = 14;
      break L1;
     }
     $11 = HEAP32[$8>>2]|0;
     $12 = ((($11)) + -12|0);
     $13 = HEAP32[$12>>2]|0;
     $14 = (($8) + ($13)|0);
     __THREW__ = 0;
     invoke_vii(3257,($1|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      label = 14;
      break L1;
     }
     __THREW__ = 0;
     $17 = (invoke_iii(3255,($1|0),(215188|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if (!($19)) {
      $20 = HEAP32[$17>>2]|0;
      $21 = ((($20)) + 28|0);
      $22 = HEAP32[$21>>2]|0;
      __THREW__ = 0;
      $23 = (invoke_iii($22|0,($17|0),10)|0);
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if (!($25)) {
       __THREW__ = 0;
       invoke_vi(3263,($1|0));
       $32 = __THREW__; __THREW__ = 0;
       $33 = $32&1;
       if ($33) {
        label = 14;
        break L1;
       }
       __THREW__ = 0;
       (invoke_iii(3268,($8|0),($23|0))|0);
       $34 = __THREW__; __THREW__ = 0;
       $35 = $34&1;
       if ($35) {
        label = 14;
        break L1;
       }
       __THREW__ = 0;
       (invoke_ii(3269,($8|0))|0);
       $36 = __THREW__; __THREW__ = 0;
       $37 = $36&1;
       if ($37) {
        label = 14;
        break L1;
       } else {
        break;
       }
      }
     }
     $26 = ___cxa_find_matching_catch_2()|0;
     $27 = tempRet0;
     __THREW__ = 0;
     invoke_vi(3263,($1|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      $30 = ___cxa_find_matching_catch_3(0|0)|0;
      $31 = tempRet0;
      ___clang_call_terminate($30);
      // unreachable;
     } else {
      $$sink19$index = $26;$$sink19$index3 = $27;
      label = 29;
      break L1;
     }
    }
   } while(0);
   $40 = ((($0)) + 16|0);
   $41 = ((($0)) + 20|0);
   $$sroa$014$021 = HEAP32[$41>>2]|0;
   $42 = $$sroa$014$021;
   $43 = ($42|0)==($40|0);
   L18: do {
    if (!($43)) {
     $$sroa$014$022 = $$sroa$014$021;$53 = $42;
     while(1) {
      $47 = $$sroa$014$022;
      $48 = ((($47)) + 8|0);
      $49 = HEAP32[$48>>2]|0;
      __THREW__ = 0;
      invoke_vii(4117,($0|0),($49|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       break;
      }
      $52 = ((($53)) + 4|0);
      $$sroa$014$0 = HEAP32[$52>>2]|0;
      $54 = $$sroa$014$0;
      $55 = ($54|0)==($40|0);
      if ($55) {
       break L18;
      } else {
       $$sroa$014$022 = $$sroa$014$0;$53 = $54;
      }
     }
     $56 = ___cxa_find_matching_catch_2()|0;
     $57 = tempRet0;
     $$sink19$index = $56;$$sink19$index3 = $57;
     label = 29;
     break L1;
    }
   } while(0);
   $44 = ((($0)) + 28|0);
   __THREW__ = 0;
   invoke_vi(707,($44|0));
   $45 = __THREW__; __THREW__ = 0;
   $46 = $45&1;
   if ($46) {
    $82 = ___cxa_find_matching_catch_2()|0;
    $83 = tempRet0;
    $$2 = $83;$$24 = $82;
    break;
   }
   $58 = ((($0)) + 24|0);
   $59 = HEAP32[$58>>2]|0;
   $60 = ($59|0)==(0);
   if ($60) {
    __ZN3osg10ReferencedD2Ev($0);
    STACKTOP = sp;return;
   }
   $61 = HEAP32[$41>>2]|0;
   $62 = HEAP32[$40>>2]|0;
   $63 = ((($62)) + 4|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = HEAP32[$61>>2]|0;
   $66 = ((($65)) + 4|0);
   HEAP32[$66>>2] = $64;
   $67 = HEAP32[$63>>2]|0;
   HEAP32[$67>>2] = $65;
   HEAP32[$58>>2] = 0;
   $68 = ($61|0)==($40|0);
   if ($68) {
    __ZN3osg10ReferencedD2Ev($0);
    STACKTOP = sp;return;
   } else {
    $$023$i$i = $61;
   }
   while(1) {
    $69 = ((($$023$i$i)) + 4|0);
    $70 = HEAP32[$69>>2]|0;
    $71 = ((($$023$i$i)) + 8|0);
    $72 = HEAP32[$71>>2]|0;
    $73 = ($72|0)==(0|0);
    if (!($73)) {
     $74 = ((($72)) + 8|0);
     $75 = HEAP32[$74>>2]|0;HEAP32[$74>>2] = (($75-1)|0);
     $76 = ($75|0)==(1);
     if ($76) {
      __THREW__ = 0;
      invoke_viii(3262,($72|0),1,1);
      $77 = __THREW__; __THREW__ = 0;
      $78 = $77&1;
      if ($78) {
       label = 26;
       break;
      }
     }
    }
    __ZdlPv($$023$i$i);
    $79 = ($70|0)==($40|0);
    if ($79) {
     label = 27;
     break;
    } else {
     $$023$i$i = $70;
    }
   }
   if ((label|0) == 26) {
    $80 = ___cxa_find_matching_catch_2()|0;
    $81 = tempRet0;
    ___cxa_call_unexpected(($80|0));
    // unreachable;
   }
   else if ((label|0) == 27) {
    __ZN3osg10ReferencedD2Ev($0);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 14) {
  $38 = ___cxa_find_matching_catch_2()|0;
  $39 = tempRet0;
  $$sink19$index = $38;$$sink19$index3 = $39;
  label = 29;
 }
 if ((label|0) == 29) {
  $84 = ((($0)) + 28|0);
  __THREW__ = 0;
  invoke_vi(707,($84|0));
  $85 = __THREW__; __THREW__ = 0;
  $86 = $85&1;
  if ($86) {
   $115 = ___cxa_find_matching_catch_3(0|0)|0;
   $116 = tempRet0;
   ___clang_call_terminate($115);
   // unreachable;
  } else {
   $$2 = $$sink19$index3;$$24 = $$sink19$index;
  }
 }
 $87 = ((($0)) + 16|0);
 $88 = ((($0)) + 24|0);
 $89 = HEAP32[$88>>2]|0;
 $90 = ($89|0)==(0);
 L47: do {
  if (!($90)) {
   $91 = ((($0)) + 20|0);
   $92 = HEAP32[$91>>2]|0;
   $93 = HEAP32[$87>>2]|0;
   $94 = ((($93)) + 4|0);
   $95 = HEAP32[$94>>2]|0;
   $96 = HEAP32[$92>>2]|0;
   $97 = ((($96)) + 4|0);
   HEAP32[$97>>2] = $95;
   $98 = HEAP32[$94>>2]|0;
   HEAP32[$98>>2] = $96;
   HEAP32[$88>>2] = 0;
   $99 = ($92|0)==($87|0);
   if (!($99)) {
    $$023$i$i9 = $92;
    while(1) {
     $100 = ((($$023$i$i9)) + 4|0);
     $101 = HEAP32[$100>>2]|0;
     $102 = ((($$023$i$i9)) + 8|0);
     $103 = HEAP32[$102>>2]|0;
     $104 = ($103|0)==(0|0);
     if (!($104)) {
      $105 = ((($103)) + 8|0);
      $106 = HEAP32[$105>>2]|0;HEAP32[$105>>2] = (($106-1)|0);
      $107 = ($106|0)==(1);
      if ($107) {
       __THREW__ = 0;
       invoke_viii(3262,($103|0),1,1);
       $108 = __THREW__; __THREW__ = 0;
       $109 = $108&1;
       if ($109) {
        break;
       }
      }
     }
     __ZdlPv($$023$i$i9);
     $110 = ($101|0)==($87|0);
     if ($110) {
      break L47;
     } else {
      $$023$i$i9 = $101;
     }
    }
    $111 = ___cxa_find_matching_catch_2()|0;
    $112 = tempRet0;
    ___cxa_call_unexpected(($111|0));
    // unreachable;
   }
  }
 } while(0);
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $113 = __THREW__; __THREW__ = 0;
 $114 = $113&1;
 if ($114) {
  $115 = ___cxa_find_matching_catch_3(0|0)|0;
  $116 = tempRet0;
  ___clang_call_terminate($115);
  // unreachable;
 } else {
  ___resumeException($$24|0);
  // unreachable;
 }
}
function __ZN5osgDB13DatabasePager12RequestQueueD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(2576,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZN5osgDB13DatabasePager12RequestQueue11updateBlockEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN5osgDB13DatabasePager12RequestQueue10invalidateEPNS0_15DatabaseRequestE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 HEAP32[$2>>2] = 0;
 $3 = ((($1)) + 92|0);
 __THREW__ = 0;
 $4 = (invoke_iii(4118,($3|0),($2|0))|0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 do {
  if (!($6)) {
   if ($4) {
    $7 = ((($0)) + 12|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = ((($8)) + 132|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = ($10|0)==(0|0);
    if (!($11)) {
     $12 = HEAP32[$2>>2]|0;
     __THREW__ = 0;
     invoke_vii(4119,($10|0),($12|0));
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
    }
   }
   __THREW__ = 0;
   invoke_vi(4120,($1|0));
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   if (!($25)) {
    $26 = HEAP32[$2>>2]|0;
    $27 = ($26|0)==(0|0);
    if ($27) {
     STACKTOP = sp;return;
    }
    $28 = ((($26)) + 8|0);
    $29 = HEAP32[$28>>2]|0;HEAP32[$28>>2] = (($29-1)|0);
    $30 = ($29|0)==(1);
    if (!($30)) {
     STACKTOP = sp;return;
    }
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($26,1,1);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $15 = ___cxa_find_matching_catch_2()|0;
 $16 = tempRet0;
 $17 = HEAP32[$2>>2]|0;
 $18 = ($17|0)==(0|0);
 if ($18) {
  ___resumeException($15|0);
  // unreachable;
 }
 $19 = ((($17)) + 8|0);
 $20 = HEAP32[$19>>2]|0;HEAP32[$19>>2] = (($20-1)|0);
 $21 = ($20|0)==(1);
 if (!($21)) {
  ___resumeException($15|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(3262,($17|0),1,1);
 $22 = __THREW__; __THREW__ = 0;
 $23 = $22&1;
 if ($23) {
  $31 = ___cxa_find_matching_catch_3(0|0)|0;
  $32 = tempRet0;
  ___clang_call_terminate($31);
  // unreachable;
 } else {
  ___resumeException($15|0);
  // unreachable;
 }
}
function __ZNK3osg12observer_ptrIN7osgUtil27IncrementalCompileOperation10CompileSetEE4lockERNS_7ref_ptrIS3_EE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  $4 = HEAP32[$1>>2]|0;
  $5 = ($4|0)==(0|0);
  if ($5) {
   $$1 = 0;
   return ($$1|0);
  }
  HEAP32[$1>>2] = 0;
  $6 = ((($4)) + 8|0);
  $7 = HEAP32[$6>>2]|0;HEAP32[$6>>2] = (($7-1)|0);
  $8 = ($7|0)==(1);
  if (!($8)) {
   $$1 = 0;
   return ($$1|0);
  }
  __ZNK3osg10Referenced24signalObserversAndDeleteEbb($4,1,1);
  $$1 = 0;
  return ($$1|0);
 }
 $9 = (__ZN3osg11ObserverSet10addRefLockEv($2)|0);
 $10 = ($9|0)==(0|0);
 if ($10) {
  $11 = HEAP32[$1>>2]|0;
  $12 = ($11|0)==(0|0);
  if ($12) {
   $$1 = 0;
   return ($$1|0);
  }
  HEAP32[$1>>2] = 0;
  $13 = ((($11)) + 8|0);
  $14 = HEAP32[$13>>2]|0;HEAP32[$13>>2] = (($14-1)|0);
  $15 = ($14|0)==(1);
  if (!($15)) {
   $$1 = 0;
   return ($$1|0);
  }
  __ZNK3osg10Referenced24signalObserversAndDeleteEbb($11,1,1);
  $$1 = 0;
  return ($$1|0);
 }
 $16 = ((($0)) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = HEAP32[$1>>2]|0;
 $19 = ($18|0)==($17|0);
 if (!($19)) {
  HEAP32[$1>>2] = $17;
  $20 = ($17|0)==(0|0);
  if (!($20)) {
   $21 = ((($17)) + 8|0);
   $22 = HEAP32[$21>>2]|0;HEAP32[$21>>2] = (($22+1)|0);
  }
  $23 = ($18|0)==(0|0);
  if (!($23)) {
   $24 = ((($18)) + 8|0);
   $25 = HEAP32[$24>>2]|0;HEAP32[$24>>2] = (($25-1)|0);
   $26 = ($25|0)==(1);
   if ($26) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($18,1,1);
   }
  }
 }
 (__ZNK3osg10Referenced14unref_nodeleteEv($9)|0);
 $27 = HEAP32[$1>>2]|0;
 $28 = ($27|0)!=(0|0);
 $$1 = $28;
 return ($$1|0);
}
function __ZN5osgDB13DatabasePager15DatabaseRequest10invalidateEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $2 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
 do {
  if ($2) {
   $3 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
   $4 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($3,162697,48)|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = ((($5)) + -12|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = (($4) + ($7)|0);
   __ZNKSt3__28ios_base6getlocEv($1,$8);
   __THREW__ = 0;
   $9 = (invoke_iii(3255,($1|0),(215188|0))|0);
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    $12 = HEAP32[$9>>2]|0;
    $13 = ((($12)) + 28|0);
    $14 = HEAP32[$13>>2]|0;
    __THREW__ = 0;
    $15 = (invoke_iii($14|0,($9|0),10)|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if (!($17)) {
     __ZNSt3__26localeD2Ev($1);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($4,$15)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($4)|0);
     break;
    }
   }
   $18 = ___cxa_find_matching_catch_2()|0;
   $19 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($1|0));
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if ($21) {
    $22 = ___cxa_find_matching_catch_3(0|0)|0;
    $23 = tempRet0;
    ___clang_call_terminate($22);
    // unreachable;
   } else {
    ___resumeException($18|0);
    // unreachable;
   }
  }
 } while(0);
 $24 = ((($0)) + 12|0);
 HEAP8[$24>>0] = 0;
 $25 = ((($0)) + 80|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($26|0)==(0|0);
 if (!($27)) {
  HEAP32[$25>>2] = 0;
  $28 = ((($26)) + 8|0);
  $29 = HEAP32[$28>>2]|0;HEAP32[$28>>2] = (($29-1)|0);
  $30 = ($29|0)==(1);
  if ($30) {
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($26,1,1);
  }
 }
 $31 = ((($0)) + 92|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = ($32|0)==(0|0);
 if (!($33)) {
  HEAP32[$31>>2] = 0;
  $34 = ((($32)) + 8|0);
  $35 = HEAP32[$34>>2]|0;HEAP32[$34>>2] = (($35-1)|0);
  $36 = ($35|0)==(1);
  if ($36) {
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($32,1,1);
  }
 }
 $37 = ((($0)) + 96|0);
 HEAP32[$37>>2] = 0;
 $38 = ((($0)) + 88|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = ($39|0)==(0|0);
 if ($40) {
  STACKTOP = sp;return;
 }
 HEAP32[$38>>2] = 0;
 $41 = ((($39)) + 8|0);
 $42 = HEAP32[$41>>2]|0;HEAP32[$41>>2] = (($42-1)|0);
 $43 = ($42|0)==(1);
 if (!($43)) {
  STACKTOP = sp;return;
 }
 __ZNK3osg10Referenced24signalObserversAndDeleteEbb($39,1,1);
 STACKTOP = sp;return;
}
function __ZN5osgDB13DatabasePager9ReadQueueD2Ev($0) {
 $0 = $0|0;
 var $$023$i$i = 0, $$1 = 0, $$13 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (73024);
 $1 = ((($0)) + 72|0);
 $2 = ((($0)) + 80|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 L1: do {
  if (!($4)) {
   $5 = ((($0)) + 76|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = HEAP32[$1>>2]|0;
   $8 = ((($7)) + 4|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = HEAP32[$6>>2]|0;
   $11 = ((($10)) + 4|0);
   HEAP32[$11>>2] = $9;
   $12 = HEAP32[$8>>2]|0;
   HEAP32[$12>>2] = $10;
   HEAP32[$2>>2] = 0;
   $13 = ($6|0)==($1|0);
   if (!($13)) {
    $$023$i$i = $6;
    while(1) {
     $14 = ((($$023$i$i)) + 4|0);
     $15 = HEAP32[$14>>2]|0;
     $16 = ((($$023$i$i)) + 8|0);
     $17 = HEAP32[$16>>2]|0;
     $18 = ($17|0)==(0|0);
     if (!($18)) {
      $19 = ((($17)) + 8|0);
      $20 = HEAP32[$19>>2]|0;HEAP32[$19>>2] = (($20-1)|0);
      $21 = ($20|0)==(1);
      if ($21) {
       __THREW__ = 0;
       invoke_viii(3262,($17|0),1,1);
       $22 = __THREW__; __THREW__ = 0;
       $23 = $22&1;
       if ($23) {
        break;
       }
      }
     }
     __ZdlPv($$023$i$i);
     $24 = ($15|0)==($1|0);
     if ($24) {
      break L1;
     } else {
      $$023$i$i = $15;
     }
    }
    $25 = ___cxa_find_matching_catch_2()|0;
    $26 = tempRet0;
    ___cxa_call_unexpected(($25|0));
    // unreachable;
   }
  }
 } while(0);
 $27 = ((($0)) + 60|0);
 __THREW__ = 0;
 invoke_vi(707,($27|0));
 $28 = __THREW__; __THREW__ = 0;
 $29 = $28&1;
 do {
  if ($29) {
   $47 = ___cxa_find_matching_catch_2()|0;
   $48 = tempRet0;
   $49 = ((($0)) + 48|0);
   $50 = ((($49)) + 11|0);
   $51 = HEAP8[$50>>0]|0;
   $52 = ($51<<24>>24)<(0);
   if ($52) {
    $53 = HEAP32[$49>>2]|0;
    __ZdlPv($53);
   }
   $54 = ((($0)) + 44|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = ($55|0)==(0|0);
   if (!($56)) {
    $57 = HEAP32[$55>>2]|0;
    $58 = ((($57)) + -12|0);
    $59 = HEAP32[$58>>2]|0;
    $60 = (($55) + ($59)|0);
    $61 = ((($60)) + 8|0);
    $62 = HEAP32[$61>>2]|0;HEAP32[$61>>2] = (($62-1)|0);
    $63 = ($62|0)==(1);
    if ($63) {
     __THREW__ = 0;
     invoke_viii(3262,($60|0),1,1);
     $64 = __THREW__; __THREW__ = 0;
     $65 = $64&1;
     if ($65) {
      $70 = ___cxa_find_matching_catch_3(0|0)|0;
      $71 = tempRet0;
      ___clang_call_terminate($70);
      // unreachable;
     }
    }
   }
   HEAP32[$54>>2] = 0;
   $$1 = $48;$$13 = $47;
  } else {
   $30 = ((($0)) + 48|0);
   $31 = ((($30)) + 11|0);
   $32 = HEAP8[$31>>0]|0;
   $33 = ($32<<24>>24)<(0);
   if ($33) {
    $34 = HEAP32[$30>>2]|0;
    __ZdlPv($34);
   }
   $35 = ((($0)) + 44|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = ($36|0)==(0|0);
   if ($37) {
    HEAP32[$35>>2] = 0;
    __ZN5osgDB13DatabasePager12RequestQueueD2Ev($0);
    return;
   }
   $38 = HEAP32[$36>>2]|0;
   $39 = ((($38)) + -12|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = (($36) + ($40)|0);
   $42 = ((($41)) + 8|0);
   $43 = HEAP32[$42>>2]|0;HEAP32[$42>>2] = (($43-1)|0);
   $44 = ($43|0)==(1);
   if (!($44)) {
    HEAP32[$35>>2] = 0;
    __ZN5osgDB13DatabasePager12RequestQueueD2Ev($0);
    return;
   }
   __THREW__ = 0;
   invoke_viii(3262,($41|0),1,1);
   $45 = __THREW__; __THREW__ = 0;
   $46 = $45&1;
   if ($46) {
    $66 = ___cxa_find_matching_catch_2()|0;
    $67 = tempRet0;
    $$1 = $67;$$13 = $66;
    break;
   } else {
    HEAP32[$35>>2] = 0;
    __ZN5osgDB13DatabasePager12RequestQueueD2Ev($0);
    return;
   }
  }
 } while(0);
 __THREW__ = 0;
 invoke_vi(2576,($0|0));
 $68 = __THREW__; __THREW__ = 0;
 $69 = $68&1;
 if ($69) {
  $70 = ___cxa_find_matching_catch_3(0|0)|0;
  $71 = tempRet0;
  ___clang_call_terminate($70);
  // unreachable;
 } else {
  ___resumeException($$13|0);
  // unreachable;
 }
}
function __ZN5osgDB13DatabasePager9ReadQueueD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(2579,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZN5osgDB13DatabasePager9ReadQueue11updateBlockEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 44|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 4|0);
 $4 = ((($0)) + 24|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  $7 = ((($0)) + 80|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)==(0);
  if ($9) {
   $16 = 0;
  } else {
   label = 3;
  }
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $10 = ((($0)) + 12|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ((($11)) + 54|0);
  $13 = HEAP8[$12>>0]|0;
  $14 = ($13<<24>>24)==(0);
  $16 = $14;
 }
 $15 = $16&1;
 $17 = ((($2)) + 24|0);
 $18 = HEAP8[$17>>0]|0;
 $19 = $18&255;
 $20 = ($15|0)==($19|0);
 if ($20) {
  return;
 }
 $21 = HEAP32[$3>>2]|0;
 $22 = ((($21)) + 8|0);
 $23 = HEAP32[$22>>2]|0;
 (FUNCTION_TABLE_ii[$23 & 8191]($3)|0);
 if (!($16)) {
  HEAP8[$17>>0] = 0;
  $41 = HEAP32[$3>>2]|0;
  $42 = ((($41)) + 12|0);
  $43 = HEAP32[$42>>2]|0;
  (FUNCTION_TABLE_ii[$43 & 8191]($3)|0);
  return;
 }
 $24 = HEAP8[$17>>0]|0;
 $25 = ($24<<24>>24)==(0);
 if ($25) {
  HEAP8[$17>>0] = 1;
  $26 = ((($2)) + 16|0);
  __THREW__ = 0;
  (invoke_ii(2504,($26|0))|0);
  $27 = __THREW__; __THREW__ = 0;
  $28 = $27&1;
  if ($28) {
   $29 = ___cxa_find_matching_catch_2()|0;
   $30 = tempRet0;
   $31 = HEAP32[$3>>2]|0;
   $32 = ((($31)) + 12|0);
   $33 = HEAP32[$32>>2]|0;
   __THREW__ = 0;
   (invoke_ii($33|0,($3|0))|0);
   $34 = __THREW__; __THREW__ = 0;
   $35 = $34&1;
   if ($35) {
    $36 = ___cxa_find_matching_catch_3(0|0)|0;
    $37 = tempRet0;
    ___clang_call_terminate($36);
    // unreachable;
   } else {
    ___resumeException($29|0);
    // unreachable;
   }
  }
 }
 $38 = HEAP32[$3>>2]|0;
 $39 = ((($38)) + 12|0);
 $40 = HEAP32[$39>>2]|0;
 (FUNCTION_TABLE_ii[$40 & 8191]($3)|0);
 return;
}
function __ZN5osgDB13DatabasePager14DatabaseThreadD2Ev($0) {
 $0 = $0|0;
 var $$0 = 0, $$02 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (73048);
 $1 = ((($0)) + 12|0);
 HEAP32[$1>>2] = (73076);
 __THREW__ = 0;
 (invoke_ii(2584,($0|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if ($3) {
   $11 = ___cxa_find_matching_catch_2()|0;
   $12 = tempRet0;
   $13 = ((($0)) + 36|0);
   $14 = ((($13)) + 11|0);
   $15 = HEAP8[$14>>0]|0;
   $16 = ($15<<24>>24)<(0);
   if ($16) {
    $17 = HEAP32[$13>>2]|0;
    __ZdlPv($17);
   }
   __THREW__ = 0;
   invoke_vi(2489,($1|0));
   $18 = __THREW__; __THREW__ = 0;
   $19 = $18&1;
   if ($19) {
    $24 = ___cxa_find_matching_catch_3(0|0)|0;
    $25 = tempRet0;
    ___clang_call_terminate($24);
    // unreachable;
   } else {
    $$0 = $12;$$02 = $11;
   }
  } else {
   $4 = ((($0)) + 36|0);
   $5 = ((($4)) + 11|0);
   $6 = HEAP8[$5>>0]|0;
   $7 = ($6<<24>>24)<(0);
   if ($7) {
    $8 = HEAP32[$4>>2]|0;
    __ZdlPv($8);
   }
   __THREW__ = 0;
   invoke_vi(2489,($1|0));
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if ($10) {
    $20 = ___cxa_find_matching_catch_2()|0;
    $21 = tempRet0;
    $$0 = $21;$$02 = $20;
    break;
   } else {
    __ZN3osg10ReferencedD2Ev($0);
    return;
   }
  }
 } while(0);
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $22 = __THREW__; __THREW__ = 0;
 $23 = $22&1;
 if ($23) {
  $24 = ___cxa_find_matching_catch_3(0|0)|0;
  $25 = tempRet0;
  ___clang_call_terminate($24);
  // unreachable;
 } else {
  ___resumeException($$02|0);
  // unreachable;
 }
}
function __ZN5osgDB13DatabasePager14DatabaseThreadD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(2582,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZN5osgDB13DatabasePager14DatabaseThread6cancelEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 12|0);
 $2 = (__ZN11OpenThreads6Thread9isRunningEv($1)|0);
 if (!($2)) {
  return 0;
 }
 $3 = ((($0)) + 20|0);
 $4 = HEAP32[$3>>2]|0;HEAP32[$3>>2] = 1;
 $5 = ((($0)) + 32|0);
 $6 = HEAP32[$5>>2]|0;
 switch ($6|0) {
 case 0:  {
  $7 = ((($0)) + 28|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ((($8)) + 88|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ((($10)) + 44|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ((($12)) + 4|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = ((($14)) + 8|0);
  $16 = HEAP32[$15>>2]|0;
  (FUNCTION_TABLE_ii[$16 & 8191]($13)|0);
  $17 = ((($12)) + 24|0);
  $18 = HEAP8[$17>>0]|0;
  $19 = ($18<<24>>24)==(0);
  if ($19) {
   HEAP8[$17>>0] = 1;
   $20 = ((($12)) + 16|0);
   __THREW__ = 0;
   (invoke_ii(2504,($20|0))|0);
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if ($22) {
    $23 = ___cxa_find_matching_catch_2()|0;
    $24 = tempRet0;
    $25 = HEAP32[$13>>2]|0;
    $26 = ((($25)) + 12|0);
    $27 = HEAP32[$26>>2]|0;
    __THREW__ = 0;
    (invoke_ii($27|0,($13|0))|0);
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if ($29) {
     $30 = ___cxa_find_matching_catch_3(0|0)|0;
     $31 = tempRet0;
     ___clang_call_terminate($30);
     // unreachable;
    } else {
     ___resumeException($23|0);
     // unreachable;
    }
   }
  }
  $32 = HEAP32[$13>>2]|0;
  $33 = ((($32)) + 12|0);
  $34 = HEAP32[$33>>2]|0;
  (FUNCTION_TABLE_ii[$34 & 8191]($13)|0);
  break;
 }
 case 1:  {
  $35 = ((($0)) + 28|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = ((($36)) + 88|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = ((($38)) + 44|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = ((($40)) + 4|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = ((($42)) + 8|0);
  $44 = HEAP32[$43>>2]|0;
  (FUNCTION_TABLE_ii[$44 & 8191]($41)|0);
  $45 = ((($40)) + 24|0);
  $46 = HEAP8[$45>>0]|0;
  $47 = ($46<<24>>24)==(0);
  if ($47) {
   HEAP8[$45>>0] = 1;
   $48 = ((($40)) + 16|0);
   __THREW__ = 0;
   (invoke_ii(2504,($48|0))|0);
   $49 = __THREW__; __THREW__ = 0;
   $50 = $49&1;
   if ($50) {
    $51 = ___cxa_find_matching_catch_2()|0;
    $52 = tempRet0;
    $53 = HEAP32[$41>>2]|0;
    $54 = ((($53)) + 12|0);
    $55 = HEAP32[$54>>2]|0;
    __THREW__ = 0;
    (invoke_ii($55|0,($41|0))|0);
    $56 = __THREW__; __THREW__ = 0;
    $57 = $56&1;
    if ($57) {
     $58 = ___cxa_find_matching_catch_3(0|0)|0;
     $59 = tempRet0;
     ___clang_call_terminate($58);
     // unreachable;
    } else {
     ___resumeException($51|0);
     // unreachable;
    }
   }
  }
  $60 = HEAP32[$41>>2]|0;
  $61 = ((($60)) + 12|0);
  $62 = HEAP32[$61>>2]|0;
  (FUNCTION_TABLE_ii[$62 & 8191]($41)|0);
  break;
 }
 case 2:  {
  $63 = ((($0)) + 28|0);
  $64 = HEAP32[$63>>2]|0;
  $65 = ((($64)) + 92|0);
  $66 = HEAP32[$65>>2]|0;
  $67 = ((($66)) + 44|0);
  $68 = HEAP32[$67>>2]|0;
  $69 = ((($68)) + 4|0);
  $70 = HEAP32[$69>>2]|0;
  $71 = ((($70)) + 8|0);
  $72 = HEAP32[$71>>2]|0;
  (FUNCTION_TABLE_ii[$72 & 8191]($69)|0);
  $73 = ((($68)) + 24|0);
  $74 = HEAP8[$73>>0]|0;
  $75 = ($74<<24>>24)==(0);
  if ($75) {
   HEAP8[$73>>0] = 1;
   $76 = ((($68)) + 16|0);
   __THREW__ = 0;
   (invoke_ii(2504,($76|0))|0);
   $77 = __THREW__; __THREW__ = 0;
   $78 = $77&1;
   if ($78) {
    $79 = ___cxa_find_matching_catch_2()|0;
    $80 = tempRet0;
    $81 = HEAP32[$69>>2]|0;
    $82 = ((($81)) + 12|0);
    $83 = HEAP32[$82>>2]|0;
    __THREW__ = 0;
    (invoke_ii($83|0,($69|0))|0);
    $84 = __THREW__; __THREW__ = 0;
    $85 = $84&1;
    if ($85) {
     $86 = ___cxa_find_matching_catch_3(0|0)|0;
     $87 = tempRet0;
     ___clang_call_terminate($86);
     // unreachable;
    } else {
     ___resumeException($79|0);
     // unreachable;
    }
   }
  }
  $88 = HEAP32[$69>>2]|0;
  $89 = ((($88)) + 12|0);
  $90 = HEAP32[$89>>2]|0;
  (FUNCTION_TABLE_ii[$90 & 8191]($69)|0);
  break;
 }
 default: {
 }
 }
 (__ZN11OpenThreads6Thread4joinEv($1)|0);
 return 0;
}
function __ZN5osgDB13DatabasePager14DatabaseThread3runEv($0) {
 $0 = $0|0;
 var $$$i = 0, $$0$off0 = 0, $$023$i$i = 0, $$023$i$i113 = 0, $$026 = 0, $$027$off0 = 0, $$11 = 0, $$1151 = 0, $$130 = 0, $$139$off0$ph = 0, $$14 = 0, $$141 = 0, $$1454 = 0, $$15 = 0, $$1555 = 0, $$16 = 0, $$1656 = 0, $$18 = 0, $$1858 = 0, $$19 = 0;
 var $$1959 = 0, $$2$off0 = 0, $$23 = 0, $$2363 = 0, $$26 = 0, $$2666 = 0, $$27 = 0, $$2767 = 0, $$28 = 0, $$2868 = 0, $$29 = 0, $$2969 = 0, $$31 = 0, $$3171 = 0, $$33 = 0, $$3373 = 0, $$36 = 0, $$3676 = 0, $$37 = 0, $$3777 = 0;
 var $$38 = 0, $$3878 = 0, $$39 = 0, $$3979 = 0, $$4 = 0, $$444 = 0, $$6 = 0, $$646 = 0, $$7 = 0, $$747 = 0, $$8 = 0, $$848 = 0, $$not = 0, $$pr = 0, $$pr$i = 0, $$pr454 = 0, $$pr458 = 0, $$pre = 0, $$pre$phi1993Z2D = 0, $$pre$phiZ2D = 0;
 var $$pre1989 = 0, $$pre1990 = 0, $$pre1991 = 0, $$sink2$i$i = 0, $$sroa$0321$1 = 0, $$sroa$0321$2 = 0, $$sroa$0321$3 = 0, $$sroa$0321$4 = 0, $$sroa$0321$5 = 0, $$sroa$0321$6 = 0, $$sroa$0321$7 = 0, $$sroa$0321$8 = 0, $$sroa$0335$1 = 0, $$sroa$0335$2 = 0, $$sroa$0335$3 = 0, $$sroa$0335$4 = 0, $$sroa$0335$6 = 0, $$sroa$0335$8 = 0, $$sroa$0364$01997 = 0, $$sroa$0364$01998 = 0;
 var $$sroa$0364$1 = 0, $$sroa$0364$4 = 0, $$sroa$0364$6459 = 0, $$sroa$0364$6460 = 0, $$sroa$0364$7 = 0, $$sroa$0364$8 = 0, $$sroa$0381$0 = 0, $$sroa$0381$2437 = 0, $$sroa$0381$2438 = 0, $$sroa$0381$3479 = 0, $$sroa$0381$3480 = 0, $$sroa$0381$4 = 0, $$sroa$0381$5 = 0, $$sroa$0381$6 = 0, $$sroa$0390$1 = 0, $$sroa$0390$10 = 0, $$sroa$0390$2 = 0, $$sroa$0390$4 = 0, $$sroa$0390$5499 = 0, $$sroa$0390$5500 = 0;
 var $$sroa$0390$6 = 0, $$sroa$0390$7 = 0, $$sroa$0390$8 = 0, $$sroa$0415$4$ph = 0, $$sroa$0421$4 = 0, $$sroa$0421$6$ph = 0, $1 = 0, $10 = 0, $100 = 0, $1000 = 0, $1001 = 0, $1002 = 0, $1003 = 0, $1004 = 0, $1005 = 0, $1006 = 0, $1007 = 0, $1008 = 0, $1009 = 0, $101 = 0;
 var $1010 = 0, $1011 = 0, $1012 = 0, $1013 = 0, $1014 = 0, $1015 = 0, $1016 = 0, $1017 = 0, $1018 = 0, $1019 = 0, $102 = 0, $1020 = 0, $1021 = 0, $1022 = 0, $1023 = 0, $1024 = 0, $1025 = 0, $1026 = 0, $1027 = 0, $1028 = 0;
 var $1029 = 0, $103 = 0, $1030 = 0, $1031 = 0, $1032 = 0, $1033 = 0, $1034 = 0, $1035 = 0, $1036 = 0, $1037 = 0, $1038 = 0, $1039 = 0, $104 = 0, $1040 = 0, $1041 = 0, $1042 = 0, $1043 = 0, $1044 = 0, $1045 = 0, $1046 = 0;
 var $1047 = 0, $1048 = 0, $1049 = 0, $105 = 0, $1050 = 0, $1051 = 0, $1052 = 0, $1053 = 0, $1054 = 0, $1055 = 0, $1056 = 0, $1057 = 0, $1058 = 0.0, $1059 = 0, $106 = 0, $1060 = 0, $1061 = 0.0, $1062 = 0, $1063 = 0.0, $1064 = 0.0;
 var $1065 = 0.0, $1066 = 0, $1067 = 0.0, $1068 = 0.0, $1069 = 0.0, $107 = 0, $1070 = 0, $1071 = 0.0, $1072 = 0.0, $1073 = 0.0, $1074 = 0.0, $1075 = 0.0, $1076 = 0.0, $1077 = 0.0, $1078 = 0.0, $1079 = 0.0, $108 = 0, $1080 = 0.0, $1081 = 0.0, $1082 = 0.0;
 var $1083 = 0.0, $1084 = 0, $1085 = 0.0, $1086 = 0, $1087 = 0.0, $1088 = 0.0, $1089 = 0.0, $109 = 0, $1090 = 0.0, $1091 = 0.0, $1092 = 0.0, $1093 = 0.0, $1094 = 0.0, $1095 = 0.0, $1096 = 0.0, $1097 = 0.0, $1098 = 0.0, $1099 = 0.0, $11 = 0, $110 = 0;
 var $1100 = 0.0, $1101 = 0.0, $1102 = 0.0, $1103 = 0.0, $1104 = 0.0, $1105 = 0.0, $1106 = 0.0, $1107 = 0.0, $1108 = 0.0, $1109 = 0.0, $111 = 0, $1110 = 0, $1111 = 0, $1112 = 0, $1113 = 0, $1114 = 0, $1115 = 0.0, $1116 = 0, $1117 = 0, $1118 = 0.0;
 var $1119 = 0, $112 = 0, $1120 = 0.0, $1121 = 0.0, $1122 = 0.0, $1123 = 0, $1124 = 0.0, $1125 = 0.0, $1126 = 0.0, $1127 = 0, $1128 = 0.0, $1129 = 0.0, $113 = 0, $1130 = 0.0, $1131 = 0.0, $1132 = 0.0, $1133 = 0.0, $1134 = 0.0, $1135 = 0.0, $1136 = 0.0;
 var $1137 = 0.0, $1138 = 0.0, $1139 = 0.0, $114 = 0, $1140 = 0.0, $1141 = 0, $1142 = 0.0, $1143 = 0, $1144 = 0.0, $1145 = 0.0, $1146 = 0.0, $1147 = 0.0, $1148 = 0.0, $1149 = 0.0, $115 = 0, $1150 = 0.0, $1151 = 0.0, $1152 = 0.0, $1153 = 0.0, $1154 = 0.0;
 var $1155 = 0.0, $1156 = 0.0, $1157 = 0.0, $1158 = 0.0, $1159 = 0.0, $116 = 0, $1160 = 0.0, $1161 = 0.0, $1162 = 0.0, $1163 = 0.0, $1164 = 0.0, $1165 = 0.0, $1166 = 0.0, $1167 = 0, $1168 = 0, $1169 = 0, $117 = 0, $1170 = 0, $1171 = 0, $1172 = 0;
 var $1173 = 0, $1174 = 0, $1175 = 0, $1176 = 0, $1177 = 0, $1178 = 0, $1179 = 0, $118 = 0, $1180 = 0, $1181 = 0, $1182 = 0, $1183 = 0, $1184 = 0, $1185 = 0, $1186 = 0, $1187 = 0, $1188 = 0, $1189 = 0, $119 = 0, $1190 = 0;
 var $1191 = 0, $1192 = 0, $1193 = 0, $1194 = 0, $1195 = 0, $1196 = 0, $1197 = 0, $1198 = 0, $1199 = 0, $12 = 0, $120 = 0, $1200 = 0, $1201 = 0, $1202 = 0, $1203 = 0, $1204 = 0, $1205 = 0, $1206 = 0, $1207 = 0, $1208 = 0;
 var $1209 = 0, $121 = 0, $1210 = 0, $1211 = 0, $1212 = 0, $1213 = 0, $1214 = 0, $1215 = 0, $1216 = 0, $1217 = 0, $1218 = 0, $1219 = 0, $122 = 0, $1220 = 0, $1221 = 0, $1222 = 0, $1223 = 0, $1224 = 0, $1225 = 0, $1226 = 0;
 var $1227 = 0, $1228 = 0, $1229 = 0, $123 = 0, $1230 = 0, $1231 = 0, $1232 = 0, $1233 = 0, $1234 = 0, $1235 = 0, $1236 = 0, $1237 = 0, $1238 = 0, $1239 = 0, $124 = 0, $1240 = 0, $1241 = 0, $1242 = 0, $1243 = 0, $1244 = 0;
 var $1245 = 0, $1246 = 0, $1247 = 0, $1248 = 0, $1249 = 0, $125 = 0, $1250 = 0, $1251 = 0, $1252 = 0, $1253 = 0, $1254 = 0, $1255 = 0, $1256 = 0, $1257 = 0, $1258 = 0, $1259 = 0, $126 = 0, $1260 = 0, $1261 = 0, $1262 = 0;
 var $1263 = 0, $1264 = 0, $1265 = 0, $1266 = 0, $1267 = 0, $1268 = 0, $1269 = 0, $127 = 0, $1270 = 0, $1271 = 0, $1272 = 0, $1273 = 0, $1274 = 0, $1275 = 0, $1276 = 0, $1277 = 0, $1278 = 0, $1279 = 0, $128 = 0, $1280 = 0;
 var $1281 = 0, $1282 = 0, $1283 = 0, $1284 = 0, $1285 = 0, $1286 = 0, $1287 = 0, $1288 = 0, $1289 = 0, $129 = 0, $1290 = 0, $1291 = 0, $1292 = 0, $1293 = 0, $1294 = 0, $1295 = 0, $1296 = 0, $1297 = 0, $1298 = 0, $1299 = 0;
 var $13 = 0, $130 = 0, $1300 = 0, $1301 = 0, $1302 = 0, $1303 = 0, $1304 = 0, $1305 = 0, $1306 = 0, $1307 = 0, $1308 = 0, $1309 = 0, $131 = 0, $1310 = 0, $1311 = 0, $1312 = 0, $1313 = 0, $1314 = 0, $1315 = 0, $1316 = 0;
 var $1317 = 0, $1318 = 0, $1319 = 0, $132 = 0, $1320 = 0, $1321 = 0, $1322 = 0, $1323 = 0, $1324 = 0, $1325 = 0, $1326 = 0, $1327 = 0, $1328 = 0, $1329 = 0, $133 = 0, $1330 = 0, $1331 = 0, $1332 = 0, $1333 = 0, $1334 = 0;
 var $1335 = 0, $1336 = 0, $1337 = 0, $1338 = 0, $1339 = 0, $134 = 0, $1340 = 0, $1341 = 0, $1342 = 0, $1343 = 0, $1344 = 0, $1345 = 0, $1346 = 0, $1347 = 0, $1348 = 0, $1349 = 0, $135 = 0, $1350 = 0, $1351 = 0, $1352 = 0;
 var $1353 = 0, $1354 = 0, $1355 = 0, $1356 = 0, $1357 = 0, $1358 = 0, $1359 = 0, $136 = 0, $1360 = 0, $1361 = 0, $1362 = 0, $1363 = 0, $1364 = 0, $1365 = 0, $1366 = 0, $1367 = 0, $1368 = 0, $1369 = 0, $137 = 0, $1370 = 0;
 var $1371 = 0, $1372 = 0, $1373 = 0, $1374 = 0, $1375 = 0, $1376 = 0, $1377 = 0, $1378 = 0, $1379 = 0, $138 = 0, $1380 = 0, $1381 = 0, $1382 = 0, $1383 = 0, $1384 = 0, $1385 = 0, $1386 = 0, $1387 = 0, $1388 = 0, $1389 = 0;
 var $139 = 0, $1390 = 0, $1391 = 0, $1392 = 0, $1393 = 0, $1394 = 0, $1395 = 0, $1396 = 0, $1397 = 0, $1398 = 0, $1399 = 0, $14 = 0, $140 = 0, $1400 = 0, $1401 = 0, $1402 = 0, $1403 = 0, $1404 = 0, $1405 = 0, $1406 = 0;
 var $1407 = 0, $1408 = 0, $1409 = 0, $141 = 0, $1410 = 0, $1411 = 0, $1412 = 0, $1413 = 0, $1414 = 0, $1415 = 0, $1416 = 0, $1417 = 0, $1418 = 0, $1419 = 0, $142 = 0, $1420 = 0, $1421 = 0, $1422 = 0, $1423 = 0, $1424 = 0;
 var $1425 = 0, $1426 = 0, $1427 = 0, $1428 = 0, $1429 = 0, $143 = 0, $1430 = 0, $1431 = 0, $1432 = 0, $1433 = 0, $1434 = 0, $1435 = 0, $1436 = 0, $1437 = 0, $1438 = 0, $1439 = 0, $144 = 0, $1440 = 0, $1441 = 0, $1442 = 0;
 var $1443 = 0, $1444 = 0, $1445 = 0, $1446 = 0, $1447 = 0, $1448 = 0, $1449 = 0, $145 = 0, $1450 = 0, $1451 = 0, $1452 = 0, $1453 = 0, $1454 = 0, $1455 = 0, $1456 = 0, $1457 = 0, $1458 = 0, $1459 = 0, $146 = 0, $1460 = 0;
 var $1461 = 0, $1462 = 0, $1463 = 0, $1464 = 0, $1465 = 0, $1466 = 0, $1467 = 0, $1468 = 0, $1469 = 0, $147 = 0, $1470 = 0, $1471 = 0, $1472 = 0, $1473 = 0, $1474 = 0, $1475 = 0, $1476 = 0, $1477 = 0, $1478 = 0, $1479 = 0;
 var $148 = 0, $1480 = 0, $1481 = 0, $1482 = 0, $1483 = 0, $1484 = 0, $1485 = 0, $1486 = 0, $1487 = 0, $1488 = 0, $1489 = 0, $149 = 0, $1490 = 0, $1491 = 0, $1492 = 0, $1493 = 0, $1494 = 0, $1495 = 0, $1496 = 0, $1497 = 0;
 var $1498 = 0, $1499 = 0, $15 = 0, $150 = 0, $1500 = 0, $1501 = 0, $1502 = 0, $1503 = 0, $1504 = 0, $1505 = 0, $1506 = 0, $1507 = 0, $1508 = 0, $1509 = 0, $151 = 0, $1510 = 0, $1511 = 0, $1512 = 0, $1513 = 0, $1514 = 0;
 var $1515 = 0, $1516 = 0, $1517 = 0, $1518 = 0, $1519 = 0, $152 = 0, $1520 = 0, $1521 = 0, $1522 = 0, $1523 = 0, $1524 = 0, $1525 = 0, $1526 = 0, $1527 = 0, $1528 = 0, $1529 = 0, $153 = 0, $1530 = 0, $1531 = 0, $1532 = 0;
 var $1533 = 0, $1534 = 0, $1535 = 0, $1536 = 0, $1537 = 0, $1538 = 0, $1539 = 0, $154 = 0, $1540 = 0, $1541 = 0, $1542 = 0, $1543 = 0, $1544 = 0, $1545 = 0, $1546 = 0, $1547 = 0, $1548 = 0, $1549 = 0, $155 = 0, $1550 = 0;
 var $1551 = 0, $1552 = 0, $1553 = 0, $1554 = 0, $1555 = 0, $1556 = 0, $1557 = 0, $1558 = 0, $1559 = 0, $156 = 0, $1560 = 0, $1561 = 0, $1562 = 0, $1563 = 0, $1564 = 0, $1565 = 0, $1566 = 0, $1567 = 0, $1568 = 0, $1569 = 0;
 var $157 = 0, $1570 = 0, $1571 = 0, $1572 = 0, $1573 = 0, $1574 = 0, $1575 = 0, $1576 = 0, $1577 = 0, $1578 = 0, $1579 = 0, $158 = 0, $1580 = 0, $1581 = 0, $1582 = 0, $1583 = 0, $1584 = 0, $1585 = 0, $1586 = 0, $1587 = 0;
 var $1588 = 0, $1589 = 0, $159 = 0, $1590 = 0, $1591 = 0, $1592 = 0, $1593 = 0, $1594 = 0, $1595 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0;
 var $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0;
 var $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0;
 var $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0;
 var $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0;
 var $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0;
 var $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0;
 var $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0;
 var $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0;
 var $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0;
 var $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0;
 var $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0;
 var $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0;
 var $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0;
 var $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0;
 var $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0;
 var $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0;
 var $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0;
 var $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0;
 var $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0;
 var $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0;
 var $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0;
 var $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0;
 var $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0;
 var $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0;
 var $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0;
 var $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0;
 var $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0;
 var $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0;
 var $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0;
 var $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0;
 var $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0;
 var $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0;
 var $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0;
 var $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0;
 var $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = 0, $834 = 0, $835 = 0;
 var $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0, $850 = 0, $851 = 0, $852 = 0, $853 = 0;
 var $854 = 0, $855 = 0, $856 = 0, $857 = 0, $858 = 0, $859 = 0, $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0, $869 = 0, $87 = 0, $870 = 0, $871 = 0;
 var $872 = 0, $873 = 0, $874 = 0, $875 = 0, $876 = 0, $877 = 0, $878 = 0, $879 = 0, $88 = 0, $880 = 0, $881 = 0, $882 = 0, $883 = 0, $884 = 0, $885 = 0, $886 = 0, $887 = 0, $888 = 0, $889 = 0, $89 = 0;
 var $890 = 0, $891 = 0, $892 = 0, $893 = 0, $894 = 0, $895 = 0, $896 = 0, $897 = 0, $898 = 0, $899 = 0, $9 = 0, $90 = 0, $900 = 0, $901 = 0, $902 = 0, $903 = 0, $904 = 0, $905 = 0, $906 = 0, $907 = 0;
 var $908 = 0, $909 = 0, $91 = 0, $910 = 0, $911 = 0, $912 = 0, $913 = 0, $914 = 0, $915 = 0, $916 = 0, $917 = 0, $918 = 0, $919 = 0, $92 = 0, $920 = 0, $921 = 0, $922 = 0, $923 = 0, $924 = 0, $925 = 0;
 var $926 = 0, $927 = 0, $928 = 0, $929 = 0, $93 = 0, $930 = 0, $931 = 0, $932 = 0, $933 = 0, $934 = 0, $935 = 0, $936 = 0, $937 = 0, $938 = 0, $939 = 0, $94 = 0, $940 = 0, $941 = 0, $942 = 0, $943 = 0;
 var $944 = 0, $945 = 0, $946 = 0, $947 = 0, $948 = 0, $949 = 0, $95 = 0, $950 = 0, $951 = 0, $952 = 0, $953 = 0, $954 = 0, $955 = 0, $956 = 0, $957 = 0, $958 = 0, $959 = 0, $96 = 0, $960 = 0, $961 = 0;
 var $962 = 0, $963 = 0, $964 = 0, $965 = 0, $966 = 0, $967 = 0, $968 = 0, $969 = 0, $97 = 0, $970 = 0, $971 = 0, $972 = 0, $973 = 0, $974 = 0, $975 = 0, $976 = 0, $977 = 0, $978 = 0, $979 = 0, $98 = 0;
 var $980 = 0, $981 = 0, $982 = 0, $983 = 0, $984 = 0, $985 = 0, $986 = 0, $987 = 0, $988 = 0, $989 = 0, $99 = 0, $990 = 0, $991 = 0, $992 = 0, $993 = 0, $994 = 0, $995 = 0, $996 = 0, $997 = 0, $998 = 0;
 var $999 = 0, $brmerge = 0, $cond = 0, $eh$lpad$body$index3Z2D = 0, $eh$lpad$body$indexZ2D = 0, $eh$lpad$body149$indexZ2D = 0, $eh$lpad$body225$index26Z2D = 0, $eh$lpad$body225$indexZ2D = 0, $eh$lpad$body241$index10Z2D = 0, $eh$lpad$body241$indexZ2D = 0, $eh$lpad$body270$index16Z2D = 0, $eh$lpad$body270$indexZ2D = 0, $eh$lpad$body288$index21Z2D = 0, $eh$lpad$body288$indexZ2D = 0, $or$cond = 0, $or$cond520 = 0, $or$cond521 = 0, dest = 0, label = 0, sp = 0;
 var stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 352|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(352|0);
 $1 = sp + 328|0;
 $2 = sp + 312|0;
 $3 = sp + 308|0;
 $4 = sp + 304|0;
 $5 = sp + 300|0;
 $6 = sp + 296|0;
 $7 = sp + 292|0;
 $8 = sp + 288|0;
 $9 = sp;
 $10 = sp + 284|0;
 $11 = sp + 272|0;
 $12 = sp + 264|0;
 $13 = sp + 256|0;
 $14 = sp + 252|0;
 $15 = sp + 240|0;
 $16 = sp + 220|0;
 $17 = sp + 208|0;
 $18 = sp + 192|0;
 $19 = sp + 12|0;
 $20 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
 do {
  if ($20) {
   $21 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
   $22 = ((($0)) + 36|0);
   $23 = ((($22)) + 11|0);
   $24 = HEAP8[$23>>0]|0;
   $25 = ($24<<24>>24)<(0);
   $26 = HEAP32[$22>>2]|0;
   $27 = $25 ? $26 : $22;
   $28 = ((($0)) + 40|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = $24&255;
   $31 = $25 ? $29 : $30;
   $32 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($21,$27,$31)|0);
   $33 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($32,162818,36)|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = ((($34)) + -12|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($33) + ($36)|0);
   __ZNKSt3__28ios_base6getlocEv($8,$37);
   __THREW__ = 0;
   $38 = (invoke_iii(3255,($8|0),(215188|0))|0);
   $39 = __THREW__; __THREW__ = 0;
   $40 = $39&1;
   if (!($40)) {
    $41 = HEAP32[$38>>2]|0;
    $42 = ((($41)) + 28|0);
    $43 = HEAP32[$42>>2]|0;
    __THREW__ = 0;
    $44 = (invoke_iii($43|0,($38|0),10)|0);
    $45 = __THREW__; __THREW__ = 0;
    $46 = $45&1;
    if (!($46)) {
     __ZNSt3__26localeD2Ev($8);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($33,$44)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($33)|0);
     break;
    }
   }
   $47 = ___cxa_find_matching_catch_2()|0;
   $48 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($8|0));
   $49 = __THREW__; __THREW__ = 0;
   $50 = $49&1;
   if ($50) {
    $51 = ___cxa_find_matching_catch_3(0|0)|0;
    $52 = tempRet0;
    ___clang_call_terminate($51);
    // unreachable;
   } else {
    ___resumeException($47|0);
    // unreachable;
   }
  }
 } while(0);
 $53 = ((($0)) + 32|0);
 $54 = HEAP32[$53>>2]|0;
 switch ($54|0) {
 case 0:  {
  $55 = ((($0)) + 28|0);
  $56 = HEAP32[$55>>2]|0;
  $57 = ((($56)) + 88|0);
  $58 = HEAP32[$57>>2]|0;
  $59 = ($58|0)==(0|0);
  if ($59) {
   $$pre$phiZ2D = $55;$$sroa$0415$4$ph = 0;$$sroa$0421$6$ph = 0;
  } else {
   $60 = ((($58)) + 8|0);
   $61 = HEAP32[$60>>2]|0;HEAP32[$60>>2] = (($61+1)|0);
   $$pre$phiZ2D = $55;$$sroa$0415$4$ph = 0;$$sroa$0421$6$ph = $58;
  }
  break;
 }
 case 1:  {
  $64 = ((($0)) + 28|0);
  $65 = HEAP32[$64>>2]|0;
  $66 = ((($65)) + 88|0);
  $67 = HEAP32[$66>>2]|0;
  $68 = ($67|0)==(0|0);
  if ($68) {
   $$sroa$0421$4 = 0;$72 = $65;
  } else {
   $69 = ((($67)) + 8|0);
   $70 = HEAP32[$69>>2]|0;HEAP32[$69>>2] = (($70+1)|0);
   $$pre = HEAP32[$64>>2]|0;
   $$sroa$0421$4 = $67;$72 = $$pre;
  }
  $71 = ((($72)) + 92|0);
  $73 = HEAP32[$71>>2]|0;
  $74 = ($73|0)==(0|0);
  if ($74) {
   $$pre$phiZ2D = $64;$$sroa$0415$4$ph = 0;$$sroa$0421$6$ph = $$sroa$0421$4;
  } else {
   $75 = ((($73)) + 8|0);
   $76 = HEAP32[$75>>2]|0;HEAP32[$75>>2] = (($76+1)|0);
   $$pre$phiZ2D = $64;$$sroa$0415$4$ph = $73;$$sroa$0421$6$ph = $$sroa$0421$4;
  }
  break;
 }
 case 2:  {
  $77 = ((($0)) + 28|0);
  $78 = HEAP32[$77>>2]|0;
  $79 = ((($78)) + 92|0);
  $80 = HEAP32[$79>>2]|0;
  $81 = ($80|0)==(0|0);
  if ($81) {
   $$pre$phiZ2D = $77;$$sroa$0415$4$ph = 0;$$sroa$0421$6$ph = 0;
  } else {
   $82 = ((($80)) + 8|0);
   $83 = HEAP32[$82>>2]|0;HEAP32[$82>>2] = (($83+1)|0);
   $$pre$phiZ2D = $77;$$sroa$0415$4$ph = 0;$$sroa$0421$6$ph = $80;
  }
  break;
 }
 default: {
  $$pre1991 = ((($0)) + 28|0);
  $$pre$phiZ2D = $$pre1991;$$sroa$0415$4$ph = 0;$$sroa$0421$6$ph = 0;
 }
 }
 $84 = ((($0)) + 24|0);
 $85 = ((($$sroa$0421$6$ph)) + 44|0);
 $86 = ((($0)) + 20|0);
 $87 = ((($0)) + 36|0);
 $88 = ((($87)) + 11|0);
 $89 = ((($0)) + 40|0);
 $90 = ((($$sroa$0421$6$ph)) + 28|0);
 $91 = ((($$sroa$0421$6$ph)) + 24|0);
 $92 = ((($$sroa$0421$6$ph)) + 80|0);
 $93 = ((($11)) + 11|0);
 $94 = ((($0)) + 12|0);
 $95 = ((($11)) + 4|0);
 $96 = ((($$sroa$0415$4$ph)) + 28|0);
 $97 = ((($18)) + 4|0);
 $98 = ((($97)) + 11|0);
 $99 = ((($16)) + 16|0);
 $100 = ((($16)) + 4|0);
 $101 = ((($100)) + 11|0);
 $102 = ((($2)) + 12|0);
 $103 = ((($2)) + 4|0);
 $104 = ((($2)) + 8|0);
 $105 = ((($1)) + 12|0);
 $106 = ((($1)) + 4|0);
 $107 = ((($1)) + 8|0);
 $108 = ((($17)) + 11|0);
 $109 = ((($17)) + 4|0);
 $110 = ((($15)) + 11|0);
 $111 = ((($12)) + 4|0);
 $112 = ((($9)) + 4|0);
 $113 = ((($9)) + 8|0);
 $114 = ((($$sroa$0421$6$ph)) + 72|0);
 $115 = ((($$sroa$0421$6$ph)) + 76|0);
 $$027$off0 = 1;
 L23: while(1) {
  HEAP8[$84>>0] = 0;
  $116 = HEAP32[$85>>2]|0;
  $117 = ((($116)) + 4|0);
  $118 = HEAP32[$117>>2]|0;
  $119 = ((($118)) + 8|0);
  $120 = HEAP32[$119>>2]|0;
  __THREW__ = 0;
  (invoke_ii($120|0,($117|0))|0);
  $121 = __THREW__; __THREW__ = 0;
  $122 = $121&1;
  if ($122) {
   label = 12;
   break;
  }
  $123 = ((($116)) + 24|0);
  $124 = HEAP8[$123>>0]|0;
  $125 = ($124<<24>>24)==(0);
  if ($125) {
   $126 = ((($116)) + 16|0);
   __THREW__ = 0;
   (invoke_iii(2501,($126|0),($117|0))|0);
   $127 = __THREW__; __THREW__ = 0;
   $128 = $127&1;
   if ($128) {
    label = 24;
    break;
   }
  }
  $138 = HEAP32[$117>>2]|0;
  $139 = ((($138)) + 12|0);
  $140 = HEAP32[$139>>2]|0;
  __THREW__ = 0;
  (invoke_ii($140|0,($117|0))|0);
  $141 = __THREW__; __THREW__ = 0;
  $142 = $141&1;
  if ($142) {
   label = 12;
   break;
  }
  /* fence */;
  $143 = HEAP32[$86>>2]|0;
  $144 = ($143|0)==(0);
  if (!($144)) {
   label = 477;
   break;
  }
  HEAP8[$84>>0] = 1;
  __THREW__ = 0;
  $145 = (invoke_ii(3265,4)|0);
  $146 = __THREW__; __THREW__ = 0;
  $147 = $146&1;
  if ($147) {
   label = 12;
   break;
  }
  if ($145) {
   __THREW__ = 0;
   $148 = (invoke_ii(3266,4)|0);
   $149 = __THREW__; __THREW__ = 0;
   $150 = $149&1;
   if ($150) {
    label = 12;
    break;
   }
   $151 = HEAP8[$88>>0]|0;
   $152 = ($151<<24>>24)<(0);
   $153 = HEAP32[$87>>2]|0;
   $154 = $152 ? $153 : $87;
   $155 = HEAP32[$89>>2]|0;
   $156 = $151&255;
   $157 = $152 ? $155 : $156;
   __THREW__ = 0;
   $158 = (invoke_iiii(3267,($148|0),($154|0),($157|0))|0);
   $159 = __THREW__; __THREW__ = 0;
   $160 = $159&1;
   if ($160) {
    label = 12;
    break;
   }
   __THREW__ = 0;
   $161 = (invoke_iiii(3267,($158|0),(162855|0),18)|0);
   $162 = __THREW__; __THREW__ = 0;
   $163 = $162&1;
   if ($163) {
    label = 12;
    break;
   }
   $164 = HEAP32[$90>>2]|0;
   $165 = ((($164)) + 8|0);
   $166 = HEAP32[$165>>2]|0;
   __THREW__ = 0;
   (invoke_ii($166|0,($90|0))|0);
   $167 = __THREW__; __THREW__ = 0;
   $168 = $167&1;
   if ($168) {
    label = 12;
    break;
   }
   $169 = HEAP32[$91>>2]|0;
   $170 = HEAP32[$90>>2]|0;
   $171 = ((($170)) + 12|0);
   $172 = HEAP32[$171>>2]|0;
   __THREW__ = 0;
   (invoke_ii($172|0,($90|0))|0);
   $173 = __THREW__; __THREW__ = 0;
   $174 = $173&1;
   if ($174) {
    label = 12;
    break;
   }
   __THREW__ = 0;
   $175 = (invoke_iii(3417,($161|0),($169|0))|0);
   $176 = __THREW__; __THREW__ = 0;
   $177 = $176&1;
   if ($177) {
    label = 12;
    break;
   }
   __THREW__ = 0;
   $178 = (invoke_iiii(3267,($175|0),(162874|0),13)|0);
   $179 = __THREW__; __THREW__ = 0;
   $180 = $179&1;
   if ($180) {
    label = 12;
    break;
   }
   $181 = HEAP32[$92>>2]|0;
   __THREW__ = 0;
   $182 = (invoke_iii(3417,($178|0),($181|0))|0);
   $183 = __THREW__; __THREW__ = 0;
   $184 = $183&1;
   if ($184) {
    label = 12;
    break;
   }
   $185 = HEAP32[$182>>2]|0;
   $186 = ((($185)) + -12|0);
   $187 = HEAP32[$186>>2]|0;
   $188 = (($182) + ($187)|0);
   __THREW__ = 0;
   invoke_vii(3257,($7|0),($188|0));
   $189 = __THREW__; __THREW__ = 0;
   $190 = $189&1;
   if ($190) {
    label = 12;
    break;
   }
   __THREW__ = 0;
   $191 = (invoke_iii(3255,($7|0),(215188|0))|0);
   $192 = __THREW__; __THREW__ = 0;
   $193 = $192&1;
   if ($193) {
    label = 41;
    break;
   }
   $194 = HEAP32[$191>>2]|0;
   $195 = ((($194)) + 28|0);
   $196 = HEAP32[$195>>2]|0;
   __THREW__ = 0;
   $197 = (invoke_iii($196|0,($191|0),10)|0);
   $198 = __THREW__; __THREW__ = 0;
   $199 = $198&1;
   if ($199) {
    label = 41;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3263,($7|0));
   $206 = __THREW__; __THREW__ = 0;
   $207 = $206&1;
   if ($207) {
    label = 12;
    break;
   }
   __THREW__ = 0;
   (invoke_iii(3268,($182|0),($197|0))|0);
   $208 = __THREW__; __THREW__ = 0;
   $209 = $208&1;
   if ($209) {
    label = 12;
    break;
   }
   __THREW__ = 0;
   (invoke_ii(3269,($182|0))|0);
   $210 = __THREW__; __THREW__ = 0;
   $211 = $210&1;
   if ($211) {
    label = 12;
    break;
   }
  }
  $212 = HEAP32[$$pre$phiZ2D>>2]|0;
  $213 = ((($212)) + 116|0);
  $214 = HEAP8[$213>>0]|0;
  $215 = ($214<<24>>24)==(0);
  if (!($215)) {
   HEAP32[$9>>2] = $9;
   HEAP32[$112>>2] = $9;
   HEAP32[$113>>2] = 0;
   $216 = HEAP32[$90>>2]|0;
   $217 = ((($216)) + 8|0);
   $218 = HEAP32[$217>>2]|0;
   __THREW__ = 0;
   (invoke_ii($218|0,($90|0))|0);
   $219 = __THREW__; __THREW__ = 0;
   $220 = $219&1;
   if ($220) {
    label = 54;
    break;
   }
   $221 = HEAP32[$92>>2]|0;
   $222 = ($221|0)==(0);
   if (!($222)) {
    $223 = HEAP32[$113>>2]|0;
    HEAP32[$113>>2] = $221;
    HEAP32[$92>>2] = $223;
    $224 = $9;
    $225 = $224;
    $226 = HEAP32[$225>>2]|0;
    $227 = (($224) + 4)|0;
    $228 = $227;
    $229 = HEAP32[$228>>2]|0;
    $230 = $114;
    $231 = $230;
    $232 = HEAP32[$231>>2]|0;
    $233 = (($230) + 4)|0;
    $234 = $233;
    $235 = HEAP32[$234>>2]|0;
    $236 = $9;
    $237 = $236;
    HEAP32[$237>>2] = $232;
    $238 = (($236) + 4)|0;
    $239 = $238;
    HEAP32[$239>>2] = $235;
    $240 = $114;
    $241 = $240;
    HEAP32[$241>>2] = $226;
    $242 = (($240) + 4)|0;
    $243 = $242;
    HEAP32[$243>>2] = $229;
    $244 = $235;
    HEAP32[$244>>2] = $9;
    $245 = HEAP32[$9>>2]|0;
    $246 = ((($245)) + 4|0);
    HEAP32[$246>>2] = $9;
    $247 = ($223|0)==(0);
    if ($247) {
     HEAP32[$114>>2] = $114;
     $$sink2$i$i = $114;
    } else {
     $248 = HEAP32[$115>>2]|0;
     HEAP32[$248>>2] = $114;
     $249 = HEAP32[$114>>2]|0;
     $$sink2$i$i = $249;
    }
    $250 = ((($$sink2$i$i)) + 4|0);
    HEAP32[$250>>2] = $114;
    $251 = HEAP32[$$sroa$0421$6$ph>>2]|0;
    $252 = ((($251)) + 12|0);
    $253 = HEAP32[$252>>2]|0;
    __THREW__ = 0;
    invoke_vi($253|0,($$sroa$0421$6$ph|0));
    $254 = __THREW__; __THREW__ = 0;
    $255 = $254&1;
    if ($255) {
     label = 55;
     break;
    }
   }
   $265 = HEAP32[$90>>2]|0;
   $266 = ((($265)) + 12|0);
   $267 = HEAP32[$266>>2]|0;
   __THREW__ = 0;
   (invoke_ii($267|0,($90|0))|0);
   $268 = __THREW__; __THREW__ = 0;
   $269 = $268&1;
   if ($269) {
    label = 65;
    break;
   }
   $270 = HEAP32[$113>>2]|0;
   $271 = ($270|0)==(0);
   if (!($271)) {
    $272 = HEAP32[$112>>2]|0;
    $273 = HEAP32[$9>>2]|0;
    $274 = ((($273)) + 4|0);
    $275 = HEAP32[$274>>2]|0;
    $276 = HEAP32[$272>>2]|0;
    $277 = ((($276)) + 4|0);
    HEAP32[$277>>2] = $275;
    $278 = HEAP32[$274>>2]|0;
    HEAP32[$278>>2] = $276;
    HEAP32[$113>>2] = 0;
    $279 = ($272|0)==($9|0);
    if (!($279)) {
     $$023$i$i = $272;
     while(1) {
      $280 = ((($$023$i$i)) + 4|0);
      $281 = HEAP32[$280>>2]|0;
      $282 = ((($$023$i$i)) + 8|0);
      $283 = HEAP32[$282>>2]|0;
      $284 = ($283|0)==(0|0);
      if (!($284)) {
       $285 = ((($283)) + 8|0);
       $286 = HEAP32[$285>>2]|0;HEAP32[$285>>2] = (($286-1)|0);
       $287 = ($286|0)==(1);
       if ($287) {
        __THREW__ = 0;
        invoke_viii(3262,($283|0),1,1);
        $288 = __THREW__; __THREW__ = 0;
        $289 = $288&1;
        if ($289) {
         label = 63;
         break L23;
        }
       }
      }
      __ZdlPv($$023$i$i);
      $290 = ($281|0)==($9|0);
      if ($290) {
       break;
      } else {
       $$023$i$i = $281;
      }
     }
    }
   }
  }
  HEAP32[$10>>2] = 0;
  __THREW__ = 0;
  invoke_vii(4121,($$sroa$0421$6$ph|0),($10|0));
  $318 = __THREW__; __THREW__ = 0;
  $319 = $318&1;
  if ($319) {
   label = 113;
   break;
  }
  __THREW__ = 0;
  $320 = (invoke_ii(3482,0)|0);
  $321 = __THREW__; __THREW__ = 0;
  $322 = $321&1;
  if ($322) {
   label = 114;
   break;
  }
  $323 = ((($320)) + 20|0);
  $324 = HEAP32[$323>>2]|0;
  $325 = ($324|0)==(0|0);
  if (!($325)) {
   $326 = ((($324)) + 8|0);
   $327 = HEAP32[$326>>2]|0;HEAP32[$326>>2] = (($327+1)|0);
  }
  __THREW__ = 0;
  $328 = (invoke_ii(3482,0)|0);
  $329 = __THREW__; __THREW__ = 0;
  $330 = $329&1;
  if ($330) {
   label = 115;
   break;
  }
  $331 = ((($328)) + 56|0);
  $332 = HEAP32[$331>>2]|0;
  $333 = ($332|0)==(0|0);
  if (!($333)) {
   $334 = HEAP32[$332>>2]|0;
   $335 = ((($334)) + -12|0);
   $336 = HEAP32[$335>>2]|0;
   $337 = (($332) + ($336)|0);
   $338 = ((($337)) + 8|0);
   $339 = HEAP32[$338>>2]|0;HEAP32[$338>>2] = (($339+1)|0);
  }
  ;HEAP32[$11>>2]=0|0;HEAP32[$11+4>>2]=0|0;HEAP32[$11+8>>2]=0|0;
  $340 = HEAP32[$10>>2]|0;
  $341 = ($340|0)==(0|0);
  L78: do {
   if ($341) {
    $$sroa$0364$6460 = 0;$$sroa$0381$3480 = $332;$$sroa$0390$5500 = $324;
    label = 457;
   } else {
    $342 = HEAP32[$$pre$phiZ2D>>2]|0;
    $343 = ((($342)) + 24|0);
    $344 = HEAP32[$343>>2]|0;
    $345 = ((($344)) + 8|0);
    $346 = HEAP32[$345>>2]|0;
    __THREW__ = 0;
    (invoke_ii($346|0,($343|0))|0);
    $347 = __THREW__; __THREW__ = 0;
    $348 = $347&1;
    if ($348) {
     $$sroa$0364$1 = 0;$$sroa$0381$0 = $332;$$sroa$0390$1 = $324;
     label = 116;
     break L23;
    }
    $349 = HEAP32[$10>>2]|0;
    $350 = ((($349)) + 84|0);
    $351 = HEAP32[$350>>2]|0;
    $352 = ($351|0)==(0|0);
    if ($352) {
     __THREW__ = 0;
     $359 = (invoke_ii(3276,148)|0);
     $360 = __THREW__; __THREW__ = 0;
     $361 = $360&1;
     if ($361) {
      label = 119;
      break L23;
     }
     __THREW__ = 0;
     invoke_vii(3435,($359|0),1);
     $362 = __THREW__; __THREW__ = 0;
     $363 = $362&1;
     if ($363) {
      label = 118;
      break L23;
     }
     $367 = ((($359)) + 12|0);
     ;HEAP32[$367>>2]=0|0;HEAP32[$367+4>>2]=0|0;HEAP32[$367+8>>2]=0|0;
     $368 = ((($359)) + 24|0);
     HEAP32[$368>>2] = 2;
     $369 = ((($359)) + 28|0);
     HEAP32[$369>>2] = 0;
     HEAP32[$359>>2] = (37212);
     $370 = ((($359)) + 32|0);
     $371 = ((($359)) + 68|0);
     dest=$370; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
     HEAP32[$371>>2] = 8;
     $372 = ((($359)) + 72|0);
     $373 = ((($359)) + 92|0);
     HEAP32[$373>>2] = 0;
     $374 = ((($359)) + 96|0);
     HEAP32[$374>>2] = 0;
     $375 = ((($359)) + 88|0);
     ;HEAP32[$372>>2]=0|0;HEAP32[$372+4>>2]=0|0;HEAP32[$372+8>>2]=0|0;HEAP32[$372+12>>2]=0|0;
     HEAP32[$375>>2] = $373;
     $376 = ((($359)) + 104|0);
     HEAP32[$376>>2] = 0;
     $377 = ((($359)) + 108|0);
     HEAP32[$377>>2] = 0;
     $378 = ((($359)) + 100|0);
     HEAP32[$378>>2] = $376;
     $379 = ((($359)) + 112|0);
     dest=$379; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
     $380 = ((($359)) + 8|0);
     $381 = HEAP32[$380>>2]|0;HEAP32[$380>>2] = (($381+1)|0);
     $$sroa$0364$01997 = $359;
    } else {
     HEAP32[$12>>2] = (58136);
     HEAP32[$111>>2] = 0;
     $353 = HEAP32[$351>>2]|0;
     $354 = ((($353)) + 16|0);
     $355 = HEAP32[$354>>2]|0;
     __THREW__ = 0;
     $356 = (invoke_iii($355|0,($351|0),($12|0))|0);
     $357 = __THREW__; __THREW__ = 0;
     $358 = $357&1;
     if ($358) {
      label = 120;
      break L23;
     }
     $364 = ($356|0)==(0|0);
     if ($364) {
      $$sroa$0364$01998 = 0;
     } else {
      $365 = ((($356)) + 8|0);
      $366 = HEAP32[$365>>2]|0;HEAP32[$365>>2] = (($366+1)|0);
      $$sroa$0364$01998 = $356;
     }
     $$sroa$0364$01997 = $$sroa$0364$01998;
    }
    $382 = HEAP32[$10>>2]|0;
    $383 = ((($382)) + 64|0);
    $384 = ((($$sroa$0364$01997)) + 132|0);
    $385 = ($384|0)==($383|0);
    if ($385) {
     $402 = $382;
    } else {
     $386 = HEAP32[$384>>2]|0;
     $387 = HEAP32[$383>>2]|0;
     $388 = ($386|0)==($387|0);
     do {
      if (!($388)) {
       HEAP32[$384>>2] = $387;
       $389 = ($387|0)==(0|0);
       if (!($389)) {
        $390 = ((($387)) + 8|0);
        $391 = HEAP32[$390>>2]|0;HEAP32[$390>>2] = (($391+1)|0);
       }
       $392 = ($386|0)==(0|0);
       if ($392) {
        break;
       }
       $393 = ((($386)) + 8|0);
       $394 = HEAP32[$393>>2]|0;HEAP32[$393>>2] = (($394-1)|0);
       $395 = ($394|0)==(1);
       if (!($395)) {
        break;
       }
       __THREW__ = 0;
       invoke_viii(3262,($386|0),1,1);
       $396 = __THREW__; __THREW__ = 0;
       $397 = $396&1;
       if ($397) {
        label = 117;
        break L23;
       }
      }
     } while(0);
     $398 = ((($382)) + 68|0);
     $399 = HEAP32[$398>>2]|0;
     $400 = ((($$sroa$0364$01997)) + 136|0);
     HEAP32[$400>>2] = $399;
     $$pre1989 = HEAP32[$10>>2]|0;
     $402 = $$pre1989;
    }
    $401 = ((($402)) + 72|0);
    $403 = ((($$sroa$0364$01997)) + 140|0);
    $404 = ($403|0)==($401|0);
    if ($404) {
     $421 = $402;
    } else {
     $405 = HEAP32[$403>>2]|0;
     $406 = HEAP32[$401>>2]|0;
     $407 = ($405|0)==($406|0);
     do {
      if (!($407)) {
       HEAP32[$403>>2] = $406;
       $408 = ($406|0)==(0|0);
       if (!($408)) {
        $409 = ((($406)) + 8|0);
        $410 = HEAP32[$409>>2]|0;HEAP32[$409>>2] = (($410+1)|0);
       }
       $411 = ($405|0)==(0|0);
       if ($411) {
        break;
       }
       $412 = ((($405)) + 8|0);
       $413 = HEAP32[$412>>2]|0;HEAP32[$412>>2] = (($413-1)|0);
       $414 = ($413|0)==(1);
       if (!($414)) {
        break;
       }
       __THREW__ = 0;
       invoke_viii(3262,($405|0),1,1);
       $415 = __THREW__; __THREW__ = 0;
       $416 = $415&1;
       if ($416) {
        label = 117;
        break L23;
       }
      }
     } while(0);
     $417 = ((($402)) + 76|0);
     $418 = HEAP32[$417>>2]|0;
     $419 = ((($$sroa$0364$01997)) + 144|0);
     HEAP32[$419>>2] = $418;
     $$pre1990 = HEAP32[$10>>2]|0;
     $421 = $$pre1990;
    }
    $420 = ((($421)) + 16|0);
    __THREW__ = 0;
    (invoke_iii(3477,($11|0),($420|0))|0);
    $422 = __THREW__; __THREW__ = 0;
    $423 = $422&1;
    if ($423) {
     label = 117;
     break L23;
    }
    $424 = HEAP32[$10>>2]|0;
    $425 = ((($424)) + 44|0);
    $426 = HEAP32[$425>>2]|0;
    $427 = HEAP32[$343>>2]|0;
    $428 = ((($427)) + 12|0);
    $429 = HEAP32[$428>>2]|0;
    __THREW__ = 0;
    (invoke_ii($429|0,($343|0))|0);
    $430 = __THREW__; __THREW__ = 0;
    $431 = $430&1;
    if ($431) {
     label = 121;
     break L23;
    }
    $432 = ((($$sroa$0364$01997)) + 128|0);
    $433 = HEAP32[$432>>2]|0;
    $434 = ($433|0)==(0|0);
    $435 = ($324|0)==($433|0);
    $or$cond = $434 | $435;
    do {
     if ($or$cond) {
      $$sroa$0390$2 = $324;
     } else {
      $436 = ((($433)) + 8|0);
      $437 = HEAP32[$436>>2]|0;HEAP32[$436>>2] = (($437+1)|0);
      if ($325) {
       $$sroa$0390$2 = $433;
       break;
      }
      $438 = ((($324)) + 8|0);
      $439 = HEAP32[$438>>2]|0;HEAP32[$438>>2] = (($439-1)|0);
      $440 = ($439|0)==(1);
      if (!($440)) {
       $$sroa$0390$2 = $433;
       break;
      }
      __THREW__ = 0;
      invoke_viii(3262,($324|0),1,1);
      $441 = __THREW__; __THREW__ = 0;
      $442 = $441&1;
      if ($442) {
       $$sroa$0364$1 = $$sroa$0364$01997;$$sroa$0381$0 = $332;$$sroa$0390$1 = $433;
       label = 116;
       break L23;
      } else {
       $$sroa$0390$2 = $433;
      }
     }
    } while(0);
    $466 = ((($$sroa$0364$01997)) + 124|0);
    $467 = HEAP32[$466>>2]|0;
    $468 = ($467|0)==(0|0);
    $469 = ($332|0)==($467|0);
    $or$cond520 = $468 | $469;
    do {
     if ($or$cond520) {
      if ($333) {
       $$sroa$0381$2438 = 0;$$sroa$0390$4 = $$sroa$0390$2;$1594 = 0;
      } else {
       $$sroa$0381$2437 = $332;
       label = 128;
      }
     } else {
      $470 = HEAP32[$467>>2]|0;
      $471 = ((($470)) + -12|0);
      $472 = HEAP32[$471>>2]|0;
      $473 = (($467) + ($472)|0);
      $474 = ((($473)) + 8|0);
      $475 = HEAP32[$474>>2]|0;HEAP32[$474>>2] = (($475+1)|0);
      if ($333) {
       $$sroa$0381$2437 = $467;
       label = 128;
       break;
      }
      $476 = HEAP32[$332>>2]|0;
      $477 = ((($476)) + -12|0);
      $478 = HEAP32[$477>>2]|0;
      $479 = (($332) + ($478)|0);
      $480 = ((($479)) + 8|0);
      $481 = HEAP32[$480>>2]|0;HEAP32[$480>>2] = (($481-1)|0);
      $482 = ($481|0)==(1);
      if (!($482)) {
       $$sroa$0381$2437 = $467;
       label = 128;
       break;
      }
      __THREW__ = 0;
      invoke_viii(3262,($479|0),1,1);
      $483 = __THREW__; __THREW__ = 0;
      $484 = $483&1;
      if ($484) {
       $$sroa$0364$1 = $$sroa$0364$01997;$$sroa$0381$0 = $467;$$sroa$0390$1 = $$sroa$0390$2;
       label = 116;
       break L23;
      } else {
       $$sroa$0381$2437 = $467;
       label = 128;
      }
     }
    } while(0);
    do {
     if ((label|0) == 128) {
      label = 0;
      $485 = HEAP32[$$sroa$0381$2437>>2]|0;
      $486 = ((($485)) + 4|0);
      $487 = HEAP32[$486>>2]|0;
      __THREW__ = 0;
      $488 = (invoke_ii($487|0,($$sroa$0381$2437|0))|0);
      $489 = __THREW__; __THREW__ = 0;
      $490 = $489&1;
      if ($490) {
       $$sroa$0364$1 = $$sroa$0364$01997;$$sroa$0381$0 = $$sroa$0381$2437;$$sroa$0390$1 = $$sroa$0390$2;
       label = 116;
       break L23;
      }
      if ($488) {
       $$sroa$0381$2438 = $$sroa$0381$2437;$$sroa$0390$4 = $$sroa$0390$2;$1594 = 1;
       break;
      }
      $491 = ($$sroa$0390$2|0)==(0|0);
      if ($491) {
       $$sroa$0381$2438 = $$sroa$0381$2437;$$sroa$0390$4 = 0;$1594 = 1;
       break;
      }
      $492 = ((($$sroa$0390$2)) + 8|0);
      $493 = HEAP32[$492>>2]|0;HEAP32[$492>>2] = (($493-1)|0);
      $494 = ($493|0)==(1);
      if (!($494)) {
       $$sroa$0381$2438 = $$sroa$0381$2437;$$sroa$0390$4 = 0;$1594 = 1;
       break;
      }
      __THREW__ = 0;
      invoke_viii(3262,($$sroa$0390$2|0),1,1);
      $495 = __THREW__; __THREW__ = 0;
      $496 = $495&1;
      if ($496) {
       $$sroa$0364$1 = $$sroa$0364$01997;$$sroa$0381$0 = $$sroa$0381$2437;$$sroa$0390$1 = 0;
       label = 116;
       break L23;
      } else {
       $$sroa$0381$2438 = $$sroa$0381$2437;$$sroa$0390$4 = 0;$1594 = 1;
      }
     }
    } while(0);
    $497 = ((($$sroa$0364$01997)) + 68|0);
    $498 = HEAP32[$497>>2]|0;
    $499 = $498 & 1;
    $500 = ($499|0)==(0);
    if (!($500)) {
     __THREW__ = 0;
     $501 = (invoke_ii(3482,0)|0);
     $502 = __THREW__; __THREW__ = 0;
     $503 = $502&1;
     if ($503) {
      $$sroa$0364$1 = $$sroa$0364$01997;$$sroa$0381$0 = $$sroa$0381$2438;$$sroa$0390$1 = $$sroa$0390$4;
      label = 116;
      break L23;
     }
     __THREW__ = 0;
     invoke_viiii(4122,($13|0),($501|0),($11|0),(0|0));
     $504 = __THREW__; __THREW__ = 0;
     $505 = $504&1;
     if ($505) {
      $$sroa$0364$1 = $$sroa$0364$01997;$$sroa$0381$0 = $$sroa$0381$2438;$$sroa$0390$1 = $$sroa$0390$4;
      label = 116;
      break L23;
     }
     $506 = HEAP32[$13>>2]|0;
     $507 = ($506|0)==(0|0);
     if ($507) {
      $508 = ($$sroa$0390$4|0)==(0|0);
      do {
       if (!($508)) {
        $509 = HEAP32[$$sroa$0390$4>>2]|0;
        $510 = ((($509)) + 12|0);
        $511 = HEAP32[$510>>2]|0;
        __THREW__ = 0;
        $512 = (invoke_iii($511|0,($$sroa$0390$4|0),($11|0))|0);
        $513 = __THREW__; __THREW__ = 0;
        $514 = $513&1;
        if ($514) {
         label = 158;
         break L23;
        }
        if (!($512)) {
         break;
        }
        $515 = HEAP32[$$sroa$0390$4>>2]|0;
        $516 = ((($515)) + 20|0);
        $517 = HEAP32[$516>>2]|0;
        __THREW__ = 0;
        $518 = (invoke_iii($517|0,($$sroa$0390$4|0),($11|0))|0);
        $519 = __THREW__; __THREW__ = 0;
        $520 = $519&1;
        if ($520) {
         label = 158;
         break L23;
        }
        if (!($518)) {
         break;
        }
        __THREW__ = 0;
        $521 = (invoke_ii(3482,0)|0);
        $522 = __THREW__; __THREW__ = 0;
        $523 = $522&1;
        if ($523) {
         label = 159;
         break L23;
        }
        $524 = HEAP32[$$sroa$0390$4>>2]|0;
        $525 = ((($524)) + 16|0);
        $526 = HEAP32[$525>>2]|0;
        __THREW__ = 0;
        invoke_viii($526|0,($15|0),($$sroa$0390$4|0),($11|0));
        $527 = __THREW__; __THREW__ = 0;
        $528 = $527&1;
        if ($528) {
         label = 160;
         break L23;
        }
        __THREW__ = 0;
        invoke_viiii(4122,($14|0),($521|0),($15|0),(0|0));
        $529 = __THREW__; __THREW__ = 0;
        $530 = $529&1;
        if ($530) {
         label = 161;
         break L23;
        }
        $531 = HEAP32[$13>>2]|0;
        $532 = HEAP32[$14>>2]|0;
        $533 = ($531|0)==($532|0);
        if ($533) {
         $543 = $531;
        } else {
         HEAP32[$13>>2] = $532;
         $534 = ($532|0)==(0|0);
         if (!($534)) {
          $535 = ((($532)) + 8|0);
          $536 = HEAP32[$535>>2]|0;HEAP32[$535>>2] = (($536+1)|0);
         }
         $537 = ($531|0)==(0|0);
         do {
          if (!($537)) {
           $538 = ((($531)) + 8|0);
           $539 = HEAP32[$538>>2]|0;HEAP32[$538>>2] = (($539-1)|0);
           $540 = ($539|0)==(1);
           if (!($540)) {
            break;
           }
           __THREW__ = 0;
           invoke_viii(3262,($531|0),1,1);
           $541 = __THREW__; __THREW__ = 0;
           $542 = $541&1;
           if ($542) {
            label = 162;
            break L23;
           }
          }
         } while(0);
         $$pr = HEAP32[$14>>2]|0;
         $543 = $$pr;
        }
        $544 = ($543|0)==(0|0);
        do {
         if (!($544)) {
          $545 = ((($543)) + 8|0);
          $546 = HEAP32[$545>>2]|0;HEAP32[$545>>2] = (($546-1)|0);
          $547 = ($546|0)==(1);
          if (!($547)) {
           break;
          }
          __THREW__ = 0;
          invoke_viii(3262,($543|0),1,1);
          $548 = __THREW__; __THREW__ = 0;
          $549 = $548&1;
          if ($549) {
           label = 161;
           break L23;
          }
         }
        } while(0);
        HEAP32[$14>>2] = 0;
        $550 = HEAP8[$110>>0]|0;
        $551 = ($550<<24>>24)<(0);
        if ($551) {
         $552 = HEAP32[$15>>2]|0;
         __ZdlPv($552);
        }
       }
      } while(0);
      $$pr454 = HEAP32[$13>>2]|0;
      $573 = ($$pr454|0)==(0|0);
      if ($573) {
       label = 189;
      } else {
       $574 = $$pr454;
       label = 171;
      }
     } else {
      $574 = $506;
      label = 171;
     }
     do {
      if ((label|0) == 171) {
       label = 0;
       $575 = (___dynamic_cast($574,26112,25952,0)|0);
       $576 = ($575|0)==(0|0);
       if ($576) {
        label = 189;
        break;
       }
       $577 = HEAP32[$$pre$phiZ2D>>2]|0;
       $578 = ((($577)) + 24|0);
       $579 = HEAP32[$578>>2]|0;
       $580 = ((($579)) + 8|0);
       $581 = HEAP32[$580>>2]|0;
       __THREW__ = 0;
       (invoke_ii($581|0,($578|0))|0);
       $582 = __THREW__; __THREW__ = 0;
       $583 = $582&1;
       if ($583) {
        label = 184;
        break L23;
       }
       $584 = HEAP32[$10>>2]|0;
       $585 = ((($584)) + 80|0);
       $586 = HEAP32[$585>>2]|0;
       $587 = ($586|0)==($575|0);
       do {
        if (!($587)) {
         HEAP32[$585>>2] = $575;
         $588 = ((($575)) + 8|0);
         $589 = HEAP32[$588>>2]|0;HEAP32[$588>>2] = (($589+1)|0);
         $590 = ($586|0)==(0|0);
         if ($590) {
          break;
         }
         $591 = ((($586)) + 8|0);
         $592 = HEAP32[$591>>2]|0;HEAP32[$591>>2] = (($592-1)|0);
         $593 = ($592|0)==(1);
         if (!($593)) {
          break;
         }
         __THREW__ = 0;
         invoke_viii(3262,($586|0),1,1);
         $594 = __THREW__; __THREW__ = 0;
         $595 = $594&1;
         if ($595) {
          label = 185;
          break L23;
         }
        }
       } while(0);
       $596 = HEAP32[$578>>2]|0;
       $597 = ((($596)) + 12|0);
       $598 = HEAP32[$597>>2]|0;
       __THREW__ = 0;
       (invoke_ii($598|0,($578|0))|0);
       $599 = __THREW__; __THREW__ = 0;
       $600 = $599&1;
       if ($600) {
        label = 186;
        break L23;
       }
       $601 = HEAP32[$$pre$phiZ2D>>2]|0;
       $602 = ((($601)) + 100|0);
       $603 = HEAP32[$602>>2]|0;
       $604 = ((($603)) + 28|0);
       $605 = HEAP32[$604>>2]|0;
       $606 = ((($605)) + 8|0);
       $607 = HEAP32[$606>>2]|0;
       __THREW__ = 0;
       (invoke_ii($607|0,($604|0))|0);
       $608 = __THREW__; __THREW__ = 0;
       $609 = $608&1;
       if ($609) {
        label = 184;
        break L23;
       }
       $610 = HEAP32[$$pre$phiZ2D>>2]|0;
       $611 = ((($610)) + 100|0);
       $612 = HEAP32[$611>>2]|0;
       $613 = HEAP32[$10>>2]|0;
       __THREW__ = 0;
       invoke_vii(4123,($612|0),($613|0));
       $614 = __THREW__; __THREW__ = 0;
       $615 = $614&1;
       if ($615) {
        label = 187;
        break L23;
       }
       $616 = HEAP32[$10>>2]|0;
       $617 = ($616|0)==(0|0);
       do {
        if (!($617)) {
         HEAP32[$10>>2] = 0;
         $618 = ((($616)) + 8|0);
         $619 = HEAP32[$618>>2]|0;HEAP32[$618>>2] = (($619-1)|0);
         $620 = ($619|0)==(1);
         if (!($620)) {
          break;
         }
         __THREW__ = 0;
         invoke_viii(3262,($616|0),1,1);
         $621 = __THREW__; __THREW__ = 0;
         $622 = $621&1;
         if ($622) {
          label = 187;
          break L23;
         }
        }
       } while(0);
       $623 = HEAP32[$604>>2]|0;
       $624 = ((($623)) + 12|0);
       $625 = HEAP32[$624>>2]|0;
       __THREW__ = 0;
       (invoke_ii($625|0,($604|0))|0);
       $626 = __THREW__; __THREW__ = 0;
       $627 = $626&1;
       if ($627) {
        label = 188;
        break L23;
       } else {
        $$026 = 4;
       }
      }
     } while(0);
     if ((label|0) == 189) {
      label = 0;
      $648 = HEAP32[$$pre$phiZ2D>>2]|0;
      $649 = ((($648)) + 24|0);
      $650 = HEAP32[$649>>2]|0;
      $651 = ((($650)) + 8|0);
      $652 = HEAP32[$651>>2]|0;
      __THREW__ = 0;
      (invoke_ii($652|0,($649|0))|0);
      $653 = __THREW__; __THREW__ = 0;
      $654 = $653&1;
      if ($654) {
       label = 184;
       break L23;
      }
      __THREW__ = 0;
      $655 = (invoke_ii(3276,36)|0);
      $656 = __THREW__; __THREW__ = 0;
      $657 = $656&1;
      if ($657) {
       label = 207;
       break L23;
      }
      __THREW__ = 0;
      invoke_vi(4124,($655|0));
      $658 = __THREW__; __THREW__ = 0;
      $659 = $658&1;
      if ($659) {
       label = 208;
       break L23;
      }
      $660 = HEAP32[$10>>2]|0;
      $661 = ((($660)) + 88|0);
      $662 = HEAP32[$661>>2]|0;
      $663 = ($662|0)==($655|0);
      do {
       if (!($663)) {
        HEAP32[$661>>2] = $655;
        $664 = ((($655)) + 8|0);
        $665 = HEAP32[$664>>2]|0;HEAP32[$664>>2] = (($665+1)|0);
        $666 = ($662|0)==(0|0);
        if ($666) {
         break;
        }
        $667 = ((($662)) + 8|0);
        $668 = HEAP32[$667>>2]|0;HEAP32[$667>>2] = (($668-1)|0);
        $669 = ($668|0)==(1);
        if (!($669)) {
         break;
        }
        __THREW__ = 0;
        invoke_viii(3262,($662|0),1,1);
        $670 = __THREW__; __THREW__ = 0;
        $671 = $670&1;
        if ($671) {
         label = 207;
         break L23;
        }
       }
      } while(0);
      $672 = HEAP32[$10>>2]|0;
      $673 = ((($672)) + 88|0);
      $674 = HEAP32[$673>>2]|0;
      $675 = ((($$sroa$0364$01997)) + 72|0);
      $676 = HEAP32[$675>>2]|0;
      $677 = ($676|0)==($674|0);
      do {
       if (!($677)) {
        HEAP32[$675>>2] = $674;
        $678 = ($674|0)==(0|0);
        if (!($678)) {
         $679 = ((($674)) + 8|0);
         $680 = HEAP32[$679>>2]|0;HEAP32[$679>>2] = (($680+1)|0);
        }
        $681 = ($676|0)==(0|0);
        if ($681) {
         break;
        }
        $682 = ((($676)) + 8|0);
        $683 = HEAP32[$682>>2]|0;HEAP32[$682>>2] = (($683-1)|0);
        $684 = ($683|0)==(1);
        if (!($684)) {
         break;
        }
        __THREW__ = 0;
        invoke_viii(3262,($676|0),1,1);
        $685 = __THREW__; __THREW__ = 0;
        $686 = $685&1;
        if ($686) {
         label = 207;
         break L23;
        }
       }
      } while(0);
      $687 = HEAP32[$649>>2]|0;
      $688 = ((($687)) + 12|0);
      $689 = HEAP32[$688>>2]|0;
      __THREW__ = 0;
      (invoke_ii($689|0,($649|0))|0);
      $690 = __THREW__; __THREW__ = 0;
      $691 = $690&1;
      if ($691) {
       label = 209;
       break L23;
      } else {
       $$026 = 0;
      }
     }
     $692 = HEAP32[$13>>2]|0;
     $693 = ($692|0)==(0|0);
     do {
      if (!($693)) {
       $694 = ((($692)) + 8|0);
       $695 = HEAP32[$694>>2]|0;HEAP32[$694>>2] = (($695-1)|0);
       $696 = ($695|0)==(1);
       if (!($696)) {
        break;
       }
       __THREW__ = 0;
       invoke_viii(3262,($692|0),1,1);
       $697 = __THREW__; __THREW__ = 0;
       $698 = $697&1;
       if ($698) {
        label = 211;
        break L23;
       }
      }
     } while(0);
     $cond = ($$026|0)==(0);
     if (!($cond)) {
      $$2$off0 = $$027$off0;$$sroa$0364$7 = $$sroa$0364$01997;$$sroa$0381$4 = $$sroa$0381$2438;$$sroa$0390$6 = $$sroa$0390$4;
      break;
     }
    }
    $719 = HEAP32[$$pre$phiZ2D>>2]|0;
    /* fence */;
    $720 = ((($719)) + 84|0);
    $721 = HEAP32[$720>>2]|0;
    $722 = (($721) - ($426))|0;
    $723 = ($722>>>0)<(2);
    L205: do {
     if ($723) {
      $724 = HEAP32[$53>>2]|0;
      switch ($724|0) {
      case 0:  {
       $725 = ($$sroa$0390$4|0)==(0|0);
       if ($725) {
        $$139$off0$ph = 0;
        break L205;
       }
       $726 = HEAP32[$$sroa$0390$4>>2]|0;
       $727 = ((($726)) + 12|0);
       $728 = HEAP32[$727>>2]|0;
       __THREW__ = 0;
       $729 = (invoke_iii($728|0,($$sroa$0390$4|0),($11|0))|0);
       $730 = __THREW__; __THREW__ = 0;
       $731 = $730&1;
       if ($731) {
        $$sroa$0364$1 = $$sroa$0364$01997;$$sroa$0381$0 = $$sroa$0381$2438;$$sroa$0390$1 = $$sroa$0390$4;
        label = 116;
        break L23;
       }
       if (!($729)) {
        $$139$off0$ph = 0;
        break L205;
       }
       $732 = HEAP32[$$sroa$0390$4>>2]|0;
       $733 = ((($732)) + 20|0);
       $734 = HEAP32[$733>>2]|0;
       __THREW__ = 0;
       $735 = (invoke_iii($734|0,($$sroa$0390$4|0),($11|0))|0);
       $736 = __THREW__; __THREW__ = 0;
       $737 = $736&1;
       if ($737) {
        $$sroa$0364$1 = $$sroa$0364$01997;$$sroa$0381$0 = $$sroa$0381$2438;$$sroa$0390$1 = $$sroa$0390$4;
        label = 116;
        break L23;
       } else {
        $$139$off0$ph = $735;
        break L205;
       }
       break;
      }
      case 1:  {
       break;
      }
      default: {
       $$139$off0$ph = 0;
       break L205;
      }
      }
      do {
       if ($1594) {
        $738 = HEAP32[$$sroa$0381$2438>>2]|0;
        $739 = HEAP32[$738>>2]|0;
        __THREW__ = 0;
        $740 = (invoke_iiii($739|0,($$sroa$0381$2438|0),($11|0),($$sroa$0364$01997|0))|0);
        $741 = __THREW__; __THREW__ = 0;
        $742 = $741&1;
        if ($742) {
         label = 226;
         break L23;
        }
        $743 = ($740|0)==(1);
        if (!($743)) {
         $$139$off0$ph = 0;
         break L205;
        }
        $753 = ($$sroa$0390$4|0)==(0|0);
        if ($753) {
         break;
        }
        $$pre$phi1993Z2D = $$sroa$0390$4;
        label = 233;
       } else {
        $746 = ($$sroa$0390$4|0)==(0|0);
        if ($746) {
         $$139$off0$ph = 0;
         break L205;
        }
        $747 = HEAP32[$$sroa$0390$4>>2]|0;
        $748 = ((($747)) + 12|0);
        $749 = HEAP32[$748>>2]|0;
        __THREW__ = 0;
        $750 = (invoke_iii($749|0,($$sroa$0390$4|0),($11|0))|0);
        $751 = __THREW__; __THREW__ = 0;
        $752 = $751&1;
        if ($752) {
         label = 226;
         break L23;
        }
        if ($750) {
         $$pre$phi1993Z2D = $$sroa$0390$4;
         label = 233;
        } else {
         $$139$off0$ph = 0;
         break L205;
        }
       }
      } while(0);
      if ((label|0) == 233) {
       label = 0;
       $754 = HEAP32[$$pre$phi1993Z2D>>2]|0;
       $755 = ((($754)) + 20|0);
       $756 = HEAP32[$755>>2]|0;
       __THREW__ = 0;
       $757 = (invoke_iii($756|0,($$sroa$0390$4|0),($11|0))|0);
       $758 = __THREW__; __THREW__ = 0;
       $759 = $758&1;
       if ($759) {
        label = 226;
        break L23;
       }
       if ($757) {
        $$139$off0$ph = 1;
        break;
       }
      }
      __THREW__ = 0;
      $760 = (invoke_ii(3265,4)|0);
      $761 = __THREW__; __THREW__ = 0;
      $762 = $761&1;
      if ($762) {
       label = 226;
       break L23;
      }
      if ($760) {
       __THREW__ = 0;
       $763 = (invoke_ii(3266,4)|0);
       $764 = __THREW__; __THREW__ = 0;
       $765 = $764&1;
       if ($765) {
        label = 226;
        break L23;
       }
       $766 = HEAP8[$88>>0]|0;
       $767 = ($766<<24>>24)<(0);
       $768 = HEAP32[$87>>2]|0;
       $769 = $767 ? $768 : $87;
       $770 = HEAP32[$89>>2]|0;
       $771 = $766&255;
       $772 = $767 ? $770 : $771;
       __THREW__ = 0;
       $773 = (invoke_iiii(3267,($763|0),($769|0),($772|0))|0);
       $774 = __THREW__; __THREW__ = 0;
       $775 = $774&1;
       if ($775) {
        label = 226;
        break L23;
       }
       __THREW__ = 0;
       $776 = (invoke_iiii(3267,($773|0),(162888|0),29)|0);
       $777 = __THREW__; __THREW__ = 0;
       $778 = $777&1;
       if ($778) {
        label = 226;
        break L23;
       }
       $779 = HEAP8[$93>>0]|0;
       $780 = ($779<<24>>24)<(0);
       $781 = HEAP32[$11>>2]|0;
       $782 = $780 ? $781 : $11;
       $783 = HEAP32[$95>>2]|0;
       $784 = $779&255;
       $785 = $780 ? $783 : $784;
       __THREW__ = 0;
       $786 = (invoke_iiii(3267,($776|0),($782|0),($785|0))|0);
       $787 = __THREW__; __THREW__ = 0;
       $788 = $787&1;
       if ($788) {
        label = 226;
        break L23;
       }
       $789 = HEAP32[$786>>2]|0;
       $790 = ((($789)) + -12|0);
       $791 = HEAP32[$790>>2]|0;
       $792 = (($786) + ($791)|0);
       __THREW__ = 0;
       invoke_vii(3257,($5|0),($792|0));
       $793 = __THREW__; __THREW__ = 0;
       $794 = $793&1;
       if ($794) {
        label = 226;
        break L23;
       }
       __THREW__ = 0;
       $795 = (invoke_iii(3255,($5|0),(215188|0))|0);
       $796 = __THREW__; __THREW__ = 0;
       $797 = $796&1;
       if ($797) {
        label = 244;
        break L23;
       }
       $798 = HEAP32[$795>>2]|0;
       $799 = ((($798)) + 28|0);
       $800 = HEAP32[$799>>2]|0;
       __THREW__ = 0;
       $801 = (invoke_iii($800|0,($795|0),10)|0);
       $802 = __THREW__; __THREW__ = 0;
       $803 = $802&1;
       if ($803) {
        label = 244;
        break L23;
       }
       __THREW__ = 0;
       invoke_vi(3263,($5|0));
       $810 = __THREW__; __THREW__ = 0;
       $811 = $810&1;
       if ($811) {
        label = 226;
        break L23;
       }
       __THREW__ = 0;
       (invoke_iii(3268,($786|0),($801|0))|0);
       $812 = __THREW__; __THREW__ = 0;
       $813 = $812&1;
       if ($813) {
        label = 226;
        break L23;
       }
       __THREW__ = 0;
       (invoke_ii(3269,($786|0))|0);
       $814 = __THREW__; __THREW__ = 0;
       $815 = $814&1;
       if ($815) {
        label = 226;
        break L23;
       }
      }
      $816 = HEAP32[$10>>2]|0;
      $817 = HEAP32[$96>>2]|0;
      $818 = ((($817)) + 8|0);
      $819 = HEAP32[$818>>2]|0;
      __THREW__ = 0;
      (invoke_ii($819|0,($96|0))|0);
      $820 = __THREW__; __THREW__ = 0;
      $821 = $820&1;
      if ($821) {
       label = 226;
       break L23;
      }
      __THREW__ = 0;
      invoke_vii(4123,($$sroa$0415$4$ph|0),($816|0));
      $822 = __THREW__; __THREW__ = 0;
      $823 = $822&1;
      if ($823) {
       label = 253;
       break L23;
      }
      $824 = HEAP32[$96>>2]|0;
      $825 = ((($824)) + 12|0);
      $826 = HEAP32[$825>>2]|0;
      __THREW__ = 0;
      (invoke_ii($826|0,($96|0))|0);
      $827 = __THREW__; __THREW__ = 0;
      $828 = $827&1;
      if ($828) {
       label = 226;
       break L23;
      }
      $838 = HEAP32[$10>>2]|0;
      $839 = ($838|0)==(0|0);
      if ($839) {
       $$sroa$0364$6460 = $$sroa$0364$01997;$$sroa$0381$3480 = $$sroa$0381$2438;$$sroa$0390$5500 = $$sroa$0390$4;
       label = 457;
       break L78;
      }
      HEAP32[$10>>2] = 0;
      $840 = ((($838)) + 8|0);
      $841 = HEAP32[$840>>2]|0;HEAP32[$840>>2] = (($841-1)|0);
      $842 = ($841|0)==(1);
      if (!($842)) {
       $$139$off0$ph = 0;
       break;
      }
      __THREW__ = 0;
      invoke_viii(3262,($838|0),1,1);
      $843 = __THREW__; __THREW__ = 0;
      $844 = $843&1;
      if ($844) {
       label = 226;
       break L23;
      } else {
       $$139$off0$ph = 0;
      }
     } else {
      $845 = HEAP32[$10>>2]|0;
      $846 = ($845|0)==(0|0);
      if ($846) {
       $$sroa$0364$6460 = $$sroa$0364$01997;$$sroa$0381$3480 = $$sroa$0381$2438;$$sroa$0390$5500 = $$sroa$0390$4;
       label = 457;
       break L78;
      }
      HEAP32[$10>>2] = 0;
      $847 = ((($845)) + 8|0);
      $848 = HEAP32[$847>>2]|0;HEAP32[$847>>2] = (($848-1)|0);
      $849 = ($848|0)==(1);
      if (!($849)) {
       $$139$off0$ph = 0;
       break;
      }
      __THREW__ = 0;
      invoke_viii(3262,($845|0),1,1);
      $850 = __THREW__; __THREW__ = 0;
      $851 = $850&1;
      if ($851) {
       $$sroa$0364$1 = $$sroa$0364$01997;$$sroa$0381$0 = $$sroa$0381$2438;$$sroa$0390$1 = $$sroa$0390$4;
       label = 116;
       break L23;
      } else {
       $$139$off0$ph = 0;
      }
     }
    } while(0);
    $$pr458 = HEAP32[$10>>2]|0;
    $852 = ($$pr458|0)==(0|0);
    if ($852) {
     $$sroa$0364$6460 = $$sroa$0364$01997;$$sroa$0381$3480 = $$sroa$0381$2438;$$sroa$0390$5500 = $$sroa$0390$4;
     label = 457;
     break;
    }
    if ($$139$off0$ph) {
     $853 = HEAP32[$$sroa$0390$4>>2]|0;
     $854 = ((($853)) + 48|0);
     $855 = HEAP32[$854>>2]|0;
     __THREW__ = 0;
     invoke_viiiii($855|0,($16|0),($$sroa$0390$4|0),($11|0),($$sroa$0364$01997|0),0);
     $856 = __THREW__; __THREW__ = 0;
     $857 = $856&1;
     if ($857) {
      $$sroa$0364$1 = $$sroa$0364$01997;$$sroa$0381$0 = $$sroa$0381$2438;$$sroa$0390$1 = $$sroa$0390$4;
      label = 116;
      break L23;
     }
    } else {
     __THREW__ = 0;
     $858 = (invoke_ii(3482,0)|0);
     $859 = __THREW__; __THREW__ = 0;
     $860 = $859&1;
     if ($860) {
      $$sroa$0364$1 = $$sroa$0364$01997;$$sroa$0381$0 = $$sroa$0381$2438;$$sroa$0390$1 = $$sroa$0390$4;
      label = 116;
      break L23;
     }
     __THREW__ = 0;
     invoke_viiiii(4125,($16|0),($858|0),($11|0),($$sroa$0364$01997|0),0);
     $861 = __THREW__; __THREW__ = 0;
     $862 = $861&1;
     if ($862) {
      $$sroa$0364$1 = $$sroa$0364$01997;$$sroa$0381$0 = $$sroa$0381$2438;$$sroa$0390$1 = $$sroa$0390$4;
      label = 116;
      break L23;
     }
    }
    __THREW__ = 0;
    $863 = (invoke_ii(4126,($16|0))|0);
    $864 = __THREW__; __THREW__ = 0;
    $865 = $864&1;
    if ($865) {
     $$sroa$0335$1 = 0;
     label = 271;
     break L23;
    }
    $866 = ($863|0)==(0|0);
    do {
     if ($866) {
      $$sroa$0335$2 = 0;
     } else {
      __THREW__ = 0;
      $867 = (invoke_ii(4126,($16|0))|0);
      $868 = __THREW__; __THREW__ = 0;
      $869 = $868&1;
      if ($869) {
       $$sroa$0335$1 = 0;
       label = 271;
       break L23;
      }
      $870 = ($867|0)==(0|0);
      if ($870) {
       $$sroa$0335$2 = 0;
       break;
      }
      $871 = ((($867)) + 8|0);
      $872 = HEAP32[$871>>2]|0;HEAP32[$871>>2] = (($872+1)|0);
      $$sroa$0335$2 = $867;
     }
    } while(0);
    $875 = HEAP32[$16>>2]|0;
    $876 = $875 | 1;
    $877 = ($876|0)==(5);
    do {
     if (!($877)) {
      __THREW__ = 0;
      $878 = (invoke_ii(3265,2)|0);
      $879 = __THREW__; __THREW__ = 0;
      $880 = $879&1;
      if ($880) {
       $$sroa$0335$1 = $$sroa$0335$2;
       label = 271;
       break L23;
      }
      if (!($878)) {
       break;
      }
      __THREW__ = 0;
      $881 = (invoke_ii(3266,2)|0);
      $882 = __THREW__; __THREW__ = 0;
      $883 = $882&1;
      if ($883) {
       $$sroa$0335$1 = $$sroa$0335$2;
       label = 271;
       break L23;
      }
      __THREW__ = 0;
      $884 = (invoke_iiii(3267,($881|0),(162918|0),22)|0);
      $885 = __THREW__; __THREW__ = 0;
      $886 = $885&1;
      if ($886) {
       $$sroa$0335$1 = $$sroa$0335$2;
       label = 271;
       break L23;
      }
      $887 = HEAP8[$93>>0]|0;
      $888 = ($887<<24>>24)<(0);
      $889 = HEAP32[$11>>2]|0;
      $890 = $888 ? $889 : $11;
      $891 = HEAP32[$95>>2]|0;
      $892 = $887&255;
      $893 = $888 ? $891 : $892;
      __THREW__ = 0;
      $894 = (invoke_iiii(3267,($884|0),($890|0),($893|0))|0);
      $895 = __THREW__; __THREW__ = 0;
      $896 = $895&1;
      if ($896) {
       $$sroa$0335$1 = $$sroa$0335$2;
       label = 271;
       break L23;
      }
      __THREW__ = 0;
      $897 = (invoke_iiii(3267,($894|0),(162941|0),3)|0);
      $898 = __THREW__; __THREW__ = 0;
      $899 = $898&1;
      if ($899) {
       $$sroa$0335$1 = $$sroa$0335$2;
       label = 271;
       break L23;
      }
      __THREW__ = 0;
      invoke_vii(4127,($17|0),($16|0));
      $900 = __THREW__; __THREW__ = 0;
      $901 = $900&1;
      if ($901) {
       label = 293;
       break L23;
      }
      $902 = HEAP8[$108>>0]|0;
      $903 = ($902<<24>>24)<(0);
      $904 = HEAP32[$17>>2]|0;
      $905 = $903 ? $904 : $17;
      $906 = HEAP32[$109>>2]|0;
      $907 = $902&255;
      $908 = $903 ? $906 : $907;
      __THREW__ = 0;
      $909 = (invoke_iiii(3267,($897|0),($905|0),($908|0))|0);
      $910 = __THREW__; __THREW__ = 0;
      $911 = $910&1;
      if ($911) {
       label = 294;
       break L23;
      }
      $912 = HEAP32[$909>>2]|0;
      $913 = ((($912)) + -12|0);
      $914 = HEAP32[$913>>2]|0;
      $915 = (($909) + ($914)|0);
      __THREW__ = 0;
      invoke_vii(3257,($4|0),($915|0));
      $916 = __THREW__; __THREW__ = 0;
      $917 = $916&1;
      if ($917) {
       label = 294;
       break L23;
      }
      __THREW__ = 0;
      $918 = (invoke_iii(3255,($4|0),(215188|0))|0);
      $919 = __THREW__; __THREW__ = 0;
      $920 = $919&1;
      if ($920) {
       label = 284;
       break L23;
      }
      $921 = HEAP32[$918>>2]|0;
      $922 = ((($921)) + 28|0);
      $923 = HEAP32[$922>>2]|0;
      __THREW__ = 0;
      $924 = (invoke_iii($923|0,($918|0),10)|0);
      $925 = __THREW__; __THREW__ = 0;
      $926 = $925&1;
      if ($926) {
       label = 284;
       break L23;
      }
      __THREW__ = 0;
      invoke_vi(3263,($4|0));
      $933 = __THREW__; __THREW__ = 0;
      $934 = $933&1;
      if ($934) {
       label = 294;
       break L23;
      }
      __THREW__ = 0;
      (invoke_iii(3268,($909|0),($924|0))|0);
      $935 = __THREW__; __THREW__ = 0;
      $936 = $935&1;
      if ($936) {
       label = 294;
       break L23;
      }
      __THREW__ = 0;
      (invoke_ii(3269,($909|0))|0);
      $937 = __THREW__; __THREW__ = 0;
      $938 = $937&1;
      if ($938) {
       label = 294;
       break L23;
      }
      $939 = HEAP8[$108>>0]|0;
      $940 = ($939<<24>>24)<(0);
      if ($940) {
       $941 = HEAP32[$17>>2]|0;
       __ZdlPv($941);
      }
     }
    } while(0);
    $949 = ($$sroa$0335$2|0)!=(0|0);
    $950 = ($$sroa$0390$4|0)!=(0|0);
    $or$cond521 = $950 & $949;
    do {
     if ($or$cond521) {
      $951 = HEAP32[$$sroa$0390$4>>2]|0;
      $952 = ((($951)) + 12|0);
      $953 = HEAP32[$952>>2]|0;
      __THREW__ = 0;
      $954 = (invoke_iii($953|0,($$sroa$0390$4|0),($11|0))|0);
      $955 = __THREW__; __THREW__ = 0;
      $956 = $955&1;
      if ($956) {
       $$sroa$0335$1 = $$sroa$0335$2;
       label = 271;
       break L23;
      }
      $$not = $954 ^ 1;
      $brmerge = $$139$off0$ph | $$not;
      if ($brmerge) {
       break;
      }
      $957 = HEAP32[$$sroa$0390$4>>2]|0;
      $958 = ((($957)) + 52|0);
      $959 = HEAP32[$958>>2]|0;
      __THREW__ = 0;
      invoke_viiiii($959|0,($18|0),($$sroa$0390$4|0),($$sroa$0335$2|0),($11|0),($$sroa$0364$01997|0));
      $960 = __THREW__; __THREW__ = 0;
      $961 = $960&1;
      if ($961) {
       $$sroa$0335$1 = $$sroa$0335$2;
       label = 271;
       break L23;
      }
      $962 = HEAP8[$98>>0]|0;
      $963 = ($962<<24>>24)<(0);
      if (!($963)) {
       break;
      }
      $964 = HEAP32[$97>>2]|0;
      __ZdlPv($964);
     }
    } while(0);
    $965 = HEAP32[$$pre$phiZ2D>>2]|0;
    $966 = ((($965)) + 24|0);
    $967 = HEAP32[$966>>2]|0;
    $968 = ((($967)) + 8|0);
    $969 = HEAP32[$968>>2]|0;
    __THREW__ = 0;
    (invoke_ii($969|0,($966|0))|0);
    $970 = __THREW__; __THREW__ = 0;
    $971 = $970&1;
    if ($971) {
     $$sroa$0335$1 = $$sroa$0335$2;
     label = 271;
     break L23;
    }
    $972 = HEAP32[$$pre$phiZ2D>>2]|0;
    /* fence */;
    $973 = ((($972)) + 84|0);
    $974 = HEAP32[$973>>2]|0;
    $975 = HEAP32[$10>>2]|0;
    $976 = ((($975)) + 44|0);
    $977 = HEAP32[$976>>2]|0;
    $978 = (($974) - ($977))|0;
    $979 = ($978>>>0)>(1);
    do {
     if ($979) {
      __THREW__ = 0;
      $980 = (invoke_ii(3265,4)|0);
      $981 = __THREW__; __THREW__ = 0;
      $982 = $981&1;
      if ($982) {
       $$sroa$0335$3 = $$sroa$0335$2;
       label = 320;
       break L23;
      }
      if ($980) {
       __THREW__ = 0;
       $983 = (invoke_ii(3266,4)|0);
       $984 = __THREW__; __THREW__ = 0;
       $985 = $984&1;
       if ($985) {
        $$sroa$0335$3 = $$sroa$0335$2;
        label = 320;
        break L23;
       }
       $986 = HEAP8[$88>>0]|0;
       $987 = ($986<<24>>24)<(0);
       $988 = HEAP32[$87>>2]|0;
       $989 = $987 ? $988 : $87;
       $990 = HEAP32[$89>>2]|0;
       $991 = $986&255;
       $992 = $987 ? $990 : $991;
       __THREW__ = 0;
       $993 = (invoke_iiii(3267,($983|0),($989|0),($992|0))|0);
       $994 = __THREW__; __THREW__ = 0;
       $995 = $994&1;
       if ($995) {
        $$sroa$0335$3 = $$sroa$0335$2;
        label = 320;
        break L23;
       }
       __THREW__ = 0;
       $996 = (invoke_iiii(3267,($993|0),(162945|0),44)|0);
       $997 = __THREW__; __THREW__ = 0;
       $998 = $997&1;
       if ($998) {
        $$sroa$0335$3 = $$sroa$0335$2;
        label = 320;
        break L23;
       }
       $999 = HEAP32[$996>>2]|0;
       $1000 = ((($999)) + -12|0);
       $1001 = HEAP32[$1000>>2]|0;
       $1002 = (($996) + ($1001)|0);
       __THREW__ = 0;
       invoke_vii(3257,($3|0),($1002|0));
       $1003 = __THREW__; __THREW__ = 0;
       $1004 = $1003&1;
       if ($1004) {
        $$sroa$0335$3 = $$sroa$0335$2;
        label = 320;
        break L23;
       }
       __THREW__ = 0;
       $1005 = (invoke_iii(3255,($3|0),(215188|0))|0);
       $1006 = __THREW__; __THREW__ = 0;
       $1007 = $1006&1;
       if ($1007) {
        label = 314;
        break L23;
       }
       $1008 = HEAP32[$1005>>2]|0;
       $1009 = ((($1008)) + 28|0);
       $1010 = HEAP32[$1009>>2]|0;
       __THREW__ = 0;
       $1011 = (invoke_iii($1010|0,($1005|0),10)|0);
       $1012 = __THREW__; __THREW__ = 0;
       $1013 = $1012&1;
       if ($1013) {
        label = 314;
        break L23;
       }
       __THREW__ = 0;
       invoke_vi(3263,($3|0));
       $1020 = __THREW__; __THREW__ = 0;
       $1021 = $1020&1;
       if ($1021) {
        $$sroa$0335$3 = $$sroa$0335$2;
        label = 320;
        break L23;
       }
       __THREW__ = 0;
       (invoke_iii(3268,($996|0),($1011|0))|0);
       $1022 = __THREW__; __THREW__ = 0;
       $1023 = $1022&1;
       if ($1023) {
        $$sroa$0335$3 = $$sroa$0335$2;
        label = 320;
        break L23;
       }
       __THREW__ = 0;
       (invoke_ii(3269,($996|0))|0);
       $1024 = __THREW__; __THREW__ = 0;
       $1025 = $1024&1;
       if ($1025) {
        $$sroa$0335$3 = $$sroa$0335$2;
        label = 320;
        break L23;
       }
      }
      $1033 = ($$sroa$0335$2|0)==(0|0);
      if ($1033) {
       $$sroa$0335$6 = 0;
       break;
      }
      $1034 = ((($$sroa$0335$2)) + 8|0);
      $1035 = HEAP32[$1034>>2]|0;HEAP32[$1034>>2] = (($1035-1)|0);
      $1036 = ($1035|0)==(1);
      if (!($1036)) {
       $$sroa$0335$6 = 0;
       break;
      }
      __THREW__ = 0;
      invoke_viii(3262,($$sroa$0335$2|0),1,1);
      $1037 = __THREW__; __THREW__ = 0;
      $1038 = $1037&1;
      if ($1038) {
       $$sroa$0335$3 = 0;
       label = 320;
       break L23;
      } else {
       $$sroa$0335$6 = 0;
      }
     } else {
      $$sroa$0335$6 = $$sroa$0335$2;
     }
    } while(0);
    $1039 = HEAP32[$966>>2]|0;
    $1040 = ((($1039)) + 12|0);
    $1041 = HEAP32[$1040>>2]|0;
    __THREW__ = 0;
    (invoke_ii($1041|0,($966|0))|0);
    $1042 = __THREW__; __THREW__ = 0;
    $1043 = $1042&1;
    if ($1043) {
     label = 367;
     break L23;
    }
    $1044 = ($$sroa$0335$6|0)==(0|0);
    do {
     if (!($1044)) {
      $1045 = ((($$sroa$0335$6)) + 68|0);
      $1046 = HEAP8[$1045>>0]|0;
      $1047 = ($1046<<24>>24)==(0);
      if ($1047) {
       $1048 = ((($$sroa$0335$6)) + 32|0);
       $1049 = ((($$sroa$0335$6)) + 52|0);
       ;HEAP32[$1049>>2]=HEAP32[$1048>>2]|0;HEAP32[$1049+4>>2]=HEAP32[$1048+4>>2]|0;HEAP32[$1049+8>>2]=HEAP32[$1048+8>>2]|0;HEAP32[$1049+12>>2]=HEAP32[$1048+12>>2]|0;
       $1050 = ((($$sroa$0335$6)) + 48|0);
       $1051 = HEAP32[$1050>>2]|0;
       $1052 = ($1051|0)==(0|0);
       if ($1052) {
        $1110 = HEAP32[$$sroa$0335$6>>2]|0;
        $1111 = ((($1110)) + 200|0);
        $1112 = HEAP32[$1111>>2]|0;
        __THREW__ = 0;
        invoke_vii($1112|0,($2|0),($$sroa$0335$6|0));
        $1113 = __THREW__; __THREW__ = 0;
        $1114 = $1113&1;
        if ($1114) {
         $$sroa$0335$1 = $$sroa$0335$6;
         label = 271;
         break L23;
        }
        $1115 = +HEAPF32[$102>>2];
        $1116 = !($1115 >= 0.0);
        do {
         if (!($1116)) {
          $1117 = ((($$sroa$0335$6)) + 64|0);
          $1118 = +HEAPF32[$1117>>2];
          $1119 = !($1118 >= 0.0);
          if ($1119) {
           ;HEAP32[$1049>>2]=HEAP32[$2>>2]|0;HEAP32[$1049+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$1049+8>>2]=HEAP32[$2+8>>2]|0;
           HEAPF32[$1117>>2] = $1115;
           break;
          }
          $1120 = +HEAPF32[$1049>>2];
          $1121 = +HEAPF32[$2>>2];
          $1122 = $1120 - $1121;
          $1123 = ((($$sroa$0335$6)) + 56|0);
          $1124 = +HEAPF32[$1123>>2];
          $1125 = +HEAPF32[$103>>2];
          $1126 = $1124 - $1125;
          $1127 = ((($$sroa$0335$6)) + 60|0);
          $1128 = +HEAPF32[$1127>>2];
          $1129 = +HEAPF32[$104>>2];
          $1130 = $1128 - $1129;
          $1131 = $1122 * $1122;
          $1132 = $1126 * $1126;
          $1133 = $1131 + $1132;
          $1134 = $1130 * $1130;
          $1135 = $1133 + $1134;
          $1136 = (+Math_sqrt((+$1135)));
          $1137 = $1136;
          $1138 = $1115;
          $1139 = $1138 + $1137;
          $1140 = $1118;
          $1141 = !($1139 <= $1140);
          if (!($1141)) {
           break;
          }
          $1142 = $1140 + $1137;
          $1143 = !($1142 <= $1138);
          if ($1143) {
           $1144 = $1138 + $1142;
           $1145 = $1144 * 0.5;
           $1146 = $1145 - $1140;
           $1147 = $1146 / $1137;
           $1148 = $1121 - $1120;
           $1149 = $1148;
           $1150 = $1149 * $1147;
           $1151 = $1120;
           $1152 = $1151 + $1150;
           $1153 = $1152;
           HEAPF32[$1049>>2] = $1153;
           $1154 = $1125 - $1124;
           $1155 = $1154;
           $1156 = $1147 * $1155;
           $1157 = $1124;
           $1158 = $1157 + $1156;
           $1159 = $1158;
           HEAPF32[$1123>>2] = $1159;
           $1160 = $1129 - $1128;
           $1161 = $1160;
           $1162 = $1147 * $1161;
           $1163 = $1128;
           $1164 = $1163 + $1162;
           $1165 = $1164;
           HEAPF32[$1127>>2] = $1165;
           $1166 = $1145;
           HEAPF32[$1117>>2] = $1166;
           break;
          } else {
           ;HEAP32[$1049>>2]=HEAP32[$2>>2]|0;HEAP32[$1049+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$1049+8>>2]=HEAP32[$2+8>>2]|0;
           HEAPF32[$1117>>2] = $1115;
           break;
          }
         }
        } while(0);
       } else {
        $1053 = HEAP32[$1051>>2]|0;
        $1054 = ((($1053)) + 140|0);
        $1055 = HEAP32[$1054>>2]|0;
        __THREW__ = 0;
        invoke_viii($1055|0,($1|0),($1051|0),($$sroa$0335$6|0));
        $1056 = __THREW__; __THREW__ = 0;
        $1057 = $1056&1;
        if ($1057) {
         $$sroa$0335$1 = $$sroa$0335$6;
         label = 271;
         break L23;
        }
        $1058 = +HEAPF32[$105>>2];
        $1059 = !($1058 >= 0.0);
        do {
         if (!($1059)) {
          $1060 = ((($$sroa$0335$6)) + 64|0);
          $1061 = +HEAPF32[$1060>>2];
          $1062 = !($1061 >= 0.0);
          if ($1062) {
           ;HEAP32[$1049>>2]=HEAP32[$1>>2]|0;HEAP32[$1049+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$1049+8>>2]=HEAP32[$1+8>>2]|0;
           HEAPF32[$1060>>2] = $1058;
           break;
          }
          $1063 = +HEAPF32[$1049>>2];
          $1064 = +HEAPF32[$1>>2];
          $1065 = $1063 - $1064;
          $1066 = ((($$sroa$0335$6)) + 56|0);
          $1067 = +HEAPF32[$1066>>2];
          $1068 = +HEAPF32[$106>>2];
          $1069 = $1067 - $1068;
          $1070 = ((($$sroa$0335$6)) + 60|0);
          $1071 = +HEAPF32[$1070>>2];
          $1072 = +HEAPF32[$107>>2];
          $1073 = $1071 - $1072;
          $1074 = $1065 * $1065;
          $1075 = $1069 * $1069;
          $1076 = $1074 + $1075;
          $1077 = $1073 * $1073;
          $1078 = $1076 + $1077;
          $1079 = (+Math_sqrt((+$1078)));
          $1080 = $1079;
          $1081 = $1058;
          $1082 = $1081 + $1080;
          $1083 = $1061;
          $1084 = !($1082 <= $1083);
          if (!($1084)) {
           break;
          }
          $1085 = $1083 + $1080;
          $1086 = !($1085 <= $1081);
          if ($1086) {
           $1087 = $1081 + $1085;
           $1088 = $1087 * 0.5;
           $1089 = $1088 - $1083;
           $1090 = $1089 / $1080;
           $1091 = $1064 - $1063;
           $1092 = $1091;
           $1093 = $1092 * $1090;
           $1094 = $1063;
           $1095 = $1094 + $1093;
           $1096 = $1095;
           HEAPF32[$1049>>2] = $1096;
           $1097 = $1068 - $1067;
           $1098 = $1097;
           $1099 = $1090 * $1098;
           $1100 = $1067;
           $1101 = $1100 + $1099;
           $1102 = $1101;
           HEAPF32[$1066>>2] = $1102;
           $1103 = $1072 - $1071;
           $1104 = $1103;
           $1105 = $1090 * $1104;
           $1106 = $1071;
           $1107 = $1106 + $1105;
           $1108 = $1107;
           HEAPF32[$1070>>2] = $1108;
           $1109 = $1088;
           HEAPF32[$1060>>2] = $1109;
           break;
          } else {
           ;HEAP32[$1049>>2]=HEAP32[$1>>2]|0;HEAP32[$1049+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$1049+8>>2]=HEAP32[$1+8>>2]|0;
           HEAPF32[$1060>>2] = $1058;
           break;
          }
         }
        } while(0);
       }
       HEAP8[$1045>>0] = 1;
      }
      $1167 = HEAP32[$16>>2]|0;
      $1168 = ($1167|0)==(5);
      do {
       if ($1168) {
        __THREW__ = 0;
        $1265 = (invoke_ii(3265,3)|0);
        $1266 = __THREW__; __THREW__ = 0;
        $1267 = $1266&1;
        if ($1267) {
         $$sroa$0321$1 = 0;
         label = 368;
         break L23;
        }
        if (!($1265)) {
         $$0$off0 = 0;$$sroa$0321$7 = 0;
         break;
        }
        __THREW__ = 0;
        $1268 = (invoke_ii(3266,3)|0);
        $1269 = __THREW__; __THREW__ = 0;
        $1270 = $1269&1;
        if ($1270) {
         $$sroa$0321$1 = 0;
         label = 368;
         break L23;
        }
        __THREW__ = 0;
        $1271 = (invoke_iiii(3267,($1268|0),(162990|0),23)|0);
        $1272 = __THREW__; __THREW__ = 0;
        $1273 = $1272&1;
        if ($1273) {
         $$sroa$0321$1 = 0;
         label = 368;
         break L23;
        }
        $1274 = HEAP32[$1271>>2]|0;
        $1275 = ((($1274)) + -12|0);
        $1276 = HEAP32[$1275>>2]|0;
        $1277 = (($1271) + ($1276)|0);
        __THREW__ = 0;
        invoke_vii(3257,($6|0),($1277|0));
        $1278 = __THREW__; __THREW__ = 0;
        $1279 = $1278&1;
        if ($1279) {
         $$sroa$0321$1 = 0;
         label = 368;
         break L23;
        }
        __THREW__ = 0;
        $1280 = (invoke_iii(3255,($6|0),(215188|0))|0);
        $1281 = __THREW__; __THREW__ = 0;
        $1282 = $1281&1;
        if ($1282) {
         label = 385;
         break L23;
        }
        $1283 = HEAP32[$1280>>2]|0;
        $1284 = ((($1283)) + 28|0);
        $1285 = HEAP32[$1284>>2]|0;
        __THREW__ = 0;
        $1286 = (invoke_iii($1285|0,($1280|0),10)|0);
        $1287 = __THREW__; __THREW__ = 0;
        $1288 = $1287&1;
        if ($1288) {
         label = 385;
         break L23;
        }
        __THREW__ = 0;
        invoke_vi(3263,($6|0));
        $1295 = __THREW__; __THREW__ = 0;
        $1296 = $1295&1;
        if ($1296) {
         $$sroa$0321$1 = 0;
         label = 368;
         break L23;
        }
        __THREW__ = 0;
        (invoke_iii(3268,($1271|0),($1286|0))|0);
        $1297 = __THREW__; __THREW__ = 0;
        $1298 = $1297&1;
        if ($1298) {
         $$sroa$0321$1 = 0;
         label = 368;
         break L23;
        }
        __THREW__ = 0;
        (invoke_ii(3269,($1271|0))|0);
        $1299 = __THREW__; __THREW__ = 0;
        $1300 = $1299&1;
        if ($1300) {
         $$sroa$0321$1 = 0;
         label = 368;
         break L23;
        } else {
         $$0$off0 = 0;$$sroa$0321$7 = 0;
        }
       } else {
        $1169 = HEAP32[$$pre$phiZ2D>>2]|0;
        $1170 = ((($1169)) + 164|0);
        $1171 = HEAP32[$1170>>2]|0;
        __THREW__ = 0;
        invoke_viii(4128,($19|0),($1169|0),($1171|0));
        $1172 = __THREW__; __THREW__ = 0;
        $1173 = $1172&1;
        if ($1173) {
         $$sroa$0321$1 = 0;
         label = 368;
         break L23;
        }
        $1174 = HEAP32[$$sroa$0335$6>>2]|0;
        $1175 = ((($1174)) + 188|0);
        $1176 = HEAP32[$1175>>2]|0;
        __THREW__ = 0;
        invoke_vii($1176|0,($$sroa$0335$6|0),($19|0));
        $1177 = __THREW__; __THREW__ = 0;
        $1178 = $1177&1;
        if ($1178) {
         $$sroa$0321$3 = 0;
         label = 370;
         break L23;
        }
        $1179 = HEAP32[$$pre$phiZ2D>>2]|0;
        $1180 = ((($1179)) + 128|0);
        $1181 = HEAP8[$1180>>0]|0;
        $1182 = ($1181<<24>>24)==(0);
        do {
         if ($1182) {
          $$sroa$0321$4 = 0;$1595 = 0;
         } else {
          $1183 = ((($1179)) + 132|0);
          $1184 = HEAP32[$1183>>2]|0;
          $1185 = ($1184|0)==(0|0);
          if ($1185) {
           $$sroa$0321$4 = 0;$1595 = 0;
           break;
          }
          __THREW__ = 0;
          $1186 = (invoke_iii(4129,($1184|0),($19|0))|0);
          $1187 = __THREW__; __THREW__ = 0;
          $1188 = $1187&1;
          if ($1188) {
           $$sroa$0321$3 = 0;
           label = 370;
           break L23;
          }
          if (!($1186)) {
           $$sroa$0321$4 = 0;$1595 = 0;
           break;
          }
          __THREW__ = 0;
          $1189 = (invoke_ii(3276,48)|0);
          $1190 = __THREW__; __THREW__ = 0;
          $1191 = $1190&1;
          if ($1191) {
           $$sroa$0321$3 = 0;
           label = 370;
           break L23;
          }
          __THREW__ = 0;
          invoke_vi(3282,($1189|0));
          $1192 = __THREW__; __THREW__ = 0;
          $1193 = $1192&1;
          if ($1193) {
           label = 371;
           break L23;
          }
          HEAP32[$1189>>2] = (48488);
          $1194 = ((($1189)) + 12|0);
          HEAP32[$1194>>2] = 0;
          $1195 = ((($1189)) + 16|0);
          HEAP32[$1195>>2] = 0;
          $1196 = ((($1189)) + 20|0);
          HEAP32[$1196>>2] = 0;
          $1197 = ((($1189)) + 24|0);
          HEAP32[$1197>>2] = $$sroa$0335$6;
          $1198 = ((($$sroa$0335$6)) + 8|0);
          $1199 = HEAP32[$1198>>2]|0;HEAP32[$1198>>2] = (($1199+1)|0);
          $1200 = ((($1189)) + 28|0);
          HEAP32[$1200>>2] = 0;
          $1201 = ((($1189)) + 36|0);
          HEAP32[$1201>>2] = 0;
          $1202 = ((($1189)) + 40|0);
          HEAP32[$1202>>2] = 0;
          $1203 = ((($1189)) + 32|0);
          HEAP32[$1203>>2] = $1201;
          $1204 = ((($1189)) + 44|0);
          HEAP32[$1204>>2] = 0;
          $1205 = ((($1189)) + 8|0);
          $1206 = HEAP32[$1205>>2]|0;HEAP32[$1205>>2] = (($1206+1)|0);
          $1207 = HEAP32[$$pre$phiZ2D>>2]|0;
          $1208 = ((($1207)) + 132|0);
          $1209 = HEAP32[$1208>>2]|0;
          $1210 = ((($1209)) + 124|0);
          __THREW__ = 0;
          invoke_viii(3560,($1189|0),($1210|0),($19|0));
          $1211 = __THREW__; __THREW__ = 0;
          $1212 = $1211&1;
          if ($1212) {
           $$sroa$0321$3 = $1189;
           label = 370;
           break L23;
          }
          __THREW__ = 0;
          $1213 = (invoke_ii(3276,24)|0);
          $1214 = __THREW__; __THREW__ = 0;
          $1215 = $1214&1;
          if ($1215) {
           $$sroa$0321$3 = $1189;
           label = 370;
           break L23;
          }
          $1216 = HEAP32[$$pre$phiZ2D>>2]|0;
          $1217 = HEAP32[$10>>2]|0;
          $1218 = ((($1213)) + 12|0);
          __THREW__ = 0;
          invoke_vi(3282,($1218|0));
          $1219 = __THREW__; __THREW__ = 0;
          $1220 = $1219&1;
          if ($1220) {
           label = 372;
           break L23;
          }
          HEAP32[$1213>>2] = (73108);
          HEAP32[$1218>>2] = (73136);
          $1221 = ((($1213)) + 4|0);
          HEAP32[$1221>>2] = $1216;
          $1222 = ((($1213)) + 8|0);
          HEAP32[$1222>>2] = $1217;
          $1223 = ($1217|0)==(0|0);
          if (!($1223)) {
           $1224 = ((($1217)) + 8|0);
           $1225 = HEAP32[$1224>>2]|0;HEAP32[$1224>>2] = (($1225+1)|0);
          }
          $1226 = HEAP32[$1200>>2]|0;
          $1227 = ($1226|0)==($1213|0);
          do {
           if (!($1227)) {
            HEAP32[$1200>>2] = $1213;
            $1228 = HEAP32[$1213>>2]|0;
            $1229 = ((($1228)) + -12|0);
            $1230 = HEAP32[$1229>>2]|0;
            $1231 = (($1213) + ($1230)|0);
            $1232 = ((($1231)) + 8|0);
            $1233 = HEAP32[$1232>>2]|0;HEAP32[$1232>>2] = (($1233+1)|0);
            $1234 = ($1226|0)==(0|0);
            if ($1234) {
             break;
            }
            $1235 = HEAP32[$1226>>2]|0;
            $1236 = ((($1235)) + -12|0);
            $1237 = HEAP32[$1236>>2]|0;
            $1238 = (($1226) + ($1237)|0);
            $1239 = ((($1238)) + 8|0);
            $1240 = HEAP32[$1239>>2]|0;HEAP32[$1239>>2] = (($1240-1)|0);
            $1241 = ($1240|0)==(1);
            if (!($1241)) {
             break;
            }
            __THREW__ = 0;
            invoke_viii(3262,($1238|0),1,1);
            $1242 = __THREW__; __THREW__ = 0;
            $1243 = $1242&1;
            if ($1243) {
             $$sroa$0321$3 = $1189;
             label = 370;
             break L23;
            }
           }
          } while(0);
          $1244 = HEAP32[$$pre$phiZ2D>>2]|0;
          $1245 = ((($1244)) + 132|0);
          $1246 = HEAP32[$1245>>2]|0;
          __THREW__ = 0;
          invoke_viii(4130,($1246|0),($1189|0),0);
          $1247 = __THREW__; __THREW__ = 0;
          $1248 = $1247&1;
          if ($1248) {
           $$sroa$0321$3 = $1189;
           label = 370;
           break L23;
          } else {
           $$sroa$0321$4 = $1189;$1595 = 1;
          }
         }
        } while(0);
        __THREW__ = 0;
        invoke_vi(2595,($19|0));
        $1259 = __THREW__; __THREW__ = 0;
        $1260 = $1259&1;
        if ($1260) {
         label = 375;
         break L23;
        }
        $$0$off0 = $1595;$$sroa$0321$7 = $$sroa$0321$4;
       }
      } while(0);
      $1301 = HEAP32[$$pre$phiZ2D>>2]|0;
      $1302 = ((($1301)) + 24|0);
      $1303 = HEAP32[$1302>>2]|0;
      $1304 = ((($1303)) + 8|0);
      $1305 = HEAP32[$1304>>2]|0;
      __THREW__ = 0;
      (invoke_ii($1305|0,($1302|0))|0);
      $1306 = __THREW__; __THREW__ = 0;
      $1307 = $1306&1;
      if ($1307) {
       $$sroa$0321$1 = $$sroa$0321$7;
       label = 368;
       break L23;
      }
      $1308 = HEAP32[$10>>2]|0;
      $1309 = ((($1308)) + 80|0);
      $1310 = HEAP32[$1309>>2]|0;
      $1311 = ($1310|0)==($$sroa$0335$6|0);
      do {
       if (!($1311)) {
        HEAP32[$1309>>2] = $$sroa$0335$6;
        $1312 = ((($$sroa$0335$6)) + 8|0);
        $1313 = HEAP32[$1312>>2]|0;HEAP32[$1312>>2] = (($1313+1)|0);
        $1314 = ($1310|0)==(0|0);
        if ($1314) {
         break;
        }
        $1315 = ((($1310)) + 8|0);
        $1316 = HEAP32[$1315>>2]|0;HEAP32[$1315>>2] = (($1316-1)|0);
        $1317 = ($1316|0)==(1);
        if (!($1317)) {
         break;
        }
        __THREW__ = 0;
        invoke_viii(3262,($1310|0),1,1);
        $1318 = __THREW__; __THREW__ = 0;
        $1319 = $1318&1;
        if ($1319) {
         label = 415;
         break L23;
        }
       }
      } while(0);
      $1320 = HEAP32[$10>>2]|0;
      $1321 = ($$sroa$0321$7|0)==(0|0);
      if ($1321) {
       $1328 = 0;
      } else {
       __THREW__ = 0;
       $1322 = (invoke_ii(3325,($$sroa$0321$7|0))|0);
       $1323 = __THREW__; __THREW__ = 0;
       $1324 = $1323&1;
       if ($1324) {
        label = 415;
        break L23;
       } else {
        $1328 = $1322;
       }
      }
      $1325 = ((($1320)) + 92|0);
      $1326 = HEAP32[$1325>>2]|0;
      $1327 = ($1326|0)==($1328|0);
      if ($1327) {
       $1338 = $1328;
      } else {
       HEAP32[$1325>>2] = $1328;
       $1329 = ($1328|0)==(0|0);
       if (!($1329)) {
        $1330 = ((($1328)) + 8|0);
        $1331 = HEAP32[$1330>>2]|0;HEAP32[$1330>>2] = (($1331+1)|0);
       }
       $1332 = ($1326|0)==(0|0);
       do {
        if (!($1332)) {
         $1333 = ((($1326)) + 8|0);
         $1334 = HEAP32[$1333>>2]|0;HEAP32[$1333>>2] = (($1334-1)|0);
         $1335 = ($1334|0)==(1);
         if (!($1335)) {
          break;
         }
         __THREW__ = 0;
         invoke_viii(3262,($1326|0),1,1);
         $1336 = __THREW__; __THREW__ = 0;
         $1337 = $1336&1;
         if ($1337) {
          label = 415;
          break L23;
         }
        }
       } while(0);
       $$pr$i = HEAP32[$1325>>2]|0;
       $1338 = $$pr$i;
      }
      $1339 = ($1338|0)==(0|0);
      if ($1339) {
       $1344 = 0;
      } else {
       $1340 = ((($1338)) + 24|0);
       $1341 = HEAP32[$1340>>2]|0;
       $1342 = ($1341|0)==(0|0);
       $$$i = $1342 ? 0 : $$sroa$0321$7;
       $1344 = $$$i;
      }
      $1343 = ((($1320)) + 96|0);
      HEAP32[$1343>>2] = $1344;
      $1345 = HEAP32[$1302>>2]|0;
      $1346 = ((($1345)) + 12|0);
      $1347 = HEAP32[$1346>>2]|0;
      __THREW__ = 0;
      (invoke_ii($1347|0,($1302|0))|0);
      $1348 = __THREW__; __THREW__ = 0;
      $1349 = $1348&1;
      if ($1349) {
       label = 416;
       break L23;
      }
      $1350 = HEAP32[$$pre$phiZ2D>>2]|0;
      if ($$0$off0) {
       $1351 = ((($1350)) + 96|0);
       $1352 = HEAP32[$1351>>2]|0;
       $1353 = ((($1352)) + 28|0);
       $1354 = HEAP32[$1353>>2]|0;
       $1355 = ((($1354)) + 8|0);
       $1356 = HEAP32[$1355>>2]|0;
       __THREW__ = 0;
       (invoke_ii($1356|0,($1353|0))|0);
       $1357 = __THREW__; __THREW__ = 0;
       $1358 = $1357&1;
       if ($1358) {
        $$sroa$0321$1 = $$sroa$0321$7;
        label = 368;
        break L23;
       }
       $1359 = HEAP32[$$pre$phiZ2D>>2]|0;
       $1360 = ((($1359)) + 96|0);
       $1361 = HEAP32[$1360>>2]|0;
       $1362 = HEAP32[$10>>2]|0;
       __THREW__ = 0;
       invoke_vii(4123,($1361|0),($1362|0));
       $1363 = __THREW__; __THREW__ = 0;
       $1364 = $1363&1;
       if ($1364) {
        label = 417;
        break L23;
       }
       $1365 = HEAP32[$10>>2]|0;
       $1366 = ($1365|0)==(0|0);
       do {
        if (!($1366)) {
         HEAP32[$10>>2] = 0;
         $1367 = ((($1365)) + 8|0);
         $1368 = HEAP32[$1367>>2]|0;HEAP32[$1367>>2] = (($1368-1)|0);
         $1369 = ($1368|0)==(1);
         if (!($1369)) {
          break;
         }
         __THREW__ = 0;
         invoke_viii(3262,($1365|0),1,1);
         $1370 = __THREW__; __THREW__ = 0;
         $1371 = $1370&1;
         if ($1371) {
          label = 417;
          break L23;
         }
        }
       } while(0);
       $1372 = HEAP32[$1353>>2]|0;
       $1373 = ((($1372)) + 12|0);
       $1374 = HEAP32[$1373>>2]|0;
       __THREW__ = 0;
       (invoke_ii($1374|0,($1353|0))|0);
       $1375 = __THREW__; __THREW__ = 0;
       $1376 = $1375&1;
       if ($1376) {
        label = 418;
        break L23;
       }
      } else {
       $1395 = ((($1350)) + 100|0);
       $1396 = HEAP32[$1395>>2]|0;
       $1397 = ((($1396)) + 28|0);
       $1398 = HEAP32[$1397>>2]|0;
       $1399 = ((($1398)) + 8|0);
       $1400 = HEAP32[$1399>>2]|0;
       __THREW__ = 0;
       (invoke_ii($1400|0,($1397|0))|0);
       $1401 = __THREW__; __THREW__ = 0;
       $1402 = $1401&1;
       if ($1402) {
        $$sroa$0321$1 = $$sroa$0321$7;
        label = 368;
        break L23;
       }
       $1403 = HEAP32[$$pre$phiZ2D>>2]|0;
       $1404 = ((($1403)) + 100|0);
       $1405 = HEAP32[$1404>>2]|0;
       $1406 = HEAP32[$10>>2]|0;
       __THREW__ = 0;
       invoke_vii(4123,($1405|0),($1406|0));
       $1407 = __THREW__; __THREW__ = 0;
       $1408 = $1407&1;
       if ($1408) {
        label = 425;
        break L23;
       }
       $1409 = HEAP32[$10>>2]|0;
       $1410 = ($1409|0)==(0|0);
       do {
        if (!($1410)) {
         HEAP32[$10>>2] = 0;
         $1411 = ((($1409)) + 8|0);
         $1412 = HEAP32[$1411>>2]|0;HEAP32[$1411>>2] = (($1412-1)|0);
         $1413 = ($1412|0)==(1);
         if (!($1413)) {
          break;
         }
         __THREW__ = 0;
         invoke_viii(3262,($1409|0),1,1);
         $1414 = __THREW__; __THREW__ = 0;
         $1415 = $1414&1;
         if ($1415) {
          label = 425;
          break L23;
         }
        }
       } while(0);
       $1416 = HEAP32[$1397>>2]|0;
       $1417 = ((($1416)) + 12|0);
       $1418 = HEAP32[$1417>>2]|0;
       __THREW__ = 0;
       (invoke_ii($1418|0,($1397|0))|0);
       $1419 = __THREW__; __THREW__ = 0;
       $1420 = $1419&1;
       if ($1420) {
        label = 426;
        break L23;
       }
      }
      do {
       if (!($1321)) {
        $1430 = ((($$sroa$0321$7)) + 8|0);
        $1431 = HEAP32[$1430>>2]|0;HEAP32[$1430>>2] = (($1431-1)|0);
        $1432 = ($1431|0)==(1);
        if (!($1432)) {
         break;
        }
        __THREW__ = 0;
        invoke_viii(3262,($$sroa$0321$7|0),1,1);
        $1433 = __THREW__; __THREW__ = 0;
        $1434 = $1433&1;
        if ($1434) {
         label = 430;
         break L23;
        }
       }
      } while(0);
      $1443 = ((($$sroa$0335$6)) + 8|0);
      $1444 = HEAP32[$1443>>2]|0;HEAP32[$1443>>2] = (($1444-1)|0);
      $1445 = ($1444|0)==(1);
      if (!($1445)) {
       break;
      }
      __THREW__ = 0;
      invoke_viii(3262,($$sroa$0335$6|0),1,1);
      $1446 = __THREW__; __THREW__ = 0;
      $1447 = $1446&1;
      if ($1447) {
       label = 444;
       break L23;
      }
     }
    } while(0);
    $1448 = HEAP32[$99>>2]|0;
    $1449 = ($1448|0)==(0|0);
    do {
     if (!($1449)) {
      $1450 = ((($1448)) + 8|0);
      $1451 = HEAP32[$1450>>2]|0;HEAP32[$1450>>2] = (($1451-1)|0);
      $1452 = ($1451|0)==(1);
      if (!($1452)) {
       break;
      }
      __THREW__ = 0;
      invoke_viii(3262,($1448|0),1,1);
      $1453 = __THREW__; __THREW__ = 0;
      $1454 = $1453&1;
      if ($1454) {
       label = 441;
       break L23;
      }
     }
    } while(0);
    HEAP32[$99>>2] = 0;
    $1455 = HEAP8[$101>>0]|0;
    $1456 = ($1455<<24>>24)<(0);
    if ($1456) {
     $1457 = HEAP32[$100>>2]|0;
     __ZdlPv($1457);
    }
    $$sroa$0364$6459 = $$sroa$0364$01997;$$sroa$0381$3479 = $$sroa$0381$2438;$$sroa$0390$5499 = $$sroa$0390$4;
    label = 458;
   }
  } while(0);
  if ((label|0) == 457) {
   label = 0;
   __THREW__ = 0;
   (invoke_i(3842)|0);
   $1486 = __THREW__; __THREW__ = 0;
   $1487 = $1486&1;
   if ($1487) {
    $$sroa$0364$1 = $$sroa$0364$6460;$$sroa$0381$0 = $$sroa$0381$3480;$$sroa$0390$1 = $$sroa$0390$5500;
    label = 116;
    break;
   } else {
    $$sroa$0364$6459 = $$sroa$0364$6460;$$sroa$0381$3479 = $$sroa$0381$3480;$$sroa$0390$5499 = $$sroa$0390$5500;
    label = 458;
   }
  }
  if ((label|0) == 458) {
   label = 0;
   if ($$027$off0) {
    __THREW__ = 0;
    (invoke_i(3842)|0);
    $1488 = __THREW__; __THREW__ = 0;
    $1489 = $1488&1;
    if ($1489) {
     $$sroa$0364$1 = $$sroa$0364$6459;$$sroa$0381$0 = $$sroa$0381$3479;$$sroa$0390$1 = $$sroa$0390$5499;
     label = 116;
     break;
    } else {
     $$2$off0 = 0;$$sroa$0364$7 = $$sroa$0364$6459;$$sroa$0381$4 = $$sroa$0381$3479;$$sroa$0390$6 = $$sroa$0390$5499;
    }
   } else {
    $$2$off0 = 0;$$sroa$0364$7 = $$sroa$0364$6459;$$sroa$0381$4 = $$sroa$0381$3479;$$sroa$0390$6 = $$sroa$0390$5499;
   }
  }
  $1490 = HEAP8[$93>>0]|0;
  $1491 = ($1490<<24>>24)<(0);
  if ($1491) {
   $1492 = HEAP32[$11>>2]|0;
   __ZdlPv($1492);
  }
  $1493 = ($$sroa$0364$7|0)==(0|0);
  if (!($1493)) {
   $1494 = ((($$sroa$0364$7)) + 8|0);
   $1495 = HEAP32[$1494>>2]|0;HEAP32[$1494>>2] = (($1495-1)|0);
   $1496 = ($1495|0)==(1);
   if ($1496) {
    __THREW__ = 0;
    invoke_viii(3262,($$sroa$0364$7|0),1,1);
    $1497 = __THREW__; __THREW__ = 0;
    $1498 = $1497&1;
    if ($1498) {
     label = 486;
     break;
    }
   }
  }
  $1499 = ($$sroa$0381$4|0)==(0|0);
  if (!($1499)) {
   $1500 = HEAP32[$$sroa$0381$4>>2]|0;
   $1501 = ((($1500)) + -12|0);
   $1502 = HEAP32[$1501>>2]|0;
   $1503 = (($$sroa$0381$4) + ($1502)|0);
   $1504 = ((($1503)) + 8|0);
   $1505 = HEAP32[$1504>>2]|0;HEAP32[$1504>>2] = (($1505-1)|0);
   $1506 = ($1505|0)==(1);
   if ($1506) {
    __THREW__ = 0;
    invoke_viii(3262,($1503|0),1,1);
    $1507 = __THREW__; __THREW__ = 0;
    $1508 = $1507&1;
    if ($1508) {
     label = 493;
     break;
    }
   }
  }
  $1509 = ($$sroa$0390$6|0)==(0|0);
  do {
   if (!($1509)) {
    $1510 = ((($$sroa$0390$6)) + 8|0);
    $1511 = HEAP32[$1510>>2]|0;HEAP32[$1510>>2] = (($1511-1)|0);
    $1512 = ($1511|0)==(1);
    if (!($1512)) {
     break;
    }
    __THREW__ = 0;
    invoke_viii(3262,($$sroa$0390$6|0),1,1);
    $1513 = __THREW__; __THREW__ = 0;
    $1514 = $1513&1;
    if ($1514) {
     label = 494;
     break L23;
    }
   }
  } while(0);
  $1515 = HEAP32[$10>>2]|0;
  $1516 = ($1515|0)==(0|0);
  do {
   if (!($1516)) {
    $1517 = ((($1515)) + 8|0);
    $1518 = HEAP32[$1517>>2]|0;HEAP32[$1517>>2] = (($1518-1)|0);
    $1519 = ($1518|0)==(1);
    if (!($1519)) {
     break;
    }
    __THREW__ = 0;
    invoke_viii(3262,($1515|0),1,1);
    $1520 = __THREW__; __THREW__ = 0;
    $1521 = $1520&1;
    if ($1521) {
     label = 498;
     break L23;
    }
   }
  } while(0);
  __THREW__ = 0;
  $1522 = (invoke_ii(4131,($94|0))|0);
  $1523 = __THREW__; __THREW__ = 0;
  $1524 = $1523&1;
  if ($1524) {
   label = 12;
   break;
  }
  $1525 = ($1522|0)==(0);
  if (!($1525)) {
   label = 477;
   break;
  }
  /* fence */;
  $1526 = HEAP32[$86>>2]|0;
  $1527 = ($1526|0)==(0);
  if ($1527) {
   $$027$off0 = $$2$off0;
  } else {
   label = 477;
   break;
  }
 }
 switch (label|0) {
  case 12: {
   $62 = ___cxa_find_matching_catch_2()|0;
   $63 = tempRet0;
   $eh$lpad$body$index3Z2D = $63;$eh$lpad$body$indexZ2D = $62;
   label = 13;
   break;
  }
  case 24: {
   $129 = ___cxa_find_matching_catch_2()|0;
   $130 = tempRet0;
   $131 = HEAP32[$117>>2]|0;
   $132 = ((($131)) + 12|0);
   $133 = HEAP32[$132>>2]|0;
   __THREW__ = 0;
   (invoke_ii($133|0,($117|0))|0);
   $134 = __THREW__; __THREW__ = 0;
   $135 = $134&1;
   if ($135) {
    $136 = ___cxa_find_matching_catch_3(0|0)|0;
    $137 = tempRet0;
    ___clang_call_terminate($136);
    // unreachable;
   } else {
    $eh$lpad$body$index3Z2D = $130;$eh$lpad$body$indexZ2D = $129;
    label = 13;
   }
   break;
  }
  case 41: {
   $200 = ___cxa_find_matching_catch_2()|0;
   $201 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($7|0));
   $202 = __THREW__; __THREW__ = 0;
   $203 = $202&1;
   if ($203) {
    $204 = ___cxa_find_matching_catch_3(0|0)|0;
    $205 = tempRet0;
    ___clang_call_terminate($204);
    // unreachable;
   } else {
    $eh$lpad$body$index3Z2D = $201;$eh$lpad$body$indexZ2D = $200;
    label = 13;
    break;
   }
   break;
  }
  case 54: {
   $256 = ___cxa_find_matching_catch_2()|0;
   $257 = tempRet0;
   $$130 = $256;$$141 = $257;
   label = 66;
   break;
  }
  case 55: {
   $258 = ___cxa_find_matching_catch_2()|0;
   $259 = tempRet0;
   $260 = HEAP32[$90>>2]|0;
   $261 = ((($260)) + 12|0);
   $262 = HEAP32[$261>>2]|0;
   __THREW__ = 0;
   (invoke_ii($262|0,($90|0))|0);
   $263 = __THREW__; __THREW__ = 0;
   $264 = $263&1;
   if (!($264)) {
    $$130 = $258;$$141 = $259;
    label = 66;
   }
   break;
  }
  case 63: {
   $291 = ___cxa_find_matching_catch_2()|0;
   $292 = tempRet0;
   ___cxa_call_unexpected(($291|0));
   // unreachable;
   break;
  }
  case 65: {
   $293 = ___cxa_find_matching_catch_2()|0;
   $294 = tempRet0;
   $$130 = $293;$$141 = $294;
   label = 66;
   break;
  }
  case 113: {
   $443 = ___cxa_find_matching_catch_2()|0;
   $444 = tempRet0;
   $$36 = $443;$$3676 = $444;
   label = 499;
   break;
  }
  case 114: {
   $445 = ___cxa_find_matching_catch_2()|0;
   $446 = tempRet0;
   $$36 = $445;$$3676 = $446;
   label = 499;
   break;
  }
  case 115: {
   $447 = ___cxa_find_matching_catch_2()|0;
   $448 = tempRet0;
   $$33 = $447;$$3373 = $448;$$sroa$0390$10 = $324;
   label = 495;
   break;
  }
  case 116: {
   $449 = ___cxa_find_matching_catch_2()|0;
   $450 = tempRet0;
   $$29 = $449;$$2969 = $450;$$sroa$0364$8 = $$sroa$0364$1;$$sroa$0381$5 = $$sroa$0381$0;$$sroa$0390$7 = $$sroa$0390$1;
   label = 484;
   break;
  }
  case 117: {
   $451 = ___cxa_find_matching_catch_2()|0;
   $452 = tempRet0;
   $$4 = $451;$$444 = $452;$$sroa$0364$4 = $$sroa$0364$01997;
   label = 122;
   break;
  }
  case 118: {
   $453 = ___cxa_find_matching_catch_2()|0;
   $454 = tempRet0;
   __ZdlPv($359);
   $$4 = $453;$$444 = $454;$$sroa$0364$4 = 0;
   label = 122;
   break;
  }
  case 119: {
   $455 = ___cxa_find_matching_catch_2()|0;
   $456 = tempRet0;
   $$4 = $455;$$444 = $456;$$sroa$0364$4 = 0;
   label = 122;
   break;
  }
  case 120: {
   $457 = ___cxa_find_matching_catch_2()|0;
   $458 = tempRet0;
   $$4 = $457;$$444 = $458;$$sroa$0364$4 = 0;
   label = 122;
   break;
  }
  case 121: {
   $459 = ___cxa_find_matching_catch_2()|0;
   $460 = tempRet0;
   $$29 = $459;$$2969 = $460;$$sroa$0364$8 = $$sroa$0364$01997;$$sroa$0381$5 = $332;$$sroa$0390$7 = $324;
   label = 484;
   break;
  }
  case 158: {
   $553 = ___cxa_find_matching_catch_2()|0;
   $554 = tempRet0;
   $$14 = $553;$$1454 = $554;
   label = 212;
   break;
  }
  case 159: {
   $555 = ___cxa_find_matching_catch_2()|0;
   $556 = tempRet0;
   $$8 = $555;$$848 = $556;
   label = 169;
   break;
  }
  case 160: {
   $557 = ___cxa_find_matching_catch_2()|0;
   $558 = tempRet0;
   $$7 = $557;$$747 = $558;
   label = 168;
   break;
  }
  case 161: {
   $559 = ___cxa_find_matching_catch_2()|0;
   $560 = tempRet0;
   $$6 = $559;$$646 = $560;
   label = 166;
   break;
  }
  case 162: {
   $561 = ___cxa_find_matching_catch_2()|0;
   $562 = tempRet0;
   $563 = HEAP32[$14>>2]|0;
   $564 = ($563|0)==(0|0);
   if (!($564)) {
    $565 = ((($563)) + 8|0);
    $566 = HEAP32[$565>>2]|0;HEAP32[$565>>2] = (($566-1)|0);
    $567 = ($566|0)==(1);
    if ($567) {
     __THREW__ = 0;
     invoke_viii(3262,($563|0),1,1);
     $568 = __THREW__; __THREW__ = 0;
     $569 = $568&1;
     if ($569) {
      break;
     }
    }
   }
   HEAP32[$14>>2] = 0;
   $$6 = $561;$$646 = $562;
   label = 166;
   break;
  }
  case 184: {
   $628 = ___cxa_find_matching_catch_2()|0;
   $629 = tempRet0;
   $$14 = $628;$$1454 = $629;
   label = 212;
   break;
  }
  case 185: {
   $630 = ___cxa_find_matching_catch_2()|0;
   $631 = tempRet0;
   $632 = HEAP32[$578>>2]|0;
   $633 = ((($632)) + 12|0);
   $634 = HEAP32[$633>>2]|0;
   __THREW__ = 0;
   (invoke_ii($634|0,($578|0))|0);
   $635 = __THREW__; __THREW__ = 0;
   $636 = $635&1;
   if (!($636)) {
    $$14 = $630;$$1454 = $631;
    label = 212;
   }
   break;
  }
  case 186: {
   $637 = ___cxa_find_matching_catch_2()|0;
   $638 = tempRet0;
   $$14 = $637;$$1454 = $638;
   label = 212;
   break;
  }
  case 187: {
   $639 = ___cxa_find_matching_catch_2()|0;
   $640 = tempRet0;
   $641 = HEAP32[$604>>2]|0;
   $642 = ((($641)) + 12|0);
   $643 = HEAP32[$642>>2]|0;
   __THREW__ = 0;
   (invoke_ii($643|0,($604|0))|0);
   $644 = __THREW__; __THREW__ = 0;
   $645 = $644&1;
   if (!($645)) {
    $$14 = $639;$$1454 = $640;
    label = 212;
   }
   break;
  }
  case 188: {
   $646 = ___cxa_find_matching_catch_2()|0;
   $647 = tempRet0;
   $$14 = $646;$$1454 = $647;
   label = 212;
   break;
  }
  case 207: {
   $699 = ___cxa_find_matching_catch_2()|0;
   $700 = tempRet0;
   $$11 = $699;$$1151 = $700;
   label = 210;
   break;
  }
  case 208: {
   $701 = ___cxa_find_matching_catch_2()|0;
   $702 = tempRet0;
   __ZdlPv($655);
   $$11 = $701;$$1151 = $702;
   label = 210;
   break;
  }
  case 209: {
   $703 = ___cxa_find_matching_catch_2()|0;
   $704 = tempRet0;
   $$14 = $703;$$1454 = $704;
   label = 212;
   break;
  }
  case 211: {
   $710 = ___cxa_find_matching_catch_2()|0;
   $711 = tempRet0;
   $$15 = $710;$$1555 = $711;
   label = 216;
   break;
  }
  case 226: {
   $744 = ___cxa_find_matching_catch_2()|0;
   $745 = tempRet0;
   $eh$lpad$body241$index10Z2D = $745;$eh$lpad$body241$indexZ2D = $744;
   label = 227;
   break;
  }
  case 244: {
   $804 = ___cxa_find_matching_catch_2()|0;
   $805 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($5|0));
   $806 = __THREW__; __THREW__ = 0;
   $807 = $806&1;
   if ($807) {
    $808 = ___cxa_find_matching_catch_3(0|0)|0;
    $809 = tempRet0;
    ___clang_call_terminate($808);
    // unreachable;
   } else {
    $eh$lpad$body241$index10Z2D = $805;$eh$lpad$body241$indexZ2D = $804;
    label = 227;
    break;
   }
   break;
  }
  case 253: {
   $829 = ___cxa_find_matching_catch_2()|0;
   $830 = tempRet0;
   $831 = HEAP32[$96>>2]|0;
   $832 = ((($831)) + 12|0);
   $833 = HEAP32[$832>>2]|0;
   __THREW__ = 0;
   (invoke_ii($833|0,($96|0))|0);
   $834 = __THREW__; __THREW__ = 0;
   $835 = $834&1;
   if ($835) {
    $836 = ___cxa_find_matching_catch_3(0|0)|0;
    $837 = tempRet0;
    ___clang_call_terminate($836);
    // unreachable;
   } else {
    $eh$lpad$body241$index10Z2D = $830;$eh$lpad$body241$indexZ2D = $829;
    label = 227;
   }
   break;
  }
  case 271: {
   $873 = ___cxa_find_matching_catch_2()|0;
   $874 = tempRet0;
   $$26 = $873;$$2666 = $874;$$sroa$0335$8 = $$sroa$0335$1;
   label = 445;
   break;
  }
  case 284: {
   $927 = ___cxa_find_matching_catch_2()|0;
   $928 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($4|0));
   $929 = __THREW__; __THREW__ = 0;
   $930 = $929&1;
   if ($930) {
    $931 = ___cxa_find_matching_catch_3(0|0)|0;
    $932 = tempRet0;
    ___clang_call_terminate($931);
    // unreachable;
   } else {
    $eh$lpad$body270$index16Z2D = $928;$eh$lpad$body270$indexZ2D = $927;
    label = 295;
    break;
   }
   break;
  }
  case 293: {
   $942 = ___cxa_find_matching_catch_2()|0;
   $943 = tempRet0;
   $$16 = $942;$$1656 = $943;
   label = 297;
   break;
  }
  case 294: {
   $944 = ___cxa_find_matching_catch_2()|0;
   $945 = tempRet0;
   $eh$lpad$body270$index16Z2D = $945;$eh$lpad$body270$indexZ2D = $944;
   label = 295;
   break;
  }
  case 314: {
   $1014 = ___cxa_find_matching_catch_2()|0;
   $1015 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($3|0));
   $1016 = __THREW__; __THREW__ = 0;
   $1017 = $1016&1;
   if ($1017) {
    $1018 = ___cxa_find_matching_catch_3(0|0)|0;
    $1019 = tempRet0;
    ___clang_call_terminate($1018);
    // unreachable;
   } else {
    $$sroa$0335$4 = $$sroa$0335$2;$eh$lpad$body288$index21Z2D = $1015;$eh$lpad$body288$indexZ2D = $1014;
    label = 321;
    break;
   }
   break;
  }
  case 320: {
   $1026 = ___cxa_find_matching_catch_2()|0;
   $1027 = tempRet0;
   $$sroa$0335$4 = $$sroa$0335$3;$eh$lpad$body288$index21Z2D = $1027;$eh$lpad$body288$indexZ2D = $1026;
   label = 321;
   break;
  }
  case 367: {
   $1249 = ___cxa_find_matching_catch_2()|0;
   $1250 = tempRet0;
   $$26 = $1249;$$2666 = $1250;$$sroa$0335$8 = $$sroa$0335$6;
   label = 445;
   break;
  }
  case 368: {
   $1251 = ___cxa_find_matching_catch_2()|0;
   $1252 = tempRet0;
   $$sroa$0321$2 = $$sroa$0321$1;$eh$lpad$body225$index26Z2D = $1252;$eh$lpad$body225$indexZ2D = $1251;
   label = 369;
   break;
  }
  case 370: {
   $1253 = ___cxa_find_matching_catch_2()|0;
   $1254 = tempRet0;
   $$18 = $1253;$$1858 = $1254;$$sroa$0321$5 = $$sroa$0321$3;
   label = 376;
   break;
  }
  case 371: {
   $1255 = ___cxa_find_matching_catch_2()|0;
   $1256 = tempRet0;
   __ZdlPv($1189);
   $$18 = $1255;$$1858 = $1256;$$sroa$0321$5 = 0;
   label = 376;
   break;
  }
  case 372: {
   $1257 = ___cxa_find_matching_catch_2()|0;
   $1258 = tempRet0;
   __ZdlPv($1213);
   $$18 = $1257;$$1858 = $1258;$$sroa$0321$5 = $1189;
   label = 376;
   break;
  }
  case 375: {
   $1261 = ___cxa_find_matching_catch_2()|0;
   $1262 = tempRet0;
   $$19 = $1261;$$1959 = $1262;$$sroa$0321$6 = $$sroa$0321$4;
   label = 377;
   break;
  }
  case 385: {
   $1289 = ___cxa_find_matching_catch_2()|0;
   $1290 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($6|0));
   $1291 = __THREW__; __THREW__ = 0;
   $1292 = $1291&1;
   if ($1292) {
    $1293 = ___cxa_find_matching_catch_3(0|0)|0;
    $1294 = tempRet0;
    ___clang_call_terminate($1293);
    // unreachable;
   } else {
    $$sroa$0321$2 = 0;$eh$lpad$body225$index26Z2D = $1290;$eh$lpad$body225$indexZ2D = $1289;
    label = 369;
    break;
   }
   break;
  }
  case 415: {
   $1377 = ___cxa_find_matching_catch_2()|0;
   $1378 = tempRet0;
   $1379 = HEAP32[$1302>>2]|0;
   $1380 = ((($1379)) + 12|0);
   $1381 = HEAP32[$1380>>2]|0;
   __THREW__ = 0;
   (invoke_ii($1381|0,($1302|0))|0);
   $1382 = __THREW__; __THREW__ = 0;
   $1383 = $1382&1;
   if (!($1383)) {
    $$23 = $1377;$$2363 = $1378;$$sroa$0321$8 = $$sroa$0321$7;
    label = 431;
   }
   break;
  }
  case 416: {
   $1384 = ___cxa_find_matching_catch_2()|0;
   $1385 = tempRet0;
   $$23 = $1384;$$2363 = $1385;$$sroa$0321$8 = $$sroa$0321$7;
   label = 431;
   break;
  }
  case 417: {
   $1386 = ___cxa_find_matching_catch_2()|0;
   $1387 = tempRet0;
   $1388 = HEAP32[$1353>>2]|0;
   $1389 = ((($1388)) + 12|0);
   $1390 = HEAP32[$1389>>2]|0;
   __THREW__ = 0;
   (invoke_ii($1390|0,($1353|0))|0);
   $1391 = __THREW__; __THREW__ = 0;
   $1392 = $1391&1;
   if (!($1392)) {
    $$23 = $1386;$$2363 = $1387;$$sroa$0321$8 = $$sroa$0321$7;
    label = 431;
   }
   break;
  }
  case 418: {
   $1393 = ___cxa_find_matching_catch_2()|0;
   $1394 = tempRet0;
   $$23 = $1393;$$2363 = $1394;$$sroa$0321$8 = $$sroa$0321$7;
   label = 431;
   break;
  }
  case 425: {
   $1421 = ___cxa_find_matching_catch_2()|0;
   $1422 = tempRet0;
   $1423 = HEAP32[$1397>>2]|0;
   $1424 = ((($1423)) + 12|0);
   $1425 = HEAP32[$1424>>2]|0;
   __THREW__ = 0;
   (invoke_ii($1425|0,($1397|0))|0);
   $1426 = __THREW__; __THREW__ = 0;
   $1427 = $1426&1;
   if (!($1427)) {
    $$23 = $1421;$$2363 = $1422;$$sroa$0321$8 = $$sroa$0321$7;
    label = 431;
   }
   break;
  }
  case 426: {
   $1428 = ___cxa_find_matching_catch_2()|0;
   $1429 = tempRet0;
   $$23 = $1428;$$2363 = $1429;$$sroa$0321$8 = $$sroa$0321$7;
   label = 431;
   break;
  }
  case 430: {
   $1435 = ___cxa_find_matching_catch_2()|0;
   $1436 = tempRet0;
   $$26 = $1435;$$2666 = $1436;$$sroa$0335$8 = $$sroa$0335$6;
   label = 445;
   break;
  }
  case 441: {
   $1458 = ___cxa_find_matching_catch_2()|0;
   $1459 = tempRet0;
   $1460 = HEAP8[$101>>0]|0;
   $1461 = ($1460<<24>>24)<(0);
   if ($1461) {
    $1462 = HEAP32[$100>>2]|0;
    __ZdlPv($1462);
   }
   $$28 = $1458;$$2868 = $1459;
   label = 456;
   break;
  }
  case 444: {
   $1463 = ___cxa_find_matching_catch_2()|0;
   $1464 = tempRet0;
   $$27 = $1463;$$2767 = $1464;
   label = 448;
   break;
  }
  case 477: {
   $1528 = ($$sroa$0415$4$ph|0)==(0|0);
   if (!($1528)) {
    $1529 = ((($$sroa$0415$4$ph)) + 8|0);
    $1530 = HEAP32[$1529>>2]|0;HEAP32[$1529>>2] = (($1530-1)|0);
    $1531 = ($1530|0)==(1);
    if ($1531) {
     __THREW__ = 0;
     invoke_viii(3262,($$sroa$0415$4$ph|0),1,1);
     $1532 = __THREW__; __THREW__ = 0;
     $1533 = $1532&1;
     if ($1533) {
      $1578 = ___cxa_find_matching_catch_2()|0;
      $1579 = tempRet0;
      $$39 = $1578;$$3979 = $1579;
      label = 508;
      break;
     }
    }
   }
   $1534 = ($$sroa$0421$6$ph|0)==(0|0);
   if ($1534) {
    STACKTOP = sp;return;
   }
   $1535 = ((($$sroa$0421$6$ph)) + 8|0);
   $1536 = HEAP32[$1535>>2]|0;HEAP32[$1535>>2] = (($1536-1)|0);
   $1537 = ($1536|0)==(1);
   if (!($1537)) {
    STACKTOP = sp;return;
   }
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($$sroa$0421$6$ph,1,1);
   STACKTOP = sp;return;
   break;
  }
  case 486: {
   $1541 = ___cxa_find_matching_catch_2()|0;
   $1542 = tempRet0;
   $$31 = $1541;$$3171 = $1542;$$sroa$0381$6 = $$sroa$0381$4;$$sroa$0390$8 = $$sroa$0390$6;
   label = 490;
   break;
  }
  case 493: {
   $1559 = ___cxa_find_matching_catch_2()|0;
   $1560 = tempRet0;
   $$33 = $1559;$$3373 = $1560;$$sroa$0390$10 = $$sroa$0390$6;
   label = 495;
   break;
  }
  case 494: {
   $1561 = ___cxa_find_matching_catch_2()|0;
   $1562 = tempRet0;
   $$36 = $1561;$$3676 = $1562;
   label = 499;
   break;
  }
  case 498: {
   $1569 = ___cxa_find_matching_catch_2()|0;
   $1570 = tempRet0;
   $$37 = $1569;$$3777 = $1570;
   label = 503;
   break;
  }
 }
 switch (label|0) {
  case 13: {
   $$38 = $eh$lpad$body$indexZ2D;$$3878 = $eh$lpad$body$index3Z2D;
   label = 505;
   break;
  }
  case 66: {
   $295 = HEAP32[$113>>2]|0;
   $296 = ($295|0)==(0);
   L555: do {
    if (!($296)) {
     $297 = HEAP32[$112>>2]|0;
     $298 = HEAP32[$9>>2]|0;
     $299 = ((($298)) + 4|0);
     $300 = HEAP32[$299>>2]|0;
     $301 = HEAP32[$297>>2]|0;
     $302 = ((($301)) + 4|0);
     HEAP32[$302>>2] = $300;
     $303 = HEAP32[$299>>2]|0;
     HEAP32[$303>>2] = $301;
     HEAP32[$113>>2] = 0;
     $304 = ($297|0)==($9|0);
     if (!($304)) {
      $$023$i$i113 = $297;
      while(1) {
       $305 = ((($$023$i$i113)) + 4|0);
       $306 = HEAP32[$305>>2]|0;
       $307 = ((($$023$i$i113)) + 8|0);
       $308 = HEAP32[$307>>2]|0;
       $309 = ($308|0)==(0|0);
       if (!($309)) {
        $310 = ((($308)) + 8|0);
        $311 = HEAP32[$310>>2]|0;HEAP32[$310>>2] = (($311-1)|0);
        $312 = ($311|0)==(1);
        if ($312) {
         __THREW__ = 0;
         invoke_viii(3262,($308|0),1,1);
         $313 = __THREW__; __THREW__ = 0;
         $314 = $313&1;
         if ($314) {
          break;
         }
        }
       }
       __ZdlPv($$023$i$i113);
       $315 = ($306|0)==($9|0);
       if ($315) {
        break L555;
       } else {
        $$023$i$i113 = $306;
       }
      }
      $316 = ___cxa_find_matching_catch_2()|0;
      $317 = tempRet0;
      ___cxa_call_unexpected(($316|0));
      // unreachable;
     }
    }
   } while(0);
   $$38 = $$130;$$3878 = $$141;
   label = 505;
   break;
  }
  case 122: {
   $461 = HEAP32[$343>>2]|0;
   $462 = ((($461)) + 12|0);
   $463 = HEAP32[$462>>2]|0;
   __THREW__ = 0;
   (invoke_ii($463|0,($343|0))|0);
   $464 = __THREW__; __THREW__ = 0;
   $465 = $464&1;
   if (!($465)) {
    $$29 = $$4;$$2969 = $$444;$$sroa$0364$8 = $$sroa$0364$4;$$sroa$0381$5 = $332;$$sroa$0390$7 = $324;
    label = 484;
   }
   break;
  }
  case 166: {
   $570 = HEAP8[$110>>0]|0;
   $571 = ($570<<24>>24)<(0);
   if ($571) {
    $572 = HEAP32[$15>>2]|0;
    __ZdlPv($572);
    $$7 = $$6;$$747 = $$646;
    label = 168;
   } else {
    $$7 = $$6;$$747 = $$646;
    label = 168;
   }
   break;
  }
  case 210: {
   $705 = HEAP32[$649>>2]|0;
   $706 = ((($705)) + 12|0);
   $707 = HEAP32[$706>>2]|0;
   __THREW__ = 0;
   (invoke_ii($707|0,($649|0))|0);
   $708 = __THREW__; __THREW__ = 0;
   $709 = $708&1;
   if (!($709)) {
    $$14 = $$11;$$1454 = $$1151;
    label = 212;
   }
   break;
  }
  case 227: {
   $$29 = $eh$lpad$body241$indexZ2D;$$2969 = $eh$lpad$body241$index10Z2D;$$sroa$0364$8 = $$sroa$0364$01997;$$sroa$0381$5 = $$sroa$0381$2438;$$sroa$0390$7 = $$sroa$0390$4;
   label = 484;
   break;
  }
  case 295: {
   $946 = HEAP8[$108>>0]|0;
   $947 = ($946<<24>>24)<(0);
   if ($947) {
    $948 = HEAP32[$17>>2]|0;
    __ZdlPv($948);
    $$16 = $eh$lpad$body270$indexZ2D;$$1656 = $eh$lpad$body270$index16Z2D;
    label = 297;
   } else {
    $$16 = $eh$lpad$body270$indexZ2D;$$1656 = $eh$lpad$body270$index16Z2D;
    label = 297;
   }
   break;
  }
  case 321: {
   $1028 = HEAP32[$966>>2]|0;
   $1029 = ((($1028)) + 12|0);
   $1030 = HEAP32[$1029>>2]|0;
   __THREW__ = 0;
   (invoke_ii($1030|0,($966|0))|0);
   $1031 = __THREW__; __THREW__ = 0;
   $1032 = $1031&1;
   if (!($1032)) {
    $$26 = $eh$lpad$body288$indexZ2D;$$2666 = $eh$lpad$body288$index21Z2D;$$sroa$0335$8 = $$sroa$0335$4;
    label = 445;
   }
   break;
  }
  case 369: {
   $$23 = $eh$lpad$body225$indexZ2D;$$2363 = $eh$lpad$body225$index26Z2D;$$sroa$0321$8 = $$sroa$0321$2;
   label = 431;
   break;
  }
  case 376: {
   __THREW__ = 0;
   invoke_vi(2595,($19|0));
   $1263 = __THREW__; __THREW__ = 0;
   $1264 = $1263&1;
   if (!($1264)) {
    $$19 = $$18;$$1959 = $$1858;$$sroa$0321$6 = $$sroa$0321$5;
    label = 377;
   }
   break;
  }
 }
 if ((label|0) == 168) {
  $$8 = $$7;$$848 = $$747;
  label = 169;
 }
 else if ((label|0) == 297) {
  $$26 = $$16;$$2666 = $$1656;$$sroa$0335$8 = $$sroa$0335$2;
  label = 445;
 }
 else if ((label|0) == 377) {
  $$23 = $$19;$$2363 = $$1959;$$sroa$0321$8 = $$sroa$0321$6;
  label = 431;
 }
 if ((label|0) == 169) {
  $$14 = $$8;$$1454 = $$848;
  label = 212;
 }
 else if ((label|0) == 431) {
  $1437 = ($$sroa$0321$8|0)==(0|0);
  if ($1437) {
   $$26 = $$23;$$2666 = $$2363;$$sroa$0335$8 = $$sroa$0335$6;
   label = 445;
  } else {
   $1438 = ((($$sroa$0321$8)) + 8|0);
   $1439 = HEAP32[$1438>>2]|0;HEAP32[$1438>>2] = (($1439-1)|0);
   $1440 = ($1439|0)==(1);
   if ($1440) {
    __THREW__ = 0;
    invoke_viii(3262,($$sroa$0321$8|0),1,1);
    $1441 = __THREW__; __THREW__ = 0;
    $1442 = $1441&1;
    if (!($1442)) {
     $$26 = $$23;$$2666 = $$2363;$$sroa$0335$8 = $$sroa$0335$6;
     label = 445;
    }
   } else {
    $$26 = $$23;$$2666 = $$2363;$$sroa$0335$8 = $$sroa$0335$6;
    label = 445;
   }
  }
 }
 do {
  if ((label|0) == 212) {
   $712 = HEAP32[$13>>2]|0;
   $713 = ($712|0)==(0|0);
   if (!($713)) {
    $714 = ((($712)) + 8|0);
    $715 = HEAP32[$714>>2]|0;HEAP32[$714>>2] = (($715-1)|0);
    $716 = ($715|0)==(1);
    if ($716) {
     __THREW__ = 0;
     invoke_viii(3262,($712|0),1,1);
     $717 = __THREW__; __THREW__ = 0;
     $718 = $717&1;
     if ($718) {
      break;
     }
    }
   }
   HEAP32[$13>>2] = 0;
   $$15 = $$14;$$1555 = $$1454;
   label = 216;
  }
  else if ((label|0) == 445) {
   $1465 = ($$sroa$0335$8|0)==(0|0);
   if ($1465) {
    $$27 = $$26;$$2767 = $$2666;
    label = 448;
   } else {
    $1466 = ((($$sroa$0335$8)) + 8|0);
    $1467 = HEAP32[$1466>>2]|0;HEAP32[$1466>>2] = (($1467-1)|0);
    $1468 = ($1467|0)==(1);
    if ($1468) {
     __THREW__ = 0;
     invoke_viii(3262,($$sroa$0335$8|0),1,1);
     $1469 = __THREW__; __THREW__ = 0;
     $1470 = $1469&1;
     if (!($1470)) {
      $$27 = $$26;$$2767 = $$2666;
      label = 448;
     }
    } else {
     $$27 = $$26;$$2767 = $$2666;
     label = 448;
    }
   }
  }
 } while(0);
 if ((label|0) == 216) {
  $$29 = $$15;$$2969 = $$1555;$$sroa$0364$8 = $$sroa$0364$01997;$$sroa$0381$5 = $$sroa$0381$2438;$$sroa$0390$7 = $$sroa$0390$4;
  label = 484;
 }
 else if ((label|0) == 448) {
  $1471 = HEAP32[$99>>2]|0;
  $1472 = ($1471|0)==(0|0);
  if (!($1472)) {
   $1473 = ((($1471)) + 8|0);
   $1474 = HEAP32[$1473>>2]|0;HEAP32[$1473>>2] = (($1474-1)|0);
   $1475 = ($1474|0)==(1);
   if ($1475) {
    __THREW__ = 0;
    invoke_viii(3262,($1471|0),1,1);
    $1476 = __THREW__; __THREW__ = 0;
    $1477 = $1476&1;
    if ($1477) {
     $1481 = ___cxa_find_matching_catch_3(0|0)|0;
     $1482 = tempRet0;
     $1483 = HEAP8[$101>>0]|0;
     $1484 = ($1483<<24>>24)<(0);
     if (!($1484)) {
      $eh$lpad$body149$indexZ2D = $1481;
      ___clang_call_terminate($eh$lpad$body149$indexZ2D);
      // unreachable;
     }
     $1485 = HEAP32[$100>>2]|0;
     __ZdlPv($1485);
     $eh$lpad$body149$indexZ2D = $1481;
     ___clang_call_terminate($eh$lpad$body149$indexZ2D);
     // unreachable;
    }
   }
  }
  HEAP32[$99>>2] = 0;
  $1478 = HEAP8[$101>>0]|0;
  $1479 = ($1478<<24>>24)<(0);
  if ($1479) {
   $1480 = HEAP32[$100>>2]|0;
   __ZdlPv($1480);
   $$28 = $$27;$$2868 = $$2767;
   label = 456;
  } else {
   $$28 = $$27;$$2868 = $$2767;
   label = 456;
  }
 }
 if ((label|0) == 456) {
  $$29 = $$28;$$2969 = $$2868;$$sroa$0364$8 = $$sroa$0364$01997;$$sroa$0381$5 = $$sroa$0381$2438;$$sroa$0390$7 = $$sroa$0390$4;
  label = 484;
 }
 if ((label|0) == 484) {
  $1538 = HEAP8[$93>>0]|0;
  $1539 = ($1538<<24>>24)<(0);
  if ($1539) {
   $1540 = HEAP32[$11>>2]|0;
   __ZdlPv($1540);
  }
  $1543 = ($$sroa$0364$8|0)==(0|0);
  if ($1543) {
   $$31 = $$29;$$3171 = $$2969;$$sroa$0381$6 = $$sroa$0381$5;$$sroa$0390$8 = $$sroa$0390$7;
   label = 490;
  } else {
   $1544 = ((($$sroa$0364$8)) + 8|0);
   $1545 = HEAP32[$1544>>2]|0;HEAP32[$1544>>2] = (($1545-1)|0);
   $1546 = ($1545|0)==(1);
   if ($1546) {
    __THREW__ = 0;
    invoke_viii(3262,($$sroa$0364$8|0),1,1);
    $1547 = __THREW__; __THREW__ = 0;
    $1548 = $1547&1;
    if (!($1548)) {
     $$31 = $$29;$$3171 = $$2969;$$sroa$0381$6 = $$sroa$0381$5;$$sroa$0390$8 = $$sroa$0390$7;
     label = 490;
    }
   } else {
    $$31 = $$29;$$3171 = $$2969;$$sroa$0381$6 = $$sroa$0381$5;$$sroa$0390$8 = $$sroa$0390$7;
    label = 490;
   }
  }
 }
 if ((label|0) == 490) {
  $1549 = ($$sroa$0381$6|0)==(0|0);
  if ($1549) {
   $$33 = $$31;$$3373 = $$3171;$$sroa$0390$10 = $$sroa$0390$8;
   label = 495;
  } else {
   $1550 = HEAP32[$$sroa$0381$6>>2]|0;
   $1551 = ((($1550)) + -12|0);
   $1552 = HEAP32[$1551>>2]|0;
   $1553 = (($$sroa$0381$6) + ($1552)|0);
   $1554 = ((($1553)) + 8|0);
   $1555 = HEAP32[$1554>>2]|0;HEAP32[$1554>>2] = (($1555-1)|0);
   $1556 = ($1555|0)==(1);
   if ($1556) {
    __THREW__ = 0;
    invoke_viii(3262,($1553|0),1,1);
    $1557 = __THREW__; __THREW__ = 0;
    $1558 = $1557&1;
    if (!($1558)) {
     $$33 = $$31;$$3373 = $$3171;$$sroa$0390$10 = $$sroa$0390$8;
     label = 495;
    }
   } else {
    $$33 = $$31;$$3373 = $$3171;$$sroa$0390$10 = $$sroa$0390$8;
    label = 495;
   }
  }
 }
 if ((label|0) == 495) {
  $1563 = ($$sroa$0390$10|0)==(0|0);
  if ($1563) {
   $$36 = $$33;$$3676 = $$3373;
   label = 499;
  } else {
   $1564 = ((($$sroa$0390$10)) + 8|0);
   $1565 = HEAP32[$1564>>2]|0;HEAP32[$1564>>2] = (($1565-1)|0);
   $1566 = ($1565|0)==(1);
   if ($1566) {
    __THREW__ = 0;
    invoke_viii(3262,($$sroa$0390$10|0),1,1);
    $1567 = __THREW__; __THREW__ = 0;
    $1568 = $1567&1;
    if (!($1568)) {
     $$36 = $$33;$$3676 = $$3373;
     label = 499;
    }
   } else {
    $$36 = $$33;$$3676 = $$3373;
    label = 499;
   }
  }
 }
 do {
  if ((label|0) == 499) {
   $1571 = HEAP32[$10>>2]|0;
   $1572 = ($1571|0)==(0|0);
   if (!($1572)) {
    $1573 = ((($1571)) + 8|0);
    $1574 = HEAP32[$1573>>2]|0;HEAP32[$1573>>2] = (($1574-1)|0);
    $1575 = ($1574|0)==(1);
    if ($1575) {
     __THREW__ = 0;
     invoke_viii(3262,($1571|0),1,1);
     $1576 = __THREW__; __THREW__ = 0;
     $1577 = $1576&1;
     if ($1577) {
      break;
     }
    }
   }
   HEAP32[$10>>2] = 0;
   $$37 = $$36;$$3777 = $$3676;
   label = 503;
  }
 } while(0);
 if ((label|0) == 503) {
  $$38 = $$37;$$3878 = $$3777;
  label = 505;
 }
 if ((label|0) == 505) {
  $1580 = ($$sroa$0415$4$ph|0)==(0|0);
  if ($1580) {
   $$39 = $$38;$$3979 = $$3878;
   label = 508;
  } else {
   $1581 = ((($$sroa$0415$4$ph)) + 8|0);
   $1582 = HEAP32[$1581>>2]|0;HEAP32[$1581>>2] = (($1582-1)|0);
   $1583 = ($1582|0)==(1);
   if ($1583) {
    __THREW__ = 0;
    invoke_viii(3262,($$sroa$0415$4$ph|0),1,1);
    $1584 = __THREW__; __THREW__ = 0;
    $1585 = $1584&1;
    if (!($1585)) {
     $$39 = $$38;$$3979 = $$3878;
     label = 508;
    }
   } else {
    $$39 = $$38;$$3979 = $$3878;
    label = 508;
   }
  }
 }
 if ((label|0) == 508) {
  $1586 = ($$sroa$0421$6$ph|0)==(0|0);
  if ($1586) {
   ___resumeException($$39|0);
   // unreachable;
  }
  $1587 = ((($$sroa$0421$6$ph)) + 8|0);
  $1588 = HEAP32[$1587>>2]|0;HEAP32[$1587>>2] = (($1588-1)|0);
  $1589 = ($1588|0)==(1);
  if (!($1589)) {
   ___resumeException($$39|0);
   // unreachable;
  }
  __THREW__ = 0;
  invoke_viii(3262,($$sroa$0421$6$ph|0),1,1);
  $1590 = __THREW__; __THREW__ = 0;
  $1591 = $1590&1;
  if (!($1591)) {
   ___resumeException($$39|0);
   // unreachable;
  }
 }
 $1592 = ___cxa_find_matching_catch_3(0|0)|0;
 $1593 = tempRet0;
 $eh$lpad$body149$indexZ2D = $1592;
 ___clang_call_terminate($eh$lpad$body149$indexZ2D);
 // unreachable;
}
function __ZThn12_N5osgDB13DatabasePager14DatabaseThreadD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -12|0);
 __ZN5osgDB13DatabasePager14DatabaseThreadD2Ev($1);
 return;
}
function __ZThn12_N5osgDB13DatabasePager14DatabaseThreadD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -12|0);
 __THREW__ = 0;
 invoke_vi(2582,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch_2()|0;
  $5 = tempRet0;
  __ZdlPv($1);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZdlPv($1);
  return;
 }
}
function __ZThn12_N5osgDB13DatabasePager14DatabaseThread6cancelEv($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -12|0);
 (__ZN5osgDB13DatabasePager14DatabaseThread6cancelEv($1)|0);
 return 0;
}
function __ZThn12_N5osgDB13DatabasePager14DatabaseThread3runEv($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -12|0);
 __ZN5osgDB13DatabasePager14DatabaseThread3runEv($1);
 return;
}
function __ZN5osgDB13DatabasePager12RequestQueue9takeFirstERN3osg7ref_ptrINS0_15DatabaseRequestEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$3 = 0, $$313 = 0, $$sink92$index = 0, $$sink92$index3 = 0, $$sroa$067$0 = 0, $$sroa$067$1 = 0, $$sroa$076$0 = 0, $$sroa$076$1 = 0, $$sroa$076$2 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0;
 var $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0;
 var $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0;
 var $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0;
 var $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0;
 var $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0;
 var $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0.0, $44 = 0, $45 = 0, $46 = 0, $47 = 0.0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0.0, $52 = 0, $53 = 0.0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index10Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp + 8|0;
 $3 = sp + 4|0;
 $4 = sp;
 $5 = ((($0)) + 28|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($6)) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 (FUNCTION_TABLE_ii[$8 & 8191]($5)|0);
 $9 = ((($0)) + 16|0);
 $10 = ((($0)) + 24|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0);
 if ($12) {
  $258 = HEAP32[$5>>2]|0;
  $259 = ((($258)) + 12|0);
  $260 = HEAP32[$259>>2]|0;
  (FUNCTION_TABLE_ii[$260 & 8191]($5)|0);
  STACKTOP = sp;return;
 }
 $13 = $9;
 $14 = ((($0)) + 12|0);
 $15 = HEAP32[$14>>2]|0;
 /* fence */;
 $16 = ((($15)) + 84|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ((($0)) + 20|0);
 $19 = HEAP32[$18>>2]|0;
 $$sroa$067$0 = $19;$$sroa$076$0 = $13;
 while(1) {
  $20 = $$sroa$067$0;
  $21 = ($20|0)==($9|0);
  if ($21) {
   label = 38;
   break;
  }
  $22 = HEAP32[$14>>2]|0;
  $23 = ((($22)) + 24|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = ((($24)) + 8|0);
  $26 = HEAP32[$25>>2]|0;
  __THREW__ = 0;
  (invoke_ii($26|0,($23|0))|0);
  $27 = __THREW__; __THREW__ = 0;
  $28 = $27&1;
  if ($28) {
   label = 12;
   break;
  }
  $29 = $$sroa$067$0;
  $30 = ((($29)) + 8|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = ((($31)) + 12|0);
  $33 = HEAP8[$32>>0]|0;
  $34 = ($33<<24>>24)==(0);
  if ($34) {
   label = 15;
  } else {
   $35 = ((($31)) + 44|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($17) - ($36))|0;
   $38 = ($37>>>0)<(2);
   if ($38) {
    $39 = $$sroa$076$0;
    $40 = ($39|0)==($9|0);
    if ($40) {
     label = 11;
    } else {
     $41 = $$sroa$076$0;
     $42 = ((($31)) + 48|0);
     $43 = +HEAPF64[$42>>3];
     $44 = ((($41)) + 8|0);
     $45 = HEAP32[$44>>2]|0;
     $46 = ((($45)) + 48|0);
     $47 = +HEAPF64[$46>>3];
     $48 = $43 > $47;
     if ($48) {
      label = 11;
     } else {
      $49 = $43 < $47;
      if ($49) {
       $$sroa$076$1 = $$sroa$076$0;
      } else {
       $50 = ((($31)) + 56|0);
       $51 = +HEAPF32[$50>>2];
       $52 = ((($45)) + 56|0);
       $53 = +HEAPF32[$52>>2];
       $54 = $51 > $53;
       if ($54) {
        label = 11;
       } else {
        $$sroa$076$1 = $$sroa$076$0;
       }
      }
     }
    }
    if ((label|0) == 11) {
     label = 0;
     $$sroa$076$1 = $$sroa$067$0;
    }
    $59 = ((($20)) + 4|0);
    $60 = HEAP32[$59>>2]|0;
    $$sroa$067$1 = $60;$$sroa$076$2 = $$sroa$076$1;
   } else {
    label = 15;
   }
  }
  if ((label|0) == 15) {
   label = 0;
   __THREW__ = 0;
   invoke_vii(4117,($0|0),($31|0));
   $61 = __THREW__; __THREW__ = 0;
   $62 = $61&1;
   if ($62) {
    label = 13;
    break;
   }
   __THREW__ = 0;
   $63 = (invoke_ii(3265,4)|0);
   $64 = __THREW__; __THREW__ = 0;
   $65 = $64&1;
   if ($65) {
    label = 13;
    break;
   }
   if ($63) {
    __THREW__ = 0;
    $66 = (invoke_ii(3266,4)|0);
    $67 = __THREW__; __THREW__ = 0;
    $68 = $67&1;
    if ($68) {
     label = 13;
     break;
    }
    __THREW__ = 0;
    $69 = (invoke_iiii(3267,($66|0),(163242|0),50)|0);
    $70 = __THREW__; __THREW__ = 0;
    $71 = $70&1;
    if ($71) {
     label = 13;
     break;
    }
    $72 = HEAP32[$30>>2]|0;
    __THREW__ = 0;
    $73 = (invoke_iii(3275,($69|0),($72|0))|0);
    $74 = __THREW__; __THREW__ = 0;
    $75 = $74&1;
    if ($75) {
     label = 13;
     break;
    }
    $76 = HEAP32[$73>>2]|0;
    $77 = ((($76)) + -12|0);
    $78 = HEAP32[$77>>2]|0;
    $79 = (($73) + ($78)|0);
    __THREW__ = 0;
    invoke_vii(3257,($2|0),($79|0));
    $80 = __THREW__; __THREW__ = 0;
    $81 = $80&1;
    if ($81) {
     label = 13;
     break;
    }
    __THREW__ = 0;
    $82 = (invoke_iii(3255,($2|0),(215188|0))|0);
    $83 = __THREW__; __THREW__ = 0;
    $84 = $83&1;
    if ($84) {
     label = 24;
     break;
    }
    $85 = HEAP32[$82>>2]|0;
    $86 = ((($85)) + 28|0);
    $87 = HEAP32[$86>>2]|0;
    __THREW__ = 0;
    $88 = (invoke_iii($87|0,($82|0),10)|0);
    $89 = __THREW__; __THREW__ = 0;
    $90 = $89&1;
    if ($90) {
     label = 24;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3263,($2|0));
    $97 = __THREW__; __THREW__ = 0;
    $98 = $97&1;
    if ($98) {
     label = 13;
     break;
    }
    __THREW__ = 0;
    (invoke_iii(3268,($73|0),($88|0))|0);
    $99 = __THREW__; __THREW__ = 0;
    $100 = $99&1;
    if ($100) {
     label = 13;
     break;
    }
    __THREW__ = 0;
    (invoke_ii(3269,($73|0))|0);
    $101 = __THREW__; __THREW__ = 0;
    $102 = $101&1;
    if ($102) {
     label = 13;
     break;
    }
   }
   $103 = ((($20)) + 4|0);
   $104 = HEAP32[$103>>2]|0;
   $105 = HEAP32[$20>>2]|0;
   $106 = ((($105)) + 4|0);
   HEAP32[$106>>2] = $104;
   $107 = HEAP32[$103>>2]|0;
   HEAP32[$107>>2] = $105;
   $108 = HEAP32[$10>>2]|0;
   $109 = (($108) + -1)|0;
   HEAP32[$10>>2] = $109;
   $110 = ((($20)) + 8|0);
   $111 = HEAP32[$110>>2]|0;
   $112 = ($111|0)==(0|0);
   if (!($112)) {
    $113 = ((($111)) + 8|0);
    $114 = HEAP32[$113>>2]|0;HEAP32[$113>>2] = (($114-1)|0);
    $115 = ($114|0)==(1);
    if ($115) {
     __THREW__ = 0;
     invoke_viii(3262,($111|0),1,1);
     $116 = __THREW__; __THREW__ = 0;
     $117 = $116&1;
     if ($117) {
      label = 34;
      break;
     }
    }
   }
   $118 = $$sroa$067$0;
   __ZdlPv($118);
   $$sroa$067$1 = $104;$$sroa$076$2 = $$sroa$076$0;
  }
  $121 = HEAP32[$23>>2]|0;
  $122 = ((($121)) + 12|0);
  $123 = HEAP32[$122>>2]|0;
  __THREW__ = 0;
  (invoke_ii($123|0,($23|0))|0);
  $124 = __THREW__; __THREW__ = 0;
  $125 = $124&1;
  if ($125) {
   label = 36;
   break;
  } else {
   $$sroa$067$0 = $$sroa$067$1;$$sroa$076$0 = $$sroa$076$2;
  }
 }
 do {
  if ((label|0) == 12) {
   $55 = ___cxa_find_matching_catch_2()|0;
   $56 = tempRet0;
   $$3 = $55;$$313 = $56;
  }
  else if ((label|0) == 13) {
   $57 = ___cxa_find_matching_catch_2()|0;
   $58 = tempRet0;
   $$sink92$index = $57;$$sink92$index3 = $58;
   label = 37;
  }
  else if ((label|0) == 24) {
   $91 = ___cxa_find_matching_catch_2()|0;
   $92 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($2|0));
   $93 = __THREW__; __THREW__ = 0;
   $94 = $93&1;
   if ($94) {
    $95 = ___cxa_find_matching_catch_3(0|0)|0;
    $96 = tempRet0;
    ___clang_call_terminate($95);
    // unreachable;
   } else {
    $$sink92$index = $91;$$sink92$index3 = $92;
    label = 37;
    break;
   }
  }
  else if ((label|0) == 34) {
   $119 = ___cxa_find_matching_catch_2()|0;
   $120 = tempRet0;
   $$sink92$index = $119;$$sink92$index3 = $120;
   label = 37;
  }
  else if ((label|0) == 36) {
   $126 = ___cxa_find_matching_catch_2()|0;
   $127 = tempRet0;
   $$3 = $126;$$313 = $127;
  }
  else if ((label|0) == 38) {
   $133 = ((($0)) + 40|0);
   HEAP32[$133>>2] = $17;
   $134 = $$sroa$076$0;
   $135 = ($134|0)==($9|0);
   do {
    if ($135) {
     __THREW__ = 0;
     $208 = (invoke_ii(3265,4)|0);
     $209 = __THREW__; __THREW__ = 0;
     $210 = $209&1;
     if ($210) {
      label = 62;
     } else {
      if ($208) {
       __THREW__ = 0;
       $211 = (invoke_ii(3266,4)|0);
       $212 = __THREW__; __THREW__ = 0;
       $213 = $212&1;
       if ($213) {
        label = 62;
       } else {
        __THREW__ = 0;
        $214 = (invoke_iiii(3267,($211|0),(163365|0),83)|0);
        $215 = __THREW__; __THREW__ = 0;
        $216 = $215&1;
        if ($216) {
         label = 62;
        } else {
         $217 = HEAP32[$10>>2]|0;
         __THREW__ = 0;
         $218 = (invoke_iii(3417,($214|0),($217|0))|0);
         $219 = __THREW__; __THREW__ = 0;
         $220 = $219&1;
         if ($220) {
          label = 62;
         } else {
          $221 = HEAP32[$218>>2]|0;
          $222 = ((($221)) + -12|0);
          $223 = HEAP32[$222>>2]|0;
          $224 = (($218) + ($223)|0);
          __THREW__ = 0;
          invoke_vii(3257,($4|0),($224|0));
          $225 = __THREW__; __THREW__ = 0;
          $226 = $225&1;
          if ($226) {
           label = 62;
          } else {
           __THREW__ = 0;
           $227 = (invoke_iii(3255,($4|0),(215188|0))|0);
           $228 = __THREW__; __THREW__ = 0;
           $229 = $228&1;
           if (!($229)) {
            $230 = HEAP32[$227>>2]|0;
            $231 = ((($230)) + 28|0);
            $232 = HEAP32[$231>>2]|0;
            __THREW__ = 0;
            $233 = (invoke_iii($232|0,($227|0),10)|0);
            $234 = __THREW__; __THREW__ = 0;
            $235 = $234&1;
            if (!($235)) {
             __THREW__ = 0;
             invoke_vi(3263,($4|0));
             $242 = __THREW__; __THREW__ = 0;
             $243 = $242&1;
             if ($243) {
              label = 62;
              break;
             }
             __THREW__ = 0;
             (invoke_iii(3268,($218|0),($233|0))|0);
             $244 = __THREW__; __THREW__ = 0;
             $245 = $244&1;
             if ($245) {
              label = 62;
              break;
             }
             __THREW__ = 0;
             (invoke_ii(3269,($218|0))|0);
             $246 = __THREW__; __THREW__ = 0;
             $247 = $246&1;
             if ($247) {
              label = 62;
              break;
             } else {
              label = 78;
              break;
             }
            }
           }
           $236 = ___cxa_find_matching_catch_2()|0;
           $237 = tempRet0;
           __THREW__ = 0;
           invoke_vi(3263,($4|0));
           $238 = __THREW__; __THREW__ = 0;
           $239 = $238&1;
           if ($239) {
            $240 = ___cxa_find_matching_catch_3(0|0)|0;
            $241 = tempRet0;
            ___clang_call_terminate($240);
            // unreachable;
           } else {
            $eh$lpad$body$index10Z2D = $237;$eh$lpad$body$indexZ2D = $236;
            break;
           }
          }
         }
        }
       }
      } else {
       label = 78;
      }
     }
    } else {
     $136 = $$sroa$076$0;
     $137 = HEAP32[$1>>2]|0;
     $138 = ((($136)) + 8|0);
     $139 = HEAP32[$138>>2]|0;
     $140 = ($137|0)==($139|0);
     if (!($140)) {
      HEAP32[$1>>2] = $139;
      $141 = ($139|0)==(0|0);
      if (!($141)) {
       $142 = ((($139)) + 8|0);
       $143 = HEAP32[$142>>2]|0;HEAP32[$142>>2] = (($143+1)|0);
      }
      $144 = ($137|0)==(0|0);
      if (!($144)) {
       $145 = ((($137)) + 8|0);
       $146 = HEAP32[$145>>2]|0;HEAP32[$145>>2] = (($146-1)|0);
       $147 = ($146|0)==(1);
       if ($147) {
        __THREW__ = 0;
        invoke_viii(3262,($137|0),1,1);
        $148 = __THREW__; __THREW__ = 0;
        $149 = $148&1;
        if ($149) {
         label = 62;
         break;
        }
       }
      }
     }
     $150 = ((($134)) + 4|0);
     $151 = HEAP32[$150>>2]|0;
     $152 = HEAP32[$134>>2]|0;
     $153 = ((($152)) + 4|0);
     HEAP32[$153>>2] = $151;
     $154 = HEAP32[$150>>2]|0;
     HEAP32[$154>>2] = $152;
     $155 = HEAP32[$10>>2]|0;
     $156 = (($155) + -1)|0;
     HEAP32[$10>>2] = $156;
     $157 = ((($134)) + 8|0);
     $158 = HEAP32[$157>>2]|0;
     $159 = ($158|0)==(0|0);
     if (!($159)) {
      $160 = ((($158)) + 8|0);
      $161 = HEAP32[$160>>2]|0;HEAP32[$160>>2] = (($161-1)|0);
      $162 = ($161|0)==(1);
      if ($162) {
       __THREW__ = 0;
       invoke_viii(3262,($158|0),1,1);
       $163 = __THREW__; __THREW__ = 0;
       $164 = $163&1;
       if ($164) {
        label = 62;
        break;
       }
      }
     }
     $165 = $$sroa$076$0;
     __ZdlPv($165);
     __THREW__ = 0;
     $166 = (invoke_ii(3265,4)|0);
     $167 = __THREW__; __THREW__ = 0;
     $168 = $167&1;
     if ($168) {
      label = 62;
     } else {
      if ($166) {
       __THREW__ = 0;
       $169 = (invoke_ii(3266,4)|0);
       $170 = __THREW__; __THREW__ = 0;
       $171 = $170&1;
       if ($171) {
        label = 62;
       } else {
        __THREW__ = 0;
        $172 = (invoke_iiii(3267,($169|0),(163293|0),71)|0);
        $173 = __THREW__; __THREW__ = 0;
        $174 = $173&1;
        if ($174) {
         label = 62;
        } else {
         $175 = HEAP32[$10>>2]|0;
         __THREW__ = 0;
         $176 = (invoke_iii(3417,($172|0),($175|0))|0);
         $177 = __THREW__; __THREW__ = 0;
         $178 = $177&1;
         if ($178) {
          label = 62;
         } else {
          $179 = HEAP32[$176>>2]|0;
          $180 = ((($179)) + -12|0);
          $181 = HEAP32[$180>>2]|0;
          $182 = (($176) + ($181)|0);
          __THREW__ = 0;
          invoke_vii(3257,($3|0),($182|0));
          $183 = __THREW__; __THREW__ = 0;
          $184 = $183&1;
          if ($184) {
           label = 62;
          } else {
           __THREW__ = 0;
           $185 = (invoke_iii(3255,($3|0),(215188|0))|0);
           $186 = __THREW__; __THREW__ = 0;
           $187 = $186&1;
           if (!($187)) {
            $188 = HEAP32[$185>>2]|0;
            $189 = ((($188)) + 28|0);
            $190 = HEAP32[$189>>2]|0;
            __THREW__ = 0;
            $191 = (invoke_iii($190|0,($185|0),10)|0);
            $192 = __THREW__; __THREW__ = 0;
            $193 = $192&1;
            if (!($193)) {
             __THREW__ = 0;
             invoke_vi(3263,($3|0));
             $200 = __THREW__; __THREW__ = 0;
             $201 = $200&1;
             if ($201) {
              label = 62;
              break;
             }
             __THREW__ = 0;
             (invoke_iii(3268,($176|0),($191|0))|0);
             $202 = __THREW__; __THREW__ = 0;
             $203 = $202&1;
             if ($203) {
              label = 62;
              break;
             }
             __THREW__ = 0;
             (invoke_ii(3269,($176|0))|0);
             $204 = __THREW__; __THREW__ = 0;
             $205 = $204&1;
             if ($205) {
              label = 62;
              break;
             } else {
              label = 78;
              break;
             }
            }
           }
           $194 = ___cxa_find_matching_catch_2()|0;
           $195 = tempRet0;
           __THREW__ = 0;
           invoke_vi(3263,($3|0));
           $196 = __THREW__; __THREW__ = 0;
           $197 = $196&1;
           if ($197) {
            $198 = ___cxa_find_matching_catch_3(0|0)|0;
            $199 = tempRet0;
            ___clang_call_terminate($198);
            // unreachable;
           } else {
            $eh$lpad$body$index10Z2D = $195;$eh$lpad$body$indexZ2D = $194;
            break;
           }
          }
         }
        }
       }
      } else {
       label = 78;
      }
     }
    }
   } while(0);
   if ((label|0) == 78) {
    $248 = HEAP32[$0>>2]|0;
    $249 = ((($248)) + 12|0);
    $250 = HEAP32[$249>>2]|0;
    __THREW__ = 0;
    invoke_vi($250|0,($0|0));
    $251 = __THREW__; __THREW__ = 0;
    $252 = $251&1;
    if ($252) {
     label = 62;
    } else {
     $258 = HEAP32[$5>>2]|0;
     $259 = ((($258)) + 12|0);
     $260 = HEAP32[$259>>2]|0;
     (FUNCTION_TABLE_ii[$260 & 8191]($5)|0);
     STACKTOP = sp;return;
    }
   }
   if ((label|0) == 62) {
    $206 = ___cxa_find_matching_catch_2()|0;
    $207 = tempRet0;
    $eh$lpad$body$index10Z2D = $207;$eh$lpad$body$indexZ2D = $206;
   }
   $$3 = $eh$lpad$body$indexZ2D;$$313 = $eh$lpad$body$index10Z2D;
  }
 } while(0);
 if ((label|0) == 37) {
  $128 = HEAP32[$23>>2]|0;
  $129 = ((($128)) + 12|0);
  $130 = HEAP32[$129>>2]|0;
  __THREW__ = 0;
  (invoke_ii($130|0,($23|0))|0);
  $131 = __THREW__; __THREW__ = 0;
  $132 = $131&1;
  if ($132) {
   $261 = ___cxa_find_matching_catch_3(0|0)|0;
   $262 = tempRet0;
   ___clang_call_terminate($261);
   // unreachable;
  } else {
   $$3 = $$sink92$index;$$313 = $$sink92$index3;
  }
 }
 $253 = HEAP32[$5>>2]|0;
 $254 = ((($253)) + 12|0);
 $255 = HEAP32[$254>>2]|0;
 __THREW__ = 0;
 (invoke_ii($255|0,($5|0))|0);
 $256 = __THREW__; __THREW__ = 0;
 $257 = $256&1;
 if ($257) {
  $261 = ___cxa_find_matching_catch_3(0|0)|0;
  $262 = tempRet0;
  ___clang_call_terminate($261);
  // unreachable;
 } else {
  ___resumeException($$3|0);
  // unreachable;
 }
}
function __ZN5osgDB13DatabasePager12RequestQueue9addNoLockEPNS0_15DatabaseRequestE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 16|0);
 $3 = ($1|0)==(0|0);
 if (!($3)) {
  $4 = ((($1)) + 8|0);
  $5 = HEAP32[$4>>2]|0;HEAP32[$4>>2] = (($5+1)|0);
 }
 __THREW__ = 0;
 $6 = (invoke_ii(3276,12)|0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $24 = ___cxa_find_matching_catch_2()|0;
  $25 = tempRet0;
  if ($3) {
   ___resumeException($24|0);
   // unreachable;
  }
  $26 = ((($1)) + 8|0);
  $27 = HEAP32[$26>>2]|0;HEAP32[$26>>2] = (($27-1)|0);
  $28 = ($27|0)==(1);
  if (!($28)) {
   ___resumeException($24|0);
   // unreachable;
  }
  __THREW__ = 0;
  invoke_viii(3262,($1|0),1,1);
  $29 = __THREW__; __THREW__ = 0;
  $30 = $29&1;
  if ($30) {
   $31 = ___cxa_find_matching_catch_3(0|0)|0;
   $32 = tempRet0;
   ___clang_call_terminate($31);
   // unreachable;
  } else {
   ___resumeException($24|0);
   // unreachable;
  }
 }
 $9 = ((($6)) + 8|0);
 HEAP32[$9>>2] = $1;
 if (!($3)) {
  $10 = ((($1)) + 8|0);
  $11 = HEAP32[$10>>2]|0;HEAP32[$10>>2] = (($11+1)|0);
 }
 $12 = ((($6)) + 4|0);
 HEAP32[$12>>2] = $2;
 $13 = HEAP32[$2>>2]|0;
 HEAP32[$6>>2] = $13;
 $14 = ((($13)) + 4|0);
 HEAP32[$14>>2] = $6;
 HEAP32[$2>>2] = $6;
 $15 = ((($0)) + 24|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + 1)|0;
 HEAP32[$15>>2] = $17;
 if ($3) {
  $21 = HEAP32[$0>>2]|0;
  $22 = ((($21)) + 12|0);
  $23 = HEAP32[$22>>2]|0;
  FUNCTION_TABLE_vi[$23 & 8191]($0);
  return;
 }
 $18 = ((($1)) + 8|0);
 $19 = HEAP32[$18>>2]|0;HEAP32[$18>>2] = (($19-1)|0);
 $20 = ($19|0)==(1);
 if (!($20)) {
  $21 = HEAP32[$0>>2]|0;
  $22 = ((($21)) + 12|0);
  $23 = HEAP32[$22>>2]|0;
  FUNCTION_TABLE_vi[$23 & 8191]($0);
  return;
 }
 __ZNK3osg10Referenced24signalObserversAndDeleteEbb($1,1,1);
 $21 = HEAP32[$0>>2]|0;
 $22 = ((($21)) + 12|0);
 $23 = HEAP32[$22>>2]|0;
 FUNCTION_TABLE_vi[$23 & 8191]($0);
 return;
}
function __ZN5osgDB8Registry8readNodeERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEPKNS_7OptionsEb($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0 = 0, $$014 = 0, $$1 = 0, $$115 = 0, $$2 = 0, $$216 = 0, $$3 = 0, $$317 = 0, $$pre = 0, $$pre$phi50Z2D = 0, $$pre$phi52Z2D = 0, $$pre$phiZ2D = 0, $$pre49 = 0, $$pre51 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0;
 var $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0;
 var $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0;
 var $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0;
 var $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0;
 var $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$indexZ2D = 0;
 var $eh$lpad$body21$index3Z2D = 0, $eh$lpad$body21$indexZ2D = 0, $eh$lpad$body32$index10Z2D = 0, $eh$lpad$body32$indexZ2D = 0, $eh$lpad$body43$index17Z2D = 0, $eh$lpad$body43$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(64|0);
 $5 = sp + 40|0;
 $6 = sp + 20|0;
 $7 = sp;
 HEAP32[$0>>2] = 1;
 $8 = ((($0)) + 4|0);
 ;HEAP32[$8>>2]=0|0;HEAP32[$8+4>>2]=0|0;HEAP32[$8+8>>2]=0|0;HEAP32[$8+12>>2]=0|0;
 $9 = ($3|0)==(0|0);
 L1: do {
  if ($9) {
   label = 32;
  } else {
   $10 = ((($3)) + 116|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = ($11|0)==(0|0);
   if ($12) {
    label = 32;
   } else {
    $13 = HEAP32[$11>>2]|0;
    $14 = ((($13)) + 16|0);
    $15 = HEAP32[$14>>2]|0;
    __THREW__ = 0;
    invoke_viiii($15|0,($5|0),($11|0),($2|0),($3|0));
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    L4: do {
     if ($17) {
      $58 = ___cxa_find_matching_catch_2()|0;
      $59 = tempRet0;
      $eh$lpad$body21$index3Z2D = $59;$eh$lpad$body21$indexZ2D = $58;
      label = 23;
     } else {
      $18 = ($5|0)==($0|0);
      do {
       if ($18) {
        $$pre51 = ((($5)) + 16|0);
        $$pre$phi52Z2D = $$pre51;
       } else {
        $19 = HEAP32[$5>>2]|0;
        HEAP32[$0>>2] = $19;
        $20 = ((($5)) + 4|0);
        __THREW__ = 0;
        (invoke_iii(3477,($8|0),($20|0))|0);
        $21 = __THREW__; __THREW__ = 0;
        $22 = $21&1;
        if (!($22)) {
         $23 = ((($0)) + 16|0);
         $24 = HEAP32[$23>>2]|0;
         $25 = ((($5)) + 16|0);
         $26 = HEAP32[$25>>2]|0;
         $27 = ($24|0)==($26|0);
         if ($27) {
          $$pre$phi52Z2D = $25;
          break;
         }
         HEAP32[$23>>2] = $26;
         $28 = ($26|0)==(0|0);
         if (!($28)) {
          $29 = ((($26)) + 8|0);
          $30 = HEAP32[$29>>2]|0;HEAP32[$29>>2] = (($30+1)|0);
         }
         $31 = ($24|0)==(0|0);
         if ($31) {
          $$pre$phi52Z2D = $25;
          break;
         }
         $32 = ((($24)) + 8|0);
         $33 = HEAP32[$32>>2]|0;HEAP32[$32>>2] = (($33-1)|0);
         $34 = ($33|0)==(1);
         if (!($34)) {
          $$pre$phi52Z2D = $25;
          break;
         }
         __THREW__ = 0;
         invoke_viii(3262,($24|0),1,1);
         $35 = __THREW__; __THREW__ = 0;
         $36 = $35&1;
         if (!($36)) {
          $$pre$phi52Z2D = $25;
          break;
         }
        }
        $60 = ___cxa_find_matching_catch_2()|0;
        $61 = tempRet0;
        $62 = ((($5)) + 16|0);
        $63 = HEAP32[$62>>2]|0;
        $64 = ($63|0)==(0|0);
        if (!($64)) {
         $65 = ((($63)) + 8|0);
         $66 = HEAP32[$65>>2]|0;HEAP32[$65>>2] = (($66-1)|0);
         $67 = ($66|0)==(1);
         if ($67) {
          __THREW__ = 0;
          invoke_viii(3262,($63|0),1,1);
          $68 = __THREW__; __THREW__ = 0;
          $69 = $68&1;
          if ($69) {
           $74 = ___cxa_find_matching_catch_3(0|0)|0;
           $75 = tempRet0;
           $76 = ((($20)) + 11|0);
           $77 = HEAP8[$76>>0]|0;
           $78 = ($77<<24>>24)<(0);
           if (!($78)) {
            $eh$lpad$body$indexZ2D = $74;
            ___clang_call_terminate($eh$lpad$body$indexZ2D);
            // unreachable;
           }
           $79 = HEAP32[$20>>2]|0;
           __ZdlPv($79);
           $eh$lpad$body$indexZ2D = $74;
           ___clang_call_terminate($eh$lpad$body$indexZ2D);
           // unreachable;
          }
         }
        }
        HEAP32[$62>>2] = 0;
        $70 = ((($20)) + 11|0);
        $71 = HEAP8[$70>>0]|0;
        $72 = ($71<<24>>24)<(0);
        if (!($72)) {
         $$0 = $61;$$014 = $60;
         break L4;
        }
        $73 = HEAP32[$20>>2]|0;
        __ZdlPv($73);
        $$0 = $61;$$014 = $60;
        break L4;
       }
      } while(0);
      $37 = HEAP32[$$pre$phi52Z2D>>2]|0;
      $38 = ($37|0)==(0|0);
      if (!($38)) {
       $39 = ((($37)) + 8|0);
       $40 = HEAP32[$39>>2]|0;HEAP32[$39>>2] = (($40-1)|0);
       $41 = ($40|0)==(1);
       if ($41) {
        __THREW__ = 0;
        invoke_viii(3262,($37|0),1,1);
        $42 = __THREW__; __THREW__ = 0;
        $43 = $42&1;
        if ($43) {
         $49 = ___cxa_find_matching_catch_2()|0;
         $50 = tempRet0;
         $51 = ((($5)) + 4|0);
         $52 = ((($51)) + 11|0);
         $53 = HEAP8[$52>>0]|0;
         $54 = ($53<<24>>24)<(0);
         if (!($54)) {
          $eh$lpad$body21$index3Z2D = $50;$eh$lpad$body21$indexZ2D = $49;
          label = 23;
          break;
         }
         $55 = HEAP32[$51>>2]|0;
         __ZdlPv($55);
         $eh$lpad$body21$index3Z2D = $50;$eh$lpad$body21$indexZ2D = $49;
         label = 23;
         break;
        }
       }
      }
      HEAP32[$$pre$phi52Z2D>>2] = 0;
      $44 = ((($5)) + 4|0);
      $45 = ((($44)) + 11|0);
      $46 = HEAP8[$45>>0]|0;
      $47 = ($46<<24>>24)<(0);
      if ($47) {
       $48 = HEAP32[$44>>2]|0;
       __ZdlPv($48);
      }
      label = 89;
      break L1;
     }
    } while(0);
    if ((label|0) == 23) {
     $$0 = $eh$lpad$body21$index3Z2D;$$014 = $eh$lpad$body21$indexZ2D;
    }
    $$3 = $$0;$$317 = $$014;
   }
  }
 } while(0);
 L42: do {
  if ((label|0) == 32) {
   $80 = ((($1)) + 48|0);
   $81 = HEAP32[$80>>2]|0;
   $82 = ($81|0)==(0|0);
   if ($82) {
    __THREW__ = 0;
    invoke_viiii(4132,($7|0),($1|0),($2|0),($3|0));
    $148 = __THREW__; __THREW__ = 0;
    $149 = $148&1;
    L46: do {
     if ($149) {
      $188 = ___cxa_find_matching_catch_2()|0;
      $189 = tempRet0;
      $eh$lpad$body43$index17Z2D = $189;$eh$lpad$body43$indexZ2D = $188;
      label = 80;
     } else {
      $150 = ($7|0)==($0|0);
      do {
       if ($150) {
        $$pre = ((($7)) + 16|0);
        $$pre$phiZ2D = $$pre;
       } else {
        $151 = HEAP32[$7>>2]|0;
        HEAP32[$0>>2] = $151;
        $152 = ((($7)) + 4|0);
        __THREW__ = 0;
        (invoke_iii(3477,($8|0),($152|0))|0);
        $153 = __THREW__; __THREW__ = 0;
        $154 = $153&1;
        if (!($154)) {
         $155 = ((($0)) + 16|0);
         $156 = HEAP32[$155>>2]|0;
         $157 = ((($7)) + 16|0);
         $158 = HEAP32[$157>>2]|0;
         $159 = ($156|0)==($158|0);
         if ($159) {
          $$pre$phiZ2D = $157;
          break;
         }
         HEAP32[$155>>2] = $158;
         $160 = ($158|0)==(0|0);
         if (!($160)) {
          $161 = ((($158)) + 8|0);
          $162 = HEAP32[$161>>2]|0;HEAP32[$161>>2] = (($162+1)|0);
         }
         $163 = ($156|0)==(0|0);
         if ($163) {
          $$pre$phiZ2D = $157;
          break;
         }
         $164 = ((($156)) + 8|0);
         $165 = HEAP32[$164>>2]|0;HEAP32[$164>>2] = (($165-1)|0);
         $166 = ($165|0)==(1);
         if (!($166)) {
          $$pre$phiZ2D = $157;
          break;
         }
         __THREW__ = 0;
         invoke_viii(3262,($156|0),1,1);
         $167 = __THREW__; __THREW__ = 0;
         $168 = $167&1;
         if (!($168)) {
          $$pre$phiZ2D = $157;
          break;
         }
        }
        $190 = ___cxa_find_matching_catch_2()|0;
        $191 = tempRet0;
        $192 = ((($7)) + 16|0);
        $193 = HEAP32[$192>>2]|0;
        $194 = ($193|0)==(0|0);
        if (!($194)) {
         $195 = ((($193)) + 8|0);
         $196 = HEAP32[$195>>2]|0;HEAP32[$195>>2] = (($196-1)|0);
         $197 = ($196|0)==(1);
         if ($197) {
          __THREW__ = 0;
          invoke_viii(3262,($193|0),1,1);
          $198 = __THREW__; __THREW__ = 0;
          $199 = $198&1;
          if ($199) {
           $204 = ___cxa_find_matching_catch_3(0|0)|0;
           $205 = tempRet0;
           $206 = ((($152)) + 11|0);
           $207 = HEAP8[$206>>0]|0;
           $208 = ($207<<24>>24)<(0);
           if (!($208)) {
            $eh$lpad$body$indexZ2D = $204;
            ___clang_call_terminate($eh$lpad$body$indexZ2D);
            // unreachable;
           }
           $209 = HEAP32[$152>>2]|0;
           __ZdlPv($209);
           $eh$lpad$body$indexZ2D = $204;
           ___clang_call_terminate($eh$lpad$body$indexZ2D);
           // unreachable;
          }
         }
        }
        HEAP32[$192>>2] = 0;
        $200 = ((($152)) + 11|0);
        $201 = HEAP8[$200>>0]|0;
        $202 = ($201<<24>>24)<(0);
        if (!($202)) {
         $$2 = $191;$$216 = $190;
         break L46;
        }
        $203 = HEAP32[$152>>2]|0;
        __ZdlPv($203);
        $$2 = $191;$$216 = $190;
        break L46;
       }
      } while(0);
      $169 = HEAP32[$$pre$phiZ2D>>2]|0;
      $170 = ($169|0)==(0|0);
      if (!($170)) {
       $171 = ((($169)) + 8|0);
       $172 = HEAP32[$171>>2]|0;HEAP32[$171>>2] = (($172-1)|0);
       $173 = ($172|0)==(1);
       if ($173) {
        __THREW__ = 0;
        invoke_viii(3262,($169|0),1,1);
        $174 = __THREW__; __THREW__ = 0;
        $175 = $174&1;
        if ($175) {
         $181 = ___cxa_find_matching_catch_2()|0;
         $182 = tempRet0;
         $183 = ((($7)) + 4|0);
         $184 = ((($183)) + 11|0);
         $185 = HEAP8[$184>>0]|0;
         $186 = ($185<<24>>24)<(0);
         if (!($186)) {
          $eh$lpad$body43$index17Z2D = $182;$eh$lpad$body43$indexZ2D = $181;
          label = 80;
          break;
         }
         $187 = HEAP32[$183>>2]|0;
         __ZdlPv($187);
         $eh$lpad$body43$index17Z2D = $182;$eh$lpad$body43$indexZ2D = $181;
         label = 80;
         break;
        }
       }
      }
      HEAP32[$$pre$phiZ2D>>2] = 0;
      $176 = ((($7)) + 4|0);
      $177 = ((($176)) + 11|0);
      $178 = HEAP8[$177>>0]|0;
      $179 = ($178<<24>>24)<(0);
      if ($179) {
       $180 = HEAP32[$176>>2]|0;
       __ZdlPv($180);
      }
      label = 89;
      break L42;
     }
    } while(0);
    if ((label|0) == 80) {
     $$2 = $eh$lpad$body43$index17Z2D;$$216 = $eh$lpad$body43$indexZ2D;
    }
    $$3 = $$2;$$317 = $$216;
    break;
   } else {
    $83 = HEAP32[$81>>2]|0;
    $84 = ((($83)) + 16|0);
    $85 = HEAP32[$84>>2]|0;
    __THREW__ = 0;
    invoke_viiii($85|0,($6|0),($81|0),($2|0),($3|0));
    $86 = __THREW__; __THREW__ = 0;
    $87 = $86&1;
    L85: do {
     if ($87) {
      $126 = ___cxa_find_matching_catch_2()|0;
      $127 = tempRet0;
      $eh$lpad$body32$index10Z2D = $127;$eh$lpad$body32$indexZ2D = $126;
      label = 52;
     } else {
      $88 = ($6|0)==($0|0);
      do {
       if ($88) {
        $$pre49 = ((($6)) + 16|0);
        $$pre$phi50Z2D = $$pre49;
       } else {
        $89 = HEAP32[$6>>2]|0;
        HEAP32[$0>>2] = $89;
        $90 = ((($6)) + 4|0);
        __THREW__ = 0;
        (invoke_iii(3477,($8|0),($90|0))|0);
        $91 = __THREW__; __THREW__ = 0;
        $92 = $91&1;
        if (!($92)) {
         $93 = ((($0)) + 16|0);
         $94 = HEAP32[$93>>2]|0;
         $95 = ((($6)) + 16|0);
         $96 = HEAP32[$95>>2]|0;
         $97 = ($94|0)==($96|0);
         if ($97) {
          $$pre$phi50Z2D = $95;
          break;
         }
         HEAP32[$93>>2] = $96;
         $98 = ($96|0)==(0|0);
         if (!($98)) {
          $99 = ((($96)) + 8|0);
          $100 = HEAP32[$99>>2]|0;HEAP32[$99>>2] = (($100+1)|0);
         }
         $101 = ($94|0)==(0|0);
         if ($101) {
          $$pre$phi50Z2D = $95;
          break;
         }
         $102 = ((($94)) + 8|0);
         $103 = HEAP32[$102>>2]|0;HEAP32[$102>>2] = (($103-1)|0);
         $104 = ($103|0)==(1);
         if (!($104)) {
          $$pre$phi50Z2D = $95;
          break;
         }
         __THREW__ = 0;
         invoke_viii(3262,($94|0),1,1);
         $105 = __THREW__; __THREW__ = 0;
         $106 = $105&1;
         if (!($106)) {
          $$pre$phi50Z2D = $95;
          break;
         }
        }
        $128 = ___cxa_find_matching_catch_2()|0;
        $129 = tempRet0;
        $130 = ((($6)) + 16|0);
        $131 = HEAP32[$130>>2]|0;
        $132 = ($131|0)==(0|0);
        if (!($132)) {
         $133 = ((($131)) + 8|0);
         $134 = HEAP32[$133>>2]|0;HEAP32[$133>>2] = (($134-1)|0);
         $135 = ($134|0)==(1);
         if ($135) {
          __THREW__ = 0;
          invoke_viii(3262,($131|0),1,1);
          $136 = __THREW__; __THREW__ = 0;
          $137 = $136&1;
          if ($137) {
           $142 = ___cxa_find_matching_catch_3(0|0)|0;
           $143 = tempRet0;
           $144 = ((($90)) + 11|0);
           $145 = HEAP8[$144>>0]|0;
           $146 = ($145<<24>>24)<(0);
           if (!($146)) {
            $eh$lpad$body$indexZ2D = $142;
            ___clang_call_terminate($eh$lpad$body$indexZ2D);
            // unreachable;
           }
           $147 = HEAP32[$90>>2]|0;
           __ZdlPv($147);
           $eh$lpad$body$indexZ2D = $142;
           ___clang_call_terminate($eh$lpad$body$indexZ2D);
           // unreachable;
          }
         }
        }
        HEAP32[$130>>2] = 0;
        $138 = ((($90)) + 11|0);
        $139 = HEAP8[$138>>0]|0;
        $140 = ($139<<24>>24)<(0);
        if (!($140)) {
         $$1 = $129;$$115 = $128;
         break L85;
        }
        $141 = HEAP32[$90>>2]|0;
        __ZdlPv($141);
        $$1 = $129;$$115 = $128;
        break L85;
       }
      } while(0);
      $107 = HEAP32[$$pre$phi50Z2D>>2]|0;
      $108 = ($107|0)==(0|0);
      if (!($108)) {
       $109 = ((($107)) + 8|0);
       $110 = HEAP32[$109>>2]|0;HEAP32[$109>>2] = (($110-1)|0);
       $111 = ($110|0)==(1);
       if ($111) {
        __THREW__ = 0;
        invoke_viii(3262,($107|0),1,1);
        $112 = __THREW__; __THREW__ = 0;
        $113 = $112&1;
        if ($113) {
         $119 = ___cxa_find_matching_catch_2()|0;
         $120 = tempRet0;
         $121 = ((($6)) + 4|0);
         $122 = ((($121)) + 11|0);
         $123 = HEAP8[$122>>0]|0;
         $124 = ($123<<24>>24)<(0);
         if (!($124)) {
          $eh$lpad$body32$index10Z2D = $120;$eh$lpad$body32$indexZ2D = $119;
          label = 52;
          break;
         }
         $125 = HEAP32[$121>>2]|0;
         __ZdlPv($125);
         $eh$lpad$body32$index10Z2D = $120;$eh$lpad$body32$indexZ2D = $119;
         label = 52;
         break;
        }
       }
      }
      HEAP32[$$pre$phi50Z2D>>2] = 0;
      $114 = ((($6)) + 4|0);
      $115 = ((($114)) + 11|0);
      $116 = HEAP8[$115>>0]|0;
      $117 = ($116<<24>>24)<(0);
      if ($117) {
       $118 = HEAP32[$114>>2]|0;
       __ZdlPv($118);
      }
      label = 89;
      break L42;
     }
    } while(0);
    if ((label|0) == 52) {
     $$1 = $eh$lpad$body32$index10Z2D;$$115 = $eh$lpad$body32$indexZ2D;
    }
    $$3 = $$1;$$317 = $$115;
    break;
   }
  }
 } while(0);
 do {
  if ((label|0) == 89) {
   if (!($4)) {
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   invoke_viii(4133,($1|0),($0|0),($3|0));
   $210 = __THREW__; __THREW__ = 0;
   $211 = $210&1;
   if ($211) {
    $56 = ___cxa_find_matching_catch_2()|0;
    $57 = tempRet0;
    $$3 = $57;$$317 = $56;
    break;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $212 = ((($0)) + 16|0);
 $213 = HEAP32[$212>>2]|0;
 $214 = ($213|0)==(0|0);
 if (!($214)) {
  $215 = ((($213)) + 8|0);
  $216 = HEAP32[$215>>2]|0;HEAP32[$215>>2] = (($216-1)|0);
  $217 = ($216|0)==(1);
  if ($217) {
   __THREW__ = 0;
   invoke_viii(3262,($213|0),1,1);
   $218 = __THREW__; __THREW__ = 0;
   $219 = $218&1;
   if ($219) {
    $224 = ___cxa_find_matching_catch_3(0|0)|0;
    $225 = tempRet0;
    $226 = ((($8)) + 11|0);
    $227 = HEAP8[$226>>0]|0;
    $228 = ($227<<24>>24)<(0);
    if (!($228)) {
     $eh$lpad$body$indexZ2D = $224;
     ___clang_call_terminate($eh$lpad$body$indexZ2D);
     // unreachable;
    }
    $229 = HEAP32[$8>>2]|0;
    __ZdlPv($229);
    $eh$lpad$body$indexZ2D = $224;
    ___clang_call_terminate($eh$lpad$body$indexZ2D);
    // unreachable;
   }
  }
 }
 HEAP32[$212>>2] = 0;
 $220 = ((($8)) + 11|0);
 $221 = HEAP8[$220>>0]|0;
 $222 = ($221<<24>>24)<(0);
 if (!($222)) {
  ___resumeException($$317|0);
  // unreachable;
 }
 $223 = HEAP32[$8>>2]|0;
 __ZdlPv($223);
 ___resumeException($$317|0);
 // unreachable;
}
function __ZN5osgDB13DatabasePager31FindCompileableGLObjectsVisitorC1EPKS0_PN3osg6ObjectE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$06 = 0, $$pre$phiZ2D = 0, $$sink = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 148|0);
 __ZN3osg10ReferencedC2Ev($3);
 HEAP32[$3>>2] = (63412);
 $4 = ((($0)) + 160|0);
 ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;
 $5 = ((($0)) + 172|0);
 HEAP32[$5>>2] = 2;
 $6 = ((($0)) + 176|0);
 HEAP32[$6>>2] = 0;
 __THREW__ = 0;
 invoke_viiii(4134,($0|0),((73656)|0),12,($2|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $28 = ___cxa_find_matching_catch_2()|0;
  $29 = tempRet0;
  $$0 = $29;$$06 = $28;
 } else {
  HEAP32[$0>>2] = (73160);
  HEAP32[$3>>2] = (73512);
  $9 = ((($0)) + 132|0);
  HEAP32[$9>>2] = $1;
  $10 = ((($0)) + 136|0);
  $11 = ((($0)) + 137|0);
  $12 = ((($0)) + 138|0);
  $13 = ((($0)) + 140|0);
  $14 = ((($0)) + 144|0);
  HEAP32[$14>>2] = 0;
  $15 = ((($1)) + 108|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = ((($0)) + 120|0);
  HEAP8[$17>>0] = $16;
  $18 = ((($1)) + 109|0);
  $19 = HEAP8[$18>>0]|0;
  HEAP8[$10>>0] = $19;
  $20 = ((($1)) + 110|0);
  $21 = HEAP8[$20>>0]|0;
  HEAP8[$11>>0] = $21;
  $22 = ((($1)) + 111|0);
  $23 = HEAP8[$22>>0]|0;
  HEAP8[$12>>0] = $23;
  $24 = ((($1)) + 112|0);
  $25 = HEAP32[$24>>2]|0;
  HEAP32[$13>>2] = $25;
  $26 = ((($1)) + 104|0);
  $27 = HEAP32[$26>>2]|0;
  switch ($27|0) {
  case 3:  {
   $37 = ((($0)) + 80|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = $38 & -68;
   $40 = $39 | 2;
   HEAP32[$37>>2] = $40;
   $41 = $39 | 130;
   $$pre$phiZ2D = $37;$$sink = $41;
   label = 7;
   break;
  }
  case 1:  {
   $30 = ((($0)) + 80|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = $31 | 129;
   HEAP32[$30>>2] = $32;
   $33 = $32 & -65;
   $$pre$phiZ2D = $30;$$sink = $33;
   label = 7;
   break;
  }
  case 2:  {
   $34 = ((($0)) + 80|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = $35 | 64;
   $$pre$phiZ2D = $34;$$sink = $36;
   label = 7;
   break;
  }
  default: {
  }
  }
  if ((label|0) == 7) {
   HEAP32[$$pre$phiZ2D>>2] = $$sink;
  }
  __THREW__ = 0;
  $42 = (invoke_ii(3482,0)|0);
  $43 = __THREW__; __THREW__ = 0;
  $44 = $43&1;
  if (!($44)) {
   $45 = ((($42)) + 12|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = ($46|0)==(2);
   if (!($47)) {
    return;
   }
   __THREW__ = 0;
   $48 = (invoke_ii(3482,0)|0);
   $49 = __THREW__; __THREW__ = 0;
   $50 = $49&1;
   if (!($50)) {
    $51 = ((($48)) + 16|0);
    $52 = HEAP32[$51>>2]|0;
    $53 = ($52|0)==(0|0);
    if ($53) {
     return;
    }
    __THREW__ = 0;
    $54 = (invoke_ii(3482,0)|0);
    $55 = __THREW__; __THREW__ = 0;
    $56 = $55&1;
    if (!($56)) {
     $57 = ((($54)) + 16|0);
     $58 = HEAP32[$57>>2]|0;
     $59 = HEAP32[$58>>2]|0;
     $60 = ((($59)) + 200|0);
     $61 = HEAP32[$60>>2]|0;
     __THREW__ = 0;
     $62 = (invoke_ii($61|0,($58|0))|0);
     $63 = __THREW__; __THREW__ = 0;
     $64 = $63&1;
     if (!($64)) {
      $65 = HEAP32[$14>>2]|0;
      $66 = ($65|0)==($62|0);
      if ($66) {
       return;
      }
      HEAP32[$14>>2] = $62;
      $67 = ($62|0)==(0|0);
      if (!($67)) {
       $68 = HEAP32[$62>>2]|0;
       $69 = ((($68)) + -12|0);
       $70 = HEAP32[$69>>2]|0;
       $71 = (($62) + ($70)|0);
       $72 = ((($71)) + 8|0);
       $73 = HEAP32[$72>>2]|0;HEAP32[$72>>2] = (($73+1)|0);
      }
      $74 = ($65|0)==(0|0);
      if ($74) {
       return;
      }
      $75 = HEAP32[$65>>2]|0;
      $76 = ((($75)) + -12|0);
      $77 = HEAP32[$76>>2]|0;
      $78 = (($65) + ($77)|0);
      $79 = ((($78)) + 8|0);
      $80 = HEAP32[$79>>2]|0;HEAP32[$79>>2] = (($80-1)|0);
      $81 = ($80|0)==(1);
      if (!($81)) {
       return;
      }
      __THREW__ = 0;
      invoke_viii(3262,($78|0),1,1);
      $82 = __THREW__; __THREW__ = 0;
      $83 = $82&1;
      if (!($83)) {
       return;
      }
     }
    }
   }
  }
  $84 = ___cxa_find_matching_catch_2()|0;
  $85 = tempRet0;
  $86 = HEAP32[$14>>2]|0;
  $87 = ($86|0)==(0|0);
  if (!($87)) {
   $88 = HEAP32[$86>>2]|0;
   $89 = ((($88)) + -12|0);
   $90 = HEAP32[$89>>2]|0;
   $91 = (($86) + ($90)|0);
   $92 = ((($91)) + 8|0);
   $93 = HEAP32[$92>>2]|0;HEAP32[$92>>2] = (($93-1)|0);
   $94 = ($93|0)==(1);
   if ($94) {
    __THREW__ = 0;
    invoke_viii(3262,($91|0),1,1);
    $95 = __THREW__; __THREW__ = 0;
    $96 = $95&1;
    if ($96) {
     $101 = ___cxa_find_matching_catch_3(0|0)|0;
     $102 = tempRet0;
     ___clang_call_terminate($101);
     // unreachable;
    }
   }
  }
  HEAP32[$14>>2] = 0;
  __THREW__ = 0;
  invoke_vii(3552,($0|0),((73656)|0));
  $97 = __THREW__; __THREW__ = 0;
  $98 = $97&1;
  if ($98) {
   $101 = ___cxa_find_matching_catch_3(0|0)|0;
   $102 = tempRet0;
   ___clang_call_terminate($101);
   // unreachable;
  } else {
   $$0 = $85;$$06 = $84;
  }
 }
 __THREW__ = 0;
 invoke_vi(388,($3|0));
 $99 = __THREW__; __THREW__ = 0;
 $100 = $99&1;
 if ($100) {
  $101 = ___cxa_find_matching_catch_3(0|0)|0;
  $102 = tempRet0;
  ___clang_call_terminate($101);
  // unreachable;
 } else {
  ___resumeException($$06|0);
  // unreachable;
 }
}
function __ZN5osgDB13DatabasePager31FindCompileableGLObjectsVisitorD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = ((73160));
 $1 = ((($0)) + 148|0);
 HEAP32[$1>>2] = ((73512));
 $2 = ((($0)) + 144|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  label = 4;
 } else {
  $5 = HEAP32[$3>>2]|0;
  $6 = ((($5)) + -12|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($3) + ($7)|0);
  $9 = ((($8)) + 8|0);
  $10 = HEAP32[$9>>2]|0;HEAP32[$9>>2] = (($10-1)|0);
  $11 = ($10|0)==(1);
  if ($11) {
   __THREW__ = 0;
   invoke_viii(3262,($8|0),1,1);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if ($13) {
    $16 = ___cxa_find_matching_catch_2()|0;
    $17 = tempRet0;
    __THREW__ = 0;
    invoke_vii(3552,($0|0),((73656)|0));
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     $20 = ___cxa_find_matching_catch_3(0|0)|0;
     $21 = tempRet0;
     ___clang_call_terminate($20);
     // unreachable;
    } else {
     $eh$lpad$body$index2Z2D = $17;$eh$lpad$body$indexZ2D = $16;
    }
   } else {
    label = 4;
   }
  } else {
   label = 4;
  }
 }
 do {
  if ((label|0) == 4) {
   HEAP32[$2>>2] = 0;
   __THREW__ = 0;
   invoke_vii(3552,($0|0),((73656)|0));
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if ($15) {
    $22 = ___cxa_find_matching_catch_2()|0;
    $23 = tempRet0;
    $eh$lpad$body$index2Z2D = $23;$eh$lpad$body$indexZ2D = $22;
    break;
   } else {
    __ZN3osg6ObjectD2Ev($1);
    return;
   }
  }
 } while(0);
 __THREW__ = 0;
 invoke_vi(388,($1|0));
 $24 = __THREW__; __THREW__ = 0;
 $25 = $24&1;
 if ($25) {
  $26 = ___cxa_find_matching_catch_3(0|0)|0;
  $27 = tempRet0;
  ___clang_call_terminate($26);
  // unreachable;
 } else {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
}
function __ZN5osgDB13DatabasePager31FindCompileableGLObjectsVisitorD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(2595,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK5osgDB13DatabasePager31FindCompileableGLObjectsVisitor11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (163048|0);
}
function __ZNK5osgDB13DatabasePager31FindCompileableGLObjectsVisitor9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (163014|0);
}
function __ZN5osgDB13DatabasePager31FindCompileableGLObjectsVisitor5applyERN3osg8DrawableE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$pre$phi7Z2D = 0, $$pre$phiZ2D = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 144|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $$pre$phi7Z2D = $1;$$pre$phiZ2D = $1;
 } else {
  $5 = ((($0)) + 128|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = HEAP32[$1>>2]|0;
  $8 = ((($7)) + 124|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (FUNCTION_TABLE_ii[$9 & 8191]($1)|0);
  $11 = ($6|0)==($10|0);
  if ($11) {
   $$pre$phi7Z2D = $1;$$pre$phiZ2D = $1;
  } else {
   $12 = HEAP32[$1>>2]|0;
   $13 = ((($12)) + 188|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = HEAP32[$2>>2]|0;
   FUNCTION_TABLE_vii[$14 & 8191]($1,$15);
   $$pre$phi7Z2D = $1;$$pre$phiZ2D = $1;
  }
 }
 __ZN7osgUtil14StateToCompile5applyERN3osg8DrawableE($0,$1);
 $16 = HEAP32[$$pre$phi7Z2D>>2]|0;
 $17 = ((($16)) + 124|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (FUNCTION_TABLE_ii[$18 & 8191]($$pre$phiZ2D)|0);
 $20 = ($19|0)==(0|0);
 if (!($20)) {
  return;
 }
 $21 = HEAP32[$1>>2]|0;
 $22 = ((($21)) + 120|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ((($0)) + 128|0);
 $25 = HEAP32[$24>>2]|0;
 FUNCTION_TABLE_vii[$23 & 8191]($$pre$phiZ2D,$25);
 return;
}
function __ZN5osgDB13DatabasePager31FindCompileableGLObjectsVisitor5applyERN3osg7TextureE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$pre$phiZ2D = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0.0, $23 = 0, $24 = 0.0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(1);
 if ($4) {
  $$pre$phiZ2D = $1;
 } else {
  $5 = ((($0)) + 128|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = HEAP32[$1>>2]|0;
  $8 = ((($7)) + 124|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (FUNCTION_TABLE_ii[$9 & 8191]($1)|0);
  $11 = ($6|0)==($10|0);
  if ($11) {
   $$pre$phiZ2D = $1;
  } else {
   $12 = ((($0)) + 136|0);
   $13 = HEAP8[$12>>0]|0;
   $14 = ($13<<24>>24)==(0);
   if (!($14)) {
    $15 = ((($0)) + 137|0);
    $16 = HEAP8[$15>>0]|0;
    $17 = ((($1)) + 121|0);
    HEAP8[$17>>0] = $16;
   }
   $18 = ((($0)) + 138|0);
   $19 = HEAP8[$18>>0]|0;
   $20 = ($19<<24>>24)==(0);
   if ($20) {
    $$pre$phiZ2D = $1;
   } else {
    $21 = ((($1)) + 100|0);
    $22 = +HEAPF32[$21>>2];
    $23 = ((($0)) + 140|0);
    $24 = +HEAPF32[$23>>2];
    $25 = $22 != $24;
    if ($25) {
     __ZN3osg7Texture16setMaxAnisotropyEf($1,$24);
     $$pre$phiZ2D = $1;
    } else {
     $$pre$phiZ2D = $1;
    }
   }
  }
 }
 __ZN7osgUtil14StateToCompile5applyERN3osg7TextureE($0,$1);
 $26 = HEAP32[$$pre$phiZ2D>>2]|0;
 $27 = ((($26)) + 124|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (FUNCTION_TABLE_ii[$28 & 8191]($1)|0);
 $30 = ($29|0)==(0|0);
 if (!($30)) {
  return;
 }
 $31 = HEAP32[$1>>2]|0;
 $32 = ((($31)) + 120|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ((($0)) + 128|0);
 $35 = HEAP32[$34>>2]|0;
 FUNCTION_TABLE_vii[$33 & 8191]($1,$35);
 return;
}
function __ZTv0_n16_N5osgDB13DatabasePager31FindCompileableGLObjectsVisitorD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __ZN5osgDB13DatabasePager31FindCompileableGLObjectsVisitorD1Ev($4);
 return;
}
function __ZTv0_n16_N5osgDB13DatabasePager31FindCompileableGLObjectsVisitorD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __THREW__ = 0;
 invoke_vi(2595,($4|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $7 = ___cxa_find_matching_catch_2()|0;
  $8 = tempRet0;
  __ZdlPv($4);
  ___resumeException($7|0);
  // unreachable;
 } else {
  __ZdlPv($4);
  return;
 }
}
function __ZTv0_n32_NK5osgDB13DatabasePager31FindCompileableGLObjectsVisitor11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (163048|0);
}
function __ZTv0_n36_NK5osgDB13DatabasePager31FindCompileableGLObjectsVisitor9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (163014|0);
}
function __ZN5osgDB13DatabasePager37DatabasePagerCompileCompletedCallback16compileCompletedEPN7osgUtil27IncrementalCompileOperation10CompileSetE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($3)) + 96|0);
 $7 = HEAP32[$6>>2]|0;
 __ZN5osgDB13DatabasePager12RequestQueue6removeEPNS0_15DatabaseRequestE($7,$5);
 $8 = ((($3)) + 100|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($9)) + 28|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11)) + 8|0);
 $13 = HEAP32[$12>>2]|0;
 (FUNCTION_TABLE_ii[$13 & 8191]($10)|0);
 __THREW__ = 0;
 invoke_vii(4123,($9|0),($5|0));
 $14 = __THREW__; __THREW__ = 0;
 $15 = $14&1;
 if (!($15)) {
  $25 = HEAP32[$10>>2]|0;
  $26 = ((($25)) + 12|0);
  $27 = HEAP32[$26>>2]|0;
  (FUNCTION_TABLE_ii[$27 & 8191]($10)|0);
  return 1;
 }
 $16 = ___cxa_find_matching_catch_2()|0;
 $17 = tempRet0;
 $18 = HEAP32[$10>>2]|0;
 $19 = ((($18)) + 12|0);
 $20 = HEAP32[$19>>2]|0;
 __THREW__ = 0;
 (invoke_ii($20|0,($10|0))|0);
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if ($22) {
  $23 = ___cxa_find_matching_catch_3(0|0)|0;
  $24 = tempRet0;
  ___clang_call_terminate($23);
  // unreachable;
 } else {
  ___resumeException($16|0);
  // unreachable;
 }
 return (0)|0;
}
function __ZN5osgDB13DatabasePager37DatabasePagerCompileCompletedCallbackD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = ((73108));
 $1 = ((($0)) + 12|0);
 HEAP32[$1>>2] = ((73136));
 $2 = ((($0)) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  HEAP32[$2>>2] = 0;
  __ZN3osg10ReferencedD2Ev($1);
  return;
 }
 $5 = ((($3)) + 8|0);
 $6 = HEAP32[$5>>2]|0;HEAP32[$5>>2] = (($6-1)|0);
 $7 = ($6|0)==(1);
 if (!($7)) {
  HEAP32[$2>>2] = 0;
  __ZN3osg10ReferencedD2Ev($1);
  return;
 }
 __THREW__ = 0;
 invoke_viii(3262,($3|0),1,1);
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if (!($9)) {
  HEAP32[$2>>2] = 0;
  __ZN3osg10ReferencedD2Ev($1);
  return;
 }
 $10 = ___cxa_find_matching_catch_2()|0;
 $11 = tempRet0;
 __THREW__ = 0;
 invoke_vi(712,($1|0));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $14 = ___cxa_find_matching_catch_3(0|0)|0;
  $15 = tempRet0;
  ___clang_call_terminate($14);
  // unreachable;
 } else {
  ___resumeException($10|0);
  // unreachable;
 }
}
function __ZN5osgDB13DatabasePager37DatabasePagerCompileCompletedCallbackD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0;
 var $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = ((73108));
 $1 = ((($0)) + 12|0);
 HEAP32[$1>>2] = ((73136));
 $2 = ((($0)) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = ((($3)) + 8|0);
  $6 = HEAP32[$5>>2]|0;HEAP32[$5>>2] = (($6-1)|0);
  $7 = ($6|0)==(1);
  if ($7) {
   __THREW__ = 0;
   invoke_viii(3262,($3|0),1,1);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if ($9) {
    $12 = ___cxa_find_matching_catch_2()|0;
    $13 = tempRet0;
    __THREW__ = 0;
    invoke_vi(712,($1|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     $16 = ___cxa_find_matching_catch_3(0|0)|0;
     $17 = tempRet0;
     ___clang_call_terminate($16);
     // unreachable;
    } else {
     $eh$lpad$body$index2Z2D = $13;$eh$lpad$body$indexZ2D = $12;
     __ZdlPv($0);
     ___resumeException($eh$lpad$body$indexZ2D|0);
     // unreachable;
    }
   }
  }
 }
 HEAP32[$2>>2] = 0;
 __THREW__ = 0;
 invoke_vi(712,($1|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if (!($11)) {
  __ZdlPv($0);
  return;
 }
 $18 = ___cxa_find_matching_catch_2()|0;
 $19 = tempRet0;
 $eh$lpad$body$index2Z2D = $19;$eh$lpad$body$indexZ2D = $18;
 __ZdlPv($0);
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
}
function __ZTv0_n16_N5osgDB13DatabasePager37DatabasePagerCompileCompletedCallbackD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 HEAP32[$4>>2] = ((73108));
 $5 = ((($4)) + 12|0);
 HEAP32[$5>>2] = ((73136));
 $6 = ((($4)) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if ($8) {
  HEAP32[$6>>2] = 0;
  __ZN3osg10ReferencedD2Ev($5);
  return;
 }
 $9 = ((($7)) + 8|0);
 $10 = HEAP32[$9>>2]|0;HEAP32[$9>>2] = (($10-1)|0);
 $11 = ($10|0)==(1);
 if (!($11)) {
  HEAP32[$6>>2] = 0;
  __ZN3osg10ReferencedD2Ev($5);
  return;
 }
 __THREW__ = 0;
 invoke_viii(3262,($7|0),1,1);
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if (!($13)) {
  HEAP32[$6>>2] = 0;
  __ZN3osg10ReferencedD2Ev($5);
  return;
 }
 $14 = ___cxa_find_matching_catch_2()|0;
 $15 = tempRet0;
 __THREW__ = 0;
 invoke_vi(712,($5|0));
 $16 = __THREW__; __THREW__ = 0;
 $17 = $16&1;
 if ($17) {
  $18 = ___cxa_find_matching_catch_3(0|0)|0;
  $19 = tempRet0;
  ___clang_call_terminate($18);
  // unreachable;
 } else {
  ___resumeException($14|0);
  // unreachable;
 }
}
function __ZTv0_n16_N5osgDB13DatabasePager37DatabasePagerCompileCompletedCallbackD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$i$index2Z2D = 0, $eh$lpad$body$i$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 HEAP32[$4>>2] = ((73108));
 $5 = ((($4)) + 12|0);
 HEAP32[$5>>2] = ((73136));
 $6 = ((($4)) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = ((($7)) + 8|0);
  $10 = HEAP32[$9>>2]|0;HEAP32[$9>>2] = (($10-1)|0);
  $11 = ($10|0)==(1);
  if ($11) {
   __THREW__ = 0;
   invoke_viii(3262,($7|0),1,1);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if ($13) {
    $16 = ___cxa_find_matching_catch_2()|0;
    $17 = tempRet0;
    __THREW__ = 0;
    invoke_vi(712,($5|0));
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     $20 = ___cxa_find_matching_catch_3(0|0)|0;
     $21 = tempRet0;
     ___clang_call_terminate($20);
     // unreachable;
    } else {
     $eh$lpad$body$i$index2Z2D = $17;$eh$lpad$body$i$indexZ2D = $16;
     __ZdlPv($4);
     ___resumeException($eh$lpad$body$i$indexZ2D|0);
     // unreachable;
    }
   }
  }
 }
 HEAP32[$6>>2] = 0;
 __THREW__ = 0;
 invoke_vi(712,($5|0));
 $14 = __THREW__; __THREW__ = 0;
 $15 = $14&1;
 if (!($15)) {
  __ZdlPv($4);
  return;
 }
 $22 = ___cxa_find_matching_catch_2()|0;
 $23 = tempRet0;
 $eh$lpad$body$i$index2Z2D = $23;$eh$lpad$body$i$indexZ2D = $22;
 __ZdlPv($4);
 ___resumeException($eh$lpad$body$i$indexZ2D|0);
 // unreachable;
}
function __ZN5osgDB13DatabasePager12RequestQueue6removeEPNS0_15DatabaseRequestE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$sroa$09$0 = 0, $$sroa$09$0$in$in = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 (FUNCTION_TABLE_ii[$5 & 8191]($2)|0);
 $6 = ((($0)) + 20|0);
 $7 = ((($0)) + 16|0);
 $$sroa$09$0$in$in = $6;
 while(1) {
  $$sroa$09$0 = HEAP32[$$sroa$09$0$in$in>>2]|0;
  $8 = $$sroa$09$0;
  $9 = ($8|0)==($7|0);
  if ($9) {
   label = 9;
   break;
  }
  $10 = $$sroa$09$0;
  $11 = ((($10)) + 8|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($12|0)==($1|0);
  $14 = ((($8)) + 4|0);
  if ($13) {
   break;
  } else {
   $$sroa$09$0$in$in = $14;
  }
 }
 if ((label|0) == 9) {
  $38 = HEAP32[$2>>2]|0;
  $39 = ((($38)) + 12|0);
  $40 = HEAP32[$39>>2]|0;
  (FUNCTION_TABLE_ii[$40 & 8191]($2)|0);
  return;
 }
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP32[$8>>2]|0;
 $17 = ((($16)) + 4|0);
 HEAP32[$17>>2] = $15;
 $18 = HEAP32[$14>>2]|0;
 HEAP32[$18>>2] = $16;
 $19 = ((($0)) + 24|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($20) + -1)|0;
 HEAP32[$19>>2] = $21;
 $22 = ((($8)) + 8|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)==(0|0);
 if (!($24)) {
  $25 = ((($23)) + 8|0);
  $26 = HEAP32[$25>>2]|0;HEAP32[$25>>2] = (($26-1)|0);
  $27 = ($26|0)==(1);
  if ($27) {
   __THREW__ = 0;
   invoke_viii(3262,($23|0),1,1);
   $28 = __THREW__; __THREW__ = 0;
   $29 = $28&1;
   if ($29) {
    $31 = ___cxa_find_matching_catch_2()|0;
    $32 = tempRet0;
    $33 = HEAP32[$2>>2]|0;
    $34 = ((($33)) + 12|0);
    $35 = HEAP32[$34>>2]|0;
    __THREW__ = 0;
    (invoke_ii($35|0,($2|0))|0);
    $36 = __THREW__; __THREW__ = 0;
    $37 = $36&1;
    if ($37) {
     $41 = ___cxa_find_matching_catch_3(0|0)|0;
     $42 = tempRet0;
     ___clang_call_terminate($41);
     // unreachable;
    } else {
     ___resumeException($31|0);
     // unreachable;
    }
   }
  }
 }
 $30 = $$sroa$09$0;
 __ZdlPv($30);
 $38 = HEAP32[$2>>2]|0;
 $39 = ((($38)) + 12|0);
 $40 = HEAP32[$39>>2]|0;
 (FUNCTION_TABLE_ii[$40 & 8191]($2)|0);
 return;
}
function __ZN5osgDB8Registry22_buildKdTreeIfRequiredERNS_12ReaderWriter10ReadResultEPKNS_7OptionsE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$sink = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($2|0)==(0|0);
 if ($3) {
  label = 3;
 } else {
  $4 = ((($2)) + 80|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0);
  if ($6) {
   label = 3;
  } else {
   $$sink = $5;
  }
 }
 if ((label|0) == 3) {
  $7 = ((($0)) + 12|0);
  $8 = HEAP32[$7>>2]|0;
  $$sink = $8;
 }
 $9 = ($$sink|0)==(2);
 if (!($9)) {
  return;
 }
 $10 = ((($0)) + 16|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0|0);
 if ($12) {
  return;
 }
 $13 = (__ZN5osgDB12ReaderWriter10ReadResult7getNodeEv($1)|0);
 $14 = ($13|0)==(0|0);
 if ($14) {
  return;
 }
 $15 = HEAP32[$10>>2]|0;
 $16 = HEAP32[$15>>2]|0;
 $17 = ((($16)) + 200|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (FUNCTION_TABLE_ii[$18 & 8191]($15)|0);
 $20 = ($19|0)==(0|0);
 if (!($20)) {
  $21 = HEAP32[$19>>2]|0;
  $22 = ((($21)) + -12|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (($19) + ($23)|0);
  $25 = ((($24)) + 8|0);
  $26 = HEAP32[$25>>2]|0;HEAP32[$25>>2] = (($26+1)|0);
 }
 __THREW__ = 0;
 $27 = (invoke_ii(4126,($1|0))|0);
 $28 = __THREW__; __THREW__ = 0;
 $29 = $28&1;
 if (!($29)) {
  $30 = HEAP32[$27>>2]|0;
  $31 = ((($30)) + 188|0);
  $32 = HEAP32[$31>>2]|0;
  __THREW__ = 0;
  invoke_vii($32|0,($27|0),($19|0));
  $33 = __THREW__; __THREW__ = 0;
  $34 = $33&1;
  if (!($34)) {
   if ($20) {
    return;
   }
   $35 = HEAP32[$19>>2]|0;
   $36 = ((($35)) + -12|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = (($19) + ($37)|0);
   $39 = ((($38)) + 8|0);
   $40 = HEAP32[$39>>2]|0;HEAP32[$39>>2] = (($40-1)|0);
   $41 = ($40|0)==(1);
   if (!($41)) {
    return;
   }
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($38,1,1);
   return;
  }
 }
 $42 = ___cxa_find_matching_catch_2()|0;
 $43 = tempRet0;
 if ($20) {
  ___resumeException($42|0);
  // unreachable;
 }
 $44 = HEAP32[$19>>2]|0;
 $45 = ((($44)) + -12|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = (($19) + ($46)|0);
 $48 = ((($47)) + 8|0);
 $49 = HEAP32[$48>>2]|0;HEAP32[$48>>2] = (($49-1)|0);
 $50 = ($49|0)==(1);
 if (!($50)) {
  ___resumeException($42|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(3262,($47|0),1,1);
 $51 = __THREW__; __THREW__ = 0;
 $52 = $51&1;
 if ($52) {
  $53 = ___cxa_find_matching_catch_3(0|0)|0;
  $54 = tempRet0;
  ___clang_call_terminate($53);
  // unreachable;
 } else {
  ___resumeException($42|0);
  // unreachable;
 }
}
function __ZN5osgDB13DatabasePagerD2Ev($0) {
 $0 = $0|0;
 var $$0 = 0, $$02 = 0, $$1 = 0, $$10 = 0, $$1012 = 0, $$11 = 0, $$1113 = 0, $$13 = 0, $$2 = 0, $$24 = 0, $$3 = 0, $$35 = 0, $$4 = 0, $$46 = 0, $$5 = 0, $$57 = 0, $$6 = 0, $$68 = 0, $$7 = 0, $$79 = 0;
 var $$pre = 0, $$pre$i = 0, $$pre$i48 = 0, $$pre$phi53Z2D = 0, $$pre$phi55Z2D = 0, $$pre$phi57Z2D = 0, $$pre$phi59Z2D = 0, $$pre$phiZ2D = 0, $$pre52 = 0, $$pre54 = 0, $$pre56 = 0, $$pre58 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0;
 var $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0;
 var $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0;
 var $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0;
 var $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0;
 var $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0;
 var $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (73684);
 __THREW__ = 0;
 (invoke_ii(2610,($0|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if ($2) {
   label = 57;
  } else {
   $3 = ((($0)) + 56|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = ((($0)) + 60|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($6|0)==($4|0);
   L3: do {
    if (!($7)) {
     $9 = $6;
     while(1) {
      $8 = ((($9)) + -4|0);
      HEAP32[$5>>2] = $8;
      $10 = HEAP32[$8>>2]|0;
      $11 = ($10|0)==(0|0);
      if (!($11)) {
       $12 = ((($10)) + 8|0);
       $13 = HEAP32[$12>>2]|0;HEAP32[$12>>2] = (($13-1)|0);
       $14 = ($13|0)==(1);
       if ($14) {
        __THREW__ = 0;
        invoke_viii(3262,($10|0),1,1);
        $15 = __THREW__; __THREW__ = 0;
        $16 = $15&1;
        if ($16) {
         break;
        }
       }
      }
      HEAP32[$8>>2] = 0;
      $17 = HEAP32[$5>>2]|0;
      $18 = ($17|0)==($4|0);
      if ($18) {
       break L3;
      } else {
       $9 = $17;
      }
     }
     $19 = ___cxa_find_matching_catch_2()|0;
     $20 = tempRet0;
     ___cxa_call_unexpected(($19|0));
     // unreachable;
    }
   } while(0);
   $21 = ((($0)) + 88|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = ($22|0)==(0|0);
   if (!($23)) {
    HEAP32[$21>>2] = 0;
    $24 = ((($22)) + 8|0);
    $25 = HEAP32[$24>>2]|0;HEAP32[$24>>2] = (($25-1)|0);
    $26 = ($25|0)==(1);
    if ($26) {
     __THREW__ = 0;
     invoke_viii(3262,($22|0),1,1);
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     if ($28) {
      label = 57;
      break;
     }
    }
   }
   $29 = ((($0)) + 92|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = ($30|0)==(0|0);
   if (!($31)) {
    HEAP32[$29>>2] = 0;
    $32 = ((($30)) + 8|0);
    $33 = HEAP32[$32>>2]|0;HEAP32[$32>>2] = (($33-1)|0);
    $34 = ($33|0)==(1);
    if ($34) {
     __THREW__ = 0;
     invoke_viii(3262,($30|0),1,1);
     $35 = __THREW__; __THREW__ = 0;
     $36 = $35&1;
     if ($36) {
      label = 57;
      break;
     }
    }
   }
   $37 = ((($0)) + 96|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = ($38|0)==(0|0);
   if (!($39)) {
    HEAP32[$37>>2] = 0;
    $40 = ((($38)) + 8|0);
    $41 = HEAP32[$40>>2]|0;HEAP32[$40>>2] = (($41-1)|0);
    $42 = ($41|0)==(1);
    if ($42) {
     __THREW__ = 0;
     invoke_viii(3262,($38|0),1,1);
     $43 = __THREW__; __THREW__ = 0;
     $44 = $43&1;
     if ($44) {
      label = 57;
      break;
     }
    }
   }
   $45 = ((($0)) + 100|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = ($46|0)==(0|0);
   if (!($47)) {
    HEAP32[$45>>2] = 0;
    $48 = ((($46)) + 8|0);
    $49 = HEAP32[$48>>2]|0;HEAP32[$48>>2] = (($49-1)|0);
    $50 = ($49|0)==(1);
    if ($50) {
     __THREW__ = 0;
     invoke_viii(3262,($46|0),1,1);
     $51 = __THREW__; __THREW__ = 0;
     $52 = $51&1;
     if ($52) {
      label = 57;
      break;
     }
    }
   }
   $53 = ((($0)) + 132|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = ($54|0)==(0|0);
   if (!($55)) {
    HEAP32[$53>>2] = 0;
    $56 = HEAP32[$54>>2]|0;
    $57 = ((($56)) + -12|0);
    $58 = HEAP32[$57>>2]|0;
    $59 = (($54) + ($58)|0);
    $60 = ((($59)) + 8|0);
    $61 = HEAP32[$60>>2]|0;HEAP32[$60>>2] = (($61-1)|0);
    $62 = ($61|0)==(1);
    if ($62) {
     __THREW__ = 0;
     invoke_viii(3262,($59|0),1,1);
     $63 = __THREW__; __THREW__ = 0;
     $64 = $63&1;
     if ($64) {
      label = 57;
      break;
     }
    }
   }
   $65 = ((($0)) + 164|0);
   $66 = HEAP32[$65>>2]|0;
   $67 = ($66|0)==(0|0);
   if (!($67)) {
    $68 = ((($66)) + 8|0);
    $69 = HEAP32[$68>>2]|0;HEAP32[$68>>2] = (($69-1)|0);
    $70 = ($69|0)==(1);
    if ($70) {
     __THREW__ = 0;
     invoke_viii(3262,($66|0),1,1);
     $71 = __THREW__; __THREW__ = 0;
     $72 = $71&1;
     if ($72) {
      $160 = ___cxa_find_matching_catch_2()|0;
      $161 = tempRet0;
      $$0 = $161;$$02 = $160;$$pre$phi59Z2D = $53;
      label = 63;
      break;
     }
    }
   }
   HEAP32[$65>>2] = 0;
   $73 = HEAP32[$53>>2]|0;
   $74 = ($73|0)==(0|0);
   if (!($74)) {
    $75 = HEAP32[$73>>2]|0;
    $76 = ((($75)) + -12|0);
    $77 = HEAP32[$76>>2]|0;
    $78 = (($73) + ($77)|0);
    $79 = ((($78)) + 8|0);
    $80 = HEAP32[$79>>2]|0;HEAP32[$79>>2] = (($80-1)|0);
    $81 = ($80|0)==(1);
    if ($81) {
     __THREW__ = 0;
     invoke_viii(3262,($78|0),1,1);
     $82 = __THREW__; __THREW__ = 0;
     $83 = $82&1;
     if ($83) {
      $162 = ___cxa_find_matching_catch_2()|0;
      $163 = tempRet0;
      $$1 = $163;$$13 = $162;
      label = 68;
      break;
     }
    }
   }
   HEAP32[$53>>2] = 0;
   $84 = ((($0)) + 120|0);
   $85 = HEAP32[$84>>2]|0;
   $86 = ($85|0)==(0|0);
   if (!($86)) {
    $87 = ((($85)) + 8|0);
    $88 = HEAP32[$87>>2]|0;HEAP32[$87>>2] = (($88-1)|0);
    $89 = ($88|0)==(1);
    if ($89) {
     __THREW__ = 0;
     invoke_viii(3262,($85|0),1,1);
     $90 = __THREW__; __THREW__ = 0;
     $91 = $90&1;
     if ($91) {
      $175 = ___cxa_find_matching_catch_2()|0;
      $176 = tempRet0;
      $$2 = $176;$$24 = $175;$$pre$phi57Z2D = $45;
      label = 73;
      break;
     }
    }
   }
   HEAP32[$84>>2] = 0;
   $92 = HEAP32[$45>>2]|0;
   $93 = ($92|0)==(0|0);
   if (!($93)) {
    $94 = ((($92)) + 8|0);
    $95 = HEAP32[$94>>2]|0;HEAP32[$94>>2] = (($95-1)|0);
    $96 = ($95|0)==(1);
    if ($96) {
     __THREW__ = 0;
     invoke_viii(3262,($92|0),1,1);
     $97 = __THREW__; __THREW__ = 0;
     $98 = $97&1;
     if ($98) {
      $185 = ___cxa_find_matching_catch_2()|0;
      $186 = tempRet0;
      $$3 = $186;$$35 = $185;$$pre$phi55Z2D = $37;
      label = 78;
      break;
     }
    }
   }
   HEAP32[$45>>2] = 0;
   $99 = HEAP32[$37>>2]|0;
   $100 = ($99|0)==(0|0);
   if (!($100)) {
    $101 = ((($99)) + 8|0);
    $102 = HEAP32[$101>>2]|0;HEAP32[$101>>2] = (($102-1)|0);
    $103 = ($102|0)==(1);
    if ($103) {
     __THREW__ = 0;
     invoke_viii(3262,($99|0),1,1);
     $104 = __THREW__; __THREW__ = 0;
     $105 = $104&1;
     if ($105) {
      $194 = ___cxa_find_matching_catch_2()|0;
      $195 = tempRet0;
      $$4 = $195;$$46 = $194;$$pre$phi53Z2D = $29;
      label = 83;
      break;
     }
    }
   }
   HEAP32[$37>>2] = 0;
   $106 = HEAP32[$29>>2]|0;
   $107 = ($106|0)==(0|0);
   if (!($107)) {
    $108 = ((($106)) + 8|0);
    $109 = HEAP32[$108>>2]|0;HEAP32[$108>>2] = (($109-1)|0);
    $110 = ($109|0)==(1);
    if ($110) {
     __THREW__ = 0;
     invoke_viii(3262,($106|0),1,1);
     $111 = __THREW__; __THREW__ = 0;
     $112 = $111&1;
     if ($112) {
      $203 = ___cxa_find_matching_catch_2()|0;
      $204 = tempRet0;
      $$5 = $204;$$57 = $203;$$pre$phiZ2D = $21;
      label = 88;
      break;
     }
    }
   }
   HEAP32[$29>>2] = 0;
   $113 = HEAP32[$21>>2]|0;
   $114 = ($113|0)==(0|0);
   if (!($114)) {
    $115 = ((($113)) + 8|0);
    $116 = HEAP32[$115>>2]|0;HEAP32[$115>>2] = (($116-1)|0);
    $117 = ($116|0)==(1);
    if ($117) {
     __THREW__ = 0;
     invoke_viii(3262,($113|0),1,1);
     $118 = __THREW__; __THREW__ = 0;
     $119 = $118&1;
     if ($119) {
      $212 = ___cxa_find_matching_catch_2()|0;
      $213 = tempRet0;
      $$6 = $213;$$68 = $212;
      label = 93;
      break;
     }
    }
   }
   HEAP32[$21>>2] = 0;
   $120 = ((($0)) + 72|0);
   __THREW__ = 0;
   invoke_vi(707,($120|0));
   $121 = __THREW__; __THREW__ = 0;
   $122 = $121&1;
   if ($122) {
    $221 = ___cxa_find_matching_catch_2()|0;
    $222 = tempRet0;
    $$7 = $222;$$79 = $221;
    label = 94;
    break;
   }
   $123 = HEAP32[$3>>2]|0;
   $124 = ($123|0)==(0|0);
   if (!($124)) {
    $125 = HEAP32[$5>>2]|0;
    $126 = ($125|0)==($123|0);
    do {
     if ($126) {
      $140 = $123;
     } else {
      $128 = $125;
      L73: while(1) {
       $127 = ((($128)) + -4|0);
       HEAP32[$5>>2] = $127;
       $129 = HEAP32[$127>>2]|0;
       $130 = ($129|0)==(0|0);
       do {
        if (!($130)) {
         $131 = ((($129)) + 8|0);
         $132 = HEAP32[$131>>2]|0;HEAP32[$131>>2] = (($132-1)|0);
         $133 = ($132|0)==(1);
         if (!($133)) {
          break;
         }
         __THREW__ = 0;
         invoke_viii(3262,($129|0),1,1);
         $134 = __THREW__; __THREW__ = 0;
         $135 = $134&1;
         if ($135) {
          label = 51;
          break L73;
         }
        }
       } while(0);
       HEAP32[$127>>2] = 0;
       $136 = HEAP32[$5>>2]|0;
       $137 = ($136|0)==($123|0);
       if ($137) {
        label = 52;
        break;
       } else {
        $128 = $136;
       }
      }
      if ((label|0) == 51) {
       $138 = ___cxa_find_matching_catch_2()|0;
       $139 = tempRet0;
       ___cxa_call_unexpected(($138|0));
       // unreachable;
      }
      else if ((label|0) == 52) {
       $$pre$i = HEAP32[$3>>2]|0;
       $140 = $$pre$i;
       break;
      }
     }
    } while(0);
    __ZdlPv($140);
   }
   $141 = ((($0)) + 40|0);
   $142 = ((($0)) + 44|0);
   $143 = HEAP32[$142>>2]|0;
   __ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEE7destroyEPNS_11__tree_nodeIjPvEE($141,$143);
   $144 = ((($0)) + 24|0);
   __THREW__ = 0;
   invoke_vi(707,($144|0));
   $145 = __THREW__; __THREW__ = 0;
   $146 = $145&1;
   if ($146) {
    $246 = ___cxa_find_matching_catch_2()|0;
    $247 = tempRet0;
    $$10 = $247;$$1012 = $246;
    label = 106;
    break;
   }
   $147 = ((($0)) + 12|0);
   __THREW__ = 0;
   invoke_vi(707,($147|0));
   $148 = __THREW__; __THREW__ = 0;
   $149 = $148&1;
   if ($149) {
    $254 = ___cxa_find_matching_catch_2()|0;
    $255 = tempRet0;
    $$11 = $255;$$1113 = $254;
    break;
   } else {
    __ZN3osg10ReferencedD2Ev($0);
    return;
   }
  }
 } while(0);
 if ((label|0) == 57) {
  $150 = ___cxa_find_matching_catch_2()|0;
  $151 = tempRet0;
  $152 = ((($0)) + 164|0);
  $153 = HEAP32[$152>>2]|0;
  $154 = ($153|0)==(0|0);
  if (!($154)) {
   $155 = ((($153)) + 8|0);
   $156 = HEAP32[$155>>2]|0;HEAP32[$155>>2] = (($156-1)|0);
   $157 = ($156|0)==(1);
   if ($157) {
    __THREW__ = 0;
    invoke_viii(3262,($153|0),1,1);
    $158 = __THREW__; __THREW__ = 0;
    $159 = $158&1;
    if ($159) {
     $261 = ___cxa_find_matching_catch_3(0|0)|0;
     $262 = tempRet0;
     ___clang_call_terminate($261);
     // unreachable;
    }
   }
  }
  HEAP32[$152>>2] = 0;
  $$pre58 = ((($0)) + 132|0);
  $$0 = $151;$$02 = $150;$$pre$phi59Z2D = $$pre58;
  label = 63;
 }
 if ((label|0) == 63) {
  $164 = HEAP32[$$pre$phi59Z2D>>2]|0;
  $165 = ($164|0)==(0|0);
  if (!($165)) {
   $166 = HEAP32[$164>>2]|0;
   $167 = ((($166)) + -12|0);
   $168 = HEAP32[$167>>2]|0;
   $169 = (($164) + ($168)|0);
   $170 = ((($169)) + 8|0);
   $171 = HEAP32[$170>>2]|0;HEAP32[$170>>2] = (($171-1)|0);
   $172 = ($171|0)==(1);
   if ($172) {
    __THREW__ = 0;
    invoke_viii(3262,($169|0),1,1);
    $173 = __THREW__; __THREW__ = 0;
    $174 = $173&1;
    if ($174) {
     $261 = ___cxa_find_matching_catch_3(0|0)|0;
     $262 = tempRet0;
     ___clang_call_terminate($261);
     // unreachable;
    }
   }
  }
  HEAP32[$$pre$phi59Z2D>>2] = 0;
  $$1 = $$0;$$13 = $$02;
  label = 68;
 }
 if ((label|0) == 68) {
  $177 = ((($0)) + 120|0);
  $178 = HEAP32[$177>>2]|0;
  $179 = ($178|0)==(0|0);
  if (!($179)) {
   $180 = ((($178)) + 8|0);
   $181 = HEAP32[$180>>2]|0;HEAP32[$180>>2] = (($181-1)|0);
   $182 = ($181|0)==(1);
   if ($182) {
    __THREW__ = 0;
    invoke_viii(3262,($178|0),1,1);
    $183 = __THREW__; __THREW__ = 0;
    $184 = $183&1;
    if ($184) {
     $261 = ___cxa_find_matching_catch_3(0|0)|0;
     $262 = tempRet0;
     ___clang_call_terminate($261);
     // unreachable;
    }
   }
  }
  HEAP32[$177>>2] = 0;
  $$pre56 = ((($0)) + 100|0);
  $$2 = $$1;$$24 = $$13;$$pre$phi57Z2D = $$pre56;
  label = 73;
 }
 if ((label|0) == 73) {
  $187 = HEAP32[$$pre$phi57Z2D>>2]|0;
  $188 = ($187|0)==(0|0);
  if (!($188)) {
   $189 = ((($187)) + 8|0);
   $190 = HEAP32[$189>>2]|0;HEAP32[$189>>2] = (($190-1)|0);
   $191 = ($190|0)==(1);
   if ($191) {
    __THREW__ = 0;
    invoke_viii(3262,($187|0),1,1);
    $192 = __THREW__; __THREW__ = 0;
    $193 = $192&1;
    if ($193) {
     $261 = ___cxa_find_matching_catch_3(0|0)|0;
     $262 = tempRet0;
     ___clang_call_terminate($261);
     // unreachable;
    }
   }
  }
  HEAP32[$$pre$phi57Z2D>>2] = 0;
  $$pre54 = ((($0)) + 96|0);
  $$3 = $$2;$$35 = $$24;$$pre$phi55Z2D = $$pre54;
  label = 78;
 }
 if ((label|0) == 78) {
  $196 = HEAP32[$$pre$phi55Z2D>>2]|0;
  $197 = ($196|0)==(0|0);
  if (!($197)) {
   $198 = ((($196)) + 8|0);
   $199 = HEAP32[$198>>2]|0;HEAP32[$198>>2] = (($199-1)|0);
   $200 = ($199|0)==(1);
   if ($200) {
    __THREW__ = 0;
    invoke_viii(3262,($196|0),1,1);
    $201 = __THREW__; __THREW__ = 0;
    $202 = $201&1;
    if ($202) {
     $261 = ___cxa_find_matching_catch_3(0|0)|0;
     $262 = tempRet0;
     ___clang_call_terminate($261);
     // unreachable;
    }
   }
  }
  HEAP32[$$pre$phi55Z2D>>2] = 0;
  $$pre52 = ((($0)) + 92|0);
  $$4 = $$3;$$46 = $$35;$$pre$phi53Z2D = $$pre52;
  label = 83;
 }
 if ((label|0) == 83) {
  $205 = HEAP32[$$pre$phi53Z2D>>2]|0;
  $206 = ($205|0)==(0|0);
  if (!($206)) {
   $207 = ((($205)) + 8|0);
   $208 = HEAP32[$207>>2]|0;HEAP32[$207>>2] = (($208-1)|0);
   $209 = ($208|0)==(1);
   if ($209) {
    __THREW__ = 0;
    invoke_viii(3262,($205|0),1,1);
    $210 = __THREW__; __THREW__ = 0;
    $211 = $210&1;
    if ($211) {
     $261 = ___cxa_find_matching_catch_3(0|0)|0;
     $262 = tempRet0;
     ___clang_call_terminate($261);
     // unreachable;
    }
   }
  }
  HEAP32[$$pre$phi53Z2D>>2] = 0;
  $$pre = ((($0)) + 88|0);
  $$5 = $$4;$$57 = $$46;$$pre$phiZ2D = $$pre;
  label = 88;
 }
 if ((label|0) == 88) {
  $214 = HEAP32[$$pre$phiZ2D>>2]|0;
  $215 = ($214|0)==(0|0);
  if (!($215)) {
   $216 = ((($214)) + 8|0);
   $217 = HEAP32[$216>>2]|0;HEAP32[$216>>2] = (($217-1)|0);
   $218 = ($217|0)==(1);
   if ($218) {
    __THREW__ = 0;
    invoke_viii(3262,($214|0),1,1);
    $219 = __THREW__; __THREW__ = 0;
    $220 = $219&1;
    if ($220) {
     $261 = ___cxa_find_matching_catch_3(0|0)|0;
     $262 = tempRet0;
     ___clang_call_terminate($261);
     // unreachable;
    }
   }
  }
  HEAP32[$$pre$phiZ2D>>2] = 0;
  $$6 = $$5;$$68 = $$57;
  label = 93;
 }
 if ((label|0) == 93) {
  $223 = ((($0)) + 72|0);
  __THREW__ = 0;
  invoke_vi(707,($223|0));
  $224 = __THREW__; __THREW__ = 0;
  $225 = $224&1;
  if ($225) {
   $261 = ___cxa_find_matching_catch_3(0|0)|0;
   $262 = tempRet0;
   ___clang_call_terminate($261);
   // unreachable;
  } else {
   $$7 = $$6;$$79 = $$68;
   label = 94;
  }
 }
 if ((label|0) == 94) {
  $226 = ((($0)) + 56|0);
  $227 = HEAP32[$226>>2]|0;
  $228 = ($227|0)==(0|0);
  if (!($228)) {
   $229 = ((($0)) + 60|0);
   $230 = HEAP32[$229>>2]|0;
   $231 = ($230|0)==($227|0);
   do {
    if ($231) {
     $245 = $227;
    } else {
     $233 = $230;
     while(1) {
      $232 = ((($233)) + -4|0);
      HEAP32[$229>>2] = $232;
      $234 = HEAP32[$232>>2]|0;
      $235 = ($234|0)==(0|0);
      if (!($235)) {
       $236 = ((($234)) + 8|0);
       $237 = HEAP32[$236>>2]|0;HEAP32[$236>>2] = (($237-1)|0);
       $238 = ($237|0)==(1);
       if ($238) {
        __THREW__ = 0;
        invoke_viii(3262,($234|0),1,1);
        $239 = __THREW__; __THREW__ = 0;
        $240 = $239&1;
        if ($240) {
         label = 100;
         break;
        }
       }
      }
      HEAP32[$232>>2] = 0;
      $241 = HEAP32[$229>>2]|0;
      $242 = ($241|0)==($227|0);
      if ($242) {
       label = 101;
       break;
      } else {
       $233 = $241;
      }
     }
     if ((label|0) == 100) {
      $243 = ___cxa_find_matching_catch_2()|0;
      $244 = tempRet0;
      ___cxa_call_unexpected(($243|0));
      // unreachable;
     }
     else if ((label|0) == 101) {
      $$pre$i48 = HEAP32[$226>>2]|0;
      $245 = $$pre$i48;
      break;
     }
    }
   } while(0);
   __ZdlPv($245);
  }
  $248 = ((($0)) + 40|0);
  $249 = ((($0)) + 44|0);
  $250 = HEAP32[$249>>2]|0;
  __ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEE7destroyEPNS_11__tree_nodeIjPvEE($248,$250);
  $251 = ((($0)) + 24|0);
  __THREW__ = 0;
  invoke_vi(707,($251|0));
  $252 = __THREW__; __THREW__ = 0;
  $253 = $252&1;
  if ($253) {
   $261 = ___cxa_find_matching_catch_3(0|0)|0;
   $262 = tempRet0;
   ___clang_call_terminate($261);
   // unreachable;
  } else {
   $$10 = $$7;$$1012 = $$79;
   label = 106;
  }
 }
 if ((label|0) == 106) {
  $256 = ((($0)) + 12|0);
  __THREW__ = 0;
  invoke_vi(707,($256|0));
  $257 = __THREW__; __THREW__ = 0;
  $258 = $257&1;
  if ($258) {
   $261 = ___cxa_find_matching_catch_3(0|0)|0;
   $262 = tempRet0;
   ___clang_call_terminate($261);
   // unreachable;
  } else {
   $$11 = $$10;$$1113 = $$1012;
  }
 }
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $259 = __THREW__; __THREW__ = 0;
 $260 = $259&1;
 if ($260) {
  $261 = ___cxa_find_matching_catch_3(0|0)|0;
  $262 = tempRet0;
  ___clang_call_terminate($261);
  // unreachable;
 } else {
  ___resumeException($$1113|0);
  // unreachable;
 }
}
function __ZN5osgDB13DatabasePagerD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(2605,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZN5osgDB13DatabasePager15requestNodeFileERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEERNS1_6vectorIPN3osg4NodeENS5_ISD_EEEEfPKNSB_10FrameStampERNSB_7ref_ptrINSB_10ReferencedEEEPKSL_($0,$1,$2,$3,$4,$5,$6) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = +$3;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 var $$$i = 0, $$$i132 = 0, $$$i144 = 0, $$$i151 = 0, $$079 = 0, $$081 = 0, $$083 = 0, $$086 = 0, $$087$lcssa = 0, $$087230 = 0, $$1 = 0, $$176 = 0, $$188 = 0, $$3 = 0, $$378 = 0, $$pr$i = 0, $$pr$i129 = 0, $$pr$i141 = 0, $$pr$i148 = 0, $$pre = 0;
 var $$pre233 = 0, $$sink227$index = 0, $$sink227$index12 = 0, $$sink228229 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0;
 var $205 = 0, $206 = 0, $207 = 0.0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0;
 var $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0;
 var $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0;
 var $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0;
 var $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0;
 var $296 = 0, $297 = 0, $298 = 0, $299 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0;
 var $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0;
 var $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0;
 var $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0;
 var $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0;
 var $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0;
 var $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0;
 var $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0;
 var $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0;
 var $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0;
 var $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0;
 var $496 = 0, $497 = 0, $498 = 0, $499 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0;
 var $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0;
 var $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0;
 var $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0;
 var $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0;
 var $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0;
 var $605 = 0, $606 = 0, $607 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0.0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index4Z2D = 0, $eh$lpad$body$indexZ2D = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $7 = sp + 24|0;
 $8 = sp + 20|0;
 $9 = sp + 16|0;
 $10 = sp + 12|0;
 $11 = sp + 8|0;
 $12 = sp + 4|0;
 $13 = sp;
 $14 = ($6|0)==(0|0);
 if ($14) {
  label = 3;
 } else {
  $15 = (___dynamic_cast($6,26488,5376,0)|0);
  $16 = ($15|0)==(0|0);
  if ($16) {
   label = 3;
  } else {
   $$086 = $15;
  }
 }
 if ((label|0) == 3) {
  $17 = (__ZN5osgDB8Registry8instanceEb(0)|0);
  $18 = ((($17)) + 160|0);
  $19 = HEAP32[$18>>2]|0;
  $$086 = $19;
 }
 $20 = ((($0)) + 53|0);
 $21 = HEAP8[$20>>0]|0;
 $22 = ($21<<24>>24)==(0);
 if ($22) {
  STACKTOP = sp;return;
 }
 $23 = HEAP32[$2>>2]|0;
 $24 = ((($2)) + 4|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($23|0)==($25|0);
 if ($26) {
  $27 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
  if (!($27)) {
   STACKTOP = sp;return;
  }
  $28 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
  $29 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($28,163988,104)|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = ((($30)) + -12|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = (($29) + ($32)|0);
  __ZNKSt3__28ios_base6getlocEv($13,$33);
  __THREW__ = 0;
  $34 = (invoke_iii(3255,($13|0),(215188|0))|0);
  $35 = __THREW__; __THREW__ = 0;
  $36 = $35&1;
  if (!($36)) {
   $37 = HEAP32[$34>>2]|0;
   $38 = ((($37)) + 28|0);
   $39 = HEAP32[$38>>2]|0;
   __THREW__ = 0;
   $40 = (invoke_iii($39|0,($34|0),10)|0);
   $41 = __THREW__; __THREW__ = 0;
   $42 = $41&1;
   if (!($42)) {
    __ZNSt3__26localeD2Ev($13);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($29,$40)|0);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($29)|0);
    STACKTOP = sp;return;
   }
  }
  $43 = ___cxa_find_matching_catch_2()|0;
  $44 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3263,($13|0));
  $45 = __THREW__; __THREW__ = 0;
  $46 = $45&1;
  if ($46) {
   $47 = ___cxa_find_matching_catch_3(0|0)|0;
   $48 = tempRet0;
   ___clang_call_terminate($47);
   // unreachable;
  } else {
   ___resumeException($43|0);
   // unreachable;
  }
 }
 $49 = ((($25)) + -4|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = HEAP32[$50>>2]|0;
 $52 = ((($51)) + 148|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = (FUNCTION_TABLE_ii[$53 & 8191]($50)|0);
 $55 = ($54|0)==(0|0);
 if ($55) {
  $56 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
  if (!($56)) {
   STACKTOP = sp;return;
  }
  $57 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
  $58 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($57,164093,133)|0);
  $59 = HEAP32[$58>>2]|0;
  $60 = ((($59)) + -12|0);
  $61 = HEAP32[$60>>2]|0;
  $62 = (($58) + ($61)|0);
  __ZNKSt3__28ios_base6getlocEv($12,$62);
  __THREW__ = 0;
  $63 = (invoke_iii(3255,($12|0),(215188|0))|0);
  $64 = __THREW__; __THREW__ = 0;
  $65 = $64&1;
  if (!($65)) {
   $66 = HEAP32[$63>>2]|0;
   $67 = ((($66)) + 28|0);
   $68 = HEAP32[$67>>2]|0;
   __THREW__ = 0;
   $69 = (invoke_iii($68|0,($63|0),10)|0);
   $70 = __THREW__; __THREW__ = 0;
   $71 = $70&1;
   if (!($71)) {
    __ZNSt3__26localeD2Ev($12);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($58,$69)|0);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($58)|0);
    STACKTOP = sp;return;
   }
  }
  $72 = ___cxa_find_matching_catch_2()|0;
  $73 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3263,($12|0));
  $74 = __THREW__; __THREW__ = 0;
  $75 = $74&1;
  if ($75) {
   $76 = ___cxa_find_matching_catch_3(0|0)|0;
   $77 = tempRet0;
   ___clang_call_terminate($76);
   // unreachable;
  } else {
   ___resumeException($72|0);
   // unreachable;
  }
 }
 $78 = HEAP32[$24>>2]|0;
 $79 = HEAP32[$2>>2]|0;
 $80 = ($78|0)==($79|0);
 if ($80) {
  $$087$lcssa = 0;
 } else {
  $$087230 = 0;$83 = $78;
  while(1) {
   $82 = ((($83)) + -4|0);
   $84 = HEAP32[$82>>2]|0;
   $85 = HEAP32[$84>>2]|0;
   $86 = ((($85)) + 180|0);
   $87 = HEAP32[$86>>2]|0;
   $88 = (FUNCTION_TABLE_ii[$87 & 8191]($84)|0);
   $89 = ($88|0)==(0|0);
   if ($89) {
    $$188 = $$087230;
   } else {
    $90 = HEAP32[$82>>2]|0;
    $$188 = $90;
   }
   $91 = HEAP32[$2>>2]|0;
   $92 = ($82|0)==($91|0);
   if ($92) {
    $$087$lcssa = $$188;
    break;
   } else {
    $$087230 = $$188;$83 = $82;
   }
  }
 }
 $81 = ($4|0)==(0|0);
 if ($81) {
  /* fence */;
  $97 = ((($0)) + 84|0);
  $98 = HEAP32[$97>>2]|0;
  $205 = $98;$207 = 0.0;
 } else {
  $93 = ((($4)) + 16|0);
  $94 = +HEAPF64[$93>>3];
  $95 = ((($4)) + 12|0);
  $96 = HEAP32[$95>>2]|0;
  $205 = $96;$207 = $94;
 }
 $99 = HEAP32[$5>>2]|0;
 $100 = ($99|0)==(0|0);
 do {
  if ($100) {
   label = 115;
  } else {
   $101 = (___dynamic_cast($99,26488,32040,0)|0);
   $102 = ($101|0)==(0|0);
   if ($102) {
    label = 115;
   } else {
    $103 = ((($0)) + 24|0);
    $104 = HEAP32[$103>>2]|0;
    $105 = ((($104)) + 8|0);
    $106 = HEAP32[$105>>2]|0;
    (FUNCTION_TABLE_ii[$106 & 8191]($103)|0);
    $107 = ((($101)) + 12|0);
    $108 = HEAP8[$107>>0]|0;
    $109 = ($108<<24>>24)==(0);
    L51: do {
     if ($109) {
      __THREW__ = 0;
      $110 = (invoke_ii(3265,4)|0);
      $111 = __THREW__; __THREW__ = 0;
      $112 = $111&1;
      if ($112) {
       label = 44;
      } else {
       if ($110) {
        __THREW__ = 0;
        $113 = (invoke_ii(3266,4)|0);
        $114 = __THREW__; __THREW__ = 0;
        $115 = $114&1;
        if ($115) {
         label = 44;
        } else {
         __THREW__ = 0;
         $116 = (invoke_iiii(3267,($113|0),(164227|0),85)|0);
         $117 = __THREW__; __THREW__ = 0;
         $118 = $117&1;
         if ($118) {
          label = 44;
         } else {
          $119 = HEAP32[$116>>2]|0;
          $120 = ((($119)) + -12|0);
          $121 = HEAP32[$120>>2]|0;
          $122 = (($116) + ($121)|0);
          __THREW__ = 0;
          invoke_vii(3257,($11|0),($122|0));
          $123 = __THREW__; __THREW__ = 0;
          $124 = $123&1;
          if ($124) {
           label = 44;
          } else {
           __THREW__ = 0;
           $125 = (invoke_iii(3255,($11|0),(215188|0))|0);
           $126 = __THREW__; __THREW__ = 0;
           $127 = $126&1;
           if (!($127)) {
            $128 = HEAP32[$125>>2]|0;
            $129 = ((($128)) + 28|0);
            $130 = HEAP32[$129>>2]|0;
            __THREW__ = 0;
            $131 = (invoke_iii($130|0,($125|0),10)|0);
            $132 = __THREW__; __THREW__ = 0;
            $133 = $132&1;
            if (!($133)) {
             __THREW__ = 0;
             invoke_vi(3263,($11|0));
             $140 = __THREW__; __THREW__ = 0;
             $141 = $140&1;
             if ($141) {
              label = 44;
              break;
             }
             __THREW__ = 0;
             (invoke_iii(3268,($116|0),($131|0))|0);
             $142 = __THREW__; __THREW__ = 0;
             $143 = $142&1;
             if ($143) {
              label = 44;
              break;
             }
             __THREW__ = 0;
             (invoke_ii(3269,($116|0))|0);
             $144 = __THREW__; __THREW__ = 0;
             $145 = $144&1;
             if ($145) {
              label = 44;
              break;
             } else {
              $$079 = 0;$$081 = 0;$$083 = 0;
              label = 108;
              break;
             }
            }
           }
           $134 = ___cxa_find_matching_catch_2()|0;
           $135 = tempRet0;
           __THREW__ = 0;
           invoke_vi(3263,($11|0));
           $136 = __THREW__; __THREW__ = 0;
           $137 = $136&1;
           if ($137) {
            $138 = ___cxa_find_matching_catch_3(0|0)|0;
            $139 = tempRet0;
            ___clang_call_terminate($138);
            // unreachable;
           } else {
            $eh$lpad$body$index4Z2D = $135;$eh$lpad$body$indexZ2D = $134;
            break;
           }
          }
         }
        }
       } else {
        $$079 = 0;$$081 = 0;$$083 = 0;
        label = 108;
       }
      }
     } else {
      __THREW__ = 0;
      $153 = (invoke_ii(3265,4)|0);
      $154 = __THREW__; __THREW__ = 0;
      $155 = $154&1;
      if ($155) {
       label = 44;
      } else {
       L69: do {
        if ($153) {
         __THREW__ = 0;
         $156 = (invoke_ii(3266,4)|0);
         $157 = __THREW__; __THREW__ = 0;
         $158 = $157&1;
         if ($158) {
          label = 44;
          break L51;
         }
         __THREW__ = 0;
         $159 = (invoke_iiii(3267,($156|0),(164313|0),31)|0);
         $160 = __THREW__; __THREW__ = 0;
         $161 = $160&1;
         if ($161) {
          label = 44;
          break L51;
         }
         $162 = ((($1)) + 11|0);
         $163 = HEAP8[$162>>0]|0;
         $164 = ($163<<24>>24)<(0);
         $165 = HEAP32[$1>>2]|0;
         $166 = $164 ? $165 : $1;
         $167 = ((($1)) + 4|0);
         $168 = HEAP32[$167>>2]|0;
         $169 = $163&255;
         $170 = $164 ? $168 : $169;
         __THREW__ = 0;
         $171 = (invoke_iiii(3267,($159|0),($166|0),($170|0))|0);
         $172 = __THREW__; __THREW__ = 0;
         $173 = $172&1;
         if ($173) {
          label = 44;
          break L51;
         }
         __THREW__ = 0;
         $174 = (invoke_iiii(3267,($171|0),(164345|0),28)|0);
         $175 = __THREW__; __THREW__ = 0;
         $176 = $175&1;
         if ($176) {
          label = 44;
          break L51;
         }
         $177 = HEAP32[$174>>2]|0;
         $178 = ((($177)) + -12|0);
         $179 = HEAP32[$178>>2]|0;
         $180 = (($174) + ($179)|0);
         __THREW__ = 0;
         invoke_vii(3257,($10|0),($180|0));
         $181 = __THREW__; __THREW__ = 0;
         $182 = $181&1;
         if ($182) {
          label = 44;
          break L51;
         }
         __THREW__ = 0;
         $183 = (invoke_iii(3255,($10|0),(215188|0))|0);
         $184 = __THREW__; __THREW__ = 0;
         $185 = $184&1;
         do {
          if (!($185)) {
           $186 = HEAP32[$183>>2]|0;
           $187 = ((($186)) + 28|0);
           $188 = HEAP32[$187>>2]|0;
           __THREW__ = 0;
           $189 = (invoke_iii($188|0,($183|0),10)|0);
           $190 = __THREW__; __THREW__ = 0;
           $191 = $190&1;
           if ($191) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3263,($10|0));
           $198 = __THREW__; __THREW__ = 0;
           $199 = $198&1;
           if ($199) {
            label = 44;
            break L51;
           }
           __THREW__ = 0;
           (invoke_iii(3268,($174|0),($189|0))|0);
           $200 = __THREW__; __THREW__ = 0;
           $201 = $200&1;
           if ($201) {
            label = 44;
            break L51;
           }
           __THREW__ = 0;
           (invoke_ii(3269,($174|0))|0);
           $202 = __THREW__; __THREW__ = 0;
           $203 = $202&1;
           if ($203) {
            label = 44;
            break L51;
           } else {
            break L69;
           }
          }
         } while(0);
         $192 = ___cxa_find_matching_catch_2()|0;
         $193 = tempRet0;
         __THREW__ = 0;
         invoke_vi(3263,($10|0));
         $194 = __THREW__; __THREW__ = 0;
         $195 = $194&1;
         if ($195) {
          $196 = ___cxa_find_matching_catch_3(0|0)|0;
          $197 = tempRet0;
          ___clang_call_terminate($196);
          // unreachable;
         } else {
          $eh$lpad$body$index4Z2D = $193;$eh$lpad$body$indexZ2D = $192;
          break L51;
         }
        }
       } while(0);
       HEAP8[$107>>0] = 1;
       $204 = ((($101)) + 44|0);
       HEAP32[$204>>2] = $205;
       $206 = ((($101)) + 48|0);
       HEAPF64[$206>>3] = $207;
       $208 = ((($101)) + 56|0);
       HEAPF32[$208>>2] = $3;
       $209 = ((($101)) + 60|0);
       $210 = HEAP32[$209>>2]|0;
       $211 = (($210) + 1)|0;
       HEAP32[$209>>2] = $211;
       $212 = HEAP32[$5>>2]|0;
       /* fence */;
       $213 = ((($212)) + 8|0);
       $214 = HEAP32[$213>>2]|0;
       $215 = ($214|0)==(1);
       if ($215) {
        __THREW__ = 0;
        $216 = (invoke_ii(3265,4)|0);
        $217 = __THREW__; __THREW__ = 0;
        $218 = $217&1;
        if ($218) {
         label = 44;
        } else {
         L88: do {
          if ($216) {
           __THREW__ = 0;
           $219 = (invoke_ii(3266,4)|0);
           $220 = __THREW__; __THREW__ = 0;
           $221 = $220&1;
           if ($221) {
            label = 44;
            break L51;
           }
           __THREW__ = 0;
           $222 = (invoke_iiii(3267,($219|0),(164313|0),31)|0);
           $223 = __THREW__; __THREW__ = 0;
           $224 = $223&1;
           if ($224) {
            label = 44;
            break L51;
           }
           $225 = ((($1)) + 11|0);
           $226 = HEAP8[$225>>0]|0;
           $227 = ($226<<24>>24)<(0);
           $228 = HEAP32[$1>>2]|0;
           $229 = $227 ? $228 : $1;
           $230 = ((($1)) + 4|0);
           $231 = HEAP32[$230>>2]|0;
           $232 = $226&255;
           $233 = $227 ? $231 : $232;
           __THREW__ = 0;
           $234 = (invoke_iiii(3267,($222|0),($229|0),($233|0))|0);
           $235 = __THREW__; __THREW__ = 0;
           $236 = $235&1;
           if ($236) {
            label = 44;
            break L51;
           }
           __THREW__ = 0;
           $237 = (invoke_iiii(3267,($234|0),(164374|0),25)|0);
           $238 = __THREW__; __THREW__ = 0;
           $239 = $238&1;
           if ($239) {
            label = 44;
            break L51;
           }
           $240 = HEAP32[$237>>2]|0;
           $241 = ((($240)) + -12|0);
           $242 = HEAP32[$241>>2]|0;
           $243 = (($237) + ($242)|0);
           __THREW__ = 0;
           invoke_vii(3257,($9|0),($243|0));
           $244 = __THREW__; __THREW__ = 0;
           $245 = $244&1;
           if ($245) {
            label = 44;
            break L51;
           }
           __THREW__ = 0;
           $246 = (invoke_iii(3255,($9|0),(215188|0))|0);
           $247 = __THREW__; __THREW__ = 0;
           $248 = $247&1;
           do {
            if (!($248)) {
             $249 = HEAP32[$246>>2]|0;
             $250 = ((($249)) + 28|0);
             $251 = HEAP32[$250>>2]|0;
             __THREW__ = 0;
             $252 = (invoke_iii($251|0,($246|0),10)|0);
             $253 = __THREW__; __THREW__ = 0;
             $254 = $253&1;
             if ($254) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3263,($9|0));
             $261 = __THREW__; __THREW__ = 0;
             $262 = $261&1;
             if ($262) {
              label = 44;
              break L51;
             }
             __THREW__ = 0;
             (invoke_iii(3268,($237|0),($252|0))|0);
             $263 = __THREW__; __THREW__ = 0;
             $264 = $263&1;
             if ($264) {
              label = 44;
              break L51;
             }
             __THREW__ = 0;
             (invoke_ii(3269,($237|0))|0);
             $265 = __THREW__; __THREW__ = 0;
             $266 = $265&1;
             if ($266) {
              label = 44;
              break L51;
             } else {
              break L88;
             }
            }
           } while(0);
           $255 = ___cxa_find_matching_catch_2()|0;
           $256 = tempRet0;
           __THREW__ = 0;
           invoke_vi(3263,($9|0));
           $257 = __THREW__; __THREW__ = 0;
           $258 = $257&1;
           if ($258) {
            $259 = ___cxa_find_matching_catch_3(0|0)|0;
            $260 = tempRet0;
            ___clang_call_terminate($259);
            // unreachable;
           } else {
            $eh$lpad$body$index4Z2D = $256;$eh$lpad$body$indexZ2D = $255;
            break L51;
           }
          }
         } while(0);
         HEAP32[$204>>2] = $205;
         HEAPF64[$206>>3] = $207;
         HEAPF32[$208>>2] = $3;
         __THREW__ = 0;
         $267 = (invoke_ii(3325,($54|0))|0);
         $268 = __THREW__; __THREW__ = 0;
         $269 = $268&1;
         if ($269) {
          label = 44;
         } else {
          $270 = ((($101)) + 72|0);
          $271 = HEAP32[$270>>2]|0;
          $272 = ($271|0)==($267|0);
          if ($272) {
           $282 = $267;
          } else {
           HEAP32[$270>>2] = $267;
           $273 = ($267|0)==(0|0);
           if (!($273)) {
            $274 = ((($267)) + 8|0);
            $275 = HEAP32[$274>>2]|0;HEAP32[$274>>2] = (($275+1)|0);
           }
           $276 = ($271|0)==(0|0);
           do {
            if (!($276)) {
             $277 = ((($271)) + 8|0);
             $278 = HEAP32[$277>>2]|0;HEAP32[$277>>2] = (($278-1)|0);
             $279 = ($278|0)==(1);
             if (!($279)) {
              break;
             }
             __THREW__ = 0;
             invoke_viii(3262,($271|0),1,1);
             $280 = __THREW__; __THREW__ = 0;
             $281 = $280&1;
             if ($281) {
              label = 44;
              break L51;
             }
            }
           } while(0);
           $$pr$i = HEAP32[$270>>2]|0;
           $282 = $$pr$i;
          }
          $283 = ($282|0)==(0|0);
          if ($283) {
           $288 = 0;
          } else {
           $284 = ((($282)) + 24|0);
           $285 = HEAP32[$284>>2]|0;
           $286 = ($285|0)!=(0|0);
           $$$i = $286 ? $54 : 0;
           $288 = $$$i;
          }
          $287 = ((($101)) + 76|0);
          HEAP32[$287>>2] = $288;
          $289 = ((($101)) + 64|0);
          $290 = ($$087$lcssa|0)==(0|0);
          if ($290) {
           $296 = 0;
          } else {
           __THREW__ = 0;
           $291 = (invoke_ii(3325,($$087$lcssa|0))|0);
           $292 = __THREW__; __THREW__ = 0;
           $293 = $292&1;
           if ($293) {
            label = 44;
            break;
           } else {
            $296 = $291;
           }
          }
          $294 = HEAP32[$289>>2]|0;
          $295 = ($294|0)==($296|0);
          if ($295) {
           $306 = $296;
          } else {
           HEAP32[$289>>2] = $296;
           $297 = ($296|0)==(0|0);
           if (!($297)) {
            $298 = ((($296)) + 8|0);
            $299 = HEAP32[$298>>2]|0;HEAP32[$298>>2] = (($299+1)|0);
           }
           $300 = ($294|0)==(0|0);
           do {
            if (!($300)) {
             $301 = ((($294)) + 8|0);
             $302 = HEAP32[$301>>2]|0;HEAP32[$301>>2] = (($302-1)|0);
             $303 = ($302|0)==(1);
             if (!($303)) {
              break;
             }
             __THREW__ = 0;
             invoke_viii(3262,($294|0),1,1);
             $304 = __THREW__; __THREW__ = 0;
             $305 = $304&1;
             if ($305) {
              label = 44;
              break L51;
             }
            }
           } while(0);
           $$pr$i129 = HEAP32[$289>>2]|0;
           $306 = $$pr$i129;
          }
          $307 = ($306|0)==(0|0);
          if ($307) {
           $312 = 0;
          } else {
           $308 = ((($306)) + 24|0);
           $309 = HEAP32[$308>>2]|0;
           $310 = ($309|0)!=(0|0);
           $$$i132 = $310 ? $$087$lcssa : 0;
           $312 = $$$i132;
          }
          $311 = ((($101)) + 68|0);
          HEAP32[$311>>2] = $312;
          $313 = ((($101)) + 84|0);
          $314 = HEAP32[$313>>2]|0;
          $315 = ($314|0)==($$086|0);
          do {
           if (!($315)) {
            HEAP32[$313>>2] = $$086;
            $316 = ($$086|0)==(0|0);
            if (!($316)) {
             $317 = ((($$086)) + 8|0);
             $318 = HEAP32[$317>>2]|0;HEAP32[$317>>2] = (($318+1)|0);
            }
            $319 = ($314|0)==(0|0);
            if ($319) {
             break;
            }
            $320 = ((($314)) + 8|0);
            $321 = HEAP32[$320>>2]|0;HEAP32[$320>>2] = (($321-1)|0);
            $322 = ($321|0)==(1);
            if (!($322)) {
             break;
            }
            __THREW__ = 0;
            invoke_viii(3262,($314|0),1,1);
            $323 = __THREW__; __THREW__ = 0;
            $324 = $323&1;
            if ($324) {
             label = 44;
             break L51;
            }
           }
          } while(0);
          $325 = ((($101)) + 88|0);
          $326 = HEAP32[$325>>2]|0;
          $327 = ($326|0)==(0|0);
          if ($327) {
           $$079 = 1;$$081 = $101;$$083 = 1;
           label = 108;
           break;
          }
          HEAP32[$325>>2] = 0;
          $328 = ((($326)) + 8|0);
          $329 = HEAP32[$328>>2]|0;HEAP32[$328>>2] = (($329-1)|0);
          $330 = ($329|0)==(1);
          if (!($330)) {
           $$079 = 1;$$081 = $101;$$083 = 1;
           label = 108;
           break;
          }
          __THREW__ = 0;
          invoke_viii(3262,($326|0),1,1);
          $331 = __THREW__; __THREW__ = 0;
          $332 = $331&1;
          if ($332) {
           label = 44;
          } else {
           $$079 = 1;$$081 = $101;$$083 = 1;
           label = 108;
          }
         }
        }
       } else {
        $$079 = 0;$$081 = $101;$$083 = 1;
        label = 108;
       }
      }
     }
    } while(0);
    if ((label|0) == 44) {
     $146 = ___cxa_find_matching_catch_2()|0;
     $147 = tempRet0;
     $eh$lpad$body$index4Z2D = $147;$eh$lpad$body$indexZ2D = $146;
    }
    else if ((label|0) == 108) {
     $333 = HEAP32[$103>>2]|0;
     $334 = ((($333)) + 12|0);
     $335 = HEAP32[$334>>2]|0;
     (FUNCTION_TABLE_ii[$335 & 8191]($103)|0);
     if (!($$079)) {
      if ($$083) {
       break;
      } else {
       label = 115;
       break;
      }
     }
     $336 = ((($0)) + 88|0);
     $337 = HEAP32[$336>>2]|0;
     $338 = ((($337)) + 28|0);
     $339 = HEAP32[$338>>2]|0;
     $340 = ((($339)) + 8|0);
     $341 = HEAP32[$340>>2]|0;
     (FUNCTION_TABLE_ii[$341 & 8191]($338)|0);
     __THREW__ = 0;
     invoke_vii(4123,($337|0),($$081|0));
     $342 = __THREW__; __THREW__ = 0;
     $343 = $342&1;
     if (!($343)) {
      $353 = HEAP32[$338>>2]|0;
      $354 = ((($353)) + 12|0);
      $355 = HEAP32[$354>>2]|0;
      (FUNCTION_TABLE_ii[$355 & 8191]($338)|0);
      if ($$083) {
       break;
      } else {
       label = 115;
       break;
      }
     }
     $344 = ___cxa_find_matching_catch_2()|0;
     $345 = tempRet0;
     $346 = HEAP32[$338>>2]|0;
     $347 = ((($346)) + 12|0);
     $348 = HEAP32[$347>>2]|0;
     __THREW__ = 0;
     (invoke_ii($348|0,($338|0))|0);
     $349 = __THREW__; __THREW__ = 0;
     $350 = $349&1;
     if ($350) {
      $351 = ___cxa_find_matching_catch_3(0|0)|0;
      $352 = tempRet0;
      ___clang_call_terminate($351);
      // unreachable;
     } else {
      ___resumeException($344|0);
      // unreachable;
     }
    }
    $148 = HEAP32[$103>>2]|0;
    $149 = ((($148)) + 12|0);
    $150 = HEAP32[$149>>2]|0;
    __THREW__ = 0;
    (invoke_ii($150|0,($103|0))|0);
    $151 = __THREW__; __THREW__ = 0;
    $152 = $151&1;
    if ($152) {
     $606 = ___cxa_find_matching_catch_3(0|0)|0;
     $607 = tempRet0;
     ___clang_call_terminate($606);
     // unreachable;
    }
    $$3 = $eh$lpad$body$index4Z2D;$$378 = $eh$lpad$body$indexZ2D;
    ___resumeException($$378|0);
    // unreachable;
   }
  }
 } while(0);
 if ((label|0) == 115) {
  $356 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
  do {
   if ($356) {
    $357 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
    $358 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($357,164400,34)|0);
    $359 = ((($1)) + 11|0);
    $360 = HEAP8[$359>>0]|0;
    $361 = ($360<<24>>24)<(0);
    $362 = HEAP32[$1>>2]|0;
    $363 = $361 ? $362 : $1;
    $364 = ((($1)) + 4|0);
    $365 = HEAP32[$364>>2]|0;
    $366 = $360&255;
    $367 = $361 ? $365 : $366;
    $368 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($358,$363,$367)|0);
    $369 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($368,174996,1)|0);
    $370 = HEAP32[$369>>2]|0;
    $371 = ((($370)) + -12|0);
    $372 = HEAP32[$371>>2]|0;
    $373 = (($369) + ($372)|0);
    __ZNKSt3__28ios_base6getlocEv($8,$373);
    __THREW__ = 0;
    $374 = (invoke_iii(3255,($8|0),(215188|0))|0);
    $375 = __THREW__; __THREW__ = 0;
    $376 = $375&1;
    if (!($376)) {
     $377 = HEAP32[$374>>2]|0;
     $378 = ((($377)) + 28|0);
     $379 = HEAP32[$378>>2]|0;
     __THREW__ = 0;
     $380 = (invoke_iii($379|0,($374|0),10)|0);
     $381 = __THREW__; __THREW__ = 0;
     $382 = $381&1;
     if (!($382)) {
      __ZNSt3__26localeD2Ev($8);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($369,$380)|0);
      (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($369)|0);
      break;
     }
    }
    $383 = ___cxa_find_matching_catch_2()|0;
    $384 = tempRet0;
    __THREW__ = 0;
    invoke_vi(3263,($8|0));
    $385 = __THREW__; __THREW__ = 0;
    $386 = $385&1;
    if ($386) {
     $387 = ___cxa_find_matching_catch_3(0|0)|0;
     $388 = tempRet0;
     ___clang_call_terminate($387);
     // unreachable;
    } else {
     ___resumeException($383|0);
     // unreachable;
    }
   }
  } while(0);
  $389 = ((($0)) + 88|0);
  $390 = HEAP32[$389>>2]|0;
  $391 = ((($390)) + 28|0);
  $392 = HEAP32[$391>>2]|0;
  $393 = ((($392)) + 8|0);
  $394 = HEAP32[$393>>2]|0;
  (FUNCTION_TABLE_ii[$394 & 8191]($391)|0);
  $395 = HEAP32[$5>>2]|0;
  $396 = ($395|0)==(0|0);
  if ($396) {
   label = 124;
  } else {
   /* fence */;
   $397 = ((($395)) + 8|0);
   $398 = HEAP32[$397>>2]|0;
   $399 = ($398|0)==(1);
   if ($399) {
    label = 124;
   }
  }
  L176: do {
   if ((label|0) == 124) {
    __THREW__ = 0;
    $400 = (invoke_ii(3276,104)|0);
    $401 = __THREW__; __THREW__ = 0;
    $402 = $401&1;
    L178: do {
     if ($402) {
      $499 = ___cxa_find_matching_catch_2()|0;
      $500 = tempRet0;
      $$1 = $500;$$176 = $499;
     } else {
      __THREW__ = 0;
      invoke_vii(3435,($400|0),1);
      $403 = __THREW__; __THREW__ = 0;
      $404 = $403&1;
      if ($404) {
       $501 = ___cxa_find_matching_catch_2()|0;
       $502 = tempRet0;
       __ZdlPv($400);
       $$1 = $502;$$176 = $501;
       break;
      }
      HEAP32[$400>>2] = (74268);
      $405 = ((($400)) + 12|0);
      HEAP8[$405>>0] = 0;
      $406 = ((($400)) + 16|0);
      dest=$406; stop=dest+84|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));HEAP8[$406+84>>0]=0|0;
      $407 = ((($400)) + 8|0);
      $408 = HEAP32[$407>>2]|0;HEAP32[$407>>2] = (($408+1)|0);
      $409 = HEAP32[$5>>2]|0;
      $410 = ($409|0)==($400|0);
      if ($410) {
       label = 130;
      } else {
       HEAP32[$5>>2] = $400;
       $411 = HEAP32[$407>>2]|0;HEAP32[$407>>2] = (($411+1)|0);
       $412 = ($409|0)==(0|0);
       if ($412) {
        label = 130;
       } else {
        $413 = ((($409)) + 8|0);
        $414 = HEAP32[$413>>2]|0;HEAP32[$413>>2] = (($414-1)|0);
        $415 = ($414|0)==(1);
        if ($415) {
         __THREW__ = 0;
         invoke_viii(3262,($409|0),1,1);
         $416 = __THREW__; __THREW__ = 0;
         $417 = $416&1;
         if (!($417)) {
          label = 130;
         }
        } else {
         label = 130;
        }
       }
      }
      L188: do {
       if ((label|0) == 130) {
        HEAP8[$405>>0] = 1;
        __THREW__ = 0;
        (invoke_iii(3477,($406|0),($1|0))|0);
        $418 = __THREW__; __THREW__ = 0;
        $419 = $418&1;
        if (!($419)) {
         $420 = ((($400)) + 28|0);
         HEAP32[$420>>2] = $205;
         $421 = ((($400)) + 32|0);
         HEAPF64[$421>>3] = $207;
         $422 = ((($400)) + 40|0);
         HEAPF32[$422>>2] = $3;
         $423 = ((($400)) + 44|0);
         HEAP32[$423>>2] = $205;
         $424 = ((($400)) + 48|0);
         HEAPF64[$424>>3] = $207;
         $425 = ((($400)) + 56|0);
         HEAPF32[$425>>2] = $3;
         __THREW__ = 0;
         $426 = (invoke_ii(3325,($54|0))|0);
         $427 = __THREW__; __THREW__ = 0;
         $428 = $427&1;
         if (!($428)) {
          $429 = ((($400)) + 72|0);
          $430 = HEAP32[$429>>2]|0;
          $431 = ($430|0)==($426|0);
          if ($431) {
           $441 = $426;
          } else {
           HEAP32[$429>>2] = $426;
           $432 = ($426|0)==(0|0);
           if (!($432)) {
            $433 = ((($426)) + 8|0);
            $434 = HEAP32[$433>>2]|0;HEAP32[$433>>2] = (($434+1)|0);
           }
           $435 = ($430|0)==(0|0);
           do {
            if (!($435)) {
             $436 = ((($430)) + 8|0);
             $437 = HEAP32[$436>>2]|0;HEAP32[$436>>2] = (($437-1)|0);
             $438 = ($437|0)==(1);
             if (!($438)) {
              break;
             }
             __THREW__ = 0;
             invoke_viii(3262,($430|0),1,1);
             $439 = __THREW__; __THREW__ = 0;
             $440 = $439&1;
             if ($440) {
              break L188;
             }
            }
           } while(0);
           $$pr$i141 = HEAP32[$429>>2]|0;
           $441 = $$pr$i141;
          }
          $442 = ($441|0)==(0|0);
          if ($442) {
           $447 = 0;
          } else {
           $443 = ((($441)) + 24|0);
           $444 = HEAP32[$443>>2]|0;
           $445 = ($444|0)!=(0|0);
           $$$i144 = $445 ? $54 : 0;
           $447 = $$$i144;
          }
          $446 = ((($400)) + 76|0);
          HEAP32[$446>>2] = $447;
          $448 = ((($400)) + 64|0);
          $449 = ($$087$lcssa|0)==(0|0);
          if ($449) {
           $455 = 0;
          } else {
           __THREW__ = 0;
           $450 = (invoke_ii(3325,($$087$lcssa|0))|0);
           $451 = __THREW__; __THREW__ = 0;
           $452 = $451&1;
           if ($452) {
            break;
           } else {
            $455 = $450;
           }
          }
          $453 = HEAP32[$448>>2]|0;
          $454 = ($453|0)==($455|0);
          if ($454) {
           $465 = $455;
          } else {
           HEAP32[$448>>2] = $455;
           $456 = ($455|0)==(0|0);
           if (!($456)) {
            $457 = ((($455)) + 8|0);
            $458 = HEAP32[$457>>2]|0;HEAP32[$457>>2] = (($458+1)|0);
           }
           $459 = ($453|0)==(0|0);
           do {
            if (!($459)) {
             $460 = ((($453)) + 8|0);
             $461 = HEAP32[$460>>2]|0;HEAP32[$460>>2] = (($461-1)|0);
             $462 = ($461|0)==(1);
             if (!($462)) {
              break;
             }
             __THREW__ = 0;
             invoke_viii(3262,($453|0),1,1);
             $463 = __THREW__; __THREW__ = 0;
             $464 = $463&1;
             if ($464) {
              break L188;
             }
            }
           } while(0);
           $$pr$i148 = HEAP32[$448>>2]|0;
           $465 = $$pr$i148;
          }
          $466 = ($465|0)==(0|0);
          if ($466) {
           $471 = 0;
          } else {
           $467 = ((($465)) + 24|0);
           $468 = HEAP32[$467>>2]|0;
           $469 = ($468|0)!=(0|0);
           $$$i151 = $469 ? $$087$lcssa : 0;
           $471 = $$$i151;
          }
          $470 = ((($400)) + 68|0);
          HEAP32[$470>>2] = $471;
          $472 = ((($400)) + 84|0);
          $473 = HEAP32[$472>>2]|0;
          $474 = ($473|0)==($$086|0);
          do {
           if (!($474)) {
            HEAP32[$472>>2] = $$086;
            $475 = ($$086|0)==(0|0);
            if (!($475)) {
             $476 = ((($$086)) + 8|0);
             $477 = HEAP32[$476>>2]|0;HEAP32[$476>>2] = (($477+1)|0);
            }
            $478 = ($473|0)==(0|0);
            if ($478) {
             break;
            }
            $479 = ((($473)) + 8|0);
            $480 = HEAP32[$479>>2]|0;HEAP32[$479>>2] = (($480-1)|0);
            $481 = ($480|0)==(1);
            if (!($481)) {
             break;
            }
            __THREW__ = 0;
            invoke_viii(3262,($473|0),1,1);
            $482 = __THREW__; __THREW__ = 0;
            $483 = $482&1;
            if ($483) {
             break L188;
            }
           }
          } while(0);
          $484 = ((($400)) + 88|0);
          $485 = HEAP32[$484>>2]|0;
          $486 = ($485|0)==(0|0);
          do {
           if (!($486)) {
            HEAP32[$484>>2] = 0;
            $487 = ((($485)) + 8|0);
            $488 = HEAP32[$487>>2]|0;HEAP32[$487>>2] = (($488-1)|0);
            $489 = ($488|0)==(1);
            if (!($489)) {
             break;
            }
            __THREW__ = 0;
            invoke_viii(3262,($485|0),1,1);
            $490 = __THREW__; __THREW__ = 0;
            $491 = $490&1;
            if ($491) {
             break L188;
            }
           }
          } while(0);
          $492 = HEAP32[$389>>2]|0;
          __THREW__ = 0;
          invoke_vii(4123,($492|0),($400|0));
          $493 = __THREW__; __THREW__ = 0;
          $494 = $493&1;
          if ($494) {
           break;
          }
          $495 = HEAP32[$407>>2]|0;HEAP32[$407>>2] = (($495-1)|0);
          $496 = ($495|0)==(1);
          if (!($496)) {
           break L176;
          }
          __THREW__ = 0;
          invoke_viii(3262,($400|0),1,1);
          $497 = __THREW__; __THREW__ = 0;
          $498 = $497&1;
          if (!($498)) {
           break L176;
          }
          $509 = ___cxa_find_matching_catch_2()|0;
          $510 = tempRet0;
          $$1 = $510;$$176 = $509;
          break L178;
         }
        }
       }
      } while(0);
      $503 = ___cxa_find_matching_catch_2()|0;
      $504 = tempRet0;
      $505 = HEAP32[$407>>2]|0;HEAP32[$407>>2] = (($505-1)|0);
      $506 = ($505|0)==(1);
      if ($506) {
       __THREW__ = 0;
       invoke_viii(3262,($400|0),1,1);
       $507 = __THREW__; __THREW__ = 0;
       $508 = $507&1;
       if ($508) {
        $606 = ___cxa_find_matching_catch_3(0|0)|0;
        $607 = tempRet0;
        ___clang_call_terminate($606);
        // unreachable;
       } else {
        $$1 = $504;$$176 = $503;
       }
      } else {
       $$1 = $504;$$176 = $503;
      }
     }
    } while(0);
    $514 = HEAP32[$391>>2]|0;
    $515 = ((($514)) + 12|0);
    $516 = HEAP32[$515>>2]|0;
    __THREW__ = 0;
    (invoke_ii($516|0,($391|0))|0);
    $517 = __THREW__; __THREW__ = 0;
    $518 = $517&1;
    if ($518) {
     $606 = ___cxa_find_matching_catch_3(0|0)|0;
     $607 = tempRet0;
     ___clang_call_terminate($606);
     // unreachable;
    } else {
     $$3 = $$1;$$378 = $$176;
     ___resumeException($$378|0);
     // unreachable;
    }
   }
  } while(0);
  $511 = HEAP32[$391>>2]|0;
  $512 = ((($511)) + 12|0);
  $513 = HEAP32[$512>>2]|0;
  (FUNCTION_TABLE_ii[$513 & 8191]($391)|0);
 }
 $519 = ((($0)) + 36|0);
 $520 = HEAP8[$519>>0]|0;
 $521 = ($520<<24>>24)==(0);
 if (!($521)) {
  STACKTOP = sp;return;
 }
 $522 = ((($0)) + 12|0);
 $523 = HEAP32[$522>>2]|0;
 $524 = ((($523)) + 8|0);
 $525 = HEAP32[$524>>2]|0;
 (FUNCTION_TABLE_ii[$525 & 8191]($522)|0);
 $526 = HEAP8[$519>>0]|0;
 $527 = ($526<<24>>24)==(0);
 L248: do {
  if ($527) {
   HEAP8[$519>>0] = 1;
   $528 = ((($0)) + 52|0);
   HEAP8[$528>>0] = 0;
   __THREW__ = 0;
   $529 = (invoke_ii(3265,4)|0);
   $530 = __THREW__; __THREW__ = 0;
   $531 = $530&1;
   L250: do {
    if ($531) {
     label = 186;
    } else {
     do {
      if ($529) {
       __THREW__ = 0;
       $532 = (invoke_ii(3266,4)|0);
       $533 = __THREW__; __THREW__ = 0;
       $534 = $533&1;
       if ($534) {
        label = 186;
        break L250;
       }
       __THREW__ = 0;
       $535 = (invoke_iiii(3267,($532|0),(163872|0),28)|0);
       $536 = __THREW__; __THREW__ = 0;
       $537 = $536&1;
       if ($537) {
        label = 186;
        break L250;
       }
       $538 = HEAP32[$535>>2]|0;
       $539 = ((($538)) + -12|0);
       $540 = HEAP32[$539>>2]|0;
       $541 = (($535) + ($540)|0);
       __THREW__ = 0;
       invoke_vii(3257,($7|0),($541|0));
       $542 = __THREW__; __THREW__ = 0;
       $543 = $542&1;
       if ($543) {
        label = 186;
        break L250;
       }
       __THREW__ = 0;
       $544 = (invoke_iii(3255,($7|0),(215188|0))|0);
       $545 = __THREW__; __THREW__ = 0;
       $546 = $545&1;
       if (!($546)) {
        $547 = HEAP32[$544>>2]|0;
        $548 = ((($547)) + 28|0);
        $549 = HEAP32[$548>>2]|0;
        __THREW__ = 0;
        $550 = (invoke_iii($549|0,($544|0),10)|0);
        $551 = __THREW__; __THREW__ = 0;
        $552 = $551&1;
        if (!($552)) {
         __THREW__ = 0;
         invoke_vi(3263,($7|0));
         $559 = __THREW__; __THREW__ = 0;
         $560 = $559&1;
         if ($560) {
          label = 186;
          break L250;
         }
         __THREW__ = 0;
         (invoke_iii(3268,($535|0),($550|0))|0);
         $561 = __THREW__; __THREW__ = 0;
         $562 = $561&1;
         if ($562) {
          label = 186;
          break L250;
         }
         __THREW__ = 0;
         (invoke_ii(3269,($535|0))|0);
         $563 = __THREW__; __THREW__ = 0;
         $564 = $563&1;
         if ($564) {
          label = 186;
          break L250;
         } else {
          break;
         }
        }
       }
       $553 = ___cxa_find_matching_catch_2()|0;
       $554 = tempRet0;
       __THREW__ = 0;
       invoke_vi(3263,($7|0));
       $555 = __THREW__; __THREW__ = 0;
       $556 = $555&1;
       if ($556) {
        $557 = ___cxa_find_matching_catch_3(0|0)|0;
        $558 = tempRet0;
        ___clang_call_terminate($557);
        // unreachable;
       } else {
        $$sink227$index = $553;$$sink227$index12 = $554;
        break L250;
       }
      }
     } while(0);
     $567 = ((($0)) + 56|0);
     $568 = HEAP32[$567>>2]|0;
     $569 = ((($0)) + 60|0);
     $570 = HEAP32[$569>>2]|0;
     $571 = ($568|0)==($570|0);
     if ($571) {
      __THREW__ = 0;
      $572 = (invoke_i(3285)|0);
      $573 = __THREW__; __THREW__ = 0;
      $574 = $573&1;
      if ($574) {
       label = 186;
       break;
      }
      $575 = HEAP32[$572>>2]|0;
      $576 = ((($575)) + 96|0);
      $577 = HEAP32[$576>>2]|0;
      __THREW__ = 0;
      $578 = (invoke_i(3285)|0);
      $579 = __THREW__; __THREW__ = 0;
      $580 = $579&1;
      if ($580) {
       label = 186;
       break;
      }
      $581 = HEAP32[$578>>2]|0;
      $582 = ((($581)) + 100|0);
      $583 = HEAP32[$582>>2]|0;
      __THREW__ = 0;
      invoke_viii(4135,($0|0),($577|0),($583|0));
      $584 = __THREW__; __THREW__ = 0;
      $585 = $584&1;
      if ($585) {
       label = 186;
       break;
      }
      $$pre = HEAP32[$567>>2]|0;
      $$pre233 = HEAP32[$569>>2]|0;
      $586 = $$pre;$588 = $$pre233;
     } else {
      $586 = $568;$588 = $570;
     }
     $587 = ($586|0)==($588|0);
     if ($587) {
      break L248;
     } else {
      $$sink228229 = $586;
     }
     while(1) {
      $589 = HEAP32[$$sink228229>>2]|0;
      $590 = ((($589)) + 12|0);
      __THREW__ = 0;
      (invoke_ii(3389,($590|0))|0);
      $591 = __THREW__; __THREW__ = 0;
      $592 = $591&1;
      if ($592) {
       break;
      }
      $593 = ((($$sink228229)) + 4|0);
      $594 = HEAP32[$569>>2]|0;
      $595 = ($593|0)==($594|0);
      if ($595) {
       break L248;
      } else {
       $$sink228229 = $593;
      }
     }
     $596 = ___cxa_find_matching_catch_2()|0;
     $597 = tempRet0;
     $$sink227$index = $596;$$sink227$index12 = $597;
    }
   } while(0);
   if ((label|0) == 186) {
    $565 = ___cxa_find_matching_catch_2()|0;
    $566 = tempRet0;
    $$sink227$index = $565;$$sink227$index12 = $566;
   }
   $601 = HEAP32[$522>>2]|0;
   $602 = ((($601)) + 12|0);
   $603 = HEAP32[$602>>2]|0;
   __THREW__ = 0;
   (invoke_ii($603|0,($522|0))|0);
   $604 = __THREW__; __THREW__ = 0;
   $605 = $604&1;
   if ($605) {
    $606 = ___cxa_find_matching_catch_3(0|0)|0;
    $607 = tempRet0;
    ___clang_call_terminate($606);
    // unreachable;
   } else {
    $$3 = $$sink227$index12;$$378 = $$sink227$index;
    ___resumeException($$378|0);
    // unreachable;
   }
  }
 } while(0);
 $598 = HEAP32[$522>>2]|0;
 $599 = ((($598)) + 12|0);
 $600 = HEAP32[$599>>2]|0;
 (FUNCTION_TABLE_ii[$600 & 8191]($522)|0);
 STACKTOP = sp;return;
}
function __ZNK5osgDB13DatabasePager9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (163974|0);
}
function __ZNK5osgDB13DatabasePager5cloneEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(168)|0);
 __THREW__ = 0;
 invoke_vii(4136,($1|0),($0|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch_2()|0;
  $5 = tempRet0;
  __ZdlPv($1);
  ___resumeException($4|0);
  // unreachable;
 } else {
  return ($1|0);
 }
 return (0)|0;
}
function __ZN5osgDB13DatabasePager6cancelEv($0) {
 $0 = $0|0;
 var $$sroa$011$016 = 0, $$sroa$05$015 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 56|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2|0)==($4|0);
 if (!($5)) {
  $$sroa$011$016 = $2;
  while(1) {
   $61 = HEAP32[$$sroa$011$016>>2]|0;
   $62 = ((($61)) + 20|0);
   $63 = HEAP32[$62>>2]|0;HEAP32[$62>>2] = 1;
   $64 = ((($$sroa$011$016)) + 4|0);
   $65 = HEAP32[$3>>2]|0;
   $66 = ($64|0)==($65|0);
   if ($66) {
    break;
   } else {
    $$sroa$011$016 = $64;
   }
  }
 }
 $6 = ((($0)) + 88|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($7)) + 44|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($9)) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11)) + 8|0);
 $13 = HEAP32[$12>>2]|0;
 (FUNCTION_TABLE_ii[$13 & 8191]($10)|0);
 $14 = ((($9)) + 24|0);
 $15 = HEAP8[$14>>0]|0;
 $16 = ($15<<24>>24)==(0);
 if ($16) {
  HEAP8[$14>>0] = 1;
  $17 = ((($9)) + 16|0);
  __THREW__ = 0;
  (invoke_ii(2504,($17|0))|0);
  $18 = __THREW__; __THREW__ = 0;
  $19 = $18&1;
  if ($19) {
   $20 = ___cxa_find_matching_catch_2()|0;
   $21 = tempRet0;
   $22 = HEAP32[$10>>2]|0;
   $23 = ((($22)) + 12|0);
   $24 = HEAP32[$23>>2]|0;
   __THREW__ = 0;
   (invoke_ii($24|0,($10|0))|0);
   $25 = __THREW__; __THREW__ = 0;
   $26 = $25&1;
   if ($26) {
    $27 = ___cxa_find_matching_catch_3(0|0)|0;
    $28 = tempRet0;
    ___clang_call_terminate($27);
    // unreachable;
   } else {
    ___resumeException($20|0);
    // unreachable;
   }
  }
 }
 $29 = HEAP32[$10>>2]|0;
 $30 = ((($29)) + 12|0);
 $31 = HEAP32[$30>>2]|0;
 (FUNCTION_TABLE_ii[$31 & 8191]($10)|0);
 $32 = ((($0)) + 92|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ((($33)) + 44|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = ((($35)) + 4|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = ((($37)) + 8|0);
 $39 = HEAP32[$38>>2]|0;
 (FUNCTION_TABLE_ii[$39 & 8191]($36)|0);
 $40 = ((($35)) + 24|0);
 $41 = HEAP8[$40>>0]|0;
 $42 = ($41<<24>>24)==(0);
 if ($42) {
  HEAP8[$40>>0] = 1;
  $43 = ((($35)) + 16|0);
  __THREW__ = 0;
  (invoke_ii(2504,($43|0))|0);
  $44 = __THREW__; __THREW__ = 0;
  $45 = $44&1;
  if ($45) {
   $46 = ___cxa_find_matching_catch_2()|0;
   $47 = tempRet0;
   $48 = HEAP32[$36>>2]|0;
   $49 = ((($48)) + 12|0);
   $50 = HEAP32[$49>>2]|0;
   __THREW__ = 0;
   (invoke_ii($50|0,($36|0))|0);
   $51 = __THREW__; __THREW__ = 0;
   $52 = $51&1;
   if ($52) {
    $53 = ___cxa_find_matching_catch_3(0|0)|0;
    $54 = tempRet0;
    ___clang_call_terminate($53);
    // unreachable;
   } else {
    ___resumeException($46|0);
    // unreachable;
   }
  }
 }
 $55 = HEAP32[$36>>2]|0;
 $56 = ((($55)) + 12|0);
 $57 = HEAP32[$56>>2]|0;
 (FUNCTION_TABLE_ii[$57 & 8191]($36)|0);
 $58 = HEAP32[$1>>2]|0;
 $59 = HEAP32[$3>>2]|0;
 $60 = ($58|0)==($59|0);
 if ($60) {
  $67 = ((($0)) + 52|0);
  HEAP8[$67>>0] = 1;
  $68 = ((($0)) + 36|0);
  HEAP8[$68>>0] = 0;
  return 0;
 } else {
  $$sroa$05$015 = $58;
 }
 while(1) {
  $69 = HEAP32[$$sroa$05$015>>2]|0;
  $70 = HEAP32[$69>>2]|0;
  $71 = ((($70)) + 12|0);
  $72 = HEAP32[$71>>2]|0;
  (FUNCTION_TABLE_ii[$72 & 8191]($69)|0);
  $73 = ((($$sroa$05$015)) + 4|0);
  $74 = HEAP32[$3>>2]|0;
  $75 = ($73|0)==($74|0);
  if ($75) {
   break;
  } else {
   $$sroa$05$015 = $73;
  }
 }
 $67 = ((($0)) + 52|0);
 HEAP8[$67>>0] = 1;
 $68 = ((($0)) + 36|0);
 HEAP8[$68>>0] = 0;
 return 0;
}
function __ZNK5osgDB13DatabasePager9isRunningEv($0) {
 $0 = $0|0;
 var $$sroa$04$08 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 56|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2|0)==($4|0);
 if ($5) {
  $12 = 0;
  return ($12|0);
 } else {
  $$sroa$04$08 = $2;
 }
 while(1) {
  $9 = HEAP32[$$sroa$04$08>>2]|0;
  $10 = ((($9)) + 12|0);
  $11 = (__ZN11OpenThreads6Thread9isRunningEv($10)|0);
  $7 = ((($$sroa$04$08)) + 4|0);
  if ($11) {
   $12 = 1;
   label = 4;
   break;
  }
  $6 = HEAP32[$3>>2]|0;
  $8 = ($7|0)==($6|0);
  if ($8) {
   $12 = 0;
   label = 4;
   break;
  } else {
   $$sroa$04$08 = $7;
  }
 }
 if ((label|0) == 4) {
  return ($12|0);
 }
 return (0)|0;
}
function __ZN5osgDB13DatabasePager5clearEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 88|0);
 $2 = HEAP32[$1>>2]|0;
 __ZN5osgDB13DatabasePager12RequestQueue5clearEv($2);
 $3 = ((($0)) + 92|0);
 $4 = HEAP32[$3>>2]|0;
 __ZN5osgDB13DatabasePager12RequestQueue5clearEv($4);
 $5 = ((($0)) + 96|0);
 $6 = HEAP32[$5>>2]|0;
 __ZN5osgDB13DatabasePager12RequestQueue5clearEv($6);
 $7 = ((($0)) + 100|0);
 $8 = HEAP32[$7>>2]|0;
 __ZN5osgDB13DatabasePager12RequestQueue5clearEv($8);
 $9 = ((($0)) + 120|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11)) + 16|0);
 $13 = HEAP32[$12>>2]|0;
 FUNCTION_TABLE_vi[$13 & 8191]($10);
 return;
}
function __ZN5osgDB13DatabasePager20setProcessorAffinityERKN11OpenThreads8AffinityE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $$sroa$03$07 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy1 = sp + 12|0;
 $$byval_copy = sp + 8|0;
 $2 = sp + 4|0;
 $3 = sp;
 $4 = ((($0)) + 40|0);
 $5 = ($4|0)==($1|0);
 if (!($5)) {
  $6 = HEAP32[$1>>2]|0;
  HEAP32[$2>>2] = $6;
  $7 = ((($1)) + 4|0);
  HEAP32[$3>>2] = $7;
  ;HEAP32[$$byval_copy>>2]=HEAP32[$2>>2]|0;
  ;HEAP32[$$byval_copy1>>2]=HEAP32[$3>>2]|0;
  __ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEE14__assign_multiINS_21__tree_const_iteratorIjPNS_11__tree_nodeIjPvEEiEEEEvT_SD_($4,$$byval_copy,$$byval_copy1);
 }
 $8 = ((($0)) + 56|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($0)) + 60|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($9|0)==($11|0);
 if ($12) {
  STACKTOP = sp;return;
 } else {
  $$sroa$03$07 = $9;
 }
 while(1) {
  $13 = HEAP32[$$sroa$03$07>>2]|0;
  $14 = ((($13)) + 12|0);
  (__ZN11OpenThreads6Thread20setProcessorAffinityERKNS_8AffinityE($14,$4)|0);
  $15 = ((($$sroa$03$07)) + 4|0);
  $16 = HEAP32[$10>>2]|0;
  $17 = ($15|0)==($16|0);
  if ($17) {
   break;
  } else {
   $$sroa$03$07 = $15;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5osgDB13DatabasePager17addDatabaseThreadENS0_14DatabaseThread4ModeERKNSt3__212basic_stringIcNS3_11char_traitsIcEENS3_9allocatorIcEEEE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$014 = 0, $$pre$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp + 8|0;
 $4 = sp + 4|0;
 $5 = sp;
 $6 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
 do {
  if ($6) {
   $7 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
   $8 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($7,163836,35)|0);
   $9 = ((($2)) + 11|0);
   $10 = HEAP8[$9>>0]|0;
   $11 = ($10<<24>>24)<(0);
   $12 = HEAP32[$2>>2]|0;
   $13 = $11 ? $12 : $2;
   $14 = ((($2)) + 4|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = $10&255;
   $17 = $11 ? $15 : $16;
   $18 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($8,$13,$17)|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ((($19)) + -12|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = (($18) + ($21)|0);
   __ZNKSt3__28ios_base6getlocEv($4,$22);
   __THREW__ = 0;
   $23 = (invoke_iii(3255,($4|0),(215188|0))|0);
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   if (!($25)) {
    $26 = HEAP32[$23>>2]|0;
    $27 = ((($26)) + 28|0);
    $28 = HEAP32[$27>>2]|0;
    __THREW__ = 0;
    $29 = (invoke_iii($28|0,($23|0),10)|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if (!($31)) {
     __ZNSt3__26localeD2Ev($4);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($18,$29)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($18)|0);
     break;
    }
   }
   $32 = ___cxa_find_matching_catch_2()|0;
   $33 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($4|0));
   $34 = __THREW__; __THREW__ = 0;
   $35 = $34&1;
   if ($35) {
    $36 = ___cxa_find_matching_catch_3(0|0)|0;
    $37 = tempRet0;
    ___clang_call_terminate($36);
    // unreachable;
   } else {
    ___resumeException($32|0);
    // unreachable;
   }
  }
 } while(0);
 $38 = ((($0)) + 56|0);
 $39 = ((($0)) + 60|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = HEAP32[$38>>2]|0;
 $42 = (($40) - ($41))|0;
 $43 = $42 >> 2;
 $44 = (__Znwj(48)|0);
 __THREW__ = 0;
 invoke_viiii(4137,($44|0),($0|0),($1|0),($2|0));
 $45 = __THREW__; __THREW__ = 0;
 $46 = $45&1;
 if ($46) {
  $93 = ___cxa_find_matching_catch_2()|0;
  $94 = tempRet0;
  __ZdlPv($44);
  $$0 = $94;$$014 = $93;
  ___resumeException($$014|0);
  // unreachable;
 }
 $47 = ((($44)) + 12|0);
 $48 = ((($0)) + 40|0);
 (__ZN11OpenThreads6Thread20setProcessorAffinityERKNS_8AffinityE($47,$48)|0);
 HEAP32[$5>>2] = $44;
 $49 = ((($44)) + 8|0);
 $50 = HEAP32[$49>>2]|0;HEAP32[$49>>2] = (($50+1)|0);
 $51 = HEAP32[$39>>2]|0;
 $52 = ((($0)) + 64|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = ($51|0)==($53|0);
 if ($54) {
  __THREW__ = 0;
  invoke_vii(4138,($38|0),($5|0));
  $61 = __THREW__; __THREW__ = 0;
  $62 = $61&1;
  if ($62) {
   $95 = ___cxa_find_matching_catch_2()|0;
   $96 = tempRet0;
   $97 = HEAP32[$5>>2]|0;
   $98 = ($97|0)==(0|0);
   if (!($98)) {
    $99 = ((($97)) + 8|0);
    $100 = HEAP32[$99>>2]|0;HEAP32[$99>>2] = (($100-1)|0);
    $101 = ($100|0)==(1);
    if ($101) {
     __THREW__ = 0;
     invoke_viii(3262,($97|0),1,1);
     $102 = __THREW__; __THREW__ = 0;
     $103 = $102&1;
     if ($103) {
      $104 = ___cxa_find_matching_catch_3(0|0)|0;
      $105 = tempRet0;
      ___clang_call_terminate($104);
      // unreachable;
     }
    }
   }
   $$0 = $96;$$014 = $95;
   ___resumeException($$014|0);
   // unreachable;
  }
 } else {
  $55 = HEAP32[$5>>2]|0;
  HEAP32[$51>>2] = $55;
  $56 = ($55|0)==(0|0);
  if ($56) {
   $60 = $51;
  } else {
   $57 = ((($55)) + 8|0);
   $58 = HEAP32[$57>>2]|0;HEAP32[$57>>2] = (($58+1)|0);
   $$pre$i = HEAP32[$39>>2]|0;
   $60 = $$pre$i;
  }
  $59 = ((($60)) + 4|0);
  HEAP32[$39>>2] = $59;
 }
 $63 = HEAP32[$5>>2]|0;
 $64 = ($63|0)==(0|0);
 if (!($64)) {
  $65 = ((($63)) + 8|0);
  $66 = HEAP32[$65>>2]|0;HEAP32[$65>>2] = (($66-1)|0);
  $67 = ($66|0)==(1);
  if ($67) {
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($63,1,1);
  }
 }
 $68 = ((($0)) + 36|0);
 $69 = HEAP8[$68>>0]|0;
 $70 = ($69<<24>>24)==(0);
 if ($70) {
  STACKTOP = sp;return ($43|0);
 }
 $71 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
 do {
  if ($71) {
   $72 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
   $73 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($72,163872,28)|0);
   $74 = HEAP32[$73>>2]|0;
   $75 = ((($74)) + -12|0);
   $76 = HEAP32[$75>>2]|0;
   $77 = (($73) + ($76)|0);
   __ZNKSt3__28ios_base6getlocEv($3,$77);
   __THREW__ = 0;
   $78 = (invoke_iii(3255,($3|0),(215188|0))|0);
   $79 = __THREW__; __THREW__ = 0;
   $80 = $79&1;
   if (!($80)) {
    $81 = HEAP32[$78>>2]|0;
    $82 = ((($81)) + 28|0);
    $83 = HEAP32[$82>>2]|0;
    __THREW__ = 0;
    $84 = (invoke_iii($83|0,($78|0),10)|0);
    $85 = __THREW__; __THREW__ = 0;
    $86 = $85&1;
    if (!($86)) {
     __ZNSt3__26localeD2Ev($3);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($73,$84)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($73)|0);
     break;
    }
   }
   $87 = ___cxa_find_matching_catch_2()|0;
   $88 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($3|0));
   $89 = __THREW__; __THREW__ = 0;
   $90 = $89&1;
   if ($90) {
    $91 = ___cxa_find_matching_catch_3(0|0)|0;
    $92 = tempRet0;
    ___clang_call_terminate($91);
    // unreachable;
   } else {
    ___resumeException($87|0);
    // unreachable;
   }
  }
 } while(0);
 (__ZN11OpenThreads6Thread11startThreadEv($47)|0);
 STACKTOP = sp;return ($43|0);
}
function __ZN5osgDB13DatabasePager16signalBeginFrameEPKN3osg10FrameStampE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 }
 $3 = ((($0)) + 96|0);
 $4 = HEAP32[$3>>2]|0;
 (__ZN5osgDB13DatabasePager12RequestQueue31pruneOldRequestsAndCheckIfEmptyEv($4)|0);
 $5 = ((($1)) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($0)) + 84|0);
 $8 = HEAP32[$7>>2]|0;HEAP32[$7>>2] = $6;
 return;
}
function __ZN5osgDB13DatabasePager14signalEndFrameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN5osgDB13DatabasePager17registerPagedLODsEPN3osg4NodeEj($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(96|0);
 $3 = sp;
 $4 = ($1|0)==(0|0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = ((($0)) + 120|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($3)) + 64|0);
 __ZN3osg10ReferencedC2Ev($7);
 HEAP32[$7>>2] = (63412);
 $8 = ((($3)) + 76|0);
 ;HEAP32[$8>>2]=0|0;HEAP32[$8+4>>2]=0|0;HEAP32[$8+8>>2]=0|0;
 $9 = ((($3)) + 88|0);
 HEAP32[$9>>2] = 2;
 $10 = ((($3)) + 92|0);
 HEAP32[$10>>2] = 0;
 __THREW__ = 0;
 invoke_viii(3283,($3|0),((73752)|0),2);
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if ($12) {
  $13 = ___cxa_find_matching_catch_2()|0;
  $14 = tempRet0;
  __THREW__ = 0;
  invoke_vi(388,($7|0));
  $15 = __THREW__; __THREW__ = 0;
  $16 = $15&1;
  if ($16) {
   $17 = ___cxa_find_matching_catch_3(0|0)|0;
   $18 = tempRet0;
   ___clang_call_terminate($17);
   // unreachable;
  } else {
   ___resumeException($13|0);
   // unreachable;
  }
 }
 HEAP32[$3>>2] = (73776);
 HEAP32[$7>>2] = (74120);
 $19 = ((($3)) + 56|0);
 HEAP32[$19>>2] = $6;
 $20 = ((($3)) + 60|0);
 HEAP32[$20>>2] = $2;
 $21 = HEAP32[$1>>2]|0;
 $22 = ((($21)) + 188|0);
 $23 = HEAP32[$22>>2]|0;
 __THREW__ = 0;
 invoke_vii($23|0,($1|0),($3|0));
 $24 = __THREW__; __THREW__ = 0;
 $25 = $24&1;
 if (!($25)) {
  __THREW__ = 0;
  invoke_vii(3284,($3|0),((73752)|0));
  $26 = __THREW__; __THREW__ = 0;
  $27 = $26&1;
  if (!($27)) {
   __ZN3osg6ObjectD2Ev($7);
   STACKTOP = sp;return;
  }
  $28 = ___cxa_find_matching_catch_2()|0;
  $29 = tempRet0;
  __THREW__ = 0;
  invoke_vi(388,($7|0));
  $30 = __THREW__; __THREW__ = 0;
  $31 = $30&1;
  if ($31) {
   $32 = ___cxa_find_matching_catch_3(0|0)|0;
   $33 = tempRet0;
   ___clang_call_terminate($32);
   // unreachable;
  } else {
   ___resumeException($28|0);
   // unreachable;
  }
 }
 $34 = ___cxa_find_matching_catch_2()|0;
 $35 = tempRet0;
 __THREW__ = 0;
 invoke_vii(3284,($3|0),((73752)|0));
 $36 = __THREW__; __THREW__ = 0;
 $37 = $36&1;
 if ($37) {
  $40 = ___cxa_find_matching_catch_3(0|0)|0;
  $41 = tempRet0;
  __THREW__ = 0;
  invoke_vi(388,($7|0));
  $42 = __THREW__; __THREW__ = 0;
  $43 = $42&1;
  if ($43) {
   $44 = ___cxa_find_matching_catch_3(0|0)|0;
   $45 = tempRet0;
   ___clang_call_terminate($44);
   // unreachable;
  } else {
   $eh$lpad$body$indexZ2D = $40;
   ___clang_call_terminate($eh$lpad$body$indexZ2D);
   // unreachable;
  }
 }
 __THREW__ = 0;
 invoke_vi(388,($7|0));
 $38 = __THREW__; __THREW__ = 0;
 $39 = $38&1;
 if (!($39)) {
  ___resumeException($34|0);
  // unreachable;
 }
 $46 = ___cxa_find_matching_catch_3(0|0)|0;
 $47 = tempRet0;
 $eh$lpad$body$indexZ2D = $46;
 ___clang_call_terminate($eh$lpad$body$indexZ2D);
 // unreachable;
}
function __ZN5osgDB13DatabasePager16updateSceneGraphERKN3osg10FrameStampE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $3 = ((($2)) + 60|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 8191]($0,$1);
 __ZN5osgDB13DatabasePager25addLoadedDataToSceneGraphERKN3osg10FrameStampE($0,$1);
 return;
}
function __ZN5osgDB13DatabasePager22removeExpiredSubgraphsERKN3osg10FrameStampE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$023$i$i = 0, $$023$i$i74 = 0, $$023$i$i89 = 0, $$5 = 0, $$572 = 0, $$sink$i$i = 0.0, $$sink$i$i80 = 0.0, $$sink$i$i91 = 0.0, $$sink$i$i97 = 0.0, $$sink73$index = 0, $$sink73$index3 = 0, $10 = 0, $100 = 0, $101 = 0.0, $102 = 0.0, $103 = 0.0, $104 = 0.0, $105 = 0.0, $106 = 0.0, $107 = 0.0;
 var $108 = 0.0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0;
 var $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0;
 var $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0;
 var $199 = 0, $2 = 0, $20 = 0, $200 = 0.0, $201 = 0, $202 = 0, $203 = 0.0, $204 = 0.0, $205 = 0, $206 = 0.0, $207 = 0.0, $208 = 0.0, $209 = 0.0, $21 = 0, $210 = 0.0, $211 = 0.0, $212 = 0.0, $213 = 0.0, $214 = 0, $215 = 0;
 var $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0;
 var $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0.0, $25 = 0, $250 = 0, $251 = 0;
 var $252 = 0.0, $253 = 0.0, $254 = 0, $255 = 0.0, $256 = 0.0, $257 = 0.0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0.0;
 var $270 = 0.0, $271 = 0.0, $272 = 0.0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0.0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0;
 var $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0.0, $293 = 0.0, $294 = 0.0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0.0, $300 = 0, $301 = 0.0, $302 = 0, $303 = 0, $304 = 0, $305 = 0;
 var $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0.0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0.0, $315 = 0.0, $316 = 0.0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0.0;
 var $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0.0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0.0, $340 = 0, $341 = 0;
 var $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0.0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0.0;
 var $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0.0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0;
 var $379 = 0, $38 = 0.0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0.0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0;
 var $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0.0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0.0, $5 = 0, $50 = 0.0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0.0, $96 = 0, $97 = 0, $98 = 0.0, $99 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp + 12|0;
 $3 = sp;
 $4 = ((($1)) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = (__ZN3osg5Timer8instanceEv()|0);
 $8 = (__ZNK3osg5Timer4tickEv($7)|0);
 $9 = tempRet0;
 $10 = ((($0)) + 120|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = HEAP32[$11>>2]|0;
 $13 = ((($12)) + 20|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (FUNCTION_TABLE_ii[$14 & 8191]($11)|0);
 $16 = (__ZN3osg5Timer8instanceEv()|0);
 $17 = (__ZNK3osg5Timer4tickEv($16)|0);
 $18 = tempRet0;
 $19 = (__ZN3osg5Timer8instanceEv()|0);
 $20 = ($18>>>0)>($9>>>0);
 $21 = ($17>>>0)>($8>>>0);
 $22 = ($18|0)==($9|0);
 $23 = $22 & $21;
 $24 = $20 | $23;
 if ($24) {
  $25 = (_i64Subtract(($17|0),($18|0),($8|0),($9|0))|0);
  $26 = tempRet0;
  $27 = (+($25>>>0)) + (4294967296.0*(+($26>>>0)));
  $$sink$i$i = $27;
 } else {
  $28 = (_i64Subtract(($8|0),($9|0),($17|0),($18|0))|0);
  $29 = tempRet0;
  $30 = (+($28>>>0)) + (4294967296.0*(+($29>>>0)));
  $31 = -$30;
  $$sink$i$i = $31;
 }
 $32 = ((($19)) + 8|0);
 $33 = +HEAPF64[$32>>3];
 $34 = $$sink$i$i * $33;
 $35 = $34 * 1000.0;
 $36 = +HEAPF64[25768];
 $37 = $36 + 1.0;
 HEAPF64[25768] = $37;
 $38 = +HEAPF64[25769];
 $39 = $35 + $38;
 HEAPF64[25769] = $39;
 $40 = +HEAPF64[25770];
 $41 = $40 < $35;
 if ($41) {
  HEAPF64[25770] = $35;
 }
 $42 = ((($0)) + 124|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = ($15>>>0)>($43>>>0);
 if (!($44)) {
  STACKTOP = sp;return;
 }
 $45 = (($15) - ($43))|0;
 HEAP32[$3>>2] = $3;
 $46 = ((($3)) + 4|0);
 HEAP32[$46>>2] = $3;
 $47 = ((($3)) + 8|0);
 HEAP32[$47>>2] = 0;
 $48 = ((($1)) + 16|0);
 $49 = +HEAPF64[$48>>3];
 $50 = $49 + -0.10000000000000001;
 $51 = HEAP32[$4>>2]|0;
 $52 = (($51) + -1)|0;
 $53 = ($45|0)>(0);
 if ($53) {
  $54 = HEAP32[$10>>2]|0;
  $55 = HEAP32[$54>>2]|0;
  $56 = ((($55)) + 24|0);
  $57 = HEAP32[$56>>2]|0;
  __THREW__ = 0;
  invoke_viidiii($57|0,($54|0),($45|0),(+$50),($52|0),($3|0),0);
  $58 = __THREW__; __THREW__ = 0;
  $59 = $58&1;
  if ($59) {
   label = 10;
  } else {
   label = 11;
  }
 } else {
  label = 11;
 }
 L16: do {
  if ((label|0) == 11) {
   $62 = HEAP32[$10>>2]|0;
   $63 = HEAP32[$62>>2]|0;
   $64 = ((($63)) + 20|0);
   $65 = HEAP32[$64>>2]|0;
   __THREW__ = 0;
   $66 = (invoke_ii($65|0,($62|0))|0);
   $67 = __THREW__; __THREW__ = 0;
   $68 = $67&1;
   if ($68) {
    label = 10;
   } else {
    $69 = HEAP32[$42>>2]|0;
    $70 = (($66) - ($69))|0;
    $71 = ($70|0)>(0);
    if ($71) {
     $72 = HEAP32[$10>>2]|0;
     $73 = HEAP32[$72>>2]|0;
     $74 = ((($73)) + 24|0);
     $75 = HEAP32[$74>>2]|0;
     __THREW__ = 0;
     invoke_viidiii($75|0,($72|0),($70|0),(+$50),($52|0),($3|0),1);
     $76 = __THREW__; __THREW__ = 0;
     $77 = $76&1;
     if ($77) {
      label = 10;
      break;
     }
    }
    __THREW__ = 0;
    $78 = (invoke_i(3384)|0);
    $79 = __THREW__; __THREW__ = 0;
    $80 = $79&1;
    if ($80) {
     label = 10;
    } else {
     __THREW__ = 0;
     $81 = (invoke_ii(3385,($78|0))|0);
     $82 = tempRet0;
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if ($84) {
      label = 10;
     } else {
      __THREW__ = 0;
      $85 = (invoke_i(3384)|0);
      $86 = __THREW__; __THREW__ = 0;
      $87 = $86&1;
      if ($87) {
       $110 = ___cxa_find_matching_catch_2()|0;
       $111 = tempRet0;
       $$5 = $110;$$572 = $111;
       break;
      }
      $88 = ($82>>>0)>($18>>>0);
      $89 = ($81>>>0)>($17>>>0);
      $90 = ($82|0)==($18|0);
      $91 = $90 & $89;
      $92 = $88 | $91;
      if ($92) {
       $93 = (_i64Subtract(($81|0),($82|0),($17|0),($18|0))|0);
       $94 = tempRet0;
       $95 = (+($93>>>0)) + (4294967296.0*(+($94>>>0)));
       $$sink$i$i80 = $95;
      } else {
       $96 = (_i64Subtract(($17|0),($18|0),($81|0),($82|0))|0);
       $97 = tempRet0;
       $98 = (+($96>>>0)) + (4294967296.0*(+($97>>>0)));
       $99 = -$98;
       $$sink$i$i80 = $99;
      }
      $100 = ((($85)) + 8|0);
      $101 = +HEAPF64[$100>>3];
      $102 = $$sink$i$i80 * $101;
      $103 = $102 * 1000.0;
      $104 = +HEAPF64[25771];
      $105 = $104 + 1.0;
      HEAPF64[25771] = $105;
      $106 = +HEAPF64[25772];
      $107 = $103 + $106;
      HEAPF64[25772] = $107;
      $108 = +HEAPF64[25773];
      $109 = $108 < $103;
      if ($109) {
       HEAPF64[25773] = $103;
      }
      $112 = HEAP32[$47>>2]|0;
      $113 = ($112|0)==(0);
      L34: do {
       if ($113) {
        label = 39;
       } else {
        $114 = ((($0)) + 116|0);
        $115 = HEAP8[$114>>0]|0;
        $116 = ($115<<24>>24)==(0);
        if ($116) {
         $162 = HEAP32[$46>>2]|0;
         $163 = HEAP32[$3>>2]|0;
         $164 = ((($163)) + 4|0);
         $165 = HEAP32[$164>>2]|0;
         $166 = HEAP32[$162>>2]|0;
         $167 = ((($166)) + 4|0);
         HEAP32[$167>>2] = $165;
         $168 = HEAP32[$164>>2]|0;
         HEAP32[$168>>2] = $166;
         HEAP32[$47>>2] = 0;
         $169 = ($162|0)==($3|0);
         if ($169) {
          label = 39;
          break;
         } else {
          $$023$i$i89 = $162;
         }
         L38: while(1) {
          $170 = ((($$023$i$i89)) + 4|0);
          $171 = HEAP32[$170>>2]|0;
          $172 = ((($$023$i$i89)) + 8|0);
          $173 = HEAP32[$172>>2]|0;
          $174 = ($173|0)==(0|0);
          do {
           if (!($174)) {
            $175 = ((($173)) + 8|0);
            $176 = HEAP32[$175>>2]|0;HEAP32[$175>>2] = (($176-1)|0);
            $177 = ($176|0)==(1);
            if (!($177)) {
             break;
            }
            __THREW__ = 0;
            invoke_viii(3262,($173|0),1,1);
            $178 = __THREW__; __THREW__ = 0;
            $179 = $178&1;
            if ($179) {
             break L38;
            }
           }
          } while(0);
          __ZdlPv($$023$i$i89);
          $180 = ($171|0)==($3|0);
          if ($180) {
           label = 39;
           break L34;
          } else {
           $$023$i$i89 = $171;
          }
         }
         $181 = ___cxa_find_matching_catch_2()|0;
         $182 = tempRet0;
         ___cxa_call_unexpected(($181|0));
         // unreachable;
        }
        $117 = ((($0)) + 88|0);
        $118 = HEAP32[$117>>2]|0;
        $119 = ((($118)) + 28|0);
        $120 = HEAP32[$119>>2]|0;
        $121 = ((($120)) + 8|0);
        $122 = HEAP32[$121>>2]|0;
        __THREW__ = 0;
        (invoke_ii($122|0,($119|0))|0);
        $123 = __THREW__; __THREW__ = 0;
        $124 = $123&1;
        if (!($124)) {
         $125 = HEAP32[$117>>2]|0;
         $126 = ((($125)) + 72|0);
         $127 = HEAP32[$47>>2]|0;
         $128 = ($127|0)==(0);
         if (!($128)) {
          $129 = HEAP32[$46>>2]|0;
          $130 = HEAP32[$3>>2]|0;
          $131 = ((($130)) + 4|0);
          $132 = HEAP32[$131>>2]|0;
          $133 = HEAP32[$129>>2]|0;
          $134 = ((($133)) + 4|0);
          HEAP32[$134>>2] = $132;
          $135 = HEAP32[$131>>2]|0;
          HEAP32[$135>>2] = $133;
          $136 = HEAP32[$126>>2]|0;
          $137 = ((($136)) + 4|0);
          HEAP32[$137>>2] = $129;
          HEAP32[$129>>2] = $136;
          HEAP32[$126>>2] = $130;
          HEAP32[$131>>2] = $126;
          $138 = ((($125)) + 80|0);
          $139 = HEAP32[$138>>2]|0;
          $140 = (($139) + ($127))|0;
          HEAP32[$138>>2] = $140;
          HEAP32[$47>>2] = 0;
         }
         $141 = HEAP32[$125>>2]|0;
         $142 = ((($141)) + 12|0);
         $143 = HEAP32[$142>>2]|0;
         __THREW__ = 0;
         invoke_vi($143|0,($125|0));
         $144 = __THREW__; __THREW__ = 0;
         $145 = $144&1;
         if ($145) {
          $155 = ___cxa_find_matching_catch_2()|0;
          $156 = tempRet0;
          $157 = HEAP32[$119>>2]|0;
          $158 = ((($157)) + 12|0);
          $159 = HEAP32[$158>>2]|0;
          __THREW__ = 0;
          (invoke_ii($159|0,($119|0))|0);
          $160 = __THREW__; __THREW__ = 0;
          $161 = $160&1;
          if (!($161)) {
           $$5 = $155;$$572 = $156;
           break L16;
          }
          $402 = ___cxa_find_matching_catch_3(0|0)|0;
          $403 = tempRet0;
          ___clang_call_terminate($402);
          // unreachable;
         } else {
          $146 = HEAP32[$119>>2]|0;
          $147 = ((($146)) + 12|0);
          $148 = HEAP32[$147>>2]|0;
          __THREW__ = 0;
          (invoke_ii($148|0,($119|0))|0);
          $149 = __THREW__; __THREW__ = 0;
          $150 = $149&1;
          if (!($150)) {
           label = 39;
           break;
          }
          $153 = ___cxa_find_matching_catch_2()|0;
          $154 = tempRet0;
          $$5 = $153;$$572 = $154;
          break L16;
         }
        }
       }
      } while(0);
      if ((label|0) == 39) {
       __THREW__ = 0;
       $183 = (invoke_i(3384)|0);
       $184 = __THREW__; __THREW__ = 0;
       $185 = $184&1;
       if (!($185)) {
        __THREW__ = 0;
        $186 = (invoke_ii(3385,($183|0))|0);
        $187 = tempRet0;
        $188 = __THREW__; __THREW__ = 0;
        $189 = $188&1;
        if (!($189)) {
         __THREW__ = 0;
         $190 = (invoke_i(3384)|0);
         $191 = __THREW__; __THREW__ = 0;
         $192 = $191&1;
         L59: do {
          if ($192) {
           $215 = ___cxa_find_matching_catch_2()|0;
           $216 = tempRet0;
           $$sink73$index = $215;$$sink73$index3 = $216;
          } else {
           $193 = ($187>>>0)>($82>>>0);
           $194 = ($186>>>0)>($81>>>0);
           $195 = ($187|0)==($82|0);
           $196 = $195 & $194;
           $197 = $193 | $196;
           if ($197) {
            $198 = (_i64Subtract(($186|0),($187|0),($81|0),($82|0))|0);
            $199 = tempRet0;
            $200 = (+($198>>>0)) + (4294967296.0*(+($199>>>0)));
            $$sink$i$i91 = $200;
           } else {
            $201 = (_i64Subtract(($81|0),($82|0),($186|0),($187|0))|0);
            $202 = tempRet0;
            $203 = (+($201>>>0)) + (4294967296.0*(+($202>>>0)));
            $204 = -$203;
            $$sink$i$i91 = $204;
           }
           $205 = ((($190)) + 8|0);
           $206 = +HEAPF64[$205>>3];
           $207 = $$sink$i$i91 * $206;
           $208 = $207 * 1000.0;
           $209 = +HEAPF64[25774];
           $210 = $209 + 1.0;
           HEAPF64[25774] = $210;
           $211 = +HEAPF64[25775];
           $212 = $208 + $211;
           HEAPF64[25775] = $212;
           $213 = +HEAPF64[25776];
           $214 = $213 < $208;
           if ($214) {
            HEAPF64[25776] = $208;
           }
           __THREW__ = 0;
           $217 = (invoke_ii(3265,4)|0);
           $218 = __THREW__; __THREW__ = 0;
           $219 = $218&1;
           L69: do {
            if (!($219)) {
             L71: do {
              if ($217) {
               __THREW__ = 0;
               $220 = (invoke_ii(3266,4)|0);
               $221 = __THREW__; __THREW__ = 0;
               $222 = $221&1;
               if ($222) {
                break L69;
               }
               __THREW__ = 0;
               $223 = (invoke_iiii(3267,($220|0),(163489|0),7)|0);
               $224 = __THREW__; __THREW__ = 0;
               $225 = $224&1;
               if ($225) {
                break L69;
               }
               $226 = HEAP32[$10>>2]|0;
               $227 = HEAP32[$226>>2]|0;
               $228 = ((($227)) + 20|0);
               $229 = HEAP32[$228>>2]|0;
               __THREW__ = 0;
               $230 = (invoke_ii($229|0,($226|0))|0);
               $231 = __THREW__; __THREW__ = 0;
               $232 = $231&1;
               if ($232) {
                break L69;
               }
               __THREW__ = 0;
               $233 = (invoke_iii(3417,($223|0),($230|0))|0);
               $234 = __THREW__; __THREW__ = 0;
               $235 = $234&1;
               if ($235) {
                break L69;
               }
               __THREW__ = 0;
               $236 = (invoke_iiii(3267,($233|0),(163497|0),11)|0);
               $237 = __THREW__; __THREW__ = 0;
               $238 = $237&1;
               if ($238) {
                break L69;
               }
               __THREW__ = 0;
               $239 = (invoke_i(3384)|0);
               $240 = __THREW__; __THREW__ = 0;
               $241 = $240&1;
               if ($241) {
                break L69;
               }
               $242 = ($187>>>0)>($9>>>0);
               $243 = ($186>>>0)>($8>>>0);
               $244 = ($187|0)==($9|0);
               $245 = $244 & $243;
               $246 = $242 | $245;
               if ($246) {
                $247 = (_i64Subtract(($186|0),($187|0),($8|0),($9|0))|0);
                $248 = tempRet0;
                $249 = (+($247>>>0)) + (4294967296.0*(+($248>>>0)));
                $$sink$i$i97 = $249;
               } else {
                $250 = (_i64Subtract(($8|0),($9|0),($186|0),($187|0))|0);
                $251 = tempRet0;
                $252 = (+($250>>>0)) + (4294967296.0*(+($251>>>0)));
                $253 = -$252;
                $$sink$i$i97 = $253;
               }
               $254 = ((($239)) + 8|0);
               $255 = +HEAPF64[$254>>3];
               $256 = $$sink$i$i97 * $255;
               $257 = $256 * 1000.0;
               __THREW__ = 0;
               $258 = (invoke_iid(3519,($236|0),(+$257))|0);
               $259 = __THREW__; __THREW__ = 0;
               $260 = $259&1;
               if ($260) {
                break L69;
               }
               __THREW__ = 0;
               $261 = (invoke_iiii(3267,($258|0),(163509|0),3)|0);
               $262 = __THREW__; __THREW__ = 0;
               $263 = $262&1;
               if ($263) {
                break L69;
               }
               __THREW__ = 0;
               $264 = (invoke_iid(3519,($261|0),(+$35))|0);
               $265 = __THREW__; __THREW__ = 0;
               $266 = $265&1;
               if ($266) {
                break L69;
               }
               __THREW__ = 0;
               $267 = (invoke_iiii(3267,($264|0),(163513|0),5)|0);
               $268 = __THREW__; __THREW__ = 0;
               $269 = $268&1;
               if ($269) {
                break L69;
               }
               $270 = +HEAPF64[25769];
               $271 = +HEAPF64[25768];
               $272 = $270 / $271;
               __THREW__ = 0;
               $273 = (invoke_iid(3519,($267|0),(+$272))|0);
               $274 = __THREW__; __THREW__ = 0;
               $275 = $274&1;
               if ($275) {
                break L69;
               }
               __THREW__ = 0;
               $276 = (invoke_iiii(3267,($273|0),(163519|0),7)|0);
               $277 = __THREW__; __THREW__ = 0;
               $278 = $277&1;
               if ($278) {
                break L69;
               }
               $279 = +HEAPF64[25770];
               __THREW__ = 0;
               $280 = (invoke_iid(3519,($276|0),(+$279))|0);
               $281 = __THREW__; __THREW__ = 0;
               $282 = $281&1;
               if ($282) {
                break L69;
               }
               __THREW__ = 0;
               $283 = (invoke_iiii(3267,($280|0),(163527|0),3)|0);
               $284 = __THREW__; __THREW__ = 0;
               $285 = $284&1;
               if ($285) {
                break L69;
               }
               __THREW__ = 0;
               $286 = (invoke_iid(3519,($283|0),(+$103))|0);
               $287 = __THREW__; __THREW__ = 0;
               $288 = $287&1;
               if ($288) {
                break L69;
               }
               __THREW__ = 0;
               $289 = (invoke_iiii(3267,($286|0),(163513|0),5)|0);
               $290 = __THREW__; __THREW__ = 0;
               $291 = $290&1;
               if ($291) {
                break L69;
               }
               $292 = +HEAPF64[25772];
               $293 = +HEAPF64[25771];
               $294 = $292 / $293;
               __THREW__ = 0;
               $295 = (invoke_iid(3519,($289|0),(+$294))|0);
               $296 = __THREW__; __THREW__ = 0;
               $297 = $296&1;
               if ($297) {
                break L69;
               }
               __THREW__ = 0;
               $298 = (invoke_iiii(3267,($295|0),(163519|0),7)|0);
               $299 = __THREW__; __THREW__ = 0;
               $300 = $299&1;
               if ($300) {
                break L69;
               }
               $301 = +HEAPF64[25773];
               __THREW__ = 0;
               $302 = (invoke_iid(3519,($298|0),(+$301))|0);
               $303 = __THREW__; __THREW__ = 0;
               $304 = $303&1;
               if ($304) {
                break L69;
               }
               __THREW__ = 0;
               $305 = (invoke_iiii(3267,($302|0),(163531|0),3)|0);
               $306 = __THREW__; __THREW__ = 0;
               $307 = $306&1;
               if ($307) {
                break L69;
               }
               __THREW__ = 0;
               $308 = (invoke_iid(3519,($305|0),(+$208))|0);
               $309 = __THREW__; __THREW__ = 0;
               $310 = $309&1;
               if ($310) {
                break L69;
               }
               __THREW__ = 0;
               $311 = (invoke_iiii(3267,($308|0),(163513|0),5)|0);
               $312 = __THREW__; __THREW__ = 0;
               $313 = $312&1;
               if ($313) {
                break L69;
               }
               $314 = +HEAPF64[25775];
               $315 = +HEAPF64[25774];
               $316 = $314 / $315;
               __THREW__ = 0;
               $317 = (invoke_iid(3519,($311|0),(+$316))|0);
               $318 = __THREW__; __THREW__ = 0;
               $319 = $318&1;
               if ($319) {
                break L69;
               }
               __THREW__ = 0;
               $320 = (invoke_iiii(3267,($317|0),(163519|0),7)|0);
               $321 = __THREW__; __THREW__ = 0;
               $322 = $321&1;
               if ($322) {
                break L69;
               }
               $323 = +HEAPF64[25776];
               __THREW__ = 0;
               $324 = (invoke_iid(3519,($320|0),(+$323))|0);
               $325 = __THREW__; __THREW__ = 0;
               $326 = $325&1;
               if ($326) {
                break L69;
               }
               $327 = HEAP32[$324>>2]|0;
               $328 = ((($327)) + -12|0);
               $329 = HEAP32[$328>>2]|0;
               $330 = (($324) + ($329)|0);
               __THREW__ = 0;
               invoke_vii(3257,($2|0),($330|0));
               $331 = __THREW__; __THREW__ = 0;
               $332 = $331&1;
               if ($332) {
                break L69;
               }
               __THREW__ = 0;
               $333 = (invoke_iii(3255,($2|0),(215188|0))|0);
               $334 = __THREW__; __THREW__ = 0;
               $335 = $334&1;
               do {
                if (!($335)) {
                 $336 = HEAP32[$333>>2]|0;
                 $337 = ((($336)) + 28|0);
                 $338 = HEAP32[$337>>2]|0;
                 __THREW__ = 0;
                 $339 = (invoke_iii($338|0,($333|0),10)|0);
                 $340 = __THREW__; __THREW__ = 0;
                 $341 = $340&1;
                 if ($341) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3263,($2|0));
                 $348 = __THREW__; __THREW__ = 0;
                 $349 = $348&1;
                 if ($349) {
                  break L69;
                 }
                 __THREW__ = 0;
                 (invoke_iii(3268,($324|0),($339|0))|0);
                 $350 = __THREW__; __THREW__ = 0;
                 $351 = $350&1;
                 if ($351) {
                  break L69;
                 }
                 __THREW__ = 0;
                 (invoke_ii(3269,($324|0))|0);
                 $352 = __THREW__; __THREW__ = 0;
                 $353 = $352&1;
                 if ($353) {
                  break L69;
                 } else {
                  break L71;
                 }
                }
               } while(0);
               $342 = ___cxa_find_matching_catch_2()|0;
               $343 = tempRet0;
               __THREW__ = 0;
               invoke_vi(3263,($2|0));
               $344 = __THREW__; __THREW__ = 0;
               $345 = $344&1;
               if ($345) {
                $346 = ___cxa_find_matching_catch_3(0|0)|0;
                $347 = tempRet0;
                ___clang_call_terminate($346);
                // unreachable;
               } else {
                $$sink73$index = $342;$$sink73$index3 = $343;
                break L59;
               }
              }
             } while(0);
             $356 = HEAP32[$47>>2]|0;
             $357 = ($356|0)==(0);
             L113: do {
              if (!($357)) {
               $358 = HEAP32[$46>>2]|0;
               $359 = HEAP32[$3>>2]|0;
               $360 = ((($359)) + 4|0);
               $361 = HEAP32[$360>>2]|0;
               $362 = HEAP32[$358>>2]|0;
               $363 = ((($362)) + 4|0);
               HEAP32[$363>>2] = $361;
               $364 = HEAP32[$360>>2]|0;
               HEAP32[$364>>2] = $362;
               HEAP32[$47>>2] = 0;
               $365 = ($358|0)==($3|0);
               if ($365) {
                break;
               } else {
                $$023$i$i74 = $358;
               }
               L115: while(1) {
                $366 = ((($$023$i$i74)) + 4|0);
                $367 = HEAP32[$366>>2]|0;
                $368 = ((($$023$i$i74)) + 8|0);
                $369 = HEAP32[$368>>2]|0;
                $370 = ($369|0)==(0|0);
                do {
                 if (!($370)) {
                  $371 = ((($369)) + 8|0);
                  $372 = HEAP32[$371>>2]|0;HEAP32[$371>>2] = (($372-1)|0);
                  $373 = ($372|0)==(1);
                  if (!($373)) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_viii(3262,($369|0),1,1);
                  $374 = __THREW__; __THREW__ = 0;
                  $375 = $374&1;
                  if ($375) {
                   break L115;
                  }
                 }
                } while(0);
                __ZdlPv($$023$i$i74);
                $376 = ($367|0)==($3|0);
                if ($376) {
                 break L113;
                } else {
                 $$023$i$i74 = $367;
                }
               }
               $377 = ___cxa_find_matching_catch_2()|0;
               $378 = tempRet0;
               ___cxa_call_unexpected(($377|0));
               // unreachable;
              }
             } while(0);
             STACKTOP = sp;return;
            }
           } while(0);
           $354 = ___cxa_find_matching_catch_2()|0;
           $355 = tempRet0;
           $$sink73$index = $354;$$sink73$index3 = $355;
          }
         } while(0);
         $$5 = $$sink73$index;$$572 = $$sink73$index3;
         break;
        }
       }
      }
      $151 = ___cxa_find_matching_catch_2()|0;
      $152 = tempRet0;
      $$5 = $151;$$572 = $152;
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 10) {
  $60 = ___cxa_find_matching_catch_2()|0;
  $61 = tempRet0;
  $$5 = $60;$$572 = $61;
 }
 $379 = HEAP32[$47>>2]|0;
 $380 = ($379|0)==(0);
 if ($380) {
  ___resumeException($$5|0);
  // unreachable;
 }
 $381 = HEAP32[$46>>2]|0;
 $382 = HEAP32[$3>>2]|0;
 $383 = ((($382)) + 4|0);
 $384 = HEAP32[$383>>2]|0;
 $385 = HEAP32[$381>>2]|0;
 $386 = ((($385)) + 4|0);
 HEAP32[$386>>2] = $384;
 $387 = HEAP32[$383>>2]|0;
 HEAP32[$387>>2] = $385;
 HEAP32[$47>>2] = 0;
 $388 = ($381|0)==($3|0);
 if ($388) {
  ___resumeException($$5|0);
  // unreachable;
 } else {
  $$023$i$i = $381;
 }
 while(1) {
  $389 = ((($$023$i$i)) + 4|0);
  $390 = HEAP32[$389>>2]|0;
  $391 = ((($$023$i$i)) + 8|0);
  $392 = HEAP32[$391>>2]|0;
  $393 = ($392|0)==(0|0);
  if (!($393)) {
   $394 = ((($392)) + 8|0);
   $395 = HEAP32[$394>>2]|0;HEAP32[$394>>2] = (($395-1)|0);
   $396 = ($395|0)==(1);
   if ($396) {
    __THREW__ = 0;
    invoke_viii(3262,($392|0),1,1);
    $397 = __THREW__; __THREW__ = 0;
    $398 = $397&1;
    if ($398) {
     label = 104;
     break;
    }
   }
  }
  __ZdlPv($$023$i$i);
  $399 = ($390|0)==($3|0);
  if ($399) {
   label = 105;
   break;
  } else {
   $$023$i$i = $390;
  }
 }
 if ((label|0) == 104) {
  $400 = ___cxa_find_matching_catch_2()|0;
  $401 = tempRet0;
  ___cxa_call_unexpected(($400|0));
  // unreachable;
 }
 else if ((label|0) == 105) {
  ___resumeException($$5|0);
  // unreachable;
 }
}
function __ZN5osgDB13DatabasePager25addLoadedDataToSceneGraphERKN3osg10FrameStampE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$$i = 0, $$0$ph = 0, $$023$i$i = 0, $$023$i$i80 = 0, $$073$ph = 0, $$2 = 0, $$275 = 0, $$3 = 0, $$376 = 0, $$5 = 0, $$578 = 0, $$pr = 0, $$pr$i = 0, $$pr6$i = 0, $$sink$i$i = 0.0, $$sink$i$i127 = 0.0, $$sink1$i$i$i = 0, $$sink2$i$i$i = 0, $$sroa$0135$0 = 0, $$sroa$0135$0166 = 0;
 var $$sroa$0135$0167 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0;
 var $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0;
 var $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0;
 var $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0;
 var $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0;
 var $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0;
 var $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0;
 var $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0;
 var $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0;
 var $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0.0, $267 = 0.0, $268 = 0.0, $269 = 0, $27 = 0, $270 = 0.0, $271 = 0, $272 = 0.0, $273 = 0.0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0;
 var $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0;
 var $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0;
 var $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0;
 var $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0;
 var $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0.0, $366 = 0, $367 = 0, $368 = 0.0, $369 = 0.0;
 var $37 = 0, $370 = 0, $371 = 0.0, $372 = 0.0, $373 = 0.0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0;
 var $388 = 0, $389 = 0, $39 = 0, $390 = 0.0, $391 = 0, $392 = 0, $393 = 0.0, $394 = 0.0, $395 = 0, $396 = 0.0, $397 = 0.0, $398 = 0.0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0;
 var $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0;
 var $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0;
 var $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0;
 var $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0;
 var $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0;
 var $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0;
 var $513 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0.0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index3Z2D = 0, $eh$lpad$body$indexZ2D = 0, $eh$lpad$body104$index14Z2D = 0, $eh$lpad$body104$indexZ2D = 0, $eh$lpad$body114$index9Z2D = 0, $eh$lpad$body114$indexZ2D = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $2 = sp + 36|0;
 $3 = sp + 32|0;
 $4 = sp + 28|0;
 $5 = sp;
 $6 = sp + 24|0;
 $7 = sp + 16|0;
 $8 = ((($1)) + 16|0);
 $9 = +HEAPF64[$8>>3];
 $10 = ((($1)) + 12|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (__ZN3osg5Timer8instanceEv()|0);
 $13 = (__ZNK3osg5Timer4tickEv($12)|0);
 $14 = tempRet0;
 HEAP32[$5>>2] = $5;
 $15 = ((($5)) + 4|0);
 HEAP32[$15>>2] = $5;
 $16 = ((($5)) + 8|0);
 HEAP32[$16>>2] = 0;
 $17 = ((($0)) + 100|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ((($18)) + 28|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ((($20)) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 __THREW__ = 0;
 (invoke_ii($22|0,($19|0))|0);
 $23 = __THREW__; __THREW__ = 0;
 $24 = $23&1;
 L1: do {
  if ($24) {
   label = 14;
  } else {
   $25 = ((($18)) + 16|0);
   $26 = ((($18)) + 24|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = HEAP32[$16>>2]|0;
   HEAP32[$26>>2] = $28;
   HEAP32[$16>>2] = $27;
   $29 = $25;
   $30 = $29;
   $31 = HEAP32[$30>>2]|0;
   $32 = (($29) + 4)|0;
   $33 = $32;
   $34 = HEAP32[$33>>2]|0;
   $35 = $5;
   $36 = $35;
   $37 = HEAP32[$36>>2]|0;
   $38 = (($35) + 4)|0;
   $39 = $38;
   $40 = HEAP32[$39>>2]|0;
   $41 = $25;
   $42 = $41;
   HEAP32[$42>>2] = $37;
   $43 = (($41) + 4)|0;
   $44 = $43;
   HEAP32[$44>>2] = $40;
   $45 = $5;
   $46 = $45;
   HEAP32[$46>>2] = $31;
   $47 = (($45) + 4)|0;
   $48 = $47;
   HEAP32[$48>>2] = $34;
   $49 = ($28|0)==(0);
   if ($49) {
    HEAP32[$25>>2] = $25;
    $$sink1$i$i$i = $25;
   } else {
    $50 = $40;
    HEAP32[$50>>2] = $25;
    $51 = HEAP32[$25>>2]|0;
    $$sink1$i$i$i = $51;
   }
   $52 = ((($$sink1$i$i$i)) + 4|0);
   HEAP32[$52>>2] = $25;
   $53 = ($27|0)==(0);
   if ($53) {
    HEAP32[$5>>2] = $5;
    $$sink2$i$i$i = $5;
   } else {
    $54 = HEAP32[$15>>2]|0;
    HEAP32[$54>>2] = $5;
    $55 = HEAP32[$5>>2]|0;
    $$sink2$i$i$i = $55;
   }
   $56 = ((($$sink2$i$i$i)) + 4|0);
   HEAP32[$56>>2] = $5;
   $57 = HEAP32[$19>>2]|0;
   $58 = ((($57)) + 12|0);
   $59 = HEAP32[$58>>2]|0;
   __THREW__ = 0;
   (invoke_ii($59|0,($19|0))|0);
   $60 = __THREW__; __THREW__ = 0;
   $61 = $60&1;
   if ($61) {
    label = 14;
   } else {
    __THREW__ = 0;
    $62 = (invoke_i(3384)|0);
    $63 = __THREW__; __THREW__ = 0;
    $64 = $63&1;
    if ($64) {
     label = 14;
    } else {
     __THREW__ = 0;
     $65 = (invoke_ii(3385,($62|0))|0);
     $66 = tempRet0;
     $67 = __THREW__; __THREW__ = 0;
     $68 = $67&1;
     if ($68) {
      label = 14;
     } else {
      $$sroa$0135$0166 = HEAP32[$15>>2]|0;
      $69 = $$sroa$0135$0166;
      $70 = ($69|0)==($5|0);
      L14: do {
       if (!($70)) {
        $71 = ((($0)) + 120|0);
        $72 = ((($7)) + 4|0);
        $73 = ((($0)) + 136|0);
        $74 = ((($0)) + 144|0);
        $75 = ((($0)) + 152|0);
        $76 = ((($0)) + 160|0);
        $$sroa$0135$0167 = $$sroa$0135$0166;$328 = $69;
        L16: while(1) {
         $82 = $$sroa$0135$0167;
         $83 = ((($82)) + 8|0);
         $84 = HEAP32[$83>>2]|0;
         HEAP32[$6>>2] = 0;
         $85 = ((($84)) + 100|0);
         $86 = HEAP8[$85>>0]|0;
         $87 = ($86<<24>>24)==(0);
         if ($87) {
          $88 = ((($84)) + 72|0);
          __THREW__ = 0;
          $89 = (invoke_iii(3561,($88|0),($6|0))|0);
          $90 = __THREW__; __THREW__ = 0;
          $91 = $90&1;
          if ($91) {
           label = 23;
           break;
          }
          if ($89) {
           __THREW__ = 0;
           $92 = (invoke_ii(3482,0)|0);
           $93 = __THREW__; __THREW__ = 0;
           $94 = $93&1;
           if ($94) {
            label = 23;
            break;
           }
           $95 = ((($92)) + 236|0);
           $96 = HEAP32[$95>>2]|0;
           $97 = ($96|0)==(0|0);
           if (!($97)) {
            __THREW__ = 0;
            $98 = (invoke_ii(3482,0)|0);
            $99 = __THREW__; __THREW__ = 0;
            $100 = $99&1;
            if ($100) {
             label = 23;
             break;
            }
            $101 = ((($98)) + 236|0);
            $102 = HEAP32[$101>>2]|0;
            $103 = ((($84)) + 80|0);
            $104 = HEAP32[$103>>2]|0;
            __THREW__ = 0;
            invoke_viii(4139,($102|0),($104|0),(0|0));
            $105 = __THREW__; __THREW__ = 0;
            $106 = $105&1;
            if ($106) {
             label = 23;
             break;
            }
           }
           $109 = HEAP32[$6>>2]|0;
           $110 = ($109|0)==(0|0);
           do {
            if ($110) {
             $186 = 0;$513 = 0;
            } else {
             $111 = (___dynamic_cast($109,25304,26216,0)|0);
             $112 = ($111|0)==(0|0);
             if ($112) {
              $151 = (___dynamic_cast($109,25304,26472,0)|0);
              $152 = ($151|0)==(0|0);
              if ($152) {
               $186 = 0;$513 = 0;
               break;
              }
              $153 = HEAP32[$151>>2]|0;
              $154 = ((($153)) + 224|0);
              $155 = HEAP32[$154>>2]|0;
              __THREW__ = 0;
              $156 = (invoke_ii($155|0,($151|0))|0);
              $157 = __THREW__; __THREW__ = 0;
              $158 = $157&1;
              if ($158) {
               label = 41;
               break L16;
              }
              $159 = ((($151)) + 136|0);
              $160 = HEAP32[$159>>2]|0;
              $161 = (((($160) + ($156<<4)|0)) + 12|0);
              $162 = HEAP32[$161>>2]|0;
              $163 = ($162|0)==(0|0);
              if ($163) {
               $186 = 0;$513 = 0;
               break;
              }
              HEAP32[$161>>2] = 0;
              $164 = ((($162)) + 8|0);
              $165 = HEAP32[$164>>2]|0;HEAP32[$164>>2] = (($165-1)|0);
              $166 = ($165|0)==(1);
              if (!($166)) {
               $186 = 0;$513 = 0;
               break;
              }
              __THREW__ = 0;
              invoke_viii(3262,($162|0),1,1);
              $167 = __THREW__; __THREW__ = 0;
              $168 = $167&1;
              if ($168) {
               label = 41;
               break L16;
              } else {
               $186 = 0;$513 = 0;
               break;
              }
             }
             $113 = HEAP32[$111>>2]|0;
             $114 = ((($113)) + 224|0);
             $115 = HEAP32[$114>>2]|0;
             __THREW__ = 0;
             $116 = (invoke_ii($115|0,($111|0))|0);
             $117 = __THREW__; __THREW__ = 0;
             $118 = $117&1;
             if ($118) {
              label = 35;
              break L16;
             }
             __THREW__ = 0;
             invoke_vii(4140,($111|0),($116|0));
             $119 = __THREW__; __THREW__ = 0;
             $120 = $119&1;
             if ($120) {
              label = 35;
              break L16;
             }
             $121 = ((($111)) + 200|0);
             $122 = HEAP32[$121>>2]|0;
             $123 = (((($122) + ($116<<6)|0)) + 40|0);
             HEAPF64[$123>>3] = $9;
             $124 = HEAP32[$111>>2]|0;
             $125 = ((($124)) + 224|0);
             $126 = HEAP32[$125>>2]|0;
             __THREW__ = 0;
             $127 = (invoke_ii($126|0,($111|0))|0);
             $128 = __THREW__; __THREW__ = 0;
             $129 = $128&1;
             if ($129) {
              label = 35;
              break L16;
             }
             __THREW__ = 0;
             invoke_vii(4140,($111|0),($127|0));
             $130 = __THREW__; __THREW__ = 0;
             $131 = $130&1;
             if ($131) {
              label = 35;
              break L16;
             }
             $132 = HEAP32[$121>>2]|0;
             $133 = (((($132) + ($127<<6)|0)) + 48|0);
             HEAP32[$133>>2] = $11;
             $134 = HEAP32[$111>>2]|0;
             $135 = ((($134)) + 224|0);
             $136 = HEAP32[$135>>2]|0;
             __THREW__ = 0;
             $137 = (invoke_ii($136|0,($111|0))|0);
             $138 = __THREW__; __THREW__ = 0;
             $139 = $138&1;
             if ($139) {
              label = 35;
              break L16;
             }
             $140 = HEAP32[$121>>2]|0;
             $141 = (((($140) + ($137<<6)|0)) + 56|0);
             $142 = HEAP32[$141>>2]|0;
             $143 = ($142|0)==(0|0);
             if ($143) {
              $186 = $111;$513 = 1;
              break;
             }
             HEAP32[$141>>2] = 0;
             $144 = ((($142)) + 8|0);
             $145 = HEAP32[$144>>2]|0;HEAP32[$144>>2] = (($145-1)|0);
             $146 = ($145|0)==(1);
             if (!($146)) {
              $186 = $111;$513 = 1;
              break;
             }
             __THREW__ = 0;
             invoke_viii(3262,($142|0),1,1);
             $147 = __THREW__; __THREW__ = 0;
             $148 = $147&1;
             if ($148) {
              label = 35;
              break L16;
             } else {
              $186 = $111;$513 = 1;
             }
            }
           } while(0);
           $171 = HEAP32[$6>>2]|0;
           $172 = HEAP32[$171>>2]|0;
           $173 = ((($172)) + 204|0);
           $174 = HEAP32[$173>>2]|0;
           $175 = ((($84)) + 80|0);
           $176 = HEAP32[$175>>2]|0;
           __THREW__ = 0;
           (invoke_iii($174|0,($171|0),($176|0))|0);
           $177 = __THREW__; __THREW__ = 0;
           $178 = $177&1;
           if ($178) {
            label = 35;
            break;
           }
           do {
            if ($513) {
             $182 = HEAP32[$71>>2]|0;
             $183 = HEAP32[$182>>2]|0;
             $184 = ((($183)) + 36|0);
             $185 = HEAP32[$184>>2]|0;
             HEAP32[$7>>2] = 0;
             $187 = ($186|0)==(0|0);
             do {
              if ($187) {
               label = 53;
              } else {
               __THREW__ = 0;
               $188 = (invoke_ii(3325,($186|0))|0);
               $189 = __THREW__; __THREW__ = 0;
               $190 = $189&1;
               if ($190) {
                label = 56;
                break L16;
               }
               $$pr$i = HEAP32[$7>>2]|0;
               $191 = ($$pr$i|0)==($188|0);
               if ($191) {
                $201 = $188;
                break;
               }
               HEAP32[$7>>2] = $188;
               $192 = ($188|0)==(0|0);
               if (!($192)) {
                $193 = ((($188)) + 8|0);
                $194 = HEAP32[$193>>2]|0;HEAP32[$193>>2] = (($194+1)|0);
               }
               $195 = ($$pr$i|0)==(0|0);
               if ($195) {
                label = 53;
                break;
               }
               $196 = ((($$pr$i)) + 8|0);
               $197 = HEAP32[$196>>2]|0;HEAP32[$196>>2] = (($197-1)|0);
               $198 = ($197|0)==(1);
               if (!($198)) {
                label = 53;
                break;
               }
               __THREW__ = 0;
               invoke_viii(3262,($$pr$i|0),1,1);
               $199 = __THREW__; __THREW__ = 0;
               $200 = $199&1;
               if ($200) {
                label = 56;
                break L16;
               } else {
                label = 53;
               }
              }
             } while(0);
             if ((label|0) == 53) {
              label = 0;
              $$pr6$i = HEAP32[$7>>2]|0;
              $201 = $$pr6$i;
             }
             $202 = ($201|0)==(0|0);
             if ($202) {
              $217 = 0;
             } else {
              $203 = ((($201)) + 24|0);
              $204 = HEAP32[$203>>2]|0;
              $205 = ($204|0)!=(0|0);
              $$$i = $205 ? $186 : 0;
              $217 = $$$i;
             }
             HEAP32[$72>>2] = $217;
             __THREW__ = 0;
             $218 = (invoke_iii($185|0,($182|0),($7|0))|0);
             $219 = __THREW__; __THREW__ = 0;
             $220 = $219&1;
             if ($220) {
              label = 69;
              break L16;
             }
             $221 = HEAP32[$7>>2]|0;
             $222 = ($221|0)==(0|0);
             do {
              if (!($222)) {
               $223 = ((($221)) + 8|0);
               $224 = HEAP32[$223>>2]|0;HEAP32[$223>>2] = (($224-1)|0);
               $225 = ($224|0)==(1);
               if (!($225)) {
                break;
               }
               __THREW__ = 0;
               invoke_viii(3262,($221|0),1,1);
               $226 = __THREW__; __THREW__ = 0;
               $227 = $226&1;
               if ($227) {
                label = 67;
                break L16;
               }
              }
             } while(0);
             $228 = HEAP32[$0>>2]|0;
             $229 = ((($228)) + 52|0);
             $230 = HEAP32[$229>>2]|0;
             if ($218) {
              $245 = $230;
              label = 74;
              break;
             }
             __THREW__ = 0;
             invoke_viii($230|0,($0|0),($186|0),($11|0));
             $231 = __THREW__; __THREW__ = 0;
             $232 = $231&1;
             if ($232) {
              label = 35;
              break L16;
             }
            } else {
             $179 = HEAP32[$0>>2]|0;
             $180 = ((($179)) + 52|0);
             $181 = HEAP32[$180>>2]|0;
             $245 = $181;
             label = 74;
            }
           } while(0);
           if ((label|0) == 74) {
            label = 0;
            $244 = HEAP32[$175>>2]|0;
            __THREW__ = 0;
            invoke_viii($245|0,($0|0),($244|0),($11|0));
            $246 = __THREW__; __THREW__ = 0;
            $247 = $246&1;
            if ($247) {
             label = 35;
             break;
            }
           }
           $248 = ((($84)) + 88|0);
           $249 = HEAP32[$248>>2]|0;
           $250 = ($249|0)==(0|0);
           do {
            if (!($250)) {
             __THREW__ = 0;
             $251 = (invoke_ii(3482,0)|0);
             $252 = __THREW__; __THREW__ = 0;
             $253 = $252&1;
             if ($253) {
              label = 35;
              break L16;
             }
             $254 = ((($251)) + 212|0);
             $255 = HEAP32[$254>>2]|0;
             $256 = ($255|0)==(0|0);
             if ($256) {
              break;
             }
             __THREW__ = 0;
             $257 = (invoke_ii(3482,0)|0);
             $258 = __THREW__; __THREW__ = 0;
             $259 = $258&1;
             if ($259) {
              label = 35;
              break L16;
             }
             $260 = ((($257)) + 212|0);
             $261 = HEAP32[$260>>2]|0;
             $262 = HEAP32[$248>>2]|0;
             __THREW__ = 0;
             invoke_vii(4141,($261|0),($262|0));
             $263 = __THREW__; __THREW__ = 0;
             $264 = $263&1;
             if ($264) {
              label = 35;
              break L16;
             }
            }
           } while(0);
           $265 = ((($84)) + 32|0);
           $266 = +HEAPF64[$265>>3];
           $267 = $9 - $266;
           $268 = +HEAPF64[$73>>3];
           $269 = $267 < $268;
           if ($269) {
            HEAPF64[$73>>3] = $267;
           }
           $270 = +HEAPF64[$74>>3];
           $271 = $267 > $270;
           if ($271) {
            HEAPF64[$74>>3] = $267;
           }
           $272 = +HEAPF64[$75>>3];
           $273 = $267 + $272;
           HEAPF64[$75>>3] = $273;
           $274 = HEAP32[$76>>2]|0;
           $275 = (($274) + 1)|0;
           HEAP32[$76>>2] = $275;
          } else {
           label = 85;
          }
         } else {
          label = 85;
         }
         if ((label|0) == 85) {
          label = 0;
          __THREW__ = 0;
          $276 = (invoke_ii(3265,4)|0);
          $277 = __THREW__; __THREW__ = 0;
          $278 = $277&1;
          if ($278) {
           label = 23;
           break;
          }
          if ($276) {
           __THREW__ = 0;
           $279 = (invoke_ii(3266,4)|0);
           $280 = __THREW__; __THREW__ = 0;
           $281 = $280&1;
           if ($281) {
            label = 23;
            break;
           }
           __THREW__ = 0;
           $282 = (invoke_iiii(3267,($279|0),(163535|0),94)|0);
           $283 = __THREW__; __THREW__ = 0;
           $284 = $283&1;
           if ($284) {
            label = 23;
            break;
           }
           $285 = HEAP32[$282>>2]|0;
           $286 = ((($285)) + -12|0);
           $287 = HEAP32[$286>>2]|0;
           $288 = (($282) + ($287)|0);
           __THREW__ = 0;
           invoke_vii(3257,($2|0),($288|0));
           $289 = __THREW__; __THREW__ = 0;
           $290 = $289&1;
           if ($290) {
            label = 23;
            break;
           }
           __THREW__ = 0;
           $291 = (invoke_iii(3255,($2|0),(215188|0))|0);
           $292 = __THREW__; __THREW__ = 0;
           $293 = $292&1;
           if ($293) {
            label = 92;
            break;
           }
           $294 = HEAP32[$291>>2]|0;
           $295 = ((($294)) + 28|0);
           $296 = HEAP32[$295>>2]|0;
           __THREW__ = 0;
           $297 = (invoke_iii($296|0,($291|0),10)|0);
           $298 = __THREW__; __THREW__ = 0;
           $299 = $298&1;
           if ($299) {
            label = 92;
            break;
           }
           __THREW__ = 0;
           invoke_vi(3263,($2|0));
           $306 = __THREW__; __THREW__ = 0;
           $307 = $306&1;
           if ($307) {
            label = 23;
            break;
           }
           __THREW__ = 0;
           (invoke_iii(3268,($282|0),($297|0))|0);
           $308 = __THREW__; __THREW__ = 0;
           $309 = $308&1;
           if ($309) {
            label = 23;
            break;
           }
           __THREW__ = 0;
           (invoke_ii(3269,($282|0))|0);
           $310 = __THREW__; __THREW__ = 0;
           $311 = $310&1;
           if ($311) {
            label = 23;
            break;
           }
          }
         }
         $312 = ((($84)) + 80|0);
         $313 = HEAP32[$312>>2]|0;
         $314 = ($313|0)==(0|0);
         if (!($314)) {
          HEAP32[$312>>2] = 0;
          $315 = ((($313)) + 8|0);
          $316 = HEAP32[$315>>2]|0;HEAP32[$315>>2] = (($316-1)|0);
          $317 = ($316|0)==(1);
          if ($317) {
           __THREW__ = 0;
           invoke_viii(3262,($313|0),1,1);
           $318 = __THREW__; __THREW__ = 0;
           $319 = $318&1;
           if ($319) {
            label = 23;
            break;
           }
          }
         }
         $320 = HEAP32[$6>>2]|0;
         $321 = ($320|0)==(0|0);
         if (!($321)) {
          $322 = ((($320)) + 8|0);
          $323 = HEAP32[$322>>2]|0;HEAP32[$322>>2] = (($323-1)|0);
          $324 = ($323|0)==(1);
          if ($324) {
           __THREW__ = 0;
           invoke_viii(3262,($320|0),1,1);
           $325 = __THREW__; __THREW__ = 0;
           $326 = $325&1;
           if ($326) {
            label = 105;
            break;
           }
          }
         }
         $327 = ((($328)) + 4|0);
         $$sroa$0135$0 = HEAP32[$327>>2]|0;
         $329 = $$sroa$0135$0;
         $330 = ($329|0)==($5|0);
         if ($330) {
          break L14;
         } else {
          $$sroa$0135$0167 = $$sroa$0135$0;$328 = $329;
         }
        }
        do {
         if ((label|0) == 23) {
          $107 = ___cxa_find_matching_catch_2()|0;
          $108 = tempRet0;
          $eh$lpad$body114$index9Z2D = $108;$eh$lpad$body114$indexZ2D = $107;
          label = 24;
         }
         else if ((label|0) == 35) {
          $149 = ___cxa_find_matching_catch_2()|0;
          $150 = tempRet0;
          $$2 = $149;$$275 = $150;
          label = 106;
         }
         else if ((label|0) == 41) {
          $169 = ___cxa_find_matching_catch_2()|0;
          $170 = tempRet0;
          $$2 = $169;$$275 = $170;
          label = 106;
         }
         else if ((label|0) == 56) {
          $206 = ___cxa_find_matching_catch_2()|0;
          $207 = tempRet0;
          $208 = HEAP32[$7>>2]|0;
          $209 = ($208|0)==(0|0);
          if (!($209)) {
           $210 = ((($208)) + 8|0);
           $211 = HEAP32[$210>>2]|0;HEAP32[$210>>2] = (($211-1)|0);
           $212 = ($211|0)==(1);
           if ($212) {
            __THREW__ = 0;
            invoke_viii(3262,($208|0),1,1);
            $213 = __THREW__; __THREW__ = 0;
            $214 = $213&1;
            if ($214) {
             $215 = ___cxa_find_matching_catch_3(0|0)|0;
             $216 = tempRet0;
             ___clang_call_terminate($215);
             // unreachable;
            }
           }
          }
          HEAP32[$7>>2] = 0;
          $eh$lpad$body104$index14Z2D = $207;$eh$lpad$body104$indexZ2D = $206;
          label = 68;
         }
         else if ((label|0) == 67) {
          $233 = ___cxa_find_matching_catch_2()|0;
          $234 = tempRet0;
          $eh$lpad$body104$index14Z2D = $234;$eh$lpad$body104$indexZ2D = $233;
          label = 68;
         }
         else if ((label|0) == 69) {
          $235 = ___cxa_find_matching_catch_2()|0;
          $236 = tempRet0;
          $237 = HEAP32[$7>>2]|0;
          $238 = ($237|0)==(0|0);
          if (!($238)) {
           $239 = ((($237)) + 8|0);
           $240 = HEAP32[$239>>2]|0;HEAP32[$239>>2] = (($240-1)|0);
           $241 = ($240|0)==(1);
           if ($241) {
            __THREW__ = 0;
            invoke_viii(3262,($237|0),1,1);
            $242 = __THREW__; __THREW__ = 0;
            $243 = $242&1;
            if ($243) {
             $511 = ___cxa_find_matching_catch_3(0|0)|0;
             $512 = tempRet0;
             ___clang_call_terminate($511);
             // unreachable;
            }
           }
          }
          HEAP32[$7>>2] = 0;
          $$0$ph = $235;$$073$ph = $236;
          label = 73;
         }
         else if ((label|0) == 92) {
          $300 = ___cxa_find_matching_catch_2()|0;
          $301 = tempRet0;
          __THREW__ = 0;
          invoke_vi(3263,($2|0));
          $302 = __THREW__; __THREW__ = 0;
          $303 = $302&1;
          if ($303) {
           $304 = ___cxa_find_matching_catch_3(0|0)|0;
           $305 = tempRet0;
           ___clang_call_terminate($304);
           // unreachable;
          } else {
           $eh$lpad$body114$index9Z2D = $301;$eh$lpad$body114$indexZ2D = $300;
           label = 24;
           break;
          }
         }
         else if ((label|0) == 105) {
          $331 = ___cxa_find_matching_catch_2()|0;
          $332 = tempRet0;
          $$3 = $331;$$376 = $332;
         }
        } while(0);
        if ((label|0) == 24) {
         $$2 = $eh$lpad$body114$indexZ2D;$$275 = $eh$lpad$body114$index9Z2D;
         label = 106;
        }
        else if ((label|0) == 68) {
         $$0$ph = $eh$lpad$body104$indexZ2D;$$073$ph = $eh$lpad$body104$index14Z2D;
         label = 73;
        }
        if ((label|0) == 73) {
         $$2 = $$0$ph;$$275 = $$073$ph;
         label = 106;
        }
        if ((label|0) == 106) {
         $333 = HEAP32[$6>>2]|0;
         $334 = ($333|0)==(0|0);
         if (!($334)) {
          $335 = ((($333)) + 8|0);
          $336 = HEAP32[$335>>2]|0;HEAP32[$335>>2] = (($336-1)|0);
          $337 = ($336|0)==(1);
          if ($337) {
           __THREW__ = 0;
           invoke_viii(3262,($333|0),1,1);
           $338 = __THREW__; __THREW__ = 0;
           $339 = $338&1;
           if ($339) {
            $511 = ___cxa_find_matching_catch_3(0|0)|0;
            $512 = tempRet0;
            ___clang_call_terminate($511);
            // unreachable;
           }
          }
         }
         HEAP32[$6>>2] = 0;
         $$3 = $$2;$$376 = $$275;
        }
        $$5 = $$3;$$578 = $$376;
        break L1;
       }
      } while(0);
      __THREW__ = 0;
      $77 = (invoke_i(3384)|0);
      $78 = __THREW__; __THREW__ = 0;
      $79 = $78&1;
      if ($79) {
       label = 14;
      } else {
       __THREW__ = 0;
       $340 = (invoke_ii(3385,($77|0))|0);
       $341 = tempRet0;
       $342 = __THREW__; __THREW__ = 0;
       $343 = $342&1;
       if ($343) {
        label = 14;
       } else {
        $344 = HEAP32[$16>>2]|0;
        $345 = ($344|0)==(0);
        if ($345) {
         STACKTOP = sp;return;
        }
        __THREW__ = 0;
        $346 = (invoke_ii(3265,4)|0);
        $347 = __THREW__; __THREW__ = 0;
        $348 = $347&1;
        if ($348) {
         label = 14;
        } else {
         L146: do {
          if ($346) {
           __THREW__ = 0;
           $349 = (invoke_ii(3266,4)|0);
           $350 = __THREW__; __THREW__ = 0;
           $351 = $350&1;
           if ($351) {
            label = 14;
            break L1;
           }
           __THREW__ = 0;
           $352 = (invoke_iiii(3267,($349|0),(163630|0),45)|0);
           $353 = __THREW__; __THREW__ = 0;
           $354 = $353&1;
           if ($354) {
            label = 14;
            break L1;
           }
           __THREW__ = 0;
           $355 = (invoke_i(3384)|0);
           $356 = __THREW__; __THREW__ = 0;
           $357 = $356&1;
           if ($357) {
            label = 14;
            break L1;
           }
           $358 = ($66>>>0)>($14>>>0);
           $359 = ($65>>>0)>($13>>>0);
           $360 = ($66|0)==($14|0);
           $361 = $360 & $359;
           $362 = $358 | $361;
           if ($362) {
            $363 = (_i64Subtract(($65|0),($66|0),($13|0),($14|0))|0);
            $364 = tempRet0;
            $365 = (+($363>>>0)) + (4294967296.0*(+($364>>>0)));
            $$sink$i$i = $365;
           } else {
            $366 = (_i64Subtract(($13|0),($14|0),($65|0),($66|0))|0);
            $367 = tempRet0;
            $368 = (+($366>>>0)) + (4294967296.0*(+($367>>>0)));
            $369 = -$368;
            $$sink$i$i = $369;
           }
           $370 = ((($355)) + 8|0);
           $371 = +HEAPF64[$370>>3];
           $372 = $$sink$i$i * $371;
           $373 = $372 * 1000.0;
           __THREW__ = 0;
           $374 = (invoke_iid(3519,($352|0),(+$373))|0);
           $375 = __THREW__; __THREW__ = 0;
           $376 = $375&1;
           if ($376) {
            label = 14;
            break L1;
           }
           __THREW__ = 0;
           $377 = (invoke_iiii(3267,($374|0),(163676|0),4)|0);
           $378 = __THREW__; __THREW__ = 0;
           $379 = $378&1;
           if ($379) {
            label = 14;
            break L1;
           }
           __THREW__ = 0;
           $380 = (invoke_i(3384)|0);
           $381 = __THREW__; __THREW__ = 0;
           $382 = $381&1;
           if ($382) {
            label = 14;
            break L1;
           }
           $383 = ($341>>>0)>($66>>>0);
           $384 = ($340>>>0)>($65>>>0);
           $385 = ($341|0)==($66|0);
           $386 = $385 & $384;
           $387 = $383 | $386;
           if ($387) {
            $388 = (_i64Subtract(($340|0),($341|0),($65|0),($66|0))|0);
            $389 = tempRet0;
            $390 = (+($388>>>0)) + (4294967296.0*(+($389>>>0)));
            $$sink$i$i127 = $390;
           } else {
            $391 = (_i64Subtract(($65|0),($66|0),($340|0),($341|0))|0);
            $392 = tempRet0;
            $393 = (+($391>>>0)) + (4294967296.0*(+($392>>>0)));
            $394 = -$393;
            $$sink$i$i127 = $394;
           }
           $395 = ((($380)) + 8|0);
           $396 = +HEAPF64[$395>>3];
           $397 = $$sink$i$i127 * $396;
           $398 = $397 * 1000.0;
           __THREW__ = 0;
           $399 = (invoke_iid(3519,($377|0),(+$398))|0);
           $400 = __THREW__; __THREW__ = 0;
           $401 = $400&1;
           if ($401) {
            label = 14;
            break L1;
           }
           __THREW__ = 0;
           $402 = (invoke_iiii(3267,($399|0),(163681|0),2)|0);
           $403 = __THREW__; __THREW__ = 0;
           $404 = $403&1;
           if ($404) {
            label = 14;
            break L1;
           }
           __THREW__ = 0;
           $405 = (invoke_iiii(3267,($402|0),(163684|0),9)|0);
           $406 = __THREW__; __THREW__ = 0;
           $407 = $406&1;
           if ($407) {
            label = 14;
            break L1;
           }
           $408 = HEAP32[$16>>2]|0;
           __THREW__ = 0;
           $409 = (invoke_iii(3417,($405|0),($408|0))|0);
           $410 = __THREW__; __THREW__ = 0;
           $411 = $410&1;
           if ($411) {
            label = 14;
            break L1;
           }
           $412 = HEAP32[$409>>2]|0;
           $413 = ((($412)) + -12|0);
           $414 = HEAP32[$413>>2]|0;
           $415 = (($409) + ($414)|0);
           __THREW__ = 0;
           invoke_vii(3257,($3|0),($415|0));
           $416 = __THREW__; __THREW__ = 0;
           $417 = $416&1;
           if ($417) {
            label = 14;
            break L1;
           }
           __THREW__ = 0;
           $418 = (invoke_iii(3255,($3|0),(215188|0))|0);
           $419 = __THREW__; __THREW__ = 0;
           $420 = $419&1;
           do {
            if (!($420)) {
             $421 = HEAP32[$418>>2]|0;
             $422 = ((($421)) + 28|0);
             $423 = HEAP32[$422>>2]|0;
             __THREW__ = 0;
             $424 = (invoke_iii($423|0,($418|0),10)|0);
             $425 = __THREW__; __THREW__ = 0;
             $426 = $425&1;
             if ($426) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3263,($3|0));
             $433 = __THREW__; __THREW__ = 0;
             $434 = $433&1;
             if ($434) {
              label = 14;
              break L1;
             }
             __THREW__ = 0;
             (invoke_iii(3268,($409|0),($424|0))|0);
             $435 = __THREW__; __THREW__ = 0;
             $436 = $435&1;
             if ($436) {
              label = 14;
              break L1;
             }
             __THREW__ = 0;
             (invoke_ii(3269,($409|0))|0);
             $437 = __THREW__; __THREW__ = 0;
             $438 = $437&1;
             if ($438) {
              label = 14;
              break L1;
             }
             $439 = HEAP32[$409>>2]|0;
             $440 = ((($439)) + -12|0);
             $441 = HEAP32[$440>>2]|0;
             $442 = (($409) + ($441)|0);
             __THREW__ = 0;
             invoke_vii(3257,($4|0),($442|0));
             $443 = __THREW__; __THREW__ = 0;
             $444 = $443&1;
             if ($444) {
              label = 14;
              break L1;
             }
             __THREW__ = 0;
             $445 = (invoke_iii(3255,($4|0),(215188|0))|0);
             $446 = __THREW__; __THREW__ = 0;
             $447 = $446&1;
             do {
              if (!($447)) {
               $448 = HEAP32[$445>>2]|0;
               $449 = ((($448)) + 28|0);
               $450 = HEAP32[$449>>2]|0;
               __THREW__ = 0;
               $451 = (invoke_iii($450|0,($445|0),10)|0);
               $452 = __THREW__; __THREW__ = 0;
               $453 = $452&1;
               if ($453) {
                break;
               }
               __THREW__ = 0;
               invoke_vi(3263,($4|0));
               $460 = __THREW__; __THREW__ = 0;
               $461 = $460&1;
               if ($461) {
                label = 14;
                break L1;
               }
               __THREW__ = 0;
               (invoke_iii(3268,($409|0),($451|0))|0);
               $462 = __THREW__; __THREW__ = 0;
               $463 = $462&1;
               if ($463) {
                label = 14;
                break L1;
               }
               __THREW__ = 0;
               (invoke_ii(3269,($409|0))|0);
               $464 = __THREW__; __THREW__ = 0;
               $465 = $464&1;
               if ($465) {
                label = 14;
                break L1;
               } else {
                break L146;
               }
              }
             } while(0);
             $454 = ___cxa_find_matching_catch_2()|0;
             $455 = tempRet0;
             __THREW__ = 0;
             invoke_vi(3263,($4|0));
             $456 = __THREW__; __THREW__ = 0;
             $457 = $456&1;
             if ($457) {
              $458 = ___cxa_find_matching_catch_3(0|0)|0;
              $459 = tempRet0;
              ___clang_call_terminate($458);
              // unreachable;
             } else {
              $eh$lpad$body$index3Z2D = $455;$eh$lpad$body$indexZ2D = $454;
              label = 15;
              break L1;
             }
            }
           } while(0);
           $427 = ___cxa_find_matching_catch_2()|0;
           $428 = tempRet0;
           __THREW__ = 0;
           invoke_vi(3263,($3|0));
           $429 = __THREW__; __THREW__ = 0;
           $430 = $429&1;
           if ($430) {
            $431 = ___cxa_find_matching_catch_3(0|0)|0;
            $432 = tempRet0;
            ___clang_call_terminate($431);
            // unreachable;
           } else {
            $eh$lpad$body$index3Z2D = $428;$eh$lpad$body$indexZ2D = $427;
            label = 15;
            break L1;
           }
          }
         } while(0);
         $$pr = HEAP32[$16>>2]|0;
         $466 = ($$pr|0)==(0);
         if ($466) {
          STACKTOP = sp;return;
         }
         $467 = HEAP32[$15>>2]|0;
         $468 = HEAP32[$5>>2]|0;
         $469 = ((($468)) + 4|0);
         $470 = HEAP32[$469>>2]|0;
         $471 = HEAP32[$467>>2]|0;
         $472 = ((($471)) + 4|0);
         HEAP32[$472>>2] = $470;
         $473 = HEAP32[$469>>2]|0;
         HEAP32[$473>>2] = $471;
         HEAP32[$16>>2] = 0;
         $474 = ($467|0)==($5|0);
         if ($474) {
          STACKTOP = sp;return;
         } else {
          $$023$i$i80 = $467;
         }
         while(1) {
          $475 = ((($$023$i$i80)) + 4|0);
          $476 = HEAP32[$475>>2]|0;
          $477 = ((($$023$i$i80)) + 8|0);
          $478 = HEAP32[$477>>2]|0;
          $479 = ($478|0)==(0|0);
          if (!($479)) {
           $480 = ((($478)) + 8|0);
           $481 = HEAP32[$480>>2]|0;HEAP32[$480>>2] = (($481-1)|0);
           $482 = ($481|0)==(1);
           if ($482) {
            __THREW__ = 0;
            invoke_viii(3262,($478|0),1,1);
            $483 = __THREW__; __THREW__ = 0;
            $484 = $483&1;
            if ($484) {
             label = 155;
             break;
            }
           }
          }
          __ZdlPv($$023$i$i80);
          $485 = ($476|0)==($5|0);
          if ($485) {
           label = 156;
           break;
          } else {
           $$023$i$i80 = $476;
          }
         }
         if ((label|0) == 155) {
          $486 = ___cxa_find_matching_catch_2()|0;
          $487 = tempRet0;
          ___cxa_call_unexpected(($486|0));
          // unreachable;
         }
         else if ((label|0) == 156) {
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 14) {
  $80 = ___cxa_find_matching_catch_2()|0;
  $81 = tempRet0;
  $eh$lpad$body$index3Z2D = $81;$eh$lpad$body$indexZ2D = $80;
  label = 15;
 }
 if ((label|0) == 15) {
  $$5 = $eh$lpad$body$indexZ2D;$$578 = $eh$lpad$body$index3Z2D;
 }
 $488 = HEAP32[$16>>2]|0;
 $489 = ($488|0)==(0);
 if ($489) {
  ___resumeException($$5|0);
  // unreachable;
 }
 $490 = HEAP32[$15>>2]|0;
 $491 = HEAP32[$5>>2]|0;
 $492 = ((($491)) + 4|0);
 $493 = HEAP32[$492>>2]|0;
 $494 = HEAP32[$490>>2]|0;
 $495 = ((($494)) + 4|0);
 HEAP32[$495>>2] = $493;
 $496 = HEAP32[$492>>2]|0;
 HEAP32[$496>>2] = $494;
 HEAP32[$16>>2] = 0;
 $497 = ($490|0)==($5|0);
 if ($497) {
  ___resumeException($$5|0);
  // unreachable;
 } else {
  $$023$i$i = $490;
 }
 while(1) {
  $498 = ((($$023$i$i)) + 4|0);
  $499 = HEAP32[$498>>2]|0;
  $500 = ((($$023$i$i)) + 8|0);
  $501 = HEAP32[$500>>2]|0;
  $502 = ($501|0)==(0|0);
  if (!($502)) {
   $503 = ((($501)) + 8|0);
   $504 = HEAP32[$503>>2]|0;HEAP32[$503>>2] = (($504-1)|0);
   $505 = ($504|0)==(1);
   if ($505) {
    __THREW__ = 0;
    invoke_viii(3262,($501|0),1,1);
    $506 = __THREW__; __THREW__ = 0;
    $507 = $506&1;
    if ($507) {
     label = 163;
     break;
    }
   }
  }
  __ZdlPv($$023$i$i);
  $508 = ($499|0)==($5|0);
  if ($508) {
   label = 164;
   break;
  } else {
   $$023$i$i = $499;
  }
 }
 if ((label|0) == 163) {
  $509 = ___cxa_find_matching_catch_2()|0;
  $510 = tempRet0;
  ___cxa_call_unexpected(($509|0));
  // unreachable;
 }
 else if ((label|0) == 164) {
  ___resumeException($$5|0);
  // unreachable;
 }
}
function __ZN5osgDB13DatabasePager20FindPagedLODsVisitorD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vii(3284,($0|0),((73752)|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  $3 = ((($0)) + 64|0);
  __ZN3osg6ObjectD2Ev($3);
  return;
 }
 $4 = ___cxa_find_matching_catch_2()|0;
 $5 = tempRet0;
 $6 = ((($0)) + 64|0);
 __THREW__ = 0;
 invoke_vi(388,($6|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch_3(0|0)|0;
  $10 = tempRet0;
  ___clang_call_terminate($9);
  // unreachable;
 } else {
  ___resumeException($4|0);
  // unreachable;
 }
}
function __ZN5osgDB13DatabasePager20FindPagedLODsVisitorD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vii(3284,($0|0),((73752)|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $6 = ___cxa_find_matching_catch_2()|0;
  $7 = tempRet0;
  $8 = ((($0)) + 64|0);
  __THREW__ = 0;
  invoke_vi(388,($8|0));
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if ($10) {
   $11 = ___cxa_find_matching_catch_3(0|0)|0;
   $12 = tempRet0;
   ___clang_call_terminate($11);
   // unreachable;
  } else {
   $eh$lpad$body$index2Z2D = $7;$eh$lpad$body$indexZ2D = $6;
   __ZdlPv($0);
   ___resumeException($eh$lpad$body$indexZ2D|0);
   // unreachable;
  }
 }
 $3 = ((($0)) + 64|0);
 __THREW__ = 0;
 invoke_vi(388,($3|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  __ZdlPv($0);
  return;
 }
 $13 = ___cxa_find_matching_catch_2()|0;
 $14 = tempRet0;
 $eh$lpad$body$index2Z2D = $14;$eh$lpad$body$indexZ2D = $13;
 __ZdlPv($0);
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
}
function __ZNK5osgDB13DatabasePager20FindPagedLODsVisitor11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (163048|0);
}
function __ZNK5osgDB13DatabasePager20FindPagedLODsVisitor9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (163694|0);
}
function __ZN5osgDB13DatabasePager20FindPagedLODsVisitor5applyERN3osg8PagedLODE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$$i = 0, $$pr6$i$pre = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = ((($0)) + 60|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($1)) + 188|0);
 HEAP32[$5>>2] = $4;
 HEAP32[$2>>2] = 0;
 $6 = (__ZNK3osg10Referenced22getOrCreateObserverSetEv($1)|0);
 $7 = ($6|0)==(0|0);
 if ($7) {
  $15 = 0;
 } else {
  HEAP32[$2>>2] = $6;
  $8 = ((($6)) + 8|0);
  $9 = HEAP32[$8>>2]|0;HEAP32[$8>>2] = (($9+1)|0);
  $$pr6$i$pre = HEAP32[$2>>2]|0;
  $10 = ($$pr6$i$pre|0)==(0|0);
  if ($10) {
   $15 = 0;
  } else {
   $11 = ((($$pr6$i$pre)) + 24|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = ($12|0)!=(0|0);
   $$$i = $13 ? $1 : 0;
   $15 = $$$i;
  }
 }
 $14 = ((($2)) + 4|0);
 HEAP32[$14>>2] = $15;
 $16 = ((($0)) + 56|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = HEAP32[$17>>2]|0;
 $19 = ((($18)) + 32|0);
 $20 = HEAP32[$19>>2]|0;
 __THREW__ = 0;
 invoke_vii($20|0,($17|0),($2|0));
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 L5: do {
  if (!($22)) {
   $23 = ((($0)) + 16|0);
   $24 = HEAP32[$23>>2]|0;
   switch ($24|0) {
   case 1:  {
    $25 = HEAP32[$1>>2]|0;
    $26 = ((($25)) + 192|0);
    $27 = HEAP32[$26>>2]|0;
    __THREW__ = 0;
    invoke_vii($27|0,($1|0),($0|0));
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if ($29) {
     break L5;
    }
    break;
   }
   case 0:  {
    break;
   }
   default: {
    $30 = HEAP32[$1>>2]|0;
    $31 = ((($30)) + 196|0);
    $32 = HEAP32[$31>>2]|0;
    __THREW__ = 0;
    invoke_vii($32|0,($1|0),($0|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break L5;
    }
   }
   }
   $35 = HEAP32[$2>>2]|0;
   $36 = ($35|0)==(0|0);
   if ($36) {
    STACKTOP = sp;return;
   }
   $37 = ((($35)) + 8|0);
   $38 = HEAP32[$37>>2]|0;HEAP32[$37>>2] = (($38-1)|0);
   $39 = ($38|0)==(1);
   if (!($39)) {
    STACKTOP = sp;return;
   }
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($35,1,1);
   STACKTOP = sp;return;
  }
 } while(0);
 $40 = ___cxa_find_matching_catch_2()|0;
 $41 = tempRet0;
 $42 = HEAP32[$2>>2]|0;
 $43 = ($42|0)==(0|0);
 if ($43) {
  ___resumeException($40|0);
  // unreachable;
 }
 $44 = ((($42)) + 8|0);
 $45 = HEAP32[$44>>2]|0;HEAP32[$44>>2] = (($45-1)|0);
 $46 = ($45|0)==(1);
 if (!($46)) {
  ___resumeException($40|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(3262,($42|0),1,1);
 $47 = __THREW__; __THREW__ = 0;
 $48 = $47&1;
 if ($48) {
  $49 = ___cxa_find_matching_catch_3(0|0)|0;
  $50 = tempRet0;
  ___clang_call_terminate($49);
  // unreachable;
 } else {
  ___resumeException($40|0);
  // unreachable;
 }
}
function __ZTv0_n16_N5osgDB13DatabasePager20FindPagedLODsVisitorD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __THREW__ = 0;
 invoke_vii(3284,($4|0),((73752)|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if (!($6)) {
  $14 = ((($4)) + 64|0);
  __ZN3osg6ObjectD2Ev($14);
  return;
 }
 $7 = ___cxa_find_matching_catch_2()|0;
 $8 = tempRet0;
 $9 = ((($4)) + 64|0);
 __THREW__ = 0;
 invoke_vi(388,($9|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if ($11) {
  $12 = ___cxa_find_matching_catch_3(0|0)|0;
  $13 = tempRet0;
  ___clang_call_terminate($12);
  // unreachable;
 } else {
  ___resumeException($7|0);
  // unreachable;
 }
}
function __ZTv0_n16_N5osgDB13DatabasePager20FindPagedLODsVisitorD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$i$index2Z2D = 0, $eh$lpad$body$i$indexZ2D = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __THREW__ = 0;
 invoke_vii(3284,($4|0),((73752)|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $10 = ___cxa_find_matching_catch_2()|0;
  $11 = tempRet0;
  $12 = ((($4)) + 64|0);
  __THREW__ = 0;
  invoke_vi(388,($12|0));
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if ($14) {
   $15 = ___cxa_find_matching_catch_3(0|0)|0;
   $16 = tempRet0;
   ___clang_call_terminate($15);
   // unreachable;
  } else {
   $eh$lpad$body$i$index2Z2D = $11;$eh$lpad$body$i$indexZ2D = $10;
   __ZdlPv($4);
   ___resumeException($eh$lpad$body$i$indexZ2D|0);
   // unreachable;
  }
 }
 $7 = ((($4)) + 64|0);
 __THREW__ = 0;
 invoke_vi(388,($7|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if (!($9)) {
  __ZdlPv($4);
  return;
 }
 $17 = ___cxa_find_matching_catch_2()|0;
 $18 = tempRet0;
 $eh$lpad$body$i$index2Z2D = $18;$eh$lpad$body$i$indexZ2D = $17;
 __ZdlPv($4);
 ___resumeException($eh$lpad$body$i$indexZ2D|0);
 // unreachable;
}
function __ZTv0_n32_NK5osgDB13DatabasePager20FindPagedLODsVisitor11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (163048|0);
}
function __ZTv0_n36_NK5osgDB13DatabasePager20FindPagedLODsVisitor9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (163694|0);
}
function __ZN5osgDB13DatabasePager12RequestQueue31pruneOldRequestsAndCheckIfEmptyEv($0) {
 $0 = $0|0;
 var $$3 = 0, $$312 = 0, $$pre = 0, $$pre$phiZ2D = 0, $$sink13$index = 0, $$sink13$index3 = 0, $$sroa$029$0 = 0, $$sroa$029$1 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $2 = ((($0)) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 (FUNCTION_TABLE_ii[$5 & 8191]($2)|0);
 $6 = ((($0)) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 /* fence */;
 $8 = ((($7)) + 84|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($0)) + 40|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==($9|0);
 if ($12) {
  $$pre = ((($0)) + 24|0);
  $$pre$phiZ2D = $$pre;
  $121 = HEAP32[$$pre$phiZ2D>>2]|0;
  $122 = ($121|0)==(0);
  $123 = HEAP32[$2>>2]|0;
  $124 = ((($123)) + 12|0);
  $125 = HEAP32[$124>>2]|0;
  (FUNCTION_TABLE_ii[$125 & 8191]($2)|0);
  STACKTOP = sp;return ($122|0);
 }
 $13 = ((($0)) + 20|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ((($0)) + 16|0);
 $16 = ((($0)) + 24|0);
 $$sroa$029$0 = $14;
 while(1) {
  $17 = $$sroa$029$0;
  $18 = ($17|0)==($15|0);
  if ($18) {
   label = 5;
   break;
  }
  $24 = HEAP32[$6>>2]|0;
  $25 = ((($24)) + 24|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = ((($26)) + 8|0);
  $28 = HEAP32[$27>>2]|0;
  __THREW__ = 0;
  (invoke_ii($28|0,($25|0))|0);
  $29 = __THREW__; __THREW__ = 0;
  $30 = $29&1;
  if ($30) {
   label = 10;
   break;
  }
  $31 = $$sroa$029$0;
  $32 = ((($31)) + 8|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = ((($33)) + 12|0);
  $35 = HEAP8[$34>>0]|0;
  $36 = ($35<<24>>24)==(0);
  if ($36) {
   label = 12;
  } else {
   $37 = ((($33)) + 44|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = (($9) - ($38))|0;
   $40 = ($39>>>0)<(2);
   if ($40) {
    $41 = ((($17)) + 4|0);
    $42 = HEAP32[$41>>2]|0;
    $$sroa$029$1 = $42;
   } else {
    label = 12;
   }
  }
  if ((label|0) == 12) {
   label = 0;
   __THREW__ = 0;
   invoke_vii(4117,($0|0),($33|0));
   $47 = __THREW__; __THREW__ = 0;
   $48 = $47&1;
   if ($48) {
    label = 11;
    break;
   }
   __THREW__ = 0;
   $49 = (invoke_ii(3265,4)|0);
   $50 = __THREW__; __THREW__ = 0;
   $51 = $50&1;
   if ($51) {
    label = 11;
    break;
   }
   if ($49) {
    __THREW__ = 0;
    $52 = (invoke_ii(3266,4)|0);
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if ($54) {
     label = 11;
     break;
    }
    __THREW__ = 0;
    $55 = (invoke_iiii(3267,($52|0),(163763|0),72)|0);
    $56 = __THREW__; __THREW__ = 0;
    $57 = $56&1;
    if ($57) {
     label = 11;
     break;
    }
    $58 = HEAP32[$32>>2]|0;
    __THREW__ = 0;
    $59 = (invoke_iii(3275,($55|0),($58|0))|0);
    $60 = __THREW__; __THREW__ = 0;
    $61 = $60&1;
    if ($61) {
     label = 11;
     break;
    }
    $62 = HEAP32[$59>>2]|0;
    $63 = ((($62)) + -12|0);
    $64 = HEAP32[$63>>2]|0;
    $65 = (($59) + ($64)|0);
    __THREW__ = 0;
    invoke_vii(3257,($1|0),($65|0));
    $66 = __THREW__; __THREW__ = 0;
    $67 = $66&1;
    if ($67) {
     label = 11;
     break;
    }
    __THREW__ = 0;
    $68 = (invoke_iii(3255,($1|0),(215188|0))|0);
    $69 = __THREW__; __THREW__ = 0;
    $70 = $69&1;
    if ($70) {
     label = 21;
     break;
    }
    $71 = HEAP32[$68>>2]|0;
    $72 = ((($71)) + 28|0);
    $73 = HEAP32[$72>>2]|0;
    __THREW__ = 0;
    $74 = (invoke_iii($73|0,($68|0),10)|0);
    $75 = __THREW__; __THREW__ = 0;
    $76 = $75&1;
    if ($76) {
     label = 21;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3263,($1|0));
    $83 = __THREW__; __THREW__ = 0;
    $84 = $83&1;
    if ($84) {
     label = 11;
     break;
    }
    __THREW__ = 0;
    (invoke_iii(3268,($59|0),($74|0))|0);
    $85 = __THREW__; __THREW__ = 0;
    $86 = $85&1;
    if ($86) {
     label = 11;
     break;
    }
    __THREW__ = 0;
    (invoke_ii(3269,($59|0))|0);
    $87 = __THREW__; __THREW__ = 0;
    $88 = $87&1;
    if ($88) {
     label = 11;
     break;
    }
   }
   $89 = ((($17)) + 4|0);
   $90 = HEAP32[$89>>2]|0;
   $91 = HEAP32[$17>>2]|0;
   $92 = ((($91)) + 4|0);
   HEAP32[$92>>2] = $90;
   $93 = HEAP32[$89>>2]|0;
   HEAP32[$93>>2] = $91;
   $94 = HEAP32[$16>>2]|0;
   $95 = (($94) + -1)|0;
   HEAP32[$16>>2] = $95;
   $96 = ((($17)) + 8|0);
   $97 = HEAP32[$96>>2]|0;
   $98 = ($97|0)==(0|0);
   if (!($98)) {
    $99 = ((($97)) + 8|0);
    $100 = HEAP32[$99>>2]|0;HEAP32[$99>>2] = (($100-1)|0);
    $101 = ($100|0)==(1);
    if ($101) {
     __THREW__ = 0;
     invoke_viii(3262,($97|0),1,1);
     $102 = __THREW__; __THREW__ = 0;
     $103 = $102&1;
     if ($103) {
      label = 31;
      break;
     }
    }
   }
   $104 = $$sroa$029$0;
   __ZdlPv($104);
   $$sroa$029$1 = $90;
  }
  $107 = HEAP32[$25>>2]|0;
  $108 = ((($107)) + 12|0);
  $109 = HEAP32[$108>>2]|0;
  __THREW__ = 0;
  (invoke_ii($109|0,($25|0))|0);
  $110 = __THREW__; __THREW__ = 0;
  $111 = $110&1;
  if ($111) {
   label = 33;
   break;
  } else {
   $$sroa$029$0 = $$sroa$029$1;
  }
 }
 do {
  if ((label|0) == 5) {
   HEAP32[$10>>2] = $9;
   $19 = HEAP32[$0>>2]|0;
   $20 = ((($19)) + 12|0);
   $21 = HEAP32[$20>>2]|0;
   __THREW__ = 0;
   invoke_vi($21|0,($0|0));
   $22 = __THREW__; __THREW__ = 0;
   $23 = $22&1;
   if ($23) {
    $119 = ___cxa_find_matching_catch_2()|0;
    $120 = tempRet0;
    $$3 = $119;$$312 = $120;
    break;
   } else {
    $$pre$phiZ2D = $16;
    $121 = HEAP32[$$pre$phiZ2D>>2]|0;
    $122 = ($121|0)==(0);
    $123 = HEAP32[$2>>2]|0;
    $124 = ((($123)) + 12|0);
    $125 = HEAP32[$124>>2]|0;
    (FUNCTION_TABLE_ii[$125 & 8191]($2)|0);
    STACKTOP = sp;return ($122|0);
   }
  }
  else if ((label|0) == 10) {
   $43 = ___cxa_find_matching_catch_2()|0;
   $44 = tempRet0;
   $$3 = $43;$$312 = $44;
  }
  else if ((label|0) == 11) {
   $45 = ___cxa_find_matching_catch_2()|0;
   $46 = tempRet0;
   $$sink13$index = $45;$$sink13$index3 = $46;
   label = 34;
  }
  else if ((label|0) == 21) {
   $77 = ___cxa_find_matching_catch_2()|0;
   $78 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($1|0));
   $79 = __THREW__; __THREW__ = 0;
   $80 = $79&1;
   if ($80) {
    $81 = ___cxa_find_matching_catch_3(0|0)|0;
    $82 = tempRet0;
    ___clang_call_terminate($81);
    // unreachable;
   } else {
    $$sink13$index = $77;$$sink13$index3 = $78;
    label = 34;
    break;
   }
  }
  else if ((label|0) == 31) {
   $105 = ___cxa_find_matching_catch_2()|0;
   $106 = tempRet0;
   $$sink13$index = $105;$$sink13$index3 = $106;
   label = 34;
  }
  else if ((label|0) == 33) {
   $112 = ___cxa_find_matching_catch_2()|0;
   $113 = tempRet0;
   $$3 = $112;$$312 = $113;
  }
 } while(0);
 if ((label|0) == 34) {
  $114 = HEAP32[$25>>2]|0;
  $115 = ((($114)) + 12|0);
  $116 = HEAP32[$115>>2]|0;
  __THREW__ = 0;
  (invoke_ii($116|0,($25|0))|0);
  $117 = __THREW__; __THREW__ = 0;
  $118 = $117&1;
  if ($118) {
   $131 = ___cxa_find_matching_catch_3(0|0)|0;
   $132 = tempRet0;
   ___clang_call_terminate($131);
   // unreachable;
  } else {
   $$3 = $$sink13$index;$$312 = $$sink13$index3;
  }
 }
 $126 = HEAP32[$2>>2]|0;
 $127 = ((($126)) + 12|0);
 $128 = HEAP32[$127>>2]|0;
 __THREW__ = 0;
 (invoke_ii($128|0,($2|0))|0);
 $129 = __THREW__; __THREW__ = 0;
 $130 = $129&1;
 if ($130) {
  $131 = ___cxa_find_matching_catch_3(0|0)|0;
  $132 = tempRet0;
  ___clang_call_terminate($131);
  // unreachable;
 } else {
  ___resumeException($$3|0);
  // unreachable;
 }
 return (0)|0;
}
function __ZN5osgDB13DatabasePager14DatabaseThreadC2EPS0_NS1_4ModeERKNSt3__212basic_stringIcNS4_11char_traitsIcEENS4_9allocatorIcEEEE($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $$05 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg10ReferencedC2Ev($0);
 $4 = ((($0)) + 12|0);
 __THREW__ = 0;
 invoke_vi(3843,($4|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $14 = ___cxa_find_matching_catch_2()|0;
  $15 = tempRet0;
  $$0 = $15;$$05 = $14;
 } else {
  HEAP32[$0>>2] = (73048);
  HEAP32[$4>>2] = (73076);
  $7 = ((($0)) + 20|0);
  HEAP32[$7>>2] = 0;
  $8 = ((($0)) + 24|0);
  HEAP8[$8>>0] = 0;
  $9 = ((($0)) + 28|0);
  HEAP32[$9>>2] = $1;
  $10 = ((($0)) + 32|0);
  HEAP32[$10>>2] = $2;
  $11 = ((($0)) + 36|0);
  __THREW__ = 0;
  invoke_vii(3457,($11|0),($3|0));
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if (!($13)) {
   return;
  }
  $16 = ___cxa_find_matching_catch_2()|0;
  $17 = tempRet0;
  __THREW__ = 0;
  invoke_vi(2489,($4|0));
  $18 = __THREW__; __THREW__ = 0;
  $19 = $18&1;
  if ($19) {
   $22 = ___cxa_find_matching_catch_3(0|0)|0;
   $23 = tempRet0;
   ___clang_call_terminate($22);
   // unreachable;
  } else {
   $$0 = $17;$$05 = $16;
  }
 }
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if ($21) {
  $22 = ___cxa_find_matching_catch_3(0|0)|0;
  $23 = tempRet0;
  ___clang_call_terminate($22);
  // unreachable;
 } else {
  ___resumeException($$05|0);
  // unreachable;
 }
}
function __ZNSt3__26vectorIN3osg7ref_ptrIN5osgDB13DatabasePager14DatabaseThreadEEENS_9allocatorIS6_EEE21__push_back_slow_pathIKS6_EEvRT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$06$i$i = 0, $$pre = 0, $$pre$i = 0, $$pre38 = 0, $$pre39 = 0, $$sroa$7$0 = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(1073741823);
 $9 = $4;
 $10 = $3;
 if ($8) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $11 = ((($0)) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) - ($4))|0;
 $14 = $13 >> 2;
 $15 = ($14>>>0)<(536870911);
 $16 = $13 >> 1;
 $17 = ($16>>>0)<($7>>>0);
 $$sroa$speculated$i = $17 ? $7 : $16;
 $$sroa$speculated$$i = $15 ? $$sroa$speculated$i : 1073741823;
 $18 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($18) {
   $28 = 0;
  } else {
   $19 = ($$sroa$speculated$$i>>>0)>(1073741823);
   if (!($19)) {
    $25 = $$sroa$speculated$$i << 2;
    $26 = (__Znwj($25)|0);
    $28 = $26;
    break;
   }
   $20 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($20|0),(204840|0));
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if ($22) {
    $23 = ___cxa_find_matching_catch_2()|0;
    $24 = tempRet0;
    ___cxa_free_exception(($20|0));
    ___resumeException($23|0);
    // unreachable;
   } else {
    HEAP32[$20>>2] = (99824);
    ___cxa_throw(($20|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $27 = (($28) + ($6<<2)|0);
 $29 = $27;
 $30 = (($28) + ($$sroa$speculated$$i<<2)|0);
 $31 = $30;
 $32 = HEAP32[$1>>2]|0;
 HEAP32[$27>>2] = $32;
 $33 = ($32|0)==(0|0);
 if ($33) {
  $38 = $10;$40 = $9;
 } else {
  $34 = ((($32)) + 8|0);
  $35 = HEAP32[$34>>2]|0;HEAP32[$34>>2] = (($35+1)|0);
  $$pre = HEAP32[$0>>2]|0;
  $$pre38 = HEAP32[$2>>2]|0;
  $38 = $$pre38;$40 = $$pre;
 }
 $36 = ((($27)) + 4|0);
 $37 = $36;
 $39 = ($38|0)==($40|0);
 if ($39) {
  $41 = $38;
  $53 = $29;$54 = $41;$56 = $38;
 } else {
  $$06$i$i = $38;$$sroa$7$0 = $29;$44 = $27;
  while(1) {
   $42 = ((($$06$i$i)) + -4|0);
   $43 = ((($44)) + -4|0);
   $45 = HEAP32[$42>>2]|0;
   HEAP32[$43>>2] = $45;
   $46 = ($45|0)==(0|0);
   if (!($46)) {
    $47 = ((($45)) + 8|0);
    $48 = HEAP32[$47>>2]|0;HEAP32[$47>>2] = (($48+1)|0);
   }
   $49 = $$sroa$7$0;
   $50 = ((($49)) + -4|0);
   $51 = $50;
   $52 = ($42|0)==($40|0);
   if ($52) {
    break;
   } else {
    $$06$i$i = $42;$$sroa$7$0 = $51;$44 = $50;
   }
  }
  $$pre$i = HEAP32[$0>>2]|0;
  $$pre39 = HEAP32[$2>>2]|0;
  $53 = $51;$54 = $$pre$i;$56 = $$pre39;
 }
 HEAP32[$0>>2] = $53;
 HEAP32[$2>>2] = $37;
 HEAP32[$11>>2] = $31;
 $55 = $54;
 $57 = ($56|0)==($55|0);
 L25: do {
  if (!($57)) {
   $59 = $56;
   while(1) {
    $58 = ((($59)) + -4|0);
    $60 = HEAP32[$58>>2]|0;
    $61 = ($60|0)==(0|0);
    if (!($61)) {
     $62 = ((($60)) + 8|0);
     $63 = HEAP32[$62>>2]|0;HEAP32[$62>>2] = (($63-1)|0);
     $64 = ($63|0)==(1);
     if ($64) {
      __THREW__ = 0;
      invoke_viii(3262,($60|0),1,1);
      $65 = __THREW__; __THREW__ = 0;
      $66 = $65&1;
      if ($66) {
       break;
      }
     }
    }
    HEAP32[$58>>2] = 0;
    $67 = ($58|0)==($55|0);
    if ($67) {
     break L25;
    } else {
     $59 = $58;
    }
   }
   $68 = ___cxa_find_matching_catch_2()|0;
   $69 = tempRet0;
   ___cxa_call_unexpected(($68|0));
   // unreachable;
  }
 } while(0);
 $70 = ($54|0)==(0);
 if ($70) {
  return;
 }
 $71 = $54;
 __ZdlPv($71);
 return;
}
function __ZN5osgDB13DatabasePager12RequestQueue5clearEv($0) {
 $0 = $0|0;
 var $$023$i$i = 0, $$2 = 0, $$24 = 0, $$sroa$013$0 = 0, $$sroa$013$032 = 0, $$sroa$013$033 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 (FUNCTION_TABLE_ii[$4 & 8191]($1)|0);
 $5 = ((($0)) + 16|0);
 $6 = ((($0)) + 20|0);
 $$sroa$013$032 = HEAP32[$6>>2]|0;
 $7 = $$sroa$013$032;
 $8 = ($7|0)==($5|0);
 L1: do {
  if ($8) {
   label = 3;
  } else {
   $9 = ((($0)) + 12|0);
   $$sroa$013$033 = $$sroa$013$032;$62 = $7;
   while(1) {
    $44 = HEAP32[$9>>2]|0;
    $45 = ((($44)) + 24|0);
    $46 = HEAP32[$45>>2]|0;
    $47 = ((($46)) + 8|0);
    $48 = HEAP32[$47>>2]|0;
    __THREW__ = 0;
    (invoke_ii($48|0,($45|0))|0);
    $49 = __THREW__; __THREW__ = 0;
    $50 = $49&1;
    if ($50) {
     label = 15;
     break;
    }
    $51 = $$sroa$013$033;
    $52 = ((($51)) + 8|0);
    $53 = HEAP32[$52>>2]|0;
    __THREW__ = 0;
    invoke_vii(4117,($0|0),($53|0));
    $54 = __THREW__; __THREW__ = 0;
    $55 = $54&1;
    if ($55) {
     label = 16;
     break;
    }
    $56 = HEAP32[$45>>2]|0;
    $57 = ((($56)) + 12|0);
    $58 = HEAP32[$57>>2]|0;
    __THREW__ = 0;
    (invoke_ii($58|0,($45|0))|0);
    $59 = __THREW__; __THREW__ = 0;
    $60 = $59&1;
    if ($60) {
     label = 17;
     break;
    }
    $61 = ((($62)) + 4|0);
    $$sroa$013$0 = HEAP32[$61>>2]|0;
    $63 = $$sroa$013$0;
    $64 = ($63|0)==($5|0);
    if ($64) {
     label = 3;
     break L1;
    } else {
     $$sroa$013$033 = $$sroa$013$0;$62 = $63;
    }
   }
   if ((label|0) == 15) {
    $65 = ___cxa_find_matching_catch_2()|0;
    $66 = tempRet0;
    $$2 = $66;$$24 = $65;
    break;
   }
   else if ((label|0) == 16) {
    $67 = ___cxa_find_matching_catch_2()|0;
    $68 = tempRet0;
    $69 = HEAP32[$45>>2]|0;
    $70 = ((($69)) + 12|0);
    $71 = HEAP32[$70>>2]|0;
    __THREW__ = 0;
    (invoke_ii($71|0,($45|0))|0);
    $72 = __THREW__; __THREW__ = 0;
    $73 = $72&1;
    if (!($73)) {
     $$2 = $68;$$24 = $67;
     break;
    }
    $86 = ___cxa_find_matching_catch_3(0|0)|0;
    $87 = tempRet0;
    ___clang_call_terminate($86);
    // unreachable;
   }
   else if ((label|0) == 17) {
    $74 = ___cxa_find_matching_catch_2()|0;
    $75 = tempRet0;
    $$2 = $75;$$24 = $74;
    break;
   }
  }
 } while(0);
 do {
  if ((label|0) == 3) {
   $10 = ((($0)) + 24|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = ($11|0)==(0);
   L15: do {
    if (!($12)) {
     $13 = HEAP32[$6>>2]|0;
     $14 = HEAP32[$5>>2]|0;
     $15 = ((($14)) + 4|0);
     $16 = HEAP32[$15>>2]|0;
     $17 = HEAP32[$13>>2]|0;
     $18 = ((($17)) + 4|0);
     HEAP32[$18>>2] = $16;
     $19 = HEAP32[$15>>2]|0;
     HEAP32[$19>>2] = $17;
     HEAP32[$10>>2] = 0;
     $20 = ($13|0)==($5|0);
     if (!($20)) {
      $$023$i$i = $13;
      while(1) {
       $21 = ((($$023$i$i)) + 4|0);
       $22 = HEAP32[$21>>2]|0;
       $23 = ((($$023$i$i)) + 8|0);
       $24 = HEAP32[$23>>2]|0;
       $25 = ($24|0)==(0|0);
       if (!($25)) {
        $26 = ((($24)) + 8|0);
        $27 = HEAP32[$26>>2]|0;HEAP32[$26>>2] = (($27-1)|0);
        $28 = ($27|0)==(1);
        if ($28) {
         __THREW__ = 0;
         invoke_viii(3262,($24|0),1,1);
         $29 = __THREW__; __THREW__ = 0;
         $30 = $29&1;
         if ($30) {
          break;
         }
        }
       }
       __ZdlPv($$023$i$i);
       $31 = ($22|0)==($5|0);
       if ($31) {
        break L15;
       } else {
        $$023$i$i = $22;
       }
      }
      $32 = ___cxa_find_matching_catch_2()|0;
      $33 = tempRet0;
      ___cxa_call_unexpected(($32|0));
      // unreachable;
     }
    }
   } while(0);
   $34 = ((($0)) + 12|0);
   $35 = HEAP32[$34>>2]|0;
   /* fence */;
   $36 = ((($35)) + 84|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = ((($0)) + 40|0);
   HEAP32[$38>>2] = $37;
   $39 = HEAP32[$0>>2]|0;
   $40 = ((($39)) + 12|0);
   $41 = HEAP32[$40>>2]|0;
   __THREW__ = 0;
   invoke_vi($41|0,($0|0));
   $42 = __THREW__; __THREW__ = 0;
   $43 = $42&1;
   if ($43) {
    $79 = ___cxa_find_matching_catch_2()|0;
    $80 = tempRet0;
    $$2 = $80;$$24 = $79;
    break;
   } else {
    $76 = HEAP32[$1>>2]|0;
    $77 = ((($76)) + 12|0);
    $78 = HEAP32[$77>>2]|0;
    (FUNCTION_TABLE_ii[$78 & 8191]($1)|0);
    return;
   }
  }
 } while(0);
 $81 = HEAP32[$1>>2]|0;
 $82 = ((($81)) + 12|0);
 $83 = HEAP32[$82>>2]|0;
 __THREW__ = 0;
 (invoke_ii($83|0,($1|0))|0);
 $84 = __THREW__; __THREW__ = 0;
 $85 = $84&1;
 if ($85) {
  $86 = ___cxa_find_matching_catch_3(0|0)|0;
  $87 = tempRet0;
  ___clang_call_terminate($86);
  // unreachable;
 } else {
  ___resumeException($$24|0);
  // unreachable;
 }
}
function __ZN5osgDB13DatabasePagerC2ERKS0_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$017 = 0, $$01970 = 0, $$02169 = 0, $$12072 = 0, $$12271 = 0, $$2 = 0, $$223 = 0, $$3 = 0, $$324 = 0, $$4 = 0, $$425 = 0, $$7 = 0, $$728 = 0, $$8 = 0, $$829 = 0, $$pre$i = 0, $$pre$i59 = 0, $$sroa$064$078 = 0, $10 = 0;
 var $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0;
 var $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0;
 var $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0;
 var $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0;
 var $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0;
 var $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0;
 var $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0;
 var $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0;
 var $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0;
 var $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0;
 var $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0;
 var $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0;
 var $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0;
 var $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0;
 var $353 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $2 = sp + 16|0;
 $3 = sp + 4|0;
 $4 = sp;
 __ZN3osg10ReferencedC2Eb($0,1);
 HEAP32[$0>>2] = (73684);
 $5 = ((($0)) + 12|0);
 __THREW__ = 0;
 invoke_vii(3507,($5|0),0);
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if ($7) {
  $175 = ___cxa_find_matching_catch_2()|0;
  $176 = tempRet0;
  $$8 = $176;$$829 = $175;
 } else {
  $8 = ((($0)) + 24|0);
  __THREW__ = 0;
  invoke_vii(3507,($8|0),0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if ($10) {
   $177 = ___cxa_find_matching_catch_2()|0;
   $178 = tempRet0;
   $$7 = $178;$$728 = $177;
  } else {
   $11 = ((($0)) + 40|0);
   $12 = ((($0)) + 44|0);
   HEAP32[$12>>2] = 0;
   $13 = ((($0)) + 48|0);
   HEAP32[$13>>2] = 0;
   $14 = ((($0)) + 44|0);
   HEAP32[$11>>2] = $14;
   $15 = ((($0)) + 56|0);
   HEAP32[$15>>2] = 0;
   $16 = ((($0)) + 60|0);
   HEAP32[$16>>2] = 0;
   $17 = ((($0)) + 64|0);
   HEAP32[$17>>2] = 0;
   $18 = ((($0)) + 72|0);
   __THREW__ = 0;
   invoke_vii(3507,($18|0),0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if ($20) {
    $179 = ___cxa_find_matching_catch_2()|0;
    $180 = tempRet0;
    $$4 = $180;$$425 = $179;
   } else {
    $21 = ((($0)) + 84|0);
    HEAP32[$21>>2] = 0;
    $22 = ((($0)) + 88|0);
    $23 = ((($0)) + 92|0);
    $24 = ((($0)) + 96|0);
    $25 = ((($0)) + 100|0);
    $26 = ((($0)) + 120|0);
    HEAP32[$26>>2] = 0;
    $27 = ((($0)) + 132|0);
    HEAP32[$27>>2] = 0;
    $28 = ((($0)) + 164|0);
    HEAP32[$28>>2] = 0;
    ;HEAP32[$22>>2]=0|0;HEAP32[$22+4>>2]=0|0;HEAP32[$22+8>>2]=0|0;HEAP32[$22+12>>2]=0|0;
    __THREW__ = 0;
    $29 = (invoke_ii(3276,32)|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    L10: do {
     if ($31) {
      label = 47;
     } else {
      __THREW__ = 0;
      invoke_vi(3282,($29|0));
      $32 = __THREW__; __THREW__ = 0;
      $33 = $32&1;
      if ($33) {
       $183 = ___cxa_find_matching_catch_2()|0;
       $184 = tempRet0;
       __ZdlPv($29);
       $$3 = $184;$$324 = $183;
       break;
      }
      $34 = ((($29)) + 12|0);
      ;HEAP32[$34>>2]=0|0;HEAP32[$34+4>>2]=0|0;HEAP32[$34+8>>2]=0|0;
      $35 = ((($29)) + 24|0);
      HEAP32[$35>>2] = 2;
      $36 = ((($29)) + 28|0);
      HEAP32[$36>>2] = 0;
      HEAP32[$29>>2] = (48340);
      $37 = HEAP32[$28>>2]|0;
      $38 = ($37|0)==($29|0);
      if (!($38)) {
       HEAP32[$28>>2] = $29;
       $39 = ((($29)) + 8|0);
       $40 = HEAP32[$39>>2]|0;HEAP32[$39>>2] = (($40+1)|0);
       $41 = ($37|0)==(0|0);
       if (!($41)) {
        $42 = ((($37)) + 8|0);
        $43 = HEAP32[$42>>2]|0;HEAP32[$42>>2] = (($43-1)|0);
        $44 = ($43|0)==(1);
        if ($44) {
         __THREW__ = 0;
         invoke_viii(3262,($37|0),1,1);
         $45 = __THREW__; __THREW__ = 0;
         $46 = $45&1;
         if ($46) {
          label = 47;
          break;
         }
        }
       }
      }
      $47 = HEAP32[$28>>2]|0;
      __THREW__ = 0;
      invoke_vii(3337,($47|0),(163901|0));
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 47;
      } else {
       $50 = ((($0)) + 36|0);
       HEAP8[$50>>0] = 0;
       $51 = ((($0)) + 52|0);
       HEAP8[$51>>0] = 0;
       $52 = ((($0)) + 53|0);
       HEAP8[$52>>0] = 1;
       $53 = ((($0)) + 54|0);
       HEAP8[$53>>0] = 0;
       $54 = ((($0)) + 68|0);
       HEAP32[$54>>2] = 0;
       $55 = HEAP32[$21>>2]|0;HEAP32[$21>>2] = 0;
       $56 = ((($1)) + 104|0);
       $57 = HEAP32[$56>>2]|0;
       $58 = ((($0)) + 104|0);
       HEAP32[$58>>2] = $57;
       $59 = ((($1)) + 108|0);
       $60 = HEAP8[$59>>0]|0;
       $61 = ((($0)) + 108|0);
       HEAP8[$61>>0] = $60;
       $62 = ((($1)) + 109|0);
       $63 = HEAP8[$62>>0]|0;
       $64 = ((($0)) + 109|0);
       HEAP8[$64>>0] = $63;
       $65 = ((($1)) + 110|0);
       $66 = HEAP8[$65>>0]|0;
       $67 = ((($0)) + 110|0);
       HEAP8[$67>>0] = $66;
       $68 = ((($1)) + 111|0);
       $69 = HEAP8[$68>>0]|0;
       $70 = ((($0)) + 111|0);
       HEAP8[$70>>0] = $69;
       $71 = ((($1)) + 112|0);
       $72 = HEAP32[$71>>2]|0;
       $73 = ((($0)) + 112|0);
       HEAP32[$73>>2] = $72;
       $74 = ((($1)) + 116|0);
       $75 = HEAP8[$74>>0]|0;
       $76 = ((($0)) + 116|0);
       HEAP8[$76>>0] = $75;
       $77 = ((($1)) + 124|0);
       $78 = HEAP32[$77>>2]|0;
       $79 = ((($0)) + 124|0);
       HEAP32[$79>>2] = $78;
       $80 = ((($1)) + 128|0);
       $81 = HEAP8[$80>>0]|0;
       $82 = ((($0)) + 128|0);
       HEAP8[$82>>0] = $81;
       __THREW__ = 0;
       $83 = (invoke_ii(3276,84)|0);
       $84 = __THREW__; __THREW__ = 0;
       $85 = $84&1;
       if ($85) {
        label = 47;
       } else {
        ;HEAP32[$2>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;
        __THREW__ = 0;
        $86 = (invoke_ii(3276,32)|0);
        $87 = __THREW__; __THREW__ = 0;
        $88 = $87&1;
        do {
         if ($88) {
          $185 = ___cxa_find_matching_catch_2()|0;
          $186 = tempRet0;
          $$01970 = $186;$$02169 = $185;
         } else {
          HEAP32[$2>>2] = $86;
          $89 = ((($2)) + 8|0);
          HEAP32[$89>>2] = -2147483616;
          $90 = ((($2)) + 4|0);
          HEAP32[$90>>2] = 16;
          dest=$86; src=163940; stop=dest+16|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
          $91 = ((($86)) + 16|0);
          HEAP8[$91>>0] = 0;
          __THREW__ = 0;
          invoke_viii(4142,($83|0),($0|0),($2|0));
          $92 = __THREW__; __THREW__ = 0;
          $93 = $92&1;
          do {
           if ($93) {
            $$017 = 1;
           } else {
            $94 = HEAP32[$22>>2]|0;
            $95 = ($94|0)==($83|0);
            if (!($95)) {
             HEAP32[$22>>2] = $83;
             $96 = ((($83)) + 8|0);
             $97 = HEAP32[$96>>2]|0;HEAP32[$96>>2] = (($97+1)|0);
             $98 = ($94|0)==(0|0);
             if (!($98)) {
              $99 = ((($94)) + 8|0);
              $100 = HEAP32[$99>>2]|0;HEAP32[$99>>2] = (($100-1)|0);
              $101 = ($100|0)==(1);
              if ($101) {
               __THREW__ = 0;
               invoke_viii(3262,($94|0),1,1);
               $102 = __THREW__; __THREW__ = 0;
               $103 = $102&1;
               if ($103) {
                $$017 = 0;
                break;
               }
              }
             }
            }
            $104 = ((($2)) + 11|0);
            $105 = HEAP8[$104>>0]|0;
            $106 = ($105<<24>>24)<(0);
            if ($106) {
             $107 = HEAP32[$2>>2]|0;
             __ZdlPv($107);
            }
            __THREW__ = 0;
            $108 = (invoke_ii(3276,84)|0);
            $109 = __THREW__; __THREW__ = 0;
            $110 = $109&1;
            if ($110) {
             label = 47;
             break L10;
            }
            ;HEAP32[$3>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;
            __THREW__ = 0;
            $111 = (invoke_ii(3276,32)|0);
            $112 = __THREW__; __THREW__ = 0;
            $113 = $112&1;
            do {
             if ($113) {
              $193 = ___cxa_find_matching_catch_2()|0;
              $194 = tempRet0;
              $$12072 = $194;$$12271 = $193;
             } else {
              HEAP32[$3>>2] = $111;
              $114 = ((($3)) + 8|0);
              HEAP32[$114>>2] = -2147483616;
              $115 = ((($3)) + 4|0);
              HEAP32[$115>>2] = 16;
              dest=$111; src=163957; stop=dest+16|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
              $116 = ((($111)) + 16|0);
              HEAP8[$116>>0] = 0;
              __THREW__ = 0;
              invoke_viii(4142,($108|0),($0|0),($3|0));
              $117 = __THREW__; __THREW__ = 0;
              $118 = $117&1;
              L39: do {
               if ($118) {
                $$0 = 1;
               } else {
                $119 = HEAP32[$23>>2]|0;
                $120 = ($119|0)==($108|0);
                do {
                 if (!($120)) {
                  HEAP32[$23>>2] = $108;
                  $121 = ((($108)) + 8|0);
                  $122 = HEAP32[$121>>2]|0;HEAP32[$121>>2] = (($122+1)|0);
                  $123 = ($119|0)==(0|0);
                  if ($123) {
                   break;
                  }
                  $124 = ((($119)) + 8|0);
                  $125 = HEAP32[$124>>2]|0;HEAP32[$124>>2] = (($125-1)|0);
                  $126 = ($125|0)==(1);
                  if (!($126)) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_viii(3262,($119|0),1,1);
                  $127 = __THREW__; __THREW__ = 0;
                  $128 = $127&1;
                  if ($128) {
                   $$0 = 0;
                   break L39;
                  }
                 }
                } while(0);
                $129 = ((($3)) + 11|0);
                $130 = HEAP8[$129>>0]|0;
                $131 = ($130<<24>>24)<(0);
                if ($131) {
                 $132 = HEAP32[$3>>2]|0;
                 __ZdlPv($132);
                }
                __THREW__ = 0;
                $133 = (invoke_ii(3276,44)|0);
                $134 = __THREW__; __THREW__ = 0;
                $135 = $134&1;
                if ($135) {
                 label = 47;
                 break L10;
                }
                __THREW__ = 0;
                invoke_vii(4143,($133|0),($0|0));
                $136 = __THREW__; __THREW__ = 0;
                $137 = $136&1;
                if ($137) {
                 $201 = ___cxa_find_matching_catch_2()|0;
                 $202 = tempRet0;
                 __ZdlPv($133);
                 $$3 = $202;$$324 = $201;
                 break L10;
                }
                $138 = HEAP32[$24>>2]|0;
                $139 = ($138|0)==($133|0);
                do {
                 if (!($139)) {
                  HEAP32[$24>>2] = $133;
                  $140 = ((($133)) + 8|0);
                  $141 = HEAP32[$140>>2]|0;HEAP32[$140>>2] = (($141+1)|0);
                  $142 = ($138|0)==(0|0);
                  if ($142) {
                   break;
                  }
                  $143 = ((($138)) + 8|0);
                  $144 = HEAP32[$143>>2]|0;HEAP32[$143>>2] = (($144-1)|0);
                  $145 = ($144|0)==(1);
                  if (!($145)) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_viii(3262,($138|0),1,1);
                  $146 = __THREW__; __THREW__ = 0;
                  $147 = $146&1;
                  if ($147) {
                   label = 47;
                   break L10;
                  }
                 }
                } while(0);
                __THREW__ = 0;
                $148 = (invoke_ii(3276,44)|0);
                $149 = __THREW__; __THREW__ = 0;
                $150 = $149&1;
                if ($150) {
                 label = 47;
                 break L10;
                }
                __THREW__ = 0;
                invoke_vii(4143,($148|0),($0|0));
                $151 = __THREW__; __THREW__ = 0;
                $152 = $151&1;
                if ($152) {
                 $203 = ___cxa_find_matching_catch_2()|0;
                 $204 = tempRet0;
                 __ZdlPv($148);
                 $$3 = $204;$$324 = $203;
                 break L10;
                }
                $153 = HEAP32[$25>>2]|0;
                $154 = ($153|0)==($148|0);
                do {
                 if (!($154)) {
                  HEAP32[$25>>2] = $148;
                  $155 = ((($148)) + 8|0);
                  $156 = HEAP32[$155>>2]|0;HEAP32[$155>>2] = (($156+1)|0);
                  $157 = ($153|0)==(0|0);
                  if ($157) {
                   break;
                  }
                  $158 = ((($153)) + 8|0);
                  $159 = HEAP32[$158>>2]|0;HEAP32[$158>>2] = (($159-1)|0);
                  $160 = ($159|0)==(1);
                  if (!($160)) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_viii(3262,($153|0),1,1);
                  $161 = __THREW__; __THREW__ = 0;
                  $162 = $161&1;
                  if ($162) {
                   label = 47;
                   break L10;
                  }
                 }
                } while(0);
                $163 = ((($1)) + 56|0);
                $164 = HEAP32[$163>>2]|0;
                $165 = ((($1)) + 60|0);
                $166 = HEAP32[$165>>2]|0;
                $167 = ($164|0)==($166|0);
                L67: do {
                 if (!($167)) {
                  $168 = ((($0)) + 64|0);
                  $$sroa$064$078 = $164;
                  L69: while(1) {
                   __THREW__ = 0;
                   $205 = (invoke_ii(3276,48)|0);
                   $206 = __THREW__; __THREW__ = 0;
                   $207 = $206&1;
                   if ($207) {
                    label = 72;
                    break;
                   }
                   $208 = HEAP32[$$sroa$064$078>>2]|0;
                   __THREW__ = 0;
                   invoke_viii(4144,($205|0),($208|0),($0|0));
                   $209 = __THREW__; __THREW__ = 0;
                   $210 = $209&1;
                   if ($210) {
                    label = 73;
                    break;
                   }
                   HEAP32[$4>>2] = $205;
                   $211 = ((($205)) + 8|0);
                   $212 = HEAP32[$211>>2]|0;HEAP32[$211>>2] = (($212+1)|0);
                   $213 = HEAP32[$16>>2]|0;
                   $214 = HEAP32[$168>>2]|0;
                   $215 = ($213|0)==($214|0);
                   if ($215) {
                    __THREW__ = 0;
                    invoke_vii(4138,($15|0),($4|0));
                    $222 = __THREW__; __THREW__ = 0;
                    $223 = $222&1;
                    if ($223) {
                     label = 74;
                     break;
                    }
                   } else {
                    $216 = HEAP32[$4>>2]|0;
                    HEAP32[$213>>2] = $216;
                    $217 = ($216|0)==(0|0);
                    if ($217) {
                     $221 = $213;
                    } else {
                     $218 = ((($216)) + 8|0);
                     $219 = HEAP32[$218>>2]|0;HEAP32[$218>>2] = (($219+1)|0);
                     $$pre$i59 = HEAP32[$16>>2]|0;
                     $221 = $$pre$i59;
                    }
                    $220 = ((($221)) + 4|0);
                    HEAP32[$16>>2] = $220;
                   }
                   $224 = HEAP32[$4>>2]|0;
                   $225 = ($224|0)==(0|0);
                   do {
                    if (!($225)) {
                     $226 = ((($224)) + 8|0);
                     $227 = HEAP32[$226>>2]|0;HEAP32[$226>>2] = (($227-1)|0);
                     $228 = ($227|0)==(1);
                     if (!($228)) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_viii(3262,($224|0),1,1);
                     $229 = __THREW__; __THREW__ = 0;
                     $230 = $229&1;
                     if ($230) {
                      label = 72;
                      break L69;
                     }
                    }
                   } while(0);
                   $231 = ((($$sroa$064$078)) + 4|0);
                   $232 = HEAP32[$165>>2]|0;
                   $233 = ($231|0)==($232|0);
                   if ($233) {
                    break L67;
                   } else {
                    $$sroa$064$078 = $231;
                   }
                  }
                  if ((label|0) == 72) {
                   $234 = ___cxa_find_matching_catch_2()|0;
                   $235 = tempRet0;
                   $$2 = $235;$$223 = $234;
                  }
                  else if ((label|0) == 73) {
                   $236 = ___cxa_find_matching_catch_2()|0;
                   $237 = tempRet0;
                   __ZdlPv($205);
                   $$2 = $237;$$223 = $236;
                  }
                  else if ((label|0) == 74) {
                   $238 = ___cxa_find_matching_catch_2()|0;
                   $239 = tempRet0;
                   $240 = HEAP32[$4>>2]|0;
                   $241 = ($240|0)==(0|0);
                   do {
                    if (!($241)) {
                     $242 = ((($240)) + 8|0);
                     $243 = HEAP32[$242>>2]|0;HEAP32[$242>>2] = (($243-1)|0);
                     $244 = ($243|0)==(1);
                     if (!($244)) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_viii(3262,($240|0),1,1);
                     $245 = __THREW__; __THREW__ = 0;
                     $246 = $245&1;
                     if (!($246)) {
                      break;
                     }
                     $352 = ___cxa_find_matching_catch_3(0|0)|0;
                     $353 = tempRet0;
                     ___clang_call_terminate($352);
                     // unreachable;
                    }
                   } while(0);
                   HEAP32[$4>>2] = 0;
                   $$2 = $239;$$223 = $238;
                  }
                  $$3 = $$2;$$324 = $$223;
                  break L10;
                 }
                } while(0);
                $169 = HEAP32[$0>>2]|0;
                $170 = ((($169)) + 36|0);
                $171 = HEAP32[$170>>2]|0;
                $172 = ((($1)) + 40|0);
                __THREW__ = 0;
                invoke_vii($171|0,($0|0),($172|0));
                $173 = __THREW__; __THREW__ = 0;
                $174 = $173&1;
                if ($174) {
                 label = 47;
                 break L10;
                }
                $247 = ((($1)) + 120|0);
                $248 = HEAP32[$247>>2]|0;
                $249 = HEAP32[$248>>2]|0;
                $250 = ((($249)) + 12|0);
                $251 = HEAP32[$250>>2]|0;
                __THREW__ = 0;
                $252 = (invoke_ii($251|0,($248|0))|0);
                $253 = __THREW__; __THREW__ = 0;
                $254 = $253&1;
                if ($254) {
                 label = 47;
                 break L10;
                }
                $255 = HEAP32[$26>>2]|0;
                $256 = ($255|0)==($252|0);
                do {
                 if (!($256)) {
                  HEAP32[$26>>2] = $252;
                  $257 = ($252|0)==(0|0);
                  if (!($257)) {
                   $258 = ((($252)) + 8|0);
                   $259 = HEAP32[$258>>2]|0;HEAP32[$258>>2] = (($259+1)|0);
                  }
                  $260 = ($255|0)==(0|0);
                  if ($260) {
                   break;
                  }
                  $261 = ((($255)) + 8|0);
                  $262 = HEAP32[$261>>2]|0;HEAP32[$261>>2] = (($262-1)|0);
                  $263 = ($262|0)==(1);
                  if (!($263)) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_viii(3262,($255|0),1,1);
                  $264 = __THREW__; __THREW__ = 0;
                  $265 = $264&1;
                  if ($265) {
                   label = 47;
                   break L10;
                  }
                 }
                } while(0);
                __THREW__ = 0;
                invoke_vi(4145,100);
                $266 = __THREW__; __THREW__ = 0;
                $267 = $266&1;
                if ($267) {
                 label = 47;
                 break L10;
                }
                $268 = ((($0)) + 136|0);
                HEAPF64[$268>>3] = 1.7976931348623157E+308;
                $269 = ((($0)) + 144|0);
                HEAPF64[$269>>3] = -1.7976931348623157E+308;
                $270 = ((($0)) + 152|0);
                HEAPF64[$270>>3] = 0.0;
                $271 = ((($0)) + 160|0);
                HEAP32[$271>>2] = 0;
                STACKTOP = sp;return;
               }
              } while(0);
              $195 = ___cxa_find_matching_catch_2()|0;
              $196 = tempRet0;
              $197 = ((($3)) + 11|0);
              $198 = HEAP8[$197>>0]|0;
              $199 = ($198<<24>>24)<(0);
              if ($199) {
               $200 = HEAP32[$3>>2]|0;
               __ZdlPv($200);
               if ($$0) {
                $$12072 = $196;$$12271 = $195;
                break;
               } else {
                $$3 = $196;$$324 = $195;
                break L10;
               }
              } else {
               if ($$0) {
                $$12072 = $196;$$12271 = $195;
                break;
               } else {
                $$3 = $196;$$324 = $195;
                break L10;
               }
              }
             }
            } while(0);
            __ZdlPv($108);
            $$3 = $$12072;$$324 = $$12271;
            break L10;
           }
          } while(0);
          $187 = ___cxa_find_matching_catch_2()|0;
          $188 = tempRet0;
          $189 = ((($2)) + 11|0);
          $190 = HEAP8[$189>>0]|0;
          $191 = ($190<<24>>24)<(0);
          if ($191) {
           $192 = HEAP32[$2>>2]|0;
           __ZdlPv($192);
           if ($$017) {
            $$01970 = $188;$$02169 = $187;
            break;
           } else {
            $$3 = $188;$$324 = $187;
            break L10;
           }
          } else {
           if ($$017) {
            $$01970 = $188;$$02169 = $187;
            break;
           } else {
            $$3 = $188;$$324 = $187;
            break L10;
           }
          }
         }
        } while(0);
        __ZdlPv($83);
        $$3 = $$01970;$$324 = $$02169;
       }
      }
     }
    } while(0);
    if ((label|0) == 47) {
     $181 = ___cxa_find_matching_catch_2()|0;
     $182 = tempRet0;
     $$3 = $182;$$324 = $181;
    }
    $272 = HEAP32[$28>>2]|0;
    $273 = ($272|0)==(0|0);
    if (!($273)) {
     $274 = ((($272)) + 8|0);
     $275 = HEAP32[$274>>2]|0;HEAP32[$274>>2] = (($275-1)|0);
     $276 = ($275|0)==(1);
     if ($276) {
      __THREW__ = 0;
      invoke_viii(3262,($272|0),1,1);
      $277 = __THREW__; __THREW__ = 0;
      $278 = $277&1;
      if ($278) {
       $352 = ___cxa_find_matching_catch_3(0|0)|0;
       $353 = tempRet0;
       ___clang_call_terminate($352);
       // unreachable;
      }
     }
    }
    HEAP32[$28>>2] = 0;
    $279 = HEAP32[$27>>2]|0;
    $280 = ($279|0)==(0|0);
    if (!($280)) {
     $281 = HEAP32[$279>>2]|0;
     $282 = ((($281)) + -12|0);
     $283 = HEAP32[$282>>2]|0;
     $284 = (($279) + ($283)|0);
     $285 = ((($284)) + 8|0);
     $286 = HEAP32[$285>>2]|0;HEAP32[$285>>2] = (($286-1)|0);
     $287 = ($286|0)==(1);
     if ($287) {
      __THREW__ = 0;
      invoke_viii(3262,($284|0),1,1);
      $288 = __THREW__; __THREW__ = 0;
      $289 = $288&1;
      if ($289) {
       $352 = ___cxa_find_matching_catch_3(0|0)|0;
       $353 = tempRet0;
       ___clang_call_terminate($352);
       // unreachable;
      }
     }
    }
    HEAP32[$27>>2] = 0;
    $290 = HEAP32[$26>>2]|0;
    $291 = ($290|0)==(0|0);
    if (!($291)) {
     $292 = ((($290)) + 8|0);
     $293 = HEAP32[$292>>2]|0;HEAP32[$292>>2] = (($293-1)|0);
     $294 = ($293|0)==(1);
     if ($294) {
      __THREW__ = 0;
      invoke_viii(3262,($290|0),1,1);
      $295 = __THREW__; __THREW__ = 0;
      $296 = $295&1;
      if ($296) {
       $352 = ___cxa_find_matching_catch_3(0|0)|0;
       $353 = tempRet0;
       ___clang_call_terminate($352);
       // unreachable;
      }
     }
    }
    HEAP32[$26>>2] = 0;
    $297 = HEAP32[$25>>2]|0;
    $298 = ($297|0)==(0|0);
    if (!($298)) {
     $299 = ((($297)) + 8|0);
     $300 = HEAP32[$299>>2]|0;HEAP32[$299>>2] = (($300-1)|0);
     $301 = ($300|0)==(1);
     if ($301) {
      __THREW__ = 0;
      invoke_viii(3262,($297|0),1,1);
      $302 = __THREW__; __THREW__ = 0;
      $303 = $302&1;
      if ($303) {
       $352 = ___cxa_find_matching_catch_3(0|0)|0;
       $353 = tempRet0;
       ___clang_call_terminate($352);
       // unreachable;
      }
     }
    }
    HEAP32[$25>>2] = 0;
    $304 = HEAP32[$24>>2]|0;
    $305 = ($304|0)==(0|0);
    if (!($305)) {
     $306 = ((($304)) + 8|0);
     $307 = HEAP32[$306>>2]|0;HEAP32[$306>>2] = (($307-1)|0);
     $308 = ($307|0)==(1);
     if ($308) {
      __THREW__ = 0;
      invoke_viii(3262,($304|0),1,1);
      $309 = __THREW__; __THREW__ = 0;
      $310 = $309&1;
      if ($310) {
       $352 = ___cxa_find_matching_catch_3(0|0)|0;
       $353 = tempRet0;
       ___clang_call_terminate($352);
       // unreachable;
      }
     }
    }
    HEAP32[$24>>2] = 0;
    $311 = HEAP32[$23>>2]|0;
    $312 = ($311|0)==(0|0);
    if (!($312)) {
     $313 = ((($311)) + 8|0);
     $314 = HEAP32[$313>>2]|0;HEAP32[$313>>2] = (($314-1)|0);
     $315 = ($314|0)==(1);
     if ($315) {
      __THREW__ = 0;
      invoke_viii(3262,($311|0),1,1);
      $316 = __THREW__; __THREW__ = 0;
      $317 = $316&1;
      if ($317) {
       $352 = ___cxa_find_matching_catch_3(0|0)|0;
       $353 = tempRet0;
       ___clang_call_terminate($352);
       // unreachable;
      }
     }
    }
    HEAP32[$23>>2] = 0;
    $318 = HEAP32[$22>>2]|0;
    $319 = ($318|0)==(0|0);
    if (!($319)) {
     $320 = ((($318)) + 8|0);
     $321 = HEAP32[$320>>2]|0;HEAP32[$320>>2] = (($321-1)|0);
     $322 = ($321|0)==(1);
     if ($322) {
      __THREW__ = 0;
      invoke_viii(3262,($318|0),1,1);
      $323 = __THREW__; __THREW__ = 0;
      $324 = $323&1;
      if ($324) {
       $352 = ___cxa_find_matching_catch_3(0|0)|0;
       $353 = tempRet0;
       ___clang_call_terminate($352);
       // unreachable;
      }
     }
    }
    HEAP32[$22>>2] = 0;
    __THREW__ = 0;
    invoke_vi(707,($18|0));
    $325 = __THREW__; __THREW__ = 0;
    $326 = $325&1;
    if ($326) {
     $352 = ___cxa_find_matching_catch_3(0|0)|0;
     $353 = tempRet0;
     ___clang_call_terminate($352);
     // unreachable;
    } else {
     $$4 = $$3;$$425 = $$324;
    }
   }
   $327 = HEAP32[$15>>2]|0;
   $328 = ($327|0)==(0|0);
   if (!($328)) {
    $329 = HEAP32[$16>>2]|0;
    $330 = ($329|0)==($327|0);
    do {
     if ($330) {
      $344 = $327;
     } else {
      $332 = $329;
      while(1) {
       $331 = ((($332)) + -4|0);
       HEAP32[$16>>2] = $331;
       $333 = HEAP32[$331>>2]|0;
       $334 = ($333|0)==(0|0);
       if (!($334)) {
        $335 = ((($333)) + 8|0);
        $336 = HEAP32[$335>>2]|0;HEAP32[$335>>2] = (($336-1)|0);
        $337 = ($336|0)==(1);
        if ($337) {
         __THREW__ = 0;
         invoke_viii(3262,($333|0),1,1);
         $338 = __THREW__; __THREW__ = 0;
         $339 = $338&1;
         if ($339) {
          label = 116;
          break;
         }
        }
       }
       HEAP32[$331>>2] = 0;
       $340 = HEAP32[$16>>2]|0;
       $341 = ($340|0)==($327|0);
       if ($341) {
        label = 117;
        break;
       } else {
        $332 = $340;
       }
      }
      if ((label|0) == 116) {
       $342 = ___cxa_find_matching_catch_2()|0;
       $343 = tempRet0;
       ___cxa_call_unexpected(($342|0));
       // unreachable;
      }
      else if ((label|0) == 117) {
       $$pre$i = HEAP32[$15>>2]|0;
       $344 = $$pre$i;
       break;
      }
     }
    } while(0);
    __ZdlPv($344);
   }
   $345 = HEAP32[$14>>2]|0;
   __ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEE7destroyEPNS_11__tree_nodeIjPvEE($11,$345);
   __THREW__ = 0;
   invoke_vi(707,($8|0));
   $346 = __THREW__; __THREW__ = 0;
   $347 = $346&1;
   if ($347) {
    $352 = ___cxa_find_matching_catch_3(0|0)|0;
    $353 = tempRet0;
    ___clang_call_terminate($352);
    // unreachable;
   } else {
    $$7 = $$4;$$728 = $$425;
   }
  }
  __THREW__ = 0;
  invoke_vi(707,($5|0));
  $348 = __THREW__; __THREW__ = 0;
  $349 = $348&1;
  if ($349) {
   $352 = ___cxa_find_matching_catch_3(0|0)|0;
   $353 = tempRet0;
   ___clang_call_terminate($352);
   // unreachable;
  } else {
   $$8 = $$7;$$829 = $$728;
  }
 }
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $350 = __THREW__; __THREW__ = 0;
 $351 = $350&1;
 if ($351) {
  $352 = ___cxa_find_matching_catch_3(0|0)|0;
  $353 = tempRet0;
  ___clang_call_terminate($352);
  // unreachable;
 } else {
  ___resumeException($$829|0);
  // unreachable;
 }
}
function __ZN5osgDB13DatabasePager9ReadQueueC2EPS0_RKNSt3__212basic_stringIcNS3_11char_traitsIcEENS3_9allocatorIcEEEE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$023$i$i = 0, $$04 = 0, $$2 = 0, $$26 = 0, $$3 = 0, $$37 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5osgDB13DatabasePager12RequestQueueC2EPS0_($0,$1);
 HEAP32[$0>>2] = (73024);
 $3 = ((($0)) + 44|0);
 HEAP32[$3>>2] = 0;
 $4 = ((($0)) + 48|0);
 __THREW__ = 0;
 invoke_vii(3457,($4|0),($2|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $36 = ___cxa_find_matching_catch_2()|0;
  $37 = tempRet0;
  $$3 = $37;$$37 = $36;
 } else {
  $7 = ((($0)) + 60|0);
  __THREW__ = 0;
  invoke_vii(3507,($7|0),0);
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if ($9) {
   $38 = ___cxa_find_matching_catch_2()|0;
   $39 = tempRet0;
   $$2 = $39;$$26 = $38;
  } else {
   $10 = ((($0)) + 72|0);
   HEAP32[$10>>2] = $10;
   $11 = ((($0)) + 76|0);
   HEAP32[$11>>2] = $10;
   $12 = ((($0)) + 80|0);
   HEAP32[$12>>2] = 0;
   __THREW__ = 0;
   $13 = (invoke_ii(3276,40)|0);
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   do {
    if ($15) {
     label = 12;
    } else {
     __THREW__ = 0;
     invoke_vi(3803,($13|0));
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      $42 = ___cxa_find_matching_catch_2()|0;
      $43 = tempRet0;
      __ZdlPv($13);
      $$0 = $43;$$04 = $42;
      break;
     }
     $18 = HEAP32[$3>>2]|0;
     $19 = ($18|0)==($13|0);
     if ($19) {
      return;
     }
     HEAP32[$3>>2] = $13;
     $20 = HEAP32[$13>>2]|0;
     $21 = ((($20)) + -12|0);
     $22 = HEAP32[$21>>2]|0;
     $23 = (($13) + ($22)|0);
     $24 = ((($23)) + 8|0);
     $25 = HEAP32[$24>>2]|0;HEAP32[$24>>2] = (($25+1)|0);
     $26 = ($18|0)==(0|0);
     if ($26) {
      return;
     }
     $27 = HEAP32[$18>>2]|0;
     $28 = ((($27)) + -12|0);
     $29 = HEAP32[$28>>2]|0;
     $30 = (($18) + ($29)|0);
     $31 = ((($30)) + 8|0);
     $32 = HEAP32[$31>>2]|0;HEAP32[$31>>2] = (($32-1)|0);
     $33 = ($32|0)==(1);
     if (!($33)) {
      return;
     }
     __THREW__ = 0;
     invoke_viii(3262,($30|0),1,1);
     $34 = __THREW__; __THREW__ = 0;
     $35 = $34&1;
     if ($35) {
      label = 12;
     } else {
      return;
     }
    }
   } while(0);
   if ((label|0) == 12) {
    $40 = ___cxa_find_matching_catch_2()|0;
    $41 = tempRet0;
    $$0 = $41;$$04 = $40;
   }
   $44 = HEAP32[$12>>2]|0;
   $45 = ($44|0)==(0);
   L25: do {
    if (!($45)) {
     $46 = HEAP32[$11>>2]|0;
     $47 = HEAP32[$10>>2]|0;
     $48 = ((($47)) + 4|0);
     $49 = HEAP32[$48>>2]|0;
     $50 = HEAP32[$46>>2]|0;
     $51 = ((($50)) + 4|0);
     HEAP32[$51>>2] = $49;
     $52 = HEAP32[$48>>2]|0;
     HEAP32[$52>>2] = $50;
     HEAP32[$12>>2] = 0;
     $53 = ($46|0)==($10|0);
     if (!($53)) {
      $$023$i$i = $46;
      while(1) {
       $54 = ((($$023$i$i)) + 4|0);
       $55 = HEAP32[$54>>2]|0;
       $56 = ((($$023$i$i)) + 8|0);
       $57 = HEAP32[$56>>2]|0;
       $58 = ($57|0)==(0|0);
       if (!($58)) {
        $59 = ((($57)) + 8|0);
        $60 = HEAP32[$59>>2]|0;HEAP32[$59>>2] = (($60-1)|0);
        $61 = ($60|0)==(1);
        if ($61) {
         __THREW__ = 0;
         invoke_viii(3262,($57|0),1,1);
         $62 = __THREW__; __THREW__ = 0;
         $63 = $62&1;
         if ($63) {
          break;
         }
        }
       }
       __ZdlPv($$023$i$i);
       $64 = ($55|0)==($10|0);
       if ($64) {
        break L25;
       } else {
        $$023$i$i = $55;
       }
      }
      $65 = ___cxa_find_matching_catch_2()|0;
      $66 = tempRet0;
      ___cxa_call_unexpected(($65|0));
      // unreachable;
     }
    }
   } while(0);
   __THREW__ = 0;
   invoke_vi(707,($7|0));
   $67 = __THREW__; __THREW__ = 0;
   $68 = $67&1;
   if ($68) {
    $86 = ___cxa_find_matching_catch_3(0|0)|0;
    $87 = tempRet0;
    ___clang_call_terminate($86);
    // unreachable;
   } else {
    $$2 = $$0;$$26 = $$04;
   }
  }
  $69 = ((($4)) + 11|0);
  $70 = HEAP8[$69>>0]|0;
  $71 = ($70<<24>>24)<(0);
  if ($71) {
   $72 = HEAP32[$4>>2]|0;
   __ZdlPv($72);
   $$3 = $$2;$$37 = $$26;
  } else {
   $$3 = $$2;$$37 = $$26;
  }
 }
 $73 = HEAP32[$3>>2]|0;
 $74 = ($73|0)==(0|0);
 if (!($74)) {
  $75 = HEAP32[$73>>2]|0;
  $76 = ((($75)) + -12|0);
  $77 = HEAP32[$76>>2]|0;
  $78 = (($73) + ($77)|0);
  $79 = ((($78)) + 8|0);
  $80 = HEAP32[$79>>2]|0;HEAP32[$79>>2] = (($80-1)|0);
  $81 = ($80|0)==(1);
  if ($81) {
   __THREW__ = 0;
   invoke_viii(3262,($78|0),1,1);
   $82 = __THREW__; __THREW__ = 0;
   $83 = $82&1;
   if ($83) {
    $86 = ___cxa_find_matching_catch_3(0|0)|0;
    $87 = tempRet0;
    ___clang_call_terminate($86);
    // unreachable;
   }
  }
 }
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vi(2576,($0|0));
 $84 = __THREW__; __THREW__ = 0;
 $85 = $84&1;
 if ($85) {
  $86 = ___cxa_find_matching_catch_3(0|0)|0;
  $87 = tempRet0;
  ___clang_call_terminate($86);
  // unreachable;
 } else {
  ___resumeException($$37|0);
  // unreachable;
 }
}
function __ZN5osgDB13DatabasePager12RequestQueueC2EPS0_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$023$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg10ReferencedC2Ev($0);
 HEAP32[$0>>2] = (73000);
 $2 = ((($0)) + 12|0);
 HEAP32[$2>>2] = $1;
 $3 = ((($0)) + 16|0);
 HEAP32[$3>>2] = $3;
 $4 = ((($0)) + 20|0);
 HEAP32[$4>>2] = $3;
 $5 = ((($0)) + 24|0);
 HEAP32[$5>>2] = 0;
 $6 = ((($0)) + 28|0);
 __THREW__ = 0;
 invoke_vii(3507,($6|0),0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if (!($8)) {
  $9 = ((($0)) + 40|0);
  HEAP32[$9>>2] = -1;
  return;
 }
 $10 = ___cxa_find_matching_catch_2()|0;
 $11 = tempRet0;
 $12 = HEAP32[$5>>2]|0;
 $13 = ($12|0)==(0);
 L4: do {
  if (!($13)) {
   $14 = HEAP32[$4>>2]|0;
   $15 = HEAP32[$3>>2]|0;
   $16 = ((($15)) + 4|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = HEAP32[$14>>2]|0;
   $19 = ((($18)) + 4|0);
   HEAP32[$19>>2] = $17;
   $20 = HEAP32[$16>>2]|0;
   HEAP32[$20>>2] = $18;
   HEAP32[$5>>2] = 0;
   $21 = ($14|0)==($3|0);
   if (!($21)) {
    $$023$i$i = $14;
    while(1) {
     $22 = ((($$023$i$i)) + 4|0);
     $23 = HEAP32[$22>>2]|0;
     $24 = ((($$023$i$i)) + 8|0);
     $25 = HEAP32[$24>>2]|0;
     $26 = ($25|0)==(0|0);
     if (!($26)) {
      $27 = ((($25)) + 8|0);
      $28 = HEAP32[$27>>2]|0;HEAP32[$27>>2] = (($28-1)|0);
      $29 = ($28|0)==(1);
      if ($29) {
       __THREW__ = 0;
       invoke_viii(3262,($25|0),1,1);
       $30 = __THREW__; __THREW__ = 0;
       $31 = $30&1;
       if ($31) {
        break;
       }
      }
     }
     __ZdlPv($$023$i$i);
     $32 = ($23|0)==($3|0);
     if ($32) {
      break L4;
     } else {
      $$023$i$i = $23;
     }
    }
    $33 = ___cxa_find_matching_catch_2()|0;
    $34 = tempRet0;
    ___cxa_call_unexpected(($33|0));
    // unreachable;
   }
  }
 } while(0);
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $35 = __THREW__; __THREW__ = 0;
 $36 = $35&1;
 if ($36) {
  $37 = ___cxa_find_matching_catch_3(0|0)|0;
  $38 = tempRet0;
  ___clang_call_terminate($37);
  // unreachable;
 } else {
  ___resumeException($10|0);
  // unreachable;
 }
}
function __ZN5osgDB13DatabasePager14DatabaseThreadC2ERKS1_PS0_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$05 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg10ReferencedC2Ev($0);
 $3 = ((($0)) + 12|0);
 __THREW__ = 0;
 invoke_vi(3843,($3|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $16 = ___cxa_find_matching_catch_2()|0;
  $17 = tempRet0;
  $$0 = $17;$$05 = $16;
 } else {
  HEAP32[$0>>2] = (73048);
  HEAP32[$3>>2] = (73076);
  $6 = ((($0)) + 20|0);
  HEAP32[$6>>2] = 0;
  $7 = ((($0)) + 24|0);
  HEAP8[$7>>0] = 0;
  $8 = ((($0)) + 28|0);
  HEAP32[$8>>2] = $2;
  $9 = ((($0)) + 32|0);
  $10 = ((($1)) + 32|0);
  $11 = HEAP32[$10>>2]|0;
  HEAP32[$9>>2] = $11;
  $12 = ((($0)) + 36|0);
  $13 = ((($1)) + 36|0);
  __THREW__ = 0;
  invoke_vii(3457,($12|0),($13|0));
  $14 = __THREW__; __THREW__ = 0;
  $15 = $14&1;
  if (!($15)) {
   return;
  }
  $18 = ___cxa_find_matching_catch_2()|0;
  $19 = tempRet0;
  __THREW__ = 0;
  invoke_vi(2489,($3|0));
  $20 = __THREW__; __THREW__ = 0;
  $21 = $20&1;
  if ($21) {
   $24 = ___cxa_find_matching_catch_3(0|0)|0;
   $25 = tempRet0;
   ___clang_call_terminate($24);
   // unreachable;
  } else {
   $$0 = $19;$$05 = $18;
  }
 }
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $22 = __THREW__; __THREW__ = 0;
 $23 = $22&1;
 if ($23) {
  $24 = ___cxa_find_matching_catch_3(0|0)|0;
  $25 = tempRet0;
  ___clang_call_terminate($24);
  // unreachable;
 } else {
  ___resumeException($$05|0);
  // unreachable;
 }
}
function __ZN5osgDB13DatabasePager12setUpThreadsEjj($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$ = 0, $$02751 = 0, $$028 = 0, $$029 = 0, $$03049 = 0, $$050 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $3 = sp + 24|0;
 $4 = sp + 12|0;
 $5 = sp;
 $6 = ((($0)) + 56|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($0)) + 60|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==($7|0);
 L1: do {
  if (!($10)) {
   $12 = $9;
   while(1) {
    $11 = ((($12)) + -4|0);
    HEAP32[$8>>2] = $11;
    $13 = HEAP32[$11>>2]|0;
    $14 = ($13|0)==(0|0);
    if (!($14)) {
     $15 = ((($13)) + 8|0);
     $16 = HEAP32[$15>>2]|0;HEAP32[$15>>2] = (($16-1)|0);
     $17 = ($16|0)==(1);
     if ($17) {
      __THREW__ = 0;
      invoke_viii(3262,($13|0),1,1);
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if ($19) {
       break;
      }
     }
    }
    HEAP32[$11>>2] = 0;
    $20 = HEAP32[$8>>2]|0;
    $21 = ($20|0)==($7|0);
    if ($21) {
     break L1;
    } else {
     $12 = $20;
    }
   }
   $22 = ___cxa_find_matching_catch_2()|0;
   $23 = tempRet0;
   ___cxa_call_unexpected(($22|0));
   // unreachable;
  }
 } while(0);
 $24 = ($1>>>0)>($2>>>0);
 $25 = (($1) - ($2))|0;
 $$ = $24 ? $25 : 1;
 $26 = ($2|0)==(0);
 $27 = ($$|0)!=(0);
 if ($26) {
  if (!($27)) {
   STACKTOP = sp;return;
  }
  $31 = ((($3)) + 8|0);
  $32 = ((($3)) + 4|0);
  $33 = ((($3)) + 11|0);
  $$03049 = 0;
  while(1) {
   $34 = HEAP32[$0>>2]|0;
   $35 = ((($34)) + 40|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (__Znwj(32)|0);
   HEAP32[$3>>2] = $37;
   HEAP32[$31>>2] = -2147483616;
   HEAP32[$32>>2] = 19;
   dest=$37; src=164435; stop=dest+19|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
   $38 = ((($37)) + 19|0);
   HEAP8[$38>>0] = 0;
   __THREW__ = 0;
   (invoke_iiii($36|0,($0|0),0,($3|0))|0);
   $39 = __THREW__; __THREW__ = 0;
   $40 = $39&1;
   if ($40) {
    break;
   }
   $41 = HEAP8[$33>>0]|0;
   $42 = ($41<<24>>24)<(0);
   if ($42) {
    $43 = HEAP32[$3>>2]|0;
    __ZdlPv($43);
   }
   $44 = (($$03049) + 1)|0;
   $45 = ($44>>>0)<($$>>>0);
   if ($45) {
    $$03049 = $44;
   } else {
    label = 34;
    break;
   }
  }
  if ((label|0) == 34) {
   STACKTOP = sp;return;
  }
  $46 = ___cxa_find_matching_catch_2()|0;
  $47 = tempRet0;
  $48 = HEAP8[$33>>0]|0;
  $49 = ($48<<24>>24)<(0);
  if ($49) {
   $50 = HEAP32[$3>>2]|0;
   __ZdlPv($50);
  }
  $$028 = $47;$$029 = $46;
  ___resumeException($$029|0);
  // unreachable;
 }
 L29: do {
  if ($27) {
   $28 = ((($4)) + 8|0);
   $29 = ((($4)) + 4|0);
   $30 = ((($4)) + 11|0);
   $$02751 = 0;
   while(1) {
    $54 = HEAP32[$0>>2]|0;
    $55 = ((($54)) + 40|0);
    $56 = HEAP32[$55>>2]|0;
    $57 = (__Znwj(16)|0);
    HEAP32[$4>>2] = $57;
    HEAP32[$28>>2] = -2147483632;
    HEAP32[$29>>2] = 15;
    dest=$57; src=164455; stop=dest+15|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
    $58 = ((($57)) + 15|0);
    HEAP8[$58>>0] = 0;
    __THREW__ = 0;
    (invoke_iiii($56|0,($0|0),1,($4|0))|0);
    $59 = __THREW__; __THREW__ = 0;
    $60 = $59&1;
    if ($60) {
     break;
    }
    $61 = HEAP8[$30>>0]|0;
    $62 = ($61<<24>>24)<(0);
    if ($62) {
     $63 = HEAP32[$4>>2]|0;
     __ZdlPv($63);
    }
    $64 = (($$02751) + 1)|0;
    $65 = ($64>>>0)<($$>>>0);
    if ($65) {
     $$02751 = $64;
    } else {
     break L29;
    }
   }
   $66 = ___cxa_find_matching_catch_2()|0;
   $67 = tempRet0;
   $68 = HEAP8[$30>>0]|0;
   $69 = ($68<<24>>24)<(0);
   if ($69) {
    $70 = HEAP32[$4>>2]|0;
    __ZdlPv($70);
   }
   $$028 = $67;$$029 = $66;
   ___resumeException($$029|0);
   // unreachable;
  }
 } while(0);
 $51 = ((($5)) + 8|0);
 $52 = ((($5)) + 4|0);
 $53 = ((($5)) + 11|0);
 $$050 = 0;
 while(1) {
  $71 = HEAP32[$0>>2]|0;
  $72 = ((($71)) + 40|0);
  $73 = HEAP32[$72>>2]|0;
  $74 = (__Znwj(32)|0);
  HEAP32[$5>>2] = $74;
  HEAP32[$51>>2] = -2147483616;
  HEAP32[$52>>2] = 16;
  dest=$74; src=164471; stop=dest+16|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
  $75 = ((($74)) + 16|0);
  HEAP8[$75>>0] = 0;
  __THREW__ = 0;
  (invoke_iiii($73|0,($0|0),2,($5|0))|0);
  $76 = __THREW__; __THREW__ = 0;
  $77 = $76&1;
  if ($77) {
   break;
  }
  $78 = HEAP8[$53>>0]|0;
  $79 = ($78<<24>>24)<(0);
  if ($79) {
   $80 = HEAP32[$5>>2]|0;
   __ZdlPv($80);
  }
  $81 = (($$050) + 1)|0;
  $82 = ($81>>>0)<($2>>>0);
  if ($82) {
   $$050 = $81;
  } else {
   label = 34;
   break;
  }
 }
 if ((label|0) == 34) {
  STACKTOP = sp;return;
 }
 $83 = ___cxa_find_matching_catch_2()|0;
 $84 = tempRet0;
 $85 = HEAP8[$53>>0]|0;
 $86 = ($85<<24>>24)<(0);
 if ($86) {
  $87 = HEAP32[$5>>2]|0;
  __ZdlPv($87);
 }
 $$028 = $84;$$029 = $83;
 ___resumeException($$029|0);
 // unreachable;
}
function __ZN5osgDB13DatabasePager15DatabaseRequestD2Ev($0) {
 $0 = $0|0;
 var $$0 = 0, $$02 = 0, $$1 = 0, $$13 = 0, $$2 = 0, $$24 = 0, $$3 = 0, $$35 = 0, $$4 = 0, $$46 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (74268);
 $1 = ((($0)) + 92|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  label = 4;
 } else {
  $4 = ((($2)) + 8|0);
  $5 = HEAP32[$4>>2]|0;HEAP32[$4>>2] = (($5-1)|0);
  $6 = ($5|0)==(1);
  if ($6) {
   __THREW__ = 0;
   invoke_viii(3262,($2|0),1,1);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $54 = ___cxa_find_matching_catch_2()|0;
    $55 = tempRet0;
    $56 = ((($0)) + 88|0);
    $57 = HEAP32[$56>>2]|0;
    $58 = ($57|0)==(0|0);
    if (!($58)) {
     $59 = ((($57)) + 8|0);
     $60 = HEAP32[$59>>2]|0;HEAP32[$59>>2] = (($60-1)|0);
     $61 = ($60|0)==(1);
     if ($61) {
      __THREW__ = 0;
      invoke_viii(3262,($57|0),1,1);
      $62 = __THREW__; __THREW__ = 0;
      $63 = $62&1;
      if ($63) {
       $113 = ___cxa_find_matching_catch_3(0|0)|0;
       $114 = tempRet0;
       ___clang_call_terminate($113);
       // unreachable;
      }
     }
    }
    HEAP32[$56>>2] = 0;
    $$0 = $55;$$02 = $54;
    label = 28;
   } else {
    label = 4;
   }
  } else {
   label = 4;
  }
 }
 do {
  if ((label|0) == 4) {
   HEAP32[$1>>2] = 0;
   $9 = ((($0)) + 88|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($10|0)==(0|0);
   if (!($11)) {
    $12 = ((($10)) + 8|0);
    $13 = HEAP32[$12>>2]|0;HEAP32[$12>>2] = (($13-1)|0);
    $14 = ($13|0)==(1);
    if ($14) {
     __THREW__ = 0;
     invoke_viii(3262,($10|0),1,1);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      $64 = ___cxa_find_matching_catch_2()|0;
      $65 = tempRet0;
      $$0 = $65;$$02 = $64;
      label = 28;
      break;
     }
    }
   }
   HEAP32[$9>>2] = 0;
   $17 = ((($0)) + 84|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = ($18|0)==(0|0);
   if (!($19)) {
    $20 = ((($18)) + 8|0);
    $21 = HEAP32[$20>>2]|0;HEAP32[$20>>2] = (($21-1)|0);
    $22 = ($21|0)==(1);
    if ($22) {
     __THREW__ = 0;
     invoke_viii(3262,($18|0),1,1);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      $66 = ___cxa_find_matching_catch_2()|0;
      $67 = tempRet0;
      $$1 = $67;$$13 = $66;
      label = 33;
      break;
     }
    }
   }
   HEAP32[$17>>2] = 0;
   $25 = ((($0)) + 80|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = ($26|0)==(0|0);
   if (!($27)) {
    $28 = ((($26)) + 8|0);
    $29 = HEAP32[$28>>2]|0;HEAP32[$28>>2] = (($29-1)|0);
    $30 = ($29|0)==(1);
    if ($30) {
     __THREW__ = 0;
     invoke_viii(3262,($26|0),1,1);
     $31 = __THREW__; __THREW__ = 0;
     $32 = $31&1;
     if ($32) {
      $76 = ___cxa_find_matching_catch_2()|0;
      $77 = tempRet0;
      $$2 = $77;$$24 = $76;
      label = 38;
      break;
     }
    }
   }
   HEAP32[$25>>2] = 0;
   $33 = ((($0)) + 72|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = ($34|0)==(0|0);
   if (!($35)) {
    $36 = ((($34)) + 8|0);
    $37 = HEAP32[$36>>2]|0;HEAP32[$36>>2] = (($37-1)|0);
    $38 = ($37|0)==(1);
    if ($38) {
     __THREW__ = 0;
     invoke_viii(3262,($34|0),1,1);
     $39 = __THREW__; __THREW__ = 0;
     $40 = $39&1;
     if ($40) {
      $86 = ___cxa_find_matching_catch_2()|0;
      $87 = tempRet0;
      $$3 = $87;$$35 = $86;
      label = 43;
      break;
     }
    }
   }
   HEAP32[$33>>2] = 0;
   $41 = ((($0)) + 64|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = ($42|0)==(0|0);
   if (!($43)) {
    $44 = ((($42)) + 8|0);
    $45 = HEAP32[$44>>2]|0;HEAP32[$44>>2] = (($45-1)|0);
    $46 = ($45|0)==(1);
    if ($46) {
     __THREW__ = 0;
     invoke_viii(3262,($42|0),1,1);
     $47 = __THREW__; __THREW__ = 0;
     $48 = $47&1;
     if ($48) {
      $96 = ___cxa_find_matching_catch_2()|0;
      $97 = tempRet0;
      $$4 = $97;$$46 = $96;
      break;
     }
    }
   }
   HEAP32[$41>>2] = 0;
   $49 = ((($0)) + 16|0);
   $50 = ((($49)) + 11|0);
   $51 = HEAP8[$50>>0]|0;
   $52 = ($51<<24>>24)<(0);
   if (!($52)) {
    __ZN3osg10ReferencedD2Ev($0);
    return;
   }
   $53 = HEAP32[$49>>2]|0;
   __ZdlPv($53);
   __ZN3osg10ReferencedD2Ev($0);
   return;
  }
 } while(0);
 if ((label|0) == 28) {
  $68 = ((($0)) + 84|0);
  $69 = HEAP32[$68>>2]|0;
  $70 = ($69|0)==(0|0);
  if (!($70)) {
   $71 = ((($69)) + 8|0);
   $72 = HEAP32[$71>>2]|0;HEAP32[$71>>2] = (($72-1)|0);
   $73 = ($72|0)==(1);
   if ($73) {
    __THREW__ = 0;
    invoke_viii(3262,($69|0),1,1);
    $74 = __THREW__; __THREW__ = 0;
    $75 = $74&1;
    if ($75) {
     $113 = ___cxa_find_matching_catch_3(0|0)|0;
     $114 = tempRet0;
     ___clang_call_terminate($113);
     // unreachable;
    }
   }
  }
  HEAP32[$68>>2] = 0;
  $$1 = $$0;$$13 = $$02;
  label = 33;
 }
 if ((label|0) == 33) {
  $78 = ((($0)) + 80|0);
  $79 = HEAP32[$78>>2]|0;
  $80 = ($79|0)==(0|0);
  if (!($80)) {
   $81 = ((($79)) + 8|0);
   $82 = HEAP32[$81>>2]|0;HEAP32[$81>>2] = (($82-1)|0);
   $83 = ($82|0)==(1);
   if ($83) {
    __THREW__ = 0;
    invoke_viii(3262,($79|0),1,1);
    $84 = __THREW__; __THREW__ = 0;
    $85 = $84&1;
    if ($85) {
     $113 = ___cxa_find_matching_catch_3(0|0)|0;
     $114 = tempRet0;
     ___clang_call_terminate($113);
     // unreachable;
    }
   }
  }
  HEAP32[$78>>2] = 0;
  $$2 = $$1;$$24 = $$13;
  label = 38;
 }
 if ((label|0) == 38) {
  $88 = ((($0)) + 72|0);
  $89 = HEAP32[$88>>2]|0;
  $90 = ($89|0)==(0|0);
  if (!($90)) {
   $91 = ((($89)) + 8|0);
   $92 = HEAP32[$91>>2]|0;HEAP32[$91>>2] = (($92-1)|0);
   $93 = ($92|0)==(1);
   if ($93) {
    __THREW__ = 0;
    invoke_viii(3262,($89|0),1,1);
    $94 = __THREW__; __THREW__ = 0;
    $95 = $94&1;
    if ($95) {
     $113 = ___cxa_find_matching_catch_3(0|0)|0;
     $114 = tempRet0;
     ___clang_call_terminate($113);
     // unreachable;
    }
   }
  }
  HEAP32[$88>>2] = 0;
  $$3 = $$2;$$35 = $$24;
  label = 43;
 }
 if ((label|0) == 43) {
  $98 = ((($0)) + 64|0);
  $99 = HEAP32[$98>>2]|0;
  $100 = ($99|0)==(0|0);
  if (!($100)) {
   $101 = ((($99)) + 8|0);
   $102 = HEAP32[$101>>2]|0;HEAP32[$101>>2] = (($102-1)|0);
   $103 = ($102|0)==(1);
   if ($103) {
    __THREW__ = 0;
    invoke_viii(3262,($99|0),1,1);
    $104 = __THREW__; __THREW__ = 0;
    $105 = $104&1;
    if ($105) {
     $113 = ___cxa_find_matching_catch_3(0|0)|0;
     $114 = tempRet0;
     ___clang_call_terminate($113);
     // unreachable;
    }
   }
  }
  HEAP32[$98>>2] = 0;
  $$4 = $$3;$$46 = $$35;
 }
 $106 = ((($0)) + 16|0);
 $107 = ((($106)) + 11|0);
 $108 = HEAP8[$107>>0]|0;
 $109 = ($108<<24>>24)<(0);
 if ($109) {
  $110 = HEAP32[$106>>2]|0;
  __ZdlPv($110);
 }
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $111 = __THREW__; __THREW__ = 0;
 $112 = $111&1;
 if ($112) {
  $113 = ___cxa_find_matching_catch_3(0|0)|0;
  $114 = tempRet0;
  ___clang_call_terminate($113);
  // unreachable;
 } else {
  ___resumeException($$46|0);
  // unreachable;
 }
}
function __ZN5osgDB13DatabasePager15DatabaseRequestD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(2629,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __GLOBAL__sub_I_DatabasePager_cpp() {
 var $$0$i = 0, $$0$i14 = 0, $$0$i22 = 0, $$0$i30 = 0, $$0$i6 = 0, $$01$i = 0, $$01$i13 = 0, $$01$i21 = 0, $$01$i29 = 0, $$01$i5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0;
 var $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0;
 var $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0;
 var $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(128|0);
 $0 = sp + 108|0;
 $1 = sp + 96|0;
 $2 = sp + 84|0;
 $3 = sp + 72|0;
 $4 = sp + 60|0;
 $5 = sp + 48|0;
 $6 = sp + 36|0;
 $7 = sp + 24|0;
 $8 = sp + 12|0;
 $9 = sp;
 HEAPF32[52337] = 1.0;
 HEAPF32[(209352)>>2] = 0.0;
 HEAPF32[(209356)>>2] = 0.0;
 HEAPF32[52340] = 0.0;
 HEAPF32[(209364)>>2] = 1.0;
 HEAPF32[(209368)>>2] = 0.0;
 HEAPF32[52343] = 0.0;
 HEAPF32[(209376)>>2] = 0.0;
 HEAPF32[(209380)>>2] = 1.0;
 $10 = (__Znwj(32)|0);
 HEAP32[$6>>2] = $10;
 $11 = ((($6)) + 8|0);
 HEAP32[$11>>2] = -2147483616;
 $12 = ((($6)) + 4|0);
 HEAP32[$12>>2] = 27;
 dest=$10; src=164597; stop=dest+27|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $13 = ((($10)) + 27|0);
 HEAP8[$13>>0] = 0;
 ;HEAP32[$7>>2]=0|0;HEAP32[$7+4>>2]=0|0;HEAP32[$7+8>>2]=0|0;
 __THREW__ = 0;
 $14 = (invoke_ii(3276,80)|0);
 $15 = __THREW__; __THREW__ = 0;
 $16 = $15&1;
 if ($16) {
  $33 = ___cxa_find_matching_catch_2()|0;
  $34 = tempRet0;
  $$0$i6 = $34;$$01$i5 = $33;
 } else {
  HEAP32[$7>>2] = $14;
  $17 = ((($7)) + 8|0);
  HEAP32[$17>>2] = -2147483568;
  $18 = ((($7)) + 4|0);
  HEAP32[$18>>2] = 65;
  dest=$14; src=164625; stop=dest+65|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
  $19 = ((($14)) + 65|0);
  HEAP8[$19>>0] = 0;
  __THREW__ = 0;
  $20 = (invoke_i(3459)|0);
  $21 = __THREW__; __THREW__ = 0;
  $22 = $21&1;
  if (!($22)) {
   __THREW__ = 0;
   invoke_viiii(3460,($20|0),2,($6|0),($7|0));
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if (!($24)) {
    $25 = ((($7)) + 11|0);
    $26 = HEAP8[$25>>0]|0;
    $27 = ($26<<24>>24)<(0);
    if ($27) {
     $28 = HEAP32[$7>>2]|0;
     __ZdlPv($28);
    }
    $29 = ((($6)) + 11|0);
    $30 = HEAP8[$29>>0]|0;
    $31 = ($30<<24>>24)<(0);
    if ($31) {
     $32 = HEAP32[$6>>2]|0;
     __ZdlPv($32);
    }
    $45 = (__Znwj(48)|0);
    HEAP32[$4>>2] = $45;
    $46 = ((($4)) + 8|0);
    HEAP32[$46>>2] = -2147483600;
    $47 = ((($4)) + 4|0);
    HEAP32[$47>>2] = 34;
    dest=$45; src=164691; stop=dest+34|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
    $48 = ((($45)) + 34|0);
    HEAP8[$48>>0] = 0;
    ;HEAP32[$5>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;
    __THREW__ = 0;
    $49 = (invoke_ii(3276,144)|0);
    $50 = __THREW__; __THREW__ = 0;
    $51 = $50&1;
    if ($51) {
     $68 = ___cxa_find_matching_catch_2()|0;
     $69 = tempRet0;
     $$0$i14 = $69;$$01$i13 = $68;
    } else {
     HEAP32[$5>>2] = $49;
     $52 = ((($5)) + 8|0);
     HEAP32[$52>>2] = -2147483504;
     $53 = ((($5)) + 4|0);
     HEAP32[$53>>2] = 141;
     _memcpy(($49|0),(164726|0),141)|0;
     $54 = ((($49)) + 141|0);
     HEAP8[$54>>0] = 0;
     __THREW__ = 0;
     $55 = (invoke_i(3459)|0);
     $56 = __THREW__; __THREW__ = 0;
     $57 = $56&1;
     if (!($57)) {
      __THREW__ = 0;
      invoke_viiii(3460,($55|0),2,($4|0),($5|0));
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if (!($59)) {
       $60 = ((($5)) + 11|0);
       $61 = HEAP8[$60>>0]|0;
       $62 = ($61<<24>>24)<(0);
       if ($62) {
        $63 = HEAP32[$5>>2]|0;
        __ZdlPv($63);
       }
       $64 = ((($4)) + 11|0);
       $65 = HEAP8[$64>>0]|0;
       $66 = ($65<<24>>24)<(0);
       if ($66) {
        $67 = HEAP32[$4>>2]|0;
        __ZdlPv($67);
       }
       $80 = (__Znwj(48)|0);
       HEAP32[$2>>2] = $80;
       $81 = ((($2)) + 8|0);
       HEAP32[$81>>2] = -2147483600;
       $82 = ((($2)) + 4|0);
       HEAP32[$82>>2] = 34;
       dest=$80; src=164868; stop=dest+34|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
       $83 = ((($80)) + 34|0);
       HEAP8[$83>>0] = 0;
       ;HEAP32[$3>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;
       __THREW__ = 0;
       $84 = (invoke_ii(3276,80)|0);
       $85 = __THREW__; __THREW__ = 0;
       $86 = $85&1;
       if ($86) {
        $103 = ___cxa_find_matching_catch_2()|0;
        $104 = tempRet0;
        $$0$i22 = $104;$$01$i21 = $103;
       } else {
        HEAP32[$3>>2] = $84;
        $87 = ((($3)) + 8|0);
        HEAP32[$87>>2] = -2147483568;
        $88 = ((($3)) + 4|0);
        HEAP32[$88>>2] = 67;
        dest=$84; src=164903; stop=dest+67|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
        $89 = ((($84)) + 67|0);
        HEAP8[$89>>0] = 0;
        __THREW__ = 0;
        $90 = (invoke_i(3459)|0);
        $91 = __THREW__; __THREW__ = 0;
        $92 = $91&1;
        if (!($92)) {
         __THREW__ = 0;
         invoke_viiii(3460,($90|0),2,($2|0),($3|0));
         $93 = __THREW__; __THREW__ = 0;
         $94 = $93&1;
         if (!($94)) {
          $95 = ((($3)) + 11|0);
          $96 = HEAP8[$95>>0]|0;
          $97 = ($96<<24>>24)<(0);
          if ($97) {
           $98 = HEAP32[$3>>2]|0;
           __ZdlPv($98);
          }
          $99 = ((($2)) + 11|0);
          $100 = HEAP8[$99>>0]|0;
          $101 = ($100<<24>>24)<(0);
          if ($101) {
           $102 = HEAP32[$2>>2]|0;
           __ZdlPv($102);
          }
          $115 = (__Znwj(32)|0);
          HEAP32[$0>>2] = $115;
          $116 = ((($0)) + 8|0);
          HEAP32[$116>>2] = -2147483616;
          $117 = ((($0)) + 4|0);
          HEAP32[$117>>2] = 22;
          dest=$115; src=164971; stop=dest+22|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
          $118 = ((($115)) + 22|0);
          HEAP8[$118>>0] = 0;
          ;HEAP32[$1>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;
          __THREW__ = 0;
          $119 = (invoke_ii(3276,64)|0);
          $120 = __THREW__; __THREW__ = 0;
          $121 = $120&1;
          do {
           if ($121) {
            $138 = ___cxa_find_matching_catch_2()|0;
            $139 = tempRet0;
            $$0$i30 = $139;$$01$i29 = $138;
           } else {
            HEAP32[$1>>2] = $119;
            $122 = ((($1)) + 8|0);
            HEAP32[$122>>2] = -2147483584;
            $123 = ((($1)) + 4|0);
            HEAP32[$123>>2] = 54;
            dest=$119; src=164994; stop=dest+54|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
            $124 = ((($119)) + 54|0);
            HEAP8[$124>>0] = 0;
            __THREW__ = 0;
            $125 = (invoke_i(3459)|0);
            $126 = __THREW__; __THREW__ = 0;
            $127 = $126&1;
            do {
             if (!($127)) {
              __THREW__ = 0;
              invoke_viiii(3460,($125|0),2,($0|0),($1|0));
              $128 = __THREW__; __THREW__ = 0;
              $129 = $128&1;
              if ($129) {
               break;
              }
              $130 = ((($1)) + 11|0);
              $131 = HEAP8[$130>>0]|0;
              $132 = ($131<<24>>24)<(0);
              if ($132) {
               $133 = HEAP32[$1>>2]|0;
               __ZdlPv($133);
              }
              $134 = ((($0)) + 11|0);
              $135 = HEAP8[$134>>0]|0;
              $136 = ($135<<24>>24)<(0);
              if ($136) {
               $137 = HEAP32[$0>>2]|0;
               __ZdlPv($137);
              }
              $150 = (__Znwj(48)|0);
              HEAP32[$8>>2] = $150;
              $151 = ((($8)) + 8|0);
              HEAP32[$151>>2] = -2147483600;
              $152 = ((($8)) + 4|0);
              HEAP32[$152>>2] = 33;
              dest=$150; src=165049; stop=dest+33|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
              $153 = ((($150)) + 33|0);
              HEAP8[$153>>0] = 0;
              ;HEAP32[$9>>2]=0|0;HEAP32[$9+4>>2]=0|0;HEAP32[$9+8>>2]=0|0;
              __THREW__ = 0;
              $154 = (invoke_ii(3276,96)|0);
              $155 = __THREW__; __THREW__ = 0;
              $156 = $155&1;
              do {
               if ($156) {
                $173 = ___cxa_find_matching_catch_2()|0;
                $174 = tempRet0;
                $$0$i = $174;$$01$i = $173;
               } else {
                HEAP32[$9>>2] = $154;
                $157 = ((($9)) + 8|0);
                HEAP32[$157>>2] = -2147483552;
                $158 = ((($9)) + 4|0);
                HEAP32[$158>>2] = 87;
                dest=$154; src=165083; stop=dest+87|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                $159 = ((($154)) + 87|0);
                HEAP8[$159>>0] = 0;
                __THREW__ = 0;
                $160 = (invoke_i(3459)|0);
                $161 = __THREW__; __THREW__ = 0;
                $162 = $161&1;
                do {
                 if (!($162)) {
                  __THREW__ = 0;
                  invoke_viiii(3460,($160|0),2,($8|0),($9|0));
                  $163 = __THREW__; __THREW__ = 0;
                  $164 = $163&1;
                  if ($164) {
                   break;
                  }
                  $165 = ((($9)) + 11|0);
                  $166 = HEAP8[$165>>0]|0;
                  $167 = ($166<<24>>24)<(0);
                  if ($167) {
                   $168 = HEAP32[$9>>2]|0;
                   __ZdlPv($168);
                  }
                  $169 = ((($8)) + 11|0);
                  $170 = HEAP8[$169>>0]|0;
                  $171 = ($170<<24>>24)<(0);
                  if (!($171)) {
                   (__ZN5osgDB13DatabasePager9prototypeEv()|0);
                   STACKTOP = sp;return;
                  }
                  $172 = HEAP32[$8>>2]|0;
                  __ZdlPv($172);
                  (__ZN5osgDB13DatabasePager9prototypeEv()|0);
                  STACKTOP = sp;return;
                 }
                } while(0);
                $175 = ___cxa_find_matching_catch_2()|0;
                $176 = tempRet0;
                $177 = ((($9)) + 11|0);
                $178 = HEAP8[$177>>0]|0;
                $179 = ($178<<24>>24)<(0);
                if (!($179)) {
                 $$0$i = $176;$$01$i = $175;
                 break;
                }
                $180 = HEAP32[$9>>2]|0;
                __ZdlPv($180);
                $$0$i = $176;$$01$i = $175;
               }
              } while(0);
              $181 = ((($8)) + 11|0);
              $182 = HEAP8[$181>>0]|0;
              $183 = ($182<<24>>24)<(0);
              if (!($183)) {
               ___resumeException($$01$i|0);
               // unreachable;
              }
              $184 = HEAP32[$8>>2]|0;
              __ZdlPv($184);
              ___resumeException($$01$i|0);
              // unreachable;
             }
            } while(0);
            $140 = ___cxa_find_matching_catch_2()|0;
            $141 = tempRet0;
            $142 = ((($1)) + 11|0);
            $143 = HEAP8[$142>>0]|0;
            $144 = ($143<<24>>24)<(0);
            if (!($144)) {
             $$0$i30 = $141;$$01$i29 = $140;
             break;
            }
            $145 = HEAP32[$1>>2]|0;
            __ZdlPv($145);
            $$0$i30 = $141;$$01$i29 = $140;
           }
          } while(0);
          $146 = ((($0)) + 11|0);
          $147 = HEAP8[$146>>0]|0;
          $148 = ($147<<24>>24)<(0);
          if (!($148)) {
           ___resumeException($$01$i29|0);
           // unreachable;
          }
          $149 = HEAP32[$0>>2]|0;
          __ZdlPv($149);
          ___resumeException($$01$i29|0);
          // unreachable;
         }
        }
        $105 = ___cxa_find_matching_catch_2()|0;
        $106 = tempRet0;
        $107 = ((($3)) + 11|0);
        $108 = HEAP8[$107>>0]|0;
        $109 = ($108<<24>>24)<(0);
        if ($109) {
         $110 = HEAP32[$3>>2]|0;
         __ZdlPv($110);
         $$0$i22 = $106;$$01$i21 = $105;
        } else {
         $$0$i22 = $106;$$01$i21 = $105;
        }
       }
       $111 = ((($2)) + 11|0);
       $112 = HEAP8[$111>>0]|0;
       $113 = ($112<<24>>24)<(0);
       if (!($113)) {
        ___resumeException($$01$i21|0);
        // unreachable;
       }
       $114 = HEAP32[$2>>2]|0;
       __ZdlPv($114);
       ___resumeException($$01$i21|0);
       // unreachable;
      }
     }
     $70 = ___cxa_find_matching_catch_2()|0;
     $71 = tempRet0;
     $72 = ((($5)) + 11|0);
     $73 = HEAP8[$72>>0]|0;
     $74 = ($73<<24>>24)<(0);
     if ($74) {
      $75 = HEAP32[$5>>2]|0;
      __ZdlPv($75);
      $$0$i14 = $71;$$01$i13 = $70;
     } else {
      $$0$i14 = $71;$$01$i13 = $70;
     }
    }
    $76 = ((($4)) + 11|0);
    $77 = HEAP8[$76>>0]|0;
    $78 = ($77<<24>>24)<(0);
    if (!($78)) {
     ___resumeException($$01$i13|0);
     // unreachable;
    }
    $79 = HEAP32[$4>>2]|0;
    __ZdlPv($79);
    ___resumeException($$01$i13|0);
    // unreachable;
   }
  }
  $35 = ___cxa_find_matching_catch_2()|0;
  $36 = tempRet0;
  $37 = ((($7)) + 11|0);
  $38 = HEAP8[$37>>0]|0;
  $39 = ($38<<24>>24)<(0);
  if ($39) {
   $40 = HEAP32[$7>>2]|0;
   __ZdlPv($40);
   $$0$i6 = $36;$$01$i5 = $35;
  } else {
   $$0$i6 = $36;$$01$i5 = $35;
  }
 }
 $41 = ((($6)) + 11|0);
 $42 = HEAP8[$41>>0]|0;
 $43 = ($42<<24>>24)<(0);
 if (!($43)) {
  ___resumeException($$01$i5|0);
  // unreachable;
 }
 $44 = HEAP32[$6>>2]|0;
 __ZdlPv($44);
 ___resumeException($$01$i5|0);
 // unreachable;
}
function __ZN5osgDB13DatabasePager9prototypeEv() {
 var $$0 = 0, $$01 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[206216]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  return (209384|0);
 }
 $2 = (___cxa_guard_acquire(206216)|0);
 $3 = ($2|0)==(0);
 if ($3) {
  return (209384|0);
 }
 __THREW__ = 0;
 $4 = (invoke_ii(3276,168)|0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $11 = ___cxa_find_matching_catch_2()|0;
  $12 = tempRet0;
  $$0 = $12;$$01 = $11;
  ___resumeException($$01|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_vi(4146,($4|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $13 = ___cxa_find_matching_catch_2()|0;
  $14 = tempRet0;
  __ZdlPv($4);
  $$0 = $14;$$01 = $13;
  ___resumeException($$01|0);
  // unreachable;
 } else {
  HEAP32[52346] = $4;
  $9 = ((($4)) + 8|0);
  $10 = HEAP32[$9>>2]|0;HEAP32[$9>>2] = (($10+1)|0);
  (___cxa_atexit((4147|0),(209384|0),(___dso_handle|0))|0);
  return (209384|0);
 }
 return (0)|0;
}
function __ZN5osgDB13DatabasePagerC2Ev($0) {
 $0 = $0|0;
 var $$0 = 0, $$034 = 0, $$036119 = 0, $$037121 = 0, $$039120 = 0, $$138123 = 0, $$140122 = 0, $$2 = 0, $$241 = 0, $$4 = 0, $$443 = 0, $$7 = 0, $$746 = 0, $$8 = 0, $$847 = 0, $$pre$i = 0, $$sroa$04$08$i = 0, $$sroa$04$08$i102 = 0, $$sroa$04$08$i107 = 0, $$sroa$04$08$i112 = 0;
 var $$sroa$04$08$i92 = 0, $$sroa$04$08$i97 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0;
 var $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0;
 var $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0;
 var $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0;
 var $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0;
 var $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0;
 var $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0;
 var $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0;
 var $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0;
 var $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0;
 var $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0;
 var $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0;
 var $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0;
 var $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0;
 var $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0;
 var $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index9Z2D = 0, $eh$lpad$body$indexZ2D = 0, dest = 0, label = 0, sp = 0;
 var src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $1 = sp + 28|0;
 $2 = sp + 24|0;
 $3 = sp + 12|0;
 $4 = sp;
 __ZN3osg10ReferencedC2Eb($0,1);
 HEAP32[$0>>2] = (73684);
 $5 = ((($0)) + 12|0);
 __THREW__ = 0;
 invoke_vii(3507,($5|0),0);
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if ($7) {
  $38 = ___cxa_find_matching_catch_2()|0;
  $39 = tempRet0;
  $$8 = $39;$$847 = $38;
 } else {
  $8 = ((($0)) + 24|0);
  __THREW__ = 0;
  invoke_vii(3507,($8|0),0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if ($10) {
   $40 = ___cxa_find_matching_catch_2()|0;
   $41 = tempRet0;
   $$7 = $41;$$746 = $40;
  } else {
   $11 = ((($0)) + 40|0);
   $12 = ((($0)) + 44|0);
   HEAP32[$12>>2] = 0;
   $13 = ((($0)) + 48|0);
   HEAP32[$13>>2] = 0;
   $14 = ((($0)) + 44|0);
   HEAP32[$11>>2] = $14;
   $15 = ((($0)) + 56|0);
   HEAP32[$15>>2] = 0;
   $16 = ((($0)) + 60|0);
   HEAP32[$16>>2] = 0;
   $17 = ((($0)) + 64|0);
   HEAP32[$17>>2] = 0;
   $18 = ((($0)) + 72|0);
   __THREW__ = 0;
   invoke_vii(3507,($18|0),0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if ($20) {
    $42 = ___cxa_find_matching_catch_2()|0;
    $43 = tempRet0;
    $$4 = $43;$$443 = $42;
   } else {
    $21 = ((($0)) + 84|0);
    HEAP32[$21>>2] = 0;
    $22 = ((($0)) + 88|0);
    $23 = ((($0)) + 92|0);
    $24 = ((($0)) + 96|0);
    $25 = ((($0)) + 100|0);
    $26 = ((($0)) + 120|0);
    HEAP32[$26>>2] = 0;
    $27 = ((($0)) + 132|0);
    HEAP32[$27>>2] = 0;
    $28 = ((($0)) + 164|0);
    HEAP32[$28>>2] = 0;
    $29 = ((($0)) + 36|0);
    HEAP8[$29>>0] = 0;
    $30 = ((($0)) + 52|0);
    HEAP8[$30>>0] = 0;
    $31 = ((($0)) + 53|0);
    ;HEAP32[$22>>2]=0|0;HEAP32[$22+4>>2]=0|0;HEAP32[$22+8>>2]=0|0;HEAP32[$22+12>>2]=0|0;
    HEAP8[$31>>0] = 1;
    $32 = ((($0)) + 54|0);
    HEAP8[$32>>0] = 0;
    $33 = ((($0)) + 68|0);
    HEAP32[$33>>2] = 0;
    $34 = HEAP32[$21>>2]|0;HEAP32[$21>>2] = 0;
    $35 = ((($0)) + 104|0);
    HEAP32[$35>>2] = 0;
    $36 = (_getenv((165171|0))|0);
    $37 = ($36|0)==(0|0);
    if ($37) {
     $58 = (_getenv((165199|0))|0);
     $59 = ($58|0)==(0|0);
     if (!($59)) {
      $$036119 = $58;
      label = 17;
     }
    } else {
     $$036119 = $36;
     label = 17;
    }
    do {
     if ((label|0) == 17) {
      $60 = (_strcmp($$036119,165227)|0);
      $61 = ($60|0)==(0);
      if ($61) {
       HEAP32[$35>>2] = 0;
       break;
      }
      $62 = (_strcmp($$036119,165239)|0);
      $63 = ($62|0)==(0);
      if (!($63)) {
       $64 = (_strcmp($$036119,165251)|0);
       $65 = ($64|0)==(0);
       if (!($65)) {
        $66 = (_strcmp($$036119,165254)|0);
        $67 = ($66|0)==(0);
        if ($67) {
         HEAP32[$35>>2] = 2;
         break;
        }
        $68 = (_strcmp($$036119,165258)|0);
        $69 = ($68|0)==(0);
        if (!($69)) {
         $70 = (_strcmp($$036119,165271)|0);
         $71 = ($70|0)==(0);
         if (!($71)) {
          break;
         }
        }
        HEAP32[$35>>2] = 3;
        break;
       }
      }
      HEAP32[$35>>2] = 1;
     }
    } while(0);
    $72 = ((($0)) + 108|0);
    HEAP8[$72>>0] = 0;
    $73 = (_getenv((165274|0))|0);
    $74 = ($73|0)==(0|0);
    do {
     if ($74) {
      label = 46;
     } else {
      $75 = (_strcmp($73,195630)|0);
      $76 = ($75|0)==(0);
      if ($76) {
       $84 = 1;
      } else {
       $77 = (_strcmp($73,165299)|0);
       $78 = ($77|0)==(0);
       if ($78) {
        $84 = 1;
       } else {
        $79 = (_strcmp($73,165303)|0);
        $80 = ($79|0)==(0);
        if ($80) {
         $84 = 1;
        } else {
         $81 = (_strcmp($73,165306)|0);
         $82 = ($81|0)==(0);
         $84 = $82;
        }
       }
      }
      $83 = $84&1;
      HEAP8[$72>>0] = $83;
      __THREW__ = 0;
      $85 = (invoke_ii(3265,3)|0);
      $86 = __THREW__; __THREW__ = 0;
      $87 = $86&1;
      if ($87) {
       label = 14;
      } else {
       if ($85) {
        __THREW__ = 0;
        $88 = (invoke_ii(3266,3)|0);
        $89 = __THREW__; __THREW__ = 0;
        $90 = $89&1;
        if ($90) {
         label = 14;
        } else {
         __THREW__ = 0;
         $91 = (invoke_iiii(3267,($88|0),(165309|0),32)|0);
         $92 = __THREW__; __THREW__ = 0;
         $93 = $92&1;
         if ($93) {
          label = 14;
         } else {
          $94 = HEAP8[$72>>0]|0;
          $95 = ($94<<24>>24)!=(0);
          __THREW__ = 0;
          $96 = (invoke_iii(4148,($91|0),($95|0))|0);
          $97 = __THREW__; __THREW__ = 0;
          $98 = $97&1;
          if ($98) {
           label = 14;
          } else {
           $99 = HEAP32[$96>>2]|0;
           $100 = ((($99)) + -12|0);
           $101 = HEAP32[$100>>2]|0;
           $102 = (($96) + ($101)|0);
           __THREW__ = 0;
           invoke_vii(3257,($2|0),($102|0));
           $103 = __THREW__; __THREW__ = 0;
           $104 = $103&1;
           if ($104) {
            label = 14;
           } else {
            __THREW__ = 0;
            $105 = (invoke_iii(3255,($2|0),(215188|0))|0);
            $106 = __THREW__; __THREW__ = 0;
            $107 = $106&1;
            if (!($107)) {
             $108 = HEAP32[$105>>2]|0;
             $109 = ((($108)) + 28|0);
             $110 = HEAP32[$109>>2]|0;
             __THREW__ = 0;
             $111 = (invoke_iii($110|0,($105|0),10)|0);
             $112 = __THREW__; __THREW__ = 0;
             $113 = $112&1;
             if (!($113)) {
              __THREW__ = 0;
              invoke_vi(3263,($2|0));
              $120 = __THREW__; __THREW__ = 0;
              $121 = $120&1;
              if ($121) {
               label = 14;
               break;
              }
              __THREW__ = 0;
              (invoke_iii(3268,($96|0),($111|0))|0);
              $122 = __THREW__; __THREW__ = 0;
              $123 = $122&1;
              if ($123) {
               label = 14;
               break;
              }
              __THREW__ = 0;
              (invoke_ii(3269,($96|0))|0);
              $124 = __THREW__; __THREW__ = 0;
              $125 = $124&1;
              if ($125) {
               label = 14;
               break;
              } else {
               label = 46;
               break;
              }
             }
            }
            $114 = ___cxa_find_matching_catch_2()|0;
            $115 = tempRet0;
            __THREW__ = 0;
            invoke_vi(3263,($2|0));
            $116 = __THREW__; __THREW__ = 0;
            $117 = $116&1;
            if ($117) {
             $118 = ___cxa_find_matching_catch_3(0|0)|0;
             $119 = tempRet0;
             ___clang_call_terminate($118);
             // unreachable;
            } else {
             $eh$lpad$body$index9Z2D = $115;$eh$lpad$body$indexZ2D = $114;
             label = 15;
             break;
            }
           }
          }
         }
        }
       } else {
        label = 46;
       }
      }
     }
    } while(0);
    L50: do {
     if ((label|0) == 46) {
      $126 = ((($0)) + 109|0);
      HEAP8[$126>>0] = 1;
      $127 = ((($0)) + 110|0);
      HEAP8[$127>>0] = 0;
      $128 = ((($0)) + 111|0);
      HEAP8[$128>>0] = 0;
      $129 = ((($0)) + 112|0);
      HEAPF32[$129>>2] = 1.0;
      $130 = ((($0)) + 116|0);
      HEAP8[$130>>0] = 1;
      $131 = (_getenv((165342|0))|0);
      $132 = ($131|0)==(0|0);
      if (!($132)) {
       $133 = (_strcmp($131,195630)|0);
       $134 = ($133|0)==(0);
       if ($134) {
        $142 = 1;
       } else {
        $135 = (_strcmp($131,165299)|0);
        $136 = ($135|0)==(0);
        if ($136) {
         $142 = 1;
        } else {
         $137 = (_strcmp($131,165303)|0);
         $138 = ($137|0)==(0);
         if ($138) {
          $142 = 1;
         } else {
          $139 = (_strcmp($131,165306)|0);
          $140 = ($139|0)==(0);
          $142 = $140;
         }
        }
       }
       $141 = $142&1;
       HEAP8[$130>>0] = $141;
      }
      $143 = ((($0)) + 124|0);
      HEAP32[$143>>2] = 300;
      $144 = (_getenv((165372|0))|0);
      $145 = ($144|0)==(0|0);
      L60: do {
       if (!($145)) {
        $146 = (_atoi($144)|0);
        HEAP32[$143>>2] = $146;
        __THREW__ = 0;
        $147 = (invoke_ii(3265,3)|0);
        $148 = __THREW__; __THREW__ = 0;
        $149 = $148&1;
        if ($149) {
         label = 14;
         break L50;
        }
        if ($147) {
         __THREW__ = 0;
         $150 = (invoke_ii(3266,3)|0);
         $151 = __THREW__; __THREW__ = 0;
         $152 = $151&1;
         if ($152) {
          label = 14;
          break L50;
         }
         __THREW__ = 0;
         $153 = (invoke_iiii(3267,($150|0),(165389|0),32)|0);
         $154 = __THREW__; __THREW__ = 0;
         $155 = $154&1;
         if ($155) {
          label = 14;
          break L50;
         }
         $156 = HEAP32[$143>>2]|0;
         __THREW__ = 0;
         $157 = (invoke_iii(3417,($153|0),($156|0))|0);
         $158 = __THREW__; __THREW__ = 0;
         $159 = $158&1;
         if ($159) {
          label = 14;
          break L50;
         }
         $160 = HEAP32[$157>>2]|0;
         $161 = ((($160)) + -12|0);
         $162 = HEAP32[$161>>2]|0;
         $163 = (($157) + ($162)|0);
         __THREW__ = 0;
         invoke_vii(3257,($1|0),($163|0));
         $164 = __THREW__; __THREW__ = 0;
         $165 = $164&1;
         if ($165) {
          label = 14;
          break L50;
         }
         __THREW__ = 0;
         $166 = (invoke_iii(3255,($1|0),(215188|0))|0);
         $167 = __THREW__; __THREW__ = 0;
         $168 = $167&1;
         do {
          if (!($168)) {
           $169 = HEAP32[$166>>2]|0;
           $170 = ((($169)) + 28|0);
           $171 = HEAP32[$170>>2]|0;
           __THREW__ = 0;
           $172 = (invoke_iii($171|0,($166|0),10)|0);
           $173 = __THREW__; __THREW__ = 0;
           $174 = $173&1;
           if ($174) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3263,($1|0));
           $181 = __THREW__; __THREW__ = 0;
           $182 = $181&1;
           if ($182) {
            label = 14;
            break L50;
           }
           __THREW__ = 0;
           (invoke_iii(3268,($157|0),($172|0))|0);
           $183 = __THREW__; __THREW__ = 0;
           $184 = $183&1;
           if ($184) {
            label = 14;
            break L50;
           }
           __THREW__ = 0;
           (invoke_ii(3269,($157|0))|0);
           $185 = __THREW__; __THREW__ = 0;
           $186 = $185&1;
           if ($186) {
            label = 14;
            break L50;
           } else {
            break L60;
           }
          }
         } while(0);
         $175 = ___cxa_find_matching_catch_2()|0;
         $176 = tempRet0;
         __THREW__ = 0;
         invoke_vi(3263,($1|0));
         $177 = __THREW__; __THREW__ = 0;
         $178 = $177&1;
         if ($178) {
          $179 = ___cxa_find_matching_catch_3(0|0)|0;
          $180 = tempRet0;
          ___clang_call_terminate($179);
          // unreachable;
         } else {
          $eh$lpad$body$index9Z2D = $176;$eh$lpad$body$indexZ2D = $175;
          label = 15;
          break L50;
         }
        }
       }
      } while(0);
      $187 = ((($0)) + 128|0);
      HEAP8[$187>>0] = 1;
      $188 = (_getenv((165422|0))|0);
      $189 = ($188|0)==(0|0);
      if (!($189)) {
       $190 = (_strcmp($188,195630)|0);
       $191 = ($190|0)==(0);
       if ($191) {
        $199 = 1;
       } else {
        $192 = (_strcmp($188,165299)|0);
        $193 = ($192|0)==(0);
        if ($193) {
         $199 = 1;
        } else {
         $194 = (_strcmp($188,165303)|0);
         $195 = ($194|0)==(0);
         if ($195) {
          $199 = 1;
         } else {
          $196 = (_strcmp($188,165306)|0);
          $197 = ($196|0)==(0);
          $199 = $197;
         }
        }
       }
       $198 = $199&1;
       HEAP8[$187>>0] = $198;
      }
      $200 = ((($0)) + 136|0);
      HEAPF64[$200>>3] = 1.7976931348623157E+308;
      $201 = ((($0)) + 144|0);
      HEAPF64[$201>>3] = -1.7976931348623157E+308;
      $202 = ((($0)) + 152|0);
      HEAPF64[$202>>3] = 0.0;
      $203 = ((($0)) + 160|0);
      HEAP32[$203>>2] = 0;
      __THREW__ = 0;
      $204 = (invoke_ii(3276,84)|0);
      $205 = __THREW__; __THREW__ = 0;
      $206 = $205&1;
      if ($206) {
       label = 14;
      } else {
       ;HEAP32[$3>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;
       __THREW__ = 0;
       $207 = (invoke_ii(3276,32)|0);
       $208 = __THREW__; __THREW__ = 0;
       $209 = $208&1;
       do {
        if ($209) {
         $297 = ___cxa_find_matching_catch_2()|0;
         $298 = tempRet0;
         $$037121 = $298;$$039120 = $297;
        } else {
         HEAP32[$3>>2] = $207;
         $210 = ((($3)) + 8|0);
         HEAP32[$210>>2] = -2147483616;
         $211 = ((($3)) + 4|0);
         HEAP32[$211>>2] = 16;
         dest=$207; src=163940; stop=dest+16|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
         $212 = ((($207)) + 16|0);
         HEAP8[$212>>0] = 0;
         __THREW__ = 0;
         invoke_viii(4142,($204|0),($0|0),($3|0));
         $213 = __THREW__; __THREW__ = 0;
         $214 = $213&1;
         L90: do {
          if ($214) {
           $$034 = 1;
          } else {
           $215 = HEAP32[$22>>2]|0;
           $216 = ($215|0)==($204|0);
           do {
            if (!($216)) {
             HEAP32[$22>>2] = $204;
             $217 = ((($204)) + 8|0);
             $218 = HEAP32[$217>>2]|0;HEAP32[$217>>2] = (($218+1)|0);
             $219 = ($215|0)==(0|0);
             if (!($219)) {
              $220 = ((($215)) + 8|0);
              $221 = HEAP32[$220>>2]|0;HEAP32[$220>>2] = (($221-1)|0);
              $222 = ($221|0)==(1);
              if (!($222)) {
               break;
              }
              __THREW__ = 0;
              invoke_viii(3262,($215|0),1,1);
              $223 = __THREW__; __THREW__ = 0;
              $224 = $223&1;
              if ($224) {
               $$034 = 0;
               break L90;
              }
             }
            }
           } while(0);
           $225 = ((($3)) + 11|0);
           $226 = HEAP8[$225>>0]|0;
           $227 = ($226<<24>>24)<(0);
           if ($227) {
            $228 = HEAP32[$3>>2]|0;
            __ZdlPv($228);
           }
           __THREW__ = 0;
           $229 = (invoke_ii(3276,84)|0);
           $230 = __THREW__; __THREW__ = 0;
           $231 = $230&1;
           if ($231) {
            label = 14;
            break L50;
           }
           ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;
           __THREW__ = 0;
           $232 = (invoke_ii(3276,32)|0);
           $233 = __THREW__; __THREW__ = 0;
           $234 = $233&1;
           do {
            if ($234) {
             $305 = ___cxa_find_matching_catch_2()|0;
             $306 = tempRet0;
             $$138123 = $306;$$140122 = $305;
            } else {
             HEAP32[$4>>2] = $232;
             $235 = ((($4)) + 8|0);
             HEAP32[$235>>2] = -2147483616;
             $236 = ((($4)) + 4|0);
             HEAP32[$236>>2] = 16;
             dest=$232; src=163957; stop=dest+16|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
             $237 = ((($232)) + 16|0);
             HEAP8[$237>>0] = 0;
             __THREW__ = 0;
             invoke_viii(4142,($229|0),($0|0),($4|0));
             $238 = __THREW__; __THREW__ = 0;
             $239 = $238&1;
             L104: do {
              if ($239) {
               $$0 = 1;
              } else {
               $240 = HEAP32[$23>>2]|0;
               $241 = ($240|0)==($229|0);
               do {
                if (!($241)) {
                 HEAP32[$23>>2] = $229;
                 $242 = ((($229)) + 8|0);
                 $243 = HEAP32[$242>>2]|0;HEAP32[$242>>2] = (($243+1)|0);
                 $244 = ($240|0)==(0|0);
                 if ($244) {
                  break;
                 }
                 $245 = ((($240)) + 8|0);
                 $246 = HEAP32[$245>>2]|0;HEAP32[$245>>2] = (($246-1)|0);
                 $247 = ($246|0)==(1);
                 if (!($247)) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_viii(3262,($240|0),1,1);
                 $248 = __THREW__; __THREW__ = 0;
                 $249 = $248&1;
                 if ($249) {
                  $$0 = 0;
                  break L104;
                 }
                }
               } while(0);
               $250 = ((($4)) + 11|0);
               $251 = HEAP8[$250>>0]|0;
               $252 = ($251<<24>>24)<(0);
               if ($252) {
                $253 = HEAP32[$4>>2]|0;
                __ZdlPv($253);
               }
               __THREW__ = 0;
               $254 = (invoke_ii(3276,44)|0);
               $255 = __THREW__; __THREW__ = 0;
               $256 = $255&1;
               if ($256) {
                label = 14;
                break L50;
               }
               __THREW__ = 0;
               invoke_vii(4143,($254|0),($0|0));
               $257 = __THREW__; __THREW__ = 0;
               $258 = $257&1;
               if ($258) {
                $313 = ___cxa_find_matching_catch_2()|0;
                $314 = tempRet0;
                __ZdlPv($254);
                $$2 = $314;$$241 = $313;
                break L50;
               }
               $259 = HEAP32[$24>>2]|0;
               $260 = ($259|0)==($254|0);
               do {
                if (!($260)) {
                 HEAP32[$24>>2] = $254;
                 $261 = ((($254)) + 8|0);
                 $262 = HEAP32[$261>>2]|0;HEAP32[$261>>2] = (($262+1)|0);
                 $263 = ($259|0)==(0|0);
                 if ($263) {
                  break;
                 }
                 $264 = ((($259)) + 8|0);
                 $265 = HEAP32[$264>>2]|0;HEAP32[$264>>2] = (($265-1)|0);
                 $266 = ($265|0)==(1);
                 if (!($266)) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_viii(3262,($259|0),1,1);
                 $267 = __THREW__; __THREW__ = 0;
                 $268 = $267&1;
                 if ($268) {
                  label = 14;
                  break L50;
                 }
                }
               } while(0);
               __THREW__ = 0;
               $269 = (invoke_ii(3276,44)|0);
               $270 = __THREW__; __THREW__ = 0;
               $271 = $270&1;
               if ($271) {
                label = 14;
                break L50;
               }
               __THREW__ = 0;
               invoke_vii(4143,($269|0),($0|0));
               $272 = __THREW__; __THREW__ = 0;
               $273 = $272&1;
               if ($273) {
                $315 = ___cxa_find_matching_catch_2()|0;
                $316 = tempRet0;
                __ZdlPv($269);
                $$2 = $316;$$241 = $315;
                break L50;
               }
               $274 = HEAP32[$25>>2]|0;
               $275 = ($274|0)==($269|0);
               do {
                if (!($275)) {
                 HEAP32[$25>>2] = $269;
                 $276 = ((($269)) + 8|0);
                 $277 = HEAP32[$276>>2]|0;HEAP32[$276>>2] = (($277+1)|0);
                 $278 = ($274|0)==(0|0);
                 if ($278) {
                  break;
                 }
                 $279 = ((($274)) + 8|0);
                 $280 = HEAP32[$279>>2]|0;HEAP32[$279>>2] = (($280-1)|0);
                 $281 = ($280|0)==(1);
                 if (!($281)) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_viii(3262,($274|0),1,1);
                 $282 = __THREW__; __THREW__ = 0;
                 $283 = $282&1;
                 if ($283) {
                  label = 14;
                  break L50;
                 }
                }
               } while(0);
               $284 = (_getenv((165441|0))|0);
               $285 = ($284|0)==(0|0);
               L132: do {
                if (!($285)) {
                 $286 = (_strcmp($284,165469)|0);
                 $287 = ($286|0)==(0);
                 if ($287) {
                  $288 = ((($0)) + 56|0);
                  $289 = HEAP32[$288>>2]|0;
                  $290 = HEAP32[$16>>2]|0;
                  $291 = ($289|0)==($290|0);
                  if ($291) {
                   break;
                  } else {
                   $$sroa$04$08$i = $289;
                  }
                  while(1) {
                   __THREW__ = 0;
                   $292 = __THREW__; __THREW__ = 0;
                   $293 = $292&1;
                   if ($293) {
                    break;
                   }
                   $294 = ((($$sroa$04$08$i)) + 4|0);
                   $295 = HEAP32[$16>>2]|0;
                   $296 = ($294|0)==($295|0);
                   if ($296) {
                    break L132;
                   } else {
                    $$sroa$04$08$i = $294;
                   }
                  }
                  $44 = ___cxa_find_matching_catch_2()|0;
                  $45 = tempRet0;
                  $eh$lpad$body$index9Z2D = $45;$eh$lpad$body$indexZ2D = $44;
                  label = 15;
                  break L50;
                 }
                 $317 = (_strcmp($284,165477)|0);
                 $318 = ($317|0)==(0);
                 if ($318) {
                  $319 = ((($0)) + 56|0);
                  $320 = HEAP32[$319>>2]|0;
                  $321 = HEAP32[$16>>2]|0;
                  $322 = ($320|0)==($321|0);
                  if ($322) {
                   break;
                  } else {
                   $$sroa$04$08$i92 = $320;
                  }
                  while(1) {
                   __THREW__ = 0;
                   $323 = __THREW__; __THREW__ = 0;
                   $324 = $323&1;
                   if ($324) {
                    break;
                   }
                   $325 = ((($$sroa$04$08$i92)) + 4|0);
                   $326 = HEAP32[$16>>2]|0;
                   $327 = ($325|0)==($326|0);
                   if ($327) {
                    break L132;
                   } else {
                    $$sroa$04$08$i92 = $325;
                   }
                  }
                  $46 = ___cxa_find_matching_catch_2()|0;
                  $47 = tempRet0;
                  $eh$lpad$body$index9Z2D = $47;$eh$lpad$body$indexZ2D = $46;
                  label = 15;
                  break L50;
                 }
                 $328 = (_strcmp($284,165481)|0);
                 $329 = ($328|0)==(0);
                 if ($329) {
                  $330 = ((($0)) + 56|0);
                  $331 = HEAP32[$330>>2]|0;
                  $332 = HEAP32[$16>>2]|0;
                  $333 = ($331|0)==($332|0);
                  if ($333) {
                   break;
                  } else {
                   $$sroa$04$08$i97 = $331;
                  }
                  while(1) {
                   __THREW__ = 0;
                   $334 = __THREW__; __THREW__ = 0;
                   $335 = $334&1;
                   if ($335) {
                    break;
                   }
                   $336 = ((($$sroa$04$08$i97)) + 4|0);
                   $337 = HEAP32[$16>>2]|0;
                   $338 = ($336|0)==($337|0);
                   if ($338) {
                    break L132;
                   } else {
                    $$sroa$04$08$i97 = $336;
                   }
                  }
                  $48 = ___cxa_find_matching_catch_2()|0;
                  $49 = tempRet0;
                  $eh$lpad$body$index9Z2D = $49;$eh$lpad$body$indexZ2D = $48;
                  label = 15;
                  break L50;
                 }
                 $339 = (_strcmp($284,165485)|0);
                 $340 = ($339|0)==(0);
                 if ($340) {
                  $341 = ((($0)) + 56|0);
                  $342 = HEAP32[$341>>2]|0;
                  $343 = HEAP32[$16>>2]|0;
                  $344 = ($342|0)==($343|0);
                  if ($344) {
                   break;
                  } else {
                   $$sroa$04$08$i102 = $342;
                  }
                  while(1) {
                   __THREW__ = 0;
                   $345 = __THREW__; __THREW__ = 0;
                   $346 = $345&1;
                   if ($346) {
                    break;
                   }
                   $347 = ((($$sroa$04$08$i102)) + 4|0);
                   $348 = HEAP32[$16>>2]|0;
                   $349 = ($347|0)==($348|0);
                   if ($349) {
                    break L132;
                   } else {
                    $$sroa$04$08$i102 = $347;
                   }
                  }
                  $50 = ___cxa_find_matching_catch_2()|0;
                  $51 = tempRet0;
                  $eh$lpad$body$index9Z2D = $51;$eh$lpad$body$indexZ2D = $50;
                  label = 15;
                  break L50;
                 }
                 $350 = (_strcmp($284,165493)|0);
                 $351 = ($350|0)==(0);
                 if ($351) {
                  $352 = ((($0)) + 56|0);
                  $353 = HEAP32[$352>>2]|0;
                  $354 = HEAP32[$16>>2]|0;
                  $355 = ($353|0)==($354|0);
                  if ($355) {
                   break;
                  } else {
                   $$sroa$04$08$i107 = $353;
                  }
                  while(1) {
                   __THREW__ = 0;
                   $356 = __THREW__; __THREW__ = 0;
                   $357 = $356&1;
                   if ($357) {
                    break;
                   }
                   $358 = ((($$sroa$04$08$i107)) + 4|0);
                   $359 = HEAP32[$16>>2]|0;
                   $360 = ($358|0)==($359|0);
                   if ($360) {
                    break L132;
                   } else {
                    $$sroa$04$08$i107 = $358;
                   }
                  }
                  $52 = ___cxa_find_matching_catch_2()|0;
                  $53 = tempRet0;
                  $eh$lpad$body$index9Z2D = $53;$eh$lpad$body$indexZ2D = $52;
                  label = 15;
                  break L50;
                 }
                 $361 = (_strcmp($284,165498)|0);
                 $362 = ($361|0)==(0);
                 if (!($362)) {
                  break;
                 }
                 $363 = ((($0)) + 56|0);
                 $364 = HEAP32[$363>>2]|0;
                 $365 = HEAP32[$16>>2]|0;
                 $366 = ($364|0)==($365|0);
                 if ($366) {
                  break;
                 } else {
                  $$sroa$04$08$i112 = $364;
                 }
                 while(1) {
                  __THREW__ = 0;
                  $367 = __THREW__; __THREW__ = 0;
                  $368 = $367&1;
                  if ($368) {
                   break;
                  }
                  $369 = ((($$sroa$04$08$i112)) + 4|0);
                  $370 = HEAP32[$16>>2]|0;
                  $371 = ($369|0)==($370|0);
                  if ($371) {
                   break L132;
                  } else {
                   $$sroa$04$08$i112 = $369;
                  }
                 }
                 $54 = ___cxa_find_matching_catch_2()|0;
                 $55 = tempRet0;
                 $eh$lpad$body$index9Z2D = $55;$eh$lpad$body$indexZ2D = $54;
                 label = 15;
                 break L50;
                }
               } while(0);
               __THREW__ = 0;
               $372 = (invoke_ii(3276,24)|0);
               $373 = __THREW__; __THREW__ = 0;
               $374 = $373&1;
               if ($374) {
                label = 14;
                break L50;
               }
               __THREW__ = 0;
               invoke_vi(3282,($372|0));
               $375 = __THREW__; __THREW__ = 0;
               $376 = $375&1;
               if ($376) {
                $390 = ___cxa_find_matching_catch_2()|0;
                $391 = tempRet0;
                __ZdlPv($372);
                $$2 = $391;$$241 = $390;
                break L50;
               }
               HEAP32[$372>>2] = (74288);
               $377 = ((($372)) + 16|0);
               HEAP32[$377>>2] = 0;
               $378 = ((($372)) + 20|0);
               HEAP32[$378>>2] = 0;
               $379 = ((($372)) + 12|0);
               HEAP32[$379>>2] = $377;
               $380 = HEAP32[$26>>2]|0;
               $381 = ($380|0)==($372|0);
               if ($381) {
                STACKTOP = sp;return;
               }
               HEAP32[$26>>2] = $372;
               $382 = ((($372)) + 8|0);
               $383 = HEAP32[$382>>2]|0;HEAP32[$382>>2] = (($383+1)|0);
               $384 = ($380|0)==(0|0);
               if ($384) {
                STACKTOP = sp;return;
               }
               $385 = ((($380)) + 8|0);
               $386 = HEAP32[$385>>2]|0;HEAP32[$385>>2] = (($386-1)|0);
               $387 = ($386|0)==(1);
               if (!($387)) {
                STACKTOP = sp;return;
               }
               __THREW__ = 0;
               invoke_viii(3262,($380|0),1,1);
               $388 = __THREW__; __THREW__ = 0;
               $389 = $388&1;
               if ($389) {
                label = 14;
                break L50;
               }
               STACKTOP = sp;return;
              }
             } while(0);
             $307 = ___cxa_find_matching_catch_2()|0;
             $308 = tempRet0;
             $309 = ((($4)) + 11|0);
             $310 = HEAP8[$309>>0]|0;
             $311 = ($310<<24>>24)<(0);
             if ($311) {
              $312 = HEAP32[$4>>2]|0;
              __ZdlPv($312);
              if ($$0) {
               $$138123 = $308;$$140122 = $307;
               break;
              } else {
               $$2 = $308;$$241 = $307;
               break L50;
              }
             } else {
              if ($$0) {
               $$138123 = $308;$$140122 = $307;
               break;
              } else {
               $$2 = $308;$$241 = $307;
               break L50;
              }
             }
            }
           } while(0);
           __ZdlPv($229);
           $$2 = $$138123;$$241 = $$140122;
           break L50;
          }
         } while(0);
         $299 = ___cxa_find_matching_catch_2()|0;
         $300 = tempRet0;
         $301 = ((($3)) + 11|0);
         $302 = HEAP8[$301>>0]|0;
         $303 = ($302<<24>>24)<(0);
         if ($303) {
          $304 = HEAP32[$3>>2]|0;
          __ZdlPv($304);
          if ($$034) {
           $$037121 = $300;$$039120 = $299;
           break;
          } else {
           $$2 = $300;$$241 = $299;
           break L50;
          }
         } else {
          if ($$034) {
           $$037121 = $300;$$039120 = $299;
           break;
          } else {
           $$2 = $300;$$241 = $299;
           break L50;
          }
         }
        }
       } while(0);
       __ZdlPv($204);
       $$2 = $$037121;$$241 = $$039120;
      }
     }
    } while(0);
    if ((label|0) == 14) {
     $56 = ___cxa_find_matching_catch_2()|0;
     $57 = tempRet0;
     $eh$lpad$body$index9Z2D = $57;$eh$lpad$body$indexZ2D = $56;
     label = 15;
    }
    if ((label|0) == 15) {
     $$2 = $eh$lpad$body$index9Z2D;$$241 = $eh$lpad$body$indexZ2D;
    }
    $392 = HEAP32[$28>>2]|0;
    $393 = ($392|0)==(0|0);
    if (!($393)) {
     $394 = ((($392)) + 8|0);
     $395 = HEAP32[$394>>2]|0;HEAP32[$394>>2] = (($395-1)|0);
     $396 = ($395|0)==(1);
     if ($396) {
      __THREW__ = 0;
      invoke_viii(3262,($392|0),1,1);
      $397 = __THREW__; __THREW__ = 0;
      $398 = $397&1;
      if ($398) {
       $472 = ___cxa_find_matching_catch_3(0|0)|0;
       $473 = tempRet0;
       ___clang_call_terminate($472);
       // unreachable;
      }
     }
    }
    HEAP32[$28>>2] = 0;
    $399 = HEAP32[$27>>2]|0;
    $400 = ($399|0)==(0|0);
    if (!($400)) {
     $401 = HEAP32[$399>>2]|0;
     $402 = ((($401)) + -12|0);
     $403 = HEAP32[$402>>2]|0;
     $404 = (($399) + ($403)|0);
     $405 = ((($404)) + 8|0);
     $406 = HEAP32[$405>>2]|0;HEAP32[$405>>2] = (($406-1)|0);
     $407 = ($406|0)==(1);
     if ($407) {
      __THREW__ = 0;
      invoke_viii(3262,($404|0),1,1);
      $408 = __THREW__; __THREW__ = 0;
      $409 = $408&1;
      if ($409) {
       $472 = ___cxa_find_matching_catch_3(0|0)|0;
       $473 = tempRet0;
       ___clang_call_terminate($472);
       // unreachable;
      }
     }
    }
    HEAP32[$27>>2] = 0;
    $410 = HEAP32[$26>>2]|0;
    $411 = ($410|0)==(0|0);
    if (!($411)) {
     $412 = ((($410)) + 8|0);
     $413 = HEAP32[$412>>2]|0;HEAP32[$412>>2] = (($413-1)|0);
     $414 = ($413|0)==(1);
     if ($414) {
      __THREW__ = 0;
      invoke_viii(3262,($410|0),1,1);
      $415 = __THREW__; __THREW__ = 0;
      $416 = $415&1;
      if ($416) {
       $472 = ___cxa_find_matching_catch_3(0|0)|0;
       $473 = tempRet0;
       ___clang_call_terminate($472);
       // unreachable;
      }
     }
    }
    HEAP32[$26>>2] = 0;
    $417 = HEAP32[$25>>2]|0;
    $418 = ($417|0)==(0|0);
    if (!($418)) {
     $419 = ((($417)) + 8|0);
     $420 = HEAP32[$419>>2]|0;HEAP32[$419>>2] = (($420-1)|0);
     $421 = ($420|0)==(1);
     if ($421) {
      __THREW__ = 0;
      invoke_viii(3262,($417|0),1,1);
      $422 = __THREW__; __THREW__ = 0;
      $423 = $422&1;
      if ($423) {
       $472 = ___cxa_find_matching_catch_3(0|0)|0;
       $473 = tempRet0;
       ___clang_call_terminate($472);
       // unreachable;
      }
     }
    }
    HEAP32[$25>>2] = 0;
    $424 = HEAP32[$24>>2]|0;
    $425 = ($424|0)==(0|0);
    if (!($425)) {
     $426 = ((($424)) + 8|0);
     $427 = HEAP32[$426>>2]|0;HEAP32[$426>>2] = (($427-1)|0);
     $428 = ($427|0)==(1);
     if ($428) {
      __THREW__ = 0;
      invoke_viii(3262,($424|0),1,1);
      $429 = __THREW__; __THREW__ = 0;
      $430 = $429&1;
      if ($430) {
       $472 = ___cxa_find_matching_catch_3(0|0)|0;
       $473 = tempRet0;
       ___clang_call_terminate($472);
       // unreachable;
      }
     }
    }
    HEAP32[$24>>2] = 0;
    $431 = HEAP32[$23>>2]|0;
    $432 = ($431|0)==(0|0);
    if (!($432)) {
     $433 = ((($431)) + 8|0);
     $434 = HEAP32[$433>>2]|0;HEAP32[$433>>2] = (($434-1)|0);
     $435 = ($434|0)==(1);
     if ($435) {
      __THREW__ = 0;
      invoke_viii(3262,($431|0),1,1);
      $436 = __THREW__; __THREW__ = 0;
      $437 = $436&1;
      if ($437) {
       $472 = ___cxa_find_matching_catch_3(0|0)|0;
       $473 = tempRet0;
       ___clang_call_terminate($472);
       // unreachable;
      }
     }
    }
    HEAP32[$23>>2] = 0;
    $438 = HEAP32[$22>>2]|0;
    $439 = ($438|0)==(0|0);
    if (!($439)) {
     $440 = ((($438)) + 8|0);
     $441 = HEAP32[$440>>2]|0;HEAP32[$440>>2] = (($441-1)|0);
     $442 = ($441|0)==(1);
     if ($442) {
      __THREW__ = 0;
      invoke_viii(3262,($438|0),1,1);
      $443 = __THREW__; __THREW__ = 0;
      $444 = $443&1;
      if ($444) {
       $472 = ___cxa_find_matching_catch_3(0|0)|0;
       $473 = tempRet0;
       ___clang_call_terminate($472);
       // unreachable;
      }
     }
    }
    HEAP32[$22>>2] = 0;
    __THREW__ = 0;
    invoke_vi(707,($18|0));
    $445 = __THREW__; __THREW__ = 0;
    $446 = $445&1;
    if ($446) {
     $472 = ___cxa_find_matching_catch_3(0|0)|0;
     $473 = tempRet0;
     ___clang_call_terminate($472);
     // unreachable;
    } else {
     $$4 = $$2;$$443 = $$241;
    }
   }
   $447 = HEAP32[$15>>2]|0;
   $448 = ($447|0)==(0|0);
   if (!($448)) {
    $449 = HEAP32[$16>>2]|0;
    $450 = ($449|0)==($447|0);
    do {
     if ($450) {
      $464 = $447;
     } else {
      $452 = $449;
      while(1) {
       $451 = ((($452)) + -4|0);
       HEAP32[$16>>2] = $451;
       $453 = HEAP32[$451>>2]|0;
       $454 = ($453|0)==(0|0);
       if (!($454)) {
        $455 = ((($453)) + 8|0);
        $456 = HEAP32[$455>>2]|0;HEAP32[$455>>2] = (($456-1)|0);
        $457 = ($456|0)==(1);
        if ($457) {
         __THREW__ = 0;
         invoke_viii(3262,($453|0),1,1);
         $458 = __THREW__; __THREW__ = 0;
         $459 = $458&1;
         if ($459) {
          label = 176;
          break;
         }
        }
       }
       HEAP32[$451>>2] = 0;
       $460 = HEAP32[$16>>2]|0;
       $461 = ($460|0)==($447|0);
       if ($461) {
        label = 177;
        break;
       } else {
        $452 = $460;
       }
      }
      if ((label|0) == 176) {
       $462 = ___cxa_find_matching_catch_2()|0;
       $463 = tempRet0;
       ___cxa_call_unexpected(($462|0));
       // unreachable;
      }
      else if ((label|0) == 177) {
       $$pre$i = HEAP32[$15>>2]|0;
       $464 = $$pre$i;
       break;
      }
     }
    } while(0);
    __ZdlPv($464);
   }
   $465 = HEAP32[$14>>2]|0;
   __ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEE7destroyEPNS_11__tree_nodeIjPvEE($11,$465);
   __THREW__ = 0;
   invoke_vi(707,($8|0));
   $466 = __THREW__; __THREW__ = 0;
   $467 = $466&1;
   if ($467) {
    $472 = ___cxa_find_matching_catch_3(0|0)|0;
    $473 = tempRet0;
    ___clang_call_terminate($472);
    // unreachable;
   } else {
    $$7 = $$4;$$746 = $$443;
   }
  }
  __THREW__ = 0;
  invoke_vi(707,($5|0));
  $468 = __THREW__; __THREW__ = 0;
  $469 = $468&1;
  if ($469) {
   $472 = ___cxa_find_matching_catch_3(0|0)|0;
   $473 = tempRet0;
   ___clang_call_terminate($472);
   // unreachable;
  } else {
   $$8 = $$7;$$847 = $$746;
  }
 }
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $470 = __THREW__; __THREW__ = 0;
 $471 = $470&1;
 if ($471) {
  $472 = ___cxa_find_matching_catch_3(0|0)|0;
  $473 = tempRet0;
  ___clang_call_terminate($472);
  // unreachable;
 } else {
  ___resumeException($$847|0);
  // unreachable;
 }
}
function __ZN3osg7ref_ptrIN5osgDB13DatabasePagerEED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = ((($1)) + 8|0);
  $4 = HEAP32[$3>>2]|0;HEAP32[$3>>2] = (($4-1)|0);
  $5 = ($4|0)==(1);
  if ($5) {
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($1,1,1);
  }
 }
 HEAP32[$0>>2] = 0;
 return;
}
function __ZN20SetBasedPagedLODListD2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (74288);
 $1 = ((($0)) + 12|0);
 $2 = ((($0)) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 __ZNSt3__26__treeIN3osg12observer_ptrINS1_8PagedLODEEENS_4lessIS4_EENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($1,$3);
 __ZN3osg10ReferencedD2Ev($0);
 return;
}
function __ZN20SetBasedPagedLODListD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (74288);
 $1 = ((($0)) + 12|0);
 $2 = ((($0)) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 __ZNSt3__26__treeIN3osg12observer_ptrINS1_8PagedLODEEENS_4lessIS4_EENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($1,$3);
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch_2()|0;
  $7 = tempRet0;
  __ZdlPv($0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZN20SetBasedPagedLODList5cloneEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(24)|0);
 ;HEAP32[$1>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;HEAP32[$1+12>>2]=0|0;HEAP32[$1+16>>2]=0|0;HEAP32[$1+20>>2]=0|0;
 __THREW__ = 0;
 invoke_vi(3282,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $7 = ___cxa_find_matching_catch_2()|0;
  $8 = tempRet0;
  __ZdlPv($1);
  ___resumeException($7|0);
  // unreachable;
 } else {
  HEAP32[$1>>2] = (74288);
  $4 = ((($1)) + 16|0);
  HEAP32[$4>>2] = 0;
  $5 = ((($1)) + 20|0);
  HEAP32[$5>>2] = 0;
  $6 = ((($1)) + 12|0);
  HEAP32[$6>>2] = $4;
  return ($1|0);
 }
 return (0)|0;
}
function __ZN20SetBasedPagedLODList5clearEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 12|0);
 $2 = ((($0)) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 __ZNSt3__26__treeIN3osg12observer_ptrINS1_8PagedLODEEENS_4lessIS4_EENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($1,$3);
 $4 = ((($0)) + 20|0);
 HEAP32[$4>>2] = 0;
 HEAP32[$1>>2] = $2;
 HEAP32[$2>>2] = 0;
 return;
}
function __ZN20SetBasedPagedLODList4sizeEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 20|0);
 $2 = HEAP32[$1>>2]|0;
 return ($2|0);
}
function __ZN20SetBasedPagedLODList21removeExpiredChildrenEidjRNSt3__24listIN3osg7ref_ptrINS2_6ObjectEEENS0_9allocatorIS5_EEEEb($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = +$2;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$0$i$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$i$i$i$i71 = 0, $$0$i$i$i64 = 0, $$0$i$i$i70 = 0, $$0$i$i$i70218 = 0, $$0$i$i$i70219 = 0, $$015 = 0, $$016$i = 0, $$020 = 0, $$0204 = 0, $$1$ = 0, $$1$lcssa = 0, $$1202 = 0, $$217 = 0, $$222 = 0, $$3 = 0, $$4 = 0, $$5 = 0;
 var $$525 = 0, $$7 = 0, $$727 = 0, $$in = 0, $$in$i = 0, $$in233 = 0, $$pre = 0, $$pre$i = 0, $$pre$i54 = 0, $$pre216 = 0, $$pre217 = 0, $$sroa$013$0$i = 0, $$sroa$079$0$be = 0, $$sroa$079$0201 = 0, $$sroa$086$0203 = 0, $$sroa$086$1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0;
 var $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0;
 var $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0;
 var $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0;
 var $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0;
 var $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0;
 var $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0;
 var $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0;
 var $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0;
 var $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0;
 var $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0;
 var $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, $eh$lpad$body36$index7Z2D = 0, $eh$lpad$body36$indexZ2D = 0, $eh$lpad$body47$index16Z2D = 0, $eh$lpad$body47$indexZ2D = 0, $eh$lpad$body50$index25Z2D = 0, $eh$lpad$body50$indexZ2D = 0, $eh$lpad$body61$indexZ2D = 0, $not$ = 0, $tmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(128|0);
 $6 = sp + 124|0;
 $7 = sp + 120|0;
 $8 = sp + 20|0;
 $9 = sp + 8|0;
 $10 = sp;
 $11 = ((($0)) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ((($0)) + 16|0);
 $14 = ($12|0)!=($13|0);
 $15 = ($1|0)>(0);
 $16 = $14 & $15;
 if (!($16)) {
  STACKTOP = sp;return;
 }
 $17 = ((($8)) + 68|0);
 $18 = ((($8)) + 80|0);
 $19 = ((($8)) + 92|0);
 $20 = ((($8)) + 96|0);
 $21 = ((($8)) + 60|0);
 $22 = ((($8)) + 64|0);
 $23 = ((($8)) + 60|0);
 $24 = ((($8)) + 56|0);
 $25 = ((($9)) + 4|0);
 $26 = ((($9)) + 8|0);
 $27 = ((($8)) + 56|0);
 $28 = ((($4)) + 8|0);
 $29 = ((($0)) + 20|0);
 $30 = ((($0)) + 16|0);
 $$0204 = $1;$$sroa$086$0203 = $12;
 L4: while(1) {
  HEAP32[$7>>2] = 0;
  $31 = ((($$sroa$086$0203)) + 16|0);
  __THREW__ = 0;
  $32 = (invoke_iii(4149,($31|0),($7|0))|0);
  $33 = __THREW__; __THREW__ = 0;
  $34 = $33&1;
  if ($34) {
   label = 16;
   break;
  }
  do {
   if ($32) {
    $35 = HEAP32[$7>>2]|0;
    $36 = ((($35)) + 188|0);
    $37 = HEAP32[$36>>2]|0;
    $38 = ($37>>>0)>($3>>>0);
    $tmp = $38 ^ $5;
    if ($tmp) {
     $$3 = $$0204;
    } else {
     __THREW__ = 0;
     invoke_vi(3282,($17|0));
     $39 = __THREW__; __THREW__ = 0;
     $40 = $39&1;
     if ($40) {
      label = 18;
      break L4;
     }
     HEAP32[$17>>2] = (63412);
     ;HEAP32[$18>>2]=0|0;HEAP32[$18+4>>2]=0|0;HEAP32[$18+8>>2]=0|0;
     HEAP32[$19>>2] = 2;
     HEAP32[$20>>2] = 0;
     __THREW__ = 0;
     invoke_viii(3283,($8|0),((74332)|0),2);
     $41 = __THREW__; __THREW__ = 0;
     $42 = $41&1;
     if ($42) {
      label = 9;
      break L4;
     }
     HEAP32[$8>>2] = (74356);
     HEAP32[$17>>2] = (74700);
     HEAP32[$21>>2] = 0;
     HEAP32[$22>>2] = 0;
     HEAP32[$24>>2] = $23;
     HEAP32[$9>>2] = 0;
     HEAP32[$25>>2] = 0;
     HEAP32[$26>>2] = 0;
     $49 = HEAP32[$7>>2]|0;
     $50 = HEAP32[$49>>2]|0;
     $51 = ((($50)) + 248|0);
     $52 = HEAP32[$51>>2]|0;
     __THREW__ = 0;
     (invoke_iidii($52|0,($49|0),(+$2),($3|0),($9|0))|0);
     $53 = __THREW__; __THREW__ = 0;
     $54 = $53&1;
     if ($54) {
      label = 22;
      break L4;
     }
     $55 = HEAP32[$25>>2]|0;
     $56 = HEAP32[$9>>2]|0;
     $57 = ($55|0)==($56|0);
     if ($57) {
      $$in = $55;$$in233 = $56;
     } else {
      $$016$i = 0;$$in$i = $56;
      while(1) {
       $58 = $$in$i;
       $59 = (($58) + ($$016$i<<2)|0);
       $60 = HEAP32[$59>>2]|0;
       $61 = HEAP32[$60>>2]|0;
       $62 = ((($61)) + 188|0);
       $63 = HEAP32[$62>>2]|0;
       __THREW__ = 0;
       invoke_vii($63|0,($60|0),($8|0));
       $64 = __THREW__; __THREW__ = 0;
       $65 = $64&1;
       if ($65) {
        label = 21;
        break L4;
       }
       $66 = (($$016$i) + 1)|0;
       $67 = HEAP32[$25>>2]|0;
       $68 = HEAP32[$9>>2]|0;
       $69 = (($67) - ($68))|0;
       $70 = $69 >> 2;
       $71 = ($66>>>0)<($70>>>0);
       if ($71) {
        $$016$i = $66;$$in$i = $68;
       } else {
        $$in = $67;$$in233 = $68;
        break;
       }
      }
     }
     $72 = $$in233;
     $73 = $$in;
     $74 = HEAP32[$24>>2]|0;
     $75 = ($74|0)==($23|0);
     if ($75) {
      $$1$lcssa = $$0204;$129 = $72;$131 = $73;
     } else {
      $$1202 = $$0204;$$sroa$079$0201 = $74;
      while(1) {
       $88 = ((($$sroa$079$0201)) + 16|0);
       __THREW__ = 0;
       invoke_vii(4150,($10|0),($88|0));
       $89 = __THREW__; __THREW__ = 0;
       $90 = $89&1;
       if ($90) {
        label = 24;
        break L4;
       }
       __THREW__ = 0;
       $91 = (invoke_iii(4151,($11|0),($10|0))|0);
       $92 = __THREW__; __THREW__ = 0;
       $93 = $92&1;
       if ($93) {
        label = 30;
        break L4;
       }
       $not$ = ($91|0)!=(0);
       $94 = $not$ << 31 >> 31;
       $$1$ = (($94) + ($$1202))|0;
       $95 = HEAP32[$10>>2]|0;
       $96 = ($95|0)==(0|0);
       if (!($96)) {
        $97 = ((($95)) + 8|0);
        $98 = HEAP32[$97>>2]|0;HEAP32[$97>>2] = (($98-1)|0);
        $99 = ($98|0)==(1);
        if ($99) {
         __THREW__ = 0;
         invoke_viii(3262,($95|0),1,1);
         $100 = __THREW__; __THREW__ = 0;
         $101 = $100&1;
         if ($101) {
          label = 40;
          break L4;
         }
        }
       }
       $111 = ((($$sroa$079$0201)) + 4|0);
       $112 = HEAP32[$111>>2]|0;
       $113 = ($112|0)==(0|0);
       if ($113) {
        $114 = ((($$sroa$079$0201)) + 8|0);
        $115 = HEAP32[$114>>2]|0;
        $116 = HEAP32[$115>>2]|0;
        $117 = ($116|0)==($$sroa$079$0201|0);
        if ($117) {
         $$sroa$079$0$be = $115;
        } else {
         $122 = $114;
         while(1) {
          $121 = HEAP32[$122>>2]|0;
          $123 = ((($121)) + 8|0);
          $124 = HEAP32[$123>>2]|0;
          $125 = HEAP32[$124>>2]|0;
          $126 = ($125|0)==($121|0);
          if ($126) {
           $$sroa$079$0$be = $124;
           break;
          } else {
           $122 = $123;
          }
         }
        }
       } else {
        $$0$i$i$i = $112;
        while(1) {
         $119 = HEAP32[$$0$i$i$i>>2]|0;
         $120 = ($119|0)==(0|0);
         if ($120) {
          break;
         } else {
          $$0$i$i$i = $119;
         }
        }
        $$sroa$079$0$be = $$0$i$i$i;
       }
       $118 = ($$sroa$079$0$be|0)==($23|0);
       if ($118) {
        break;
       } else {
        $$1202 = $$1$;$$sroa$079$0201 = $$sroa$079$0$be;
       }
      }
      $$pre = HEAP32[$9>>2]|0;
      $$pre216 = HEAP32[$25>>2]|0;
      $$1$lcssa = $$1$;$129 = $$pre;$131 = $$pre216;
     }
     $130 = ($129|0)==($131|0);
     if ($130) {
      $163 = $129;
     } else {
      $$sroa$013$0$i = $129;
      while(1) {
       $132 = HEAP32[$$sroa$013$0$i>>2]|0;
       $133 = ($132|0)==(0|0);
       if (!($133)) {
        $134 = ((($132)) + 8|0);
        $135 = HEAP32[$134>>2]|0;HEAP32[$134>>2] = (($135+1)|0);
       }
       __THREW__ = 0;
       $136 = (invoke_ii(3276,12)|0);
       $137 = __THREW__; __THREW__ = 0;
       $138 = $137&1;
       if ($138) {
        label = 53;
        break L4;
       }
       $139 = ((($136)) + 8|0);
       HEAP32[$139>>2] = $132;
       if (!($133)) {
        $140 = ((($132)) + 8|0);
        $141 = HEAP32[$140>>2]|0;HEAP32[$140>>2] = (($141+1)|0);
       }
       $142 = ((($136)) + 4|0);
       HEAP32[$142>>2] = $4;
       $143 = HEAP32[$4>>2]|0;
       HEAP32[$136>>2] = $143;
       $144 = ((($143)) + 4|0);
       HEAP32[$144>>2] = $136;
       HEAP32[$4>>2] = $136;
       $145 = HEAP32[$28>>2]|0;
       $146 = (($145) + 1)|0;
       HEAP32[$28>>2] = $146;
       do {
        if (!($133)) {
         $147 = ((($132)) + 8|0);
         $148 = HEAP32[$147>>2]|0;HEAP32[$147>>2] = (($148-1)|0);
         $149 = ($148|0)==(1);
         if (!($149)) {
          break;
         }
         __THREW__ = 0;
         invoke_viii(3262,($132|0),1,1);
         $150 = __THREW__; __THREW__ = 0;
         $151 = $150&1;
         if ($151) {
          label = 20;
          break L4;
         }
        }
       } while(0);
       $152 = ((($$sroa$013$0$i)) + 4|0);
       $153 = ($152|0)==($131|0);
       if ($153) {
        break;
       } else {
        $$sroa$013$0$i = $152;
       }
      }
      $$pre217 = HEAP32[$9>>2]|0;
      $163 = $$pre217;
     }
     $164 = ($163|0)==(0|0);
     if (!($164)) {
      $165 = HEAP32[$25>>2]|0;
      $166 = ($165|0)==($163|0);
      if ($166) {
       $180 = $163;
      } else {
       $168 = $165;
       while(1) {
        $167 = ((($168)) + -4|0);
        HEAP32[$25>>2] = $167;
        $169 = HEAP32[$167>>2]|0;
        $170 = ($169|0)==(0|0);
        do {
         if (!($170)) {
          $171 = ((($169)) + 8|0);
          $172 = HEAP32[$171>>2]|0;HEAP32[$171>>2] = (($172-1)|0);
          $173 = ($172|0)==(1);
          if (!($173)) {
           break;
          }
          __THREW__ = 0;
          invoke_viii(3262,($169|0),1,1);
          $174 = __THREW__; __THREW__ = 0;
          $175 = $174&1;
          if ($175) {
           label = 64;
           break L4;
          }
         }
        } while(0);
        HEAP32[$167>>2] = 0;
        $176 = HEAP32[$25>>2]|0;
        $177 = ($176|0)==($163|0);
        if ($177) {
         break;
        } else {
         $168 = $176;
        }
       }
       $$pre$i = HEAP32[$9>>2]|0;
       $180 = $$pre$i;
      }
      __ZdlPv($180);
     }
     HEAP32[$8>>2] = ((74356));
     HEAP32[$17>>2] = ((74700));
     $181 = HEAP32[$23>>2]|0;
     __ZNSt3__26__treeIN3osg7ref_ptrINS1_8PagedLODEEENS_4lessIS4_EENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($27,$181);
     __THREW__ = 0;
     invoke_vii(3284,($8|0),((74332)|0));
     $182 = __THREW__; __THREW__ = 0;
     $183 = $182&1;
     if ($183) {
      label = 69;
      break L4;
     }
     __THREW__ = 0;
     invoke_vi(388,($17|0));
     $184 = __THREW__; __THREW__ = 0;
     $185 = $184&1;
     if ($185) {
      label = 81;
      break L4;
     }
     $$3 = $$1$lcssa;
    }
    $223 = ((($$sroa$086$0203)) + 4|0);
    $224 = HEAP32[$223>>2]|0;
    $225 = ($224|0)==(0|0);
    if ($225) {
     $226 = ((($$sroa$086$0203)) + 8|0);
     $227 = HEAP32[$226>>2]|0;
     $228 = HEAP32[$227>>2]|0;
     $229 = ($228|0)==($$sroa$086$0203|0);
     if ($229) {
      $$4 = $$3;$$sroa$086$1 = $227;
      break;
     } else {
      $233 = $226;
     }
     while(1) {
      $232 = HEAP32[$233>>2]|0;
      $234 = ((($232)) + 8|0);
      $235 = HEAP32[$234>>2]|0;
      $236 = HEAP32[$235>>2]|0;
      $237 = ($236|0)==($232|0);
      if ($237) {
       $$4 = $$3;$$sroa$086$1 = $235;
       break;
      } else {
       $233 = $234;
      }
     }
    } else {
     $$0$i$i$i64 = $224;
     while(1) {
      $230 = HEAP32[$$0$i$i$i64>>2]|0;
      $231 = ($230|0)==(0|0);
      if ($231) {
       break;
      } else {
       $$0$i$i$i64 = $230;
      }
     }
     $$4 = $$3;$$sroa$086$1 = $$0$i$i$i64;
     break;
    }
   } else {
    $238 = ((($$sroa$086$0203)) + 4|0);
    $239 = HEAP32[$238>>2]|0;
    $240 = ($239|0)==(0|0);
    if ($240) {
     $241 = ((($$sroa$086$0203)) + 8|0);
     $242 = HEAP32[$241>>2]|0;
     $243 = HEAP32[$242>>2]|0;
     $244 = ($243|0)==($$sroa$086$0203|0);
     if ($244) {
      $$0$i$i$i70219 = $242;
      label = 99;
     } else {
      $248 = $241;
      while(1) {
       $247 = HEAP32[$248>>2]|0;
       $249 = ((($247)) + 8|0);
       $250 = HEAP32[$249>>2]|0;
       $251 = HEAP32[$250>>2]|0;
       $252 = ($251|0)==($247|0);
       if ($252) {
        $$0$i$i$i70 = $250;
        label = 98;
        break;
       } else {
        $248 = $249;
       }
      }
     }
    } else {
     $$0$i$i$i$i = $239;
     while(1) {
      $245 = HEAP32[$$0$i$i$i$i>>2]|0;
      $246 = ($245|0)==(0|0);
      if ($246) {
       break;
      } else {
       $$0$i$i$i$i = $245;
      }
     }
     $$0$i$i$i70 = $$0$i$i$i$i;
     label = 98;
    }
    if ((label|0) == 98) {
     label = 0;
     if ($240) {
      $$0$i$i$i70219 = $$0$i$i$i70;
      label = 99;
     } else {
      $$0$i$i$i$i$i = $239;
      while(1) {
       $257 = HEAP32[$$0$i$i$i$i$i>>2]|0;
       $258 = ($257|0)==(0|0);
       if ($258) {
        break;
       } else {
        $$0$i$i$i$i$i = $257;
       }
      }
      $$0$i$i$i$i71 = $$0$i$i$i$i$i;$$0$i$i$i70218 = $$0$i$i$i70;
     }
    }
    if ((label|0) == 99) {
     label = 0;
     $253 = ((($$sroa$086$0203)) + 8|0);
     $254 = HEAP32[$253>>2]|0;
     $255 = HEAP32[$254>>2]|0;
     $256 = ($255|0)==($$sroa$086$0203|0);
     if ($256) {
      $$0$i$i$i$i71 = $254;$$0$i$i$i70218 = $$0$i$i$i70219;
     } else {
      $260 = $253;
      while(1) {
       $259 = HEAP32[$260>>2]|0;
       $261 = ((($259)) + 8|0);
       $262 = HEAP32[$261>>2]|0;
       $263 = HEAP32[$262>>2]|0;
       $264 = ($263|0)==($259|0);
       if ($264) {
        $$0$i$i$i$i71 = $262;$$0$i$i$i70218 = $$0$i$i$i70219;
        break;
       } else {
        $260 = $261;
       }
      }
     }
    }
    $265 = HEAP32[$11>>2]|0;
    $266 = ($265|0)==($$sroa$086$0203|0);
    if ($266) {
     $267 = $$0$i$i$i$i71;
     HEAP32[$11>>2] = $267;
    }
    $268 = HEAP32[$29>>2]|0;
    $269 = (($268) + -1)|0;
    HEAP32[$29>>2] = $269;
    $270 = HEAP32[$30>>2]|0;
    __ZNSt3__213__tree_removeIPNS_16__tree_node_baseIPvEEEEvT_S5_($270,$$sroa$086$0203);
    $271 = HEAP32[$31>>2]|0;
    $272 = ($271|0)==(0|0);
    if (!($272)) {
     $273 = ((($271)) + 8|0);
     $274 = HEAP32[$273>>2]|0;HEAP32[$273>>2] = (($274-1)|0);
     $275 = ($274|0)==(1);
     if ($275) {
      __THREW__ = 0;
      invoke_viii(3262,($271|0),1,1);
      $276 = __THREW__; __THREW__ = 0;
      $277 = $276&1;
      if ($277) {
       label = 16;
       break L4;
      }
     }
    }
    __ZdlPv($$sroa$086$0203);
    $278 = (($$0204) + -1)|0;
    __THREW__ = 0;
    $279 = (invoke_ii(3265,4)|0);
    $280 = __THREW__; __THREW__ = 0;
    $281 = $280&1;
    if ($281) {
     label = 16;
     break L4;
    }
    if ($279) {
     __THREW__ = 0;
     $282 = (invoke_ii(3266,4)|0);
     $283 = __THREW__; __THREW__ = 0;
     $284 = $283&1;
     if ($284) {
      label = 16;
      break L4;
     }
     __THREW__ = 0;
     $285 = (invoke_iiii(3267,($282|0),(165601|0),91)|0);
     $286 = __THREW__; __THREW__ = 0;
     $287 = $286&1;
     if ($287) {
      label = 16;
      break L4;
     }
     $288 = HEAP32[$285>>2]|0;
     $289 = ((($288)) + -12|0);
     $290 = HEAP32[$289>>2]|0;
     $291 = (($285) + ($290)|0);
     __THREW__ = 0;
     invoke_vii(3257,($6|0),($291|0));
     $292 = __THREW__; __THREW__ = 0;
     $293 = $292&1;
     if ($293) {
      label = 16;
      break L4;
     }
     __THREW__ = 0;
     $294 = (invoke_iii(3255,($6|0),(215188|0))|0);
     $295 = __THREW__; __THREW__ = 0;
     $296 = $295&1;
     if ($296) {
      label = 115;
      break L4;
     }
     $297 = HEAP32[$294>>2]|0;
     $298 = ((($297)) + 28|0);
     $299 = HEAP32[$298>>2]|0;
     __THREW__ = 0;
     $300 = (invoke_iii($299|0,($294|0),10)|0);
     $301 = __THREW__; __THREW__ = 0;
     $302 = $301&1;
     if ($302) {
      label = 115;
      break L4;
     }
     __THREW__ = 0;
     invoke_vi(3263,($6|0));
     $309 = __THREW__; __THREW__ = 0;
     $310 = $309&1;
     if ($310) {
      label = 16;
      break L4;
     }
     __THREW__ = 0;
     (invoke_iii(3268,($285|0),($300|0))|0);
     $311 = __THREW__; __THREW__ = 0;
     $312 = $311&1;
     if ($312) {
      label = 16;
      break L4;
     }
     __THREW__ = 0;
     (invoke_ii(3269,($285|0))|0);
     $313 = __THREW__; __THREW__ = 0;
     $314 = $313&1;
     if ($314) {
      label = 16;
      break L4;
     } else {
      $$4 = $278;$$sroa$086$1 = $$0$i$i$i70218;
     }
    } else {
     $$4 = $278;$$sroa$086$1 = $$0$i$i$i70218;
    }
   }
  } while(0);
  $315 = HEAP32[$7>>2]|0;
  $316 = ($315|0)==(0|0);
  if (!($316)) {
   $317 = ((($315)) + 8|0);
   $318 = HEAP32[$317>>2]|0;HEAP32[$317>>2] = (($318-1)|0);
   $319 = ($318|0)==(1);
   if ($319) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($315,1,1);
   }
  }
  $320 = ($$sroa$086$1|0)!=($13|0);
  $321 = ($$4|0)>(0);
  $322 = $320 & $321;
  if ($322) {
   $$0204 = $$4;$$sroa$086$0203 = $$sroa$086$1;
  } else {
   label = 3;
   break;
  }
 }
 switch (label|0) {
  case 3: {
   STACKTOP = sp;return;
   break;
  }
  case 9: {
   $43 = ___cxa_find_matching_catch_2()|0;
   $44 = tempRet0;
   __THREW__ = 0;
   invoke_vi(388,($17|0));
   $45 = __THREW__; __THREW__ = 0;
   $46 = $45&1;
   if ($46) {
    $47 = ___cxa_find_matching_catch_3(0|0)|0;
    $48 = tempRet0;
    ___clang_call_terminate($47);
    // unreachable;
   } else {
    $eh$lpad$body36$index7Z2D = $44;$eh$lpad$body36$indexZ2D = $43;
    label = 19;
   }
   break;
  }
  case 16: {
   $76 = ___cxa_find_matching_catch_2()|0;
   $77 = tempRet0;
   $eh$lpad$body$index2Z2D = $77;$eh$lpad$body$indexZ2D = $76;
   label = 17;
   break;
  }
  case 18: {
   $78 = ___cxa_find_matching_catch_2()|0;
   $79 = tempRet0;
   $eh$lpad$body36$index7Z2D = $79;$eh$lpad$body36$indexZ2D = $78;
   label = 19;
   break;
  }
  case 20: {
   $80 = ___cxa_find_matching_catch_2()|0;
   $81 = tempRet0;
   $eh$lpad$body47$index16Z2D = $81;$eh$lpad$body47$indexZ2D = $80;
   label = 23;
   break;
  }
  case 21: {
   $82 = ___cxa_find_matching_catch_2()|0;
   $83 = tempRet0;
   $eh$lpad$body47$index16Z2D = $83;$eh$lpad$body47$indexZ2D = $82;
   label = 23;
   break;
  }
  case 22: {
   $84 = ___cxa_find_matching_catch_2()|0;
   $85 = tempRet0;
   $eh$lpad$body47$index16Z2D = $85;$eh$lpad$body47$indexZ2D = $84;
   label = 23;
   break;
  }
  case 24: {
   $86 = ___cxa_find_matching_catch_2()|0;
   $87 = tempRet0;
   $$217 = $86;$$222 = $87;
   label = 72;
   break;
  }
  case 30: {
   $102 = ___cxa_find_matching_catch_2()|0;
   $103 = tempRet0;
   $104 = HEAP32[$10>>2]|0;
   $105 = ($104|0)==(0|0);
   if (!($105)) {
    $106 = ((($104)) + 8|0);
    $107 = HEAP32[$106>>2]|0;HEAP32[$106>>2] = (($107-1)|0);
    $108 = ($107|0)==(1);
    if ($108) {
     __THREW__ = 0;
     invoke_viii(3262,($104|0),1,1);
     $109 = __THREW__; __THREW__ = 0;
     $110 = $109&1;
     if ($110) {
      break;
     }
    }
   }
   HEAP32[$10>>2] = 0;
   $$015 = $102;$$020 = $103;
   label = 41;
   break;
  }
  case 40: {
   $127 = ___cxa_find_matching_catch_2()|0;
   $128 = tempRet0;
   $$015 = $127;$$020 = $128;
   label = 41;
   break;
  }
  case 53: {
   $154 = ___cxa_find_matching_catch_2()|0;
   $155 = tempRet0;
   if ($133) {
    $eh$lpad$body47$index16Z2D = $155;$eh$lpad$body47$indexZ2D = $154;
    label = 23;
   } else {
    $156 = ((($132)) + 8|0);
    $157 = HEAP32[$156>>2]|0;HEAP32[$156>>2] = (($157-1)|0);
    $158 = ($157|0)==(1);
    if ($158) {
     __THREW__ = 0;
     invoke_viii(3262,($132|0),1,1);
     $159 = __THREW__; __THREW__ = 0;
     $160 = $159&1;
     if ($160) {
      $161 = ___cxa_find_matching_catch_3(0|0)|0;
      $162 = tempRet0;
      ___clang_call_terminate($161);
      // unreachable;
     } else {
      $eh$lpad$body47$index16Z2D = $155;$eh$lpad$body47$indexZ2D = $154;
      label = 23;
     }
    } else {
     $eh$lpad$body47$index16Z2D = $155;$eh$lpad$body47$indexZ2D = $154;
     label = 23;
    }
   }
   break;
  }
  case 64: {
   $178 = ___cxa_find_matching_catch_2()|0;
   $179 = tempRet0;
   ___cxa_call_unexpected(($178|0));
   // unreachable;
   break;
  }
  case 69: {
   $186 = ___cxa_find_matching_catch_2()|0;
   $187 = tempRet0;
   __THREW__ = 0;
   invoke_vi(388,($17|0));
   $188 = __THREW__; __THREW__ = 0;
   $189 = $188&1;
   if ($189) {
    $190 = ___cxa_find_matching_catch_3(0|0)|0;
    $191 = tempRet0;
    ___clang_call_terminate($190);
    // unreachable;
   } else {
    $eh$lpad$body50$index25Z2D = $187;$eh$lpad$body50$indexZ2D = $186;
    label = 82;
   }
   break;
  }
  case 81: {
   $210 = ___cxa_find_matching_catch_2()|0;
   $211 = tempRet0;
   $eh$lpad$body50$index25Z2D = $211;$eh$lpad$body50$indexZ2D = $210;
   label = 82;
   break;
  }
  case 115: {
   $303 = ___cxa_find_matching_catch_2()|0;
   $304 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($6|0));
   $305 = __THREW__; __THREW__ = 0;
   $306 = $305&1;
   if ($306) {
    $307 = ___cxa_find_matching_catch_3(0|0)|0;
    $308 = tempRet0;
    ___clang_call_terminate($307);
    // unreachable;
   } else {
    $eh$lpad$body$index2Z2D = $304;$eh$lpad$body$indexZ2D = $303;
    label = 17;
    break;
   }
   break;
  }
 }
 if ((label|0) == 17) {
  $$7 = $eh$lpad$body$indexZ2D;$$727 = $eh$lpad$body$index2Z2D;
  label = 125;
 }
 else if ((label|0) == 19) {
  $$7 = $eh$lpad$body36$indexZ2D;$$727 = $eh$lpad$body36$index7Z2D;
  label = 125;
 }
 else if ((label|0) == 23) {
  $$217 = $eh$lpad$body47$indexZ2D;$$222 = $eh$lpad$body47$index16Z2D;
  label = 72;
 }
 else if ((label|0) == 41) {
  $$217 = $$015;$$222 = $$020;
  label = 72;
 }
 else if ((label|0) == 82) {
  $$5 = $eh$lpad$body50$indexZ2D;$$525 = $eh$lpad$body50$index25Z2D;
  label = 87;
 }
 do {
  if ((label|0) == 72) {
   $192 = HEAP32[$9>>2]|0;
   $193 = ($192|0)==(0|0);
   if (!($193)) {
    $194 = HEAP32[$25>>2]|0;
    $195 = ($194|0)==($192|0);
    do {
     if ($195) {
      $209 = $192;
     } else {
      $197 = $194;
      while(1) {
       $196 = ((($197)) + -4|0);
       HEAP32[$25>>2] = $196;
       $198 = HEAP32[$196>>2]|0;
       $199 = ($198|0)==(0|0);
       if (!($199)) {
        $200 = ((($198)) + 8|0);
        $201 = HEAP32[$200>>2]|0;HEAP32[$200>>2] = (($201-1)|0);
        $202 = ($201|0)==(1);
        if ($202) {
         __THREW__ = 0;
         invoke_viii(3262,($198|0),1,1);
         $203 = __THREW__; __THREW__ = 0;
         $204 = $203&1;
         if ($204) {
          label = 78;
          break;
         }
        }
       }
       HEAP32[$196>>2] = 0;
       $205 = HEAP32[$25>>2]|0;
       $206 = ($205|0)==($192|0);
       if ($206) {
        label = 79;
        break;
       } else {
        $197 = $205;
       }
      }
      if ((label|0) == 78) {
       $207 = ___cxa_find_matching_catch_2()|0;
       $208 = tempRet0;
       ___cxa_call_unexpected(($207|0));
       // unreachable;
      }
      else if ((label|0) == 79) {
       $$pre$i54 = HEAP32[$9>>2]|0;
       $209 = $$pre$i54;
       break;
      }
     }
    } while(0);
    __ZdlPv($209);
   }
   HEAP32[$8>>2] = ((74356));
   HEAP32[$17>>2] = ((74700));
   $212 = HEAP32[$23>>2]|0;
   __ZNSt3__26__treeIN3osg7ref_ptrINS1_8PagedLODEEENS_4lessIS4_EENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($27,$212);
   __THREW__ = 0;
   invoke_vii(3284,($8|0),((74332)|0));
   $213 = __THREW__; __THREW__ = 0;
   $214 = $213&1;
   if (!($214)) {
    __THREW__ = 0;
    invoke_vi(388,($17|0));
    $215 = __THREW__; __THREW__ = 0;
    $216 = $215&1;
    if ($216) {
     break;
    } else {
     $$5 = $$217;$$525 = $$222;
     label = 87;
     break;
    }
   }
   $217 = ___cxa_find_matching_catch_3(0|0)|0;
   $218 = tempRet0;
   __THREW__ = 0;
   invoke_vi(388,($17|0));
   $219 = __THREW__; __THREW__ = 0;
   $220 = $219&1;
   if ($220) {
    $221 = ___cxa_find_matching_catch_3(0|0)|0;
    $222 = tempRet0;
    ___clang_call_terminate($221);
    // unreachable;
   } else {
    $eh$lpad$body61$indexZ2D = $217;
    ___clang_call_terminate($eh$lpad$body61$indexZ2D);
    // unreachable;
   }
  }
 } while(0);
 if ((label|0) == 87) {
  $$7 = $$5;$$727 = $$525;
  label = 125;
 }
 if ((label|0) == 125) {
  $323 = HEAP32[$7>>2]|0;
  $324 = ($323|0)==(0|0);
  if ($324) {
   ___resumeException($$7|0);
   // unreachable;
  }
  $325 = ((($323)) + 8|0);
  $326 = HEAP32[$325>>2]|0;HEAP32[$325>>2] = (($326-1)|0);
  $327 = ($326|0)==(1);
  if (!($327)) {
   ___resumeException($$7|0);
   // unreachable;
  }
  __THREW__ = 0;
  invoke_viii(3262,($323|0),1,1);
  $328 = __THREW__; __THREW__ = 0;
  $329 = $328&1;
  if (!($329)) {
   ___resumeException($$7|0);
   // unreachable;
  }
 }
 $330 = ___cxa_find_matching_catch_3(0|0)|0;
 $331 = tempRet0;
 $eh$lpad$body61$indexZ2D = $330;
 ___clang_call_terminate($eh$lpad$body61$indexZ2D);
 // unreachable;
}
function __ZN20SetBasedPagedLODList11removeNodesERNSt3__26vectorIN3osg7ref_ptrINS2_4NodeEEENS0_9allocatorIS5_EEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$ph$lcssa$i$i$i = 0, $$0$ph13$i$i$i = 0, $$07$ph12$i$i$i = 0, $$0710$i$i$i = 0, $$sroa$025$039 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index2Z2D = 0;
 var $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp + 8|0;
 $3 = sp;
 $4 = HEAP32[$1>>2]|0;
 $5 = ((($1)) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4|0)==($6|0);
 if ($7) {
  STACKTOP = sp;return;
 }
 $8 = ((($0)) + 12|0);
 $9 = ((($0)) + 16|0);
 $10 = ((($0)) + 20|0);
 $11 = ((($0)) + 16|0);
 $$sroa$025$039 = $4;
 while(1) {
  $12 = HEAP32[$$sroa$025$039>>2]|0;
  $13 = ($12|0)==(0|0);
  if ($13) {
   $15 = 0;
  } else {
   $14 = (___dynamic_cast($12,25952,26216,0)|0);
   $15 = $14;
  }
  __ZN3osg12observer_ptrINS_8PagedLODEEC2EPS1_($3,$15);
  $16 = HEAP32[$9>>2]|0;
  $17 = ($16|0)==(0|0);
  if (!($17)) {
   $18 = HEAP32[$3>>2]|0;
   $$0$ph13$i$i$i = $9;$$07$ph12$i$i$i = $16;
   L11: while(1) {
    $$0710$i$i$i = $$07$ph12$i$i$i;
    while(1) {
     $19 = ((($$0710$i$i$i)) + 16|0);
     $20 = HEAP32[$19>>2]|0;
     $21 = ($20>>>0)<($18>>>0);
     if (!($21)) {
      break;
     }
     $24 = ((($$0710$i$i$i)) + 4|0);
     $25 = HEAP32[$24>>2]|0;
     $26 = ($25|0)==(0|0);
     if ($26) {
      $$0$ph$lcssa$i$i$i = $$0$ph13$i$i$i;
      break L11;
     } else {
      $$0710$i$i$i = $25;
     }
    }
    $22 = HEAP32[$$0710$i$i$i>>2]|0;
    $23 = ($22|0)==(0|0);
    if ($23) {
     $$0$ph$lcssa$i$i$i = $$0710$i$i$i;
     break;
    } else {
     $$0$ph13$i$i$i = $$0710$i$i$i;$$07$ph12$i$i$i = $22;
    }
   }
   $27 = ($$0$ph$lcssa$i$i$i|0)==($9|0);
   if (!($27)) {
    $28 = ((($$0$ph$lcssa$i$i$i)) + 16|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = ($18>>>0)<($29>>>0);
    if (!($30)) {
     __THREW__ = 0;
     $31 = (invoke_ii(3265,4)|0);
     $32 = __THREW__; __THREW__ = 0;
     $33 = $32&1;
     if ($33) {
      label = 27;
      break;
     }
     if ($31) {
      __THREW__ = 0;
      $34 = (invoke_ii(3266,4)|0);
      $35 = __THREW__; __THREW__ = 0;
      $36 = $35&1;
      if ($36) {
       label = 27;
       break;
      }
      __THREW__ = 0;
      $37 = (invoke_iiii(3267,($34|0),(165568|0),32)|0);
      $38 = __THREW__; __THREW__ = 0;
      $39 = $38&1;
      if ($39) {
       label = 27;
       break;
      }
      $40 = HEAP32[$37>>2]|0;
      $41 = ((($40)) + -12|0);
      $42 = HEAP32[$41>>2]|0;
      $43 = (($37) + ($42)|0);
      __THREW__ = 0;
      invoke_vii(3257,($2|0),($43|0));
      $44 = __THREW__; __THREW__ = 0;
      $45 = $44&1;
      if ($45) {
       label = 27;
       break;
      }
      __THREW__ = 0;
      $46 = (invoke_iii(3255,($2|0),(215188|0))|0);
      $47 = __THREW__; __THREW__ = 0;
      $48 = $47&1;
      if ($48) {
       label = 21;
       break;
      }
      $49 = HEAP32[$46>>2]|0;
      $50 = ((($49)) + 28|0);
      $51 = HEAP32[$50>>2]|0;
      __THREW__ = 0;
      $52 = (invoke_iii($51|0,($46|0),10)|0);
      $53 = __THREW__; __THREW__ = 0;
      $54 = $53&1;
      if ($54) {
       label = 21;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3263,($2|0));
      $61 = __THREW__; __THREW__ = 0;
      $62 = $61&1;
      if ($62) {
       label = 27;
       break;
      }
      __THREW__ = 0;
      (invoke_iii(3268,($37|0),($52|0))|0);
      $63 = __THREW__; __THREW__ = 0;
      $64 = $63&1;
      if ($64) {
       label = 27;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(3269,($37|0))|0);
      $65 = __THREW__; __THREW__ = 0;
      $66 = $65&1;
      if ($66) {
       label = 27;
       break;
      }
     }
     $69 = ((($$0$ph$lcssa$i$i$i)) + 4|0);
     $70 = HEAP32[$69>>2]|0;
     $71 = ($70|0)==(0|0);
     if ($71) {
      $72 = ((($$0$ph$lcssa$i$i$i)) + 8|0);
      $73 = HEAP32[$72>>2]|0;
      $74 = HEAP32[$73>>2]|0;
      $75 = ($74|0)==($$0$ph$lcssa$i$i$i|0);
      if ($75) {
       $$0$i$i$i$i = $73;
      } else {
       $79 = $72;
       while(1) {
        $78 = HEAP32[$79>>2]|0;
        $80 = ((($78)) + 8|0);
        $81 = HEAP32[$80>>2]|0;
        $82 = HEAP32[$81>>2]|0;
        $83 = ($82|0)==($78|0);
        if ($83) {
         $$0$i$i$i$i = $81;
         break;
        } else {
         $79 = $80;
        }
       }
      }
     } else {
      $$0$i$i$i$i$i = $70;
      while(1) {
       $76 = HEAP32[$$0$i$i$i$i$i>>2]|0;
       $77 = ($76|0)==(0|0);
       if ($77) {
        break;
       } else {
        $$0$i$i$i$i$i = $76;
       }
      }
      $$0$i$i$i$i = $$0$i$i$i$i$i;
     }
     $84 = HEAP32[$8>>2]|0;
     $85 = ($84|0)==($$0$ph$lcssa$i$i$i|0);
     if ($85) {
      $86 = $$0$i$i$i$i;
      HEAP32[$8>>2] = $86;
     }
     $87 = HEAP32[$10>>2]|0;
     $88 = (($87) + -1)|0;
     HEAP32[$10>>2] = $88;
     $89 = HEAP32[$11>>2]|0;
     __ZNSt3__213__tree_removeIPNS_16__tree_node_baseIPvEEEEvT_S5_($89,$$0$ph$lcssa$i$i$i);
     $90 = HEAP32[$28>>2]|0;
     $91 = ($90|0)==(0|0);
     if (!($91)) {
      $92 = ((($90)) + 8|0);
      $93 = HEAP32[$92>>2]|0;HEAP32[$92>>2] = (($93-1)|0);
      $94 = ($93|0)==(1);
      if ($94) {
       __THREW__ = 0;
       invoke_viii(3262,($90|0),1,1);
       $95 = __THREW__; __THREW__ = 0;
       $96 = $95&1;
       if ($96) {
        label = 27;
        break;
       }
      }
     }
     __ZdlPv($$0$ph$lcssa$i$i$i);
    }
   }
  }
  $97 = HEAP32[$3>>2]|0;
  $98 = ($97|0)==(0|0);
  if (!($98)) {
   $99 = ((($97)) + 8|0);
   $100 = HEAP32[$99>>2]|0;HEAP32[$99>>2] = (($100-1)|0);
   $101 = ($100|0)==(1);
   if ($101) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($97,1,1);
   }
  }
  $102 = ((($$sroa$025$039)) + 4|0);
  $103 = HEAP32[$5>>2]|0;
  $104 = ($102|0)==($103|0);
  if ($104) {
   label = 3;
   break;
  } else {
   $$sroa$025$039 = $102;
  }
 }
 do {
  if ((label|0) == 3) {
   STACKTOP = sp;return;
  }
  else if ((label|0) == 21) {
   $55 = ___cxa_find_matching_catch_2()|0;
   $56 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($2|0));
   $57 = __THREW__; __THREW__ = 0;
   $58 = $57&1;
   if ($58) {
    $59 = ___cxa_find_matching_catch_3(0|0)|0;
    $60 = tempRet0;
    ___clang_call_terminate($59);
    // unreachable;
   } else {
    $eh$lpad$body$index2Z2D = $56;$eh$lpad$body$indexZ2D = $55;
    break;
   }
  }
  else if ((label|0) == 27) {
   $67 = ___cxa_find_matching_catch_2()|0;
   $68 = tempRet0;
   $eh$lpad$body$index2Z2D = $68;$eh$lpad$body$indexZ2D = $67;
  }
 } while(0);
 $105 = HEAP32[$3>>2]|0;
 $106 = ($105|0)==(0|0);
 if ($106) {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 $107 = ((($105)) + 8|0);
 $108 = HEAP32[$107>>2]|0;HEAP32[$107>>2] = (($108-1)|0);
 $109 = ($108|0)==(1);
 if (!($109)) {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(3262,($105|0),1,1);
 $110 = __THREW__; __THREW__ = 0;
 $111 = $110&1;
 if ($111) {
  $112 = ___cxa_find_matching_catch_3(0|0)|0;
  $113 = tempRet0;
  ___clang_call_terminate($112);
  // unreachable;
 } else {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
}
function __ZN20SetBasedPagedLODList14insertPagedLODERKN3osg12observer_ptrINS0_8PagedLODEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i$i$i = 0, $$0$ph$i$i$i$i = 0, $$024$i$i$i$i = 0, $$025$i$i$i$i = 0, $$039$i$i$i = 0, $$in$i$i$i$i = 0, $$pre$i$i$i$i = 0, $$sink$be$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = ((($0)) + 12|0);
 $4 = ((($0)) + 16|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 do {
  if ($6) {
   $$025$i$i$i$i = $4;$$039$i$i$i = $4;
  } else {
   $7 = HEAP32[$1>>2]|0;
   $9 = $5;
   while(1) {
    $8 = ((($9)) + 16|0);
    $10 = HEAP32[$8>>2]|0;
    $11 = ($7>>>0)<($10>>>0);
    if ($11) {
     $$sink$be$i$i = $9;
    } else {
     $12 = ($10>>>0)<($7>>>0);
     if (!($12)) {
      break;
     }
     $13 = ((($9)) + 4|0);
     $$sink$be$i$i = $13;
    }
    $14 = HEAP32[$$sink$be$i$i>>2]|0;
    $15 = ($14|0)==(0|0);
    if ($15) {
     label = 18;
     break;
    } else {
     $9 = $14;
    }
   }
   if ((label|0) == 18) {
    $48 = ((($0)) + 16|0);
    $$0$i$i$i$i = $48;$$024$i$i$i$i = $5;
    while(1) {
     $49 = ((($$024$i$i$i$i)) + 16|0);
     $50 = HEAP32[$49>>2]|0;
     $51 = ($7>>>0)<($50>>>0);
     if ($51) {
      $52 = HEAP32[$$024$i$i$i$i>>2]|0;
      $53 = ($52|0)==(0|0);
      if ($53) {
       label = 22;
       break;
      } else {
       $$0$ph$i$i$i$i = $$024$i$i$i$i;$$in$i$i$i$i = $52;
      }
     } else {
      $54 = ($50>>>0)<($7>>>0);
      if (!($54)) {
       label = 26;
       break;
      }
      $55 = ((($$024$i$i$i$i)) + 4|0);
      $56 = HEAP32[$55>>2]|0;
      $57 = ($56|0)==(0|0);
      if ($57) {
       label = 25;
       break;
      } else {
       $$0$ph$i$i$i$i = $55;$$in$i$i$i$i = $56;
      }
     }
     $$0$i$i$i$i = $$0$ph$i$i$i$i;$$024$i$i$i$i = $$in$i$i$i$i;
    }
    if ((label|0) == 22) {
     $$025$i$i$i$i = $$024$i$i$i$i;$$039$i$i$i = $$024$i$i$i$i;
     break;
    }
    else if ((label|0) == 25) {
     $$025$i$i$i$i = $55;$$039$i$i$i = $$024$i$i$i$i;
     break;
    }
    else if ((label|0) == 26) {
     $$025$i$i$i$i = $$0$i$i$i$i;$$039$i$i$i = $$024$i$i$i$i;
     break;
    }
   }
   $16 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(3)|0);
   if (!($16)) {
    STACKTOP = sp;return;
   }
   $17 = (__ZN3osg6notifyENS_14NotifySeverityE(3)|0);
   $18 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($17,165502,46)|0);
   $19 = HEAP32[$1>>2]|0;
   $20 = ($19|0)==(0|0);
   if ($20) {
    $26 = 0;
   } else {
    $21 = ((($19)) + 24|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = ($22|0)==(0|0);
    if ($23) {
     $26 = 0;
    } else {
     $24 = ((($1)) + 4|0);
     $25 = HEAP32[$24>>2]|0;
     $26 = $25;
    }
   }
   $27 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEPKv($18,$26)|0);
   $28 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($27,165549,18)|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = ((($29)) + -12|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = (($28) + ($31)|0);
   __ZNKSt3__28ios_base6getlocEv($2,$32);
   __THREW__ = 0;
   $33 = (invoke_iii(3255,($2|0),(215188|0))|0);
   $34 = __THREW__; __THREW__ = 0;
   $35 = $34&1;
   if (!($35)) {
    $36 = HEAP32[$33>>2]|0;
    $37 = ((($36)) + 28|0);
    $38 = HEAP32[$37>>2]|0;
    __THREW__ = 0;
    $39 = (invoke_iii($38|0,($33|0),10)|0);
    $40 = __THREW__; __THREW__ = 0;
    $41 = $40&1;
    if (!($41)) {
     __ZNSt3__26localeD2Ev($2);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($28,$39)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($28)|0);
     STACKTOP = sp;return;
    }
   }
   $42 = ___cxa_find_matching_catch_2()|0;
   $43 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($2|0));
   $44 = __THREW__; __THREW__ = 0;
   $45 = $44&1;
   if ($45) {
    $46 = ___cxa_find_matching_catch_3(0|0)|0;
    $47 = tempRet0;
    ___clang_call_terminate($46);
    // unreachable;
   } else {
    ___resumeException($42|0);
    // unreachable;
   }
  }
 } while(0);
 $58 = HEAP32[$$025$i$i$i$i>>2]|0;
 $59 = ($58|0)==(0|0);
 if (!($59)) {
  STACKTOP = sp;return;
 }
 $60 = (__Znwj(24)|0);
 $61 = ((($60)) + 16|0);
 $62 = HEAP32[$1>>2]|0;
 HEAP32[$61>>2] = $62;
 $63 = ($62|0)==(0|0);
 if (!($63)) {
  $64 = ((($62)) + 8|0);
  $65 = HEAP32[$64>>2]|0;HEAP32[$64>>2] = (($65+1)|0);
 }
 $66 = ((($60)) + 20|0);
 $67 = ((($1)) + 4|0);
 $68 = HEAP32[$67>>2]|0;
 HEAP32[$66>>2] = $68;
 HEAP32[$60>>2] = 0;
 $69 = ((($60)) + 4|0);
 HEAP32[$69>>2] = 0;
 $70 = ((($60)) + 8|0);
 HEAP32[$70>>2] = $$039$i$i$i;
 HEAP32[$$025$i$i$i$i>>2] = $60;
 $71 = HEAP32[$3>>2]|0;
 $72 = HEAP32[$71>>2]|0;
 $73 = ($72|0)==(0|0);
 if ($73) {
  $77 = $60;
 } else {
  $74 = $72;
  HEAP32[$3>>2] = $74;
  $$pre$i$i$i$i = HEAP32[$$025$i$i$i$i>>2]|0;
  $77 = $$pre$i$i$i$i;
 }
 $75 = ((($0)) + 16|0);
 $76 = HEAP32[$75>>2]|0;
 __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($76,$77);
 $78 = ((($0)) + 20|0);
 $79 = HEAP32[$78>>2]|0;
 $80 = (($79) + 1)|0;
 HEAP32[$78>>2] = $80;
 STACKTOP = sp;return;
}
function __ZNK20SetBasedPagedLODList16containsPagedLODERKN3osg12observer_ptrINS0_8PagedLODEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$09$i$i = 0, $$sink$be$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $$09$i$i = 0;
  return ($$09$i$i|0);
 }
 $5 = HEAP32[$1>>2]|0;
 $7 = $3;
 while(1) {
  $6 = ((($7)) + 16|0);
  $8 = HEAP32[$6>>2]|0;
  $9 = ($5>>>0)<($8>>>0);
  if ($9) {
   $$sink$be$i$i = $7;
  } else {
   $10 = ($8>>>0)<($5>>>0);
   if (!($10)) {
    $$09$i$i = 1;
    label = 8;
    break;
   }
   $11 = ((($7)) + 4|0);
   $$sink$be$i$i = $11;
  }
  $12 = HEAP32[$$sink$be$i$i>>2]|0;
  $13 = ($12|0)==(0|0);
  if ($13) {
   $$09$i$i = 0;
   label = 8;
   break;
  } else {
   $7 = $12;
  }
 }
 if ((label|0) == 8) {
  return ($$09$i$i|0);
 }
 return (0)|0;
}
function __ZN3osg12observer_ptrINS_8PagedLODEEC2EPS1_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$ = 0, $$pr = 0, $$pr6 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = 0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   label = 9;
  } else {
   __THREW__ = 0;
   $3 = (invoke_ii(3325,($1|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $$pr = HEAP32[$0>>2]|0;
    $6 = ($$pr|0)==($3|0);
    if ($6) {
     $16 = $3;
     break;
    }
    HEAP32[$0>>2] = $3;
    $7 = ($3|0)==(0|0);
    if (!($7)) {
     $8 = ((($3)) + 8|0);
     $9 = HEAP32[$8>>2]|0;HEAP32[$8>>2] = (($9+1)|0);
    }
    $10 = ($$pr|0)==(0|0);
    if ($10) {
     label = 9;
     break;
    }
    $11 = ((($$pr)) + 8|0);
    $12 = HEAP32[$11>>2]|0;HEAP32[$11>>2] = (($12-1)|0);
    $13 = ($12|0)==(1);
    if (!($13)) {
     label = 9;
     break;
    }
    __THREW__ = 0;
    invoke_viii(3262,($$pr|0),1,1);
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if (!($15)) {
     label = 9;
     break;
    }
   }
   $23 = ___cxa_find_matching_catch_2()|0;
   $24 = tempRet0;
   $25 = HEAP32[$0>>2]|0;
   $26 = ($25|0)==(0|0);
   if ($26) {
    HEAP32[$0>>2] = 0;
    ___resumeException($23|0);
    // unreachable;
   }
   $27 = ((($25)) + 8|0);
   $28 = HEAP32[$27>>2]|0;HEAP32[$27>>2] = (($28-1)|0);
   $29 = ($28|0)==(1);
   if (!($29)) {
    HEAP32[$0>>2] = 0;
    ___resumeException($23|0);
    // unreachable;
   }
   __THREW__ = 0;
   invoke_viii(3262,($25|0),1,1);
   $30 = __THREW__; __THREW__ = 0;
   $31 = $30&1;
   if ($31) {
    $32 = ___cxa_find_matching_catch_3(0|0)|0;
    $33 = tempRet0;
    ___clang_call_terminate($32);
    // unreachable;
   } else {
    HEAP32[$0>>2] = 0;
    ___resumeException($23|0);
    // unreachable;
   }
  }
 } while(0);
 if ((label|0) == 9) {
  $$pr6 = HEAP32[$0>>2]|0;
  $16 = $$pr6;
 }
 $17 = ($16|0)==(0|0);
 if ($17) {
  $22 = 0;
  $21 = ((($0)) + 4|0);
  HEAP32[$21>>2] = $22;
  return;
 }
 $18 = ((($16)) + 24|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)!=(0|0);
 $$ = $20 ? $1 : 0;
 $22 = $$;
 $21 = ((($0)) + 4|0);
 HEAP32[$21>>2] = $22;
 return;
}
function __ZNK3osg12observer_ptrINS_8PagedLODEE4lockERNS_7ref_ptrIS1_EE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  $4 = HEAP32[$1>>2]|0;
  $5 = ($4|0)==(0|0);
  if ($5) {
   $$1 = 0;
   return ($$1|0);
  }
  HEAP32[$1>>2] = 0;
  $6 = ((($4)) + 8|0);
  $7 = HEAP32[$6>>2]|0;HEAP32[$6>>2] = (($7-1)|0);
  $8 = ($7|0)==(1);
  if (!($8)) {
   $$1 = 0;
   return ($$1|0);
  }
  __ZNK3osg10Referenced24signalObserversAndDeleteEbb($4,1,1);
  $$1 = 0;
  return ($$1|0);
 }
 $9 = (__ZN3osg11ObserverSet10addRefLockEv($2)|0);
 $10 = ($9|0)==(0|0);
 if ($10) {
  $11 = HEAP32[$1>>2]|0;
  $12 = ($11|0)==(0|0);
  if ($12) {
   $$1 = 0;
   return ($$1|0);
  }
  HEAP32[$1>>2] = 0;
  $13 = ((($11)) + 8|0);
  $14 = HEAP32[$13>>2]|0;HEAP32[$13>>2] = (($14-1)|0);
  $15 = ($14|0)==(1);
  if (!($15)) {
   $$1 = 0;
   return ($$1|0);
  }
  __ZNK3osg10Referenced24signalObserversAndDeleteEbb($11,1,1);
  $$1 = 0;
  return ($$1|0);
 }
 $16 = ((($0)) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = HEAP32[$1>>2]|0;
 $19 = ($18|0)==($17|0);
 if (!($19)) {
  HEAP32[$1>>2] = $17;
  $20 = ($17|0)==(0|0);
  if (!($20)) {
   $21 = ((($17)) + 8|0);
   $22 = HEAP32[$21>>2]|0;HEAP32[$21>>2] = (($22+1)|0);
  }
  $23 = ($18|0)==(0|0);
  if (!($23)) {
   $24 = ((($18)) + 8|0);
   $25 = HEAP32[$24>>2]|0;HEAP32[$24>>2] = (($25-1)|0);
   $26 = ($25|0)==(1);
   if ($26) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($18,1,1);
   }
  }
 }
 (__ZNK3osg10Referenced14unref_nodeleteEv($9)|0);
 $27 = HEAP32[$1>>2]|0;
 $28 = ($27|0)!=(0|0);
 $$1 = $28;
 return ($$1|0);
}
function __ZN3osg12observer_ptrINS_8PagedLODEEC2ERKNS_7ref_ptrIS1_EE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$ = 0, $$pr = 0, $$pr6 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = 0;
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 do {
  if ($3) {
   label = 9;
  } else {
   __THREW__ = 0;
   $4 = (invoke_ii(3325,($2|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $$pr = HEAP32[$0>>2]|0;
    $7 = ($$pr|0)==($4|0);
    if ($7) {
     $17 = $4;
     break;
    }
    HEAP32[$0>>2] = $4;
    $8 = ($4|0)==(0|0);
    if (!($8)) {
     $9 = ((($4)) + 8|0);
     $10 = HEAP32[$9>>2]|0;HEAP32[$9>>2] = (($10+1)|0);
    }
    $11 = ($$pr|0)==(0|0);
    if ($11) {
     label = 9;
     break;
    }
    $12 = ((($$pr)) + 8|0);
    $13 = HEAP32[$12>>2]|0;HEAP32[$12>>2] = (($13-1)|0);
    $14 = ($13|0)==(1);
    if (!($14)) {
     label = 9;
     break;
    }
    __THREW__ = 0;
    invoke_viii(3262,($$pr|0),1,1);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     label = 9;
     break;
    }
   }
   $25 = ___cxa_find_matching_catch_2()|0;
   $26 = tempRet0;
   $27 = HEAP32[$0>>2]|0;
   $28 = ($27|0)==(0|0);
   if ($28) {
    HEAP32[$0>>2] = 0;
    ___resumeException($25|0);
    // unreachable;
   }
   $29 = ((($27)) + 8|0);
   $30 = HEAP32[$29>>2]|0;HEAP32[$29>>2] = (($30-1)|0);
   $31 = ($30|0)==(1);
   if (!($31)) {
    HEAP32[$0>>2] = 0;
    ___resumeException($25|0);
    // unreachable;
   }
   __THREW__ = 0;
   invoke_viii(3262,($27|0),1,1);
   $32 = __THREW__; __THREW__ = 0;
   $33 = $32&1;
   if ($33) {
    $34 = ___cxa_find_matching_catch_3(0|0)|0;
    $35 = tempRet0;
    ___clang_call_terminate($34);
    // unreachable;
   } else {
    HEAP32[$0>>2] = 0;
    ___resumeException($25|0);
    // unreachable;
   }
  }
 } while(0);
 if ((label|0) == 9) {
  $$pr6 = HEAP32[$0>>2]|0;
  $17 = $$pr6;
 }
 $18 = ($17|0)==(0|0);
 if ($18) {
  $24 = 0;
  $23 = ((($0)) + 4|0);
  HEAP32[$23>>2] = $24;
  return;
 }
 $19 = ((($17)) + 24|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)==(0|0);
 $22 = HEAP32[$1>>2]|0;
 $$ = $21 ? 0 : $22;
 $24 = $$;
 $23 = ((($0)) + 4|0);
 HEAP32[$23>>2] = $24;
 return;
}
function __ZNSt3__26__treeIN3osg12observer_ptrINS1_8PagedLODEEENS_4lessIS4_EENS_9allocatorIS4_EEE14__erase_uniqueIS4_EEjRKT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$0$i$i$i = 0, $$0$i$i$i$i = 0, $$0$ph$lcssa$i$i = 0, $$0$ph13$i$i = 0, $$07$ph12$i$i = 0, $$0710$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $$0 = 0;
  return ($$0|0);
 }
 $5 = HEAP32[$1>>2]|0;
 $$0$ph13$i$i = $2;$$07$ph12$i$i = $3;
 L4: while(1) {
  $$0710$i$i = $$07$ph12$i$i;
  while(1) {
   $6 = ((($$0710$i$i)) + 16|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($7>>>0)<($5>>>0);
   if (!($8)) {
    break;
   }
   $11 = ((($$0710$i$i)) + 4|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = ($12|0)==(0|0);
   if ($13) {
    $$0$ph$lcssa$i$i = $$0$ph13$i$i;
    break L4;
   } else {
    $$0710$i$i = $12;
   }
  }
  $9 = HEAP32[$$0710$i$i>>2]|0;
  $10 = ($9|0)==(0|0);
  if ($10) {
   $$0$ph$lcssa$i$i = $$0710$i$i;
   break;
  } else {
   $$0$ph13$i$i = $$0710$i$i;$$07$ph12$i$i = $9;
  }
 }
 $14 = ($$0$ph$lcssa$i$i|0)==($2|0);
 if ($14) {
  $$0 = 0;
  return ($$0|0);
 }
 $15 = ((($$0$ph$lcssa$i$i)) + 16|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($5>>>0)<($16>>>0);
 if ($17) {
  $$0 = 0;
  return ($$0|0);
 }
 $18 = ((($$0$ph$lcssa$i$i)) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)==(0|0);
 if ($20) {
  $21 = ((($$0$ph$lcssa$i$i)) + 8|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = HEAP32[$22>>2]|0;
  $24 = ($23|0)==($$0$ph$lcssa$i$i|0);
  if ($24) {
   $$0$i$i$i = $22;
  } else {
   $28 = $21;
   while(1) {
    $27 = HEAP32[$28>>2]|0;
    $29 = ((($27)) + 8|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = HEAP32[$30>>2]|0;
    $32 = ($31|0)==($27|0);
    if ($32) {
     $$0$i$i$i = $30;
     break;
    } else {
     $28 = $29;
    }
   }
  }
 } else {
  $$0$i$i$i$i = $19;
  while(1) {
   $25 = HEAP32[$$0$i$i$i$i>>2]|0;
   $26 = ($25|0)==(0|0);
   if ($26) {
    break;
   } else {
    $$0$i$i$i$i = $25;
   }
  }
  $$0$i$i$i = $$0$i$i$i$i;
 }
 $33 = HEAP32[$0>>2]|0;
 $34 = ($33|0)==($$0$ph$lcssa$i$i|0);
 if ($34) {
  $35 = $$0$i$i$i;
  HEAP32[$0>>2] = $35;
 }
 $36 = ((($0)) + 8|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (($37) + -1)|0;
 HEAP32[$36>>2] = $38;
 __ZNSt3__213__tree_removeIPNS_16__tree_node_baseIPvEEEEvT_S5_($3,$$0$ph$lcssa$i$i);
 $39 = HEAP32[$15>>2]|0;
 $40 = ($39|0)==(0|0);
 if (!($40)) {
  $41 = ((($39)) + 8|0);
  $42 = HEAP32[$41>>2]|0;HEAP32[$41>>2] = (($42-1)|0);
  $43 = ($42|0)==(1);
  if ($43) {
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($39,1,1);
  }
 }
 __ZdlPv($$0$ph$lcssa$i$i);
 $$0 = 1;
 return ($$0|0);
}
function __ZNSt3__26__treeIN3osg7ref_ptrINS1_8PagedLODEEENS_4lessIS4_EENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 }
 $3 = HEAP32[$1>>2]|0;
 __ZNSt3__26__treeIN3osg7ref_ptrINS1_8PagedLODEEENS_4lessIS4_EENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($0,$3);
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 __ZNSt3__26__treeIN3osg7ref_ptrINS1_8PagedLODEEENS_4lessIS4_EENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($0,$5);
 $6 = ((($1)) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = ((($7)) + 8|0);
  $10 = HEAP32[$9>>2]|0;HEAP32[$9>>2] = (($10-1)|0);
  $11 = ($10|0)==(1);
  if ($11) {
   __THREW__ = 0;
   invoke_viii(3262,($7|0),1,1);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if ($13) {
    $14 = ___cxa_find_matching_catch_2()|0;
    $15 = tempRet0;
    ___cxa_call_unexpected(($14|0));
    // unreachable;
   }
  }
 }
 __ZdlPv($1);
 return;
}
function __ZN5osgDB13DatabasePager22ExpirePagedLODsVisitorD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = ((74356));
 $1 = ((($0)) + 68|0);
 HEAP32[$1>>2] = ((74700));
 $2 = ((($0)) + 56|0);
 $3 = ((($0)) + 60|0);
 $4 = HEAP32[$3>>2]|0;
 __ZNSt3__26__treeIN3osg7ref_ptrINS1_8PagedLODEEENS_4lessIS4_EENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($2,$4);
 __THREW__ = 0;
 invoke_vii(3284,($0|0),((74332)|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if (!($6)) {
  __ZN3osg6ObjectD2Ev($1);
  return;
 }
 $7 = ___cxa_find_matching_catch_2()|0;
 $8 = tempRet0;
 __THREW__ = 0;
 invoke_vi(388,($1|0));
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if ($10) {
  $11 = ___cxa_find_matching_catch_3(0|0)|0;
  $12 = tempRet0;
  ___clang_call_terminate($11);
  // unreachable;
 } else {
  ___resumeException($7|0);
  // unreachable;
 }
}
function __ZN5osgDB13DatabasePager22ExpirePagedLODsVisitorD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = ((74356));
 $1 = ((($0)) + 68|0);
 HEAP32[$1>>2] = ((74700));
 $2 = ((($0)) + 56|0);
 $3 = ((($0)) + 60|0);
 $4 = HEAP32[$3>>2]|0;
 __ZNSt3__26__treeIN3osg7ref_ptrINS1_8PagedLODEEENS_4lessIS4_EENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($2,$4);
 __THREW__ = 0;
 invoke_vii(3284,($0|0),((74332)|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $9 = ___cxa_find_matching_catch_2()|0;
  $10 = tempRet0;
  __THREW__ = 0;
  invoke_vi(388,($1|0));
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if ($12) {
   $13 = ___cxa_find_matching_catch_3(0|0)|0;
   $14 = tempRet0;
   ___clang_call_terminate($13);
   // unreachable;
  } else {
   $eh$lpad$body$index2Z2D = $10;$eh$lpad$body$indexZ2D = $9;
   __ZdlPv($0);
   ___resumeException($eh$lpad$body$indexZ2D|0);
   // unreachable;
  }
 }
 __THREW__ = 0;
 invoke_vi(388,($1|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if (!($8)) {
  __ZdlPv($0);
  return;
 }
 $15 = ___cxa_find_matching_catch_2()|0;
 $16 = tempRet0;
 $eh$lpad$body$index2Z2D = $16;$eh$lpad$body$indexZ2D = $15;
 __ZdlPv($0);
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
}
function __ZNK5osgDB13DatabasePager22ExpirePagedLODsVisitor11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (163048|0);
}
function __ZNK5osgDB13DatabasePager22ExpirePagedLODsVisitor9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (165693|0);
}
function __ZN5osgDB13DatabasePager22ExpirePagedLODsVisitor5applyERN3osg8PagedLODE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i$i$i = 0, $$0$ph$i$i$i$i = 0, $$013$i = 0, $$024$i$i$i$i = 0, $$025$i$i$i$i = 0, $$039$i$i$i = 0, $$in$i$i$i$i = 0, $$pre$i$i$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 56|0);
 $3 = ((($1)) + 8|0);
 $4 = HEAP32[$3>>2]|0;HEAP32[$3>>2] = (($4+1)|0);
 $5 = ((($0)) + 60|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 do {
  if ($7) {
   $$025$i$i$i$i = $5;$$039$i$i$i = $5;
  } else {
   $8 = ((($0)) + 60|0);
   $$0$i$i$i$i = $8;$$024$i$i$i$i = $6;
   while(1) {
    $9 = ((($$024$i$i$i$i)) + 16|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = ($10>>>0)>($1>>>0);
    if ($11) {
     $12 = HEAP32[$$024$i$i$i$i>>2]|0;
     $13 = ($12|0)==(0|0);
     if ($13) {
      label = 6;
      break;
     } else {
      $$0$ph$i$i$i$i = $$024$i$i$i$i;$$in$i$i$i$i = $12;
     }
    } else {
     $14 = ($10>>>0)<($1>>>0);
     if (!($14)) {
      label = 10;
      break;
     }
     $15 = ((($$024$i$i$i$i)) + 4|0);
     $16 = HEAP32[$15>>2]|0;
     $17 = ($16|0)==(0|0);
     if ($17) {
      label = 9;
      break;
     } else {
      $$0$ph$i$i$i$i = $15;$$in$i$i$i$i = $16;
     }
    }
    $$0$i$i$i$i = $$0$ph$i$i$i$i;$$024$i$i$i$i = $$in$i$i$i$i;
   }
   if ((label|0) == 6) {
    $$025$i$i$i$i = $$024$i$i$i$i;$$039$i$i$i = $$024$i$i$i$i;
    break;
   }
   else if ((label|0) == 9) {
    $$025$i$i$i$i = $15;$$039$i$i$i = $$024$i$i$i$i;
    break;
   }
   else if ((label|0) == 10) {
    $$025$i$i$i$i = $$0$i$i$i$i;$$039$i$i$i = $$024$i$i$i$i;
    break;
   }
  }
 } while(0);
 $18 = HEAP32[$$025$i$i$i$i>>2]|0;
 $19 = ($18|0)==(0|0);
 do {
  if ($19) {
   __THREW__ = 0;
   $20 = (invoke_ii(3276,20)|0);
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if (!($22)) {
    $23 = ((($20)) + 16|0);
    HEAP32[$23>>2] = $1;
    $24 = HEAP32[$3>>2]|0;HEAP32[$3>>2] = (($24+1)|0);
    HEAP32[$20>>2] = 0;
    $25 = ((($20)) + 4|0);
    HEAP32[$25>>2] = 0;
    $26 = ((($20)) + 8|0);
    HEAP32[$26>>2] = $$039$i$i$i;
    HEAP32[$$025$i$i$i$i>>2] = $20;
    $27 = HEAP32[$2>>2]|0;
    $28 = HEAP32[$27>>2]|0;
    $29 = ($28|0)==(0|0);
    if ($29) {
     $33 = $20;
    } else {
     $30 = $28;
     HEAP32[$2>>2] = $30;
     $$pre$i$i$i$i = HEAP32[$$025$i$i$i$i>>2]|0;
     $33 = $$pre$i$i$i$i;
    }
    $31 = ((($0)) + 60|0);
    $32 = HEAP32[$31>>2]|0;
    __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($32,$33);
    $34 = ((($0)) + 64|0);
    $35 = HEAP32[$34>>2]|0;
    $36 = (($35) + 1)|0;
    HEAP32[$34>>2] = $36;
    break;
   }
   $62 = ___cxa_find_matching_catch_2()|0;
   $63 = tempRet0;
   $64 = HEAP32[$3>>2]|0;HEAP32[$3>>2] = (($64-1)|0);
   $65 = ($64|0)==(1);
   if (!($65)) {
    ___resumeException($62|0);
    // unreachable;
   }
   __THREW__ = 0;
   invoke_viii(3262,($1|0),1,1);
   $66 = __THREW__; __THREW__ = 0;
   $67 = $66&1;
   if ($67) {
    $68 = ___cxa_find_matching_catch_3(0|0)|0;
    $69 = tempRet0;
    ___clang_call_terminate($68);
    // unreachable;
   } else {
    ___resumeException($62|0);
    // unreachable;
   }
  }
 } while(0);
 $37 = HEAP32[$3>>2]|0;HEAP32[$3>>2] = (($37-1)|0);
 $38 = ($37|0)==(1);
 if ($38) {
  __ZNK3osg10Referenced24signalObserversAndDeleteEbb($1,1,1);
 }
 $39 = ((($1)) + 200|0);
 $40 = ((($1)) + 204|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = HEAP32[$39>>2]|0;
 $43 = (($41) - ($42))|0;
 $44 = $43 >> 6;
 $45 = ($44|0)==(0);
 $46 = $42;
 if (!($45)) {
  $$013$i = 0;
  while(1) {
   $47 = (((($46) + ($$013$i<<6)|0)) + 56|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = ($48|0)==(0|0);
   if (!($49)) {
    $50 = (___dynamic_cast($48,26488,32040,0)|0);
    $51 = ($50|0)==(0|0);
    if (!($51)) {
     $52 = ((($50)) + 100|0);
     HEAP8[$52>>0] = 1;
    }
   }
   $53 = (($$013$i) + 1)|0;
   $exitcond$i = ($53|0)==($44|0);
   if ($exitcond$i) {
    break;
   } else {
    $$013$i = $53;
   }
  }
 }
 $54 = ((($0)) + 16|0);
 $55 = HEAP32[$54>>2]|0;
 switch ($55|0) {
 case 1:  {
  $56 = HEAP32[$1>>2]|0;
  $57 = ((($56)) + 192|0);
  $58 = HEAP32[$57>>2]|0;
  FUNCTION_TABLE_vii[$58 & 8191]($1,$0);
  return;
  break;
 }
 case 0:  {
  return;
  break;
 }
 default: {
  $59 = HEAP32[$1>>2]|0;
  $60 = ((($59)) + 196|0);
  $61 = HEAP32[$60>>2]|0;
  FUNCTION_TABLE_vii[$61 & 8191]($1,$0);
  return;
 }
 }
}
function __ZTv0_n16_N5osgDB13DatabasePager22ExpirePagedLODsVisitorD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 HEAP32[$4>>2] = ((74356));
 $5 = ((($4)) + 68|0);
 HEAP32[$5>>2] = ((74700));
 $6 = ((($4)) + 56|0);
 $7 = ((($4)) + 60|0);
 $8 = HEAP32[$7>>2]|0;
 __ZNSt3__26__treeIN3osg7ref_ptrINS1_8PagedLODEEENS_4lessIS4_EENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($6,$8);
 __THREW__ = 0;
 invoke_vii(3284,($4|0),((74332)|0));
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if (!($10)) {
  __ZN3osg6ObjectD2Ev($5);
  return;
 }
 $11 = ___cxa_find_matching_catch_2()|0;
 $12 = tempRet0;
 __THREW__ = 0;
 invoke_vi(388,($5|0));
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 if ($14) {
  $15 = ___cxa_find_matching_catch_3(0|0)|0;
  $16 = tempRet0;
  ___clang_call_terminate($15);
  // unreachable;
 } else {
  ___resumeException($11|0);
  // unreachable;
 }
}
function __ZTv0_n16_N5osgDB13DatabasePager22ExpirePagedLODsVisitorD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $eh$lpad$body$i$index2Z2D = 0, $eh$lpad$body$i$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 HEAP32[$4>>2] = ((74356));
 $5 = ((($4)) + 68|0);
 HEAP32[$5>>2] = ((74700));
 $6 = ((($4)) + 56|0);
 $7 = ((($4)) + 60|0);
 $8 = HEAP32[$7>>2]|0;
 __ZNSt3__26__treeIN3osg7ref_ptrINS1_8PagedLODEEENS_4lessIS4_EENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($6,$8);
 __THREW__ = 0;
 invoke_vii(3284,($4|0),((74332)|0));
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if ($10) {
  $13 = ___cxa_find_matching_catch_2()|0;
  $14 = tempRet0;
  __THREW__ = 0;
  invoke_vi(388,($5|0));
  $15 = __THREW__; __THREW__ = 0;
  $16 = $15&1;
  if ($16) {
   $17 = ___cxa_find_matching_catch_3(0|0)|0;
   $18 = tempRet0;
   ___clang_call_terminate($17);
   // unreachable;
  } else {
   $eh$lpad$body$i$index2Z2D = $14;$eh$lpad$body$i$indexZ2D = $13;
   __ZdlPv($4);
   ___resumeException($eh$lpad$body$i$indexZ2D|0);
   // unreachable;
  }
 }
 __THREW__ = 0;
 invoke_vi(388,($5|0));
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if (!($12)) {
  __ZdlPv($4);
  return;
 }
 $19 = ___cxa_find_matching_catch_2()|0;
 $20 = tempRet0;
 $eh$lpad$body$i$index2Z2D = $20;$eh$lpad$body$i$indexZ2D = $19;
 __ZdlPv($4);
 ___resumeException($eh$lpad$body$i$indexZ2D|0);
 // unreachable;
}
function __ZTv0_n32_NK5osgDB13DatabasePager22ExpirePagedLODsVisitor11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (163048|0);
}
function __ZTv0_n36_NK5osgDB13DatabasePager22ExpirePagedLODsVisitor9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (165693|0);
}
function __ZNSt3__26__treeIN3osg12observer_ptrINS1_8PagedLODEEENS_4lessIS4_EENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 }
 $3 = HEAP32[$1>>2]|0;
 __ZNSt3__26__treeIN3osg12observer_ptrINS1_8PagedLODEEENS_4lessIS4_EENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($0,$3);
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 __ZNSt3__26__treeIN3osg12observer_ptrINS1_8PagedLODEEENS_4lessIS4_EENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($0,$5);
 $6 = ((($1)) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = ((($7)) + 8|0);
  $10 = HEAP32[$9>>2]|0;HEAP32[$9>>2] = (($10-1)|0);
  $11 = ($10|0)==(1);
  if ($11) {
   __THREW__ = 0;
   invoke_viii(3262,($7|0),1,1);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if ($13) {
    $14 = ___cxa_find_matching_catch_2()|0;
    $15 = tempRet0;
    ___cxa_call_unexpected(($14|0));
    // unreachable;
   }
  }
 }
 __ZdlPv($1);
 return;
}
function __ZN5osgDB13DatabasePager30setIncrementalCompileOperationEPN7osgUtil27IncrementalCompileOperationE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$pr = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 132|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==($1|0);
 if ($4) {
  $20 = $1;
 } else {
  HEAP32[$2>>2] = $1;
  $5 = ($1|0)==(0|0);
  if (!($5)) {
   $6 = HEAP32[$1>>2]|0;
   $7 = ((($6)) + -12|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($1) + ($8)|0);
   $10 = ((($9)) + 8|0);
   $11 = HEAP32[$10>>2]|0;HEAP32[$10>>2] = (($11+1)|0);
  }
  $12 = ($3|0)==(0|0);
  if (!($12)) {
   $13 = HEAP32[$3>>2]|0;
   $14 = ((($13)) + -12|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (($3) + ($15)|0);
   $17 = ((($16)) + 8|0);
   $18 = HEAP32[$17>>2]|0;HEAP32[$17>>2] = (($18-1)|0);
   $19 = ($18|0)==(1);
   if ($19) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($16,1,1);
   }
  }
  $$pr = HEAP32[$2>>2]|0;
  $20 = $$pr;
 }
 $21 = ($20|0)==(0|0);
 if ($21) {
  return;
 }
 $22 = ((($20)) + 136|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ((($0)) + 164|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)==($23|0);
 if ($26) {
  return;
 }
 HEAP32[$24>>2] = $23;
 $27 = ($23|0)==(0|0);
 if (!($27)) {
  $28 = ((($23)) + 8|0);
  $29 = HEAP32[$28>>2]|0;HEAP32[$28>>2] = (($29+1)|0);
 }
 $30 = ($25|0)==(0|0);
 if ($30) {
  return;
 }
 $31 = ((($25)) + 8|0);
 $32 = HEAP32[$31>>2]|0;HEAP32[$31>>2] = (($32-1)|0);
 $33 = ($32|0)==(1);
 if (!($33)) {
  return;
 }
 __ZNK3osg10Referenced24signalObserversAndDeleteEbb($25,1,1);
 return;
}
function __ZN5osgDB13DatabasePager6createEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN5osgDB13DatabasePager9prototypeEv()|0);
 $0 = HEAP32[52346]|0;
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  (__ZN5osgDB13DatabasePager9prototypeEv()|0);
  $2 = HEAP32[52346]|0;
  $3 = HEAP32[$2>>2]|0;
  $4 = ((($3)) + 20|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (FUNCTION_TABLE_ii[$5 & 8191]($2)|0);
  $10 = $6;
  return ($10|0);
 }
 $7 = (__Znwj(168)|0);
 __THREW__ = 0;
 invoke_vi(4146,($7|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $11 = ___cxa_find_matching_catch_2()|0;
  $12 = tempRet0;
  __ZdlPv($7);
  ___resumeException($11|0);
  // unreachable;
 } else {
  $10 = $7;
  return ($10|0);
 }
 return (0)|0;
}
function __ZNK5osgDB13DatabasePager24requiresUpdateSceneGraphEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 100|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($4)) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 (FUNCTION_TABLE_ii[$6 & 8191]($3)|0);
 $7 = ((($2)) + 24|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$3>>2]|0;
 $10 = ((($9)) + 12|0);
 $11 = HEAP32[$10>>2]|0;
 (FUNCTION_TABLE_ii[$11 & 8191]($3)|0);
 $12 = ($8|0)!=(0);
 return ($12|0);
}
function __ZNK5osgDB13DatabasePager14requiresRedrawEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 96|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($4)) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 (FUNCTION_TABLE_ii[$6 & 8191]($3)|0);
 $7 = ((($2)) + 24|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$3>>2]|0;
 $10 = ((($9)) + 12|0);
 $11 = HEAP32[$10>>2]|0;
 (FUNCTION_TABLE_ii[$11 & 8191]($3)|0);
 $12 = ($8|0)!=(0);
 return ($12|0);
}
function __ZN5osgDB10ImagePager11ImageThreadD2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (74848);
 $1 = ((($0)) + 12|0);
 HEAP32[$1>>2] = (74876);
 $2 = ((($0)) + 32|0);
 $3 = ((($2)) + 11|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)<(0);
 if ($5) {
  $6 = HEAP32[$2>>2]|0;
  __ZdlPv($6);
 }
 __THREW__ = 0;
 invoke_vi(2489,($1|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if (!($8)) {
  __ZN3osg10ReferencedD2Ev($0);
  return;
 }
 $9 = ___cxa_find_matching_catch_2()|0;
 $10 = tempRet0;
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if ($12) {
  $13 = ___cxa_find_matching_catch_3(0|0)|0;
  $14 = tempRet0;
  ___clang_call_terminate($13);
  // unreachable;
 } else {
  ___resumeException($9|0);
  // unreachable;
 }
}
function __ZN5osgDB10ImagePager11ImageThreadD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (74848);
 $1 = ((($0)) + 12|0);
 HEAP32[$1>>2] = (74876);
 $2 = ((($0)) + 32|0);
 $3 = ((($2)) + 11|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)<(0);
 if ($5) {
  $6 = HEAP32[$2>>2]|0;
  __ZdlPv($6);
 }
 __THREW__ = 0;
 invoke_vi(2489,($1|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $11 = ___cxa_find_matching_catch_2()|0;
  $12 = tempRet0;
  __THREW__ = 0;
  invoke_vi(712,($0|0));
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if ($14) {
   $15 = ___cxa_find_matching_catch_3(0|0)|0;
   $16 = tempRet0;
   ___clang_call_terminate($15);
   // unreachable;
  } else {
   $eh$lpad$body$index2Z2D = $12;$eh$lpad$body$indexZ2D = $11;
   __ZdlPv($0);
   ___resumeException($eh$lpad$body$indexZ2D|0);
   // unreachable;
  }
 }
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if (!($10)) {
  __ZdlPv($0);
  return;
 }
 $17 = ___cxa_find_matching_catch_2()|0;
 $18 = tempRet0;
 $eh$lpad$body$index2Z2D = $18;$eh$lpad$body$indexZ2D = $17;
 __ZdlPv($0);
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
}
function __ZN5osgDB10ImagePager11ImageThread6cancelEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 12|0);
 $2 = (__ZN11OpenThreads6Thread9isRunningEv($1)|0);
 if (!($2)) {
  return 0;
 }
 $3 = ((($0)) + 20|0);
 HEAP8[$3>>0] = 1;
 $4 = ((($0)) + 24|0);
 $5 = HEAP32[$4>>2]|0;
 switch ($5|0) {
 case 0:  {
  $6 = ((($0)) + 28|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ((($7)) + 44|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ((($9)) + 36|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ((($11)) + 4|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ((($13)) + 8|0);
  $15 = HEAP32[$14>>2]|0;
  (FUNCTION_TABLE_ii[$15 & 8191]($12)|0);
  $16 = ((($11)) + 24|0);
  $17 = HEAP8[$16>>0]|0;
  $18 = ($17<<24>>24)==(0);
  if ($18) {
   HEAP8[$16>>0] = 1;
   $19 = ((($11)) + 16|0);
   __THREW__ = 0;
   (invoke_ii(2504,($19|0))|0);
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if ($21) {
    $22 = ___cxa_find_matching_catch_2()|0;
    $23 = tempRet0;
    $24 = HEAP32[$12>>2]|0;
    $25 = ((($24)) + 12|0);
    $26 = HEAP32[$25>>2]|0;
    __THREW__ = 0;
    (invoke_ii($26|0,($12|0))|0);
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     $29 = ___cxa_find_matching_catch_3(0|0)|0;
     $30 = tempRet0;
     ___clang_call_terminate($29);
     // unreachable;
    } else {
     ___resumeException($22|0);
     // unreachable;
    }
   }
  }
  $31 = HEAP32[$12>>2]|0;
  $32 = ((($31)) + 12|0);
  $33 = HEAP32[$32>>2]|0;
  (FUNCTION_TABLE_ii[$33 & 8191]($12)|0);
  break;
 }
 case 1:  {
  $34 = ((($0)) + 28|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = ((($35)) + 44|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = ((($37)) + 36|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = ((($39)) + 4|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = ((($41)) + 8|0);
  $43 = HEAP32[$42>>2]|0;
  (FUNCTION_TABLE_ii[$43 & 8191]($40)|0);
  $44 = ((($39)) + 24|0);
  $45 = HEAP8[$44>>0]|0;
  $46 = ($45<<24>>24)==(0);
  if ($46) {
   HEAP8[$44>>0] = 1;
   $47 = ((($39)) + 16|0);
   __THREW__ = 0;
   (invoke_ii(2504,($47|0))|0);
   $48 = __THREW__; __THREW__ = 0;
   $49 = $48&1;
   if ($49) {
    $50 = ___cxa_find_matching_catch_2()|0;
    $51 = tempRet0;
    $52 = HEAP32[$40>>2]|0;
    $53 = ((($52)) + 12|0);
    $54 = HEAP32[$53>>2]|0;
    __THREW__ = 0;
    (invoke_ii($54|0,($40|0))|0);
    $55 = __THREW__; __THREW__ = 0;
    $56 = $55&1;
    if ($56) {
     $57 = ___cxa_find_matching_catch_3(0|0)|0;
     $58 = tempRet0;
     ___clang_call_terminate($57);
     // unreachable;
    } else {
     ___resumeException($50|0);
     // unreachable;
    }
   }
  }
  $59 = HEAP32[$40>>2]|0;
  $60 = ((($59)) + 12|0);
  $61 = HEAP32[$60>>2]|0;
  (FUNCTION_TABLE_ii[$61 & 8191]($40)|0);
  break;
 }
 case 2:  {
  $62 = ((($0)) + 28|0);
  $63 = HEAP32[$62>>2]|0;
  $64 = ((($63)) + 44|0);
  $65 = HEAP32[$64>>2]|0;
  $66 = ((($65)) + 36|0);
  $67 = HEAP32[$66>>2]|0;
  $68 = ((($67)) + 4|0);
  $69 = HEAP32[$68>>2]|0;
  $70 = ((($69)) + 8|0);
  $71 = HEAP32[$70>>2]|0;
  (FUNCTION_TABLE_ii[$71 & 8191]($68)|0);
  $72 = ((($67)) + 24|0);
  $73 = HEAP8[$72>>0]|0;
  $74 = ($73<<24>>24)==(0);
  if ($74) {
   HEAP8[$72>>0] = 1;
   $75 = ((($67)) + 16|0);
   __THREW__ = 0;
   (invoke_ii(2504,($75|0))|0);
   $76 = __THREW__; __THREW__ = 0;
   $77 = $76&1;
   if ($77) {
    $78 = ___cxa_find_matching_catch_2()|0;
    $79 = tempRet0;
    $80 = HEAP32[$68>>2]|0;
    $81 = ((($80)) + 12|0);
    $82 = HEAP32[$81>>2]|0;
    __THREW__ = 0;
    (invoke_ii($82|0,($68|0))|0);
    $83 = __THREW__; __THREW__ = 0;
    $84 = $83&1;
    if ($84) {
     $85 = ___cxa_find_matching_catch_3(0|0)|0;
     $86 = tempRet0;
     ___clang_call_terminate($85);
     // unreachable;
    } else {
     ___resumeException($78|0);
     // unreachable;
    }
   }
  }
  $87 = HEAP32[$68>>2]|0;
  $88 = ((($87)) + 12|0);
  $89 = HEAP32[$88>>2]|0;
  (FUNCTION_TABLE_ii[$89 & 8191]($68)|0);
  break;
 }
 default: {
 }
 }
 (__ZN11OpenThreads6Thread4joinEv($1)|0);
 return 0;
}
function __ZN5osgDB10ImagePager11ImageThread3runEv($0) {
 $0 = $0|0;
 var $$0$off0 = 0, $$110 = 0, $$18 = 0, $$2 = 0, $$211 = 0, $$3 = 0, $$312 = 0, $$4 = 0, $$413 = 0, $$5 = 0, $$514 = 0, $$pr = 0, $$pre = 0, $$pre$i = 0, $$pre$phiZ2D = 0, $$sroa$048$6$ph = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0;
 var $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0;
 var $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0;
 var $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0;
 var $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0;
 var $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0;
 var $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0;
 var $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0;
 var $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0;
 var $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index4Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp + 12|0;
 $2 = sp + 8|0;
 $3 = sp + 4|0;
 $4 = sp;
 $5 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
 do {
  if ($5) {
   $6 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
   $7 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($6,165827,31)|0);
   $8 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEPKv($7,$0)|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = ((($9)) + -12|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (($8) + ($11)|0);
   __ZNKSt3__28ios_base6getlocEv($2,$12);
   __THREW__ = 0;
   $13 = (invoke_iii(3255,($2|0),(215188|0))|0);
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if (!($15)) {
    $16 = HEAP32[$13>>2]|0;
    $17 = ((($16)) + 28|0);
    $18 = HEAP32[$17>>2]|0;
    __THREW__ = 0;
    $19 = (invoke_iii($18|0,($13|0),10)|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if (!($21)) {
     __ZNSt3__26localeD2Ev($2);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($8,$19)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($8)|0);
     break;
    }
   }
   $22 = ___cxa_find_matching_catch_2()|0;
   $23 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($2|0));
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   if ($25) {
    $26 = ___cxa_find_matching_catch_3(0|0)|0;
    $27 = tempRet0;
    ___clang_call_terminate($26);
    // unreachable;
   } else {
    ___resumeException($22|0);
    // unreachable;
   }
  }
 } while(0);
 $28 = ((($0)) + 24|0);
 $29 = HEAP32[$28>>2]|0;
 switch ($29|0) {
 case 0:  {
  $30 = ((($0)) + 28|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = ((($31)) + 44|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $$pre$phiZ2D = $30;$$sroa$048$6$ph = 0;
  } else {
   $35 = ((($33)) + 8|0);
   $36 = HEAP32[$35>>2]|0;HEAP32[$35>>2] = (($36+1)|0);
   $$pre$phiZ2D = $30;$$sroa$048$6$ph = $33;
  }
  break;
 }
 case 1:  {
  $41 = ((($0)) + 28|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = ((($42)) + 44|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = ($44|0)==(0|0);
  if ($45) {
   $$pre$phiZ2D = $41;$$sroa$048$6$ph = 0;
  } else {
   $46 = ((($44)) + 8|0);
   $47 = HEAP32[$46>>2]|0;HEAP32[$46>>2] = (($47+1)|0);
   $$pre$phiZ2D = $41;$$sroa$048$6$ph = $44;
  }
  break;
 }
 case 2:  {
  $48 = ((($0)) + 28|0);
  $49 = HEAP32[$48>>2]|0;
  $50 = ((($49)) + 44|0);
  $51 = HEAP32[$50>>2]|0;
  $52 = ($51|0)==(0|0);
  if ($52) {
   $$pre$phiZ2D = $48;$$sroa$048$6$ph = 0;
  } else {
   $53 = ((($51)) + 8|0);
   $54 = HEAP32[$53>>2]|0;HEAP32[$53>>2] = (($54+1)|0);
   $$pre$phiZ2D = $48;$$sroa$048$6$ph = $51;
  }
  break;
 }
 default: {
  $$pre = ((($0)) + 28|0);
  $$pre$phiZ2D = $$pre;$$sroa$048$6$ph = 0;
 }
 }
 $55 = ((($$sroa$048$6$ph)) + 36|0);
 $56 = ((($0)) + 12|0);
 $57 = ((($0)) + 20|0);
 $$0$off0 = 1;
 L20: while(1) {
  $58 = HEAP32[$55>>2]|0;
  $59 = ((($58)) + 4|0);
  $60 = HEAP32[$59>>2]|0;
  $61 = ((($60)) + 8|0);
  $62 = HEAP32[$61>>2]|0;
  __THREW__ = 0;
  (invoke_ii($62|0,($59|0))|0);
  $63 = __THREW__; __THREW__ = 0;
  $64 = $63&1;
  if ($64) {
   label = 12;
   break;
  }
  $65 = ((($58)) + 24|0);
  $66 = HEAP8[$65>>0]|0;
  $67 = ($66<<24>>24)==(0);
  if ($67) {
   $68 = ((($58)) + 16|0);
   __THREW__ = 0;
   (invoke_iii(2501,($68|0),($59|0))|0);
   $69 = __THREW__; __THREW__ = 0;
   $70 = $69&1;
   if ($70) {
    label = 23;
    break;
   }
  }
  $80 = HEAP32[$59>>2]|0;
  $81 = ((($80)) + 12|0);
  $82 = HEAP32[$81>>2]|0;
  __THREW__ = 0;
  (invoke_ii($82|0,($59|0))|0);
  $83 = __THREW__; __THREW__ = 0;
  $84 = $83&1;
  if ($84) {
   label = 12;
   break;
  }
  HEAP32[$3>>2] = 0;
  __THREW__ = 0;
  invoke_vii(4152,($$sroa$048$6$ph|0),($3|0));
  $85 = __THREW__; __THREW__ = 0;
  $86 = $85&1;
  if ($86) {
   label = 33;
   break;
  }
  $87 = HEAP32[$3>>2]|0;
  $88 = ($87|0)==(0|0);
  if ($88) {
   __THREW__ = 0;
   (invoke_i(3842)|0);
   $185 = __THREW__; __THREW__ = 0;
   $186 = $185&1;
   if ($186) {
    label = 33;
    break;
   }
  } else {
   $89 = ((($87)) + 24|0);
   $90 = ((($87)) + 60|0);
   $91 = HEAP32[$90>>2]|0;
   __THREW__ = 0;
   invoke_viii(4153,($4|0),($89|0),($91|0));
   $92 = __THREW__; __THREW__ = 0;
   $93 = $92&1;
   if ($93) {
    label = 33;
    break;
   }
   $94 = HEAP32[$4>>2]|0;
   $95 = ($94|0)==(0|0);
   if (!($95)) {
    $96 = HEAP32[$3>>2]|0;
    $97 = ((($96)) + 40|0);
    $98 = HEAP32[$97>>2]|0;
    $99 = ($98|0)==(0|0);
    do {
     if ($99) {
      label = 39;
     } else {
      $100 = ((($98)) + 24|0);
      $101 = HEAP32[$100>>2]|0;
      $102 = ($101|0)==(0|0);
      if ($102) {
       label = 39;
      } else {
       $103 = ((($96)) + 44|0);
       $104 = HEAP32[$103>>2]|0;
       $105 = ($104|0)==(0|0);
       if ($105) {
        label = 39;
       } else {
        $108 = (___dynamic_cast($104,26112,32960,0)|0);
        $109 = ($108|0)==(0|0);
        if ($109) {
         label = 39;
        } else {
         $110 = ((($96)) + 48|0);
         $111 = HEAP32[$110>>2]|0;
         $112 = ($111|0)>(-1);
         if ($112) {
          __THREW__ = 0;
          invoke_viii(4154,($108|0),($111|0),($94|0));
          $113 = __THREW__; __THREW__ = 0;
          $114 = $113&1;
          if ($114) {
           label = 37;
           break L20;
          } else {
           break;
          }
         } else {
          __THREW__ = 0;
          invoke_vii(4155,($108|0),($94|0));
          $117 = __THREW__; __THREW__ = 0;
          $118 = $117&1;
          if ($118) {
           label = 37;
           break L20;
          } else {
           break;
          }
         }
        }
       }
      }
     }
    } while(0);
    if ((label|0) == 39) {
     label = 0;
     $119 = ((($96)) + 52|0);
     $120 = HEAP32[$119>>2]|0;
     $121 = ($120|0)==($94|0);
     if (!($121)) {
      HEAP32[$119>>2] = $94;
      $122 = ((($94)) + 8|0);
      $123 = HEAP32[$122>>2]|0;HEAP32[$122>>2] = (($123+1)|0);
      $124 = ($120|0)==(0|0);
      if (!($124)) {
       $125 = ((($120)) + 8|0);
       $126 = HEAP32[$125>>2]|0;HEAP32[$125>>2] = (($126-1)|0);
       $127 = ($126|0)==(1);
       if ($127) {
        __THREW__ = 0;
        invoke_viii(3262,($120|0),1,1);
        $128 = __THREW__; __THREW__ = 0;
        $129 = $128&1;
        if ($129) {
         label = 37;
         break;
        }
       }
      }
     }
     $130 = HEAP32[$$pre$phiZ2D>>2]|0;
     $131 = ((($130)) + 60|0);
     $132 = HEAP32[$131>>2]|0;
     $133 = ((($132)) + 24|0);
     $134 = HEAP32[$133>>2]|0;
     $135 = ((($134)) + 8|0);
     $136 = HEAP32[$135>>2]|0;
     __THREW__ = 0;
     (invoke_ii($136|0,($133|0))|0);
     $137 = __THREW__; __THREW__ = 0;
     $138 = $137&1;
     if ($138) {
      label = 37;
      break;
     }
     $139 = HEAP32[$$pre$phiZ2D>>2]|0;
     $140 = ((($139)) + 60|0);
     $141 = HEAP32[$140>>2]|0;
     $142 = ((($141)) + 16|0);
     $143 = HEAP32[$142>>2]|0;
     $144 = ((($141)) + 20|0);
     $145 = HEAP32[$144>>2]|0;
     $146 = ($143|0)==($145|0);
     if ($146) {
      $153 = ((($141)) + 12|0);
      __THREW__ = 0;
      invoke_vii(4156,($153|0),($3|0));
      $154 = __THREW__; __THREW__ = 0;
      $155 = $154&1;
      if ($155) {
       label = 50;
       break;
      }
     } else {
      $147 = HEAP32[$3>>2]|0;
      HEAP32[$143>>2] = $147;
      $148 = ($147|0)==(0|0);
      if ($148) {
       $152 = $143;
      } else {
       $149 = ((($147)) + 8|0);
       $150 = HEAP32[$149>>2]|0;HEAP32[$149>>2] = (($150+1)|0);
       $$pre$i = HEAP32[$142>>2]|0;
       $152 = $$pre$i;
      }
      $151 = ((($152)) + 4|0);
      HEAP32[$142>>2] = $151;
     }
     $156 = HEAP32[$133>>2]|0;
     $157 = ((($156)) + 12|0);
     $158 = HEAP32[$157>>2]|0;
     __THREW__ = 0;
     (invoke_ii($158|0,($133|0))|0);
     $159 = __THREW__; __THREW__ = 0;
     $160 = $159&1;
     if ($160) {
      label = 51;
      break;
     }
    }
    $$pr = HEAP32[$4>>2]|0;
    $177 = ($$pr|0)==(0|0);
    if (!($177)) {
     $178 = ((($$pr)) + 8|0);
     $179 = HEAP32[$178>>2]|0;HEAP32[$178>>2] = (($179-1)|0);
     $180 = ($179|0)==(1);
     if ($180) {
      __THREW__ = 0;
      invoke_viii(3262,($$pr|0),1,1);
      $181 = __THREW__; __THREW__ = 0;
      $182 = $181&1;
      if ($182) {
       label = 60;
       break;
      }
     }
    }
   }
  }
  if ($$0$off0) {
   __THREW__ = 0;
   (invoke_i(3842)|0);
   $187 = __THREW__; __THREW__ = 0;
   $188 = $187&1;
   if ($188) {
    label = 33;
    break;
   }
  }
  $189 = HEAP32[$3>>2]|0;
  $190 = ($189|0)==(0|0);
  if (!($190)) {
   $191 = ((($189)) + 8|0);
   $192 = HEAP32[$191>>2]|0;HEAP32[$191>>2] = (($192-1)|0);
   $193 = ($192|0)==(1);
   if ($193) {
    __THREW__ = 0;
    invoke_viii(3262,($189|0),1,1);
    $194 = __THREW__; __THREW__ = 0;
    $195 = $194&1;
    if ($195) {
     label = 84;
     break;
    }
   }
  }
  __THREW__ = 0;
  $196 = (invoke_ii(4131,($56|0))|0);
  $197 = __THREW__; __THREW__ = 0;
  $198 = $197&1;
  if ($198) {
   label = 12;
   break;
  }
  $199 = ($196|0)==(0);
  if (!($199)) {
   label = 71;
   break;
  }
  $200 = HEAP8[$57>>0]|0;
  $201 = ($200<<24>>24)==(0);
  if ($201) {
   $$0$off0 = 0;
  } else {
   label = 71;
   break;
  }
 }
 L71: do {
  if ((label|0) == 12) {
   $37 = ___cxa_find_matching_catch_2()|0;
   $38 = tempRet0;
   $eh$lpad$body$index4Z2D = $38;$eh$lpad$body$indexZ2D = $37;
   label = 14;
  }
  else if ((label|0) == 23) {
   $71 = ___cxa_find_matching_catch_2()|0;
   $72 = tempRet0;
   $73 = HEAP32[$59>>2]|0;
   $74 = ((($73)) + 12|0);
   $75 = HEAP32[$74>>2]|0;
   __THREW__ = 0;
   (invoke_ii($75|0,($59|0))|0);
   $76 = __THREW__; __THREW__ = 0;
   $77 = $76&1;
   if ($77) {
    $78 = ___cxa_find_matching_catch_3(0|0)|0;
    $79 = tempRet0;
    ___clang_call_terminate($78);
    // unreachable;
   } else {
    $eh$lpad$body$index4Z2D = $72;$eh$lpad$body$indexZ2D = $71;
    label = 14;
   }
  }
  else if ((label|0) == 33) {
   $106 = ___cxa_find_matching_catch_2()|0;
   $107 = tempRet0;
   $$3 = $107;$$312 = $106;
   label = 85;
  }
  else if ((label|0) == 37) {
   $115 = ___cxa_find_matching_catch_2()|0;
   $116 = tempRet0;
   $$110 = $115;$$18 = $116;
   label = 52;
  }
  else if ((label|0) == 50) {
   $161 = ___cxa_find_matching_catch_2()|0;
   $162 = tempRet0;
   $163 = HEAP32[$133>>2]|0;
   $164 = ((($163)) + 12|0);
   $165 = HEAP32[$164>>2]|0;
   __THREW__ = 0;
   (invoke_ii($165|0,($133|0))|0);
   $166 = __THREW__; __THREW__ = 0;
   $167 = $166&1;
   if ($167) {
    $257 = ___cxa_find_matching_catch_3(0|0)|0;
    $258 = tempRet0;
    ___clang_call_terminate($257);
    // unreachable;
   } else {
    $$110 = $161;$$18 = $162;
    label = 52;
   }
  }
  else if ((label|0) == 51) {
   $168 = ___cxa_find_matching_catch_2()|0;
   $169 = tempRet0;
   $$110 = $168;$$18 = $169;
   label = 52;
  }
  else if ((label|0) == 60) {
   $183 = ___cxa_find_matching_catch_2()|0;
   $184 = tempRet0;
   $$2 = $184;$$211 = $183;
   label = 61;
  }
  else if ((label|0) == 71) {
   __THREW__ = 0;
   $202 = (invoke_ii(3265,4)|0);
   $203 = __THREW__; __THREW__ = 0;
   $204 = $203&1;
   L74: do {
    if (!($204)) {
     do {
      if ($202) {
       __THREW__ = 0;
       $205 = (invoke_ii(3266,4)|0);
       $206 = __THREW__; __THREW__ = 0;
       $207 = $206&1;
       if ($207) {
        break L74;
       }
       __THREW__ = 0;
       $208 = (invoke_iiii(3267,($205|0),(165859|0),31)|0);
       $209 = __THREW__; __THREW__ = 0;
       $210 = $209&1;
       if ($210) {
        break L74;
       }
       $211 = HEAP32[$208>>2]|0;
       $212 = ((($211)) + -12|0);
       $213 = HEAP32[$212>>2]|0;
       $214 = (($208) + ($213)|0);
       __THREW__ = 0;
       invoke_vii(3257,($1|0),($214|0));
       $215 = __THREW__; __THREW__ = 0;
       $216 = $215&1;
       if ($216) {
        break L74;
       }
       __THREW__ = 0;
       $217 = (invoke_iii(3255,($1|0),(215188|0))|0);
       $218 = __THREW__; __THREW__ = 0;
       $219 = $218&1;
       if (!($219)) {
        $220 = HEAP32[$217>>2]|0;
        $221 = ((($220)) + 28|0);
        $222 = HEAP32[$221>>2]|0;
        __THREW__ = 0;
        $223 = (invoke_iii($222|0,($217|0),10)|0);
        $224 = __THREW__; __THREW__ = 0;
        $225 = $224&1;
        if (!($225)) {
         __THREW__ = 0;
         invoke_vi(3263,($1|0));
         $232 = __THREW__; __THREW__ = 0;
         $233 = $232&1;
         if ($233) {
          break L74;
         }
         __THREW__ = 0;
         (invoke_iii(3268,($208|0),($223|0))|0);
         $234 = __THREW__; __THREW__ = 0;
         $235 = $234&1;
         if ($235) {
          break L74;
         }
         __THREW__ = 0;
         (invoke_ii(3269,($208|0))|0);
         $236 = __THREW__; __THREW__ = 0;
         $237 = $236&1;
         if ($237) {
          break L74;
         } else {
          break;
         }
        }
       }
       $226 = ___cxa_find_matching_catch_2()|0;
       $227 = tempRet0;
       __THREW__ = 0;
       invoke_vi(3263,($1|0));
       $228 = __THREW__; __THREW__ = 0;
       $229 = $228&1;
       if ($229) {
        $230 = ___cxa_find_matching_catch_3(0|0)|0;
        $231 = tempRet0;
        ___clang_call_terminate($230);
        // unreachable;
       } else {
        $eh$lpad$body$index4Z2D = $227;$eh$lpad$body$indexZ2D = $226;
        label = 14;
        break L71;
       }
      }
     } while(0);
     $247 = ($$sroa$048$6$ph|0)==(0|0);
     if ($247) {
      STACKTOP = sp;return;
     }
     $248 = ((($$sroa$048$6$ph)) + 8|0);
     $249 = HEAP32[$248>>2]|0;HEAP32[$248>>2] = (($249-1)|0);
     $250 = ($249|0)==(1);
     if (!($250)) {
      STACKTOP = sp;return;
     }
     __ZNK3osg10Referenced24signalObserversAndDeleteEbb($$sroa$048$6$ph,1,1);
     STACKTOP = sp;return;
    }
   } while(0);
   $39 = ___cxa_find_matching_catch_2()|0;
   $40 = tempRet0;
   $eh$lpad$body$index4Z2D = $40;$eh$lpad$body$indexZ2D = $39;
   label = 14;
  }
  else if ((label|0) == 84) {
   $238 = ___cxa_find_matching_catch_2()|0;
   $239 = tempRet0;
   $$4 = $239;$$413 = $238;
   label = 89;
  }
 } while(0);
 if ((label|0) == 14) {
  $$5 = $eh$lpad$body$index4Z2D;$$514 = $eh$lpad$body$indexZ2D;
 }
 else if ((label|0) == 52) {
  $170 = HEAP32[$4>>2]|0;
  $171 = ($170|0)==(0|0);
  if (!($171)) {
   $172 = ((($170)) + 8|0);
   $173 = HEAP32[$172>>2]|0;HEAP32[$172>>2] = (($173-1)|0);
   $174 = ($173|0)==(1);
   if ($174) {
    __THREW__ = 0;
    invoke_viii(3262,($170|0),1,1);
    $175 = __THREW__; __THREW__ = 0;
    $176 = $175&1;
    if ($176) {
     $257 = ___cxa_find_matching_catch_3(0|0)|0;
     $258 = tempRet0;
     ___clang_call_terminate($257);
     // unreachable;
    }
   }
  }
  HEAP32[$4>>2] = 0;
  $$2 = $$18;$$211 = $$110;
  label = 61;
 }
 if ((label|0) == 61) {
  $$3 = $$2;$$312 = $$211;
  label = 85;
 }
 if ((label|0) == 85) {
  $240 = HEAP32[$3>>2]|0;
  $241 = ($240|0)==(0|0);
  if (!($241)) {
   $242 = ((($240)) + 8|0);
   $243 = HEAP32[$242>>2]|0;HEAP32[$242>>2] = (($243-1)|0);
   $244 = ($243|0)==(1);
   if ($244) {
    __THREW__ = 0;
    invoke_viii(3262,($240|0),1,1);
    $245 = __THREW__; __THREW__ = 0;
    $246 = $245&1;
    if ($246) {
     $257 = ___cxa_find_matching_catch_3(0|0)|0;
     $258 = tempRet0;
     ___clang_call_terminate($257);
     // unreachable;
    }
   }
  }
  HEAP32[$3>>2] = 0;
  $$4 = $$3;$$413 = $$312;
  label = 89;
 }
 if ((label|0) == 89) {
  $$5 = $$4;$$514 = $$413;
 }
 $251 = ($$sroa$048$6$ph|0)==(0|0);
 if ($251) {
  ___resumeException($$514|0);
  // unreachable;
 }
 $252 = ((($$sroa$048$6$ph)) + 8|0);
 $253 = HEAP32[$252>>2]|0;HEAP32[$252>>2] = (($253-1)|0);
 $254 = ($253|0)==(1);
 if (!($254)) {
  ___resumeException($$514|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(3262,($$sroa$048$6$ph|0),1,1);
 $255 = __THREW__; __THREW__ = 0;
 $256 = $255&1;
 if ($256) {
  $257 = ___cxa_find_matching_catch_3(0|0)|0;
  $258 = tempRet0;
  ___clang_call_terminate($257);
  // unreachable;
 } else {
  ___resumeException($$514|0);
  // unreachable;
 }
}
function __ZThn12_N5osgDB10ImagePager11ImageThreadD1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -12|0);
 HEAP32[$1>>2] = (74848);
 $2 = ((($1)) + 12|0);
 HEAP32[$2>>2] = (74876);
 $3 = ((($1)) + 32|0);
 $4 = ((($3)) + 11|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)<(0);
 if ($6) {
  $7 = HEAP32[$3>>2]|0;
  __ZdlPv($7);
 }
 __THREW__ = 0;
 invoke_vi(2489,($2|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if (!($9)) {
  __ZN3osg10ReferencedD2Ev($1);
  return;
 }
 $10 = ___cxa_find_matching_catch_2()|0;
 $11 = tempRet0;
 __THREW__ = 0;
 invoke_vi(712,($1|0));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $14 = ___cxa_find_matching_catch_3(0|0)|0;
  $15 = tempRet0;
  ___clang_call_terminate($14);
  // unreachable;
 } else {
  ___resumeException($10|0);
  // unreachable;
 }
}
function __ZThn12_N5osgDB10ImagePager11ImageThreadD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -12|0);
 __ZN5osgDB10ImagePager11ImageThreadD0Ev($1);
 return;
}
function __ZThn12_N5osgDB10ImagePager11ImageThread6cancelEv($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -12|0);
 (__ZN5osgDB10ImagePager11ImageThread6cancelEv($1)|0);
 return 0;
}
function __ZThn12_N5osgDB10ImagePager11ImageThread3runEv($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -12|0);
 __ZN5osgDB10ImagePager11ImageThread3runEv($1);
 return;
}
function __ZN5osgDB10ImagePager9ReadQueue9takeFirstERN3osg7ref_ptrINS0_12ImageRequestEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$lcssa$i$i10$i = 0, $$078$i$i$i = 0, $$09$i$i$i = 0, $$pre$i = 0, $$sink25$index = 0, $$sink25$index4 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp + 4|0;
 $3 = sp;
 $4 = ((($0)) + 24|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($5)) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 (FUNCTION_TABLE_ii[$7 & 8191]($4)|0);
 $8 = ((($0)) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($0)) + 16|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($9|0)==($11|0);
 if ($12) {
  $157 = HEAP32[$4>>2]|0;
  $158 = ((($157)) + 12|0);
  $159 = HEAP32[$158>>2]|0;
  (FUNCTION_TABLE_ii[$159 & 8191]($4)|0);
  STACKTOP = sp;return;
 }
 $13 = ((($0)) + 12|0);
 __THREW__ = 0;
 invoke_viii(4157,($9|0),($11|0),($3|0));
 $14 = __THREW__; __THREW__ = 0;
 $15 = $14&1;
 L4: do {
  if ($15) {
   label = 17;
  } else {
   __THREW__ = 0;
   $16 = (invoke_ii(3265,4)|0);
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if ($18) {
    label = 17;
   } else {
    do {
     if ($16) {
      __THREW__ = 0;
      $19 = (invoke_ii(3266,4)|0);
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if ($21) {
       label = 17;
       break L4;
      }
      __THREW__ = 0;
      $22 = (invoke_iiii(3267,($19|0),(165891|0),45)|0);
      $23 = __THREW__; __THREW__ = 0;
      $24 = $23&1;
      if ($24) {
       label = 17;
       break L4;
      }
      $25 = HEAP32[$10>>2]|0;
      $26 = HEAP32[$8>>2]|0;
      $27 = (($25) - ($26))|0;
      $28 = $27 >> 2;
      __THREW__ = 0;
      $29 = (invoke_iii(3417,($22|0),($28|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 17;
       break L4;
      }
      $32 = HEAP32[$29>>2]|0;
      $33 = ((($32)) + -12|0);
      $34 = HEAP32[$33>>2]|0;
      $35 = (($29) + ($34)|0);
      __THREW__ = 0;
      invoke_vii(3257,($2|0),($35|0));
      $36 = __THREW__; __THREW__ = 0;
      $37 = $36&1;
      if ($37) {
       label = 17;
       break L4;
      }
      __THREW__ = 0;
      $38 = (invoke_iii(3255,($2|0),(215188|0))|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       $41 = HEAP32[$38>>2]|0;
       $42 = ((($41)) + 28|0);
       $43 = HEAP32[$42>>2]|0;
       __THREW__ = 0;
       $44 = (invoke_iii($43|0,($38|0),10)|0);
       $45 = __THREW__; __THREW__ = 0;
       $46 = $45&1;
       if (!($46)) {
        __THREW__ = 0;
        invoke_vi(3263,($2|0));
        $53 = __THREW__; __THREW__ = 0;
        $54 = $53&1;
        if ($54) {
         label = 17;
         break L4;
        }
        __THREW__ = 0;
        (invoke_iii(3268,($29|0),($44|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 17;
         break L4;
        }
        __THREW__ = 0;
        (invoke_ii(3269,($29|0))|0);
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 17;
         break L4;
        } else {
         break;
        }
       }
      }
      $47 = ___cxa_find_matching_catch_2()|0;
      $48 = tempRet0;
      __THREW__ = 0;
      invoke_vi(3263,($2|0));
      $49 = __THREW__; __THREW__ = 0;
      $50 = $49&1;
      if ($50) {
       $51 = ___cxa_find_matching_catch_3(0|0)|0;
       $52 = tempRet0;
       ___clang_call_terminate($51);
       // unreachable;
      } else {
       $$sink25$index = $47;$$sink25$index4 = $48;
       break L4;
      }
     }
    } while(0);
    $61 = HEAP32[$8>>2]|0;
    $62 = HEAP32[$1>>2]|0;
    $63 = HEAP32[$61>>2]|0;
    $64 = ($62|0)==($63|0);
    if (!($64)) {
     HEAP32[$1>>2] = $63;
     $65 = ($63|0)==(0|0);
     if (!($65)) {
      $66 = ((($63)) + 8|0);
      $67 = HEAP32[$66>>2]|0;HEAP32[$66>>2] = (($67+1)|0);
     }
     $68 = ($62|0)==(0|0);
     if (!($68)) {
      $69 = ((($62)) + 8|0);
      $70 = HEAP32[$69>>2]|0;HEAP32[$69>>2] = (($70-1)|0);
      $71 = ($70|0)==(1);
      if ($71) {
       __THREW__ = 0;
       invoke_viii(3262,($62|0),1,1);
       $72 = __THREW__; __THREW__ = 0;
       $73 = $72&1;
       if ($73) {
        label = 17;
        break;
       }
      }
     }
    }
    $74 = HEAP32[$1>>2]|0;
    $75 = ((($74)) + 56|0);
    HEAP32[$75>>2] = 0;
    $76 = HEAP32[$8>>2]|0;
    $77 = ((($76)) + 4|0);
    $78 = HEAP32[$10>>2]|0;
    $79 = ($77|0)==($78|0);
    do {
     if ($79) {
      $$0$lcssa$i$i10$i = $76;$167 = $77;
      label = 33;
     } else {
      $$078$i$i$i = $77;$$09$i$i$i = $76;
      while(1) {
       $80 = HEAP32[$$09$i$i$i>>2]|0;
       $81 = HEAP32[$$078$i$i$i>>2]|0;
       $82 = ($80|0)==($81|0);
       if (!($82)) {
        HEAP32[$$09$i$i$i>>2] = $81;
        $83 = ($81|0)==(0|0);
        if (!($83)) {
         $84 = ((($81)) + 8|0);
         $85 = HEAP32[$84>>2]|0;HEAP32[$84>>2] = (($85+1)|0);
        }
        $86 = ($80|0)==(0|0);
        if (!($86)) {
         $87 = ((($80)) + 8|0);
         $88 = HEAP32[$87>>2]|0;HEAP32[$87>>2] = (($88-1)|0);
         $89 = ($88|0)==(1);
         if ($89) {
          __THREW__ = 0;
          invoke_viii(3262,($80|0),1,1);
          $90 = __THREW__; __THREW__ = 0;
          $91 = $90&1;
          if ($91) {
           label = 50;
           break;
          }
         }
        }
       }
       $92 = ((($$078$i$i$i)) + 4|0);
       $93 = ((($$09$i$i$i)) + 4|0);
       $94 = ($92|0)==($78|0);
       if ($94) {
        label = 32;
        break;
       } else {
        $$078$i$i$i = $92;$$09$i$i$i = $93;
       }
      }
      if ((label|0) == 32) {
       $$pre$i = HEAP32[$10>>2]|0;
       $95 = ($$pre$i|0)==($93|0);
       if ($95) {
        $114 = $93;
        break;
       } else {
        $$0$lcssa$i$i10$i = $93;$167 = $$pre$i;
        label = 33;
        break;
       }
      }
      else if ((label|0) == 50) {
       $155 = ___cxa_find_matching_catch_2()|0;
       $156 = tempRet0;
       $$sink25$index = $155;$$sink25$index4 = $156;
       break L4;
      }
     }
    } while(0);
    L45: do {
     if ((label|0) == 33) {
      $97 = $167;
      while(1) {
       $96 = ((($97)) + -4|0);
       HEAP32[$10>>2] = $96;
       $98 = HEAP32[$96>>2]|0;
       $99 = ($98|0)==(0|0);
       if (!($99)) {
        $100 = ((($98)) + 8|0);
        $101 = HEAP32[$100>>2]|0;HEAP32[$100>>2] = (($101-1)|0);
        $102 = ($101|0)==(1);
        if ($102) {
         __THREW__ = 0;
         invoke_viii(3262,($98|0),1,1);
         $103 = __THREW__; __THREW__ = 0;
         $104 = $103&1;
         if ($104) {
          break;
         }
        }
       }
       HEAP32[$96>>2] = 0;
       $105 = HEAP32[$10>>2]|0;
       $106 = ($105|0)==($$0$lcssa$i$i10$i|0);
       if ($106) {
        $114 = $$0$lcssa$i$i10$i;
        break L45;
       } else {
        $97 = $105;
       }
      }
      $107 = ___cxa_find_matching_catch_2()|0;
      $108 = tempRet0;
      ___cxa_call_unexpected(($107|0));
      // unreachable;
     }
    } while(0);
    $109 = ((($0)) + 36|0);
    $110 = HEAP32[$109>>2]|0;
    $111 = ((($110)) + 4|0);
    $112 = HEAP32[$13>>2]|0;
    $113 = ($112|0)==($114|0);
    if ($113) {
     $121 = 0;
    } else {
     $115 = ((($0)) + 40|0);
     $116 = HEAP32[$115>>2]|0;
     $117 = ((($116)) + 26|0);
     $118 = HEAP8[$117>>0]|0;
     $119 = ($118<<24>>24)==(0);
     $121 = $119;
    }
    $120 = $121&1;
    $122 = ((($110)) + 24|0);
    $123 = HEAP8[$122>>0]|0;
    $124 = $123&255;
    $125 = ($120|0)==($124|0);
    if ($125) {
     $157 = HEAP32[$4>>2]|0;
     $158 = ((($157)) + 12|0);
     $159 = HEAP32[$158>>2]|0;
     (FUNCTION_TABLE_ii[$159 & 8191]($4)|0);
     STACKTOP = sp;return;
    }
    $126 = HEAP32[$111>>2]|0;
    $127 = ((($126)) + 8|0);
    $128 = HEAP32[$127>>2]|0;
    __THREW__ = 0;
    (invoke_ii($128|0,($111|0))|0);
    $129 = __THREW__; __THREW__ = 0;
    $130 = $129&1;
    if ($130) {
     label = 17;
    } else {
     if (!($121)) {
      HEAP8[$122>>0] = 0;
      $150 = HEAP32[$111>>2]|0;
      $151 = ((($150)) + 12|0);
      $152 = HEAP32[$151>>2]|0;
      __THREW__ = 0;
      (invoke_ii($152|0,($111|0))|0);
      $153 = __THREW__; __THREW__ = 0;
      $154 = $153&1;
      if ($154) {
       label = 17;
       break;
      }
      $157 = HEAP32[$4>>2]|0;
      $158 = ((($157)) + 12|0);
      $159 = HEAP32[$158>>2]|0;
      (FUNCTION_TABLE_ii[$159 & 8191]($4)|0);
      STACKTOP = sp;return;
     }
     $131 = HEAP8[$122>>0]|0;
     $132 = ($131<<24>>24)==(0);
     if ($132) {
      HEAP8[$122>>0] = 1;
      $133 = ((($110)) + 16|0);
      __THREW__ = 0;
      (invoke_ii(2504,($133|0))|0);
      $134 = __THREW__; __THREW__ = 0;
      $135 = $134&1;
      if ($135) {
       $136 = ___cxa_find_matching_catch_2()|0;
       $137 = tempRet0;
       $138 = HEAP32[$111>>2]|0;
       $139 = ((($138)) + 12|0);
       $140 = HEAP32[$139>>2]|0;
       __THREW__ = 0;
       (invoke_ii($140|0,($111|0))|0);
       $141 = __THREW__; __THREW__ = 0;
       $142 = $141&1;
       if (!($142)) {
        $$sink25$index = $136;$$sink25$index4 = $137;
        break;
       }
       $143 = ___cxa_find_matching_catch_3(0|0)|0;
       $144 = tempRet0;
       ___clang_call_terminate($143);
       // unreachable;
      }
     }
     $145 = HEAP32[$111>>2]|0;
     $146 = ((($145)) + 12|0);
     $147 = HEAP32[$146>>2]|0;
     __THREW__ = 0;
     (invoke_ii($147|0,($111|0))|0);
     $148 = __THREW__; __THREW__ = 0;
     $149 = $148&1;
     if ($149) {
      label = 17;
     } else {
      $157 = HEAP32[$4>>2]|0;
      $158 = ((($157)) + 12|0);
      $159 = HEAP32[$158>>2]|0;
      (FUNCTION_TABLE_ii[$159 & 8191]($4)|0);
      STACKTOP = sp;return;
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 17) {
  $59 = ___cxa_find_matching_catch_2()|0;
  $60 = tempRet0;
  $$sink25$index = $59;$$sink25$index4 = $60;
 }
 $160 = HEAP32[$4>>2]|0;
 $161 = ((($160)) + 12|0);
 $162 = HEAP32[$161>>2]|0;
 __THREW__ = 0;
 (invoke_ii($162|0,($4|0))|0);
 $163 = __THREW__; __THREW__ = 0;
 $164 = $163&1;
 if ($164) {
  $165 = ___cxa_find_matching_catch_3(0|0)|0;
  $166 = tempRet0;
  ___clang_call_terminate($165);
  // unreachable;
 } else {
  ___resumeException($$sink25$index|0);
  // unreachable;
 }
}
function __ZNSt3__26vectorIN3osg7ref_ptrIN5osgDB10ImagePager12ImageRequestEEENS_9allocatorIS6_EEE21__push_back_slow_pathIKS6_EEvRT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$06$i$i = 0, $$pre = 0, $$pre$i = 0, $$pre38 = 0, $$pre39 = 0, $$sroa$7$0 = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(1073741823);
 $9 = $4;
 $10 = $3;
 if ($8) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $11 = ((($0)) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) - ($4))|0;
 $14 = $13 >> 2;
 $15 = ($14>>>0)<(536870911);
 $16 = $13 >> 1;
 $17 = ($16>>>0)<($7>>>0);
 $$sroa$speculated$i = $17 ? $7 : $16;
 $$sroa$speculated$$i = $15 ? $$sroa$speculated$i : 1073741823;
 $18 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($18) {
   $28 = 0;
  } else {
   $19 = ($$sroa$speculated$$i>>>0)>(1073741823);
   if (!($19)) {
    $25 = $$sroa$speculated$$i << 2;
    $26 = (__Znwj($25)|0);
    $28 = $26;
    break;
   }
   $20 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($20|0),(204840|0));
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if ($22) {
    $23 = ___cxa_find_matching_catch_2()|0;
    $24 = tempRet0;
    ___cxa_free_exception(($20|0));
    ___resumeException($23|0);
    // unreachable;
   } else {
    HEAP32[$20>>2] = (99824);
    ___cxa_throw(($20|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $27 = (($28) + ($6<<2)|0);
 $29 = $27;
 $30 = (($28) + ($$sroa$speculated$$i<<2)|0);
 $31 = $30;
 $32 = HEAP32[$1>>2]|0;
 HEAP32[$27>>2] = $32;
 $33 = ($32|0)==(0|0);
 if ($33) {
  $38 = $10;$40 = $9;
 } else {
  $34 = ((($32)) + 8|0);
  $35 = HEAP32[$34>>2]|0;HEAP32[$34>>2] = (($35+1)|0);
  $$pre = HEAP32[$0>>2]|0;
  $$pre38 = HEAP32[$2>>2]|0;
  $38 = $$pre38;$40 = $$pre;
 }
 $36 = ((($27)) + 4|0);
 $37 = $36;
 $39 = ($38|0)==($40|0);
 if ($39) {
  $41 = $38;
  $53 = $29;$54 = $41;$56 = $38;
 } else {
  $$06$i$i = $38;$$sroa$7$0 = $29;$44 = $27;
  while(1) {
   $42 = ((($$06$i$i)) + -4|0);
   $43 = ((($44)) + -4|0);
   $45 = HEAP32[$42>>2]|0;
   HEAP32[$43>>2] = $45;
   $46 = ($45|0)==(0|0);
   if (!($46)) {
    $47 = ((($45)) + 8|0);
    $48 = HEAP32[$47>>2]|0;HEAP32[$47>>2] = (($48+1)|0);
   }
   $49 = $$sroa$7$0;
   $50 = ((($49)) + -4|0);
   $51 = $50;
   $52 = ($42|0)==($40|0);
   if ($52) {
    break;
   } else {
    $$06$i$i = $42;$$sroa$7$0 = $51;$44 = $50;
   }
  }
  $$pre$i = HEAP32[$0>>2]|0;
  $$pre39 = HEAP32[$2>>2]|0;
  $53 = $51;$54 = $$pre$i;$56 = $$pre39;
 }
 HEAP32[$0>>2] = $53;
 HEAP32[$2>>2] = $37;
 HEAP32[$11>>2] = $31;
 $55 = $54;
 $57 = ($56|0)==($55|0);
 L25: do {
  if (!($57)) {
   $59 = $56;
   while(1) {
    $58 = ((($59)) + -4|0);
    $60 = HEAP32[$58>>2]|0;
    $61 = ($60|0)==(0|0);
    if (!($61)) {
     $62 = ((($60)) + 8|0);
     $63 = HEAP32[$62>>2]|0;HEAP32[$62>>2] = (($63-1)|0);
     $64 = ($63|0)==(1);
     if ($64) {
      __THREW__ = 0;
      invoke_viii(3262,($60|0),1,1);
      $65 = __THREW__; __THREW__ = 0;
      $66 = $65&1;
      if ($66) {
       break;
      }
     }
    }
    HEAP32[$58>>2] = 0;
    $67 = ($58|0)==($55|0);
    if ($67) {
     break L25;
    } else {
     $59 = $58;
    }
   }
   $68 = ___cxa_find_matching_catch_2()|0;
   $69 = tempRet0;
   ___cxa_call_unexpected(($68|0));
   // unreachable;
  }
 } while(0);
 $70 = ($54|0)==(0);
 if ($70) {
  return;
 }
 $71 = $54;
 __ZdlPv($71);
 return;
}
function __ZNSt3__26__sortIRN5osgDB10ImagePager22SortFileRequestFunctorEPN3osg7ref_ptrINS2_12ImageRequestEEEEEvT0_SA_T_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$$0174 = 0, $$0 = 0, $$0$ph = 0, $$0154 = 0, $$0160236 = 0, $$0167 = 0, $$0174 = 0, $$0180$ph = 0, $$1 = 0, $$1155 = 0, $$1161 = 0, $$2156 = 0, $$2162 = 0, $$2176 = 0, $$3157 = 0, $$3163 = 0, $$3170 = 0, $$4158 = 0, $$4164 = 0, $$4171 = 0;
 var $$5159 = 0, $$5165 = 0, $$5172 = 0, $$6166 = 0, $$6173 = 0, $$pre$phi268Z2D = 0, $$pre$phiZ2D = 0, $10 = 0.0, $100 = 0.0, $101 = 0, $102 = 0, $103 = 0.0, $104 = 0, $105 = 0, $106 = 0, $107 = 0.0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0.0, $115 = 0, $116 = 0, $117 = 0.0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0.0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0.0, $129 = 0;
 var $13 = 0.0, $130 = 0, $131 = 0.0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0.0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0.0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0.0, $154 = 0, $155 = 0, $156 = 0.0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0.0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0.0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0.0, $179 = 0, $18 = 0, $180 = 0, $181 = 0.0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0.0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0.0, $198 = 0, $199 = 0, $20 = 0.0, $200 = 0.0, $201 = 0;
 var $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $22 = 0, $23 = 0.0, $24 = 0, $25 = 0, $26 = 0, $27 = 0.0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0.0, $35 = 0, $36 = 0, $37 = 0.0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0.0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0.0, $51 = 0, $52 = 0, $53 = 0.0, $54 = 0, $55 = 0, $56 = 0, $57 = 0.0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0.0, $67 = 0, $68 = 0, $69 = 0.0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0.0, $76 = 0, $77 = 0, $78 = 0.0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0.0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $$0$ph = $0;$$0180$ph = $1;
 L1: while(1) {
  $3 = $$0180$ph;
  $4 = ((($$0180$ph)) + -4|0);
  $$0 = $$0$ph;
  while(1) {
   $$1 = $$0;
   L5: while(1) {
    $5 = $$1;
    $6 = (($3) - ($5))|0;
    $7 = $6 >> 2;
    switch ($7|0) {
    case 2:  {
     label = 5;
     break L1;
     break;
    }
    case 3:  {
     label = 7;
     break L1;
     break;
    }
    case 4:  {
     label = 15;
     break L1;
     break;
    }
    case 5:  {
     label = 27;
     break L1;
     break;
    }
    case 1: case 0:  {
     label = 73;
     break L1;
     break;
    }
    default: {
    }
    }
    $90 = ($6|0)<(28);
    if ($90) {
     label = 29;
     break L1;
    }
    $91 = ($6|0)>(3996);
    $92 = (($7|0) / 2)&-1;
    $93 = (($$1) + ($92<<2)|0);
    do {
     if ($91) {
      $94 = (($7|0) / 4)&-1;
      $95 = (($$1) + ($94<<2)|0);
      $96 = (($93) + ($94<<2)|0);
      $97 = (__ZNSt3__27__sort5IRN5osgDB10ImagePager22SortFileRequestFunctorEPN3osg7ref_ptrINS2_12ImageRequestEEEEEjT0_SA_SA_SA_SA_T_($$1,$95,$93,$96,$4,$2)|0);
      $$0167 = $97;$$pre$phi268Z2D = $93;$$pre$phiZ2D = $$1;
     } else {
      $98 = HEAP32[$93>>2]|0;
      $99 = ((($98)) + 16|0);
      $100 = +HEAPF64[$99>>3];
      $101 = HEAP32[$$1>>2]|0;
      $102 = ((($101)) + 16|0);
      $103 = +HEAPF64[$102>>3];
      $104 = $100 < $103;
      $105 = HEAP32[$4>>2]|0;
      $106 = ((($105)) + 16|0);
      $107 = +HEAPF64[$106>>3];
      $108 = $107 < $100;
      $109 = $98;
      $110 = $105;
      $111 = $101;
      if (!($104)) {
       if (!($108)) {
        $$0167 = 0;$$pre$phi268Z2D = $93;$$pre$phiZ2D = $$1;
        break;
       }
       HEAP32[$93>>2] = $110;
       HEAP32[$4>>2] = $109;
       $112 = HEAP32[$93>>2]|0;
       $113 = ((($112)) + 16|0);
       $114 = +HEAPF64[$113>>3];
       $115 = HEAP32[$$1>>2]|0;
       $116 = ((($115)) + 16|0);
       $117 = +HEAPF64[$116>>3];
       $118 = $114 < $117;
       if (!($118)) {
        $$0167 = 1;$$pre$phi268Z2D = $93;$$pre$phiZ2D = $$1;
        break;
       }
       $119 = $112;
       $120 = $115;
       HEAP32[$$1>>2] = $119;
       HEAP32[$93>>2] = $120;
       $$0167 = 2;$$pre$phi268Z2D = $93;$$pre$phiZ2D = $$1;
       break;
      }
      if ($108) {
       HEAP32[$$1>>2] = $110;
       HEAP32[$4>>2] = $111;
       $$0167 = 1;$$pre$phi268Z2D = $93;$$pre$phiZ2D = $$1;
       break;
      }
      HEAP32[$$1>>2] = $109;
      HEAP32[$93>>2] = $111;
      $121 = HEAP32[$4>>2]|0;
      $122 = ((($121)) + 16|0);
      $123 = +HEAPF64[$122>>3];
      $124 = $123 < $103;
      if ($124) {
       $125 = $121;
       HEAP32[$93>>2] = $125;
       HEAP32[$4>>2] = $111;
       $$0167 = 2;$$pre$phi268Z2D = $93;$$pre$phiZ2D = $$1;
      } else {
       $$0167 = 1;$$pre$phi268Z2D = $93;$$pre$phiZ2D = $$1;
      }
     }
    } while(0);
    $126 = HEAP32[$$pre$phiZ2D>>2]|0;
    $127 = ((($126)) + 16|0);
    $128 = +HEAPF64[$127>>3];
    $129 = HEAP32[$$pre$phi268Z2D>>2]|0;
    $130 = ((($129)) + 16|0);
    $131 = +HEAPF64[$130>>3];
    $132 = $128 < $131;
    if ($132) {
     $$3157 = $4;$$3170 = $$0167;
     break;
    } else {
     $$0154 = $4;
    }
    while(1) {
     $133 = ((($$0154)) + -4|0);
     $134 = ($$1|0)==($133|0);
     if ($134) {
      break;
     }
     $167 = HEAP32[$133>>2]|0;
     $168 = ((($167)) + 16|0);
     $169 = +HEAPF64[$168>>3];
     $170 = $169 < $131;
     if ($170) {
      label = 55;
      break L5;
     } else {
      $$0154 = $133;
     }
    }
    $135 = ((($$1)) + 4|0);
    $136 = HEAP32[$4>>2]|0;
    $137 = ((($136)) + 16|0);
    $138 = +HEAPF64[$137>>3];
    $139 = $128 < $138;
    $140 = $136;
    if ($139) {
     $$1161 = $135;
    } else {
     $141 = ($135|0)==($4|0);
     if ($141) {
      label = 73;
      break L1;
     } else {
      $$0160236 = $135;
     }
     while(1) {
      $142 = HEAP32[$$0160236>>2]|0;
      $143 = ((($142)) + 16|0);
      $144 = +HEAPF64[$143>>3];
      $145 = $128 < $144;
      if ($145) {
       break;
      }
      $148 = ((($$0160236)) + 4|0);
      $149 = ($148|0)==($4|0);
      if ($149) {
       label = 73;
       break L1;
      } else {
       $$0160236 = $148;
      }
     }
     $146 = $142;
     HEAP32[$$0160236>>2] = $140;
     HEAP32[$4>>2] = $146;
     $147 = ((($$0160236)) + 4|0);
     $$1161 = $147;
    }
    $150 = ($$1161|0)==($4|0);
    if ($150) {
     label = 73;
     break L1;
    } else {
     $$1155 = $4;$$2162 = $$1161;
    }
    while(1) {
     $151 = HEAP32[$$pre$phiZ2D>>2]|0;
     $152 = ((($151)) + 16|0);
     $153 = +HEAPF64[$152>>3];
     $$3163 = $$2162;
     while(1) {
      $154 = HEAP32[$$3163>>2]|0;
      $155 = ((($154)) + 16|0);
      $156 = +HEAPF64[$155>>3];
      $157 = $153 < $156;
      $158 = ((($$3163)) + 4|0);
      if ($157) {
       break;
      } else {
       $$3163 = $158;
      }
     }
     $159 = $154;
     $$2156 = $$1155;
     while(1) {
      $160 = ((($$2156)) + -4|0);
      $161 = HEAP32[$160>>2]|0;
      $162 = ((($161)) + 16|0);
      $163 = +HEAPF64[$162>>3];
      $164 = $153 < $163;
      if ($164) {
       $$2156 = $160;
      } else {
       break;
      }
     }
     $165 = ($$3163>>>0)<($160>>>0);
     if (!($165)) {
      $$1 = $$3163;
      continue L5;
     }
     $166 = $161;
     HEAP32[$$3163>>2] = $166;
     HEAP32[$160>>2] = $159;
     $$1155 = $160;$$2162 = $158;
    }
   }
   if ((label|0) == 55) {
    label = 0;
    $171 = $126;
    $172 = $167;
    HEAP32[$$1>>2] = $172;
    HEAP32[$133>>2] = $171;
    $173 = (($$0167) + 1)|0;
    $$3157 = $133;$$3170 = $173;
   }
   $174 = ((($$1)) + 4|0);
   $175 = ($174>>>0)<($$3157>>>0);
   L45: do {
    if ($175) {
     $$0174 = $93;$$4158 = $$3157;$$4164 = $174;$$4171 = $$3170;
     while(1) {
      $176 = HEAP32[$$0174>>2]|0;
      $177 = ((($176)) + 16|0);
      $178 = +HEAPF64[$177>>3];
      $$5165 = $$4164;
      while(1) {
       $179 = HEAP32[$$5165>>2]|0;
       $180 = ((($179)) + 16|0);
       $181 = +HEAPF64[$180>>3];
       $182 = $181 < $178;
       $183 = ((($$5165)) + 4|0);
       if ($182) {
        $$5165 = $183;
       } else {
        break;
       }
      }
      $184 = $179;
      $$5159 = $$4158;
      while(1) {
       $185 = ((($$5159)) + -4|0);
       $186 = HEAP32[$185>>2]|0;
       $187 = ((($186)) + 16|0);
       $188 = +HEAPF64[$187>>3];
       $189 = $188 < $178;
       if ($189) {
        break;
       } else {
        $$5159 = $185;
       }
      }
      $190 = ($$5165>>>0)>($185>>>0);
      if ($190) {
       $$2176 = $$0174;$$5172 = $$4171;$$6166 = $$5165;
       break L45;
      }
      $191 = $186;
      HEAP32[$$5165>>2] = $191;
      HEAP32[$185>>2] = $184;
      $192 = (($$4171) + 1)|0;
      $193 = ($$0174|0)==($$5165|0);
      $$$0174 = $193 ? $185 : $$0174;
      $$0174 = $$$0174;$$4158 = $185;$$4164 = $183;$$4171 = $192;
     }
    } else {
     $$2176 = $93;$$5172 = $$3170;$$6166 = $174;
    }
   } while(0);
   $194 = ($$6166|0)==($$2176|0);
   if ($194) {
    $$6173 = $$5172;
   } else {
    $195 = HEAP32[$$2176>>2]|0;
    $196 = ((($195)) + 16|0);
    $197 = +HEAPF64[$196>>3];
    $198 = HEAP32[$$6166>>2]|0;
    $199 = ((($198)) + 16|0);
    $200 = +HEAPF64[$199>>3];
    $201 = $197 < $200;
    if ($201) {
     $202 = $195;
     $203 = $198;
     $204 = (($$5172) + 1)|0;
     HEAP32[$$6166>>2] = $202;
     HEAP32[$$2176>>2] = $203;
     $$6173 = $204;
    } else {
     $$6173 = $$5172;
    }
   }
   $205 = ($$6173|0)==(0);
   if ($205) {
    $206 = (__ZNSt3__227__insertion_sort_incompleteIRN5osgDB10ImagePager22SortFileRequestFunctorEPN3osg7ref_ptrINS2_12ImageRequestEEEEEbT0_SA_T_($$1,$$6166,$2)|0);
    $207 = ((($$6166)) + 4|0);
    $208 = (__ZNSt3__227__insertion_sort_incompleteIRN5osgDB10ImagePager22SortFileRequestFunctorEPN3osg7ref_ptrINS2_12ImageRequestEEEEEbT0_SA_T_($207,$$0180$ph,$2)|0);
    if ($208) {
     label = 72;
     break;
    }
    if ($206) {
     $$0 = $207;
     continue;
    }
   }
   $209 = $$6166;
   $210 = (($209) - ($5))|0;
   $211 = (($3) - ($209))|0;
   $212 = ($210|0)<($211|0);
   if (!($212)) {
    label = 71;
    break;
   }
   __ZNSt3__26__sortIRN5osgDB10ImagePager22SortFileRequestFunctorEPN3osg7ref_ptrINS2_12ImageRequestEEEEEvT0_SA_T_($$1,$$6166,$2);
   $213 = ((($$6166)) + 4|0);
   $$0 = $213;
  }
  if ((label|0) == 71) {
   label = 0;
   $214 = ((($$6166)) + 4|0);
   __ZNSt3__26__sortIRN5osgDB10ImagePager22SortFileRequestFunctorEPN3osg7ref_ptrINS2_12ImageRequestEEEEEvT0_SA_T_($214,$$0180$ph,$2);
   $$0$ph = $$1;$$0180$ph = $$6166;
   continue;
  }
  else if ((label|0) == 72) {
   label = 0;
   if ($206) {
    label = 73;
    break;
   } else {
    $$0$ph = $$1;$$0180$ph = $$6166;
    continue;
   }
  }
 }
 if ((label|0) == 5) {
  $8 = HEAP32[$4>>2]|0;
  $9 = ((($8)) + 16|0);
  $10 = +HEAPF64[$9>>3];
  $11 = HEAP32[$$1>>2]|0;
  $12 = ((($11)) + 16|0);
  $13 = +HEAPF64[$12>>3];
  $14 = $10 < $13;
  if (!($14)) {
   return;
  }
  $15 = $8;
  $16 = $11;
  HEAP32[$$1>>2] = $15;
  HEAP32[$4>>2] = $16;
  return;
 }
 else if ((label|0) == 7) {
  $17 = ((($$1)) + 4|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = ((($18)) + 16|0);
  $20 = +HEAPF64[$19>>3];
  $21 = HEAP32[$$1>>2]|0;
  $22 = ((($21)) + 16|0);
  $23 = +HEAPF64[$22>>3];
  $24 = $20 < $23;
  $25 = HEAP32[$4>>2]|0;
  $26 = ((($25)) + 16|0);
  $27 = +HEAPF64[$26>>3];
  $28 = $27 < $20;
  $29 = $18;
  $30 = $25;
  $31 = $21;
  if (!($24)) {
   if (!($28)) {
    return;
   }
   HEAP32[$17>>2] = $30;
   HEAP32[$4>>2] = $29;
   $32 = HEAP32[$17>>2]|0;
   $33 = ((($32)) + 16|0);
   $34 = +HEAPF64[$33>>3];
   $35 = HEAP32[$$1>>2]|0;
   $36 = ((($35)) + 16|0);
   $37 = +HEAPF64[$36>>3];
   $38 = $34 < $37;
   if (!($38)) {
    return;
   }
   $39 = $32;
   $40 = $35;
   HEAP32[$$1>>2] = $39;
   HEAP32[$17>>2] = $40;
   return;
  }
  if ($28) {
   HEAP32[$$1>>2] = $30;
   HEAP32[$4>>2] = $31;
   return;
  }
  HEAP32[$$1>>2] = $29;
  HEAP32[$17>>2] = $31;
  $41 = HEAP32[$4>>2]|0;
  $42 = ((($41)) + 16|0);
  $43 = +HEAPF64[$42>>3];
  $44 = $43 < $23;
  if (!($44)) {
   return;
  }
  $45 = $41;
  HEAP32[$17>>2] = $45;
  HEAP32[$4>>2] = $31;
  return;
 }
 else if ((label|0) == 15) {
  $46 = ((($$1)) + 4|0);
  $47 = ((($$1)) + 8|0);
  $48 = HEAP32[$46>>2]|0;
  $49 = ((($48)) + 16|0);
  $50 = +HEAPF64[$49>>3];
  $51 = HEAP32[$$1>>2]|0;
  $52 = ((($51)) + 16|0);
  $53 = +HEAPF64[$52>>3];
  $54 = $50 < $53;
  $55 = HEAP32[$47>>2]|0;
  $56 = ((($55)) + 16|0);
  $57 = +HEAPF64[$56>>3];
  $58 = $57 < $50;
  $59 = $48;
  $60 = $55;
  $61 = $51;
  do {
   if ($54) {
    if ($58) {
     HEAP32[$$1>>2] = $60;
     HEAP32[$47>>2] = $61;
     $68 = $51;$72 = $61;
     break;
    }
    HEAP32[$$1>>2] = $59;
    HEAP32[$46>>2] = $61;
    $63 = $57 < $53;
    if ($63) {
     HEAP32[$46>>2] = $60;
     HEAP32[$47>>2] = $61;
     $68 = $51;$72 = $61;
    } else {
     $68 = $55;$72 = $60;
    }
   } else {
    if ($58) {
     HEAP32[$46>>2] = $60;
     HEAP32[$47>>2] = $59;
     $62 = $57 < $53;
     if ($62) {
      HEAP32[$$1>>2] = $60;
      HEAP32[$46>>2] = $61;
      $68 = $48;$72 = $59;
     } else {
      $68 = $48;$72 = $59;
     }
    } else {
     $68 = $55;$72 = $60;
    }
   }
  } while(0);
  $64 = HEAP32[$4>>2]|0;
  $65 = ((($64)) + 16|0);
  $66 = +HEAPF64[$65>>3];
  $67 = ((($68)) + 16|0);
  $69 = +HEAPF64[$67>>3];
  $70 = $66 < $69;
  if (!($70)) {
   return;
  }
  $71 = $64;
  HEAP32[$47>>2] = $71;
  HEAP32[$4>>2] = $72;
  $73 = HEAP32[$47>>2]|0;
  $74 = ((($73)) + 16|0);
  $75 = +HEAPF64[$74>>3];
  $76 = HEAP32[$46>>2]|0;
  $77 = ((($76)) + 16|0);
  $78 = +HEAPF64[$77>>3];
  $79 = $75 < $78;
  if (!($79)) {
   return;
  }
  $80 = $73;
  $81 = $76;
  HEAP32[$46>>2] = $80;
  HEAP32[$47>>2] = $81;
  $82 = HEAP32[$$1>>2]|0;
  $83 = ((($82)) + 16|0);
  $84 = +HEAPF64[$83>>3];
  $85 = $75 < $84;
  if (!($85)) {
   return;
  }
  $86 = $82;
  HEAP32[$$1>>2] = $80;
  HEAP32[$46>>2] = $86;
  return;
 }
 else if ((label|0) == 27) {
  $87 = ((($$1)) + 4|0);
  $88 = ((($$1)) + 8|0);
  $89 = ((($$1)) + 12|0);
  (__ZNSt3__27__sort5IRN5osgDB10ImagePager22SortFileRequestFunctorEPN3osg7ref_ptrINS2_12ImageRequestEEEEEjT0_SA_SA_SA_SA_T_($$1,$87,$88,$89,$4,$2)|0);
  return;
 }
 else if ((label|0) == 29) {
  __ZNSt3__218__insertion_sort_3IRN5osgDB10ImagePager22SortFileRequestFunctorEPN3osg7ref_ptrINS2_12ImageRequestEEEEEvT0_SA_T_($$1,$$0180$ph,$2);
  return;
 }
 else if ((label|0) == 73) {
  return;
 }
}
function __ZNSt3__27__sort5IRN5osgDB10ImagePager22SortFileRequestFunctorEPN3osg7ref_ptrINS2_12ImageRequestEEEEEjT0_SA_SA_SA_SA_T_($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$0 = 0, $$0$i = 0, $$026$i$i = 0, $$pre$i = 0, $10 = 0, $100 = 0.0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $11 = 0.0, $12 = 0, $13 = 0, $14 = 0, $15 = 0.0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0;
 var $21 = 0, $22 = 0.0, $23 = 0, $24 = 0, $25 = 0.0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0.0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0.0, $38 = 0, $39 = 0, $40 = 0.0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0.0, $48 = 0, $49 = 0, $50 = 0.0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0.0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0.0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0.0, $68 = 0, $69 = 0, $7 = 0, $70 = 0.0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0.0, $78 = 0;
 var $79 = 0, $8 = 0.0, $80 = 0.0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0.0, $88 = 0, $89 = 0, $9 = 0, $90 = 0.0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0.0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $6 = HEAP32[$1>>2]|0;
 $7 = ((($6)) + 16|0);
 $8 = +HEAPF64[$7>>3];
 $9 = HEAP32[$0>>2]|0;
 $10 = ((($9)) + 16|0);
 $11 = +HEAPF64[$10>>3];
 $12 = $8 < $11;
 $13 = HEAP32[$2>>2]|0;
 $14 = ((($13)) + 16|0);
 $15 = +HEAPF64[$14>>3];
 $16 = $15 < $8;
 $17 = $6;
 $18 = $13;
 $19 = $9;
 do {
  if ($12) {
   if ($16) {
    HEAP32[$0>>2] = $18;
    HEAP32[$2>>2] = $19;
    $$026$i$i = 1;$39 = $9;$43 = $19;
    break;
   }
   HEAP32[$0>>2] = $17;
   HEAP32[$1>>2] = $19;
   $30 = HEAP32[$2>>2]|0;
   $31 = ((($30)) + 16|0);
   $32 = +HEAPF64[$31>>3];
   $33 = $32 < $11;
   $34 = $30;
   if ($33) {
    HEAP32[$1>>2] = $34;
    HEAP32[$2>>2] = $19;
    $$026$i$i = 2;$39 = $9;$43 = $19;
   } else {
    $$026$i$i = 1;$39 = $30;$43 = $34;
   }
  } else {
   if ($16) {
    HEAP32[$1>>2] = $18;
    HEAP32[$2>>2] = $17;
    $20 = HEAP32[$1>>2]|0;
    $21 = ((($20)) + 16|0);
    $22 = +HEAPF64[$21>>3];
    $23 = HEAP32[$0>>2]|0;
    $24 = ((($23)) + 16|0);
    $25 = +HEAPF64[$24>>3];
    $26 = $22 < $25;
    if ($26) {
     $27 = $20;
     $28 = $23;
     HEAP32[$0>>2] = $27;
     HEAP32[$1>>2] = $28;
     $$pre$i = HEAP32[$2>>2]|0;
     $29 = $$pre$i;
     $$026$i$i = 2;$39 = $$pre$i;$43 = $29;
    } else {
     $$026$i$i = 1;$39 = $6;$43 = $17;
    }
   } else {
    $$026$i$i = 0;$39 = $13;$43 = $18;
   }
  }
 } while(0);
 $35 = HEAP32[$3>>2]|0;
 $36 = ((($35)) + 16|0);
 $37 = +HEAPF64[$36>>3];
 $38 = ((($39)) + 16|0);
 $40 = +HEAPF64[$38>>3];
 $41 = $37 < $40;
 if ($41) {
  $42 = $35;
  HEAP32[$2>>2] = $42;
  HEAP32[$3>>2] = $43;
  $44 = (($$026$i$i) + 1)|0;
  $45 = HEAP32[$2>>2]|0;
  $46 = ((($45)) + 16|0);
  $47 = +HEAPF64[$46>>3];
  $48 = HEAP32[$1>>2]|0;
  $49 = ((($48)) + 16|0);
  $50 = +HEAPF64[$49>>3];
  $51 = $47 < $50;
  if ($51) {
   $52 = $45;
   $53 = $48;
   HEAP32[$1>>2] = $52;
   HEAP32[$2>>2] = $53;
   $54 = (($$026$i$i) + 2)|0;
   $55 = HEAP32[$1>>2]|0;
   $56 = ((($55)) + 16|0);
   $57 = +HEAPF64[$56>>3];
   $58 = HEAP32[$0>>2]|0;
   $59 = ((($58)) + 16|0);
   $60 = +HEAPF64[$59>>3];
   $61 = $57 < $60;
   if ($61) {
    $62 = (($$026$i$i) + 3)|0;
    $63 = $58;
    $64 = $55;
    HEAP32[$0>>2] = $64;
    HEAP32[$1>>2] = $63;
    $$0$i = $62;
   } else {
    $$0$i = $54;
   }
  } else {
   $$0$i = $44;
  }
 } else {
  $$0$i = $$026$i$i;
 }
 $65 = HEAP32[$4>>2]|0;
 $66 = ((($65)) + 16|0);
 $67 = +HEAPF64[$66>>3];
 $68 = HEAP32[$3>>2]|0;
 $69 = ((($68)) + 16|0);
 $70 = +HEAPF64[$69>>3];
 $71 = $67 < $70;
 if (!($71)) {
  $$0 = $$0$i;
  return ($$0|0);
 }
 $72 = $65;
 $73 = $68;
 HEAP32[$3>>2] = $72;
 HEAP32[$4>>2] = $73;
 $74 = (($$0$i) + 1)|0;
 $75 = HEAP32[$3>>2]|0;
 $76 = ((($75)) + 16|0);
 $77 = +HEAPF64[$76>>3];
 $78 = HEAP32[$2>>2]|0;
 $79 = ((($78)) + 16|0);
 $80 = +HEAPF64[$79>>3];
 $81 = $77 < $80;
 if (!($81)) {
  $$0 = $74;
  return ($$0|0);
 }
 $82 = $75;
 $83 = $78;
 HEAP32[$2>>2] = $82;
 HEAP32[$3>>2] = $83;
 $84 = (($$0$i) + 2)|0;
 $85 = HEAP32[$2>>2]|0;
 $86 = ((($85)) + 16|0);
 $87 = +HEAPF64[$86>>3];
 $88 = HEAP32[$1>>2]|0;
 $89 = ((($88)) + 16|0);
 $90 = +HEAPF64[$89>>3];
 $91 = $87 < $90;
 if (!($91)) {
  $$0 = $84;
  return ($$0|0);
 }
 $92 = $85;
 $93 = $88;
 HEAP32[$1>>2] = $92;
 HEAP32[$2>>2] = $93;
 $94 = (($$0$i) + 3)|0;
 $95 = HEAP32[$1>>2]|0;
 $96 = ((($95)) + 16|0);
 $97 = +HEAPF64[$96>>3];
 $98 = HEAP32[$0>>2]|0;
 $99 = ((($98)) + 16|0);
 $100 = +HEAPF64[$99>>3];
 $101 = $97 < $100;
 if (!($101)) {
  $$0 = $94;
  return ($$0|0);
 }
 $102 = $95;
 $103 = $98;
 $104 = (($$0$i) + 4)|0;
 HEAP32[$0>>2] = $102;
 HEAP32[$1>>2] = $103;
 $$0 = $104;
 return ($$0|0);
}
function __ZNSt3__218__insertion_sort_3IRN5osgDB10ImagePager22SortFileRequestFunctorEPN3osg7ref_ptrINS2_12ImageRequestEEEEEvT0_SA_T_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$03348 = 0, $$034 = 0, $$049 = 0, $$049$phi = 0, $$1 = 0, $$1$phi = 0, $$pre = 0, $$pre55$pre = 0, $$pre5557 = 0, $$pre5558 = 0, $10 = 0.0, $11 = 0, $12 = 0, $13 = 0, $14 = 0.0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0.0, $26 = 0, $27 = 0.0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0.0, $47 = 0, $48 = 0, $49 = 0.0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0.0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 8|0);
 $4 = ((($0)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($5)) + 16|0);
 $7 = +HEAPF64[$6>>3];
 $8 = HEAP32[$0>>2]|0;
 $9 = ((($8)) + 16|0);
 $10 = +HEAPF64[$9>>3];
 $11 = $7 < $10;
 $12 = HEAP32[$3>>2]|0;
 $13 = ((($12)) + 16|0);
 $14 = +HEAPF64[$13>>3];
 $15 = $14 < $7;
 $16 = $5;
 $17 = $12;
 $18 = $8;
 do {
  if ($11) {
   if ($15) {
    HEAP32[$0>>2] = $17;
    HEAP32[$3>>2] = $18;
    $$pre5558 = $8;
    break;
   }
   HEAP32[$0>>2] = $16;
   HEAP32[$4>>2] = $18;
   $20 = $14 < $10;
   if ($20) {
    HEAP32[$4>>2] = $17;
    HEAP32[$3>>2] = $18;
    $$pre5558 = $8;
   } else {
    $$pre5558 = $12;
   }
  } else {
   if ($15) {
    HEAP32[$4>>2] = $17;
    HEAP32[$3>>2] = $16;
    $19 = $14 < $10;
    if ($19) {
     HEAP32[$0>>2] = $17;
     HEAP32[$4>>2] = $18;
     $$pre5558 = $5;
    } else {
     $$pre5558 = $5;
    }
   } else {
    $$pre5558 = $12;
   }
  }
 } while(0);
 $21 = ((($0)) + 12|0);
 $22 = ($21|0)==($1|0);
 if ($22) {
  return;
 } else {
  $$03348 = $21;$$049 = $3;$$pre5557 = $$pre5558;
 }
 L13: while(1) {
  $23 = HEAP32[$$03348>>2]|0;
  $24 = ((($23)) + 16|0);
  $25 = +HEAPF64[$24>>3];
  $26 = ((($$pre5557)) + 16|0);
  $27 = +HEAPF64[$26>>3];
  $28 = $25 < $27;
  if ($28) {
   $29 = ($23|0)==(0|0);
   if ($29) {
    $$034 = $$049;$$1 = $$03348;$34 = $$pre5557;
   } else {
    $30 = ((($23)) + 8|0);
    $31 = HEAP32[$30>>2]|0;HEAP32[$30>>2] = (($31+1)|0);
    $$pre55$pre = HEAP32[$$049>>2]|0;
    $$034 = $$049;$$1 = $$03348;$34 = $$pre55$pre;
   }
   while(1) {
    $32 = HEAP32[$$1>>2]|0;
    $33 = ($32|0)==($34|0);
    if (!($33)) {
     HEAP32[$$1>>2] = $34;
     $35 = ($34|0)==(0|0);
     if (!($35)) {
      $36 = ((($34)) + 8|0);
      $37 = HEAP32[$36>>2]|0;HEAP32[$36>>2] = (($37+1)|0);
     }
     $38 = ($32|0)==(0|0);
     if (!($38)) {
      $39 = ((($32)) + 8|0);
      $40 = HEAP32[$39>>2]|0;HEAP32[$39>>2] = (($40-1)|0);
      $41 = ($40|0)==(1);
      if ($41) {
       __THREW__ = 0;
       invoke_viii(3262,($32|0),1,1);
       $42 = __THREW__; __THREW__ = 0;
       $43 = $42&1;
       if ($43) {
        break L13;
       }
      }
     }
    }
    $44 = ($$034|0)==($0|0);
    if ($44) {
     break;
    }
    $45 = ((($$034)) + -4|0);
    $46 = +HEAPF64[$24>>3];
    $47 = HEAP32[$45>>2]|0;
    $48 = ((($47)) + 16|0);
    $49 = +HEAPF64[$48>>3];
    $50 = $46 < $49;
    if ($50) {
     $$1$phi = $$034;$$034 = $45;$34 = $47;$$1 = $$1$phi;
    } else {
     break;
    }
   }
   $51 = HEAP32[$$034>>2]|0;
   $52 = ($51|0)==($23|0);
   if (!($52)) {
    HEAP32[$$034>>2] = $23;
    if (!($29)) {
     $53 = ((($23)) + 8|0);
     $54 = HEAP32[$53>>2]|0;HEAP32[$53>>2] = (($54+1)|0);
    }
    $55 = ($51|0)==(0|0);
    if (!($55)) {
     $56 = ((($51)) + 8|0);
     $57 = HEAP32[$56>>2]|0;HEAP32[$56>>2] = (($57-1)|0);
     $58 = ($57|0)==(1);
     if ($58) {
      __THREW__ = 0;
      invoke_viii(3262,($51|0),1,1);
      $59 = __THREW__; __THREW__ = 0;
      $60 = $59&1;
      if ($60) {
       break;
      }
     }
    }
   }
   if (!($29)) {
    $61 = ((($23)) + 8|0);
    $62 = HEAP32[$61>>2]|0;HEAP32[$61>>2] = (($62-1)|0);
    $63 = ($62|0)==(1);
    if ($63) {
     __ZNK3osg10Referenced24signalObserversAndDeleteEbb($23,1,1);
    }
   }
  }
  $71 = ((($$03348)) + 4|0);
  $72 = ($71|0)==($1|0);
  if ($72) {
   label = 10;
   break;
  }
  $$pre = HEAP32[$$03348>>2]|0;
  $$049$phi = $$03348;$$03348 = $71;$$pre5557 = $$pre;$$049 = $$049$phi;
 }
 if ((label|0) == 10) {
  return;
 }
 $64 = ___cxa_find_matching_catch_2()|0;
 $65 = tempRet0;
 if ($29) {
  ___resumeException($64|0);
  // unreachable;
 }
 $66 = ((($23)) + 8|0);
 $67 = HEAP32[$66>>2]|0;HEAP32[$66>>2] = (($67-1)|0);
 $68 = ($67|0)==(1);
 if (!($68)) {
  ___resumeException($64|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(3262,($23|0),1,1);
 $69 = __THREW__; __THREW__ = 0;
 $70 = $69&1;
 if ($70) {
  $73 = ___cxa_find_matching_catch_3(0|0)|0;
  $74 = tempRet0;
  ___clang_call_terminate($73);
  // unreachable;
 } else {
  ___resumeException($64|0);
  // unreachable;
 }
}
function __ZNSt3__227__insertion_sort_incompleteIRN5osgDB10ImagePager22SortFileRequestFunctorEPN3osg7ref_ptrINS2_12ImageRequestEEEEEbT0_SA_T_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$$3 = 0, $$068 = 0, $$07195 = 0, $$07494 = 0, $$07693 = 0, $$07693$phi = 0, $$170 = 0, $$175 = 0, $$177 = 0, $$177$phi = 0, $$3 = 0, $$5 = 0, $$pre = 0, $$pre105$pre = 0, $$pre105107 = 0, $$pre105108 = 0, $10 = 0.0, $100 = 0.0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0.0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0.0, $116 = 0, $117 = 0.0, $118 = 0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0.0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0.0, $137 = 0, $138 = 0, $139 = 0.0;
 var $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0;
 var $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0.0, $22 = 0, $23 = 0, $24 = 0.0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0.0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0.0, $36 = 0, $37 = 0, $38 = 0.0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0.0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0.0, $53 = 0, $54 = 0, $55 = 0.0, $56 = 0, $57 = 0, $58 = 0, $59 = 0.0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0.0, $69 = 0, $7 = 0, $70 = 0, $71 = 0.0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0.0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0.0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0.0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0.0;
 var $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = $1;
 $4 = $0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 switch ($6|0) {
 case 2:  {
  $7 = ((($1)) + -4|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ((($8)) + 16|0);
  $10 = +HEAPF64[$9>>3];
  $11 = HEAP32[$0>>2]|0;
  $12 = ((($11)) + 16|0);
  $13 = +HEAPF64[$12>>3];
  $14 = $10 < $13;
  if (!($14)) {
   $$5 = 1;
   return ($$5|0);
  }
  $15 = $8;
  $16 = $11;
  HEAP32[$0>>2] = $15;
  HEAP32[$7>>2] = $16;
  $$5 = 1;
  return ($$5|0);
  break;
 }
 case 3:  {
  $17 = ((($0)) + 4|0);
  $18 = ((($1)) + -4|0);
  $19 = HEAP32[$17>>2]|0;
  $20 = ((($19)) + 16|0);
  $21 = +HEAPF64[$20>>3];
  $22 = HEAP32[$0>>2]|0;
  $23 = ((($22)) + 16|0);
  $24 = +HEAPF64[$23>>3];
  $25 = $21 < $24;
  $26 = HEAP32[$18>>2]|0;
  $27 = ((($26)) + 16|0);
  $28 = +HEAPF64[$27>>3];
  $29 = $28 < $21;
  $30 = $19;
  $31 = $26;
  $32 = $22;
  if (!($25)) {
   if (!($29)) {
    $$5 = 1;
    return ($$5|0);
   }
   HEAP32[$17>>2] = $31;
   HEAP32[$18>>2] = $30;
   $33 = HEAP32[$17>>2]|0;
   $34 = ((($33)) + 16|0);
   $35 = +HEAPF64[$34>>3];
   $36 = HEAP32[$0>>2]|0;
   $37 = ((($36)) + 16|0);
   $38 = +HEAPF64[$37>>3];
   $39 = $35 < $38;
   if (!($39)) {
    $$5 = 1;
    return ($$5|0);
   }
   $40 = $33;
   $41 = $36;
   HEAP32[$0>>2] = $40;
   HEAP32[$17>>2] = $41;
   $$5 = 1;
   return ($$5|0);
  }
  if ($29) {
   HEAP32[$0>>2] = $31;
   HEAP32[$18>>2] = $32;
   $$5 = 1;
   return ($$5|0);
  }
  HEAP32[$0>>2] = $30;
  HEAP32[$17>>2] = $32;
  $42 = HEAP32[$18>>2]|0;
  $43 = ((($42)) + 16|0);
  $44 = +HEAPF64[$43>>3];
  $45 = $44 < $24;
  if (!($45)) {
   $$5 = 1;
   return ($$5|0);
  }
  $46 = $42;
  HEAP32[$17>>2] = $46;
  HEAP32[$18>>2] = $32;
  $$5 = 1;
  return ($$5|0);
  break;
 }
 case 4:  {
  $47 = ((($0)) + 4|0);
  $48 = ((($0)) + 8|0);
  $49 = ((($1)) + -4|0);
  $50 = HEAP32[$47>>2]|0;
  $51 = ((($50)) + 16|0);
  $52 = +HEAPF64[$51>>3];
  $53 = HEAP32[$0>>2]|0;
  $54 = ((($53)) + 16|0);
  $55 = +HEAPF64[$54>>3];
  $56 = $52 < $55;
  $57 = HEAP32[$48>>2]|0;
  $58 = ((($57)) + 16|0);
  $59 = +HEAPF64[$58>>3];
  $60 = $59 < $52;
  $61 = $50;
  $62 = $57;
  $63 = $53;
  do {
   if ($56) {
    if ($60) {
     HEAP32[$0>>2] = $62;
     HEAP32[$48>>2] = $63;
     $70 = $53;$74 = $63;
     break;
    }
    HEAP32[$0>>2] = $61;
    HEAP32[$47>>2] = $63;
    $65 = $59 < $55;
    if ($65) {
     HEAP32[$47>>2] = $62;
     HEAP32[$48>>2] = $63;
     $70 = $53;$74 = $63;
    } else {
     $70 = $57;$74 = $62;
    }
   } else {
    if ($60) {
     HEAP32[$47>>2] = $62;
     HEAP32[$48>>2] = $61;
     $64 = $59 < $55;
     if ($64) {
      HEAP32[$0>>2] = $62;
      HEAP32[$47>>2] = $63;
      $70 = $50;$74 = $61;
     } else {
      $70 = $50;$74 = $61;
     }
    } else {
     $70 = $57;$74 = $62;
    }
   }
  } while(0);
  $66 = HEAP32[$49>>2]|0;
  $67 = ((($66)) + 16|0);
  $68 = +HEAPF64[$67>>3];
  $69 = ((($70)) + 16|0);
  $71 = +HEAPF64[$69>>3];
  $72 = $68 < $71;
  if (!($72)) {
   $$5 = 1;
   return ($$5|0);
  }
  $73 = $66;
  HEAP32[$48>>2] = $73;
  HEAP32[$49>>2] = $74;
  $75 = HEAP32[$48>>2]|0;
  $76 = ((($75)) + 16|0);
  $77 = +HEAPF64[$76>>3];
  $78 = HEAP32[$47>>2]|0;
  $79 = ((($78)) + 16|0);
  $80 = +HEAPF64[$79>>3];
  $81 = $77 < $80;
  if (!($81)) {
   $$5 = 1;
   return ($$5|0);
  }
  $82 = $75;
  $83 = $78;
  HEAP32[$47>>2] = $82;
  HEAP32[$48>>2] = $83;
  $84 = HEAP32[$0>>2]|0;
  $85 = ((($84)) + 16|0);
  $86 = +HEAPF64[$85>>3];
  $87 = $77 < $86;
  if (!($87)) {
   $$5 = 1;
   return ($$5|0);
  }
  $88 = $84;
  HEAP32[$0>>2] = $82;
  HEAP32[$47>>2] = $88;
  $$5 = 1;
  return ($$5|0);
  break;
 }
 case 5:  {
  $89 = ((($0)) + 4|0);
  $90 = ((($0)) + 8|0);
  $91 = ((($0)) + 12|0);
  $92 = ((($1)) + -4|0);
  (__ZNSt3__27__sort5IRN5osgDB10ImagePager22SortFileRequestFunctorEPN3osg7ref_ptrINS2_12ImageRequestEEEEEjT0_SA_SA_SA_SA_T_($0,$89,$90,$91,$92,$2)|0);
  $$5 = 1;
  return ($$5|0);
  break;
 }
 case 1: case 0:  {
  $$5 = 1;
  return ($$5|0);
  break;
 }
 default: {
  $93 = ((($0)) + 8|0);
  $94 = ((($0)) + 4|0);
  $95 = HEAP32[$94>>2]|0;
  $96 = ((($95)) + 16|0);
  $97 = +HEAPF64[$96>>3];
  $98 = HEAP32[$0>>2]|0;
  $99 = ((($98)) + 16|0);
  $100 = +HEAPF64[$99>>3];
  $101 = $97 < $100;
  $102 = HEAP32[$93>>2]|0;
  $103 = ((($102)) + 16|0);
  $104 = +HEAPF64[$103>>3];
  $105 = $104 < $97;
  $106 = $95;
  $107 = $102;
  $108 = $98;
  do {
   if ($101) {
    if ($105) {
     HEAP32[$0>>2] = $107;
     HEAP32[$93>>2] = $108;
     $$pre105108 = $98;
     break;
    }
    HEAP32[$0>>2] = $106;
    HEAP32[$94>>2] = $108;
    $110 = $104 < $100;
    if ($110) {
     HEAP32[$94>>2] = $107;
     HEAP32[$93>>2] = $108;
     $$pre105108 = $98;
    } else {
     $$pre105108 = $102;
    }
   } else {
    if ($105) {
     HEAP32[$94>>2] = $107;
     HEAP32[$93>>2] = $106;
     $109 = $104 < $100;
     if ($109) {
      HEAP32[$0>>2] = $107;
      HEAP32[$94>>2] = $108;
      $$pre105108 = $95;
     } else {
      $$pre105108 = $95;
     }
    } else {
     $$pre105108 = $102;
    }
   }
  } while(0);
  $111 = ((($0)) + 12|0);
  $112 = ($111|0)==($1|0);
  L13: do {
   if ($112) {
    $$170 = 1;$$3 = 0;
   } else {
    $$07195 = $111;$$07494 = 0;$$07693 = $93;$$pre105107 = $$pre105108;
    L14: while(1) {
     $113 = HEAP32[$$07195>>2]|0;
     $114 = ((($113)) + 16|0);
     $115 = +HEAPF64[$114>>3];
     $116 = ((($$pre105107)) + 16|0);
     $117 = +HEAPF64[$116>>3];
     $118 = $115 < $117;
     if ($118) {
      $119 = ($113|0)==(0|0);
      if ($119) {
       $$068 = $$07693;$$177 = $$07195;$124 = $$pre105107;
      } else {
       $120 = ((($113)) + 8|0);
       $121 = HEAP32[$120>>2]|0;HEAP32[$120>>2] = (($121+1)|0);
       $$pre105$pre = HEAP32[$$07693>>2]|0;
       $$068 = $$07693;$$177 = $$07195;$124 = $$pre105$pre;
      }
      while(1) {
       $122 = HEAP32[$$177>>2]|0;
       $123 = ($122|0)==($124|0);
       if (!($123)) {
        HEAP32[$$177>>2] = $124;
        $125 = ($124|0)==(0|0);
        if (!($125)) {
         $126 = ((($124)) + 8|0);
         $127 = HEAP32[$126>>2]|0;HEAP32[$126>>2] = (($127+1)|0);
        }
        $128 = ($122|0)==(0|0);
        if (!($128)) {
         $129 = ((($122)) + 8|0);
         $130 = HEAP32[$129>>2]|0;HEAP32[$129>>2] = (($130-1)|0);
         $131 = ($130|0)==(1);
         if ($131) {
          __THREW__ = 0;
          invoke_viii(3262,($122|0),1,1);
          $132 = __THREW__; __THREW__ = 0;
          $133 = $132&1;
          if ($133) {
           break L14;
          }
         }
        }
       }
       $134 = ($$068|0)==($0|0);
       if ($134) {
        break;
       }
       $135 = ((($$068)) + -4|0);
       $136 = +HEAPF64[$114>>3];
       $137 = HEAP32[$135>>2]|0;
       $138 = ((($137)) + 16|0);
       $139 = +HEAPF64[$138>>3];
       $140 = $136 < $139;
       if ($140) {
        $$177$phi = $$068;$$068 = $135;$124 = $137;$$177 = $$177$phi;
       } else {
        break;
       }
      }
      $141 = HEAP32[$$068>>2]|0;
      $142 = ($141|0)==($113|0);
      if (!($142)) {
       HEAP32[$$068>>2] = $113;
       if (!($119)) {
        $143 = ((($113)) + 8|0);
        $144 = HEAP32[$143>>2]|0;HEAP32[$143>>2] = (($144+1)|0);
       }
       $145 = ($141|0)==(0|0);
       if (!($145)) {
        $146 = ((($141)) + 8|0);
        $147 = HEAP32[$146>>2]|0;HEAP32[$146>>2] = (($147-1)|0);
        $148 = ($147|0)==(1);
        if ($148) {
         __THREW__ = 0;
         invoke_viii(3262,($141|0),1,1);
         $149 = __THREW__; __THREW__ = 0;
         $150 = $149&1;
         if ($150) {
          break;
         }
        }
       }
      }
      $151 = (($$07494) + 1)|0;
      $152 = ($151|0)==(8);
      $153 = ((($$07195)) + 4|0);
      $154 = ($153|0)==($1|0);
      if (!($119)) {
       $155 = ((($113)) + 8|0);
       $156 = HEAP32[$155>>2]|0;HEAP32[$155>>2] = (($156-1)|0);
       $157 = ($156|0)==(1);
       if ($157) {
        __ZNK3osg10Referenced24signalObserversAndDeleteEbb($113,1,1);
       }
      }
      if ($152) {
       $$170 = 0;$$3 = $154;
       break L13;
      } else {
       $$175 = $151;
      }
     } else {
      $$175 = $$07494;
     }
     $165 = ((($$07195)) + 4|0);
     $166 = ($165|0)==($1|0);
     if ($166) {
      $$170 = 1;$$3 = 0;
      break L13;
     }
     $$pre = HEAP32[$$07195>>2]|0;
     $$07693$phi = $$07195;$$07195 = $165;$$07494 = $$175;$$pre105107 = $$pre;$$07693 = $$07693$phi;
    }
    $158 = ___cxa_find_matching_catch_2()|0;
    $159 = tempRet0;
    if ($119) {
     ___resumeException($158|0);
     // unreachable;
    }
    $160 = ((($113)) + 8|0);
    $161 = HEAP32[$160>>2]|0;HEAP32[$160>>2] = (($161-1)|0);
    $162 = ($161|0)==(1);
    if (!($162)) {
     ___resumeException($158|0);
     // unreachable;
    }
    __THREW__ = 0;
    invoke_viii(3262,($113|0),1,1);
    $163 = __THREW__; __THREW__ = 0;
    $164 = $163&1;
    if ($164) {
     $167 = ___cxa_find_matching_catch_3(0|0)|0;
     $168 = tempRet0;
     ___clang_call_terminate($167);
     // unreachable;
    } else {
     ___resumeException($158|0);
     // unreachable;
    }
   }
  } while(0);
  $$$3 = $$170 | $$3;
  $$5 = $$$3;
  return ($$5|0);
 }
 }
 return (0)|0;
}
function __ZN5osgDB10ImagePagerD2Ev($0) {
 $0 = $0|0;
 var $$0 = 0, $$02 = 0, $$2 = 0, $$24 = 0, $$3 = 0, $$35 = 0, $$4 = 0, $$46 = 0, $$pre$i = 0, $$pre$i13 = 0, $1 = 0, $10 = 0, $100 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (74904);
 __THREW__ = 0;
 (invoke_ii(4158,($0|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if ($2) {
   $45 = ___cxa_find_matching_catch_2()|0;
   $46 = tempRet0;
   $47 = ((($0)) + 60|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = ($48|0)==(0|0);
   if (!($49)) {
    $50 = ((($48)) + 8|0);
    $51 = HEAP32[$50>>2]|0;HEAP32[$50>>2] = (($51-1)|0);
    $52 = ($51|0)==(1);
    if ($52) {
     __THREW__ = 0;
     invoke_viii(3262,($48|0),1,1);
     $53 = __THREW__; __THREW__ = 0;
     $54 = $53&1;
     if ($54) {
      $99 = ___cxa_find_matching_catch_3(0|0)|0;
      $100 = tempRet0;
      ___clang_call_terminate($99);
      // unreachable;
     }
    }
   }
   HEAP32[$47>>2] = 0;
   $$0 = $46;$$02 = $45;
   label = 25;
  } else {
   $3 = ((($0)) + 60|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = ($4|0)==(0|0);
   if (!($5)) {
    $6 = ((($4)) + 8|0);
    $7 = HEAP32[$6>>2]|0;HEAP32[$6>>2] = (($7-1)|0);
    $8 = ($7|0)==(1);
    if ($8) {
     __THREW__ = 0;
     invoke_viii(3262,($4|0),1,1);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      $55 = ___cxa_find_matching_catch_2()|0;
      $56 = tempRet0;
      $$0 = $56;$$02 = $55;
      label = 25;
      break;
     }
    }
   }
   HEAP32[$3>>2] = 0;
   $11 = ((($0)) + 48|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = ($12|0)==(0|0);
   if (!($13)) {
    $14 = ((($0)) + 52|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = ($15|0)==($12|0);
    do {
     if ($16) {
      $30 = $12;
     } else {
      $18 = $15;
      while(1) {
       $17 = ((($18)) + -4|0);
       HEAP32[$14>>2] = $17;
       $19 = HEAP32[$17>>2]|0;
       $20 = ($19|0)==(0|0);
       if (!($20)) {
        $21 = ((($19)) + 8|0);
        $22 = HEAP32[$21>>2]|0;HEAP32[$21>>2] = (($22-1)|0);
        $23 = ($22|0)==(1);
        if ($23) {
         __THREW__ = 0;
         invoke_viii(3262,($19|0),1,1);
         $24 = __THREW__; __THREW__ = 0;
         $25 = $24&1;
         if ($25) {
          label = 11;
          break;
         }
        }
       }
       HEAP32[$17>>2] = 0;
       $26 = HEAP32[$14>>2]|0;
       $27 = ($26|0)==($12|0);
       if ($27) {
        label = 12;
        break;
       } else {
        $18 = $26;
       }
      }
      if ((label|0) == 11) {
       $28 = ___cxa_find_matching_catch_2()|0;
       $29 = tempRet0;
       ___cxa_call_unexpected(($28|0));
       // unreachable;
      }
      else if ((label|0) == 12) {
       $$pre$i = HEAP32[$11>>2]|0;
       $30 = $$pre$i;
       break;
      }
     }
    } while(0);
    __ZdlPv($30);
   }
   $31 = ((($0)) + 44|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ($32|0)==(0|0);
   if (!($33)) {
    $34 = ((($32)) + 8|0);
    $35 = HEAP32[$34>>2]|0;HEAP32[$34>>2] = (($35-1)|0);
    $36 = ($35|0)==(1);
    if ($36) {
     __THREW__ = 0;
     invoke_viii(3262,($32|0),1,1);
     $37 = __THREW__; __THREW__ = 0;
     $38 = $37&1;
     if ($38) {
      $77 = ___cxa_find_matching_catch_2()|0;
      $78 = tempRet0;
      $$2 = $78;$$24 = $77;
      label = 40;
      break;
     }
    }
   }
   HEAP32[$31>>2] = 0;
   $39 = ((($0)) + 32|0);
   __THREW__ = 0;
   invoke_vi(707,($39|0));
   $40 = __THREW__; __THREW__ = 0;
   $41 = $40&1;
   if ($41) {
    $87 = ___cxa_find_matching_catch_2()|0;
    $88 = tempRet0;
    $$3 = $88;$$35 = $87;
    label = 42;
    break;
   }
   $42 = ((($0)) + 12|0);
   __THREW__ = 0;
   invoke_vi(707,($42|0));
   $43 = __THREW__; __THREW__ = 0;
   $44 = $43&1;
   if ($44) {
    $92 = ___cxa_find_matching_catch_2()|0;
    $93 = tempRet0;
    $$4 = $93;$$46 = $92;
    break;
   } else {
    __ZN3osg10ReferencedD2Ev($0);
    return;
   }
  }
 } while(0);
 if ((label|0) == 25) {
  $57 = ((($0)) + 48|0);
  $58 = HEAP32[$57>>2]|0;
  $59 = ($58|0)==(0|0);
  if (!($59)) {
   $60 = ((($0)) + 52|0);
   $61 = HEAP32[$60>>2]|0;
   $62 = ($61|0)==($58|0);
   do {
    if ($62) {
     $76 = $58;
    } else {
     $64 = $61;
     while(1) {
      $63 = ((($64)) + -4|0);
      HEAP32[$60>>2] = $63;
      $65 = HEAP32[$63>>2]|0;
      $66 = ($65|0)==(0|0);
      if (!($66)) {
       $67 = ((($65)) + 8|0);
       $68 = HEAP32[$67>>2]|0;HEAP32[$67>>2] = (($68-1)|0);
       $69 = ($68|0)==(1);
       if ($69) {
        __THREW__ = 0;
        invoke_viii(3262,($65|0),1,1);
        $70 = __THREW__; __THREW__ = 0;
        $71 = $70&1;
        if ($71) {
         label = 31;
         break;
        }
       }
      }
      HEAP32[$63>>2] = 0;
      $72 = HEAP32[$60>>2]|0;
      $73 = ($72|0)==($58|0);
      if ($73) {
       label = 32;
       break;
      } else {
       $64 = $72;
      }
     }
     if ((label|0) == 31) {
      $74 = ___cxa_find_matching_catch_2()|0;
      $75 = tempRet0;
      ___cxa_call_unexpected(($74|0));
      // unreachable;
     }
     else if ((label|0) == 32) {
      $$pre$i13 = HEAP32[$57>>2]|0;
      $76 = $$pre$i13;
      break;
     }
    }
   } while(0);
   __ZdlPv($76);
  }
  $79 = ((($0)) + 44|0);
  $80 = HEAP32[$79>>2]|0;
  $81 = ($80|0)==(0|0);
  if (!($81)) {
   $82 = ((($80)) + 8|0);
   $83 = HEAP32[$82>>2]|0;HEAP32[$82>>2] = (($83-1)|0);
   $84 = ($83|0)==(1);
   if ($84) {
    __THREW__ = 0;
    invoke_viii(3262,($80|0),1,1);
    $85 = __THREW__; __THREW__ = 0;
    $86 = $85&1;
    if ($86) {
     $99 = ___cxa_find_matching_catch_3(0|0)|0;
     $100 = tempRet0;
     ___clang_call_terminate($99);
     // unreachable;
    }
   }
  }
  HEAP32[$79>>2] = 0;
  $$2 = $$0;$$24 = $$02;
  label = 40;
 }
 if ((label|0) == 40) {
  $89 = ((($0)) + 32|0);
  __THREW__ = 0;
  invoke_vi(707,($89|0));
  $90 = __THREW__; __THREW__ = 0;
  $91 = $90&1;
  if ($91) {
   $99 = ___cxa_find_matching_catch_3(0|0)|0;
   $100 = tempRet0;
   ___clang_call_terminate($99);
   // unreachable;
  } else {
   $$3 = $$2;$$35 = $$24;
   label = 42;
  }
 }
 if ((label|0) == 42) {
  $94 = ((($0)) + 12|0);
  __THREW__ = 0;
  invoke_vi(707,($94|0));
  $95 = __THREW__; __THREW__ = 0;
  $96 = $95&1;
  if ($96) {
   $99 = ___cxa_find_matching_catch_3(0|0)|0;
   $100 = tempRet0;
   ___clang_call_terminate($99);
   // unreachable;
  } else {
   $$4 = $$3;$$46 = $$35;
  }
 }
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $97 = __THREW__; __THREW__ = 0;
 $98 = $97&1;
 if ($98) {
  $99 = ___cxa_find_matching_catch_3(0|0)|0;
  $100 = tempRet0;
  ___clang_call_terminate($99);
  // unreachable;
 } else {
  ___resumeException($$46|0);
  // unreachable;
 }
}
function __ZN5osgDB10ImagePagerD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(2657,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK5osgDB10ImagePager14getPreLoadTimeEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 64|0);
 $2 = +HEAPF64[$1>>3];
 return (+$2);
}
function __ZN5osgDB10ImagePager16readRefImageFileERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEPKN3osg10ReferencedE($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $6 = 0;
 } else {
  $5 = (___dynamic_cast($3,26488,5376,0)|0);
  $6 = $5;
 }
 __ZN5osgDB16readRefImageFileERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEPKNS_7OptionsE($0,$2,$6);
 return;
}
function __ZN5osgDB10ImagePager16requestImageFileERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEPN3osg6ObjectEidPKNSA_10FrameStampERNSA_7ref_ptrINSA_10ReferencedEEEPKSH_($0,$1,$2,$3,$4,$5,$6,$7) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = +$4;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 var $$$i = 0, $$018 = 0, $$1 = 0, $$116 = 0, $$2 = 0, $$217 = 0, $$pr$i = 0, $$sroa$032$053 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $phitmp = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $8 = ($7|0)==(0|0);
 if ($8) {
  label = 3;
 } else {
  $9 = (___dynamic_cast($7,26488,5376,0)|0);
  $10 = ($9|0)==(0|0);
  if ($10) {
   label = 3;
  } else {
   $$018 = $9;
  }
 }
 if ((label|0) == 3) {
  $11 = (__ZN5osgDB8Registry8instanceEb(0)|0);
  $12 = ((($11)) + 160|0);
  $13 = HEAP32[$12>>2]|0;
  $$018 = $13;
 }
 $14 = HEAP32[$6>>2]|0;
 $15 = ($14|0)==(0|0);
 if (!($15)) {
  $16 = (___dynamic_cast($14,26488,32664,0)|0);
  $phitmp = ($16|0)==(0|0);
  if (!($phitmp)) {
   /* fence */;
   $17 = ((($14)) + 8|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = ($18|0)>(1);
   if ($19) {
    return;
   }
  }
 }
 $20 = (__Znwj(64)|0);
 __THREW__ = 0;
 invoke_vii(3435,($20|0),1);
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if ($22) {
  $100 = ___cxa_find_matching_catch_2()|0;
  $101 = tempRet0;
  __ZdlPv($20);
  $$2 = $101;$$217 = $100;
  ___resumeException($$217|0);
  // unreachable;
 }
 HEAP32[$20>>2] = (74952);
 $23 = ((($20)) + 12|0);
 $24 = ((($20)) + 48|0);
 dest=$23; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAP32[$24>>2] = -1;
 $25 = ((($20)) + 52|0);
 HEAP32[$25>>2] = 0;
 $26 = ((($20)) + 56|0);
 HEAP32[$26>>2] = 0;
 $27 = ((($20)) + 60|0);
 HEAP32[$27>>2] = 0;
 $28 = ((($20)) + 8|0);
 $29 = HEAP32[$28>>2]|0;HEAP32[$28>>2] = (($29+1)|0);
 $30 = ((($20)) + 16|0);
 HEAPF64[$30>>3] = $4;
 $31 = ((($20)) + 24|0);
 __THREW__ = 0;
 (invoke_iii(3477,($31|0),($1|0))|0);
 $32 = __THREW__; __THREW__ = 0;
 $33 = $32&1;
 L15: do {
  if ($33) {
   label = 36;
  } else {
   $34 = ((($20)) + 40|0);
   $35 = ($2|0)==(0|0);
   if ($35) {
    $41 = 0;
   } else {
    __THREW__ = 0;
    $36 = (invoke_ii(3325,($2|0))|0);
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     label = 36;
     break;
    } else {
     $41 = $36;
    }
   }
   $39 = HEAP32[$34>>2]|0;
   $40 = ($39|0)==($41|0);
   if ($40) {
    $51 = $41;
   } else {
    HEAP32[$34>>2] = $41;
    $42 = ($41|0)==(0|0);
    if (!($42)) {
     $43 = ((($41)) + 8|0);
     $44 = HEAP32[$43>>2]|0;HEAP32[$43>>2] = (($44+1)|0);
    }
    $45 = ($39|0)==(0|0);
    if (!($45)) {
     $46 = ((($39)) + 8|0);
     $47 = HEAP32[$46>>2]|0;HEAP32[$46>>2] = (($47-1)|0);
     $48 = ($47|0)==(1);
     if ($48) {
      __THREW__ = 0;
      invoke_viii(3262,($39|0),1,1);
      $49 = __THREW__; __THREW__ = 0;
      $50 = $49&1;
      if ($50) {
       label = 36;
       break;
      }
     }
    }
    $$pr$i = HEAP32[$34>>2]|0;
    $51 = $$pr$i;
   }
   $52 = ($51|0)==(0|0);
   if ($52) {
    $57 = 0;
   } else {
    $53 = ((($51)) + 24|0);
    $54 = HEAP32[$53>>2]|0;
    $55 = ($54|0)!=(0|0);
    $$$i = $55 ? $2 : 0;
    $57 = $$$i;
   }
   $56 = ((($20)) + 44|0);
   HEAP32[$56>>2] = $57;
   HEAP32[$24>>2] = $3;
   $58 = ((($0)) + 44|0);
   $59 = HEAP32[$58>>2]|0;
   HEAP32[$26>>2] = $59;
   $60 = HEAP32[$27>>2]|0;
   $61 = ($60|0)==($$018|0);
   if (!($61)) {
    HEAP32[$27>>2] = $$018;
    $62 = ($$018|0)==(0|0);
    if (!($62)) {
     $63 = ((($$018)) + 8|0);
     $64 = HEAP32[$63>>2]|0;HEAP32[$63>>2] = (($64+1)|0);
    }
    $65 = ($60|0)==(0|0);
    if (!($65)) {
     $66 = ((($60)) + 8|0);
     $67 = HEAP32[$66>>2]|0;HEAP32[$66>>2] = (($67-1)|0);
     $68 = ($67|0)==(1);
     if ($68) {
      __THREW__ = 0;
      invoke_viii(3262,($60|0),1,1);
      $69 = __THREW__; __THREW__ = 0;
      $70 = $69&1;
      if ($70) {
       label = 36;
       break;
      }
     }
    }
   }
   $71 = HEAP32[$6>>2]|0;
   $72 = ($71|0)==($20|0);
   if (!($72)) {
    HEAP32[$6>>2] = $20;
    $73 = HEAP32[$28>>2]|0;HEAP32[$28>>2] = (($73+1)|0);
    $74 = ($71|0)==(0|0);
    if (!($74)) {
     $75 = ((($71)) + 8|0);
     $76 = HEAP32[$75>>2]|0;HEAP32[$75>>2] = (($76-1)|0);
     $77 = ($76|0)==(1);
     if ($77) {
      __THREW__ = 0;
      invoke_viii(3262,($71|0),1,1);
      $78 = __THREW__; __THREW__ = 0;
      $79 = $78&1;
      if ($79) {
       label = 36;
       break;
      }
     }
    }
   }
   $80 = HEAP32[$58>>2]|0;
   __THREW__ = 0;
   invoke_vii(4159,($80|0),($20|0));
   $81 = __THREW__; __THREW__ = 0;
   $82 = $81&1;
   if ($82) {
    label = 36;
   } else {
    $83 = ((($0)) + 24|0);
    $84 = HEAP8[$83>>0]|0;
    $85 = ($84<<24>>24)==(0);
    if ($85) {
     $86 = ((($0)) + 12|0);
     $87 = HEAP32[$86>>2]|0;
     $88 = ((($87)) + 8|0);
     $89 = HEAP32[$88>>2]|0;
     __THREW__ = 0;
     (invoke_ii($89|0,($86|0))|0);
     $90 = __THREW__; __THREW__ = 0;
     $91 = $90&1;
     if ($91) {
      label = 36;
      break;
     }
     $92 = HEAP8[$83>>0]|0;
     $93 = ($92<<24>>24)==(0);
     L50: do {
      if ($93) {
       HEAP8[$83>>0] = 1;
       $94 = ((($0)) + 25|0);
       HEAP8[$94>>0] = 0;
       $95 = ((($0)) + 48|0);
       $96 = HEAP32[$95>>2]|0;
       $97 = ((($0)) + 52|0);
       $98 = HEAP32[$97>>2]|0;
       $99 = ($96|0)==($98|0);
       if (!($99)) {
        $$sroa$032$053 = $96;
        while(1) {
         $104 = HEAP32[$$sroa$032$053>>2]|0;
         $105 = ((($104)) + 12|0);
         __THREW__ = 0;
         (invoke_ii(3389,($105|0))|0);
         $106 = __THREW__; __THREW__ = 0;
         $107 = $106&1;
         if ($107) {
          break;
         }
         $108 = ((($$sroa$032$053)) + 4|0);
         $109 = HEAP32[$97>>2]|0;
         $110 = ($108|0)==($109|0);
         if ($110) {
          break L50;
         } else {
          $$sroa$032$053 = $108;
         }
        }
        $111 = ___cxa_find_matching_catch_2()|0;
        $112 = tempRet0;
        $113 = HEAP32[$86>>2]|0;
        $114 = ((($113)) + 12|0);
        $115 = HEAP32[$114>>2]|0;
        __THREW__ = 0;
        (invoke_ii($115|0,($86|0))|0);
        $116 = __THREW__; __THREW__ = 0;
        $117 = $116&1;
        if (!($117)) {
         $$1 = $112;$$116 = $111;
         break L15;
        }
        $131 = ___cxa_find_matching_catch_3(0|0)|0;
        $132 = tempRet0;
        ___clang_call_terminate($131);
        // unreachable;
       }
      }
     } while(0);
     $118 = HEAP32[$86>>2]|0;
     $119 = ((($118)) + 12|0);
     $120 = HEAP32[$119>>2]|0;
     __THREW__ = 0;
     (invoke_ii($120|0,($86|0))|0);
     $121 = __THREW__; __THREW__ = 0;
     $122 = $121&1;
     if ($122) {
      $123 = ___cxa_find_matching_catch_2()|0;
      $124 = tempRet0;
      $$1 = $124;$$116 = $123;
      break;
     }
    }
    $125 = HEAP32[$28>>2]|0;HEAP32[$28>>2] = (($125-1)|0);
    $126 = ($125|0)==(1);
    if (!($126)) {
     return;
    }
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($20,1,1);
    return;
   }
  }
 } while(0);
 if ((label|0) == 36) {
  $102 = ___cxa_find_matching_catch_2()|0;
  $103 = tempRet0;
  $$1 = $103;$$116 = $102;
 }
 $127 = HEAP32[$28>>2]|0;HEAP32[$28>>2] = (($127-1)|0);
 $128 = ($127|0)==(1);
 if (!($128)) {
  $$2 = $$1;$$217 = $$116;
  ___resumeException($$217|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(3262,($20|0),1,1);
 $129 = __THREW__; __THREW__ = 0;
 $130 = $129&1;
 if ($130) {
  $131 = ___cxa_find_matching_catch_3(0|0)|0;
  $132 = tempRet0;
  ___clang_call_terminate($131);
  // unreachable;
 } else {
  $$2 = $$1;$$217 = $$116;
  ___resumeException($$217|0);
  // unreachable;
 }
}
function __ZNK5osgDB10ImagePager24requiresUpdateSceneGraphEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 60|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($2)) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4|0)!=($6|0);
 return ($7|0);
}
function __ZN5osgDB10ImagePager16updateSceneGraphERKN3osg10FrameStampE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$ = 0, $$phi$trans$insert = 0, $$pre = 0, $$sink18$index = 0, $$sink18$index3 = 0, $$sroa$024$045 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = ((($0)) + 60|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($4)) + 24|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($6)) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 (FUNCTION_TABLE_ii[$8 & 8191]($5)|0);
 $9 = HEAP32[$3>>2]|0;
 $10 = ((($9)) + 12|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($9)) + 16|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($11|0)==($13|0);
 if ($14) {
  $32 = HEAP32[$5>>2]|0;
  $33 = ((($32)) + 12|0);
  $34 = HEAP32[$33>>2]|0;
  (FUNCTION_TABLE_ii[$34 & 8191]($5)|0);
  STACKTOP = sp;return;
 }
 $$sroa$024$045 = $11;
 while(1) {
  $35 = HEAP32[$$sroa$024$045>>2]|0;
  $36 = ((($35)) + 40|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = ($37|0)==(0|0);
  if ($38) {
   label = 16;
  } else {
   $39 = ((($37)) + 24|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = ($40|0)==(0|0);
   if ($41) {
    label = 16;
   } else {
    $42 = ((($35)) + 44|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = ($43|0)==(0|0);
    if ($44) {
     label = 16;
    } else {
     $45 = (___dynamic_cast($43,26112,26864,0)|0);
     $46 = ($45|0)==(0|0);
     if ($46) {
      label = 16;
     } else {
      $47 = ((($35)) + 48|0);
      $48 = HEAP32[$47>>2]|0;
      $49 = ($48|0)>(0);
      $$ = $49 ? $48 : 0;
      $50 = HEAP32[$45>>2]|0;
      $51 = ((($50)) + 196|0);
      $52 = HEAP32[$51>>2]|0;
      $53 = ((($35)) + 52|0);
      $54 = HEAP32[$53>>2]|0;
      __THREW__ = 0;
      invoke_viii($52|0,($45|0),($$|0),($54|0));
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 15;
       break;
      }
     }
    }
   }
  }
  if ((label|0) == 16) {
   label = 0;
   __THREW__ = 0;
   $59 = (invoke_ii(3265,3)|0);
   $60 = __THREW__; __THREW__ = 0;
   $61 = $60&1;
   if ($61) {
    label = 29;
    break;
   }
   if ($59) {
    __THREW__ = 0;
    $62 = (invoke_ii(3266,3)|0);
    $63 = __THREW__; __THREW__ = 0;
    $64 = $63&1;
    if ($64) {
     label = 29;
     break;
    }
    __THREW__ = 0;
    $65 = (invoke_iiii(3267,($62|0),(165971|0),86)|0);
    $66 = __THREW__; __THREW__ = 0;
    $67 = $66&1;
    if ($67) {
     label = 29;
     break;
    }
    $68 = HEAP32[$65>>2]|0;
    $69 = ((($68)) + -12|0);
    $70 = HEAP32[$69>>2]|0;
    $71 = (($65) + ($70)|0);
    __THREW__ = 0;
    invoke_vii(3257,($2|0),($71|0));
    $72 = __THREW__; __THREW__ = 0;
    $73 = $72&1;
    if ($73) {
     label = 29;
     break;
    }
    __THREW__ = 0;
    $74 = (invoke_iii(3255,($2|0),(215188|0))|0);
    $75 = __THREW__; __THREW__ = 0;
    $76 = $75&1;
    if ($76) {
     label = 23;
     break;
    }
    $77 = HEAP32[$74>>2]|0;
    $78 = ((($77)) + 28|0);
    $79 = HEAP32[$78>>2]|0;
    __THREW__ = 0;
    $80 = (invoke_iii($79|0,($74|0),10)|0);
    $81 = __THREW__; __THREW__ = 0;
    $82 = $81&1;
    if ($82) {
     label = 23;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3263,($2|0));
    $89 = __THREW__; __THREW__ = 0;
    $90 = $89&1;
    if ($90) {
     label = 29;
     break;
    }
    __THREW__ = 0;
    (invoke_iii(3268,($65|0),($80|0))|0);
    $91 = __THREW__; __THREW__ = 0;
    $92 = $91&1;
    if ($92) {
     label = 29;
     break;
    }
    __THREW__ = 0;
    (invoke_ii(3269,($65|0))|0);
    $93 = __THREW__; __THREW__ = 0;
    $94 = $93&1;
    if ($94) {
     label = 29;
     break;
    }
   }
  }
  $16 = ((($$sroa$024$045)) + 4|0);
  $15 = HEAP32[$3>>2]|0;
  $20 = ((($15)) + 16|0);
  $97 = HEAP32[$20>>2]|0;
  $98 = ($16|0)==($97|0);
  if ($98) {
   label = 3;
   break;
  } else {
   $$sroa$024$045 = $16;
  }
 }
 do {
  if ((label|0) == 3) {
   $$phi$trans$insert = ((($15)) + 12|0);
   $$pre = HEAP32[$$phi$trans$insert>>2]|0;
   $17 = ($16|0)==($$pre|0);
   if ($17) {
    $32 = HEAP32[$5>>2]|0;
    $33 = ((($32)) + 12|0);
    $34 = HEAP32[$33>>2]|0;
    (FUNCTION_TABLE_ii[$34 & 8191]($5)|0);
    STACKTOP = sp;return;
   } else {
    $19 = $16;
   }
   while(1) {
    $18 = ((($19)) + -4|0);
    HEAP32[$20>>2] = $18;
    $21 = HEAP32[$18>>2]|0;
    $22 = ($21|0)==(0|0);
    if (!($22)) {
     $23 = ((($21)) + 8|0);
     $24 = HEAP32[$23>>2]|0;HEAP32[$23>>2] = (($24-1)|0);
     $25 = ($24|0)==(1);
     if ($25) {
      __THREW__ = 0;
      invoke_viii(3262,($21|0),1,1);
      $26 = __THREW__; __THREW__ = 0;
      $27 = $26&1;
      if ($27) {
       label = 8;
       break;
      }
     }
    }
    HEAP32[$18>>2] = 0;
    $28 = HEAP32[$20>>2]|0;
    $29 = ($28|0)==($$pre|0);
    if ($29) {
     label = 9;
     break;
    } else {
     $19 = $28;
    }
   }
   if ((label|0) == 8) {
    $30 = ___cxa_find_matching_catch_2()|0;
    $31 = tempRet0;
    ___cxa_call_unexpected(($30|0));
    // unreachable;
   }
   else if ((label|0) == 9) {
    $32 = HEAP32[$5>>2]|0;
    $33 = ((($32)) + 12|0);
    $34 = HEAP32[$33>>2]|0;
    (FUNCTION_TABLE_ii[$34 & 8191]($5)|0);
    STACKTOP = sp;return;
   }
  }
  else if ((label|0) == 15) {
   $57 = ___cxa_find_matching_catch_2()|0;
   $58 = tempRet0;
   $$sink18$index = $57;$$sink18$index3 = $58;
  }
  else if ((label|0) == 23) {
   $83 = ___cxa_find_matching_catch_2()|0;
   $84 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($2|0));
   $85 = __THREW__; __THREW__ = 0;
   $86 = $85&1;
   if ($86) {
    $87 = ___cxa_find_matching_catch_3(0|0)|0;
    $88 = tempRet0;
    ___clang_call_terminate($87);
    // unreachable;
   } else {
    $$sink18$index = $83;$$sink18$index3 = $84;
    break;
   }
  }
  else if ((label|0) == 29) {
   $95 = ___cxa_find_matching_catch_2()|0;
   $96 = tempRet0;
   $$sink18$index = $95;$$sink18$index3 = $96;
  }
 } while(0);
 $99 = HEAP32[$5>>2]|0;
 $100 = ((($99)) + 12|0);
 $101 = HEAP32[$100>>2]|0;
 __THREW__ = 0;
 (invoke_ii($101|0,($5|0))|0);
 $102 = __THREW__; __THREW__ = 0;
 $103 = $102&1;
 if ($103) {
  $104 = ___cxa_find_matching_catch_3(0|0)|0;
  $105 = tempRet0;
  ___clang_call_terminate($104);
  // unreachable;
 } else {
  ___resumeException($$sink18$index|0);
  // unreachable;
 }
}
function __ZN5osgDB10ImagePager16signalBeginFrameEPKN3osg10FrameStampE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 }
 $3 = ((($1)) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 28|0);
 $6 = HEAP32[$5>>2]|0;HEAP32[$5>>2] = $4;
 return;
}
function __ZN5osgDB10ImagePager14signalEndFrameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN5osgDB10ImagePager9ReadQueue3addEPNS0_12ImageRequestE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$05 = 0, $$1 = 0, $$16 = 0, $$pre$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index3Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp + 4|0;
 $3 = sp;
 $4 = ((($0)) + 24|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($5)) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 (FUNCTION_TABLE_ii[$7 & 8191]($4)|0);
 $8 = ((($0)) + 12|0);
 HEAP32[$3>>2] = $1;
 $9 = ($1|0)==(0|0);
 if (!($9)) {
  $10 = ((($1)) + 8|0);
  $11 = HEAP32[$10>>2]|0;HEAP32[$10>>2] = (($11+1)|0);
 }
 $12 = ((($0)) + 16|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($0)) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($13|0)==($15|0);
 if ($16) {
  __THREW__ = 0;
  invoke_vii(4156,($8|0),($3|0));
  $23 = __THREW__; __THREW__ = 0;
  $24 = $23&1;
  if ($24) {
   $94 = ___cxa_find_matching_catch_2()|0;
   $95 = tempRet0;
   $96 = HEAP32[$3>>2]|0;
   $97 = ($96|0)==(0|0);
   if (!($97)) {
    $98 = ((($96)) + 8|0);
    $99 = HEAP32[$98>>2]|0;HEAP32[$98>>2] = (($99-1)|0);
    $100 = ($99|0)==(1);
    if ($100) {
     __THREW__ = 0;
     invoke_viii(3262,($96|0),1,1);
     $101 = __THREW__; __THREW__ = 0;
     $102 = $101&1;
     if ($102) {
      $160 = ___cxa_find_matching_catch_3(0|0)|0;
      $161 = tempRet0;
      ___clang_call_terminate($160);
      // unreachable;
     }
    }
   }
   HEAP32[$3>>2] = 0;
   $$0 = $95;$$05 = $94;
   label = 32;
  } else {
   label = 8;
  }
 } else {
  $17 = HEAP32[$3>>2]|0;
  HEAP32[$13>>2] = $17;
  $18 = ($17|0)==(0|0);
  if ($18) {
   $22 = $13;
  } else {
   $19 = ((($17)) + 8|0);
   $20 = HEAP32[$19>>2]|0;HEAP32[$19>>2] = (($20+1)|0);
   $$pre$i = HEAP32[$12>>2]|0;
   $22 = $$pre$i;
  }
  $21 = ((($22)) + 4|0);
  HEAP32[$12>>2] = $21;
  label = 8;
 }
 do {
  if ((label|0) == 8) {
   $25 = HEAP32[$3>>2]|0;
   $26 = ($25|0)==(0|0);
   if (!($26)) {
    $27 = ((($25)) + 8|0);
    $28 = HEAP32[$27>>2]|0;HEAP32[$27>>2] = (($28-1)|0);
    $29 = ($28|0)==(1);
    if ($29) {
     __THREW__ = 0;
     invoke_viii(3262,($25|0),1,1);
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      $92 = ___cxa_find_matching_catch_2()|0;
      $93 = tempRet0;
      $$0 = $93;$$05 = $92;
      label = 32;
      break;
     }
    }
   }
   $32 = ((($1)) + 56|0);
   HEAP32[$32>>2] = $0;
   __THREW__ = 0;
   $33 = (invoke_ii(3265,4)|0);
   $34 = __THREW__; __THREW__ = 0;
   $35 = $34&1;
   L23: do {
    if ($35) {
     label = 33;
    } else {
     do {
      if ($33) {
       __THREW__ = 0;
       $36 = (invoke_ii(3266,4)|0);
       $37 = __THREW__; __THREW__ = 0;
       $38 = $37&1;
       if ($38) {
        label = 33;
        break L23;
       }
       __THREW__ = 0;
       $39 = (invoke_iiii(3267,($36|0),(166058|0),27)|0);
       $40 = __THREW__; __THREW__ = 0;
       $41 = $40&1;
       if ($41) {
        label = 33;
        break L23;
       }
       $42 = ((($1)) + 24|0);
       $43 = ((($42)) + 11|0);
       $44 = HEAP8[$43>>0]|0;
       $45 = ($44<<24>>24)<(0);
       $46 = HEAP32[$42>>2]|0;
       $47 = $45 ? $46 : $42;
       $48 = ((($1)) + 28|0);
       $49 = HEAP32[$48>>2]|0;
       $50 = $44&255;
       $51 = $45 ? $49 : $50;
       __THREW__ = 0;
       $52 = (invoke_iiii(3267,($39|0),($47|0),($51|0))|0);
       $53 = __THREW__; __THREW__ = 0;
       $54 = $53&1;
       if ($54) {
        label = 33;
        break L23;
       }
       __THREW__ = 0;
       $55 = (invoke_iiii(3267,($52|0),(166086|0),10)|0);
       $56 = __THREW__; __THREW__ = 0;
       $57 = $56&1;
       if ($57) {
        label = 33;
        break L23;
       }
       $58 = HEAP32[$12>>2]|0;
       $59 = HEAP32[$8>>2]|0;
       $60 = (($58) - ($59))|0;
       $61 = $60 >> 2;
       __THREW__ = 0;
       $62 = (invoke_iii(3417,($55|0),($61|0))|0);
       $63 = __THREW__; __THREW__ = 0;
       $64 = $63&1;
       if ($64) {
        label = 33;
        break L23;
       }
       $65 = HEAP32[$62>>2]|0;
       $66 = ((($65)) + -12|0);
       $67 = HEAP32[$66>>2]|0;
       $68 = (($62) + ($67)|0);
       __THREW__ = 0;
       invoke_vii(3257,($2|0),($68|0));
       $69 = __THREW__; __THREW__ = 0;
       $70 = $69&1;
       if ($70) {
        label = 33;
        break L23;
       }
       __THREW__ = 0;
       $71 = (invoke_iii(3255,($2|0),(215188|0))|0);
       $72 = __THREW__; __THREW__ = 0;
       $73 = $72&1;
       if (!($73)) {
        $74 = HEAP32[$71>>2]|0;
        $75 = ((($74)) + 28|0);
        $76 = HEAP32[$75>>2]|0;
        __THREW__ = 0;
        $77 = (invoke_iii($76|0,($71|0),10)|0);
        $78 = __THREW__; __THREW__ = 0;
        $79 = $78&1;
        if (!($79)) {
         __THREW__ = 0;
         invoke_vi(3263,($2|0));
         $80 = __THREW__; __THREW__ = 0;
         $81 = $80&1;
         if ($81) {
          label = 33;
          break L23;
         }
         __THREW__ = 0;
         (invoke_iii(3268,($62|0),($77|0))|0);
         $88 = __THREW__; __THREW__ = 0;
         $89 = $88&1;
         if ($89) {
          label = 33;
          break L23;
         }
         __THREW__ = 0;
         (invoke_ii(3269,($62|0))|0);
         $90 = __THREW__; __THREW__ = 0;
         $91 = $90&1;
         if ($91) {
          label = 33;
          break L23;
         } else {
          break;
         }
        }
       }
       $82 = ___cxa_find_matching_catch_2()|0;
       $83 = tempRet0;
       __THREW__ = 0;
       invoke_vi(3263,($2|0));
       $84 = __THREW__; __THREW__ = 0;
       $85 = $84&1;
       if ($85) {
        $86 = ___cxa_find_matching_catch_3(0|0)|0;
        $87 = tempRet0;
        ___clang_call_terminate($86);
        // unreachable;
       } else {
        $eh$lpad$body$index3Z2D = $83;$eh$lpad$body$indexZ2D = $82;
        break L23;
       }
      }
     } while(0);
     $105 = ((($0)) + 36|0);
     $106 = HEAP32[$105>>2]|0;
     $107 = ((($106)) + 4|0);
     $108 = ((($0)) + 12|0);
     $109 = HEAP32[$108>>2]|0;
     $110 = HEAP32[$12>>2]|0;
     $111 = ($109|0)==($110|0);
     if ($111) {
      $118 = 0;
     } else {
      $112 = ((($0)) + 40|0);
      $113 = HEAP32[$112>>2]|0;
      $114 = ((($113)) + 26|0);
      $115 = HEAP8[$114>>0]|0;
      $116 = ($115<<24>>24)==(0);
      $118 = $116;
     }
     $117 = $118&1;
     $119 = ((($106)) + 24|0);
     $120 = HEAP8[$119>>0]|0;
     $121 = $120&255;
     $122 = ($117|0)==($121|0);
     if ($122) {
      $152 = HEAP32[$4>>2]|0;
      $153 = ((($152)) + 12|0);
      $154 = HEAP32[$153>>2]|0;
      (FUNCTION_TABLE_ii[$154 & 8191]($4)|0);
      STACKTOP = sp;return;
     }
     $123 = HEAP32[$107>>2]|0;
     $124 = ((($123)) + 8|0);
     $125 = HEAP32[$124>>2]|0;
     __THREW__ = 0;
     (invoke_ii($125|0,($107|0))|0);
     $126 = __THREW__; __THREW__ = 0;
     $127 = $126&1;
     if ($127) {
      label = 33;
     } else {
      if (!($118)) {
       HEAP8[$119>>0] = 0;
       $147 = HEAP32[$107>>2]|0;
       $148 = ((($147)) + 12|0);
       $149 = HEAP32[$148>>2]|0;
       __THREW__ = 0;
       (invoke_ii($149|0,($107|0))|0);
       $150 = __THREW__; __THREW__ = 0;
       $151 = $150&1;
       if ($151) {
        label = 33;
        break;
       }
       $152 = HEAP32[$4>>2]|0;
       $153 = ((($152)) + 12|0);
       $154 = HEAP32[$153>>2]|0;
       (FUNCTION_TABLE_ii[$154 & 8191]($4)|0);
       STACKTOP = sp;return;
      }
      $128 = HEAP8[$119>>0]|0;
      $129 = ($128<<24>>24)==(0);
      if ($129) {
       HEAP8[$119>>0] = 1;
       $130 = ((($106)) + 16|0);
       __THREW__ = 0;
       (invoke_ii(2504,($130|0))|0);
       $131 = __THREW__; __THREW__ = 0;
       $132 = $131&1;
       if ($132) {
        $133 = ___cxa_find_matching_catch_2()|0;
        $134 = tempRet0;
        $135 = HEAP32[$107>>2]|0;
        $136 = ((($135)) + 12|0);
        $137 = HEAP32[$136>>2]|0;
        __THREW__ = 0;
        (invoke_ii($137|0,($107|0))|0);
        $138 = __THREW__; __THREW__ = 0;
        $139 = $138&1;
        if (!($139)) {
         $eh$lpad$body$index3Z2D = $134;$eh$lpad$body$indexZ2D = $133;
         break;
        }
        $140 = ___cxa_find_matching_catch_3(0|0)|0;
        $141 = tempRet0;
        ___clang_call_terminate($140);
        // unreachable;
       }
      }
      $142 = HEAP32[$107>>2]|0;
      $143 = ((($142)) + 12|0);
      $144 = HEAP32[$143>>2]|0;
      __THREW__ = 0;
      (invoke_ii($144|0,($107|0))|0);
      $145 = __THREW__; __THREW__ = 0;
      $146 = $145&1;
      if ($146) {
       label = 33;
      } else {
       $152 = HEAP32[$4>>2]|0;
       $153 = ((($152)) + 12|0);
       $154 = HEAP32[$153>>2]|0;
       (FUNCTION_TABLE_ii[$154 & 8191]($4)|0);
       STACKTOP = sp;return;
      }
     }
    }
   } while(0);
   if ((label|0) == 33) {
    $103 = ___cxa_find_matching_catch_2()|0;
    $104 = tempRet0;
    $eh$lpad$body$index3Z2D = $104;$eh$lpad$body$indexZ2D = $103;
   }
   $$1 = $eh$lpad$body$index3Z2D;$$16 = $eh$lpad$body$indexZ2D;
  }
 } while(0);
 if ((label|0) == 32) {
  $$1 = $$0;$$16 = $$05;
 }
 $155 = HEAP32[$4>>2]|0;
 $156 = ((($155)) + 12|0);
 $157 = HEAP32[$156>>2]|0;
 __THREW__ = 0;
 (invoke_ii($157|0,($4|0))|0);
 $158 = __THREW__; __THREW__ = 0;
 $159 = $158&1;
 if ($159) {
  $160 = ___cxa_find_matching_catch_3(0|0)|0;
  $161 = tempRet0;
  ___clang_call_terminate($160);
  // unreachable;
 } else {
  ___resumeException($$16|0);
  // unreachable;
 }
}
function __ZN5osgDB10ImagePager12ImageRequestD2Ev($0) {
 $0 = $0|0;
 var $$0 = 0, $$02 = 0, $$1 = 0, $$13 = 0, $$2 = 0, $$24 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (74952);
 $1 = ((($0)) + 60|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  label = 4;
 } else {
  $4 = ((($2)) + 8|0);
  $5 = HEAP32[$4>>2]|0;HEAP32[$4>>2] = (($5-1)|0);
  $6 = ($5|0)==(1);
  if ($6) {
   __THREW__ = 0;
   invoke_viii(3262,($2|0),1,1);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $38 = ___cxa_find_matching_catch_2()|0;
    $39 = tempRet0;
    $40 = ((($0)) + 52|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = ($41|0)==(0|0);
    if (!($42)) {
     $43 = ((($41)) + 8|0);
     $44 = HEAP32[$43>>2]|0;HEAP32[$43>>2] = (($44-1)|0);
     $45 = ($44|0)==(1);
     if ($45) {
      __THREW__ = 0;
      invoke_viii(3262,($41|0),1,1);
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       $77 = ___cxa_find_matching_catch_3(0|0)|0;
       $78 = tempRet0;
       ___clang_call_terminate($77);
       // unreachable;
      }
     }
    }
    HEAP32[$40>>2] = 0;
    $$0 = $39;$$02 = $38;
    label = 22;
   } else {
    label = 4;
   }
  } else {
   label = 4;
  }
 }
 do {
  if ((label|0) == 4) {
   HEAP32[$1>>2] = 0;
   $9 = ((($0)) + 52|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($10|0)==(0|0);
   if (!($11)) {
    $12 = ((($10)) + 8|0);
    $13 = HEAP32[$12>>2]|0;HEAP32[$12>>2] = (($13-1)|0);
    $14 = ($13|0)==(1);
    if ($14) {
     __THREW__ = 0;
     invoke_viii(3262,($10|0),1,1);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      $48 = ___cxa_find_matching_catch_2()|0;
      $49 = tempRet0;
      $$0 = $49;$$02 = $48;
      label = 22;
      break;
     }
    }
   }
   HEAP32[$9>>2] = 0;
   $17 = ((($0)) + 40|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = ($18|0)==(0|0);
   if (!($19)) {
    $20 = ((($18)) + 8|0);
    $21 = HEAP32[$20>>2]|0;HEAP32[$20>>2] = (($21-1)|0);
    $22 = ($21|0)==(1);
    if ($22) {
     __THREW__ = 0;
     invoke_viii(3262,($18|0),1,1);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      $50 = ___cxa_find_matching_catch_2()|0;
      $51 = tempRet0;
      $$1 = $51;$$13 = $50;
      label = 27;
      break;
     }
    }
   }
   HEAP32[$17>>2] = 0;
   $25 = ((($0)) + 36|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = ($26|0)==(0|0);
   if (!($27)) {
    $28 = ((($26)) + 8|0);
    $29 = HEAP32[$28>>2]|0;HEAP32[$28>>2] = (($29-1)|0);
    $30 = ($29|0)==(1);
    if ($30) {
     __THREW__ = 0;
     invoke_viii(3262,($26|0),1,1);
     $31 = __THREW__; __THREW__ = 0;
     $32 = $31&1;
     if ($32) {
      $60 = ___cxa_find_matching_catch_2()|0;
      $61 = tempRet0;
      $$2 = $61;$$24 = $60;
      break;
     }
    }
   }
   HEAP32[$25>>2] = 0;
   $33 = ((($0)) + 24|0);
   $34 = ((($33)) + 11|0);
   $35 = HEAP8[$34>>0]|0;
   $36 = ($35<<24>>24)<(0);
   if (!($36)) {
    __ZN3osg10ReferencedD2Ev($0);
    return;
   }
   $37 = HEAP32[$33>>2]|0;
   __ZdlPv($37);
   __ZN3osg10ReferencedD2Ev($0);
   return;
  }
 } while(0);
 if ((label|0) == 22) {
  $52 = ((($0)) + 40|0);
  $53 = HEAP32[$52>>2]|0;
  $54 = ($53|0)==(0|0);
  if (!($54)) {
   $55 = ((($53)) + 8|0);
   $56 = HEAP32[$55>>2]|0;HEAP32[$55>>2] = (($56-1)|0);
   $57 = ($56|0)==(1);
   if ($57) {
    __THREW__ = 0;
    invoke_viii(3262,($53|0),1,1);
    $58 = __THREW__; __THREW__ = 0;
    $59 = $58&1;
    if ($59) {
     $77 = ___cxa_find_matching_catch_3(0|0)|0;
     $78 = tempRet0;
     ___clang_call_terminate($77);
     // unreachable;
    }
   }
  }
  HEAP32[$52>>2] = 0;
  $$1 = $$0;$$13 = $$02;
  label = 27;
 }
 if ((label|0) == 27) {
  $62 = ((($0)) + 36|0);
  $63 = HEAP32[$62>>2]|0;
  $64 = ($63|0)==(0|0);
  if (!($64)) {
   $65 = ((($63)) + 8|0);
   $66 = HEAP32[$65>>2]|0;HEAP32[$65>>2] = (($66-1)|0);
   $67 = ($66|0)==(1);
   if ($67) {
    __THREW__ = 0;
    invoke_viii(3262,($63|0),1,1);
    $68 = __THREW__; __THREW__ = 0;
    $69 = $68&1;
    if ($69) {
     $77 = ___cxa_find_matching_catch_3(0|0)|0;
     $78 = tempRet0;
     ___clang_call_terminate($77);
     // unreachable;
    }
   }
  }
  HEAP32[$62>>2] = 0;
  $$2 = $$1;$$24 = $$13;
 }
 $70 = ((($0)) + 24|0);
 $71 = ((($70)) + 11|0);
 $72 = HEAP8[$71>>0]|0;
 $73 = ($72<<24>>24)<(0);
 if ($73) {
  $74 = HEAP32[$70>>2]|0;
  __ZdlPv($74);
 }
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $75 = __THREW__; __THREW__ = 0;
 $76 = $75&1;
 if ($76) {
  $77 = ___cxa_find_matching_catch_3(0|0)|0;
  $78 = tempRet0;
  ___clang_call_terminate($77);
  // unreachable;
 } else {
  ___resumeException($$24|0);
  // unreachable;
 }
}
function __ZN5osgDB10ImagePager12ImageRequestD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(2666,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZN5osgDB10ImagePager6cancelEv($0) {
 $0 = $0|0;
 var $$sroa$03$013 = 0, $$sroa$09$014 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 48|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 52|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2|0)==($4|0);
 if (!($5)) {
  $$sroa$09$014 = $2;
  while(1) {
   $35 = HEAP32[$$sroa$09$014>>2]|0;
   $36 = ((($35)) + 20|0);
   HEAP8[$36>>0] = 1;
   $37 = ((($$sroa$09$014)) + 4|0);
   $38 = ($37|0)==($4|0);
   if ($38) {
    break;
   } else {
    $$sroa$09$014 = $37;
   }
  }
 }
 $6 = ((($0)) + 44|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($7)) + 36|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($9)) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11)) + 8|0);
 $13 = HEAP32[$12>>2]|0;
 (FUNCTION_TABLE_ii[$13 & 8191]($10)|0);
 $14 = ((($9)) + 24|0);
 $15 = HEAP8[$14>>0]|0;
 $16 = ($15<<24>>24)==(0);
 if ($16) {
  HEAP8[$14>>0] = 1;
  $17 = ((($9)) + 16|0);
  __THREW__ = 0;
  (invoke_ii(2504,($17|0))|0);
  $18 = __THREW__; __THREW__ = 0;
  $19 = $18&1;
  if ($19) {
   $20 = ___cxa_find_matching_catch_2()|0;
   $21 = tempRet0;
   $22 = HEAP32[$10>>2]|0;
   $23 = ((($22)) + 12|0);
   $24 = HEAP32[$23>>2]|0;
   __THREW__ = 0;
   (invoke_ii($24|0,($10|0))|0);
   $25 = __THREW__; __THREW__ = 0;
   $26 = $25&1;
   if ($26) {
    $27 = ___cxa_find_matching_catch_3(0|0)|0;
    $28 = tempRet0;
    ___clang_call_terminate($27);
    // unreachable;
   } else {
    ___resumeException($20|0);
    // unreachable;
   }
  }
 }
 $29 = HEAP32[$10>>2]|0;
 $30 = ((($29)) + 12|0);
 $31 = HEAP32[$30>>2]|0;
 (FUNCTION_TABLE_ii[$31 & 8191]($10)|0);
 $32 = HEAP32[$1>>2]|0;
 $33 = HEAP32[$3>>2]|0;
 $34 = ($32|0)==($33|0);
 if ($34) {
  $39 = ((($0)) + 25|0);
  HEAP8[$39>>0] = 1;
  $40 = ((($0)) + 24|0);
  HEAP8[$40>>0] = 0;
  return 0;
 } else {
  $$sroa$03$013 = $32;
 }
 while(1) {
  $41 = HEAP32[$$sroa$03$013>>2]|0;
  $42 = HEAP32[$41>>2]|0;
  $43 = ((($42)) + 12|0);
  $44 = HEAP32[$43>>2]|0;
  (FUNCTION_TABLE_ii[$44 & 8191]($41)|0);
  $45 = ((($$sroa$03$013)) + 4|0);
  $46 = HEAP32[$3>>2]|0;
  $47 = ($45|0)==($46|0);
  if ($47) {
   break;
  } else {
   $$sroa$03$013 = $45;
  }
 }
 $39 = ((($0)) + 25|0);
 HEAP8[$39>>0] = 1;
 $40 = ((($0)) + 24|0);
 HEAP8[$40>>0] = 0;
 return 0;
}
function __ZN5osgDB10ImagePager9ReadQueueC2EPS0_RKNSt3__212basic_stringIcNS3_11char_traitsIcEENS3_9allocatorIcEEEE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$04 = 0, $$1 = 0, $$15 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5osgDB10ImagePager12RequestQueueC2Ev($0);
 HEAP32[$0>>2] = (74972);
 $3 = ((($0)) + 36|0);
 HEAP32[$3>>2] = 0;
 $4 = ((($0)) + 40|0);
 HEAP32[$4>>2] = $1;
 $5 = ((($0)) + 44|0);
 __THREW__ = 0;
 invoke_vii(3457,($5|0),($2|0));
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if ($7) {
  $31 = ___cxa_find_matching_catch_2()|0;
  $32 = tempRet0;
  $$1 = $32;$$15 = $31;
 } else {
  __THREW__ = 0;
  $8 = (invoke_ii(3276,40)|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  do {
   if ($10) {
    label = 10;
   } else {
    __THREW__ = 0;
    invoke_vi(3803,($8|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     $35 = ___cxa_find_matching_catch_2()|0;
     $36 = tempRet0;
     __ZdlPv($8);
     $$0 = $36;$$04 = $35;
     break;
    }
    $13 = HEAP32[$3>>2]|0;
    $14 = ($13|0)==($8|0);
    if ($14) {
     return;
    }
    HEAP32[$3>>2] = $8;
    $15 = HEAP32[$8>>2]|0;
    $16 = ((($15)) + -12|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = (($8) + ($17)|0);
    $19 = ((($18)) + 8|0);
    $20 = HEAP32[$19>>2]|0;HEAP32[$19>>2] = (($20+1)|0);
    $21 = ($13|0)==(0|0);
    if ($21) {
     return;
    }
    $22 = HEAP32[$13>>2]|0;
    $23 = ((($22)) + -12|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = (($13) + ($24)|0);
    $26 = ((($25)) + 8|0);
    $27 = HEAP32[$26>>2]|0;HEAP32[$26>>2] = (($27-1)|0);
    $28 = ($27|0)==(1);
    if (!($28)) {
     return;
    }
    __THREW__ = 0;
    invoke_viii(3262,($25|0),1,1);
    $29 = __THREW__; __THREW__ = 0;
    $30 = $29&1;
    if ($30) {
     label = 10;
    } else {
     return;
    }
   }
  } while(0);
  if ((label|0) == 10) {
   $33 = ___cxa_find_matching_catch_2()|0;
   $34 = tempRet0;
   $$0 = $34;$$04 = $33;
  }
  $37 = ((($5)) + 11|0);
  $38 = HEAP8[$37>>0]|0;
  $39 = ($38<<24>>24)<(0);
  if ($39) {
   $40 = HEAP32[$5>>2]|0;
   __ZdlPv($40);
   $$1 = $$0;$$15 = $$04;
  } else {
   $$1 = $$0;$$15 = $$04;
  }
 }
 $41 = HEAP32[$3>>2]|0;
 $42 = ($41|0)==(0|0);
 if (!($42)) {
  $43 = HEAP32[$41>>2]|0;
  $44 = ((($43)) + -12|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = (($41) + ($45)|0);
  $47 = ((($46)) + 8|0);
  $48 = HEAP32[$47>>2]|0;HEAP32[$47>>2] = (($48-1)|0);
  $49 = ($48|0)==(1);
  if ($49) {
   __THREW__ = 0;
   invoke_viii(3262,($46|0),1,1);
   $50 = __THREW__; __THREW__ = 0;
   $51 = $50&1;
   if ($51) {
    $54 = ___cxa_find_matching_catch_3(0|0)|0;
    $55 = tempRet0;
    ___clang_call_terminate($54);
    // unreachable;
   }
  }
 }
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vi(2670,($0|0));
 $52 = __THREW__; __THREW__ = 0;
 $53 = $52&1;
 if ($53) {
  $54 = ___cxa_find_matching_catch_3(0|0)|0;
  $55 = tempRet0;
  ___clang_call_terminate($54);
  // unreachable;
 } else {
  ___resumeException($$15|0);
  // unreachable;
 }
}
function __ZN5osgDB10ImagePager12RequestQueueC2Ev($0) {
 $0 = $0|0;
 var $$pre$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg10ReferencedC2Ev($0);
 HEAP32[$0>>2] = (74992);
 $1 = ((($0)) + 12|0);
 HEAP32[$1>>2] = 0;
 $2 = ((($0)) + 16|0);
 HEAP32[$2>>2] = 0;
 $3 = ((($0)) + 20|0);
 HEAP32[$3>>2] = 0;
 $4 = ((($0)) + 24|0);
 __THREW__ = 0;
 invoke_vii(3507,($4|0),0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if (!($6)) {
  return;
 }
 $7 = ___cxa_find_matching_catch_2()|0;
 $8 = tempRet0;
 $9 = HEAP32[$1>>2]|0;
 $10 = ($9|0)==(0|0);
 if (!($10)) {
  $11 = HEAP32[$2>>2]|0;
  $12 = ($11|0)==($9|0);
  do {
   if ($12) {
    $26 = $9;
   } else {
    $14 = $11;
    while(1) {
     $13 = ((($14)) + -4|0);
     HEAP32[$2>>2] = $13;
     $15 = HEAP32[$13>>2]|0;
     $16 = ($15|0)==(0|0);
     if (!($16)) {
      $17 = ((($15)) + 8|0);
      $18 = HEAP32[$17>>2]|0;HEAP32[$17>>2] = (($18-1)|0);
      $19 = ($18|0)==(1);
      if ($19) {
       __THREW__ = 0;
       invoke_viii(3262,($15|0),1,1);
       $20 = __THREW__; __THREW__ = 0;
       $21 = $20&1;
       if ($21) {
        label = 9;
        break;
       }
      }
     }
     HEAP32[$13>>2] = 0;
     $22 = HEAP32[$2>>2]|0;
     $23 = ($22|0)==($9|0);
     if ($23) {
      label = 10;
      break;
     } else {
      $14 = $22;
     }
    }
    if ((label|0) == 9) {
     $24 = ___cxa_find_matching_catch_2()|0;
     $25 = tempRet0;
     ___cxa_call_unexpected(($24|0));
     // unreachable;
    }
    else if ((label|0) == 10) {
     $$pre$i = HEAP32[$1>>2]|0;
     $26 = $$pre$i;
     break;
    }
   }
  } while(0);
  __ZdlPv($26);
 }
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $27 = __THREW__; __THREW__ = 0;
 $28 = $27&1;
 if ($28) {
  $29 = ___cxa_find_matching_catch_3(0|0)|0;
  $30 = tempRet0;
  ___clang_call_terminate($29);
  // unreachable;
 } else {
  ___resumeException($7|0);
  // unreachable;
 }
}
function __ZN5osgDB10ImagePager12RequestQueueD2Ev($0) {
 $0 = $0|0;
 var $$pre$i = 0, $$pre$i6 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (74992);
 $1 = ((($0)) + 24|0);
 __THREW__ = 0;
 invoke_vi(707,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  $4 = ((($0)) + 12|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0|0);
  if ($6) {
   __ZN3osg10ReferencedD2Ev($0);
   return;
  }
  $7 = ((($0)) + 16|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)==($5|0);
  do {
   if ($9) {
    $23 = $5;
   } else {
    $11 = $8;
    while(1) {
     $10 = ((($11)) + -4|0);
     HEAP32[$7>>2] = $10;
     $12 = HEAP32[$10>>2]|0;
     $13 = ($12|0)==(0|0);
     if (!($13)) {
      $14 = ((($12)) + 8|0);
      $15 = HEAP32[$14>>2]|0;HEAP32[$14>>2] = (($15-1)|0);
      $16 = ($15|0)==(1);
      if ($16) {
       __THREW__ = 0;
       invoke_viii(3262,($12|0),1,1);
       $17 = __THREW__; __THREW__ = 0;
       $18 = $17&1;
       if ($18) {
        label = 8;
        break;
       }
      }
     }
     HEAP32[$10>>2] = 0;
     $19 = HEAP32[$7>>2]|0;
     $20 = ($19|0)==($5|0);
     if ($20) {
      label = 9;
      break;
     } else {
      $11 = $19;
     }
    }
    if ((label|0) == 8) {
     $21 = ___cxa_find_matching_catch_2()|0;
     $22 = tempRet0;
     ___cxa_call_unexpected(($21|0));
     // unreachable;
    }
    else if ((label|0) == 9) {
     $$pre$i = HEAP32[$4>>2]|0;
     $23 = $$pre$i;
     break;
    }
   }
  } while(0);
  __ZdlPv($23);
  __ZN3osg10ReferencedD2Ev($0);
  return;
 }
 $24 = ___cxa_find_matching_catch_2()|0;
 $25 = tempRet0;
 $26 = ((($0)) + 12|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ($27|0)==(0|0);
 if (!($28)) {
  $29 = ((($0)) + 16|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = ($30|0)==($27|0);
  do {
   if ($31) {
    $45 = $27;
   } else {
    $33 = $30;
    while(1) {
     $32 = ((($33)) + -4|0);
     HEAP32[$29>>2] = $32;
     $34 = HEAP32[$32>>2]|0;
     $35 = ($34|0)==(0|0);
     if (!($35)) {
      $36 = ((($34)) + 8|0);
      $37 = HEAP32[$36>>2]|0;HEAP32[$36>>2] = (($37-1)|0);
      $38 = ($37|0)==(1);
      if ($38) {
       __THREW__ = 0;
       invoke_viii(3262,($34|0),1,1);
       $39 = __THREW__; __THREW__ = 0;
       $40 = $39&1;
       if ($40) {
        label = 18;
        break;
       }
      }
     }
     HEAP32[$32>>2] = 0;
     $41 = HEAP32[$29>>2]|0;
     $42 = ($41|0)==($27|0);
     if ($42) {
      label = 19;
      break;
     } else {
      $33 = $41;
     }
    }
    if ((label|0) == 18) {
     $43 = ___cxa_find_matching_catch_2()|0;
     $44 = tempRet0;
     ___cxa_call_unexpected(($43|0));
     // unreachable;
    }
    else if ((label|0) == 19) {
     $$pre$i6 = HEAP32[$26>>2]|0;
     $45 = $$pre$i6;
     break;
    }
   }
  } while(0);
  __ZdlPv($45);
 }
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $46 = __THREW__; __THREW__ = 0;
 $47 = $46&1;
 if ($47) {
  $48 = ___cxa_find_matching_catch_3(0|0)|0;
  $49 = tempRet0;
  ___clang_call_terminate($48);
  // unreachable;
 } else {
  ___resumeException($24|0);
  // unreachable;
 }
}
function __ZN5osgDB10ImagePager12RequestQueueD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(2670,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZN5osgDB10ImagePager9ReadQueueD2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (74972);
 $1 = ((($0)) + 44|0);
 $2 = ((($1)) + 11|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)<(0);
 if ($4) {
  $5 = HEAP32[$1>>2]|0;
  __ZdlPv($5);
 }
 $6 = ((($0)) + 36|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if ($8) {
  HEAP32[$6>>2] = 0;
  __ZN5osgDB10ImagePager12RequestQueueD2Ev($0);
  return;
 }
 $9 = HEAP32[$7>>2]|0;
 $10 = ((($9)) + -12|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($7) + ($11)|0);
 $13 = ((($12)) + 8|0);
 $14 = HEAP32[$13>>2]|0;HEAP32[$13>>2] = (($14-1)|0);
 $15 = ($14|0)==(1);
 if (!($15)) {
  HEAP32[$6>>2] = 0;
  __ZN5osgDB10ImagePager12RequestQueueD2Ev($0);
  return;
 }
 __THREW__ = 0;
 invoke_viii(3262,($12|0),1,1);
 $16 = __THREW__; __THREW__ = 0;
 $17 = $16&1;
 if (!($17)) {
  HEAP32[$6>>2] = 0;
  __ZN5osgDB10ImagePager12RequestQueueD2Ev($0);
  return;
 }
 $18 = ___cxa_find_matching_catch_2()|0;
 $19 = tempRet0;
 __THREW__ = 0;
 invoke_vi(2670,($0|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if ($21) {
  $22 = ___cxa_find_matching_catch_3(0|0)|0;
  $23 = tempRet0;
  ___clang_call_terminate($22);
  // unreachable;
 } else {
  ___resumeException($18|0);
  // unreachable;
 }
}
function __ZN5osgDB10ImagePager9ReadQueueD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (74972);
 $1 = ((($0)) + 44|0);
 $2 = ((($1)) + 11|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)<(0);
 if ($4) {
  $5 = HEAP32[$1>>2]|0;
  __ZdlPv($5);
 }
 $6 = ((($0)) + 36|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = ((($9)) + -12|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (($7) + ($11)|0);
  $13 = ((($12)) + 8|0);
  $14 = HEAP32[$13>>2]|0;HEAP32[$13>>2] = (($14-1)|0);
  $15 = ($14|0)==(1);
  if ($15) {
   __THREW__ = 0;
   invoke_viii(3262,($12|0),1,1);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if ($17) {
    $20 = ___cxa_find_matching_catch_2()|0;
    $21 = tempRet0;
    __THREW__ = 0;
    invoke_vi(2670,($0|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     $24 = ___cxa_find_matching_catch_3(0|0)|0;
     $25 = tempRet0;
     ___clang_call_terminate($24);
     // unreachable;
    } else {
     $eh$lpad$body$index2Z2D = $21;$eh$lpad$body$indexZ2D = $20;
     __ZdlPv($0);
     ___resumeException($eh$lpad$body$indexZ2D|0);
     // unreachable;
    }
   }
  }
 }
 HEAP32[$6>>2] = 0;
 __THREW__ = 0;
 invoke_vi(2670,($0|0));
 $18 = __THREW__; __THREW__ = 0;
 $19 = $18&1;
 if (!($19)) {
  __ZdlPv($0);
  return;
 }
 $26 = ___cxa_find_matching_catch_2()|0;
 $27 = tempRet0;
 $eh$lpad$body$index2Z2D = $27;$eh$lpad$body$indexZ2D = $26;
 __ZdlPv($0);
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
}
function __ZN5osgDB10ImagePagerC2Ev($0) {
 $0 = $0|0;
 var $$0 = 0, $$0$i = 0, $$0$i$sink = 0, $$0$i53 = 0, $$0$i53$sink = 0, $$0$i72 = 0, $$0$i72$sink = 0, $$0$lpad$bodyZZ2D = 0, $$012 = 0, $$01496 = 0, $$01795 = 0, $$05$i = 0, $$05$i$sink = 0, $$05$i52 = 0, $$05$i52$sink = 0, $$05$i71 = 0, $$05$i71$sink = 0, $$06 = 0, $$06$lpad$bodyZZ2D = 0, $$09 = 0;
 var $$09$lpad$bodyZZ2D = 0, $$1 = 0, $$10 = 0, $$1027 = 0, $$110 = 0, $$115 = 0, $$118 = 0, $$12 = 0, $$1229 = 0, $$13 = 0, $$1330 = 0, $$17 = 0, $$21698 = 0, $$21997 = 0, $$3 = 0, $$320 = 0, $$4 = 0, $$421 = 0, $$5100 = 0, $$52299 = 0;
 var $$6 = 0, $$623 = 0, $$7 = 0, $$724 = 0, $$8102 = 0, $$825101 = 0, $$9 = 0, $$926 = 0, $$pre$i = 0, $$pre$i42 = 0, $$pre$i58 = 0, $$pre$i77 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0;
 var $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0;
 var $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0;
 var $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0;
 var $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0;
 var $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0;
 var $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0;
 var $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0;
 var $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0;
 var $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0;
 var $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(64|0);
 $1 = sp + 48|0;
 $2 = sp + 44|0;
 $3 = sp + 32|0;
 $4 = sp + 28|0;
 $5 = sp + 16|0;
 $6 = sp + 12|0;
 $7 = sp;
 __ZN3osg10ReferencedC2Eb($0,1);
 HEAP32[$0>>2] = (74904);
 $8 = ((($0)) + 12|0);
 __THREW__ = 0;
 invoke_vii(3507,($8|0),0);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if ($10) {
  $226 = ___cxa_find_matching_catch_2()|0;
  $227 = tempRet0;
  $$13 = $227;$$1330 = $226;
 } else {
  $11 = ((($0)) + 25|0);
  HEAP8[$11>>0] = 0;
  $12 = ((($0)) + 28|0);
  HEAP32[$12>>2] = 0;
  $13 = ((($0)) + 32|0);
  __THREW__ = 0;
  invoke_vii(3507,($13|0),0);
  $14 = __THREW__; __THREW__ = 0;
  $15 = $14&1;
  if ($15) {
   $228 = ___cxa_find_matching_catch_2()|0;
   $229 = tempRet0;
   $$12 = $229;$$1229 = $228;
  } else {
   $16 = ((($0)) + 44|0);
   $17 = ((($0)) + 48|0);
   $18 = ((($0)) + 52|0);
   $19 = ((($0)) + 60|0);
   $20 = ((($0)) + 24|0);
   HEAP8[$20>>0] = 0;
   $21 = ((($0)) + 26|0);
   HEAP8[$21>>0] = 0;
   ;HEAP32[$16>>2]=0|0;HEAP32[$16+4>>2]=0|0;HEAP32[$16+8>>2]=0|0;HEAP32[$16+12>>2]=0|0;HEAP32[$16+16>>2]=0|0;
   __THREW__ = 0;
   $22 = (invoke_ii(3276,56)|0);
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   L7: do {
    if ($24) {
     label = 78;
    } else {
     ;HEAP32[$1>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;
     __THREW__ = 0;
     $25 = (invoke_ii(3276,16)|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     do {
      if ($27) {
       $232 = ___cxa_find_matching_catch_2()|0;
       $233 = tempRet0;
       $$01496 = $233;$$01795 = $232;
      } else {
       HEAP32[$1>>2] = $25;
       $28 = ((($1)) + 8|0);
       HEAP32[$28>>2] = -2147483632;
       $29 = ((($1)) + 4|0);
       HEAP32[$29>>2] = 11;
       dest=$25; src=166260; stop=dest+11|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
       $30 = ((($25)) + 11|0);
       HEAP8[$30>>0] = 0;
       __THREW__ = 0;
       invoke_viii(4160,($22|0),($0|0),($1|0));
       $31 = __THREW__; __THREW__ = 0;
       $32 = $31&1;
       do {
        if ($32) {
         $$012 = 1;
        } else {
         $33 = HEAP32[$16>>2]|0;
         $34 = ($33|0)==($22|0);
         if (!($34)) {
          HEAP32[$16>>2] = $22;
          $35 = ((($22)) + 8|0);
          $36 = HEAP32[$35>>2]|0;HEAP32[$35>>2] = (($36+1)|0);
          $37 = ($33|0)==(0|0);
          if (!($37)) {
           $38 = ((($33)) + 8|0);
           $39 = HEAP32[$38>>2]|0;HEAP32[$38>>2] = (($39-1)|0);
           $40 = ($39|0)==(1);
           if ($40) {
            __THREW__ = 0;
            invoke_viii(3262,($33|0),1,1);
            $41 = __THREW__; __THREW__ = 0;
            $42 = $41&1;
            if ($42) {
             $$012 = 0;
             break;
            }
           }
          }
         }
         $43 = ((($1)) + 11|0);
         $44 = HEAP8[$43>>0]|0;
         $45 = ($44<<24>>24)<(0);
         if ($45) {
          $46 = HEAP32[$1>>2]|0;
          __ZdlPv($46);
         }
         __THREW__ = 0;
         $47 = (invoke_ii(3276,36)|0);
         $48 = __THREW__; __THREW__ = 0;
         $49 = $48&1;
         if ($49) {
          label = 78;
          break L7;
         }
         __THREW__ = 0;
         invoke_vi(4161,($47|0));
         $50 = __THREW__; __THREW__ = 0;
         $51 = $50&1;
         if ($51) {
          $240 = ___cxa_find_matching_catch_2()|0;
          $241 = tempRet0;
          __ZdlPv($47);
          $$10 = $241;$$1027 = $240;
          break L7;
         }
         $52 = HEAP32[$19>>2]|0;
         $53 = ($52|0)==($47|0);
         if (!($53)) {
          HEAP32[$19>>2] = $47;
          $54 = ((($47)) + 8|0);
          $55 = HEAP32[$54>>2]|0;HEAP32[$54>>2] = (($55+1)|0);
          $56 = ($52|0)==(0|0);
          if (!($56)) {
           $57 = ((($52)) + 8|0);
           $58 = HEAP32[$57>>2]|0;HEAP32[$57>>2] = (($58-1)|0);
           $59 = ($58|0)==(1);
           if ($59) {
            __THREW__ = 0;
            invoke_viii(3262,($52|0),1,1);
            $60 = __THREW__; __THREW__ = 0;
            $61 = $60&1;
            if ($61) {
             label = 78;
             break L7;
            }
           }
          }
         }
         __THREW__ = 0;
         $62 = (invoke_ii(3276,44)|0);
         $63 = __THREW__; __THREW__ = 0;
         $64 = $63&1;
         L31: do {
          if ($64) {
           $242 = ___cxa_find_matching_catch_2()|0;
           $243 = tempRet0;
           $$3 = $243;$$320 = $242;
          } else {
           ;HEAP32[$3>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;
           __THREW__ = 0;
           $65 = (invoke_ii(3276,16)|0);
           $66 = __THREW__; __THREW__ = 0;
           $67 = $66&1;
           do {
            if ($67) {
             $244 = ___cxa_find_matching_catch_2()|0;
             $245 = tempRet0;
             $$21698 = $245;$$21997 = $244;
            } else {
             HEAP32[$3>>2] = $65;
             $68 = ((($3)) + 8|0);
             HEAP32[$68>>2] = -2147483632;
             $69 = ((($3)) + 4|0);
             HEAP32[$69>>2] = 14;
             dest=$65; src=166272; stop=dest+14|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
             $70 = ((($65)) + 14|0);
             HEAP8[$70>>0] = 0;
             __THREW__ = 0;
             invoke_vi(3282,($62|0));
             $71 = __THREW__; __THREW__ = 0;
             $72 = $71&1;
             L37: do {
              if ($72) {
               $$09 = 1;
               label = 87;
              } else {
               $73 = ((($62)) + 12|0);
               __THREW__ = 0;
               invoke_vi(3843,($73|0));
               $74 = __THREW__; __THREW__ = 0;
               $75 = $74&1;
               do {
                if ($75) {
                 $82 = ___cxa_find_matching_catch_2()|0;
                 $83 = tempRet0;
                 $$0$i = $83;$$05$i = $82;
                } else {
                 HEAP32[$62>>2] = (74848);
                 HEAP32[$73>>2] = (74876);
                 $76 = ((($62)) + 20|0);
                 HEAP8[$76>>0] = 0;
                 $77 = ((($62)) + 24|0);
                 HEAP32[$77>>2] = 0;
                 $78 = ((($62)) + 28|0);
                 HEAP32[$78>>2] = $0;
                 $79 = ((($62)) + 32|0);
                 __THREW__ = 0;
                 invoke_vii(3457,($79|0),($3|0));
                 $80 = __THREW__; __THREW__ = 0;
                 $81 = $80&1;
                 if ($81) {
                  $84 = ___cxa_find_matching_catch_2()|0;
                  $85 = tempRet0;
                  __THREW__ = 0;
                  invoke_vi(2489,($73|0));
                  $86 = __THREW__; __THREW__ = 0;
                  $87 = $86&1;
                  if (!($87)) {
                   $$0$i = $85;$$05$i = $84;
                   break;
                  }
                  $90 = ___cxa_find_matching_catch_3(0|0)|0;
                  $91 = tempRet0;
                  ___clang_call_terminate($90);
                  // unreachable;
                 }
                 HEAP32[$2>>2] = $62;
                 $92 = ((($62)) + 8|0);
                 $93 = HEAP32[$92>>2]|0;HEAP32[$92>>2] = (($93+1)|0);
                 $94 = HEAP32[$18>>2]|0;
                 $95 = ((($0)) + 56|0);
                 $96 = HEAP32[$95>>2]|0;
                 $97 = ($94|0)==($96|0);
                 do {
                  if ($97) {
                   __THREW__ = 0;
                   invoke_vii(4162,($17|0),($2|0));
                   $104 = __THREW__; __THREW__ = 0;
                   $105 = $104&1;
                   if (!($105)) {
                    break;
                   }
                   $248 = ___cxa_find_matching_catch_2()|0;
                   $249 = tempRet0;
                   $250 = HEAP32[$2>>2]|0;
                   $251 = ($250|0)==(0|0);
                   do {
                    if (!($251)) {
                     $252 = ((($250)) + 8|0);
                     $253 = HEAP32[$252>>2]|0;HEAP32[$252>>2] = (($253-1)|0);
                     $254 = ($253|0)==(1);
                     if (!($254)) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_viii(3262,($250|0),1,1);
                     $255 = __THREW__; __THREW__ = 0;
                     $256 = $255&1;
                     if (!($256)) {
                      break;
                     }
                     $337 = ___cxa_find_matching_catch_3(0|0)|0;
                     $338 = tempRet0;
                     ___clang_call_terminate($337);
                     // unreachable;
                    }
                   } while(0);
                   HEAP32[$2>>2] = 0;
                   $$110 = 0;$$115 = $249;$$118 = $248;
                   break L37;
                  } else {
                   $98 = HEAP32[$2>>2]|0;
                   HEAP32[$94>>2] = $98;
                   $99 = ($98|0)==(0|0);
                   if ($99) {
                    $103 = $94;
                   } else {
                    $100 = ((($98)) + 8|0);
                    $101 = HEAP32[$100>>2]|0;HEAP32[$100>>2] = (($101+1)|0);
                    $$pre$i42 = HEAP32[$18>>2]|0;
                    $103 = $$pre$i42;
                   }
                   $102 = ((($103)) + 4|0);
                   HEAP32[$18>>2] = $102;
                  }
                 } while(0);
                 $106 = HEAP32[$2>>2]|0;
                 $107 = ($106|0)==(0|0);
                 do {
                  if (!($107)) {
                   $108 = ((($106)) + 8|0);
                   $109 = HEAP32[$108>>2]|0;HEAP32[$108>>2] = (($109-1)|0);
                   $110 = ($109|0)==(1);
                   if (!($110)) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(3262,($106|0),1,1);
                   $111 = __THREW__; __THREW__ = 0;
                   $112 = $111&1;
                   if ($112) {
                    $$09 = 0;
                    label = 87;
                    break L37;
                   }
                  }
                 } while(0);
                 HEAP32[$2>>2] = 0;
                 $113 = ((($3)) + 11|0);
                 $114 = HEAP8[$113>>0]|0;
                 $115 = ($114<<24>>24)<(0);
                 if ($115) {
                  $116 = HEAP32[$3>>2]|0;
                  __ZdlPv($116);
                 }
                 __THREW__ = 0;
                 $117 = (invoke_ii(3276,44)|0);
                 $118 = __THREW__; __THREW__ = 0;
                 $119 = $118&1;
                 L66: do {
                  if ($119) {
                   $261 = ___cxa_find_matching_catch_2()|0;
                   $262 = tempRet0;
                   $$6 = $262;$$623 = $261;
                  } else {
                   ;HEAP32[$5>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;
                   __THREW__ = 0;
                   $120 = (invoke_ii(3276,16)|0);
                   $121 = __THREW__; __THREW__ = 0;
                   $122 = $121&1;
                   do {
                    if ($122) {
                     $263 = ___cxa_find_matching_catch_2()|0;
                     $264 = tempRet0;
                     $$5100 = $264;$$52299 = $263;
                    } else {
                     HEAP32[$5>>2] = $120;
                     $123 = ((($5)) + 8|0);
                     HEAP32[$123>>2] = -2147483632;
                     $124 = ((($5)) + 4|0);
                     HEAP32[$124>>2] = 14;
                     dest=$120; src=166287; stop=dest+14|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                     $125 = ((($120)) + 14|0);
                     HEAP8[$125>>0] = 0;
                     __THREW__ = 0;
                     invoke_vi(3282,($117|0));
                     $126 = __THREW__; __THREW__ = 0;
                     $127 = $126&1;
                     L72: do {
                      if ($127) {
                       $$06 = 1;
                       label = 100;
                      } else {
                       $128 = ((($117)) + 12|0);
                       __THREW__ = 0;
                       invoke_vi(3843,($128|0));
                       $129 = __THREW__; __THREW__ = 0;
                       $130 = $129&1;
                       do {
                        if ($130) {
                         $137 = ___cxa_find_matching_catch_2()|0;
                         $138 = tempRet0;
                         $$0$i53 = $138;$$05$i52 = $137;
                        } else {
                         HEAP32[$117>>2] = (74848);
                         HEAP32[$128>>2] = (74876);
                         $131 = ((($117)) + 20|0);
                         HEAP8[$131>>0] = 0;
                         $132 = ((($117)) + 24|0);
                         HEAP32[$132>>2] = 0;
                         $133 = ((($117)) + 28|0);
                         HEAP32[$133>>2] = $0;
                         $134 = ((($117)) + 32|0);
                         __THREW__ = 0;
                         invoke_vii(3457,($134|0),($5|0));
                         $135 = __THREW__; __THREW__ = 0;
                         $136 = $135&1;
                         if ($136) {
                          $139 = ___cxa_find_matching_catch_2()|0;
                          $140 = tempRet0;
                          __THREW__ = 0;
                          invoke_vi(2489,($128|0));
                          $141 = __THREW__; __THREW__ = 0;
                          $142 = $141&1;
                          if (!($142)) {
                           $$0$i53 = $140;$$05$i52 = $139;
                           break;
                          }
                          $145 = ___cxa_find_matching_catch_3(0|0)|0;
                          $146 = tempRet0;
                          ___clang_call_terminate($145);
                          // unreachable;
                         }
                         HEAP32[$4>>2] = $117;
                         $147 = ((($117)) + 8|0);
                         $148 = HEAP32[$147>>2]|0;HEAP32[$147>>2] = (($148+1)|0);
                         $149 = HEAP32[$18>>2]|0;
                         $150 = HEAP32[$95>>2]|0;
                         $151 = ($149|0)==($150|0);
                         do {
                          if ($151) {
                           __THREW__ = 0;
                           invoke_vii(4162,($17|0),($4|0));
                           $158 = __THREW__; __THREW__ = 0;
                           $159 = $158&1;
                           if (!($159)) {
                            break;
                           }
                           $267 = ___cxa_find_matching_catch_2()|0;
                           $268 = tempRet0;
                           $269 = HEAP32[$4>>2]|0;
                           $270 = ($269|0)==(0|0);
                           do {
                            if (!($270)) {
                             $271 = ((($269)) + 8|0);
                             $272 = HEAP32[$271>>2]|0;HEAP32[$271>>2] = (($272-1)|0);
                             $273 = ($272|0)==(1);
                             if (!($273)) {
                              break;
                             }
                             __THREW__ = 0;
                             invoke_viii(3262,($269|0),1,1);
                             $274 = __THREW__; __THREW__ = 0;
                             $275 = $274&1;
                             if (!($275)) {
                              break;
                             }
                             $337 = ___cxa_find_matching_catch_3(0|0)|0;
                             $338 = tempRet0;
                             ___clang_call_terminate($337);
                             // unreachable;
                            }
                           } while(0);
                           HEAP32[$4>>2] = 0;
                           $$17 = 0;$$4 = $268;$$421 = $267;
                           break L72;
                          } else {
                           $152 = HEAP32[$4>>2]|0;
                           HEAP32[$149>>2] = $152;
                           $153 = ($152|0)==(0|0);
                           if ($153) {
                            $157 = $149;
                           } else {
                            $154 = ((($152)) + 8|0);
                            $155 = HEAP32[$154>>2]|0;HEAP32[$154>>2] = (($155+1)|0);
                            $$pre$i58 = HEAP32[$18>>2]|0;
                            $157 = $$pre$i58;
                           }
                           $156 = ((($157)) + 4|0);
                           HEAP32[$18>>2] = $156;
                          }
                         } while(0);
                         $160 = HEAP32[$4>>2]|0;
                         $161 = ($160|0)==(0|0);
                         do {
                          if (!($161)) {
                           $162 = ((($160)) + 8|0);
                           $163 = HEAP32[$162>>2]|0;HEAP32[$162>>2] = (($163-1)|0);
                           $164 = ($163|0)==(1);
                           if (!($164)) {
                            break;
                           }
                           __THREW__ = 0;
                           invoke_viii(3262,($160|0),1,1);
                           $165 = __THREW__; __THREW__ = 0;
                           $166 = $165&1;
                           if ($166) {
                            $$06 = 0;
                            label = 100;
                            break L72;
                           }
                          }
                         } while(0);
                         HEAP32[$4>>2] = 0;
                         $167 = ((($5)) + 11|0);
                         $168 = HEAP8[$167>>0]|0;
                         $169 = ($168<<24>>24)<(0);
                         if ($169) {
                          $170 = HEAP32[$5>>2]|0;
                          __ZdlPv($170);
                         }
                         __THREW__ = 0;
                         $171 = (invoke_ii(3276,44)|0);
                         $172 = __THREW__; __THREW__ = 0;
                         $173 = $172&1;
                         L101: do {
                          if ($173) {
                           $280 = ___cxa_find_matching_catch_2()|0;
                           $281 = tempRet0;
                           $$9 = $281;$$926 = $280;
                          } else {
                           ;HEAP32[$7>>2]=0|0;HEAP32[$7+4>>2]=0|0;HEAP32[$7+8>>2]=0|0;
                           __THREW__ = 0;
                           $174 = (invoke_ii(3276,16)|0);
                           $175 = __THREW__; __THREW__ = 0;
                           $176 = $175&1;
                           do {
                            if ($176) {
                             $282 = ___cxa_find_matching_catch_2()|0;
                             $283 = tempRet0;
                             $$8102 = $283;$$825101 = $282;
                            } else {
                             HEAP32[$7>>2] = $174;
                             $177 = ((($7)) + 8|0);
                             HEAP32[$177>>2] = -2147483632;
                             $178 = ((($7)) + 4|0);
                             HEAP32[$178>>2] = 14;
                             dest=$174; src=166302; stop=dest+14|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                             $179 = ((($174)) + 14|0);
                             HEAP8[$179>>0] = 0;
                             __THREW__ = 0;
                             invoke_vi(3282,($171|0));
                             $180 = __THREW__; __THREW__ = 0;
                             $181 = $180&1;
                             L107: do {
                              if ($181) {
                               $$0 = 1;
                               label = 113;
                              } else {
                               $182 = ((($171)) + 12|0);
                               __THREW__ = 0;
                               invoke_vi(3843,($182|0));
                               $183 = __THREW__; __THREW__ = 0;
                               $184 = $183&1;
                               do {
                                if ($184) {
                                 $191 = ___cxa_find_matching_catch_2()|0;
                                 $192 = tempRet0;
                                 $$0$i72 = $192;$$05$i71 = $191;
                                } else {
                                 HEAP32[$171>>2] = (74848);
                                 HEAP32[$182>>2] = (74876);
                                 $185 = ((($171)) + 20|0);
                                 HEAP8[$185>>0] = 0;
                                 $186 = ((($171)) + 24|0);
                                 HEAP32[$186>>2] = 0;
                                 $187 = ((($171)) + 28|0);
                                 HEAP32[$187>>2] = $0;
                                 $188 = ((($171)) + 32|0);
                                 __THREW__ = 0;
                                 invoke_vii(3457,($188|0),($7|0));
                                 $189 = __THREW__; __THREW__ = 0;
                                 $190 = $189&1;
                                 if ($190) {
                                  $193 = ___cxa_find_matching_catch_2()|0;
                                  $194 = tempRet0;
                                  __THREW__ = 0;
                                  invoke_vi(2489,($182|0));
                                  $195 = __THREW__; __THREW__ = 0;
                                  $196 = $195&1;
                                  if (!($196)) {
                                   $$0$i72 = $194;$$05$i71 = $193;
                                   break;
                                  }
                                  $199 = ___cxa_find_matching_catch_3(0|0)|0;
                                  $200 = tempRet0;
                                  ___clang_call_terminate($199);
                                  // unreachable;
                                 }
                                 HEAP32[$6>>2] = $171;
                                 $201 = ((($171)) + 8|0);
                                 $202 = HEAP32[$201>>2]|0;HEAP32[$201>>2] = (($202+1)|0);
                                 $203 = HEAP32[$18>>2]|0;
                                 $204 = HEAP32[$95>>2]|0;
                                 $205 = ($203|0)==($204|0);
                                 do {
                                  if ($205) {
                                   __THREW__ = 0;
                                   invoke_vii(4162,($17|0),($6|0));
                                   $212 = __THREW__; __THREW__ = 0;
                                   $213 = $212&1;
                                   if (!($213)) {
                                    break;
                                   }
                                   $286 = ___cxa_find_matching_catch_2()|0;
                                   $287 = tempRet0;
                                   $288 = HEAP32[$6>>2]|0;
                                   $289 = ($288|0)==(0|0);
                                   do {
                                    if (!($289)) {
                                     $290 = ((($288)) + 8|0);
                                     $291 = HEAP32[$290>>2]|0;HEAP32[$290>>2] = (($291-1)|0);
                                     $292 = ($291|0)==(1);
                                     if (!($292)) {
                                      break;
                                     }
                                     __THREW__ = 0;
                                     invoke_viii(3262,($288|0),1,1);
                                     $293 = __THREW__; __THREW__ = 0;
                                     $294 = $293&1;
                                     if (!($294)) {
                                      break;
                                     }
                                     $337 = ___cxa_find_matching_catch_3(0|0)|0;
                                     $338 = tempRet0;
                                     ___clang_call_terminate($337);
                                     // unreachable;
                                    }
                                   } while(0);
                                   HEAP32[$6>>2] = 0;
                                   $$1 = 0;$$7 = $287;$$724 = $286;
                                   break L107;
                                  } else {
                                   $206 = HEAP32[$6>>2]|0;
                                   HEAP32[$203>>2] = $206;
                                   $207 = ($206|0)==(0|0);
                                   if ($207) {
                                    $211 = $203;
                                   } else {
                                    $208 = ((($206)) + 8|0);
                                    $209 = HEAP32[$208>>2]|0;HEAP32[$208>>2] = (($209+1)|0);
                                    $$pre$i77 = HEAP32[$18>>2]|0;
                                    $211 = $$pre$i77;
                                   }
                                   $210 = ((($211)) + 4|0);
                                   HEAP32[$18>>2] = $210;
                                  }
                                 } while(0);
                                 $214 = HEAP32[$6>>2]|0;
                                 $215 = ($214|0)==(0|0);
                                 do {
                                  if (!($215)) {
                                   $216 = ((($214)) + 8|0);
                                   $217 = HEAP32[$216>>2]|0;HEAP32[$216>>2] = (($217-1)|0);
                                   $218 = ($217|0)==(1);
                                   if (!($218)) {
                                    break;
                                   }
                                   __THREW__ = 0;
                                   invoke_viii(3262,($214|0),1,1);
                                   $219 = __THREW__; __THREW__ = 0;
                                   $220 = $219&1;
                                   if ($220) {
                                    $$0 = 0;
                                    label = 113;
                                    break L107;
                                   }
                                  }
                                 } while(0);
                                 HEAP32[$6>>2] = 0;
                                 $221 = ((($7)) + 11|0);
                                 $222 = HEAP8[$221>>0]|0;
                                 $223 = ($222<<24>>24)<(0);
                                 if (!($223)) {
                                  $225 = ((($0)) + 64|0);
                                  HEAPF64[$225>>3] = 1.0;
                                  STACKTOP = sp;return;
                                 }
                                 $224 = HEAP32[$7>>2]|0;
                                 __ZdlPv($224);
                                 $225 = ((($0)) + 64|0);
                                 HEAPF64[$225>>3] = 1.0;
                                 STACKTOP = sp;return;
                                }
                               } while(0);
                               __THREW__ = 0;
                               invoke_vi(712,($171|0));
                               $197 = __THREW__; __THREW__ = 0;
                               $198 = $197&1;
                               if (!($198)) {
                                $$0$i72$sink = $$0$i72;$$0$lpad$bodyZZ2D = 1;$$05$i71$sink = $$05$i71;
                                label = 114;
                                break;
                               }
                               $199 = ___cxa_find_matching_catch_3(0|0)|0;
                               $200 = tempRet0;
                               ___clang_call_terminate($199);
                               // unreachable;
                              }
                             } while(0);
                             if ((label|0) == 113) {
                              $284 = ___cxa_find_matching_catch_2()|0;
                              $285 = tempRet0;
                              $$0$i72$sink = $285;$$0$lpad$bodyZZ2D = $$0;$$05$i71$sink = $284;
                              label = 114;
                             }
                             if ((label|0) == 114) {
                              $$1 = $$0$lpad$bodyZZ2D;$$7 = $$0$i72$sink;$$724 = $$05$i71$sink;
                             }
                             $295 = ((($7)) + 11|0);
                             $296 = HEAP8[$295>>0]|0;
                             $297 = ($296<<24>>24)<(0);
                             if ($297) {
                              $298 = HEAP32[$7>>2]|0;
                              __ZdlPv($298);
                              if ($$1) {
                               $$8102 = $$7;$$825101 = $$724;
                               break;
                              } else {
                               $$9 = $$7;$$926 = $$724;
                               break L101;
                              }
                             } else {
                              if ($$1) {
                               $$8102 = $$7;$$825101 = $$724;
                               break;
                              } else {
                               $$9 = $$7;$$926 = $$724;
                               break L101;
                              }
                             }
                            }
                           } while(0);
                           __ZdlPv($171);
                           $$9 = $$8102;$$926 = $$825101;
                          }
                         } while(0);
                         $$10 = $$9;$$1027 = $$926;
                         break L7;
                        }
                       } while(0);
                       __THREW__ = 0;
                       invoke_vi(712,($117|0));
                       $143 = __THREW__; __THREW__ = 0;
                       $144 = $143&1;
                       if (!($144)) {
                        $$0$i53$sink = $$0$i53;$$05$i52$sink = $$05$i52;$$06$lpad$bodyZZ2D = 1;
                        label = 101;
                        break;
                       }
                       $145 = ___cxa_find_matching_catch_3(0|0)|0;
                       $146 = tempRet0;
                       ___clang_call_terminate($145);
                       // unreachable;
                      }
                     } while(0);
                     if ((label|0) == 100) {
                      $265 = ___cxa_find_matching_catch_2()|0;
                      $266 = tempRet0;
                      $$0$i53$sink = $266;$$05$i52$sink = $265;$$06$lpad$bodyZZ2D = $$06;
                      label = 101;
                     }
                     if ((label|0) == 101) {
                      $$17 = $$06$lpad$bodyZZ2D;$$4 = $$0$i53$sink;$$421 = $$05$i52$sink;
                     }
                     $276 = ((($5)) + 11|0);
                     $277 = HEAP8[$276>>0]|0;
                     $278 = ($277<<24>>24)<(0);
                     if ($278) {
                      $279 = HEAP32[$5>>2]|0;
                      __ZdlPv($279);
                      if ($$17) {
                       $$5100 = $$4;$$52299 = $$421;
                       break;
                      } else {
                       $$6 = $$4;$$623 = $$421;
                       break L66;
                      }
                     } else {
                      if ($$17) {
                       $$5100 = $$4;$$52299 = $$421;
                       break;
                      } else {
                       $$6 = $$4;$$623 = $$421;
                       break L66;
                      }
                     }
                    }
                   } while(0);
                   __ZdlPv($117);
                   $$6 = $$5100;$$623 = $$52299;
                  }
                 } while(0);
                 $$10 = $$6;$$1027 = $$623;
                 break L7;
                }
               } while(0);
               __THREW__ = 0;
               invoke_vi(712,($62|0));
               $88 = __THREW__; __THREW__ = 0;
               $89 = $88&1;
               if (!($89)) {
                $$0$i$sink = $$0$i;$$05$i$sink = $$05$i;$$09$lpad$bodyZZ2D = 1;
                label = 88;
                break;
               }
               $90 = ___cxa_find_matching_catch_3(0|0)|0;
               $91 = tempRet0;
               ___clang_call_terminate($90);
               // unreachable;
              }
             } while(0);
             if ((label|0) == 87) {
              $246 = ___cxa_find_matching_catch_2()|0;
              $247 = tempRet0;
              $$0$i$sink = $247;$$05$i$sink = $246;$$09$lpad$bodyZZ2D = $$09;
              label = 88;
             }
             if ((label|0) == 88) {
              $$110 = $$09$lpad$bodyZZ2D;$$115 = $$0$i$sink;$$118 = $$05$i$sink;
             }
             $257 = ((($3)) + 11|0);
             $258 = HEAP8[$257>>0]|0;
             $259 = ($258<<24>>24)<(0);
             if ($259) {
              $260 = HEAP32[$3>>2]|0;
              __ZdlPv($260);
              if ($$110) {
               $$21698 = $$115;$$21997 = $$118;
               break;
              } else {
               $$3 = $$115;$$320 = $$118;
               break L31;
              }
             } else {
              if ($$110) {
               $$21698 = $$115;$$21997 = $$118;
               break;
              } else {
               $$3 = $$115;$$320 = $$118;
               break L31;
              }
             }
            }
           } while(0);
           __ZdlPv($62);
           $$3 = $$21698;$$320 = $$21997;
          }
         } while(0);
         $$10 = $$3;$$1027 = $$320;
         break L7;
        }
       } while(0);
       $234 = ___cxa_find_matching_catch_2()|0;
       $235 = tempRet0;
       $236 = ((($1)) + 11|0);
       $237 = HEAP8[$236>>0]|0;
       $238 = ($237<<24>>24)<(0);
       if ($238) {
        $239 = HEAP32[$1>>2]|0;
        __ZdlPv($239);
        if ($$012) {
         $$01496 = $235;$$01795 = $234;
         break;
        } else {
         $$10 = $235;$$1027 = $234;
         break L7;
        }
       } else {
        if ($$012) {
         $$01496 = $235;$$01795 = $234;
         break;
        } else {
         $$10 = $235;$$1027 = $234;
         break L7;
        }
       }
      }
     } while(0);
     __ZdlPv($22);
     $$10 = $$01496;$$1027 = $$01795;
    }
   } while(0);
   if ((label|0) == 78) {
    $230 = ___cxa_find_matching_catch_2()|0;
    $231 = tempRet0;
    $$10 = $231;$$1027 = $230;
   }
   $299 = HEAP32[$19>>2]|0;
   $300 = ($299|0)==(0|0);
   if (!($300)) {
    $301 = ((($299)) + 8|0);
    $302 = HEAP32[$301>>2]|0;HEAP32[$301>>2] = (($302-1)|0);
    $303 = ($302|0)==(1);
    if ($303) {
     __THREW__ = 0;
     invoke_viii(3262,($299|0),1,1);
     $304 = __THREW__; __THREW__ = 0;
     $305 = $304&1;
     if ($305) {
      $337 = ___cxa_find_matching_catch_3(0|0)|0;
      $338 = tempRet0;
      ___clang_call_terminate($337);
      // unreachable;
     }
    }
   }
   HEAP32[$19>>2] = 0;
   $306 = HEAP32[$17>>2]|0;
   $307 = ($306|0)==(0|0);
   if (!($307)) {
    $308 = HEAP32[$18>>2]|0;
    $309 = ($308|0)==($306|0);
    do {
     if ($309) {
      $323 = $306;
     } else {
      $311 = $308;
      while(1) {
       $310 = ((($311)) + -4|0);
       HEAP32[$18>>2] = $310;
       $312 = HEAP32[$310>>2]|0;
       $313 = ($312|0)==(0|0);
       if (!($313)) {
        $314 = ((($312)) + 8|0);
        $315 = HEAP32[$314>>2]|0;HEAP32[$314>>2] = (($315-1)|0);
        $316 = ($315|0)==(1);
        if ($316) {
         __THREW__ = 0;
         invoke_viii(3262,($312|0),1,1);
         $317 = __THREW__; __THREW__ = 0;
         $318 = $317&1;
         if ($318) {
          label = 133;
          break;
         }
        }
       }
       HEAP32[$310>>2] = 0;
       $319 = HEAP32[$18>>2]|0;
       $320 = ($319|0)==($306|0);
       if ($320) {
        label = 134;
        break;
       } else {
        $311 = $319;
       }
      }
      if ((label|0) == 133) {
       $321 = ___cxa_find_matching_catch_2()|0;
       $322 = tempRet0;
       ___cxa_call_unexpected(($321|0));
       // unreachable;
      }
      else if ((label|0) == 134) {
       $$pre$i = HEAP32[$17>>2]|0;
       $323 = $$pre$i;
       break;
      }
     }
    } while(0);
    __ZdlPv($323);
   }
   $324 = HEAP32[$16>>2]|0;
   $325 = ($324|0)==(0|0);
   if (!($325)) {
    $326 = ((($324)) + 8|0);
    $327 = HEAP32[$326>>2]|0;HEAP32[$326>>2] = (($327-1)|0);
    $328 = ($327|0)==(1);
    if ($328) {
     __THREW__ = 0;
     invoke_viii(3262,($324|0),1,1);
     $329 = __THREW__; __THREW__ = 0;
     $330 = $329&1;
     if ($330) {
      $337 = ___cxa_find_matching_catch_3(0|0)|0;
      $338 = tempRet0;
      ___clang_call_terminate($337);
      // unreachable;
     }
    }
   }
   HEAP32[$16>>2] = 0;
   __THREW__ = 0;
   invoke_vi(707,($13|0));
   $331 = __THREW__; __THREW__ = 0;
   $332 = $331&1;
   if ($332) {
    $337 = ___cxa_find_matching_catch_3(0|0)|0;
    $338 = tempRet0;
    ___clang_call_terminate($337);
    // unreachable;
   } else {
    $$12 = $$10;$$1229 = $$1027;
   }
  }
  __THREW__ = 0;
  invoke_vi(707,($8|0));
  $333 = __THREW__; __THREW__ = 0;
  $334 = $333&1;
  if ($334) {
   $337 = ___cxa_find_matching_catch_3(0|0)|0;
   $338 = tempRet0;
   ___clang_call_terminate($337);
   // unreachable;
  } else {
   $$13 = $$12;$$1330 = $$1229;
  }
 }
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $335 = __THREW__; __THREW__ = 0;
 $336 = $335&1;
 if ($336) {
  $337 = ___cxa_find_matching_catch_3(0|0)|0;
  $338 = tempRet0;
  ___clang_call_terminate($337);
  // unreachable;
 } else {
  ___resumeException($$1330|0);
  // unreachable;
 }
}
function __ZNSt3__26vectorIN3osg7ref_ptrIN5osgDB10ImagePager11ImageThreadEEENS_9allocatorIS6_EEE21__push_back_slow_pathIKS6_EEvRT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$06$i$i = 0, $$pre = 0, $$pre$i = 0, $$pre38 = 0, $$pre39 = 0, $$sroa$7$0 = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(1073741823);
 $9 = $4;
 $10 = $3;
 if ($8) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $11 = ((($0)) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) - ($4))|0;
 $14 = $13 >> 2;
 $15 = ($14>>>0)<(536870911);
 $16 = $13 >> 1;
 $17 = ($16>>>0)<($7>>>0);
 $$sroa$speculated$i = $17 ? $7 : $16;
 $$sroa$speculated$$i = $15 ? $$sroa$speculated$i : 1073741823;
 $18 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($18) {
   $28 = 0;
  } else {
   $19 = ($$sroa$speculated$$i>>>0)>(1073741823);
   if (!($19)) {
    $25 = $$sroa$speculated$$i << 2;
    $26 = (__Znwj($25)|0);
    $28 = $26;
    break;
   }
   $20 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($20|0),(204840|0));
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if ($22) {
    $23 = ___cxa_find_matching_catch_2()|0;
    $24 = tempRet0;
    ___cxa_free_exception(($20|0));
    ___resumeException($23|0);
    // unreachable;
   } else {
    HEAP32[$20>>2] = (99824);
    ___cxa_throw(($20|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $27 = (($28) + ($6<<2)|0);
 $29 = $27;
 $30 = (($28) + ($$sroa$speculated$$i<<2)|0);
 $31 = $30;
 $32 = HEAP32[$1>>2]|0;
 HEAP32[$27>>2] = $32;
 $33 = ($32|0)==(0|0);
 if ($33) {
  $38 = $10;$40 = $9;
 } else {
  $34 = ((($32)) + 8|0);
  $35 = HEAP32[$34>>2]|0;HEAP32[$34>>2] = (($35+1)|0);
  $$pre = HEAP32[$0>>2]|0;
  $$pre38 = HEAP32[$2>>2]|0;
  $38 = $$pre38;$40 = $$pre;
 }
 $36 = ((($27)) + 4|0);
 $37 = $36;
 $39 = ($38|0)==($40|0);
 if ($39) {
  $41 = $38;
  $53 = $29;$54 = $41;$56 = $38;
 } else {
  $$06$i$i = $38;$$sroa$7$0 = $29;$44 = $27;
  while(1) {
   $42 = ((($$06$i$i)) + -4|0);
   $43 = ((($44)) + -4|0);
   $45 = HEAP32[$42>>2]|0;
   HEAP32[$43>>2] = $45;
   $46 = ($45|0)==(0|0);
   if (!($46)) {
    $47 = ((($45)) + 8|0);
    $48 = HEAP32[$47>>2]|0;HEAP32[$47>>2] = (($48+1)|0);
   }
   $49 = $$sroa$7$0;
   $50 = ((($49)) + -4|0);
   $51 = $50;
   $52 = ($42|0)==($40|0);
   if ($52) {
    break;
   } else {
    $$06$i$i = $42;$$sroa$7$0 = $51;$44 = $50;
   }
  }
  $$pre$i = HEAP32[$0>>2]|0;
  $$pre39 = HEAP32[$2>>2]|0;
  $53 = $51;$54 = $$pre$i;$56 = $$pre39;
 }
 HEAP32[$0>>2] = $53;
 HEAP32[$2>>2] = $37;
 HEAP32[$11>>2] = $31;
 $55 = $54;
 $57 = ($56|0)==($55|0);
 L25: do {
  if (!($57)) {
   $59 = $56;
   while(1) {
    $58 = ((($59)) + -4|0);
    $60 = HEAP32[$58>>2]|0;
    $61 = ($60|0)==(0|0);
    if (!($61)) {
     $62 = ((($60)) + 8|0);
     $63 = HEAP32[$62>>2]|0;HEAP32[$62>>2] = (($63-1)|0);
     $64 = ($63|0)==(1);
     if ($64) {
      __THREW__ = 0;
      invoke_viii(3262,($60|0),1,1);
      $65 = __THREW__; __THREW__ = 0;
      $66 = $65&1;
      if ($66) {
       break;
      }
     }
    }
    HEAP32[$58>>2] = 0;
    $67 = ($58|0)==($55|0);
    if ($67) {
     break L25;
    } else {
     $59 = $58;
    }
   }
   $68 = ___cxa_find_matching_catch_2()|0;
   $69 = tempRet0;
   ___cxa_call_unexpected(($68|0));
   // unreachable;
  }
 } while(0);
 $70 = ($54|0)==(0);
 if ($70) {
  return;
 }
 $71 = $54;
 __ZdlPv($71);
 return;
}
function __ZN5osgDB11ObjectCacheD2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (75012);
 $1 = ((($0)) + 24|0);
 __THREW__ = 0;
 invoke_vi(707,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  $4 = ((($0)) + 12|0);
  $5 = ((($0)) + 16|0);
  $6 = HEAP32[$5>>2]|0;
  __ZNSt3__26__treeINS_12__value_typeINS_4pairINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7ref_ptrIKN5osgDB7OptionsEEEEENS2_INSA_INS9_6ObjectEEEdEEEENS_19__map_value_compareISF_SJ_NSB_11ObjectCache9ClassCompELb1EEENS6_ISJ_EEE7destroyEPNS_11__tree_nodeISJ_PvEE($4,$6);
  __ZN3osg10ReferencedD2Ev($0);
  return;
 }
 $7 = ___cxa_find_matching_catch_2()|0;
 $8 = tempRet0;
 $9 = ((($0)) + 12|0);
 $10 = ((($0)) + 16|0);
 $11 = HEAP32[$10>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_4pairINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7ref_ptrIKN5osgDB7OptionsEEEEENS2_INSA_INS9_6ObjectEEEdEEEENS_19__map_value_compareISF_SJ_NSB_11ObjectCache9ClassCompELb1EEENS6_ISJ_EEE7destroyEPNS_11__tree_nodeISJ_PvEE($9,$11);
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $14 = ___cxa_find_matching_catch_3(0|0)|0;
  $15 = tempRet0;
  ___clang_call_terminate($14);
  // unreachable;
 } else {
  ___resumeException($7|0);
  // unreachable;
 }
}
function __ZN5osgDB11ObjectCacheD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0;
 var $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (75012);
 $1 = ((($0)) + 24|0);
 __THREW__ = 0;
 invoke_vi(707,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $9 = ___cxa_find_matching_catch_2()|0;
  $10 = tempRet0;
  $11 = ((($0)) + 12|0);
  $12 = ((($0)) + 16|0);
  $13 = HEAP32[$12>>2]|0;
  __ZNSt3__26__treeINS_12__value_typeINS_4pairINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7ref_ptrIKN5osgDB7OptionsEEEEENS2_INSA_INS9_6ObjectEEEdEEEENS_19__map_value_compareISF_SJ_NSB_11ObjectCache9ClassCompELb1EEENS6_ISJ_EEE7destroyEPNS_11__tree_nodeISJ_PvEE($11,$13);
  __THREW__ = 0;
  invoke_vi(712,($0|0));
  $14 = __THREW__; __THREW__ = 0;
  $15 = $14&1;
  if ($15) {
   $16 = ___cxa_find_matching_catch_3(0|0)|0;
   $17 = tempRet0;
   ___clang_call_terminate($16);
   // unreachable;
  } else {
   $eh$lpad$body$index2Z2D = $10;$eh$lpad$body$indexZ2D = $9;
   __ZdlPv($0);
   ___resumeException($eh$lpad$body$indexZ2D|0);
   // unreachable;
  }
 }
 $4 = ((($0)) + 12|0);
 $5 = ((($0)) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_4pairINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7ref_ptrIKN5osgDB7OptionsEEEEENS2_INSA_INS9_6ObjectEEEdEEEENS_19__map_value_compareISF_SJ_NSB_11ObjectCache9ClassCompELb1EEENS6_ISJ_EEE7destroyEPNS_11__tree_nodeISJ_PvEE($4,$6);
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if (!($8)) {
  __ZdlPv($0);
  return;
 }
 $18 = ___cxa_find_matching_catch_2()|0;
 $19 = tempRet0;
 $eh$lpad$body$index2Z2D = $19;$eh$lpad$body$indexZ2D = $18;
 __ZdlPv($0);
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
}
function __ZNSt3__26__treeINS_12__value_typeINS_4pairINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7ref_ptrIKN5osgDB7OptionsEEEEENS2_INSA_INS9_6ObjectEEEdEEEENS_19__map_value_compareISF_SJ_NSB_11ObjectCache9ClassCompELb1EEENS6_ISJ_EEE7destroyEPNS_11__tree_nodeISJ_PvEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 }
 $3 = HEAP32[$1>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_4pairINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7ref_ptrIKN5osgDB7OptionsEEEEENS2_INSA_INS9_6ObjectEEEdEEEENS_19__map_value_compareISF_SJ_NSB_11ObjectCache9ClassCompELb1EEENS6_ISJ_EEE7destroyEPNS_11__tree_nodeISJ_PvEE($0,$3);
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_4pairINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7ref_ptrIKN5osgDB7OptionsEEEEENS2_INSA_INS9_6ObjectEEEdEEEENS_19__map_value_compareISF_SJ_NSB_11ObjectCache9ClassCompELb1EEENS6_ISJ_EEE7destroyEPNS_11__tree_nodeISJ_PvEE($0,$5);
 $6 = ((($1)) + 16|0);
 __THREW__ = 0;
 invoke_vi(4163,($6|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch_2()|0;
  $10 = tempRet0;
  ___cxa_call_unexpected(($9|0));
  // unreachable;
 }
 __ZdlPv($1);
 return;
}
function __ZNSt3__24pairIKNS0_INS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7ref_ptrIKN5osgDB7OptionsEEEEENS0_INS8_INS7_6ObjectEEEdEEED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = ((($2)) + 8|0);
  $5 = HEAP32[$4>>2]|0;HEAP32[$4>>2] = (($5-1)|0);
  $6 = ($5|0)==(1);
  if ($6) {
   __THREW__ = 0;
   invoke_viii(3262,($2|0),1,1);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $27 = ___cxa_find_matching_catch_2()|0;
    $28 = tempRet0;
    $29 = ((($0)) + 12|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = ($30|0)==(0|0);
    if (!($31)) {
     $32 = ((($30)) + 8|0);
     $33 = HEAP32[$32>>2]|0;HEAP32[$32>>2] = (($33-1)|0);
     $34 = ($33|0)==(1);
     if ($34) {
      __THREW__ = 0;
      invoke_viii(3262,($30|0),1,1);
      $35 = __THREW__; __THREW__ = 0;
      $36 = $35&1;
      if ($36) {
       $41 = ___cxa_find_matching_catch_3(0|0)|0;
       $42 = tempRet0;
       $43 = ((($0)) + 11|0);
       $44 = HEAP8[$43>>0]|0;
       $45 = ($44<<24>>24)<(0);
       if (!($45)) {
        ___clang_call_terminate($41);
        // unreachable;
       }
       $46 = HEAP32[$0>>2]|0;
       __ZdlPv($46);
       ___clang_call_terminate($41);
       // unreachable;
      }
     }
    }
    HEAP32[$29>>2] = 0;
    $37 = ((($0)) + 11|0);
    $38 = HEAP8[$37>>0]|0;
    $39 = ($38<<24>>24)<(0);
    if (!($39)) {
     ___resumeException($27|0);
     // unreachable;
    }
    $40 = HEAP32[$0>>2]|0;
    __ZdlPv($40);
    ___resumeException($27|0);
    // unreachable;
   }
  }
 }
 HEAP32[$1>>2] = 0;
 $9 = ((($0)) + 12|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if (!($11)) {
  $12 = ((($10)) + 8|0);
  $13 = HEAP32[$12>>2]|0;HEAP32[$12>>2] = (($13-1)|0);
  $14 = ($13|0)==(1);
  if ($14) {
   __THREW__ = 0;
   invoke_viii(3262,($10|0),1,1);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if ($16) {
    $21 = ___cxa_find_matching_catch_2()|0;
    $22 = tempRet0;
    $23 = ((($0)) + 11|0);
    $24 = HEAP8[$23>>0]|0;
    $25 = ($24<<24>>24)<(0);
    if (!($25)) {
     ___resumeException($21|0);
     // unreachable;
    }
    $26 = HEAP32[$0>>2]|0;
    __ZdlPv($26);
    ___resumeException($21|0);
    // unreachable;
   }
  }
 }
 HEAP32[$9>>2] = 0;
 $17 = ((($0)) + 11|0);
 $18 = HEAP8[$17>>0]|0;
 $19 = ($18<<24>>24)<(0);
 if (!($19)) {
  return;
 }
 $20 = HEAP32[$0>>2]|0;
 __ZdlPv($20);
 return;
}
function __ZNK5osgDB11ObjectCache9ClassCompclERKNSt3__24pairINS2_12basic_stringIcNS2_11char_traitsIcEENS2_9allocatorIcEEEEN3osg7ref_ptrIKNS_7OptionsEEEEESH_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$sroa$speculated$i$i$i = 0, $$sroa$speculated$i$i$i14 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($2)) + 11|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)<(0);
 $6 = ((($2)) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $4&255;
 $9 = $5 ? $7 : $8;
 $10 = ((($1)) + 11|0);
 $11 = HEAP8[$10>>0]|0;
 $12 = ($11<<24>>24)<(0);
 $13 = ((($1)) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $11&255;
 $16 = $12 ? $14 : $15;
 $17 = ($9>>>0)<($16>>>0);
 $$sroa$speculated$i$i$i = $17 ? $9 : $16;
 $18 = ($$sroa$speculated$i$i$i|0)==(0);
 if ($18) {
  label = 3;
 } else {
  $19 = HEAP32[$1>>2]|0;
  $20 = $12 ? $19 : $1;
  $21 = HEAP32[$2>>2]|0;
  $22 = $5 ? $21 : $2;
  $23 = (_memcmp($20,$22,$$sroa$speculated$i$i$i)|0);
  $24 = ($23|0)==(0);
  if ($24) {
   label = 3;
  } else {
   $26 = ($23|0)<(0);
   if ($26) {
    $$0 = 1;
    return ($$0|0);
   }
  }
 }
 if ((label|0) == 3) {
  $25 = ($16>>>0)<($9>>>0);
  if ($25) {
   $$0 = 1;
   return ($$0|0);
  }
 }
 $27 = ($16>>>0)<($9>>>0);
 $$sroa$speculated$i$i$i14 = $27 ? $16 : $9;
 $28 = ($$sroa$speculated$i$i$i14|0)==(0);
 if ($28) {
  label = 7;
 } else {
  $29 = HEAP32[$2>>2]|0;
  $30 = $5 ? $29 : $2;
  $31 = HEAP32[$1>>2]|0;
  $32 = $12 ? $31 : $1;
  $33 = (_memcmp($30,$32,$$sroa$speculated$i$i$i14)|0);
  $34 = ($33|0)==(0);
  if ($34) {
   label = 7;
  } else {
   $35 = ($33|0)<(0);
   if ($35) {
    $$0 = 0;
    return ($$0|0);
   }
  }
 }
 if ((label|0) == 7) {
  if ($17) {
   $$0 = 0;
   return ($$0|0);
  }
 }
 $36 = ((($1)) + 12|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = ((($2)) + 12|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = ($37|0)==($39|0);
 if ($40) {
  $$0 = 0;
  return ($$0|0);
 }
 $41 = ($37|0)!=(0|0);
 $42 = ($39|0)!=(0|0);
 $or$cond = $41 & $42;
 if ($or$cond) {
  $43 = (__ZNK5osgDB7OptionsltERKS0_($37,$39)|0);
  $$0 = $43;
  return ($$0|0);
 } else {
  $44 = ($37>>>0)<($39>>>0);
  $$0 = $44;
  return ($$0|0);
 }
 return (0)|0;
}
function __ZN5osgDB11ObjectCacheC2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg10ReferencedC2Eb($0,1);
 HEAP32[$0>>2] = (75012);
 $1 = ((($0)) + 12|0);
 $2 = ((($0)) + 16|0);
 HEAP32[$2>>2] = 0;
 $3 = ((($0)) + 20|0);
 HEAP32[$3>>2] = 0;
 $4 = ((($0)) + 16|0);
 HEAP32[$1>>2] = $4;
 $5 = ((($0)) + 24|0);
 __THREW__ = 0;
 invoke_vii(3507,($5|0),0);
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if (!($7)) {
  return;
 }
 $8 = ___cxa_find_matching_catch_2()|0;
 $9 = tempRet0;
 $10 = HEAP32[$4>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_4pairINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7ref_ptrIKN5osgDB7OptionsEEEEENS2_INSA_INS9_6ObjectEEEdEEEENS_19__map_value_compareISF_SJ_NSB_11ObjectCache9ClassCompELb1EEENS6_ISJ_EEE7destroyEPNS_11__tree_nodeISJ_PvEE($1,$10);
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if ($12) {
  $13 = ___cxa_find_matching_catch_3(0|0)|0;
  $14 = tempRet0;
  ___clang_call_terminate($13);
  // unreachable;
 } else {
  ___resumeException($8|0);
  // unreachable;
 }
}
function __ZN5osgDB11ObjectCache14addObjectCacheEPS0_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i$i$i = 0, $$0$i$i$i$i$i = 0, $$1 = 0, $$18 = 0, $$byval_copy = 0, $$pre$i$i$i$i$i = 0, $$sroa$031$0 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0.0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index4Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $$byval_copy = sp + 16|0;
 $2 = sp + 12|0;
 $3 = sp + 8|0;
 $4 = sp + 4|0;
 $5 = sp;
 $6 = ($1|0)==($0|0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = ((($0)) + 24|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($8)) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 (FUNCTION_TABLE_ii[$10 & 8191]($7)|0);
 $11 = ((($1)) + 24|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ((($12)) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 __THREW__ = 0;
 (invoke_ii($14|0,($11|0))|0);
 $15 = __THREW__; __THREW__ = 0;
 $16 = $15&1;
 L4: do {
  if ($16) {
   $58 = ___cxa_find_matching_catch_2()|0;
   $59 = tempRet0;
   $$1 = $59;$$18 = $58;
  } else {
   __THREW__ = 0;
   $17 = (invoke_ii(3265,5)|0);
   $18 = __THREW__; __THREW__ = 0;
   $19 = $18&1;
   L7: do {
    if ($19) {
     label = 19;
    } else {
     do {
      if ($17) {
       __THREW__ = 0;
       $20 = (invoke_ii(3266,5)|0);
       $21 = __THREW__; __THREW__ = 0;
       $22 = $21&1;
       if ($22) {
        label = 19;
        break L7;
       }
       __THREW__ = 0;
       $23 = (invoke_iiii(3267,($20|0),(166339|0),38)|0);
       $24 = __THREW__; __THREW__ = 0;
       $25 = $24&1;
       if ($25) {
        label = 19;
        break L7;
       }
       $26 = ((($1)) + 20|0);
       $27 = HEAP32[$26>>2]|0;
       __THREW__ = 0;
       $28 = (invoke_iii(3417,($23|0),($27|0))|0);
       $29 = __THREW__; __THREW__ = 0;
       $30 = $29&1;
       if ($30) {
        label = 19;
        break L7;
       }
       $31 = HEAP32[$28>>2]|0;
       $32 = ((($31)) + -12|0);
       $33 = HEAP32[$32>>2]|0;
       $34 = (($28) + ($33)|0);
       __THREW__ = 0;
       invoke_vii(3257,($5|0),($34|0));
       $35 = __THREW__; __THREW__ = 0;
       $36 = $35&1;
       if ($36) {
        label = 19;
        break L7;
       }
       __THREW__ = 0;
       $37 = (invoke_iii(3255,($5|0),(215188|0))|0);
       $38 = __THREW__; __THREW__ = 0;
       $39 = $38&1;
       if (!($39)) {
        $40 = HEAP32[$37>>2]|0;
        $41 = ((($40)) + 28|0);
        $42 = HEAP32[$41>>2]|0;
        __THREW__ = 0;
        $43 = (invoke_iii($42|0,($37|0),10)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         __THREW__ = 0;
         invoke_vi(3263,($5|0));
         $46 = __THREW__; __THREW__ = 0;
         $47 = $46&1;
         if ($47) {
          label = 19;
          break L7;
         }
         __THREW__ = 0;
         (invoke_iii(3268,($28|0),($43|0))|0);
         $54 = __THREW__; __THREW__ = 0;
         $55 = $54&1;
         if ($55) {
          label = 19;
          break L7;
         }
         __THREW__ = 0;
         (invoke_ii(3269,($28|0))|0);
         $56 = __THREW__; __THREW__ = 0;
         $57 = $56&1;
         if ($57) {
          label = 19;
          break L7;
         } else {
          break;
         }
        }
       }
       $48 = ___cxa_find_matching_catch_2()|0;
       $49 = tempRet0;
       __THREW__ = 0;
       invoke_vi(3263,($5|0));
       $50 = __THREW__; __THREW__ = 0;
       $51 = $50&1;
       if ($51) {
        $52 = ___cxa_find_matching_catch_3(0|0)|0;
        $53 = tempRet0;
        ___clang_call_terminate($52);
        // unreachable;
       } else {
        $eh$lpad$body$index4Z2D = $49;$eh$lpad$body$indexZ2D = $48;
        break L7;
       }
      }
     } while(0);
     $69 = ((($0)) + 12|0);
     $70 = ((($1)) + 12|0);
     $71 = HEAP32[$70>>2]|0;
     $72 = ((($1)) + 16|0);
     $73 = ($71|0)==($72|0);
     L25: do {
      if (!($73)) {
       $74 = ((($0)) + 16|0);
       $75 = $74;
       $76 = ((($0)) + 16|0);
       $77 = ((($0)) + 20|0);
       $$sroa$031$0 = $71;
       while(1) {
        $78 = ((($$sroa$031$0)) + 16|0);
        HEAP32[$4>>2] = $75;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy>>2]=HEAP32[$4>>2]|0;
        $79 = (invoke_iiiiii(4164,($69|0),($$byval_copy|0),($2|0),($3|0),($78|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 18;
         break;
        }
        $82 = HEAP32[$79>>2]|0;
        $83 = ($82|0)==(0|0);
        if ($83) {
         __THREW__ = 0;
         $84 = (invoke_ii(3276,48)|0);
         $85 = __THREW__; __THREW__ = 0;
         $86 = $85&1;
         if ($86) {
          label = 18;
          break;
         }
         $87 = ((($84)) + 16|0);
         __THREW__ = 0;
         invoke_vii(3457,($87|0),($78|0));
         $88 = __THREW__; __THREW__ = 0;
         $89 = $88&1;
         if ($89) {
          label = 31;
          break;
         }
         $90 = ((($84)) + 28|0);
         $91 = ((($$sroa$031$0)) + 28|0);
         $92 = HEAP32[$91>>2]|0;
         HEAP32[$90>>2] = $92;
         $93 = ($92|0)==(0|0);
         if (!($93)) {
          $94 = ((($92)) + 8|0);
          $95 = HEAP32[$94>>2]|0;HEAP32[$94>>2] = (($95+1)|0);
         }
         $96 = ((($84)) + 32|0);
         $97 = ((($$sroa$031$0)) + 32|0);
         $98 = HEAP32[$97>>2]|0;
         HEAP32[$96>>2] = $98;
         $99 = ($98|0)==(0|0);
         if (!($99)) {
          $100 = ((($98)) + 8|0);
          $101 = HEAP32[$100>>2]|0;HEAP32[$100>>2] = (($101+1)|0);
         }
         $104 = ((($84)) + 40|0);
         $105 = ((($$sroa$031$0)) + 40|0);
         $106 = +HEAPF64[$105>>3];
         HEAPF64[$104>>3] = $106;
         $107 = HEAP32[$2>>2]|0;
         HEAP32[$84>>2] = 0;
         $108 = ((($84)) + 4|0);
         HEAP32[$108>>2] = 0;
         $109 = ((($84)) + 8|0);
         HEAP32[$109>>2] = $107;
         HEAP32[$79>>2] = $84;
         $110 = HEAP32[$69>>2]|0;
         $111 = HEAP32[$110>>2]|0;
         $112 = ($111|0)==(0|0);
         if ($112) {
          $115 = $84;
         } else {
          $113 = $111;
          HEAP32[$69>>2] = $113;
          $$pre$i$i$i$i$i = HEAP32[$79>>2]|0;
          $115 = $$pre$i$i$i$i$i;
         }
         $114 = HEAP32[$76>>2]|0;
         __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($114,$115);
         $116 = HEAP32[$77>>2]|0;
         $117 = (($116) + 1)|0;
         HEAP32[$77>>2] = $117;
        }
        $118 = ((($$sroa$031$0)) + 4|0);
        $119 = HEAP32[$118>>2]|0;
        $120 = ($119|0)==(0|0);
        if ($120) {
         $121 = ((($$sroa$031$0)) + 8|0);
         $122 = HEAP32[$121>>2]|0;
         $123 = HEAP32[$122>>2]|0;
         $124 = ($123|0)==($$sroa$031$0|0);
         if ($124) {
          $$0$i$i$i$i = $122;
         } else {
          $128 = $121;
          while(1) {
           $127 = HEAP32[$128>>2]|0;
           $129 = ((($127)) + 8|0);
           $130 = HEAP32[$129>>2]|0;
           $131 = HEAP32[$130>>2]|0;
           $132 = ($131|0)==($127|0);
           if ($132) {
            $$0$i$i$i$i = $130;
            break;
           } else {
            $128 = $129;
           }
          }
         }
        } else {
         $$0$i$i$i$i$i = $119;
         while(1) {
          $125 = HEAP32[$$0$i$i$i$i$i>>2]|0;
          $126 = ($125|0)==(0|0);
          if ($126) {
           break;
          } else {
           $$0$i$i$i$i$i = $125;
          }
         }
         $$0$i$i$i$i = $$0$i$i$i$i$i;
        }
        $133 = ($$0$i$i$i$i|0)==($72|0);
        if ($133) {
         break L25;
        } else {
         $$sroa$031$0 = $$0$i$i$i$i;
        }
       }
       if ((label|0) == 18) {
        $60 = ___cxa_find_matching_catch_2()|0;
        $61 = tempRet0;
        $eh$lpad$body$index4Z2D = $61;$eh$lpad$body$indexZ2D = $60;
        break L7;
       }
       else if ((label|0) == 31) {
        $102 = ___cxa_find_matching_catch_2()|0;
        $103 = tempRet0;
        __ZdlPv($84);
        $eh$lpad$body$index4Z2D = $103;$eh$lpad$body$indexZ2D = $102;
        break L7;
       }
      }
     } while(0);
     $134 = HEAP32[$11>>2]|0;
     $135 = ((($134)) + 12|0);
     $136 = HEAP32[$135>>2]|0;
     __THREW__ = 0;
     (invoke_ii($136|0,($11|0))|0);
     $137 = __THREW__; __THREW__ = 0;
     $138 = $137&1;
     if ($138) {
      $142 = ___cxa_find_matching_catch_2()|0;
      $143 = tempRet0;
      $$1 = $143;$$18 = $142;
      break L4;
     }
     $139 = HEAP32[$7>>2]|0;
     $140 = ((($139)) + 12|0);
     $141 = HEAP32[$140>>2]|0;
     (FUNCTION_TABLE_ii[$141 & 8191]($7)|0);
     STACKTOP = sp;return;
    }
   } while(0);
   if ((label|0) == 19) {
    $62 = ___cxa_find_matching_catch_2()|0;
    $63 = tempRet0;
    $eh$lpad$body$index4Z2D = $63;$eh$lpad$body$indexZ2D = $62;
   }
   $64 = HEAP32[$11>>2]|0;
   $65 = ((($64)) + 12|0);
   $66 = HEAP32[$65>>2]|0;
   __THREW__ = 0;
   (invoke_ii($66|0,($11|0))|0);
   $67 = __THREW__; __THREW__ = 0;
   $68 = $67&1;
   if ($68) {
    $149 = ___cxa_find_matching_catch_3(0|0)|0;
    $150 = tempRet0;
    ___clang_call_terminate($149);
    // unreachable;
   } else {
    $$1 = $eh$lpad$body$index4Z2D;$$18 = $eh$lpad$body$indexZ2D;
   }
  }
 } while(0);
 $144 = HEAP32[$7>>2]|0;
 $145 = ((($144)) + 12|0);
 $146 = HEAP32[$145>>2]|0;
 __THREW__ = 0;
 (invoke_ii($146|0,($7|0))|0);
 $147 = __THREW__; __THREW__ = 0;
 $148 = $147&1;
 if ($148) {
  $149 = ___cxa_find_matching_catch_3(0|0)|0;
  $150 = tempRet0;
  ___clang_call_terminate($149);
  // unreachable;
 } else {
  ___resumeException($$18|0);
  // unreachable;
 }
}
function __ZNSt3__26__treeINS_12__value_typeINS_4pairINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7ref_ptrIKN5osgDB7OptionsEEEEENS2_INSA_INS9_6ObjectEEEdEEEENS_19__map_value_compareISF_SJ_NSB_11ObjectCache9ClassCompELb1EEENS6_ISJ_EEE12__find_equalISF_EERPNS_16__tree_node_baseIPvEENS_21__tree_const_iteratorISJ_PNS_11__tree_nodeISJ_SS_EEiEERPNS_15__tree_end_nodeISU_EESV_RKT_($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0$be$i = 0, $$0$be$i26 = 0, $$0$i = 0, $$0$i$i = 0, $$0$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i$i = 0, $$0$i23 = 0, $$024$be$in$i = 0, $$024$be$in$i25 = 0, $$024$i = 0, $$024$i22 = 0, $$08$i$i = 0, $$2 = 0, $$sroa$045$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = ((($0)) + 4|0);
 $6 = HEAP32[$1>>2]|0;
 $7 = ($6|0)==($5|0);
 $8 = $6;
 if (!($7)) {
  $9 = ((($6)) + 16|0);
  $10 = (__ZNK5osgDB11ObjectCache9ClassCompclERKNSt3__24pairINS2_12basic_stringIcNS2_11char_traitsIcEENS2_9allocatorIcEEEEN3osg7ref_ptrIKNS_7OptionsEEEEESH_(0,$4,$9)|0);
  if (!($10)) {
   $40 = (__ZNK5osgDB11ObjectCache9ClassCompclERKNSt3__24pairINS2_12basic_stringIcNS2_11char_traitsIcEENS2_9allocatorIcEEEEN3osg7ref_ptrIKNS_7OptionsEEEEESH_(0,$9,$4)|0);
   if (!($40)) {
    HEAP32[$2>>2] = $8;
    HEAP32[$3>>2] = $8;
    $$2 = $3;
    return ($$2|0);
   }
   $41 = ((($6)) + 4|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = ($42|0)==(0|0);
   if ($43) {
    $44 = ((($6)) + 8|0);
    $45 = HEAP32[$44>>2]|0;
    $46 = HEAP32[$45>>2]|0;
    $47 = ($46|0)==($6|0);
    if ($47) {
     $$0$i$i$i$i$i = $45;
    } else {
     $51 = $44;
     while(1) {
      $50 = HEAP32[$51>>2]|0;
      $52 = ((($50)) + 8|0);
      $53 = HEAP32[$52>>2]|0;
      $54 = HEAP32[$53>>2]|0;
      $55 = ($54|0)==($50|0);
      if ($55) {
       $$0$i$i$i$i$i = $53;
       break;
      } else {
       $51 = $52;
      }
     }
    }
   } else {
    $$0$i$i$i$i$i$i = $42;
    while(1) {
     $48 = HEAP32[$$0$i$i$i$i$i$i>>2]|0;
     $49 = ($48|0)==(0|0);
     if ($49) {
      break;
     } else {
      $$0$i$i$i$i$i$i = $48;
     }
    }
    $$0$i$i$i$i$i = $$0$i$i$i$i$i$i;
   }
   $56 = ($$0$i$i$i$i$i|0)==($5|0);
   if (!($56)) {
    $57 = ((($$0$i$i$i$i$i)) + 16|0);
    $58 = (__ZNK5osgDB11ObjectCache9ClassCompclERKNSt3__24pairINS2_12basic_stringIcNS2_11char_traitsIcEENS2_9allocatorIcEEEEN3osg7ref_ptrIKNS_7OptionsEEEEESH_(0,$4,$57)|0);
    if (!($58)) {
     $63 = HEAP32[$5>>2]|0;
     $64 = ($63|0)==(0|0);
     if ($64) {
      HEAP32[$2>>2] = $5;
      $$2 = $5;
      return ($$2|0);
     }
     $65 = ((($0)) + 4|0);
     $$0$i = $65;$$024$i = $63;
     while(1) {
      $66 = ((($$024$i)) + 16|0);
      $67 = (__ZNK5osgDB11ObjectCache9ClassCompclERKNSt3__24pairINS2_12basic_stringIcNS2_11char_traitsIcEENS2_9allocatorIcEEEEN3osg7ref_ptrIKNS_7OptionsEEEEESH_(0,$4,$66)|0);
      if ($67) {
       $68 = HEAP32[$$024$i>>2]|0;
       $69 = ($68|0)==(0|0);
       if ($69) {
        label = 38;
        break;
       } else {
        $$0$be$i = $$024$i;$$024$be$in$i = $68;
       }
      } else {
       $70 = (__ZNK5osgDB11ObjectCache9ClassCompclERKNSt3__24pairINS2_12basic_stringIcNS2_11char_traitsIcEENS2_9allocatorIcEEEEN3osg7ref_ptrIKNS_7OptionsEEEEESH_(0,$66,$4)|0);
       if (!($70)) {
        label = 43;
        break;
       }
       $71 = ((($$024$i)) + 4|0);
       $72 = HEAP32[$71>>2]|0;
       $73 = ($72|0)==(0|0);
       if ($73) {
        label = 42;
        break;
       } else {
        $$0$be$i = $71;$$024$be$in$i = $72;
       }
      }
      $$0$i = $$0$be$i;$$024$i = $$024$be$in$i;
     }
     if ((label|0) == 38) {
      HEAP32[$2>>2] = $$024$i;
      $$2 = $$024$i;
      return ($$2|0);
     }
     else if ((label|0) == 42) {
      HEAP32[$2>>2] = $$024$i;
      $$2 = $71;
      return ($$2|0);
     }
     else if ((label|0) == 43) {
      HEAP32[$2>>2] = $$024$i;
      $$2 = $$0$i;
      return ($$2|0);
     }
    }
   }
   $59 = ((($6)) + 4|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = ($60|0)==(0|0);
   if ($61) {
    HEAP32[$2>>2] = $8;
    $62 = ((($6)) + 4|0);
    $$2 = $62;
    return ($$2|0);
   } else {
    HEAP32[$2>>2] = $$0$i$i$i$i$i;
    $$2 = $$0$i$i$i$i$i;
    return ($$2|0);
   }
  }
 }
 $11 = HEAP32[$0>>2]|0;
 $12 = ($6|0)==($11|0);
 if ($12) {
  $$sroa$045$0 = $8;
 } else {
  $13 = HEAP32[$6>>2]|0;
  $14 = ($13|0)==(0|0);
  if ($14) {
   $$0$i$i = $6;
   while(1) {
    $18 = ((($$0$i$i)) + 8|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = HEAP32[$19>>2]|0;
    $21 = ($20|0)==($$0$i$i|0);
    if ($21) {
     $$0$i$i = $19;
    } else {
     $$08$i$i = $19;
     break;
    }
   }
  } else {
   $$0$i$i$i = $13;
   while(1) {
    $15 = ((($$0$i$i$i)) + 4|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = ($16|0)==(0|0);
    if ($17) {
     $$08$i$i = $$0$i$i$i;
     break;
    } else {
     $$0$i$i$i = $16;
    }
   }
  }
  $22 = $$08$i$i;
  $23 = ((($$08$i$i)) + 16|0);
  $24 = (__ZNK5osgDB11ObjectCache9ClassCompclERKNSt3__24pairINS2_12basic_stringIcNS2_11char_traitsIcEENS2_9allocatorIcEEEEN3osg7ref_ptrIKNS_7OptionsEEEEESH_(0,$23,$4)|0);
  if ($24) {
   $$sroa$045$0 = $22;
  } else {
   $29 = HEAP32[$5>>2]|0;
   $30 = ($29|0)==(0|0);
   if ($30) {
    HEAP32[$2>>2] = $5;
    $$2 = $5;
    return ($$2|0);
   }
   $31 = ((($0)) + 4|0);
   $$0$i23 = $31;$$024$i22 = $29;
   while(1) {
    $32 = ((($$024$i22)) + 16|0);
    $33 = (__ZNK5osgDB11ObjectCache9ClassCompclERKNSt3__24pairINS2_12basic_stringIcNS2_11char_traitsIcEENS2_9allocatorIcEEEEN3osg7ref_ptrIKNS_7OptionsEEEEESH_(0,$4,$32)|0);
    if ($33) {
     $34 = HEAP32[$$024$i22>>2]|0;
     $35 = ($34|0)==(0|0);
     if ($35) {
      label = 16;
      break;
     } else {
      $$0$be$i26 = $$024$i22;$$024$be$in$i25 = $34;
     }
    } else {
     $36 = (__ZNK5osgDB11ObjectCache9ClassCompclERKNSt3__24pairINS2_12basic_stringIcNS2_11char_traitsIcEENS2_9allocatorIcEEEEN3osg7ref_ptrIKNS_7OptionsEEEEESH_(0,$32,$4)|0);
     if (!($36)) {
      label = 21;
      break;
     }
     $37 = ((($$024$i22)) + 4|0);
     $38 = HEAP32[$37>>2]|0;
     $39 = ($38|0)==(0|0);
     if ($39) {
      label = 20;
      break;
     } else {
      $$0$be$i26 = $37;$$024$be$in$i25 = $38;
     }
    }
    $$0$i23 = $$0$be$i26;$$024$i22 = $$024$be$in$i25;
   }
   if ((label|0) == 16) {
    HEAP32[$2>>2] = $$024$i22;
    $$2 = $$024$i22;
    return ($$2|0);
   }
   else if ((label|0) == 20) {
    HEAP32[$2>>2] = $$024$i22;
    $$2 = $37;
    return ($$2|0);
   }
   else if ((label|0) == 21) {
    HEAP32[$2>>2] = $$024$i22;
    $$2 = $$0$i23;
    return ($$2|0);
   }
  }
 }
 $25 = HEAP32[$6>>2]|0;
 $26 = ($25|0)==(0|0);
 if ($26) {
  HEAP32[$2>>2] = $6;
  $$2 = $6;
  return ($$2|0);
 } else {
  $27 = $$sroa$045$0;
  HEAP32[$2>>2] = $27;
  $28 = ((($27)) + 4|0);
  $$2 = $28;
  return ($$2|0);
 }
 return (0)|0;
}
function __ZN5osgDB11ObjectCache21addEntryToObjectCacheERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEPN3osg6ObjectEdPKNS_7OptionsE($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = +$3;
 $4 = $4|0;
 var $$0 = 0, $$08 = 0, $$1 = 0, $$19 = 0, $$2$ph = 0, $$210$ph = 0, $$4 = 0, $$412 = 0, $$5 = 0, $$513 = 0, $$phi$trans$insert73 = 0, $$phi$trans$insert74 = 0, $$pre = 0, $$pre$phi76Z2D = 0, $$pre$phi79Z2D = 0, $$pre75 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0;
 var $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0;
 var $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0;
 var $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0;
 var $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $eh$lpad$body$index3Z2D = 0, $eh$lpad$body$indexZ2D = 0, $eh$lpad$body31$index9Z2D = 0, $eh$lpad$body31$indexZ2D = 0, $eh$lpad$body38$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $5 = sp + 40|0;
 $6 = sp + 24|0;
 $7 = sp + 16|0;
 $8 = sp;
 $9 = ((($0)) + 24|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ((($10)) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 (FUNCTION_TABLE_ii[$12 & 8191]($9)|0);
 $13 = ($2|0)==(0|0);
 if (!($13)) {
  $14 = ((($2)) + 8|0);
  $15 = HEAP32[$14>>2]|0;HEAP32[$14>>2] = (($15+1)|0);
  $16 = HEAP32[$14>>2]|0;HEAP32[$14>>2] = (($16+1)|0);
 }
 $17 = ((($0)) + 12|0);
 HEAP32[$7>>2] = (58136);
 $18 = ((($7)) + 4|0);
 HEAP32[$18>>2] = 0;
 __THREW__ = 0;
 $19 = (invoke_iii(4165,($4|0),($7|0))|0);
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 L4: do {
  if ($21) {
   label = 58;
  } else {
   $22 = ($19|0)==(0|0);
   if (!($22)) {
    $23 = ((($19)) + 8|0);
    $24 = HEAP32[$23>>2]|0;HEAP32[$23>>2] = (($24+1)|0);
   }
   __THREW__ = 0;
   invoke_vii(3457,($6|0),($1|0));
   $25 = __THREW__; __THREW__ = 0;
   $26 = $25&1;
   L9: do {
    if ($26) {
     $156 = ___cxa_find_matching_catch_2()|0;
     $157 = tempRet0;
     $eh$lpad$body$index3Z2D = $157;$eh$lpad$body$indexZ2D = $156;
     label = 60;
    } else {
     $27 = ((($6)) + 12|0);
     HEAP32[$27>>2] = $19;
     if (!($22)) {
      $28 = ((($19)) + 8|0);
      $29 = HEAP32[$28>>2]|0;HEAP32[$28>>2] = (($29+1)|0);
     }
     __THREW__ = 0;
     $30 = (invoke_iii(4166,($17|0),($6|0))|0);
     $31 = __THREW__; __THREW__ = 0;
     $32 = $31&1;
     do {
      if (!($32)) {
       $33 = HEAP32[$30>>2]|0;
       $34 = ($33|0)==($2|0);
       if (!($34)) {
        HEAP32[$30>>2] = $2;
        if (!($13)) {
         $35 = ((($2)) + 8|0);
         $36 = HEAP32[$35>>2]|0;HEAP32[$35>>2] = (($36+1)|0);
        }
        $37 = ($33|0)==(0|0);
        if (!($37)) {
         $38 = ((($33)) + 8|0);
         $39 = HEAP32[$38>>2]|0;HEAP32[$38>>2] = (($39-1)|0);
         $40 = ($39|0)==(1);
         if ($40) {
          __THREW__ = 0;
          invoke_viii(3262,($33|0),1,1);
          $41 = __THREW__; __THREW__ = 0;
          $42 = $41&1;
          if ($42) {
           break;
          }
         }
        }
       }
       $43 = ((($30)) + 8|0);
       HEAPF64[$43>>3] = $3;
       $44 = HEAP32[$27>>2]|0;
       $45 = ($44|0)==(0|0);
       if (!($45)) {
        $46 = ((($44)) + 8|0);
        $47 = HEAP32[$46>>2]|0;HEAP32[$46>>2] = (($47-1)|0);
        $48 = ($47|0)==(1);
        if ($48) {
         __THREW__ = 0;
         invoke_viii(3262,($44|0),1,1);
         $49 = __THREW__; __THREW__ = 0;
         $50 = $49&1;
         if ($50) {
          $55 = ___cxa_find_matching_catch_2()|0;
          $56 = tempRet0;
          $57 = ((($6)) + 11|0);
          $58 = HEAP8[$57>>0]|0;
          $59 = ($58<<24>>24)<(0);
          if (!($59)) {
           $eh$lpad$body$index3Z2D = $56;$eh$lpad$body$indexZ2D = $55;
           label = 60;
           break L9;
          }
          $60 = HEAP32[$6>>2]|0;
          __ZdlPv($60);
          $eh$lpad$body$index3Z2D = $56;$eh$lpad$body$indexZ2D = $55;
          label = 60;
          break L9;
         }
        }
       }
       HEAP32[$27>>2] = 0;
       $51 = ((($6)) + 11|0);
       $52 = HEAP8[$51>>0]|0;
       $53 = ($52<<24>>24)<(0);
       if ($53) {
        $54 = HEAP32[$6>>2]|0;
        __ZdlPv($54);
       }
       if (!($22)) {
        $61 = ((($19)) + 8|0);
        $62 = HEAP32[$61>>2]|0;HEAP32[$61>>2] = (($62-1)|0);
        $63 = ($62|0)==(1);
        if ($63) {
         __THREW__ = 0;
         invoke_viii(3262,($19|0),1,1);
         $64 = __THREW__; __THREW__ = 0;
         $65 = $64&1;
         if ($65) {
          label = 58;
          break L4;
         }
        }
       }
       if (!($13)) {
        $66 = ((($2)) + 8|0);
        $67 = HEAP32[$66>>2]|0;HEAP32[$66>>2] = (($67-1)|0);
        $68 = ($67|0)==(1);
        if ($68) {
         __THREW__ = 0;
         invoke_viii(3262,($2|0),1,1);
         $69 = __THREW__; __THREW__ = 0;
         $70 = $69&1;
         if ($70) {
          $152 = ___cxa_find_matching_catch_2()|0;
          $153 = tempRet0;
          $$2$ph = $153;$$210$ph = $152;$$pre$phi79Z2D = $66;
          label = 74;
          break L4;
         }
        }
        $71 = HEAP32[$66>>2]|0;HEAP32[$66>>2] = (($71-1)|0);
        $72 = ($71|0)==(1);
        if ($72) {
         __THREW__ = 0;
         invoke_viii(3262,($2|0),1,1);
         $73 = __THREW__; __THREW__ = 0;
         $74 = $73&1;
         if ($74) {
          $150 = ___cxa_find_matching_catch_2()|0;
          $151 = tempRet0;
          $$5 = $151;$$513 = $150;
          label = 83;
          break L4;
         }
        }
       }
       __THREW__ = 0;
       $75 = (invoke_ii(3265,5)|0);
       $76 = __THREW__; __THREW__ = 0;
       $77 = $76&1;
       do {
        if (!($77)) {
         if (!($75)) {
          $200 = HEAP32[$9>>2]|0;
          $201 = ((($200)) + 12|0);
          $202 = HEAP32[$201>>2]|0;
          (FUNCTION_TABLE_ii[$202 & 8191]($9)|0);
          STACKTOP = sp;return;
         }
         __THREW__ = 0;
         $78 = (invoke_ii(3266,5)|0);
         $79 = __THREW__; __THREW__ = 0;
         $80 = $79&1;
         if (!($80)) {
          __THREW__ = 0;
          $81 = (invoke_iiii(3267,($78|0),(166378|0),7)|0);
          $82 = __THREW__; __THREW__ = 0;
          $83 = $82&1;
          if (!($83)) {
           $84 = ((($1)) + 11|0);
           $85 = HEAP8[$84>>0]|0;
           $86 = ($85<<24>>24)<(0);
           $87 = HEAP32[$1>>2]|0;
           $88 = $86 ? $87 : $1;
           $89 = ((($1)) + 4|0);
           $90 = HEAP32[$89>>2]|0;
           $91 = $85&255;
           $92 = $86 ? $90 : $91;
           __THREW__ = 0;
           $93 = (invoke_iiii(3267,($81|0),($88|0),($92|0))|0);
           $94 = __THREW__; __THREW__ = 0;
           $95 = $94&1;
           if (!($95)) {
            __THREW__ = 0;
            $96 = (invoke_iiii(3267,($93|0),(166386|0),15)|0);
            $97 = __THREW__; __THREW__ = 0;
            $98 = $97&1;
            if ($98) {
             break;
            }
            $99 = ($4|0)==(0|0);
            do {
             if ($99) {
              $103 = ((($8)) + 11|0);
              ;HEAP32[$8>>2]=0|0;HEAP32[$8+4>>2]=0|0;HEAP32[$8+8>>2]=0|0;
              $$pre$phi76Z2D = $103;$104 = 0;$109 = 0;
              label = 41;
             } else {
              $100 = ((($4)) + 32|0);
              __THREW__ = 0;
              invoke_vii(3457,($8|0),($100|0));
              $101 = __THREW__; __THREW__ = 0;
              $102 = $101&1;
              if ($102) {
               $193 = ___cxa_find_matching_catch_2()|0;
               $194 = tempRet0;
               $$4 = $194;$$412 = $193;
               break;
              } else {
               $$phi$trans$insert73 = ((($8)) + 11|0);
               $$pre = HEAP8[$$phi$trans$insert73>>0]|0;
               $$phi$trans$insert74 = ((($8)) + 4|0);
               $$pre75 = HEAP32[$$phi$trans$insert74>>2]|0;
               $$pre$phi76Z2D = $$phi$trans$insert73;$104 = $$pre;$109 = $$pre75;
               label = 41;
               break;
              }
             }
            } while(0);
            do {
             if ((label|0) == 41) {
              $105 = ($104<<24>>24)<(0);
              $106 = HEAP32[$8>>2]|0;
              $107 = $105 ? $106 : $8;
              $108 = $104&255;
              $110 = $105 ? $109 : $108;
              __THREW__ = 0;
              $111 = (invoke_iiii(3267,($96|0),($107|0),($110|0))|0);
              $112 = __THREW__; __THREW__ = 0;
              $113 = $112&1;
              L64: do {
               if ($113) {
                label = 78;
               } else {
                __THREW__ = 0;
                $114 = (invoke_iiii(3267,($111|0),(166402|0),17)|0);
                $115 = __THREW__; __THREW__ = 0;
                $116 = $115&1;
                if ($116) {
                 label = 78;
                 break;
                }
                __THREW__ = 0;
                $117 = (invoke_iii(3275,($114|0),($0|0))|0);
                $118 = __THREW__; __THREW__ = 0;
                $119 = $118&1;
                if ($119) {
                 label = 78;
                 break;
                }
                $120 = HEAP32[$117>>2]|0;
                $121 = ((($120)) + -12|0);
                $122 = HEAP32[$121>>2]|0;
                $123 = (($117) + ($122)|0);
                __THREW__ = 0;
                invoke_vii(3257,($5|0),($123|0));
                $124 = __THREW__; __THREW__ = 0;
                $125 = $124&1;
                if ($125) {
                 label = 78;
                 break;
                }
                __THREW__ = 0;
                $126 = (invoke_iii(3255,($5|0),(215188|0))|0);
                $127 = __THREW__; __THREW__ = 0;
                $128 = $127&1;
                do {
                 if (!($128)) {
                  $129 = HEAP32[$126>>2]|0;
                  $130 = ((($129)) + 28|0);
                  $131 = HEAP32[$130>>2]|0;
                  __THREW__ = 0;
                  $132 = (invoke_iii($131|0,($126|0),10)|0);
                  $133 = __THREW__; __THREW__ = 0;
                  $134 = $133&1;
                  if ($134) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3263,($5|0));
                  $141 = __THREW__; __THREW__ = 0;
                  $142 = $141&1;
                  if ($142) {
                   label = 78;
                   break L64;
                  }
                  __THREW__ = 0;
                  (invoke_iii(3268,($117|0),($132|0))|0);
                  $143 = __THREW__; __THREW__ = 0;
                  $144 = $143&1;
                  if ($144) {
                   label = 78;
                   break L64;
                  }
                  __THREW__ = 0;
                  (invoke_ii(3269,($117|0))|0);
                  $145 = __THREW__; __THREW__ = 0;
                  $146 = $145&1;
                  if ($146) {
                   label = 78;
                   break L64;
                  }
                  $147 = HEAP8[$$pre$phi76Z2D>>0]|0;
                  $148 = ($147<<24>>24)<(0);
                  if ($148) {
                   $149 = HEAP32[$8>>2]|0;
                   __ZdlPv($149);
                  }
                  $200 = HEAP32[$9>>2]|0;
                  $201 = ((($200)) + 12|0);
                  $202 = HEAP32[$201>>2]|0;
                  (FUNCTION_TABLE_ii[$202 & 8191]($9)|0);
                  STACKTOP = sp;return;
                 }
                } while(0);
                $135 = ___cxa_find_matching_catch_2()|0;
                $136 = tempRet0;
                __THREW__ = 0;
                invoke_vi(3263,($5|0));
                $137 = __THREW__; __THREW__ = 0;
                $138 = $137&1;
                if ($138) {
                 $139 = ___cxa_find_matching_catch_3(0|0)|0;
                 $140 = tempRet0;
                 ___clang_call_terminate($139);
                 // unreachable;
                } else {
                 $eh$lpad$body31$index9Z2D = $136;$eh$lpad$body31$indexZ2D = $135;
                 break;
                }
               }
              } while(0);
              if ((label|0) == 78) {
               $195 = ___cxa_find_matching_catch_2()|0;
               $196 = tempRet0;
               $eh$lpad$body31$index9Z2D = $196;$eh$lpad$body31$indexZ2D = $195;
              }
              $197 = HEAP8[$$pre$phi76Z2D>>0]|0;
              $198 = ($197<<24>>24)<(0);
              if (!($198)) {
               $$4 = $eh$lpad$body31$index9Z2D;$$412 = $eh$lpad$body31$indexZ2D;
               break;
              }
              $199 = HEAP32[$8>>2]|0;
              __ZdlPv($199);
              $$4 = $eh$lpad$body31$index9Z2D;$$412 = $eh$lpad$body31$indexZ2D;
             }
            } while(0);
            $$5 = $$4;$$513 = $$412;
            label = 83;
            break L4;
           }
          }
         }
        }
       } while(0);
       $191 = ___cxa_find_matching_catch_2()|0;
       $192 = tempRet0;
       $$5 = $192;$$513 = $191;
       label = 83;
       break L4;
      }
     } while(0);
     $158 = ___cxa_find_matching_catch_2()|0;
     $159 = tempRet0;
     $160 = HEAP32[$27>>2]|0;
     $161 = ($160|0)==(0|0);
     if (!($161)) {
      $162 = ((($160)) + 8|0);
      $163 = HEAP32[$162>>2]|0;HEAP32[$162>>2] = (($163-1)|0);
      $164 = ($163|0)==(1);
      if ($164) {
       __THREW__ = 0;
       invoke_viii(3262,($160|0),1,1);
       $165 = __THREW__; __THREW__ = 0;
       $166 = $165&1;
       if ($166) {
        $171 = ___cxa_find_matching_catch_3(0|0)|0;
        $172 = tempRet0;
        $173 = ((($6)) + 11|0);
        $174 = HEAP8[$173>>0]|0;
        $175 = ($174<<24>>24)<(0);
        if (!($175)) {
         $eh$lpad$body38$indexZ2D = $171;
         ___clang_call_terminate($eh$lpad$body38$indexZ2D);
         // unreachable;
        }
        $176 = HEAP32[$6>>2]|0;
        __ZdlPv($176);
        $eh$lpad$body38$indexZ2D = $171;
        ___clang_call_terminate($eh$lpad$body38$indexZ2D);
        // unreachable;
       }
      }
     }
     HEAP32[$27>>2] = 0;
     $167 = ((($6)) + 11|0);
     $168 = HEAP8[$167>>0]|0;
     $169 = ($168<<24>>24)<(0);
     if ($169) {
      $170 = HEAP32[$6>>2]|0;
      __ZdlPv($170);
      $$0 = $159;$$08 = $158;
     } else {
      $$0 = $159;$$08 = $158;
     }
    }
   } while(0);
   if ((label|0) == 60) {
    $$0 = $eh$lpad$body$index3Z2D;$$08 = $eh$lpad$body$indexZ2D;
   }
   if ($22) {
    $$1 = $$0;$$19 = $$08;
    label = 71;
   } else {
    $177 = ((($19)) + 8|0);
    $178 = HEAP32[$177>>2]|0;HEAP32[$177>>2] = (($178-1)|0);
    $179 = ($178|0)==(1);
    if ($179) {
     __THREW__ = 0;
     invoke_viii(3262,($19|0),1,1);
     $180 = __THREW__; __THREW__ = 0;
     $181 = $180&1;
     if (!($181)) {
      $$1 = $$0;$$19 = $$08;
      label = 71;
     }
    } else {
     $$1 = $$0;$$19 = $$08;
     label = 71;
    }
   }
  }
 } while(0);
 if ((label|0) == 58) {
  $154 = ___cxa_find_matching_catch_2()|0;
  $155 = tempRet0;
  $$1 = $155;$$19 = $154;
  label = 71;
 }
 if ((label|0) == 71) {
  if ($13) {
   $$5 = $$1;$$513 = $$19;
   label = 83;
  } else {
   $182 = ((($2)) + 8|0);
   $183 = HEAP32[$182>>2]|0;HEAP32[$182>>2] = (($183-1)|0);
   $184 = ($183|0)==(1);
   if ($184) {
    __THREW__ = 0;
    invoke_viii(3262,($2|0),1,1);
    $185 = __THREW__; __THREW__ = 0;
    $186 = $185&1;
    if (!($186)) {
     $$2$ph = $$1;$$210$ph = $$19;$$pre$phi79Z2D = $182;
     label = 74;
    }
   } else {
    $$2$ph = $$1;$$210$ph = $$19;$$pre$phi79Z2D = $182;
    label = 74;
   }
  }
 }
 if ((label|0) == 74) {
  $187 = HEAP32[$$pre$phi79Z2D>>2]|0;HEAP32[$$pre$phi79Z2D>>2] = (($187-1)|0);
  $188 = ($187|0)==(1);
  if ($188) {
   __THREW__ = 0;
   invoke_viii(3262,($2|0),1,1);
   $189 = __THREW__; __THREW__ = 0;
   $190 = $189&1;
   if (!($190)) {
    $$5 = $$2$ph;$$513 = $$210$ph;
    label = 83;
   }
  } else {
   $$5 = $$2$ph;$$513 = $$210$ph;
   label = 83;
  }
 }
 if ((label|0) == 83) {
  $203 = HEAP32[$9>>2]|0;
  $204 = ((($203)) + 12|0);
  $205 = HEAP32[$204>>2]|0;
  __THREW__ = 0;
  (invoke_ii($205|0,($9|0))|0);
  $206 = __THREW__; __THREW__ = 0;
  $207 = $206&1;
  if (!($207)) {
   ___resumeException($$513|0);
   // unreachable;
  }
 }
 $208 = ___cxa_find_matching_catch_3(0|0)|0;
 $209 = tempRet0;
 $eh$lpad$body38$indexZ2D = $208;
 ___clang_call_terminate($eh$lpad$body38$indexZ2D);
 // unreachable;
}
function __ZN3osg5cloneIN5osgDB7OptionsEEEPT_PKS3_RKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp + 4|0;
 $3 = sp;
 $4 = ($0|0)==(0|0);
 if ($4) {
  $62 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(2)|0);
  if (!($62)) {
   $$1 = 0;
   STACKTOP = sp;return ($$1|0);
  }
  $63 = (__ZN3osg6notifyENS_14NotifySeverityE(2)|0);
  $64 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($63,166509,88)|0);
  $65 = HEAP32[$64>>2]|0;
  $66 = ((($65)) + -12|0);
  $67 = HEAP32[$66>>2]|0;
  $68 = (($64) + ($67)|0);
  __ZNKSt3__28ios_base6getlocEv($3,$68);
  __THREW__ = 0;
  $69 = (invoke_iii(3255,($3|0),(215188|0))|0);
  $70 = __THREW__; __THREW__ = 0;
  $71 = $70&1;
  if (!($71)) {
   $72 = HEAP32[$69>>2]|0;
   $73 = ((($72)) + 28|0);
   $74 = HEAP32[$73>>2]|0;
   __THREW__ = 0;
   $75 = (invoke_iii($74|0,($69|0),10)|0);
   $76 = __THREW__; __THREW__ = 0;
   $77 = $76&1;
   if (!($77)) {
    __ZNSt3__26localeD2Ev($3);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($64,$75)|0);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($64)|0);
    $$1 = 0;
    STACKTOP = sp;return ($$1|0);
   }
  }
  $78 = ___cxa_find_matching_catch_2()|0;
  $79 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3263,($3|0));
  $80 = __THREW__; __THREW__ = 0;
  $81 = $80&1;
  if ($81) {
   $82 = ___cxa_find_matching_catch_3(0|0)|0;
   $83 = tempRet0;
   ___clang_call_terminate($82);
   // unreachable;
  } else {
   ___resumeException($78|0);
   // unreachable;
  }
 }
 $5 = HEAP32[$0>>2]|0;
 $6 = ((($5)) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_iii[$7 & 8191]($0,$1)|0);
 $9 = ($8|0)==(0|0);
 if ($9) {
  label = 9;
 } else {
  $10 = ((($8)) + 8|0);
  $11 = HEAP32[$10>>2]|0;HEAP32[$10>>2] = (($11+1)|0);
  $12 = (___dynamic_cast($8,26112,5376,0)|0);
  $13 = ($12|0)==(0|0);
  if ($13) {
   label = 9;
  } else {
   __THREW__ = 0;
   (invoke_ii(3335,($8|0))|0);
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if ($15) {
    label = 5;
   } else {
    $$1 = $12;
    STACKTOP = sp;return ($$1|0);
   }
  }
 }
 L19: do {
  if ((label|0) == 9) {
   __THREW__ = 0;
   $23 = (invoke_ii(3265,2)|0);
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   if ($25) {
    label = 5;
   } else {
    do {
     if ($23) {
      __THREW__ = 0;
      $26 = (invoke_ii(3266,2)|0);
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       label = 5;
       break L19;
      }
      __THREW__ = 0;
      $29 = (invoke_iiii(3267,($26|0),(166420|0),88)|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 5;
       break L19;
      }
      $32 = HEAP32[$29>>2]|0;
      $33 = ((($32)) + -12|0);
      $34 = HEAP32[$33>>2]|0;
      $35 = (($29) + ($34)|0);
      __THREW__ = 0;
      invoke_vii(3257,($2|0),($35|0));
      $36 = __THREW__; __THREW__ = 0;
      $37 = $36&1;
      if ($37) {
       label = 5;
       break L19;
      }
      __THREW__ = 0;
      $38 = (invoke_iii(3255,($2|0),(215188|0))|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       $41 = HEAP32[$38>>2]|0;
       $42 = ((($41)) + 28|0);
       $43 = HEAP32[$42>>2]|0;
       __THREW__ = 0;
       $44 = (invoke_iii($43|0,($38|0),10)|0);
       $45 = __THREW__; __THREW__ = 0;
       $46 = $45&1;
       if (!($46)) {
        __THREW__ = 0;
        invoke_vi(3263,($2|0));
        $53 = __THREW__; __THREW__ = 0;
        $54 = $53&1;
        if ($54) {
         label = 5;
         break L19;
        }
        __THREW__ = 0;
        (invoke_iii(3268,($29|0),($44|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 5;
         break L19;
        }
        __THREW__ = 0;
        (invoke_ii(3269,($29|0))|0);
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 5;
         break L19;
        } else {
         break;
        }
       }
      }
      $47 = ___cxa_find_matching_catch_2()|0;
      $48 = tempRet0;
      __THREW__ = 0;
      invoke_vi(3263,($2|0));
      $49 = __THREW__; __THREW__ = 0;
      $50 = $49&1;
      if ($50) {
       $51 = ___cxa_find_matching_catch_3(0|0)|0;
       $52 = tempRet0;
       ___clang_call_terminate($51);
       // unreachable;
      } else {
       $eh$lpad$body$index2Z2D = $48;$eh$lpad$body$indexZ2D = $47;
       break L19;
      }
     }
    } while(0);
    if ($9) {
     $$1 = 0;
     STACKTOP = sp;return ($$1|0);
    }
    $59 = ((($8)) + 8|0);
    $60 = HEAP32[$59>>2]|0;HEAP32[$59>>2] = (($60-1)|0);
    $61 = ($60|0)==(1);
    if (!($61)) {
     $$1 = 0;
     STACKTOP = sp;return ($$1|0);
    }
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($8,1,1);
    $$1 = 0;
    STACKTOP = sp;return ($$1|0);
   }
  }
 } while(0);
 if ((label|0) == 5) {
  $16 = ___cxa_find_matching_catch_2()|0;
  $17 = tempRet0;
  $eh$lpad$body$index2Z2D = $17;$eh$lpad$body$indexZ2D = $16;
 }
 if ($9) {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 $18 = ((($8)) + 8|0);
 $19 = HEAP32[$18>>2]|0;HEAP32[$18>>2] = (($19-1)|0);
 $20 = ($19|0)==(1);
 if (!($20)) {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(3262,($8|0),1,1);
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if ($22) {
  $84 = ___cxa_find_matching_catch_3(0|0)|0;
  $85 = tempRet0;
  ___clang_call_terminate($84);
  // unreachable;
 } else {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 return (0)|0;
}
function __ZNSt3__23mapINS_4pairINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7ref_ptrIKN5osgDB7OptionsEEEEENS1_INS9_INS8_6ObjectEEEdEENSA_11ObjectCache9ClassCompENS5_INS1_IKSE_SH_EEEEEixERSK_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$be$i = 0, $$0$i = 0, $$014 = 0, $$024$be$in$i = 0, $$024$i = 0, $$025$i = 0, $$025$i68 = 0, $$049 = 0, $$04967 = 0, $$pre = 0, $$pre$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 do {
  if ($4) {
   $$025$i = $2;$$049 = $2;$14 = $3;$43 = 0;
   label = 12;
  } else {
   $5 = ((($0)) + 4|0);
   $$0$i = $5;$$024$i = $3;
   while(1) {
    $6 = ((($$024$i)) + 16|0);
    $7 = (__ZNK5osgDB11ObjectCache9ClassCompclERKNSt3__24pairINS2_12basic_stringIcNS2_11char_traitsIcEENS2_9allocatorIcEEEEN3osg7ref_ptrIKNS_7OptionsEEEEESH_(0,$1,$6)|0);
    if ($7) {
     $8 = HEAP32[$$024$i>>2]|0;
     $9 = ($8|0)==(0|0);
     if ($9) {
      label = 5;
      break;
     } else {
      $$0$be$i = $$024$i;$$024$be$in$i = $8;
     }
    } else {
     $10 = (__ZNK5osgDB11ObjectCache9ClassCompclERKNSt3__24pairINS2_12basic_stringIcNS2_11char_traitsIcEENS2_9allocatorIcEEEEN3osg7ref_ptrIKNS_7OptionsEEEEESH_(0,$6,$1)|0);
     if (!($10)) {
      label = 10;
      break;
     }
     $11 = ((($$024$i)) + 4|0);
     $12 = HEAP32[$11>>2]|0;
     $13 = ($12|0)==(0|0);
     if ($13) {
      label = 9;
      break;
     } else {
      $$0$be$i = $11;$$024$be$in$i = $12;
     }
    }
    $$0$i = $$0$be$i;$$024$i = $$024$be$in$i;
   }
   if ((label|0) == 5) {
    $$025$i68 = $$024$i;$$04967 = $$024$i;
    break;
   }
   else if ((label|0) == 9) {
    $$025$i68 = $11;$$04967 = $$024$i;
    break;
   }
   else if ((label|0) == 10) {
    $$pre = HEAP32[$$0$i>>2]|0;
    $$025$i = $$0$i;$$049 = $$024$i;$14 = $$pre;$43 = $$pre;
    label = 12;
    break;
   }
  }
 } while(0);
 if ((label|0) == 12) {
  $15 = ($14|0)==(0|0);
  if ($15) {
   $$025$i68 = $$025$i;$$04967 = $$049;
  } else {
   $$014 = $43;
   $42 = ((($$014)) + 32|0);
   return ($42|0);
  }
 }
 $16 = (__Znwj(48)|0);
 $17 = ((($16)) + 16|0);
 __THREW__ = 0;
 invoke_vii(3457,($17|0),($1|0));
 $18 = __THREW__; __THREW__ = 0;
 $19 = $18&1;
 if ($19) {
  $26 = ___cxa_find_matching_catch_2()|0;
  $27 = tempRet0;
  __ZdlPv($16);
  ___resumeException($26|0);
  // unreachable;
 }
 $20 = ((($16)) + 28|0);
 $21 = ((($1)) + 12|0);
 $22 = HEAP32[$21>>2]|0;
 HEAP32[$20>>2] = $22;
 $23 = ($22|0)==(0|0);
 if (!($23)) {
  $24 = ((($22)) + 8|0);
  $25 = HEAP32[$24>>2]|0;HEAP32[$24>>2] = (($25+1)|0);
 }
 $28 = ((($16)) + 32|0);
 HEAP32[$28>>2] = 0;
 $29 = ((($16)) + 40|0);
 HEAPF64[$29>>3] = 0.0;
 HEAP32[$16>>2] = 0;
 $30 = ((($16)) + 4|0);
 HEAP32[$30>>2] = 0;
 $31 = ((($16)) + 8|0);
 HEAP32[$31>>2] = $$04967;
 HEAP32[$$025$i68>>2] = $16;
 $32 = HEAP32[$0>>2]|0;
 $33 = HEAP32[$32>>2]|0;
 $34 = ($33|0)==(0|0);
 if ($34) {
  $38 = $16;
 } else {
  $35 = $33;
  HEAP32[$0>>2] = $35;
  $$pre$i = HEAP32[$$025$i68>>2]|0;
  $38 = $$pre$i;
 }
 $36 = ((($0)) + 4|0);
 $37 = HEAP32[$36>>2]|0;
 __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($37,$38);
 $39 = ((($0)) + 8|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = (($40) + 1)|0;
 HEAP32[$39>>2] = $41;
 $$014 = $16;
 $42 = ((($$014)) + 32|0);
 return ($42|0);
}
function __ZN5osgDB11ObjectCache21getRefFromObjectCacheERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEPKNS_7OptionsE($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $$0$ph$lcssa$i$i$i = 0, $$0$ph13$i$i$i = 0, $$07$ph12$i$i$i = 0, $$0710$i$i$i = 0, $$08 = 0, $$1 = 0, $$19 = 0, $$3 = 0, $$311 = 0, $$sroa$0$0$i$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0;
 var $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0;
 var $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0;
 var $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0;
 var $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0;
 var $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index5Z2D = 0, $eh$lpad$body$indexZ2D = 0, $eh$lpad$body28$index12Z2D = 0, $eh$lpad$body28$indexZ2D = 0, $eh$lpad$body34$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $4 = sp + 20|0;
 $5 = sp + 16|0;
 $6 = sp;
 $7 = ((($1)) + 24|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($8)) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 (FUNCTION_TABLE_ii[$10 & 8191]($7)|0);
 $11 = ($3|0)==(0|0);
 if (!($11)) {
  $12 = ((($3)) + 8|0);
  $13 = HEAP32[$12>>2]|0;HEAP32[$12>>2] = (($13+1)|0);
 }
 __THREW__ = 0;
 invoke_vii(3457,($6|0),($2|0));
 $14 = __THREW__; __THREW__ = 0;
 $15 = $14&1;
 L4: do {
  if ($15) {
   $136 = ___cxa_find_matching_catch_2()|0;
   $137 = tempRet0;
   $eh$lpad$body$index5Z2D = $137;$eh$lpad$body$indexZ2D = $136;
   label = 48;
  } else {
   $16 = ((($6)) + 12|0);
   HEAP32[$16>>2] = $3;
   if (!($11)) {
    $17 = ((($3)) + 8|0);
    $18 = HEAP32[$17>>2]|0;HEAP32[$17>>2] = (($18+1)|0);
   }
   $19 = ((($1)) + 16|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = ($20|0)==(0|0);
   do {
    if ($21) {
     label = 15;
    } else {
     $$0$ph13$i$i$i = $19;$$07$ph12$i$i$i = $20;
     L11: while(1) {
      $$0710$i$i$i = $$07$ph12$i$i$i;
      while(1) {
       $22 = ((($$0710$i$i$i)) + 16|0);
       __THREW__ = 0;
       $23 = (invoke_iiii(4167,0,($22|0),($6|0))|0);
       $24 = __THREW__; __THREW__ = 0;
       $25 = $24&1;
       if ($25) {
        break L11;
       }
       if (!($23)) {
        break;
       }
       $28 = ((($$0710$i$i$i)) + 4|0);
       $29 = HEAP32[$28>>2]|0;
       $30 = ($29|0)==(0|0);
       if ($30) {
        $$0$ph$lcssa$i$i$i = $$0$ph13$i$i$i;
        label = 12;
        break L11;
       } else {
        $$0710$i$i$i = $29;
       }
      }
      $26 = HEAP32[$$0710$i$i$i>>2]|0;
      $27 = ($26|0)==(0|0);
      if ($27) {
       $$0$ph$lcssa$i$i$i = $$0710$i$i$i;
       label = 12;
       break;
      } else {
       $$0$ph13$i$i$i = $$0710$i$i$i;$$07$ph12$i$i$i = $26;
      }
     }
     if ((label|0) == 12) {
      $31 = ($$0$ph$lcssa$i$i$i|0)==($19|0);
      if ($31) {
       label = 15;
       break;
      }
      $32 = ((($$0$ph$lcssa$i$i$i)) + 16|0);
      __THREW__ = 0;
      $33 = (invoke_iiii(4167,0,($6|0),($32|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if (!($35)) {
       if ($33) {
        label = 15;
        break;
       } else {
        $$sroa$0$0$i$i = $$0$ph$lcssa$i$i$i;
        break;
       }
      }
     }
     $138 = ___cxa_find_matching_catch_2()|0;
     $139 = tempRet0;
     $140 = HEAP32[$16>>2]|0;
     $141 = ($140|0)==(0|0);
     if (!($141)) {
      $142 = ((($140)) + 8|0);
      $143 = HEAP32[$142>>2]|0;HEAP32[$142>>2] = (($143-1)|0);
      $144 = ($143|0)==(1);
      if ($144) {
       __THREW__ = 0;
       invoke_viii(3262,($140|0),1,1);
       $145 = __THREW__; __THREW__ = 0;
       $146 = $145&1;
       if ($146) {
        $151 = ___cxa_find_matching_catch_3(0|0)|0;
        $152 = tempRet0;
        $153 = ((($6)) + 11|0);
        $154 = HEAP8[$153>>0]|0;
        $155 = ($154<<24>>24)<(0);
        if (!($155)) {
         $eh$lpad$body34$indexZ2D = $151;
         ___clang_call_terminate($eh$lpad$body34$indexZ2D);
         // unreachable;
        }
        $156 = HEAP32[$6>>2]|0;
        __ZdlPv($156);
        $eh$lpad$body34$indexZ2D = $151;
        ___clang_call_terminate($eh$lpad$body34$indexZ2D);
        // unreachable;
       }
      }
     }
     HEAP32[$16>>2] = 0;
     $147 = ((($6)) + 11|0);
     $148 = HEAP8[$147>>0]|0;
     $149 = ($148<<24>>24)<(0);
     if (!($149)) {
      $$0 = $139;$$08 = $138;
      label = 56;
      break L4;
     }
     $150 = HEAP32[$6>>2]|0;
     __ZdlPv($150);
     $$0 = $139;$$08 = $138;
     label = 56;
     break L4;
    }
   } while(0);
   if ((label|0) == 15) {
    $$sroa$0$0$i$i = $19;
   }
   $36 = HEAP32[$16>>2]|0;
   $37 = ($36|0)==(0|0);
   if (!($37)) {
    $38 = ((($36)) + 8|0);
    $39 = HEAP32[$38>>2]|0;HEAP32[$38>>2] = (($39-1)|0);
    $40 = ($39|0)==(1);
    if ($40) {
     __THREW__ = 0;
     invoke_viii(3262,($36|0),1,1);
     $41 = __THREW__; __THREW__ = 0;
     $42 = $41&1;
     if ($42) {
      $47 = ___cxa_find_matching_catch_2()|0;
      $48 = tempRet0;
      $49 = ((($6)) + 11|0);
      $50 = HEAP8[$49>>0]|0;
      $51 = ($50<<24>>24)<(0);
      if (!($51)) {
       $eh$lpad$body$index5Z2D = $48;$eh$lpad$body$indexZ2D = $47;
       label = 48;
       break;
      }
      $52 = HEAP32[$6>>2]|0;
      __ZdlPv($52);
      $eh$lpad$body$index5Z2D = $48;$eh$lpad$body$indexZ2D = $47;
      label = 48;
      break;
     }
    }
   }
   HEAP32[$16>>2] = 0;
   $43 = ((($6)) + 11|0);
   $44 = HEAP8[$43>>0]|0;
   $45 = ($44<<24>>24)<(0);
   if ($45) {
    $46 = HEAP32[$6>>2]|0;
    __ZdlPv($46);
   }
   if (!($11)) {
    $53 = ((($3)) + 8|0);
    $54 = HEAP32[$53>>2]|0;HEAP32[$53>>2] = (($54-1)|0);
    $55 = ($54|0)==(1);
    if ($55) {
     __THREW__ = 0;
     invoke_viii(3262,($3|0),1,1);
     $56 = __THREW__; __THREW__ = 0;
     $57 = $56&1;
     if ($57) {
      $134 = ___cxa_find_matching_catch_2()|0;
      $135 = tempRet0;
      $$1 = $135;$$19 = $134;
      label = 59;
      break;
     }
    }
   }
   $58 = ($$sroa$0$0$i$i|0)==($19|0);
   if ($58) {
    HEAP32[$0>>2] = 0;
    $235 = HEAP32[$7>>2]|0;
    $236 = ((($235)) + 12|0);
    $237 = HEAP32[$236>>2]|0;
    (FUNCTION_TABLE_ii[$237 & 8191]($7)|0);
    STACKTOP = sp;return;
   }
   $59 = ((($$sroa$0$0$i$i)) + 28|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = ($60|0)==(0|0);
   L54: do {
    if ($61) {
     __THREW__ = 0;
     $169 = (invoke_ii(3265,5)|0);
     $170 = __THREW__; __THREW__ = 0;
     $171 = $170&1;
     if ($171) {
      label = 60;
     } else {
      if ($169) {
       __THREW__ = 0;
       $172 = (invoke_ii(3266,5)|0);
       $173 = __THREW__; __THREW__ = 0;
       $174 = $173&1;
       if ($174) {
        label = 60;
       } else {
        __THREW__ = 0;
        $175 = (invoke_iiii(3267,($172|0),(166598|0),6)|0);
        $176 = __THREW__; __THREW__ = 0;
        $177 = $176&1;
        if ($177) {
         label = 60;
        } else {
         $178 = ((($2)) + 11|0);
         $179 = HEAP8[$178>>0]|0;
         $180 = ($179<<24>>24)<(0);
         $181 = HEAP32[$2>>2]|0;
         $182 = $180 ? $181 : $2;
         $183 = ((($2)) + 4|0);
         $184 = HEAP32[$183>>2]|0;
         $185 = $179&255;
         $186 = $180 ? $184 : $185;
         __THREW__ = 0;
         $187 = (invoke_iiii(3267,($175|0),($182|0),($186|0))|0);
         $188 = __THREW__; __THREW__ = 0;
         $189 = $188&1;
         if ($189) {
          label = 60;
         } else {
          __THREW__ = 0;
          $190 = (invoke_iiii(3267,($187|0),(166623|0),16)|0);
          $191 = __THREW__; __THREW__ = 0;
          $192 = $191&1;
          if ($192) {
           label = 60;
          } else {
           __THREW__ = 0;
           $193 = (invoke_iii(3275,($190|0),($1|0))|0);
           $194 = __THREW__; __THREW__ = 0;
           $195 = $194&1;
           if ($195) {
            label = 60;
           } else {
            $196 = HEAP32[$193>>2]|0;
            $197 = ((($196)) + -12|0);
            $198 = HEAP32[$197>>2]|0;
            $199 = (($193) + ($198)|0);
            __THREW__ = 0;
            invoke_vii(3257,($4|0),($199|0));
            $200 = __THREW__; __THREW__ = 0;
            $201 = $200&1;
            if ($201) {
             label = 60;
            } else {
             __THREW__ = 0;
             $202 = (invoke_iii(3255,($4|0),(215188|0))|0);
             $203 = __THREW__; __THREW__ = 0;
             $204 = $203&1;
             do {
              if (!($204)) {
               $205 = HEAP32[$202>>2]|0;
               $206 = ((($205)) + 28|0);
               $207 = HEAP32[$206>>2]|0;
               __THREW__ = 0;
               $208 = (invoke_iii($207|0,($202|0),10)|0);
               $209 = __THREW__; __THREW__ = 0;
               $210 = $209&1;
               if ($210) {
                break;
               }
               __THREW__ = 0;
               invoke_vi(3263,($4|0));
               $217 = __THREW__; __THREW__ = 0;
               $218 = $217&1;
               if ($218) {
                label = 60;
                break L54;
               }
               __THREW__ = 0;
               (invoke_iii(3268,($193|0),($208|0))|0);
               $219 = __THREW__; __THREW__ = 0;
               $220 = $219&1;
               if ($220) {
                label = 60;
                break L54;
               }
               __THREW__ = 0;
               (invoke_ii(3269,($193|0))|0);
               $221 = __THREW__; __THREW__ = 0;
               $222 = $221&1;
               if ($222) {
                label = 60;
                break L54;
               } else {
                label = 80;
                break L54;
               }
              }
             } while(0);
             $211 = ___cxa_find_matching_catch_2()|0;
             $212 = tempRet0;
             __THREW__ = 0;
             invoke_vi(3263,($4|0));
             $213 = __THREW__; __THREW__ = 0;
             $214 = $213&1;
             if ($214) {
              $215 = ___cxa_find_matching_catch_3(0|0)|0;
              $216 = tempRet0;
              ___clang_call_terminate($215);
              // unreachable;
             } else {
              $eh$lpad$body28$index12Z2D = $212;$eh$lpad$body28$indexZ2D = $211;
              break;
             }
            }
           }
          }
         }
        }
       }
      } else {
       label = 80;
      }
     }
    } else {
     $62 = ((($60)) + 8|0);
     $63 = HEAP32[$62>>2]|0;HEAP32[$62>>2] = (($63+1)|0);
     __THREW__ = 0;
     $64 = (invoke_ii(3265,5)|0);
     $65 = __THREW__; __THREW__ = 0;
     $66 = $65&1;
     if ($66) {
      label = 60;
     } else {
      if ($64) {
       __THREW__ = 0;
       $67 = (invoke_ii(3266,5)|0);
       $68 = __THREW__; __THREW__ = 0;
       $69 = $68&1;
       if ($69) {
        label = 60;
       } else {
        __THREW__ = 0;
        $70 = (invoke_iiii(3267,($67|0),(166598|0),6)|0);
        $71 = __THREW__; __THREW__ = 0;
        $72 = $71&1;
        if ($72) {
         label = 60;
        } else {
         $73 = ((($2)) + 11|0);
         $74 = HEAP8[$73>>0]|0;
         $75 = ($74<<24>>24)<(0);
         $76 = HEAP32[$2>>2]|0;
         $77 = $75 ? $76 : $2;
         $78 = ((($2)) + 4|0);
         $79 = HEAP32[$78>>2]|0;
         $80 = $74&255;
         $81 = $75 ? $79 : $80;
         __THREW__ = 0;
         $82 = (invoke_iiii(3267,($70|0),($77|0),($81|0))|0);
         $83 = __THREW__; __THREW__ = 0;
         $84 = $83&1;
         if ($84) {
          label = 60;
         } else {
          __THREW__ = 0;
          $85 = (invoke_iiii(3267,($82|0),(166386|0),15)|0);
          $86 = __THREW__; __THREW__ = 0;
          $87 = $86&1;
          if ($87) {
           label = 60;
          } else {
           $88 = ((($60)) + 32|0);
           $89 = ((($88)) + 11|0);
           $90 = HEAP8[$89>>0]|0;
           $91 = ($90<<24>>24)<(0);
           $92 = HEAP32[$88>>2]|0;
           $93 = $91 ? $92 : $88;
           $94 = ((($60)) + 36|0);
           $95 = HEAP32[$94>>2]|0;
           $96 = $90&255;
           $97 = $91 ? $95 : $96;
           __THREW__ = 0;
           $98 = (invoke_iiii(3267,($85|0),($93|0),($97|0))|0);
           $99 = __THREW__; __THREW__ = 0;
           $100 = $99&1;
           if ($100) {
            label = 60;
           } else {
            __THREW__ = 0;
            $101 = (invoke_iiii(3267,($98|0),(166605|0),17)|0);
            $102 = __THREW__; __THREW__ = 0;
            $103 = $102&1;
            if ($103) {
             label = 60;
            } else {
             __THREW__ = 0;
             $104 = (invoke_iii(3275,($101|0),($1|0))|0);
             $105 = __THREW__; __THREW__ = 0;
             $106 = $105&1;
             if ($106) {
              label = 60;
             } else {
              $107 = HEAP32[$104>>2]|0;
              $108 = ((($107)) + -12|0);
              $109 = HEAP32[$108>>2]|0;
              $110 = (($104) + ($109)|0);
              __THREW__ = 0;
              invoke_vii(3257,($5|0),($110|0));
              $111 = __THREW__; __THREW__ = 0;
              $112 = $111&1;
              if ($112) {
               label = 60;
               break;
              }
              __THREW__ = 0;
              $113 = (invoke_iii(3255,($5|0),(215188|0))|0);
              $114 = __THREW__; __THREW__ = 0;
              $115 = $114&1;
              do {
               if (!($115)) {
                $116 = HEAP32[$113>>2]|0;
                $117 = ((($116)) + 28|0);
                $118 = HEAP32[$117>>2]|0;
                __THREW__ = 0;
                $119 = (invoke_iii($118|0,($113|0),10)|0);
                $120 = __THREW__; __THREW__ = 0;
                $121 = $120&1;
                if ($121) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3263,($5|0));
                $128 = __THREW__; __THREW__ = 0;
                $129 = $128&1;
                if ($129) {
                 label = 60;
                 break L54;
                }
                __THREW__ = 0;
                (invoke_iii(3268,($104|0),($119|0))|0);
                $130 = __THREW__; __THREW__ = 0;
                $131 = $130&1;
                if ($131) {
                 label = 60;
                 break L54;
                }
                __THREW__ = 0;
                (invoke_ii(3269,($104|0))|0);
                $132 = __THREW__; __THREW__ = 0;
                $133 = $132&1;
                if ($133) {
                 label = 60;
                 break L54;
                } else {
                 label = 80;
                 break L54;
                }
               }
              } while(0);
              $122 = ___cxa_find_matching_catch_2()|0;
              $123 = tempRet0;
              __THREW__ = 0;
              invoke_vi(3263,($5|0));
              $124 = __THREW__; __THREW__ = 0;
              $125 = $124&1;
              if ($125) {
               $126 = ___cxa_find_matching_catch_3(0|0)|0;
               $127 = tempRet0;
               ___clang_call_terminate($126);
               // unreachable;
              } else {
               $eh$lpad$body28$index12Z2D = $123;$eh$lpad$body28$indexZ2D = $122;
               break;
              }
             }
            }
           }
          }
         }
        }
       }
      } else {
       label = 80;
      }
     }
    }
   } while(0);
   if ((label|0) == 60) {
    $162 = ___cxa_find_matching_catch_2()|0;
    $163 = tempRet0;
    $eh$lpad$body28$index12Z2D = $163;$eh$lpad$body28$indexZ2D = $162;
   }
   else if ((label|0) == 80) {
    $223 = ((($$sroa$0$0$i$i)) + 32|0);
    $224 = HEAP32[$223>>2]|0;
    HEAP32[$0>>2] = $224;
    $225 = ($224|0)==(0|0);
    if (!($225)) {
     $226 = ((($224)) + 8|0);
     $227 = HEAP32[$226>>2]|0;HEAP32[$226>>2] = (($227+1)|0);
    }
    if ($61) {
     $235 = HEAP32[$7>>2]|0;
     $236 = ((($235)) + 12|0);
     $237 = HEAP32[$236>>2]|0;
     (FUNCTION_TABLE_ii[$237 & 8191]($7)|0);
     STACKTOP = sp;return;
    }
    $228 = ((($60)) + 8|0);
    $229 = HEAP32[$228>>2]|0;HEAP32[$228>>2] = (($229-1)|0);
    $230 = ($229|0)==(1);
    if (!($230)) {
     $235 = HEAP32[$7>>2]|0;
     $236 = ((($235)) + 12|0);
     $237 = HEAP32[$236>>2]|0;
     (FUNCTION_TABLE_ii[$237 & 8191]($7)|0);
     STACKTOP = sp;return;
    }
    __THREW__ = 0;
    invoke_viii(3262,($60|0),1,1);
    $231 = __THREW__; __THREW__ = 0;
    $232 = $231&1;
    if ($232) {
     $233 = ___cxa_find_matching_catch_2()|0;
     $234 = tempRet0;
     $$3 = $234;$$311 = $233;
     label = 88;
     break;
    } else {
     $235 = HEAP32[$7>>2]|0;
     $236 = ((($235)) + 12|0);
     $237 = HEAP32[$236>>2]|0;
     (FUNCTION_TABLE_ii[$237 & 8191]($7)|0);
     STACKTOP = sp;return;
    }
   }
   if ($61) {
    $$3 = $eh$lpad$body28$index12Z2D;$$311 = $eh$lpad$body28$indexZ2D;
    label = 88;
   } else {
    $164 = ((($60)) + 8|0);
    $165 = HEAP32[$164>>2]|0;HEAP32[$164>>2] = (($165-1)|0);
    $166 = ($165|0)==(1);
    if ($166) {
     __THREW__ = 0;
     invoke_viii(3262,($60|0),1,1);
     $167 = __THREW__; __THREW__ = 0;
     $168 = $167&1;
     if (!($168)) {
      $$3 = $eh$lpad$body28$index12Z2D;$$311 = $eh$lpad$body28$indexZ2D;
      label = 88;
     }
    } else {
     $$3 = $eh$lpad$body28$index12Z2D;$$311 = $eh$lpad$body28$indexZ2D;
     label = 88;
    }
   }
  }
 } while(0);
 if ((label|0) == 48) {
  $$0 = $eh$lpad$body$index5Z2D;$$08 = $eh$lpad$body$indexZ2D;
  label = 56;
 }
 if ((label|0) == 56) {
  if ($11) {
   $$1 = $$0;$$19 = $$08;
   label = 59;
  } else {
   $157 = ((($3)) + 8|0);
   $158 = HEAP32[$157>>2]|0;HEAP32[$157>>2] = (($158-1)|0);
   $159 = ($158|0)==(1);
   if ($159) {
    __THREW__ = 0;
    invoke_viii(3262,($3|0),1,1);
    $160 = __THREW__; __THREW__ = 0;
    $161 = $160&1;
    if (!($161)) {
     $$1 = $$0;$$19 = $$08;
     label = 59;
    }
   } else {
    $$1 = $$0;$$19 = $$08;
    label = 59;
   }
  }
 }
 if ((label|0) == 59) {
  $$3 = $$1;$$311 = $$19;
  label = 88;
 }
 if ((label|0) == 88) {
  $238 = HEAP32[$7>>2]|0;
  $239 = ((($238)) + 12|0);
  $240 = HEAP32[$239>>2]|0;
  __THREW__ = 0;
  (invoke_ii($240|0,($7|0))|0);
  $241 = __THREW__; __THREW__ = 0;
  $242 = $241&1;
  if (!($242)) {
   ___resumeException($$311|0);
   // unreachable;
  }
 }
 $243 = ___cxa_find_matching_catch_3(0|0)|0;
 $244 = tempRet0;
 $eh$lpad$body34$indexZ2D = $243;
 ___clang_call_terminate($eh$lpad$body34$indexZ2D);
 // unreachable;
}
function __ZN5osgDB11ObjectCache53updateTimeStampOfObjectsInCacheWithExternalReferencesEd($0,$1) {
 $0 = $0|0;
 $1 = +$1;
 var $$0$i$i$i$i = 0, $$sroa$06$0$be = 0, $$sroa$06$016 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 (FUNCTION_TABLE_ii[$5 & 8191]($2)|0);
 $6 = ((($0)) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($0)) + 16|0);
 $9 = ($7|0)==($8|0);
 if ($9) {
  $10 = HEAP32[$2>>2]|0;
  $11 = ((($10)) + 12|0);
  $12 = HEAP32[$11>>2]|0;
  (FUNCTION_TABLE_ii[$12 & 8191]($2)|0);
  return;
 } else {
  $$sroa$06$016 = $7;
 }
 while(1) {
  $13 = ((($$sroa$06$016)) + 32|0);
  $14 = HEAP32[$13>>2]|0;
  /* fence */;
  $15 = ((($14)) + 8|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($16|0)>(1);
  if ($17) {
   $18 = ((($$sroa$06$016)) + 40|0);
   HEAPF64[$18>>3] = $1;
  }
  $19 = ((($$sroa$06$016)) + 4|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = ($20|0)==(0|0);
  if ($21) {
   $22 = ((($$sroa$06$016)) + 8|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = HEAP32[$23>>2]|0;
   $25 = ($24|0)==($$sroa$06$016|0);
   if ($25) {
    $$sroa$06$0$be = $23;
   } else {
    $30 = $22;
    while(1) {
     $29 = HEAP32[$30>>2]|0;
     $31 = ((($29)) + 8|0);
     $32 = HEAP32[$31>>2]|0;
     $33 = HEAP32[$32>>2]|0;
     $34 = ($33|0)==($29|0);
     if ($34) {
      $$sroa$06$0$be = $32;
      break;
     } else {
      $30 = $31;
     }
    }
   }
  } else {
   $$0$i$i$i$i = $20;
   while(1) {
    $27 = HEAP32[$$0$i$i$i$i>>2]|0;
    $28 = ($27|0)==(0|0);
    if ($28) {
     break;
    } else {
     $$0$i$i$i$i = $27;
    }
   }
   $$sroa$06$0$be = $$0$i$i$i$i;
  }
  $26 = ($$sroa$06$0$be|0)==($8|0);
  if ($26) {
   break;
  } else {
   $$sroa$06$016 = $$sroa$06$0$be;
  }
 }
 $10 = HEAP32[$2>>2]|0;
 $11 = ((($10)) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 (FUNCTION_TABLE_ii[$12 & 8191]($2)|0);
 return;
}
function __ZN5osgDB11ObjectCache27removeExpiredObjectsInCacheEd($0,$1) {
 $0 = $0|0;
 $1 = +$1;
 var $$0$i$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i6 = 0, $$0$i$i$i$i10 = 0, $$0$i$i$i$i1030 = 0, $$0$i$i$i$i1031 = 0, $$0$i$i$i$i4 = 0, $$sroa$014$0$be = 0, $$sroa$014$027 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0.0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 (FUNCTION_TABLE_ii[$5 & 8191]($2)|0);
 $6 = ((($0)) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($0)) + 16|0);
 $9 = ($7|0)==($8|0);
 if ($9) {
  $64 = HEAP32[$2>>2]|0;
  $65 = ((($64)) + 12|0);
  $66 = HEAP32[$65>>2]|0;
  (FUNCTION_TABLE_ii[$66 & 8191]($2)|0);
  return;
 }
 $10 = ((($0)) + 20|0);
 $11 = ((($0)) + 16|0);
 $$sroa$014$027 = $7;
 L4: while(1) {
  $12 = ((($$sroa$014$027)) + 16|0);
  $13 = ((($$sroa$014$027)) + 40|0);
  $14 = +HEAPF64[$13>>3];
  $15 = !($14 <= $1);
  $16 = ((($$sroa$014$027)) + 4|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = ($17|0)==(0|0);
  do {
   if ($15) {
    if ($18) {
     $52 = ((($$sroa$014$027)) + 8|0);
     $53 = HEAP32[$52>>2]|0;
     $54 = HEAP32[$53>>2]|0;
     $55 = ($54|0)==($$sroa$014$027|0);
     if ($55) {
      $$sroa$014$0$be = $53;
      break;
     } else {
      $59 = $52;
     }
     while(1) {
      $58 = HEAP32[$59>>2]|0;
      $60 = ((($58)) + 8|0);
      $61 = HEAP32[$60>>2]|0;
      $62 = HEAP32[$61>>2]|0;
      $63 = ($62|0)==($58|0);
      if ($63) {
       $$sroa$014$0$be = $61;
       break;
      } else {
       $59 = $60;
      }
     }
    } else {
     $$0$i$i$i$i = $17;
     while(1) {
      $56 = HEAP32[$$0$i$i$i$i>>2]|0;
      $57 = ($56|0)==(0|0);
      if ($57) {
       break;
      } else {
       $$0$i$i$i$i = $56;
      }
     }
     $$sroa$014$0$be = $$0$i$i$i$i;
     break;
    }
   } else {
    if ($18) {
     $19 = ((($$sroa$014$027)) + 8|0);
     $20 = HEAP32[$19>>2]|0;
     $21 = HEAP32[$20>>2]|0;
     $22 = ($21|0)==($$sroa$014$027|0);
     if ($22) {
      $$0$i$i$i$i1031 = $20;
      label = 10;
     } else {
      $26 = $19;
      while(1) {
       $25 = HEAP32[$26>>2]|0;
       $27 = ((($25)) + 8|0);
       $28 = HEAP32[$27>>2]|0;
       $29 = HEAP32[$28>>2]|0;
       $30 = ($29|0)==($25|0);
       if ($30) {
        $$0$i$i$i$i10 = $28;
        label = 9;
        break;
       } else {
        $26 = $27;
       }
      }
     }
    } else {
     $$0$i$i$i$i$i6 = $17;
     while(1) {
      $23 = HEAP32[$$0$i$i$i$i$i6>>2]|0;
      $24 = ($23|0)==(0|0);
      if ($24) {
       break;
      } else {
       $$0$i$i$i$i$i6 = $23;
      }
     }
     $$0$i$i$i$i10 = $$0$i$i$i$i$i6;
     label = 9;
    }
    if ((label|0) == 9) {
     label = 0;
     if ($18) {
      $$0$i$i$i$i1031 = $$0$i$i$i$i10;
      label = 10;
     } else {
      $$0$i$i$i$i$i = $17;
      while(1) {
       $35 = HEAP32[$$0$i$i$i$i$i>>2]|0;
       $36 = ($35|0)==(0|0);
       if ($36) {
        break;
       } else {
        $$0$i$i$i$i$i = $35;
       }
      }
      $$0$i$i$i$i1030 = $$0$i$i$i$i10;$$0$i$i$i$i4 = $$0$i$i$i$i$i;
     }
    }
    if ((label|0) == 10) {
     label = 0;
     $31 = ((($$sroa$014$027)) + 8|0);
     $32 = HEAP32[$31>>2]|0;
     $33 = HEAP32[$32>>2]|0;
     $34 = ($33|0)==($$sroa$014$027|0);
     if ($34) {
      $$0$i$i$i$i1030 = $$0$i$i$i$i1031;$$0$i$i$i$i4 = $32;
     } else {
      $38 = $31;
      while(1) {
       $37 = HEAP32[$38>>2]|0;
       $39 = ((($37)) + 8|0);
       $40 = HEAP32[$39>>2]|0;
       $41 = HEAP32[$40>>2]|0;
       $42 = ($41|0)==($37|0);
       if ($42) {
        $$0$i$i$i$i1030 = $$0$i$i$i$i1031;$$0$i$i$i$i4 = $40;
        break;
       } else {
        $38 = $39;
       }
      }
     }
    }
    $43 = HEAP32[$6>>2]|0;
    $44 = ($43|0)==($$sroa$014$027|0);
    if ($44) {
     $45 = $$0$i$i$i$i4;
     HEAP32[$6>>2] = $45;
    }
    $46 = HEAP32[$10>>2]|0;
    $47 = (($46) + -1)|0;
    HEAP32[$10>>2] = $47;
    $48 = HEAP32[$11>>2]|0;
    __ZNSt3__213__tree_removeIPNS_16__tree_node_baseIPvEEEEvT_S5_($48,$$sroa$014$027);
    __THREW__ = 0;
    invoke_vi(4163,($12|0));
    $49 = __THREW__; __THREW__ = 0;
    $50 = $49&1;
    if ($50) {
     break L4;
    }
    __ZdlPv($$sroa$014$027);
    $$sroa$014$0$be = $$0$i$i$i$i1030;
   }
  } while(0);
  $51 = ($$sroa$014$0$be|0)==($8|0);
  if ($51) {
   label = 24;
   break;
  } else {
   $$sroa$014$027 = $$sroa$014$0$be;
  }
 }
 if ((label|0) == 24) {
  $64 = HEAP32[$2>>2]|0;
  $65 = ((($64)) + 12|0);
  $66 = HEAP32[$65>>2]|0;
  (FUNCTION_TABLE_ii[$66 & 8191]($2)|0);
  return;
 }
 $67 = ___cxa_find_matching_catch_2()|0;
 $68 = tempRet0;
 $69 = HEAP32[$2>>2]|0;
 $70 = ((($69)) + 12|0);
 $71 = HEAP32[$70>>2]|0;
 __THREW__ = 0;
 (invoke_ii($71|0,($2|0))|0);
 $72 = __THREW__; __THREW__ = 0;
 $73 = $72&1;
 if ($73) {
  $74 = ___cxa_find_matching_catch_3(0|0)|0;
  $75 = tempRet0;
  ___clang_call_terminate($74);
  // unreachable;
 } else {
  ___resumeException($67|0);
  // unreachable;
 }
}
function __ZN5osgDB11ObjectCache5clearEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 (FUNCTION_TABLE_ii[$4 & 8191]($1)|0);
 $5 = ((($0)) + 12|0);
 $6 = ((($0)) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_4pairINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7ref_ptrIKN5osgDB7OptionsEEEEENS2_INSA_INS9_6ObjectEEEdEEEENS_19__map_value_compareISF_SJ_NSB_11ObjectCache9ClassCompELb1EEENS6_ISJ_EEE7destroyEPNS_11__tree_nodeISJ_PvEE($5,$7);
 $8 = ((($0)) + 20|0);
 HEAP32[$8>>2] = 0;
 HEAP32[$5>>2] = $6;
 HEAP32[$6>>2] = 0;
 $9 = HEAP32[$1>>2]|0;
 $10 = ((($9)) + 12|0);
 $11 = HEAP32[$10>>2]|0;
 (FUNCTION_TABLE_ii[$11 & 8191]($1)|0);
 return;
}
function __ZN5osgDB7OptionsC2ERKS0_RKN3osg6CopyOpE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i$i = 0, $$0$i$i$i$i$i$i35 = 0, $$0$i$i$i$i$i39 = 0, $$08$i = 0, $$10 = 0, $$1029 = 0, $$7 = 0, $$726 = 0, $$9 = 0, $$928 = 0, $$byval_copy = 0, $$byval_copy18 = 0, $$in10$i$i = 0, $$in16$i$i = 0, $$pre$i = 0, $$pre$i$i$i$i$i$i = 0, $$pre$i$i$i$i$i$i33 = 0, $$pre9$i = 0, $10 = 0;
 var $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0;
 var $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0;
 var $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0;
 var $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0;
 var $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0;
 var $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0;
 var $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0;
 var $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0;
 var $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$i$i$i$i$i$i$index3Z2D = 0, $eh$lpad$body$i$i$i$i$i$i$indexZ2D = 0, $eh$lpad$body$i$index9Z2D = 0, $eh$lpad$body$i$indexZ2D = 0, $eh$lpad$body$i40$index14Z2D = 0;
 var $eh$lpad$body$i40$indexZ2D = 0, $scevgep$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $$byval_copy18 = sp + 28|0;
 $$byval_copy = sp + 24|0;
 $3 = sp + 20|0;
 $4 = sp + 16|0;
 $5 = sp + 12|0;
 $6 = sp + 8|0;
 $7 = sp + 4|0;
 $8 = sp;
 __ZN3osg6ObjectC2ERKS0_RKNS_6CopyOpE($0,$1,$2);
 HEAP32[$0>>2] = (37212);
 $9 = ((($0)) + 32|0);
 $10 = ((($1)) + 32|0);
 __THREW__ = 0;
 invoke_vii(3457,($9|0),($10|0));
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if ($12) {
  $214 = ___cxa_find_matching_catch_2()|0;
  $215 = tempRet0;
  $$10 = $215;$$1029 = $214;
 } else {
  $13 = ((($0)) + 44|0);
  $14 = ((($1)) + 44|0);
  __THREW__ = 0;
  invoke_vii(4168,($13|0),($14|0));
  $15 = __THREW__; __THREW__ = 0;
  $16 = $15&1;
  if ($16) {
   $216 = ___cxa_find_matching_catch_2()|0;
   $217 = tempRet0;
   $$9 = $217;$$928 = $216;
  } else {
   $17 = ((($0)) + 68|0);
   $18 = ((($1)) + 68|0);
   $19 = HEAP32[$18>>2]|0;
   HEAP32[$17>>2] = $19;
   $20 = ((($0)) + 72|0);
   $21 = ((($1)) + 72|0);
   $22 = HEAP32[$21>>2]|0;
   HEAP32[$20>>2] = $22;
   $23 = ($22|0)==(0|0);
   if (!($23)) {
    $24 = ((($22)) + 8|0);
    $25 = HEAP32[$24>>2]|0;HEAP32[$24>>2] = (($25+1)|0);
   }
   $26 = ((($0)) + 76|0);
   $27 = ((($1)) + 76|0);
   $28 = HEAP32[$27>>2]|0;
   HEAP32[$26>>2] = $28;
   $29 = ((($0)) + 80|0);
   $30 = ((($1)) + 80|0);
   $31 = HEAP32[$30>>2]|0;
   HEAP32[$29>>2] = $31;
   $32 = ((($0)) + 84|0);
   HEAP32[$32>>2] = 0;
   $33 = ((($0)) + 88|0);
   $34 = ((($0)) + 92|0);
   HEAP32[$34>>2] = 0;
   $35 = ((($0)) + 96|0);
   HEAP32[$35>>2] = 0;
   $36 = ((($0)) + 92|0);
   HEAP32[$33>>2] = $36;
   $37 = ((($1)) + 88|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = ((($1)) + 92|0);
   $40 = ($38|0)==($39|0);
   L10: do {
    if ($40) {
     label = 22;
    } else {
     $41 = $36;
     $$in10$i$i = $38;
     while(1) {
      $42 = ((($$in10$i$i)) + 16|0);
      HEAP32[$8>>2] = $41;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy>>2]=HEAP32[$8>>2]|0;
      $43 = (invoke_iiiiii(4169,($33|0),($$byval_copy|0),($6|0),($7|0),($42|0))|0);
      $44 = __THREW__; __THREW__ = 0;
      $45 = $44&1;
      if ($45) {
       label = 21;
       break;
      }
      $46 = HEAP32[$43>>2]|0;
      $47 = ($46|0)==(0|0);
      if ($47) {
       __THREW__ = 0;
       $48 = (invoke_ii(3276,32)|0);
       $49 = __THREW__; __THREW__ = 0;
       $50 = $49&1;
       if ($50) {
        label = 21;
        break;
       }
       $51 = ((($48)) + 16|0);
       __THREW__ = 0;
       invoke_vii(3457,($51|0),($42|0));
       $52 = __THREW__; __THREW__ = 0;
       $53 = $52&1;
       if ($53) {
        label = 11;
        break;
       }
       $56 = ((($48)) + 28|0);
       $57 = ((($$in10$i$i)) + 28|0);
       $58 = HEAP32[$57>>2]|0;
       HEAP32[$56>>2] = $58;
       $59 = HEAP32[$6>>2]|0;
       HEAP32[$48>>2] = 0;
       $60 = ((($48)) + 4|0);
       HEAP32[$60>>2] = 0;
       $61 = ((($48)) + 8|0);
       HEAP32[$61>>2] = $59;
       HEAP32[$43>>2] = $48;
       $62 = HEAP32[$33>>2]|0;
       $63 = HEAP32[$62>>2]|0;
       $64 = ($63|0)==(0|0);
       if ($64) {
        $67 = $48;
       } else {
        $65 = $63;
        HEAP32[$33>>2] = $65;
        $$pre$i$i$i$i$i$i = HEAP32[$43>>2]|0;
        $67 = $$pre$i$i$i$i$i$i;
       }
       $66 = HEAP32[$34>>2]|0;
       __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($66,$67);
       $68 = HEAP32[$35>>2]|0;
       $69 = (($68) + 1)|0;
       HEAP32[$35>>2] = $69;
      }
      $70 = ((($$in10$i$i)) + 4|0);
      $71 = HEAP32[$70>>2]|0;
      $72 = ($71|0)==(0|0);
      if ($72) {
       $73 = ((($$in10$i$i)) + 8|0);
       $74 = HEAP32[$73>>2]|0;
       $75 = HEAP32[$74>>2]|0;
       $76 = ($75|0)==($$in10$i$i|0);
       if ($76) {
        $$0$i$i$i$i$i = $74;
       } else {
        $80 = $73;
        while(1) {
         $79 = HEAP32[$80>>2]|0;
         $81 = ((($79)) + 8|0);
         $82 = HEAP32[$81>>2]|0;
         $83 = HEAP32[$82>>2]|0;
         $84 = ($83|0)==($79|0);
         if ($84) {
          $$0$i$i$i$i$i = $82;
          break;
         } else {
          $80 = $81;
         }
        }
       }
      } else {
       $$0$i$i$i$i$i$i = $71;
       while(1) {
        $77 = HEAP32[$$0$i$i$i$i$i$i>>2]|0;
        $78 = ($77|0)==(0|0);
        if ($78) {
         break;
        } else {
         $$0$i$i$i$i$i$i = $77;
        }
       }
       $$0$i$i$i$i$i = $$0$i$i$i$i$i$i;
      }
      $85 = ($$0$i$i$i$i$i|0)==($39|0);
      if ($85) {
       label = 22;
       break L10;
      } else {
       $$in10$i$i = $$0$i$i$i$i$i;
      }
     }
     if ((label|0) == 11) {
      $54 = ___cxa_find_matching_catch_2()|0;
      $55 = tempRet0;
      __ZdlPv($48);
      $eh$lpad$body$i$index9Z2D = $55;$eh$lpad$body$i$indexZ2D = $54;
     }
     else if ((label|0) == 21) {
      $86 = ___cxa_find_matching_catch_2()|0;
      $87 = tempRet0;
      $eh$lpad$body$i$index9Z2D = $87;$eh$lpad$body$i$indexZ2D = $86;
     }
     $218 = HEAP32[$36>>2]|0;
     __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPvEENS_19__map_value_compareIS7_S9_NS_4lessIS7_EELb1EEENS5_IS9_EEE7destroyEPNS_11__tree_nodeIS9_S8_EE($33,$218);
     $$7 = $eh$lpad$body$i$index9Z2D;$$726 = $eh$lpad$body$i$indexZ2D;
    }
   } while(0);
   L35: do {
    if ((label|0) == 22) {
     $88 = ((($0)) + 100|0);
     $89 = ((($0)) + 104|0);
     HEAP32[$89>>2] = 0;
     $90 = ((($0)) + 108|0);
     HEAP32[$90>>2] = 0;
     $91 = ((($0)) + 104|0);
     HEAP32[$88>>2] = $91;
     $92 = ((($1)) + 100|0);
     $93 = HEAP32[$92>>2]|0;
     $94 = ((($1)) + 104|0);
     $95 = ($93|0)==($94|0);
     L37: do {
      if (!($95)) {
       $96 = $91;
       $$in16$i$i = $93;
       while(1) {
        $97 = ((($$in16$i$i)) + 16|0);
        HEAP32[$5>>2] = $96;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy18>>2]=HEAP32[$5>>2]|0;
        $98 = (invoke_iiiiii(4170,($88|0),($$byval_copy18|0),($3|0),($4|0),($97|0))|0);
        $99 = __THREW__; __THREW__ = 0;
        $100 = $99&1;
        if ($100) {
         label = 42;
         break;
        }
        $101 = HEAP32[$98>>2]|0;
        $102 = ($101|0)==(0|0);
        if ($102) {
         __THREW__ = 0;
         $103 = (invoke_ii(3276,40)|0);
         $104 = __THREW__; __THREW__ = 0;
         $105 = $104&1;
         if ($105) {
          label = 42;
          break;
         }
         $106 = ((($103)) + 16|0);
         __THREW__ = 0;
         invoke_vii(3457,($106|0),($97|0));
         $107 = __THREW__; __THREW__ = 0;
         $108 = $107&1;
         if ($108) {
          label = 31;
          break;
         }
         $109 = ((($103)) + 28|0);
         $110 = ((($$in16$i$i)) + 28|0);
         __THREW__ = 0;
         invoke_vii(3457,($109|0),($110|0));
         $111 = __THREW__; __THREW__ = 0;
         $112 = $111&1;
         if ($112) {
          label = 29;
          break;
         }
         $121 = HEAP32[$3>>2]|0;
         HEAP32[$103>>2] = 0;
         $122 = ((($103)) + 4|0);
         HEAP32[$122>>2] = 0;
         $123 = ((($103)) + 8|0);
         HEAP32[$123>>2] = $121;
         HEAP32[$98>>2] = $103;
         $124 = HEAP32[$88>>2]|0;
         $125 = HEAP32[$124>>2]|0;
         $126 = ($125|0)==(0|0);
         if ($126) {
          $129 = $103;
         } else {
          $127 = $125;
          HEAP32[$88>>2] = $127;
          $$pre$i$i$i$i$i$i33 = HEAP32[$98>>2]|0;
          $129 = $$pre$i$i$i$i$i$i33;
         }
         $128 = HEAP32[$89>>2]|0;
         __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($128,$129);
         $130 = HEAP32[$90>>2]|0;
         $131 = (($130) + 1)|0;
         HEAP32[$90>>2] = $131;
        }
        $132 = ((($$in16$i$i)) + 4|0);
        $133 = HEAP32[$132>>2]|0;
        $134 = ($133|0)==(0|0);
        if ($134) {
         $135 = ((($$in16$i$i)) + 8|0);
         $136 = HEAP32[$135>>2]|0;
         $137 = HEAP32[$136>>2]|0;
         $138 = ($137|0)==($$in16$i$i|0);
         if ($138) {
          $$0$i$i$i$i$i39 = $136;
         } else {
          $142 = $135;
          while(1) {
           $141 = HEAP32[$142>>2]|0;
           $143 = ((($141)) + 8|0);
           $144 = HEAP32[$143>>2]|0;
           $145 = HEAP32[$144>>2]|0;
           $146 = ($145|0)==($141|0);
           if ($146) {
            $$0$i$i$i$i$i39 = $144;
            break;
           } else {
            $142 = $143;
           }
          }
         }
        } else {
         $$0$i$i$i$i$i$i35 = $133;
         while(1) {
          $139 = HEAP32[$$0$i$i$i$i$i$i35>>2]|0;
          $140 = ($139|0)==(0|0);
          if ($140) {
           break;
          } else {
           $$0$i$i$i$i$i$i35 = $139;
          }
         }
         $$0$i$i$i$i$i39 = $$0$i$i$i$i$i$i35;
        }
        $147 = ($$0$i$i$i$i$i39|0)==($94|0);
        if ($147) {
         break L37;
        } else {
         $$in16$i$i = $$0$i$i$i$i$i39;
        }
       }
       if ((label|0) == 29) {
        $113 = ___cxa_find_matching_catch_2()|0;
        $114 = tempRet0;
        $115 = ((($103)) + 27|0);
        $116 = HEAP8[$115>>0]|0;
        $117 = ($116<<24>>24)<(0);
        if ($117) {
         $118 = HEAP32[$106>>2]|0;
         __ZdlPv($118);
         $eh$lpad$body$i$i$i$i$i$i$index3Z2D = $114;$eh$lpad$body$i$i$i$i$i$i$indexZ2D = $113;
         label = 32;
        } else {
         $eh$lpad$body$i$i$i$i$i$i$index3Z2D = $114;$eh$lpad$body$i$i$i$i$i$i$indexZ2D = $113;
         label = 32;
        }
       }
       else if ((label|0) == 31) {
        $119 = ___cxa_find_matching_catch_2()|0;
        $120 = tempRet0;
        $eh$lpad$body$i$i$i$i$i$i$index3Z2D = $120;$eh$lpad$body$i$i$i$i$i$i$indexZ2D = $119;
        label = 32;
       }
       else if ((label|0) == 42) {
        $148 = ___cxa_find_matching_catch_2()|0;
        $149 = tempRet0;
        $eh$lpad$body$i40$index14Z2D = $149;$eh$lpad$body$i40$indexZ2D = $148;
       }
       if ((label|0) == 32) {
        __ZdlPv($103);
        $eh$lpad$body$i40$index14Z2D = $eh$lpad$body$i$i$i$i$i$i$index3Z2D;$eh$lpad$body$i40$indexZ2D = $eh$lpad$body$i$i$i$i$i$i$indexZ2D;
       }
       $219 = HEAP32[$91>>2]|0;
       __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES7_EENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($88,$219);
       $220 = HEAP32[$36>>2]|0;
       __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPvEENS_19__map_value_compareIS7_S9_NS_4lessIS7_EELb1EEENS5_IS9_EEE7destroyEPNS_11__tree_nodeIS9_S8_EE($33,$220);
       $$7 = $eh$lpad$body$i40$index14Z2D;$$726 = $eh$lpad$body$i40$indexZ2D;
       break L35;
      }
     } while(0);
     $150 = ((($0)) + 112|0);
     $151 = ((($1)) + 112|0);
     $152 = HEAP32[$151>>2]|0;
     HEAP32[$150>>2] = $152;
     $153 = ($152|0)==(0|0);
     if (!($153)) {
      $154 = HEAP32[$152>>2]|0;
      $155 = ((($154)) + -12|0);
      $156 = HEAP32[$155>>2]|0;
      $157 = (($152) + ($156)|0);
      $158 = ((($157)) + 8|0);
      $159 = HEAP32[$158>>2]|0;HEAP32[$158>>2] = (($159+1)|0);
     }
     $160 = ((($0)) + 116|0);
     $161 = ((($1)) + 116|0);
     $162 = HEAP32[$161>>2]|0;
     HEAP32[$160>>2] = $162;
     $163 = ($162|0)==(0|0);
     if (!($163)) {
      $164 = HEAP32[$162>>2]|0;
      $165 = ((($164)) + -12|0);
      $166 = HEAP32[$165>>2]|0;
      $167 = (($162) + ($166)|0);
      $168 = ((($167)) + 8|0);
      $169 = HEAP32[$168>>2]|0;HEAP32[$168>>2] = (($169+1)|0);
     }
     $170 = ((($0)) + 120|0);
     $171 = ((($1)) + 120|0);
     $172 = HEAP32[$171>>2]|0;
     HEAP32[$170>>2] = $172;
     $173 = ($172|0)==(0|0);
     if (!($173)) {
      $174 = HEAP32[$172>>2]|0;
      $175 = ((($174)) + -12|0);
      $176 = HEAP32[$175>>2]|0;
      $177 = (($172) + ($176)|0);
      $178 = ((($177)) + 8|0);
      $179 = HEAP32[$178>>2]|0;HEAP32[$178>>2] = (($179+1)|0);
     }
     $180 = ((($0)) + 124|0);
     $181 = ((($1)) + 124|0);
     $182 = HEAP32[$181>>2]|0;
     HEAP32[$180>>2] = $182;
     $183 = ($182|0)==(0|0);
     if (!($183)) {
      $184 = HEAP32[$182>>2]|0;
      $185 = ((($184)) + -12|0);
      $186 = HEAP32[$185>>2]|0;
      $187 = (($182) + ($186)|0);
      $188 = ((($187)) + 8|0);
      $189 = HEAP32[$188>>2]|0;HEAP32[$188>>2] = (($189+1)|0);
     }
     $190 = ((($0)) + 128|0);
     $191 = ((($1)) + 128|0);
     $192 = HEAP32[$191>>2]|0;
     HEAP32[$190>>2] = $192;
     $193 = ($192|0)==(0|0);
     if (!($193)) {
      $194 = ((($192)) + 8|0);
      $195 = HEAP32[$194>>2]|0;HEAP32[$194>>2] = (($195+1)|0);
     }
     $196 = ((($0)) + 132|0);
     $197 = ((($1)) + 132|0);
     $198 = HEAP32[$197>>2]|0;
     HEAP32[$196>>2] = $198;
     $199 = ($198|0)==(0|0);
     if (!($199)) {
      $200 = ((($198)) + 8|0);
      $201 = HEAP32[$200>>2]|0;HEAP32[$200>>2] = (($201+1)|0);
     }
     $202 = ((($0)) + 136|0);
     $203 = ((($1)) + 136|0);
     $204 = HEAP32[$203>>2]|0;
     HEAP32[$202>>2] = $204;
     $205 = ((($0)) + 140|0);
     $206 = ((($1)) + 140|0);
     $207 = HEAP32[$206>>2]|0;
     HEAP32[$205>>2] = $207;
     $208 = ($207|0)==(0|0);
     if ($208) {
      $211 = ((($0)) + 144|0);
      $212 = ((($1)) + 144|0);
      $213 = HEAP32[$212>>2]|0;
      HEAP32[$211>>2] = $213;
      STACKTOP = sp;return;
     }
     $209 = ((($207)) + 8|0);
     $210 = HEAP32[$209>>2]|0;HEAP32[$209>>2] = (($210+1)|0);
     $211 = ((($0)) + 144|0);
     $212 = ((($1)) + 144|0);
     $213 = HEAP32[$212>>2]|0;
     HEAP32[$211>>2] = $213;
     STACKTOP = sp;return;
    }
   } while(0);
   $221 = HEAP32[$32>>2]|0;
   $222 = ($221|0)==(0|0);
   if (!($222)) {
    $223 = ((($221)) + 8|0);
    $224 = HEAP32[$223>>2]|0;HEAP32[$223>>2] = (($224-1)|0);
    $225 = ($224|0)==(1);
    if ($225) {
     __THREW__ = 0;
     invoke_viii(3262,($221|0),1,1);
     $226 = __THREW__; __THREW__ = 0;
     $227 = $226&1;
     if ($227) {
      $257 = ___cxa_find_matching_catch_3(0|0)|0;
      $258 = tempRet0;
      ___clang_call_terminate($257);
      // unreachable;
     }
    }
   }
   HEAP32[$32>>2] = 0;
   $228 = HEAP32[$20>>2]|0;
   $229 = ($228|0)==(0|0);
   if (!($229)) {
    $230 = ((($228)) + 8|0);
    $231 = HEAP32[$230>>2]|0;HEAP32[$230>>2] = (($231-1)|0);
    $232 = ($231|0)==(1);
    if ($232) {
     __THREW__ = 0;
     invoke_viii(3262,($228|0),1,1);
     $233 = __THREW__; __THREW__ = 0;
     $234 = $233&1;
     if ($234) {
      $257 = ___cxa_find_matching_catch_3(0|0)|0;
      $258 = tempRet0;
      ___clang_call_terminate($257);
      // unreachable;
     }
    }
   }
   HEAP32[$20>>2] = 0;
   __ZNSt3__212__deque_baseINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS4_IS6_EEE5clearEv($13);
   $235 = ((($0)) + 48|0);
   $236 = HEAP32[$235>>2]|0;
   $237 = ((($0)) + 52|0);
   $238 = HEAP32[$237>>2]|0;
   $239 = ($236|0)==($238|0);
   if (!($239)) {
    $$08$i = $236;
    while(1) {
     $240 = HEAP32[$$08$i>>2]|0;
     __ZdlPv($240);
     $241 = ((($$08$i)) + 4|0);
     $242 = ($241|0)==($238|0);
     if ($242) {
      break;
     } else {
      $$08$i = $241;
     }
    }
    $$pre$i = HEAP32[$235>>2]|0;
    $$pre9$i = HEAP32[$237>>2]|0;
    $243 = ($$pre9$i|0)==($$pre$i|0);
    if (!($243)) {
     $scevgep$i$i$i$i$i = ((($$pre9$i)) + -4|0);
     $244 = $scevgep$i$i$i$i$i;
     $245 = $$pre$i;
     $246 = (($244) - ($245))|0;
     $247 = $246 >>> 2;
     $248 = $247 ^ -1;
     $scevgep5$i$i$i$i$i = (($$pre9$i) + ($248<<2)|0);
     HEAP32[$237>>2] = $scevgep5$i$i$i$i$i;
    }
   }
   $249 = HEAP32[$13>>2]|0;
   $250 = ($249|0)==(0|0);
   if ($250) {
    $$9 = $$7;$$928 = $$726;
   } else {
    __ZdlPv($249);
    $$9 = $$7;$$928 = $$726;
   }
  }
  $251 = ((($9)) + 11|0);
  $252 = HEAP8[$251>>0]|0;
  $253 = ($252<<24>>24)<(0);
  if ($253) {
   $254 = HEAP32[$9>>2]|0;
   __ZdlPv($254);
   $$10 = $$9;$$1029 = $$928;
  } else {
   $$10 = $$9;$$1029 = $$928;
  }
 }
 __THREW__ = 0;
 invoke_vi(388,($0|0));
 $255 = __THREW__; __THREW__ = 0;
 $256 = $255&1;
 if ($256) {
  $257 = ___cxa_find_matching_catch_3(0|0)|0;
  $258 = tempRet0;
  ___clang_call_terminate($257);
  // unreachable;
 } else {
  ___resumeException($$1029|0);
  // unreachable;
 }
}
function __ZNSt3__25dequeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS4_IS6_EEEC2ERKS8_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$08$i = 0, $$byval_copy = 0, $$byval_copy1 = 0, $$pre$i = 0, $$pre9$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $$byval_copy1 = sp + 24|0;
 $$byval_copy = sp + 16|0;
 $2 = sp + 8|0;
 $3 = sp;
 ;HEAP32[$0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;HEAP32[$0+16>>2]=0|0;HEAP32[$0+20>>2]=0|0;
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($1)) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7>>>0) / 341)&-1;
 $9 = (($5) + ($8<<2)|0);
 $10 = ((($1)) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==($5|0);
 if ($12) {
  $17 = 0;
 } else {
  $13 = HEAP32[$9>>2]|0;
  $14 = (($7>>>0) % 341)&-1;
  $15 = (($13) + (($14*12)|0)|0);
  $17 = $15;
 }
 HEAP32[$2>>2] = $9;
 $16 = ((($2)) + 4|0);
 HEAP32[$16>>2] = $17;
 $18 = ((($1)) + 20|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($7) + ($19))|0;
 $21 = (($20>>>0) / 341)&-1;
 $22 = (($5) + ($21<<2)|0);
 if ($12) {
  $27 = 0;
 } else {
  $23 = HEAP32[$22>>2]|0;
  $24 = (($20>>>0) % 341)&-1;
  $25 = (($23) + (($24*12)|0)|0);
  $27 = $25;
 }
 HEAP32[$3>>2] = $22;
 $26 = ((($3)) + 4|0);
 HEAP32[$26>>2] = $27;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$2>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$2+4>>2]|0;
 ;HEAP32[$$byval_copy1>>2]=HEAP32[$3>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$3+4>>2]|0;
 invoke_viiii(4171,($0|0),($$byval_copy|0),($$byval_copy1|0),(0|0));
 $28 = __THREW__; __THREW__ = 0;
 $29 = $28&1;
 if (!($29)) {
  STACKTOP = sp;return;
 }
 $30 = ___cxa_find_matching_catch_2()|0;
 $31 = tempRet0;
 __ZNSt3__212__deque_baseINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS4_IS6_EEE5clearEv($0);
 $32 = ((($0)) + 4|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ((($0)) + 8|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = ($33|0)==($35|0);
 if (!($36)) {
  $$08$i = $33;
  while(1) {
   $37 = HEAP32[$$08$i>>2]|0;
   __ZdlPv($37);
   $38 = ((($$08$i)) + 4|0);
   $39 = ($38|0)==($35|0);
   if ($39) {
    break;
   } else {
    $$08$i = $38;
   }
  }
  $$pre$i = HEAP32[$32>>2]|0;
  $$pre9$i = HEAP32[$34>>2]|0;
  $40 = ($$pre9$i|0)==($$pre$i|0);
  if (!($40)) {
   $scevgep$i$i$i$i$i = ((($$pre9$i)) + -4|0);
   $41 = $scevgep$i$i$i$i$i;
   $42 = $$pre$i;
   $43 = (($41) - ($42))|0;
   $44 = $43 >>> 2;
   $45 = $44 ^ -1;
   $scevgep5$i$i$i$i$i = (($$pre9$i) + ($45<<2)|0);
   HEAP32[$34>>2] = $scevgep5$i$i$i$i$i;
  }
 }
 $46 = HEAP32[$0>>2]|0;
 $47 = ($46|0)==(0|0);
 if ($47) {
  ___resumeException($30|0);
  // unreachable;
 }
 __ZdlPv($46);
 ___resumeException($30|0);
 // unreachable;
}
function __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPvEENS_19__map_value_compareIS7_S9_NS_4lessIS7_EELb1EEENS5_IS9_EEE12__find_equalIS7_EERPNS_16__tree_node_baseIS8_EENS_21__tree_const_iteratorIS9_PNS_11__tree_nodeIS9_S8_EEiEERPNS_15__tree_end_nodeISJ_EESK_RKT_($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0$i$i = 0, $$0$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i$i = 0, $$08$i$i = 0, $$2 = 0, $$pre = 0, $$sroa$052$0 = 0, $$sroa$speculated$i$i$i$i$i = 0, $$sroa$speculated$i$i$i$i$i21 = 0, $$sroa$speculated$i$i$i$i$i26 = 0, $$sroa$speculated$i$i$i$i$i32 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = ((($0)) + 4|0);
 $6 = HEAP32[$1>>2]|0;
 $7 = ($6|0)==($5|0);
 $8 = $6;
 do {
  if (!($7)) {
   $9 = ((($6)) + 16|0);
   $10 = ((($9)) + 11|0);
   $11 = HEAP8[$10>>0]|0;
   $12 = ($11<<24>>24)<(0);
   $13 = ((($6)) + 20|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = $11&255;
   $16 = $12 ? $14 : $15;
   $17 = ((($4)) + 11|0);
   $18 = HEAP8[$17>>0]|0;
   $19 = ($18<<24>>24)<(0);
   $20 = ((($4)) + 4|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = $18&255;
   $23 = $19 ? $21 : $22;
   $24 = ($16>>>0)<($23>>>0);
   $$sroa$speculated$i$i$i$i$i32 = $24 ? $16 : $23;
   $25 = ($$sroa$speculated$i$i$i$i$i32|0)==(0);
   if ($25) {
    label = 4;
   } else {
    $26 = HEAP32[$4>>2]|0;
    $27 = $19 ? $26 : $4;
    $28 = HEAP32[$9>>2]|0;
    $29 = $12 ? $28 : $9;
    $30 = (_memcmp($27,$29,$$sroa$speculated$i$i$i$i$i32)|0);
    $31 = ($30|0)==(0);
    if ($31) {
     label = 4;
    } else {
     $33 = ($30|0)<(0);
     if ($33) {
      break;
     }
    }
   }
   if ((label|0) == 4) {
    $32 = ($23>>>0)<($16>>>0);
    if ($32) {
     break;
    }
   }
   $74 = ($23>>>0)<($16>>>0);
   $$sroa$speculated$i$i$i$i$i21 = $74 ? $23 : $16;
   $75 = ($$sroa$speculated$i$i$i$i$i21|0)==(0);
   if ($75) {
    label = 20;
   } else {
    $76 = HEAP32[$9>>2]|0;
    $77 = $12 ? $76 : $9;
    $78 = HEAP32[$4>>2]|0;
    $79 = $19 ? $78 : $4;
    $80 = (_memcmp($77,$79,$$sroa$speculated$i$i$i$i$i21)|0);
    $81 = ($80|0)==(0);
    if ($81) {
     label = 20;
    } else {
     $82 = ($80|0)<(0);
     if (!($82)) {
      label = 36;
     }
    }
   }
   if ((label|0) == 20) {
    if (!($24)) {
     label = 36;
    }
   }
   if ((label|0) == 36) {
    HEAP32[$2>>2] = $8;
    HEAP32[$3>>2] = $8;
    $$2 = $3;
    return ($$2|0);
   }
   $83 = ((($6)) + 4|0);
   $84 = HEAP32[$83>>2]|0;
   $85 = ($84|0)==(0|0);
   if ($85) {
    $86 = ((($6)) + 8|0);
    $87 = HEAP32[$86>>2]|0;
    $88 = HEAP32[$87>>2]|0;
    $89 = ($88|0)==($6|0);
    if ($89) {
     $$0$i$i$i$i$i = $87;
    } else {
     $93 = $86;
     while(1) {
      $92 = HEAP32[$93>>2]|0;
      $94 = ((($92)) + 8|0);
      $95 = HEAP32[$94>>2]|0;
      $96 = HEAP32[$95>>2]|0;
      $97 = ($96|0)==($92|0);
      if ($97) {
       $$0$i$i$i$i$i = $95;
       break;
      } else {
       $93 = $94;
      }
     }
    }
   } else {
    $$0$i$i$i$i$i$i = $84;
    while(1) {
     $90 = HEAP32[$$0$i$i$i$i$i$i>>2]|0;
     $91 = ($90|0)==(0|0);
     if ($91) {
      break;
     } else {
      $$0$i$i$i$i$i$i = $90;
     }
    }
    $$0$i$i$i$i$i = $$0$i$i$i$i$i$i;
   }
   $98 = ($$0$i$i$i$i$i|0)==($5|0);
   do {
    if (!($98)) {
     $99 = ((($$0$i$i$i$i$i)) + 16|0);
     $100 = ((($99)) + 11|0);
     $101 = HEAP8[$100>>0]|0;
     $102 = ($101<<24>>24)<(0);
     $103 = ((($$0$i$i$i$i$i)) + 20|0);
     $104 = HEAP32[$103>>2]|0;
     $105 = $101&255;
     $106 = $102 ? $104 : $105;
     $107 = ($106>>>0)<($23>>>0);
     $$sroa$speculated$i$i$i$i$i = $107 ? $106 : $23;
     $108 = ($$sroa$speculated$i$i$i$i$i|0)==(0);
     if ($108) {
      label = 30;
     } else {
      $109 = HEAP32[$4>>2]|0;
      $110 = $19 ? $109 : $4;
      $111 = HEAP32[$99>>2]|0;
      $112 = $102 ? $111 : $99;
      $113 = (_memcmp($110,$112,$$sroa$speculated$i$i$i$i$i)|0);
      $114 = ($113|0)==(0);
      if ($114) {
       label = 30;
      } else {
       $116 = ($113|0)<(0);
       if ($116) {
        break;
       }
      }
     }
     if ((label|0) == 30) {
      $115 = ($23>>>0)<($106>>>0);
      if ($115) {
       break;
      }
     }
     $120 = (__ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPvEENS_19__map_value_compareIS7_S9_NS_4lessIS7_EELb1EEENS5_IS9_EEE12__find_equalIS7_EERPNS_16__tree_node_baseIS8_EERPNS_15__tree_end_nodeISJ_EERKT_($0,$2,$4)|0);
     $$2 = $120;
     return ($$2|0);
    }
   } while(0);
   $117 = ((($6)) + 4|0);
   $118 = HEAP32[$117>>2]|0;
   $119 = ($118|0)==(0|0);
   if ($119) {
    HEAP32[$2>>2] = $8;
    $$2 = $83;
    return ($$2|0);
   } else {
    HEAP32[$2>>2] = $$0$i$i$i$i$i;
    $$2 = $$0$i$i$i$i$i;
    return ($$2|0);
   }
  }
 } while(0);
 $34 = HEAP32[$0>>2]|0;
 $35 = ($6|0)==($34|0);
 $$pre = HEAP32[$6>>2]|0;
 do {
  if ($35) {
   $$sroa$052$0 = $8;
  } else {
   $36 = ($$pre|0)==(0|0);
   if ($36) {
    $$0$i$i = $6;
    while(1) {
     $40 = ((($$0$i$i)) + 8|0);
     $41 = HEAP32[$40>>2]|0;
     $42 = HEAP32[$41>>2]|0;
     $43 = ($42|0)==($$0$i$i|0);
     if ($43) {
      $$0$i$i = $41;
     } else {
      $$08$i$i = $41;
      break;
     }
    }
   } else {
    $$0$i$i$i = $$pre;
    while(1) {
     $37 = ((($$0$i$i$i)) + 4|0);
     $38 = HEAP32[$37>>2]|0;
     $39 = ($38|0)==(0|0);
     if ($39) {
      $$08$i$i = $$0$i$i$i;
      break;
     } else {
      $$0$i$i$i = $38;
     }
    }
   }
   $44 = $$08$i$i;
   $45 = ((($$08$i$i)) + 16|0);
   $46 = ((($4)) + 11|0);
   $47 = HEAP8[$46>>0]|0;
   $48 = ($47<<24>>24)<(0);
   $49 = ((($4)) + 4|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = $47&255;
   $52 = $48 ? $50 : $51;
   $53 = ((($45)) + 11|0);
   $54 = HEAP8[$53>>0]|0;
   $55 = ($54<<24>>24)<(0);
   $56 = ((($$08$i$i)) + 20|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = $54&255;
   $59 = $55 ? $57 : $58;
   $60 = ($52>>>0)<($59>>>0);
   $$sroa$speculated$i$i$i$i$i26 = $60 ? $52 : $59;
   $61 = ($$sroa$speculated$i$i$i$i$i26|0)==(0);
   if ($61) {
    label = 12;
   } else {
    $62 = HEAP32[$45>>2]|0;
    $63 = $55 ? $62 : $45;
    $64 = HEAP32[$4>>2]|0;
    $65 = $48 ? $64 : $4;
    $66 = (_memcmp($63,$65,$$sroa$speculated$i$i$i$i$i26)|0);
    $67 = ($66|0)==(0);
    if ($67) {
     label = 12;
    } else {
     $69 = ($66|0)<(0);
     if ($69) {
      $$sroa$052$0 = $44;
      break;
     }
    }
   }
   if ((label|0) == 12) {
    $68 = ($59>>>0)<($52>>>0);
    if ($68) {
     $$sroa$052$0 = $44;
     break;
    }
   }
   $73 = (__ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPvEENS_19__map_value_compareIS7_S9_NS_4lessIS7_EELb1EEENS5_IS9_EEE12__find_equalIS7_EERPNS_16__tree_node_baseIS8_EERPNS_15__tree_end_nodeISJ_EERKT_($0,$2,$4)|0);
   $$2 = $73;
   return ($$2|0);
  }
 } while(0);
 $70 = ($$pre|0)==(0|0);
 if ($70) {
  HEAP32[$2>>2] = $6;
  $$2 = $6;
  return ($$2|0);
 } else {
  $71 = $$sroa$052$0;
  HEAP32[$2>>2] = $71;
  $72 = ((($71)) + 4|0);
  $$2 = $72;
  return ($$2|0);
 }
 return (0)|0;
}
function __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES7_EENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE12__find_equalIS7_EERPNS_16__tree_node_baseIPvEENS_21__tree_const_iteratorIS8_PNS_11__tree_nodeIS8_SH_EEiEERPNS_15__tree_end_nodeISJ_EESK_RKT_($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0$i$i = 0, $$0$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i$i = 0, $$08$i$i = 0, $$2 = 0, $$pre = 0, $$sroa$052$0 = 0, $$sroa$speculated$i$i$i$i$i = 0, $$sroa$speculated$i$i$i$i$i21 = 0, $$sroa$speculated$i$i$i$i$i26 = 0, $$sroa$speculated$i$i$i$i$i32 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = ((($0)) + 4|0);
 $6 = HEAP32[$1>>2]|0;
 $7 = ($6|0)==($5|0);
 $8 = $6;
 do {
  if (!($7)) {
   $9 = ((($6)) + 16|0);
   $10 = ((($9)) + 11|0);
   $11 = HEAP8[$10>>0]|0;
   $12 = ($11<<24>>24)<(0);
   $13 = ((($6)) + 20|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = $11&255;
   $16 = $12 ? $14 : $15;
   $17 = ((($4)) + 11|0);
   $18 = HEAP8[$17>>0]|0;
   $19 = ($18<<24>>24)<(0);
   $20 = ((($4)) + 4|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = $18&255;
   $23 = $19 ? $21 : $22;
   $24 = ($16>>>0)<($23>>>0);
   $$sroa$speculated$i$i$i$i$i32 = $24 ? $16 : $23;
   $25 = ($$sroa$speculated$i$i$i$i$i32|0)==(0);
   if ($25) {
    label = 4;
   } else {
    $26 = HEAP32[$4>>2]|0;
    $27 = $19 ? $26 : $4;
    $28 = HEAP32[$9>>2]|0;
    $29 = $12 ? $28 : $9;
    $30 = (_memcmp($27,$29,$$sroa$speculated$i$i$i$i$i32)|0);
    $31 = ($30|0)==(0);
    if ($31) {
     label = 4;
    } else {
     $33 = ($30|0)<(0);
     if ($33) {
      break;
     }
    }
   }
   if ((label|0) == 4) {
    $32 = ($23>>>0)<($16>>>0);
    if ($32) {
     break;
    }
   }
   $74 = ($23>>>0)<($16>>>0);
   $$sroa$speculated$i$i$i$i$i21 = $74 ? $23 : $16;
   $75 = ($$sroa$speculated$i$i$i$i$i21|0)==(0);
   if ($75) {
    label = 20;
   } else {
    $76 = HEAP32[$9>>2]|0;
    $77 = $12 ? $76 : $9;
    $78 = HEAP32[$4>>2]|0;
    $79 = $19 ? $78 : $4;
    $80 = (_memcmp($77,$79,$$sroa$speculated$i$i$i$i$i21)|0);
    $81 = ($80|0)==(0);
    if ($81) {
     label = 20;
    } else {
     $82 = ($80|0)<(0);
     if (!($82)) {
      label = 36;
     }
    }
   }
   if ((label|0) == 20) {
    if (!($24)) {
     label = 36;
    }
   }
   if ((label|0) == 36) {
    HEAP32[$2>>2] = $8;
    HEAP32[$3>>2] = $8;
    $$2 = $3;
    return ($$2|0);
   }
   $83 = ((($6)) + 4|0);
   $84 = HEAP32[$83>>2]|0;
   $85 = ($84|0)==(0|0);
   if ($85) {
    $86 = ((($6)) + 8|0);
    $87 = HEAP32[$86>>2]|0;
    $88 = HEAP32[$87>>2]|0;
    $89 = ($88|0)==($6|0);
    if ($89) {
     $$0$i$i$i$i$i = $87;
    } else {
     $93 = $86;
     while(1) {
      $92 = HEAP32[$93>>2]|0;
      $94 = ((($92)) + 8|0);
      $95 = HEAP32[$94>>2]|0;
      $96 = HEAP32[$95>>2]|0;
      $97 = ($96|0)==($92|0);
      if ($97) {
       $$0$i$i$i$i$i = $95;
       break;
      } else {
       $93 = $94;
      }
     }
    }
   } else {
    $$0$i$i$i$i$i$i = $84;
    while(1) {
     $90 = HEAP32[$$0$i$i$i$i$i$i>>2]|0;
     $91 = ($90|0)==(0|0);
     if ($91) {
      break;
     } else {
      $$0$i$i$i$i$i$i = $90;
     }
    }
    $$0$i$i$i$i$i = $$0$i$i$i$i$i$i;
   }
   $98 = ($$0$i$i$i$i$i|0)==($5|0);
   do {
    if (!($98)) {
     $99 = ((($$0$i$i$i$i$i)) + 16|0);
     $100 = ((($99)) + 11|0);
     $101 = HEAP8[$100>>0]|0;
     $102 = ($101<<24>>24)<(0);
     $103 = ((($$0$i$i$i$i$i)) + 20|0);
     $104 = HEAP32[$103>>2]|0;
     $105 = $101&255;
     $106 = $102 ? $104 : $105;
     $107 = ($106>>>0)<($23>>>0);
     $$sroa$speculated$i$i$i$i$i = $107 ? $106 : $23;
     $108 = ($$sroa$speculated$i$i$i$i$i|0)==(0);
     if ($108) {
      label = 30;
     } else {
      $109 = HEAP32[$4>>2]|0;
      $110 = $19 ? $109 : $4;
      $111 = HEAP32[$99>>2]|0;
      $112 = $102 ? $111 : $99;
      $113 = (_memcmp($110,$112,$$sroa$speculated$i$i$i$i$i)|0);
      $114 = ($113|0)==(0);
      if ($114) {
       label = 30;
      } else {
       $116 = ($113|0)<(0);
       if ($116) {
        break;
       }
      }
     }
     if ((label|0) == 30) {
      $115 = ($23>>>0)<($106>>>0);
      if ($115) {
       break;
      }
     }
     $120 = (__ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES7_EENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE12__find_equalIS7_EERPNS_16__tree_node_baseIPvEERPNS_15__tree_end_nodeISJ_EERKT_($0,$2,$4)|0);
     $$2 = $120;
     return ($$2|0);
    }
   } while(0);
   $117 = ((($6)) + 4|0);
   $118 = HEAP32[$117>>2]|0;
   $119 = ($118|0)==(0|0);
   if ($119) {
    HEAP32[$2>>2] = $8;
    $$2 = $83;
    return ($$2|0);
   } else {
    HEAP32[$2>>2] = $$0$i$i$i$i$i;
    $$2 = $$0$i$i$i$i$i;
    return ($$2|0);
   }
  }
 } while(0);
 $34 = HEAP32[$0>>2]|0;
 $35 = ($6|0)==($34|0);
 $$pre = HEAP32[$6>>2]|0;
 do {
  if ($35) {
   $$sroa$052$0 = $8;
  } else {
   $36 = ($$pre|0)==(0|0);
   if ($36) {
    $$0$i$i = $6;
    while(1) {
     $40 = ((($$0$i$i)) + 8|0);
     $41 = HEAP32[$40>>2]|0;
     $42 = HEAP32[$41>>2]|0;
     $43 = ($42|0)==($$0$i$i|0);
     if ($43) {
      $$0$i$i = $41;
     } else {
      $$08$i$i = $41;
      break;
     }
    }
   } else {
    $$0$i$i$i = $$pre;
    while(1) {
     $37 = ((($$0$i$i$i)) + 4|0);
     $38 = HEAP32[$37>>2]|0;
     $39 = ($38|0)==(0|0);
     if ($39) {
      $$08$i$i = $$0$i$i$i;
      break;
     } else {
      $$0$i$i$i = $38;
     }
    }
   }
   $44 = $$08$i$i;
   $45 = ((($$08$i$i)) + 16|0);
   $46 = ((($4)) + 11|0);
   $47 = HEAP8[$46>>0]|0;
   $48 = ($47<<24>>24)<(0);
   $49 = ((($4)) + 4|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = $47&255;
   $52 = $48 ? $50 : $51;
   $53 = ((($45)) + 11|0);
   $54 = HEAP8[$53>>0]|0;
   $55 = ($54<<24>>24)<(0);
   $56 = ((($$08$i$i)) + 20|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = $54&255;
   $59 = $55 ? $57 : $58;
   $60 = ($52>>>0)<($59>>>0);
   $$sroa$speculated$i$i$i$i$i26 = $60 ? $52 : $59;
   $61 = ($$sroa$speculated$i$i$i$i$i26|0)==(0);
   if ($61) {
    label = 12;
   } else {
    $62 = HEAP32[$45>>2]|0;
    $63 = $55 ? $62 : $45;
    $64 = HEAP32[$4>>2]|0;
    $65 = $48 ? $64 : $4;
    $66 = (_memcmp($63,$65,$$sroa$speculated$i$i$i$i$i26)|0);
    $67 = ($66|0)==(0);
    if ($67) {
     label = 12;
    } else {
     $69 = ($66|0)<(0);
     if ($69) {
      $$sroa$052$0 = $44;
      break;
     }
    }
   }
   if ((label|0) == 12) {
    $68 = ($59>>>0)<($52>>>0);
    if ($68) {
     $$sroa$052$0 = $44;
     break;
    }
   }
   $73 = (__ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES7_EENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE12__find_equalIS7_EERPNS_16__tree_node_baseIPvEERPNS_15__tree_end_nodeISJ_EERKT_($0,$2,$4)|0);
   $$2 = $73;
   return ($$2|0);
  }
 } while(0);
 $70 = ($$pre|0)==(0|0);
 if ($70) {
  HEAP32[$2>>2] = $6;
  $$2 = $6;
  return ($$2|0);
 } else {
  $71 = $$sroa$052$0;
  HEAP32[$2>>2] = $71;
  $72 = ((($71)) + 4|0);
  $$2 = $72;
  return ($$2|0);
 }
 return (0)|0;
}
function __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPvEENS_19__map_value_compareIS7_S9_NS_4lessIS7_EELb1EEENS5_IS9_EEE12__find_equalIS7_EERPNS_16__tree_node_baseIS8_EERPNS_15__tree_end_nodeISJ_EERKT_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$0$ph = 0, $$024 = 0, $$025 = 0, $$in = 0, $$sroa$speculated$i$i$i$i$i = 0, $$sroa$speculated$i$i$i$i$i26 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  HEAP32[$1>>2] = $3;
  $$025 = $3;
  return ($$025|0);
 }
 $6 = ((($0)) + 4|0);
 $7 = ((($2)) + 11|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = ($8<<24>>24)<(0);
 $10 = ((($2)) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $8&255;
 $13 = $9 ? $11 : $12;
 $14 = HEAP32[$2>>2]|0;
 $15 = $9 ? $14 : $2;
 $$0 = $6;$$024 = $4;
 while(1) {
  $16 = ((($$024)) + 16|0);
  $17 = ((($16)) + 11|0);
  $18 = HEAP8[$17>>0]|0;
  $19 = ($18<<24>>24)<(0);
  $20 = ((($$024)) + 20|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = $18&255;
  $23 = $19 ? $21 : $22;
  $24 = ($23>>>0)<($13>>>0);
  $$sroa$speculated$i$i$i$i$i26 = $24 ? $23 : $13;
  $25 = ($$sroa$speculated$i$i$i$i$i26|0)==(0);
  if ($25) {
   label = 6;
  } else {
   $26 = HEAP32[$16>>2]|0;
   $27 = $19 ? $26 : $16;
   $28 = (_memcmp($15,$27,$$sroa$speculated$i$i$i$i$i26)|0);
   $29 = ($28|0)==(0);
   if ($29) {
    label = 6;
   } else {
    $31 = ($28|0)<(0);
    if ($31) {
     label = 8;
    } else {
     label = 10;
    }
   }
  }
  if ((label|0) == 6) {
   label = 0;
   $30 = ($13>>>0)<($23>>>0);
   if ($30) {
    label = 8;
   } else {
    label = 10;
   }
  }
  if ((label|0) == 8) {
   label = 0;
   $32 = HEAP32[$$024>>2]|0;
   $33 = ($32|0)==(0|0);
   if ($33) {
    label = 9;
    break;
   } else {
    $$0$ph = $$024;$$in = $32;
   }
  }
  else if ((label|0) == 10) {
   label = 0;
   $34 = ($13>>>0)<($23>>>0);
   $$sroa$speculated$i$i$i$i$i = $34 ? $13 : $23;
   $35 = ($$sroa$speculated$i$i$i$i$i|0)==(0);
   if ($35) {
    label = 12;
   } else {
    $36 = HEAP32[$16>>2]|0;
    $37 = $19 ? $36 : $16;
    $38 = (_memcmp($37,$15,$$sroa$speculated$i$i$i$i$i)|0);
    $39 = ($38|0)==(0);
    if ($39) {
     label = 12;
    } else {
     $40 = ($38|0)<(0);
     if (!($40)) {
      label = 16;
      break;
     }
    }
   }
   if ((label|0) == 12) {
    label = 0;
    if (!($24)) {
     label = 16;
     break;
    }
   }
   $41 = ((($$024)) + 4|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = ($42|0)==(0|0);
   if ($43) {
    label = 15;
    break;
   } else {
    $$0$ph = $41;$$in = $42;
   }
  }
  $$0 = $$0$ph;$$024 = $$in;
 }
 if ((label|0) == 9) {
  HEAP32[$1>>2] = $$024;
  $$025 = $$024;
  return ($$025|0);
 }
 else if ((label|0) == 15) {
  HEAP32[$1>>2] = $$024;
  $$025 = $41;
  return ($$025|0);
 }
 else if ((label|0) == 16) {
  HEAP32[$1>>2] = $$024;
  $$025 = $$0;
  return ($$025|0);
 }
 return (0)|0;
}
function __ZNSt3__25dequeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS4_IS6_EEE8__appendINS_16__deque_iteratorIS6_PKS6_RSB_PKSC_iLi0EEEEEvT_SH_PNS_9enable_ifIXsr21__is_forward_iteratorISH_EE5valueEvE4typeE($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$$i$i = 0, $$0$i$i$i = 0, $$neg$i$i$i = 0, $$pre = 0, $$pre23 = 0, $$pre24 = 0, $$pre25 = 0, $$sroa$0$022 = 0, $$sroa$0$1 = 0, $$sroa$5$0$ph = 0, $$sroa$5$021 = 0, $$sroa$5$1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $9 = 0, $phitmp = 0, $sum = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $4 = $1;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + 4)|0;
 $8 = $7;
 $9 = HEAP32[$8>>2]|0;
 $10 = $2;
 $11 = $10;
 $12 = HEAP32[$11>>2]|0;
 $13 = (($10) + 4)|0;
 $14 = $13;
 $15 = HEAP32[$14>>2]|0;
 $16 = $15;
 $17 = $9;
 $18 = ($16|0)==($17|0);
 $19 = $6;
 if ($18) {
  $$0$i$i$i = 0;
 } else {
  $20 = (($12) - ($6))|0;
  $21 = $20 >> 2;
  $22 = ($21*341)|0;
  $23 = $12;
  $24 = HEAP32[$23>>2]|0;
  $25 = (($15) - ($24))|0;
  $26 = (($25|0) / 12)&-1;
  $27 = (($26) + ($22))|0;
  $28 = $6;
  $29 = HEAP32[$28>>2]|0;
  $30 = (($9) - ($29))|0;
  $$neg$i$i$i = (($30|0) / -12)&-1;
  $31 = (($27) + ($$neg$i$i$i))|0;
  $$0$i$i$i = $31;
 }
 $32 = ((($0)) + 8|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ((($0)) + 4|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (($33) - ($35))|0;
 $37 = $36 >> 2;
 $38 = ($37|0)==(0);
 $39 = ($37*341)|0;
 $40 = (($39) + -1)|0;
 $$$i$i = $38 ? 0 : $40;
 $41 = ((($0)) + 16|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ((($0)) + 20|0);
 $44 = HEAP32[$43>>2]|0;
 $sum = (($44) + ($42))|0;
 $45 = (($$$i$i) - ($sum))|0;
 $46 = ($$0$i$i$i>>>0)>($45>>>0);
 $47 = $35;
 $48 = $33;
 if ($46) {
  $49 = (($$0$i$i$i) - ($45))|0;
  __ZNSt3__25dequeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS4_IS6_EEE19__add_back_capacityEj($0,$49);
  $$pre = HEAP32[$43>>2]|0;
  $$pre23 = HEAP32[$41>>2]|0;
  $$pre24 = HEAP32[$34>>2]|0;
  $$pre25 = HEAP32[$32>>2]|0;
  $51 = $$pre;$52 = $$pre23;$55 = $$pre24;$56 = $$pre25;
 } else {
  $51 = $44;$52 = $42;$55 = $47;$56 = $48;
 }
 $50 = (($52) + ($51))|0;
 $53 = (($50>>>0) / 341)&-1;
 $54 = (($55) + ($53<<2)|0);
 $57 = ($56|0)==($55|0);
 if ($57) {
  $$sroa$5$0$ph = 0;
 } else {
  $58 = HEAP32[$54>>2]|0;
  $59 = (($50>>>0) % 341)&-1;
  $60 = (($58) + (($59*12)|0)|0);
  $phitmp = $60;
  $$sroa$5$0$ph = $phitmp;
 }
 $61 = ((($1)) + 4|0);
 $62 = HEAP32[$61>>2]|0;
 $63 = ((($2)) + 4|0);
 $64 = HEAP32[$63>>2]|0;
 $65 = ($62|0)==($64|0);
 if ($65) {
  return;
 }
 $$sroa$0$022 = $54;$$sroa$5$021 = $$sroa$5$0$ph;$67 = $62;$77 = $19;
 while(1) {
  $66 = $$sroa$5$021;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_($66,$67);
  $68 = ((($66)) + 12|0);
  $69 = $68;
  $70 = HEAP32[$$sroa$0$022>>2]|0;
  $71 = (($69) - ($70))|0;
  $72 = ($71|0)==(4092);
  if ($72) {
   $73 = ((($$sroa$0$022)) + 4|0);
   $74 = HEAP32[$73>>2]|0;
   $$sroa$0$1 = $73;$$sroa$5$1 = $74;
  } else {
   $$sroa$0$1 = $$sroa$0$022;$$sroa$5$1 = $69;
  }
  $75 = ((($67)) + 12|0);
  HEAP32[$61>>2] = $75;
  $76 = HEAP32[$77>>2]|0;
  $78 = $75;
  $79 = (($78) - ($76))|0;
  $80 = ($79|0)==(4092);
  if ($80) {
   $81 = ((($77)) + 4|0);
   HEAP32[$1>>2] = $81;
   $82 = HEAP32[$81>>2]|0;
   HEAP32[$61>>2] = $82;
   $83 = $82;
   $86 = $83;$88 = $81;
  } else {
   $86 = $75;$88 = $77;
  }
  $84 = HEAP32[$43>>2]|0;
  $85 = (($84) + 1)|0;
  HEAP32[$43>>2] = $85;
  $87 = ($86|0)==($64|0);
  if ($87) {
   break;
  } else {
   $$sroa$0$022 = $$sroa$0$1;$$sroa$5$021 = $$sroa$5$1;$67 = $86;$77 = $88;
  }
 }
 return;
}
function __ZNSt3__25dequeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS4_IS6_EEE19__add_back_capacityEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$0152184$lcssa = 0, $$0152184228 = 0, $$0153169 = 0, $$024172 = 0, $$025 = 0, $$026 = 0, $$1154$lcssa = 0, $$1181 = 0, $$2155177 = 0, $$2175 = 0, $$3170 = 0, $$in = 0, $$in$i = 0, $$in$i38 = 0, $$in$i51 = 0, $$in$i65 = 0, $$in$i80 = 0, $$neg = 0, $$pre = 0;
 var $$pre$i40 = 0, $$pre$i53 = 0, $$pre$i67 = 0, $$pre195 = 0, $$pre196 = 0, $$pre197 = 0, $$pre47$i33 = 0, $$pre47$i46 = 0, $$pre47$i60 = 0, $$pre48$i45 = 0, $$pre48$i58 = 0, $$pre48$i72 = 0, $$sroa$13$0$i = 0, $$sroa$13$0$i37 = 0, $$sroa$13$0$i50 = 0, $$sroa$13$0$i64 = 0, $$sroa$13$0$i79 = 0, $$sroa$13$1$i = 0, $$sroa$13$1$i42 = 0, $$sroa$13$1$i55 = 0;
 var $$sroa$13$1$i69 = 0, $$sroa$13$1$i84 = 0, $$sroa$speculated = 0, $$sroa$speculated$i = 0, $$sroa$speculated$i35 = 0, $$sroa$speculated$i48 = 0, $$sroa$speculated$i62 = 0, $$sroa$speculated$i77 = 0, $$sroa$speculated122 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0;
 var $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0;
 var $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0;
 var $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0;
 var $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0;
 var $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0;
 var $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0;
 var $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0;
 var $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0;
 var $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0;
 var $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0;
 var $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0;
 var $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0;
 var $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0;
 var $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0;
 var $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index10Z2D = 0, $eh$lpad$body$indexZ2D = 0, $eh$lpad$body90$indexZ2D = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i$i$i27 = 0, $scevgep5$i$i$i$i = 0, $scevgep5$i$i$i$i28 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $2 = sp + 20|0;
 $3 = sp;
 $4 = ((($0)) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($0)) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5|0)==($7|0);
 $9 = $8&1;
 $10 = (($9) + ($1))|0;
 $11 = (($10>>>0) / 341)&-1;
 $12 = (($10>>>0) % 341)&-1;
 $13 = ($12|0)!=(0);
 $14 = $13&1;
 $15 = (($14) + ($11))|0;
 $16 = ((($0)) + 16|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($17>>>0) / 341)&-1;
 $19 = ($15>>>0)<($18>>>0);
 $$sroa$speculated122 = $19 ? $15 : $18;
 $20 = (($15) - ($$sroa$speculated122))|0;
 $21 = ($20|0)==(0);
 $22 = $5;
 if ($21) {
  $23 = Math_imul($$sroa$speculated122, -341)|0;
  $24 = (($23) + ($17))|0;
  HEAP32[$16>>2] = $24;
  $25 = ($$sroa$speculated122|0)==(0);
  if ($25) {
   STACKTOP = sp;return;
  }
  $26 = ((($0)) + 12|0);
  $$0153169 = $$sroa$speculated122;$28 = $7;$31 = $5;
  L6: while(1) {
   $27 = HEAP32[$28>>2]|0;
   $29 = ((($28)) + 4|0);
   HEAP32[$6>>2] = $29;
   $30 = HEAP32[$26>>2]|0;
   $32 = ($31|0)==($30|0);
   $33 = $30;
   $34 = $31;
   do {
    if ($32) {
     $35 = HEAP32[$0>>2]|0;
     $36 = ($29>>>0)>($35>>>0);
     $37 = $35;
     if ($36) {
      $38 = $29;
      $39 = (($38) - ($37))|0;
      $40 = $39 >> 2;
      $41 = (($40) + 1)|0;
      $42 = (($41|0) / -2)&-1;
      $43 = (($29) + ($42<<2)|0);
      $44 = (($34) - ($38))|0;
      $45 = $44 >> 2;
      $46 = ($45|0)==(0);
      if ($46) {
       $49 = $29;
      } else {
       _memmove(($43|0),($29|0),($44|0))|0;
       $$pre47$i33 = HEAP32[$6>>2]|0;
       $49 = $$pre47$i33;
      }
      $47 = (($43) + ($45<<2)|0);
      HEAP32[$4>>2] = $47;
      $48 = (($49) + ($42<<2)|0);
      HEAP32[$6>>2] = $48;
      $78 = $47;
      break;
     }
     $50 = (($33) - ($37))|0;
     $51 = $50 >> 1;
     $52 = ($51|0)==(0);
     $$sroa$speculated$i35 = $52 ? 1 : $51;
     $53 = ($$sroa$speculated$i35>>>0)>(1073741823);
     if ($53) {
      break L6;
     }
     $59 = $$sroa$speculated$i35 >>> 2;
     $60 = $$sroa$speculated$i35 << 2;
     $61 = (__Znwj($60)|0);
     $62 = $61;
     $63 = (($61) + ($59<<2)|0);
     $64 = $63;
     $65 = (($61) + ($$sroa$speculated$i35<<2)|0);
     $66 = $65;
     $67 = ($29|0)==($31|0);
     if ($67) {
      $$sroa$13$1$i42 = $64;$75 = $35;
     } else {
      $$in$i38 = $63;$$sroa$13$0$i37 = $64;$69 = $29;
      while(1) {
       $68 = HEAP32[$69>>2]|0;
       HEAP32[$$in$i38>>2] = $68;
       $70 = $$sroa$13$0$i37;
       $71 = ((($70)) + 4|0);
       $72 = $71;
       $73 = ((($69)) + 4|0);
       $74 = ($73|0)==($31|0);
       if ($74) {
        break;
       } else {
        $$in$i38 = $71;$$sroa$13$0$i37 = $72;$69 = $73;
       }
      }
      $$pre$i40 = HEAP32[$0>>2]|0;
      $$sroa$13$1$i42 = $72;$75 = $$pre$i40;
     }
     HEAP32[$0>>2] = $62;
     HEAP32[$6>>2] = $64;
     HEAP32[$4>>2] = $$sroa$13$1$i42;
     HEAP32[$26>>2] = $66;
     $76 = ($75|0)==(0|0);
     $77 = $$sroa$13$1$i42;
     if ($76) {
      $78 = $77;
     } else {
      __ZdlPv($75);
      $$pre48$i45 = HEAP32[$4>>2]|0;
      $78 = $$pre48$i45;
     }
    } else {
     $78 = $31;
    }
   } while(0);
   HEAP32[$78>>2] = $27;
   $79 = HEAP32[$4>>2]|0;
   $80 = ((($79)) + 4|0);
   HEAP32[$4>>2] = $80;
   $81 = (($$0153169) + -1)|0;
   $82 = ($81|0)==(0);
   if ($82) {
    label = 119;
    break;
   }
   $$pre197 = HEAP32[$6>>2]|0;
   $$0153169 = $81;$28 = $$pre197;$31 = $80;
  }
  if ((label|0) == 119) {
   STACKTOP = sp;return;
  }
  $54 = (___cxa_allocate_exception(8)|0);
  __THREW__ = 0;
  invoke_vii(3366,($54|0),(204840|0));
  $55 = __THREW__; __THREW__ = 0;
  $56 = $55&1;
  if ($56) {
   $57 = ___cxa_find_matching_catch_2()|0;
   $58 = tempRet0;
   ___cxa_free_exception(($54|0));
   ___resumeException($57|0);
   // unreachable;
  } else {
   HEAP32[$54>>2] = (99824);
   ___cxa_throw(($54|0),(34608|0),(3230|0));
   // unreachable;
  }
 }
 $83 = $7;
 $84 = ((($0)) + 12|0);
 $85 = HEAP32[$84>>2]|0;
 $86 = HEAP32[$0>>2]|0;
 $87 = (($85) - ($86))|0;
 $88 = $87 >> 2;
 $89 = (($22) - ($83))|0;
 $90 = $89 >> 2;
 $91 = (($88) - ($90))|0;
 $92 = ($20>>>0)>($91>>>0);
 if (!($92)) {
  $93 = ($85|0)==($22|0);
  L34: do {
   if ($93) {
    $$0152184$lcssa = $20;
    label = 23;
   } else {
    $$0152184228 = $20;$$in = $85;$100 = $5;
    L35: while(1) {
     $97 = $$in;
     $98 = (__Znwj(4092)|0);
     $99 = $98;
     $101 = ($100|0)==($97|0);
     $102 = $100;
     do {
      if ($101) {
       $103 = HEAP32[$6>>2]|0;
       $104 = HEAP32[$0>>2]|0;
       $105 = ($103>>>0)>($104>>>0);
       $106 = $104;
       if ($105) {
        $107 = $103;
        $108 = (($107) - ($106))|0;
        $109 = $108 >> 2;
        $110 = (($109) + 1)|0;
        $111 = (($110|0) / -2)&-1;
        $112 = (($103) + ($111<<2)|0);
        $113 = (($102) - ($107))|0;
        $114 = $113 >> 2;
        $115 = ($114|0)==(0);
        if ($115) {
         $118 = $103;
        } else {
         _memmove(($112|0),($103|0),($113|0))|0;
         $$pre47$i46 = HEAP32[$6>>2]|0;
         $118 = $$pre47$i46;
        }
        $116 = (($112) + ($114<<2)|0);
        HEAP32[$4>>2] = $116;
        $117 = (($118) + ($111<<2)|0);
        HEAP32[$6>>2] = $117;
        $147 = $116;
        break;
       }
       $119 = (($$in) - ($106))|0;
       $120 = $119 >> 1;
       $121 = ($120|0)==(0);
       $$sroa$speculated$i48 = $121 ? 1 : $120;
       $122 = ($$sroa$speculated$i48>>>0)>(1073741823);
       if ($122) {
        break L35;
       }
       $128 = $$sroa$speculated$i48 >>> 2;
       $129 = $$sroa$speculated$i48 << 2;
       $130 = (__Znwj($129)|0);
       $131 = $130;
       $132 = (($130) + ($128<<2)|0);
       $133 = $132;
       $134 = (($130) + ($$sroa$speculated$i48<<2)|0);
       $135 = $134;
       $136 = ($103|0)==($97|0);
       if ($136) {
        $$sroa$13$1$i55 = $133;$144 = $104;
       } else {
        $$in$i51 = $132;$$sroa$13$0$i50 = $133;$138 = $103;
        while(1) {
         $137 = HEAP32[$138>>2]|0;
         HEAP32[$$in$i51>>2] = $137;
         $139 = $$sroa$13$0$i50;
         $140 = ((($139)) + 4|0);
         $141 = $140;
         $142 = ((($138)) + 4|0);
         $143 = ($142|0)==($97|0);
         if ($143) {
          break;
         } else {
          $$in$i51 = $140;$$sroa$13$0$i50 = $141;$138 = $142;
         }
        }
        $$pre$i53 = HEAP32[$0>>2]|0;
        $$sroa$13$1$i55 = $141;$144 = $$pre$i53;
       }
       HEAP32[$0>>2] = $131;
       HEAP32[$6>>2] = $133;
       HEAP32[$4>>2] = $$sroa$13$1$i55;
       HEAP32[$84>>2] = $135;
       $145 = ($144|0)==(0|0);
       $146 = $$sroa$13$1$i55;
       if ($145) {
        $147 = $146;
       } else {
        __ZdlPv($144);
        $$pre48$i58 = HEAP32[$4>>2]|0;
        $147 = $$pre48$i58;
       }
      } else {
       $147 = $100;
      }
     } while(0);
     HEAP32[$147>>2] = $99;
     $148 = HEAP32[$4>>2]|0;
     $149 = ((($148)) + 4|0);
     HEAP32[$4>>2] = $149;
     $150 = (($$0152184228) + -1)|0;
     $151 = ($150|0)==(0);
     if ($151) {
      label = 22;
      break;
     }
     $152 = $149;
     $$pre = HEAP32[$84>>2]|0;
     $153 = ($$pre|0)==($152|0);
     if ($153) {
      $$0152184$lcssa = $150;
      label = 23;
      break L34;
     } else {
      $$0152184228 = $150;$$in = $$pre;$100 = $149;
     }
    }
    if ((label|0) == 22) {
     $$pre195 = HEAP32[$16>>2]|0;
     $$1154$lcssa = $$sroa$speculated122;$169 = $$pre195;$424 = $149;
     break;
    }
    $123 = (___cxa_allocate_exception(8)|0);
    __THREW__ = 0;
    invoke_vii(3366,($123|0),(204840|0));
    $124 = __THREW__; __THREW__ = 0;
    $125 = $124&1;
    if ($125) {
     $126 = ___cxa_find_matching_catch_2()|0;
     $127 = tempRet0;
     ___cxa_free_exception(($123|0));
     ___resumeException($126|0);
     // unreachable;
    } else {
     HEAP32[$123>>2] = (99824);
     ___cxa_throw(($123|0),(34608|0),(3230|0));
     // unreachable;
    }
   }
  } while(0);
  if ((label|0) == 23) {
   $94 = ($15>>>0)>($18>>>0);
   $95 = $94 ? $18 : $15;
   $96 = $95 ^ -1;
   $$1181 = $$0152184$lcssa;
   while(1) {
    $154 = (__Znwj(4092)|0);
    HEAP32[$2>>2] = $154;
    __ZNSt3__214__split_bufferIPNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS4_IS7_EEE10push_frontERKS7_($0,$2);
    $155 = (($$1181) + -1)|0;
    $156 = HEAP32[$4>>2]|0;
    $157 = HEAP32[$6>>2]|0;
    $158 = (($156) - ($157))|0;
    $159 = ($158|0)==(4);
    $$neg = $159 << 31 >> 31;
    $160 = HEAP32[$16>>2]|0;
    $161 = (($160) + 341)|0;
    $162 = (($161) + ($$neg))|0;
    HEAP32[$16>>2] = $162;
    $163 = ($155|0)==(0);
    if ($163) {
     break;
    } else {
     $$1181 = $155;
    }
   }
   $164 = $156;
   $165 = (($$0152184$lcssa) + -1)|0;
   $166 = (($165) - ($96))|0;
   $$1154$lcssa = $166;$169 = $162;$424 = $164;
  }
  $167 = Math_imul($$1154$lcssa, -341)|0;
  $168 = (($169) + ($167))|0;
  HEAP32[$16>>2] = $168;
  $170 = ($$1154$lcssa|0)==(0);
  if ($170) {
   STACKTOP = sp;return;
  }
  $$2155177 = $$1154$lcssa;$175 = $424;
  L69: while(1) {
   $171 = HEAP32[$6>>2]|0;
   $172 = HEAP32[$171>>2]|0;
   $173 = ((($171)) + 4|0);
   HEAP32[$6>>2] = $173;
   $174 = HEAP32[$84>>2]|0;
   $176 = ($175|0)==($174|0);
   $177 = $174;
   $178 = $175;
   do {
    if ($176) {
     $179 = HEAP32[$0>>2]|0;
     $180 = ($173>>>0)>($179>>>0);
     $181 = $179;
     if ($180) {
      $182 = $173;
      $183 = (($182) - ($181))|0;
      $184 = $183 >> 2;
      $185 = (($184) + 1)|0;
      $186 = (($185|0) / -2)&-1;
      $187 = (($173) + ($186<<2)|0);
      $188 = (($178) - ($182))|0;
      $189 = $188 >> 2;
      $190 = ($189|0)==(0);
      if ($190) {
       $193 = $173;
      } else {
       _memmove(($187|0),($173|0),($188|0))|0;
       $$pre47$i60 = HEAP32[$6>>2]|0;
       $193 = $$pre47$i60;
      }
      $191 = (($187) + ($189<<2)|0);
      HEAP32[$4>>2] = $191;
      $192 = (($193) + ($186<<2)|0);
      HEAP32[$6>>2] = $192;
      $222 = $191;
      break;
     }
     $194 = (($177) - ($181))|0;
     $195 = $194 >> 1;
     $196 = ($195|0)==(0);
     $$sroa$speculated$i62 = $196 ? 1 : $195;
     $197 = ($$sroa$speculated$i62>>>0)>(1073741823);
     if ($197) {
      break L69;
     }
     $203 = $$sroa$speculated$i62 >>> 2;
     $204 = $$sroa$speculated$i62 << 2;
     $205 = (__Znwj($204)|0);
     $206 = $205;
     $207 = (($205) + ($203<<2)|0);
     $208 = $207;
     $209 = (($205) + ($$sroa$speculated$i62<<2)|0);
     $210 = $209;
     $211 = ($173|0)==($175|0);
     if ($211) {
      $$sroa$13$1$i69 = $208;$219 = $179;
     } else {
      $$in$i65 = $207;$$sroa$13$0$i64 = $208;$213 = $173;
      while(1) {
       $212 = HEAP32[$213>>2]|0;
       HEAP32[$$in$i65>>2] = $212;
       $214 = $$sroa$13$0$i64;
       $215 = ((($214)) + 4|0);
       $216 = $215;
       $217 = ((($213)) + 4|0);
       $218 = ($217|0)==($175|0);
       if ($218) {
        break;
       } else {
        $$in$i65 = $215;$$sroa$13$0$i64 = $216;$213 = $217;
       }
      }
      $$pre$i67 = HEAP32[$0>>2]|0;
      $$sroa$13$1$i69 = $216;$219 = $$pre$i67;
     }
     HEAP32[$0>>2] = $206;
     HEAP32[$6>>2] = $208;
     HEAP32[$4>>2] = $$sroa$13$1$i69;
     HEAP32[$84>>2] = $210;
     $220 = ($219|0)==(0|0);
     $221 = $$sroa$13$1$i69;
     if ($220) {
      $222 = $221;
     } else {
      __ZdlPv($219);
      $$pre48$i72 = HEAP32[$4>>2]|0;
      $222 = $$pre48$i72;
     }
    } else {
     $222 = $175;
    }
   } while(0);
   HEAP32[$222>>2] = $172;
   $223 = HEAP32[$4>>2]|0;
   $224 = ((($223)) + 4|0);
   HEAP32[$4>>2] = $224;
   $225 = (($$2155177) + -1)|0;
   $226 = ($225|0)==(0);
   if ($226) {
    label = 119;
    break;
   } else {
    $$2155177 = $225;$175 = $224;
   }
  }
  if ((label|0) == 119) {
   STACKTOP = sp;return;
  }
  $198 = (___cxa_allocate_exception(8)|0);
  __THREW__ = 0;
  invoke_vii(3366,($198|0),(204840|0));
  $199 = __THREW__; __THREW__ = 0;
  $200 = $199&1;
  if ($200) {
   $201 = ___cxa_find_matching_catch_2()|0;
   $202 = tempRet0;
   ___cxa_free_exception(($198|0));
   ___resumeException($201|0);
   // unreachable;
  } else {
   HEAP32[$198>>2] = (99824);
   ___cxa_throw(($198|0),(34608|0),(3230|0));
   // unreachable;
  }
 }
 $227 = $87 >> 1;
 $228 = (($90) + ($20))|0;
 $229 = ($227>>>0)<($228>>>0);
 $$sroa$speculated = $229 ? $228 : $227;
 $230 = (($90) - ($$sroa$speculated122))|0;
 $231 = ((($0)) + 12|0);
 $232 = ((($3)) + 12|0);
 HEAP32[$232>>2] = 0;
 $233 = ((($3)) + 16|0);
 HEAP32[$233>>2] = $231;
 $234 = ($$sroa$speculated|0)==(0);
 do {
  if ($234) {
   $243 = 0;
  } else {
   $235 = ($$sroa$speculated>>>0)>(1073741823);
   if (!($235)) {
    $241 = $$sroa$speculated << 2;
    $242 = (__Znwj($241)|0);
    $243 = $242;
    break;
   }
   $236 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($236|0),(204840|0));
   $237 = __THREW__; __THREW__ = 0;
   $238 = $237&1;
   if ($238) {
    $239 = ___cxa_find_matching_catch_2()|0;
    $240 = tempRet0;
    ___cxa_free_exception(($236|0));
    ___resumeException($239|0);
    // unreachable;
   } else {
    HEAP32[$236>>2] = (99824);
    ___cxa_throw(($236|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 HEAP32[$3>>2] = $243;
 $244 = (($243) + ($230<<2)|0);
 $245 = ((($3)) + 8|0);
 HEAP32[$245>>2] = $244;
 $246 = ((($3)) + 4|0);
 HEAP32[$246>>2] = $244;
 $247 = (($243) + ($$sroa$speculated<<2)|0);
 $248 = ((($3)) + 12|0);
 HEAP32[$248>>2] = $247;
 $$2175 = $20;$255 = $244;
 L103: while(1) {
  __THREW__ = 0;
  $250 = (invoke_ii(3276,4092)|0);
  $251 = __THREW__; __THREW__ = 0;
  $252 = $251&1;
  if ($252) {
   label = 84;
   break;
  }
  $253 = $250;
  $254 = HEAP32[$248>>2]|0;
  $256 = ($255|0)==($254|0);
  $257 = $254;
  $258 = $255;
  do {
   if ($256) {
    $259 = HEAP32[$246>>2]|0;
    $260 = HEAP32[$3>>2]|0;
    $261 = ($259>>>0)>($260>>>0);
    $262 = $260;
    if ($261) {
     $263 = $259;
     $264 = (($263) - ($262))|0;
     $265 = $264 >> 2;
     $266 = (($265) + 1)|0;
     $267 = (($266|0) / -2)&-1;
     $268 = (($259) + ($267<<2)|0);
     $269 = (($258) - ($263))|0;
     $270 = $269 >> 2;
     $271 = ($270|0)==(0);
     if (!($271)) {
      _memmove(($268|0),($259|0),($269|0))|0;
     }
     $272 = (($268) + ($270<<2)|0);
     HEAP32[$245>>2] = $272;
     HEAP32[$246>>2] = $268;
     $305 = $272;
     break;
    }
    $273 = (($257) - ($262))|0;
    $274 = $273 >> 1;
    $275 = ($274|0)==(0);
    $$sroa$speculated$i77 = $275 ? 1 : $274;
    $276 = ($$sroa$speculated$i77>>>0)>(1073741823);
    if ($276) {
     label = 75;
     break L103;
    }
    $285 = $$sroa$speculated$i77 << 2;
    __THREW__ = 0;
    $286 = (invoke_ii(3276,($285|0))|0);
    $287 = __THREW__; __THREW__ = 0;
    $288 = $287&1;
    if ($288) {
     label = 84;
     break L103;
    }
    $289 = $$sroa$speculated$i77 >>> 2;
    $290 = $286;
    $291 = (($286) + ($289<<2)|0);
    $292 = $291;
    $293 = (($286) + ($$sroa$speculated$i77<<2)|0);
    $294 = $293;
    $295 = ($259|0)==($255|0);
    if ($295) {
     $$sroa$13$1$i84 = $292;
    } else {
     $$in$i80 = $291;$$sroa$13$0$i79 = $292;$297 = $259;
     while(1) {
      $296 = HEAP32[$297>>2]|0;
      HEAP32[$$in$i80>>2] = $296;
      $298 = $$sroa$13$0$i79;
      $299 = ((($298)) + 4|0);
      $300 = $299;
      $301 = ((($297)) + 4|0);
      $302 = ($301|0)==($255|0);
      if ($302) {
       $$sroa$13$1$i84 = $300;
       break;
      } else {
       $$in$i80 = $299;$$sroa$13$0$i79 = $300;$297 = $301;
      }
     }
    }
    HEAP32[$3>>2] = $290;
    HEAP32[$246>>2] = $292;
    HEAP32[$245>>2] = $$sroa$13$1$i84;
    HEAP32[$248>>2] = $294;
    $303 = ($260|0)==(0|0);
    $304 = $$sroa$13$1$i84;
    if ($303) {
     $305 = $304;
    } else {
     __ZdlPv($260);
     $305 = $304;
    }
   } else {
    $305 = $255;
   }
  } while(0);
  HEAP32[$305>>2] = $253;
  $306 = HEAP32[$245>>2]|0;
  $307 = ((($306)) + 4|0);
  HEAP32[$245>>2] = $307;
  $308 = (($$2175) + -1)|0;
  $309 = ($308|0)==(0);
  if ($309) {
   label = 66;
   break;
  } else {
   $$2175 = $308;$255 = $307;
  }
 }
 L122: do {
  if ((label|0) == 66) {
   $249 = ($$sroa$speculated122|0)==(0);
   L125: do {
    if (!($249)) {
     $$pre196 = HEAP32[$6>>2]|0;
     $$3170 = $$sroa$speculated122;$324 = $307;$375 = $$pre196;
     L127: while(1) {
      $323 = HEAP32[$248>>2]|0;
      $325 = ($324|0)==($323|0);
      $326 = $323;
      $327 = $324;
      do {
       if ($325) {
        $328 = HEAP32[$246>>2]|0;
        $329 = HEAP32[$3>>2]|0;
        $330 = ($328>>>0)>($329>>>0);
        $331 = $329;
        if ($330) {
         $332 = $328;
         $333 = (($332) - ($331))|0;
         $334 = $333 >> 2;
         $335 = (($334) + 1)|0;
         $336 = (($335|0) / -2)&-1;
         $337 = (($328) + ($336<<2)|0);
         $338 = (($327) - ($332))|0;
         $339 = $338 >> 2;
         $340 = ($339|0)==(0);
         if (!($340)) {
          _memmove(($337|0),($328|0),($338|0))|0;
         }
         $341 = (($337) + ($339<<2)|0);
         HEAP32[$245>>2] = $341;
         HEAP32[$246>>2] = $337;
         $376 = $341;
         break;
        }
        $342 = (($326) - ($331))|0;
        $343 = $342 >> 1;
        $344 = ($343|0)==(0);
        $$sroa$speculated$i = $344 ? 1 : $343;
        $345 = ($$sroa$speculated$i>>>0)>(1073741823);
        if ($345) {
         label = 94;
         break L127;
        }
        $354 = $$sroa$speculated$i << 2;
        __THREW__ = 0;
        $355 = (invoke_ii(3276,($354|0))|0);
        $356 = __THREW__; __THREW__ = 0;
        $357 = $356&1;
        if ($357) {
         label = 103;
         break L127;
        }
        $358 = $$sroa$speculated$i >>> 2;
        $359 = $355;
        $360 = (($355) + ($358<<2)|0);
        $361 = $360;
        $362 = (($355) + ($$sroa$speculated$i<<2)|0);
        $363 = $362;
        $364 = ($328|0)==($324|0);
        if ($364) {
         $$sroa$13$1$i = $361;
        } else {
         $$in$i = $360;$$sroa$13$0$i = $361;$366 = $328;
         while(1) {
          $365 = HEAP32[$366>>2]|0;
          HEAP32[$$in$i>>2] = $365;
          $367 = $$sroa$13$0$i;
          $368 = ((($367)) + 4|0);
          $369 = $368;
          $370 = ((($366)) + 4|0);
          $371 = ($370|0)==($324|0);
          if ($371) {
           $$sroa$13$1$i = $369;
           break;
          } else {
           $$in$i = $368;$$sroa$13$0$i = $369;$366 = $370;
          }
         }
        }
        HEAP32[$3>>2] = $359;
        HEAP32[$246>>2] = $361;
        HEAP32[$245>>2] = $$sroa$13$1$i;
        HEAP32[$248>>2] = $363;
        $372 = ($329|0)==(0|0);
        $373 = $$sroa$13$1$i;
        if ($372) {
         $376 = $373;
        } else {
         __ZdlPv($329);
         $376 = $373;
        }
       } else {
        $376 = $324;
       }
      } while(0);
      $374 = HEAP32[$375>>2]|0;
      HEAP32[$376>>2] = $374;
      $377 = HEAP32[$245>>2]|0;
      $378 = ((($377)) + 4|0);
      HEAP32[$245>>2] = $378;
      $379 = HEAP32[$6>>2]|0;
      $380 = ((($379)) + 4|0);
      HEAP32[$6>>2] = $380;
      $381 = (($$3170) + -1)|0;
      $382 = ($381|0)==(0);
      if ($382) {
       break L125;
      } else {
       $$3170 = $381;$324 = $378;$375 = $380;
      }
     }
     do {
      if ((label|0) == 94) {
       $346 = (___cxa_allocate_exception(8)|0);
       __THREW__ = 0;
       invoke_vii(3366,($346|0),(204840|0));
       $347 = __THREW__; __THREW__ = 0;
       $348 = $347&1;
       if ($348) {
        $352 = ___cxa_find_matching_catch_2()|0;
        $353 = tempRet0;
        ___cxa_free_exception(($346|0));
        $eh$lpad$body$index10Z2D = $353;$eh$lpad$body$indexZ2D = $352;
        break;
       } else {
        HEAP32[$346>>2] = (99824);
        __THREW__ = 0;
        invoke_viii(3695,($346|0),(34608|0),(3230|0));
        $349 = __THREW__; __THREW__ = 0;
        $350 = ___cxa_find_matching_catch_2()|0;
        $351 = tempRet0;
        $eh$lpad$body$index10Z2D = $351;$eh$lpad$body$indexZ2D = $350;
        break;
       }
      }
      else if ((label|0) == 103) {
       $383 = ___cxa_find_matching_catch_2()|0;
       $384 = tempRet0;
       $eh$lpad$body$index10Z2D = $384;$eh$lpad$body$indexZ2D = $383;
      }
     } while(0);
     $$025 = $eh$lpad$body$index10Z2D;$$026 = $eh$lpad$body$indexZ2D;
     break L122;
    }
   } while(0);
   $385 = HEAP32[$4>>2]|0;
   $$0 = $385;
   while(1) {
    $386 = HEAP32[$6>>2]|0;
    $387 = ($$0|0)==($386|0);
    if ($387) {
     break;
    }
    $388 = ((($$0)) + -4|0);
    __THREW__ = 0;
    invoke_vii(4172,($3|0),($388|0));
    $389 = __THREW__; __THREW__ = 0;
    $390 = $389&1;
    if ($390) {
     label = 108;
     break;
    } else {
     $$0 = $388;
    }
   }
   if ((label|0) == 108) {
    $391 = ___cxa_find_matching_catch_2()|0;
    $392 = tempRet0;
    $$025 = $392;$$026 = $391;
    break;
   }
   $393 = $386;
   $394 = HEAP32[$0>>2]|0;
   $395 = HEAP32[$3>>2]|0;
   HEAP32[$0>>2] = $395;
   HEAP32[$3>>2] = $394;
   $396 = HEAP32[$246>>2]|0;
   HEAP32[$6>>2] = $396;
   HEAP32[$246>>2] = $393;
   $397 = HEAP32[$4>>2]|0;
   $398 = HEAP32[$245>>2]|0;
   HEAP32[$4>>2] = $398;
   HEAP32[$245>>2] = $397;
   $399 = HEAP32[$84>>2]|0;
   $400 = HEAP32[$248>>2]|0;
   HEAP32[$84>>2] = $400;
   HEAP32[$248>>2] = $399;
   $401 = HEAP32[$16>>2]|0;
   $402 = Math_imul($$sroa$speculated122, -341)|0;
   $403 = (($401) + ($402))|0;
   HEAP32[$16>>2] = $403;
   $404 = $397;
   $405 = ($404|0)==($$0|0);
   if (!($405)) {
    $scevgep$i$i$i$i27 = ((($404)) + -4|0);
    $406 = $scevgep$i$i$i$i27;
    $407 = (($406) - ($393))|0;
    $408 = $407 >>> 2;
    $409 = $408 ^ -1;
    $scevgep5$i$i$i$i28 = (($404) + ($409<<2)|0);
    HEAP32[$245>>2] = $scevgep5$i$i$i$i28;
   }
   $410 = ($394|0)==(0);
   if (!($410)) {
    $411 = $394;
    __ZdlPv($411);
   }
   STACKTOP = sp;return;
  }
  else if ((label|0) == 75) {
   $277 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($277|0),(204840|0));
   $278 = __THREW__; __THREW__ = 0;
   $279 = $278&1;
   if ($279) {
    $283 = ___cxa_find_matching_catch_3(0|0)|0;
    $284 = tempRet0;
    ___cxa_free_exception(($277|0));
    $eh$lpad$body90$indexZ2D = $283;
    label = 85;
    break;
   } else {
    HEAP32[$277>>2] = (99824);
    __THREW__ = 0;
    invoke_viii(3695,($277|0),(34608|0),(3230|0));
    $280 = __THREW__; __THREW__ = 0;
    $281 = ___cxa_find_matching_catch_3(0|0)|0;
    $282 = tempRet0;
    $eh$lpad$body90$indexZ2D = $281;
    label = 85;
    break;
   }
  }
  else if ((label|0) == 84) {
   $310 = ___cxa_find_matching_catch_3(0|0)|0;
   $311 = tempRet0;
   $eh$lpad$body90$indexZ2D = $310;
   label = 85;
  }
 } while(0);
 if ((label|0) == 85) {
  (___cxa_begin_catch(($eh$lpad$body90$indexZ2D|0))|0);
  $312 = HEAP32[$246>>2]|0;
  $313 = HEAP32[$245>>2]|0;
  $314 = ($312|0)==($313|0);
  if (!($314)) {
   $$024172 = $312;
   while(1) {
    $320 = HEAP32[$$024172>>2]|0;
    __ZdlPv($320);
    $321 = ((($$024172)) + 4|0);
    $322 = ($321|0)==($313|0);
    if ($322) {
     break;
    } else {
     $$024172 = $321;
    }
   }
  }
  __THREW__ = 0;
  invoke_v(3314);
  $315 = __THREW__; __THREW__ = 0;
  $316 = ___cxa_find_matching_catch_2()|0;
  $317 = tempRet0;
  __THREW__ = 0;
  invoke_v(3261);
  $318 = __THREW__; __THREW__ = 0;
  $319 = $318&1;
  if ($319) {
   $422 = ___cxa_find_matching_catch_3(0|0)|0;
   $423 = tempRet0;
   ___clang_call_terminate($422);
   // unreachable;
  } else {
   $$025 = $317;$$026 = $316;
  }
 }
 $412 = HEAP32[$246>>2]|0;
 $413 = HEAP32[$245>>2]|0;
 $414 = ($413|0)==($412|0);
 if (!($414)) {
  $scevgep$i$i$i$i = ((($413)) + -4|0);
  $415 = $scevgep$i$i$i$i;
  $416 = $412;
  $417 = (($415) - ($416))|0;
  $418 = $417 >>> 2;
  $419 = $418 ^ -1;
  $scevgep5$i$i$i$i = (($413) + ($419<<2)|0);
  HEAP32[$245>>2] = $scevgep5$i$i$i$i;
 }
 $420 = HEAP32[$3>>2]|0;
 $421 = ($420|0)==(0|0);
 if ($421) {
  ___resumeException($$026|0);
  // unreachable;
 }
 __ZdlPv($420);
 ___resumeException($$026|0);
 // unreachable;
}
function __ZNSt3__214__split_bufferIPNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS4_IS7_EEE10push_frontERKS7_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i = 0, $$cast = 0, $$in = 0, $$pre = 0, $$pre47 = 0, $$pre48 = 0, $$sroa$13$0 = 0, $$sroa$13$1 = 0, $$sroa$speculated = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = ($3|0)==($4|0);
 $6 = $4;
 do {
  if ($5) {
   $7 = ((($0)) + 8|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ((($0)) + 12|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($8>>>0)<($10>>>0);
   $$cast = $10;
   if ($11) {
    $12 = $8;
    $13 = (($$cast) - ($12))|0;
    $14 = $13 >> 2;
    $15 = (($14) + 1)|0;
    $16 = (($15|0) / 2)&-1;
    $17 = (($8) + ($16<<2)|0);
    $18 = $3;
    $19 = (($12) - ($18))|0;
    $20 = $19 >> 2;
    $21 = ($20|0)==(0);
    $22 = (0 - ($20))|0;
    $23 = (($17) + ($22<<2)|0);
    if ($21) {
     $$0$i$i = $17;$25 = $8;
    } else {
     _memmove(($23|0),($3|0),($19|0))|0;
     $$pre47 = HEAP32[$7>>2]|0;
     $$0$i$i = $23;$25 = $$pre47;
    }
    HEAP32[$2>>2] = $$0$i$i;
    $24 = (($25) + ($16<<2)|0);
    HEAP32[$7>>2] = $24;
    $55 = $$0$i$i;
    break;
   }
   $26 = (($$cast) - ($6))|0;
   $27 = $26 >> 1;
   $28 = ($27|0)==(0);
   $$sroa$speculated = $28 ? 1 : $27;
   $29 = ($$sroa$speculated>>>0)>(1073741823);
   if ($29) {
    $30 = (___cxa_allocate_exception(8)|0);
    __THREW__ = 0;
    invoke_vii(3366,($30|0),(204840|0));
    $31 = __THREW__; __THREW__ = 0;
    $32 = $31&1;
    if ($32) {
     $33 = ___cxa_find_matching_catch_2()|0;
     $34 = tempRet0;
     ___cxa_free_exception(($30|0));
     ___resumeException($33|0);
     // unreachable;
    } else {
     HEAP32[$30>>2] = (99824);
     ___cxa_throw(($30|0),(34608|0),(3230|0));
     // unreachable;
    }
   }
   $35 = (($$sroa$speculated) + 3)|0;
   $36 = $35 >>> 2;
   $37 = $$sroa$speculated << 2;
   $38 = (__Znwj($37)|0);
   $39 = $38;
   $40 = (($38) + ($36<<2)|0);
   $41 = $40;
   $42 = (($38) + ($$sroa$speculated<<2)|0);
   $43 = $42;
   $44 = ($3|0)==($8|0);
   if ($44) {
    $$sroa$13$1 = $41;$52 = $3;
   } else {
    $$in = $40;$$sroa$13$0 = $41;$46 = $3;
    while(1) {
     $45 = HEAP32[$46>>2]|0;
     HEAP32[$$in>>2] = $45;
     $47 = $$sroa$13$0;
     $48 = ((($47)) + 4|0);
     $49 = $48;
     $50 = ((($46)) + 4|0);
     $51 = ($50|0)==($8|0);
     if ($51) {
      break;
     } else {
      $$in = $48;$$sroa$13$0 = $49;$46 = $50;
     }
    }
    $$pre = HEAP32[$0>>2]|0;
    $$sroa$13$1 = $49;$52 = $$pre;
   }
   HEAP32[$0>>2] = $39;
   HEAP32[$2>>2] = $41;
   HEAP32[$7>>2] = $$sroa$13$1;
   HEAP32[$9>>2] = $43;
   $53 = ($52|0)==(0|0);
   if ($53) {
    $55 = $40;
   } else {
    __ZdlPv($52);
    $$pre48 = HEAP32[$2>>2]|0;
    $55 = $$pre48;
   }
  } else {
   $55 = $3;
  }
 } while(0);
 $54 = ((($55)) + -4|0);
 $56 = HEAP32[$1>>2]|0;
 HEAP32[$54>>2] = $56;
 $57 = HEAP32[$2>>2]|0;
 $58 = ((($57)) + -4|0);
 HEAP32[$2>>2] = $58;
 return;
}
function __ZNSt3__214__split_bufferIPNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERNS4_IS7_EEE10push_frontERKS7_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i = 0, $$cast = 0, $$in = 0, $$pre = 0, $$pre47 = 0, $$pre48 = 0, $$sroa$13$0 = 0, $$sroa$13$1 = 0, $$sroa$speculated = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = ($3|0)==($4|0);
 $6 = $4;
 do {
  if ($5) {
   $7 = ((($0)) + 8|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ((($0)) + 12|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($8>>>0)<($10>>>0);
   $$cast = $10;
   if ($11) {
    $12 = $8;
    $13 = (($$cast) - ($12))|0;
    $14 = $13 >> 2;
    $15 = (($14) + 1)|0;
    $16 = (($15|0) / 2)&-1;
    $17 = (($8) + ($16<<2)|0);
    $18 = $3;
    $19 = (($12) - ($18))|0;
    $20 = $19 >> 2;
    $21 = ($20|0)==(0);
    $22 = (0 - ($20))|0;
    $23 = (($17) + ($22<<2)|0);
    if ($21) {
     $$0$i$i = $17;$25 = $8;
    } else {
     _memmove(($23|0),($3|0),($19|0))|0;
     $$pre47 = HEAP32[$7>>2]|0;
     $$0$i$i = $23;$25 = $$pre47;
    }
    HEAP32[$2>>2] = $$0$i$i;
    $24 = (($25) + ($16<<2)|0);
    HEAP32[$7>>2] = $24;
    $55 = $$0$i$i;
    break;
   }
   $26 = (($$cast) - ($6))|0;
   $27 = $26 >> 1;
   $28 = ($27|0)==(0);
   $$sroa$speculated = $28 ? 1 : $27;
   $29 = ($$sroa$speculated>>>0)>(1073741823);
   if ($29) {
    $30 = (___cxa_allocate_exception(8)|0);
    __THREW__ = 0;
    invoke_vii(3366,($30|0),(204840|0));
    $31 = __THREW__; __THREW__ = 0;
    $32 = $31&1;
    if ($32) {
     $33 = ___cxa_find_matching_catch_2()|0;
     $34 = tempRet0;
     ___cxa_free_exception(($30|0));
     ___resumeException($33|0);
     // unreachable;
    } else {
     HEAP32[$30>>2] = (99824);
     ___cxa_throw(($30|0),(34608|0),(3230|0));
     // unreachable;
    }
   }
   $35 = (($$sroa$speculated) + 3)|0;
   $36 = $35 >>> 2;
   $37 = $$sroa$speculated << 2;
   $38 = (__Znwj($37)|0);
   $39 = $38;
   $40 = (($38) + ($36<<2)|0);
   $41 = $40;
   $42 = (($38) + ($$sroa$speculated<<2)|0);
   $43 = $42;
   $44 = ($3|0)==($8|0);
   if ($44) {
    $$sroa$13$1 = $41;$52 = $3;
   } else {
    $$in = $40;$$sroa$13$0 = $41;$46 = $3;
    while(1) {
     $45 = HEAP32[$46>>2]|0;
     HEAP32[$$in>>2] = $45;
     $47 = $$sroa$13$0;
     $48 = ((($47)) + 4|0);
     $49 = $48;
     $50 = ((($46)) + 4|0);
     $51 = ($50|0)==($8|0);
     if ($51) {
      break;
     } else {
      $$in = $48;$$sroa$13$0 = $49;$46 = $50;
     }
    }
    $$pre = HEAP32[$0>>2]|0;
    $$sroa$13$1 = $49;$52 = $$pre;
   }
   HEAP32[$0>>2] = $39;
   HEAP32[$2>>2] = $41;
   HEAP32[$7>>2] = $$sroa$13$1;
   HEAP32[$9>>2] = $43;
   $53 = ($52|0)==(0|0);
   if ($53) {
    $55 = $40;
   } else {
    __ZdlPv($52);
    $$pre48 = HEAP32[$2>>2]|0;
    $55 = $$pre48;
   }
  } else {
   $55 = $3;
  }
 } while(0);
 $54 = ((($55)) + -4|0);
 $56 = HEAP32[$1>>2]|0;
 HEAP32[$54>>2] = $56;
 $57 = HEAP32[$2>>2]|0;
 $58 = ((($57)) + -4|0);
 HEAP32[$2>>2] = $58;
 return;
}
function __ZNK5osgDB7OptionsltERKS0_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$$$i$i = 0, $$$i$i = 0, $$sroa$speculated$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 32|0);
 $3 = ((($1)) + 32|0);
 $4 = ((($3)) + 11|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)<(0);
 $7 = HEAP32[$3>>2]|0;
 $8 = ((($1)) + 36|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $5&255;
 $11 = $6 ? $7 : $3;
 $12 = $6 ? $9 : $10;
 $13 = ((($2)) + 11|0);
 $14 = HEAP8[$13>>0]|0;
 $15 = ($14<<24>>24)<(0);
 if ($15) {
  $16 = ((($0)) + 36|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = HEAP32[$2>>2]|0;
  $21 = $17;$23 = $18;
 } else {
  $19 = $14&255;
  $21 = $19;$23 = $2;
 }
 $20 = ($12>>>0)<($21>>>0);
 $$sroa$speculated$i$i = $20 ? $12 : $21;
 $22 = ($$sroa$speculated$i$i|0)==(0);
 if (!($22)) {
  $24 = (_memcmp($23,$11,$$sroa$speculated$i$i)|0);
  $25 = ($24|0)==(0);
  if (!($25)) {
   $27 = $24;
   $28 = ($27|0)<(0);
   return ($28|0);
  }
 }
 $26 = ($21>>>0)<($12>>>0);
 $$$i$i = $20&1;
 $$$$i$i = $26 ? -1 : $$$i$i;
 $27 = $$$$i$i;
 $28 = ($27|0)<(0);
 return ($28|0);
}
function __ZN5osgDB12ReaderWriter10ReadResult9getObjectEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 return ($2|0);
}
function __ZN5osgDB12ReaderWriter10ReadResult8getImageEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  $5 = 0;
  return ($5|0);
 }
 $4 = (___dynamic_cast($2,26112,25320,0)|0);
 $5 = $4;
 return ($5|0);
}
function __ZN5osgDB12ReaderWriter10ReadResult14getHeightFieldEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  $5 = 0;
  return ($5|0);
 }
 $4 = (___dynamic_cast($2,26112,26576,0)|0);
 $5 = $4;
 return ($5|0);
}
function __ZN5osgDB12ReaderWriter10ReadResult7getNodeEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  $5 = 0;
  return ($5|0);
 }
 $4 = (___dynamic_cast($2,26112,25952,0)|0);
 $5 = $4;
 return ($5|0);
}
function __ZN5osgDB12ReaderWriter10ReadResult10getArchiveEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  $5 = 0;
  return ($5|0);
 }
 $4 = (___dynamic_cast($2,26112,32912,0)|0);
 $5 = $4;
 return ($5|0);
}
function __ZN5osgDB12ReaderWriter10ReadResult9getShaderEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  $5 = 0;
  return ($5|0);
 }
 $4 = (___dynamic_cast($2,26112,26544,0)|0);
 $5 = $4;
 return ($5|0);
}
function __ZNK5osgDB12ReaderWriter10ReadResult13statusMessageEv($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$03 = 0, $$1 = 0, $$14 = 0, $$2 = 0, $$25 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $2 = sp + 12|0;
 $3 = sp;
 ;HEAP32[$0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;
 $4 = HEAP32[$1>>2]|0;
 switch ($4|0) {
 case 0:  {
  __THREW__ = 0;
  (invoke_iii(3937,($0|0),(166663|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if ($6) {
   label = 3;
  } else {
   label = 11;
  }
  break;
 }
 case 1:  {
  __THREW__ = 0;
  (invoke_iii(3937,($0|0),(166679|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if ($10) {
   label = 3;
  } else {
   label = 11;
  }
  break;
 }
 case 2:  {
  __THREW__ = 0;
  (invoke_iii(3937,($0|0),(166696|0))|0);
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if ($12) {
   label = 3;
  } else {
   label = 11;
  }
  break;
 }
 case 3:  {
  __THREW__ = 0;
  (invoke_iii(3937,($0|0),(166711|0))|0);
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if ($14) {
   label = 3;
  } else {
   label = 11;
  }
  break;
 }
 case 4:  {
  __THREW__ = 0;
  (invoke_iii(3937,($0|0),(166722|0))|0);
  $15 = __THREW__; __THREW__ = 0;
  $16 = $15&1;
  if ($16) {
   label = 3;
  } else {
   label = 11;
  }
  break;
 }
 case 5:  {
  __THREW__ = 0;
  (invoke_iii(3937,($0|0),(166734|0))|0);
  $17 = __THREW__; __THREW__ = 0;
  $18 = $17&1;
  if ($18) {
   label = 3;
  } else {
   label = 11;
  }
  break;
 }
 case 6:  {
  __THREW__ = 0;
  (invoke_iii(3937,($0|0),(166757|0))|0);
  $19 = __THREW__; __THREW__ = 0;
  $20 = $19&1;
  if ($20) {
   label = 3;
  } else {
   label = 11;
  }
  break;
 }
 case 7:  {
  __THREW__ = 0;
  (invoke_iii(3937,($0|0),(166772|0))|0);
  $21 = __THREW__; __THREW__ = 0;
  $22 = $21&1;
  if ($22) {
   label = 3;
  } else {
   label = 11;
  }
  break;
 }
 default: {
  label = 11;
 }
 }
 if ((label|0) == 3) {
  $7 = ___cxa_find_matching_catch_2()|0;
  $8 = tempRet0;
  $$2 = $8;$$25 = $7;
 }
 else if ((label|0) == 11) {
  $23 = ((($1)) + 4|0);
  $24 = ((($23)) + 11|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = ($25<<24>>24)<(0);
  if ($26) {
   $27 = ((($1)) + 8|0);
   $28 = HEAP32[$27>>2]|0;
   $30 = $28;
  } else {
   $29 = $25&255;
   $30 = $29;
  }
  $31 = ($30|0)==(0);
  if ($31) {
   STACKTOP = sp;return;
  }
  __THREW__ = 0;
  invoke_viii(4173,($3|0),(166800|0),($23|0));
  $32 = __THREW__; __THREW__ = 0;
  $33 = $32&1;
  if ($33) {
   $54 = ___cxa_find_matching_catch_2()|0;
   $55 = tempRet0;
   $$1 = $55;$$14 = $54;
  } else {
   __THREW__ = 0;
   invoke_viii(3542,($2|0),($3|0),(174996|0));
   $34 = __THREW__; __THREW__ = 0;
   $35 = $34&1;
   do {
    if ($35) {
     $56 = ___cxa_find_matching_catch_2()|0;
     $57 = tempRet0;
     $$0 = $57;$$03 = $56;
    } else {
     $36 = ((($2)) + 11|0);
     $37 = HEAP8[$36>>0]|0;
     $38 = ($37<<24>>24)<(0);
     $39 = HEAP32[$2>>2]|0;
     $40 = $38 ? $39 : $2;
     $41 = ((($2)) + 4|0);
     $42 = HEAP32[$41>>2]|0;
     $43 = $37&255;
     $44 = $38 ? $42 : $43;
     __THREW__ = 0;
     (invoke_iiii(3544,($0|0),($40|0),($44|0))|0);
     $45 = __THREW__; __THREW__ = 0;
     $46 = $45&1;
     if ($46) {
      $58 = ___cxa_find_matching_catch_2()|0;
      $59 = tempRet0;
      $60 = HEAP8[$36>>0]|0;
      $61 = ($60<<24>>24)<(0);
      if (!($61)) {
       $$0 = $59;$$03 = $58;
       break;
      }
      $62 = HEAP32[$2>>2]|0;
      __ZdlPv($62);
      $$0 = $59;$$03 = $58;
      break;
     }
     $47 = HEAP8[$36>>0]|0;
     $48 = ($47<<24>>24)<(0);
     if ($48) {
      $49 = HEAP32[$2>>2]|0;
      __ZdlPv($49);
     }
     $50 = ((($3)) + 11|0);
     $51 = HEAP8[$50>>0]|0;
     $52 = ($51<<24>>24)<(0);
     if ($52) {
      $53 = HEAP32[$3>>2]|0;
      __ZdlPv($53);
     }
     STACKTOP = sp;return;
    }
   } while(0);
   $63 = ((($3)) + 11|0);
   $64 = HEAP8[$63>>0]|0;
   $65 = ($64<<24>>24)<(0);
   if ($65) {
    $66 = HEAP32[$3>>2]|0;
    __ZdlPv($66);
    $$1 = $$0;$$14 = $$03;
   } else {
    $$1 = $$0;$$14 = $$03;
   }
  }
  $$2 = $$1;$$25 = $$14;
 }
 $67 = ((($0)) + 11|0);
 $68 = HEAP8[$67>>0]|0;
 $69 = ($68<<24>>24)<(0);
 if (!($69)) {
  ___resumeException($$25|0);
  // unreachable;
 }
 $70 = HEAP32[$0>>2]|0;
 __ZdlPv($70);
 ___resumeException($$25|0);
 // unreachable;
}
function __ZNK5osgDB12ReaderWriter11WriteResult13statusMessageEv($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$03 = 0, $$1 = 0, $$14 = 0, $$2 = 0, $$25 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $2 = sp + 12|0;
 $3 = sp;
 ;HEAP32[$0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;
 $4 = HEAP32[$1>>2]|0;
 switch ($4|0) {
 case 0:  {
  __THREW__ = 0;
  (invoke_iii(3937,($0|0),(166663|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if ($6) {
   label = 3;
  } else {
   label = 7;
  }
  break;
 }
 case 1:  {
  __THREW__ = 0;
  (invoke_iii(3937,($0|0),(166679|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if ($10) {
   label = 3;
  } else {
   label = 7;
  }
  break;
 }
 case 2:  {
  __THREW__ = 0;
  (invoke_iii(3937,($0|0),(166803|0))|0);
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if ($12) {
   label = 3;
  } else {
   label = 7;
  }
  break;
 }
 case 3:  {
  __THREW__ = 0;
  (invoke_iii(3937,($0|0),(166815|0))|0);
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if ($14) {
   label = 3;
  } else {
   label = 7;
  }
  break;
 }
 default: {
  label = 7;
 }
 }
 if ((label|0) == 3) {
  $7 = ___cxa_find_matching_catch_2()|0;
  $8 = tempRet0;
  $$2 = $8;$$25 = $7;
 }
 else if ((label|0) == 7) {
  $15 = ((($1)) + 4|0);
  $16 = ((($15)) + 11|0);
  $17 = HEAP8[$16>>0]|0;
  $18 = ($17<<24>>24)<(0);
  if ($18) {
   $19 = ((($1)) + 8|0);
   $20 = HEAP32[$19>>2]|0;
   $22 = $20;
  } else {
   $21 = $17&255;
   $22 = $21;
  }
  $23 = ($22|0)==(0);
  if ($23) {
   STACKTOP = sp;return;
  }
  __THREW__ = 0;
  invoke_viii(4173,($3|0),(166800|0),($15|0));
  $24 = __THREW__; __THREW__ = 0;
  $25 = $24&1;
  if ($25) {
   $46 = ___cxa_find_matching_catch_2()|0;
   $47 = tempRet0;
   $$1 = $47;$$14 = $46;
  } else {
   __THREW__ = 0;
   invoke_viii(3542,($2|0),($3|0),(174996|0));
   $26 = __THREW__; __THREW__ = 0;
   $27 = $26&1;
   do {
    if ($27) {
     $48 = ___cxa_find_matching_catch_2()|0;
     $49 = tempRet0;
     $$0 = $49;$$03 = $48;
    } else {
     $28 = ((($2)) + 11|0);
     $29 = HEAP8[$28>>0]|0;
     $30 = ($29<<24>>24)<(0);
     $31 = HEAP32[$2>>2]|0;
     $32 = $30 ? $31 : $2;
     $33 = ((($2)) + 4|0);
     $34 = HEAP32[$33>>2]|0;
     $35 = $29&255;
     $36 = $30 ? $34 : $35;
     __THREW__ = 0;
     (invoke_iiii(3544,($0|0),($32|0),($36|0))|0);
     $37 = __THREW__; __THREW__ = 0;
     $38 = $37&1;
     if ($38) {
      $50 = ___cxa_find_matching_catch_2()|0;
      $51 = tempRet0;
      $52 = HEAP8[$28>>0]|0;
      $53 = ($52<<24>>24)<(0);
      if (!($53)) {
       $$0 = $51;$$03 = $50;
       break;
      }
      $54 = HEAP32[$2>>2]|0;
      __ZdlPv($54);
      $$0 = $51;$$03 = $50;
      break;
     }
     $39 = HEAP8[$28>>0]|0;
     $40 = ($39<<24>>24)<(0);
     if ($40) {
      $41 = HEAP32[$2>>2]|0;
      __ZdlPv($41);
     }
     $42 = ((($3)) + 11|0);
     $43 = HEAP8[$42>>0]|0;
     $44 = ($43<<24>>24)<(0);
     if ($44) {
      $45 = HEAP32[$3>>2]|0;
      __ZdlPv($45);
     }
     STACKTOP = sp;return;
    }
   } while(0);
   $55 = ((($3)) + 11|0);
   $56 = HEAP8[$55>>0]|0;
   $57 = ($56<<24>>24)<(0);
   if ($57) {
    $58 = HEAP32[$3>>2]|0;
    __ZdlPv($58);
    $$1 = $$0;$$14 = $$03;
   } else {
    $$1 = $$0;$$14 = $$03;
   }
  }
  $$2 = $$1;$$25 = $$14;
 }
 $59 = ((($0)) + 11|0);
 $60 = HEAP8[$59>>0]|0;
 $61 = ($60<<24>>24)<(0);
 if (!($61)) {
  ___resumeException($$25|0);
  // unreachable;
 }
 $62 = HEAP32[$0>>2]|0;
 __ZdlPv($62);
 ___resumeException($$25|0);
 // unreachable;
}
function __ZN5osgDB8Registry10readObjectERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEPKNS_7OptionsEb($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0 = 0, $$014 = 0, $$1 = 0, $$115 = 0, $$2 = 0, $$216 = 0, $$3 = 0, $$317 = 0, $$pre = 0, $$pre$phi50Z2D = 0, $$pre$phi52Z2D = 0, $$pre$phiZ2D = 0, $$pre49 = 0, $$pre51 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0;
 var $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0;
 var $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0;
 var $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0;
 var $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0;
 var $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$indexZ2D = 0;
 var $eh$lpad$body21$index3Z2D = 0, $eh$lpad$body21$indexZ2D = 0, $eh$lpad$body32$index10Z2D = 0, $eh$lpad$body32$indexZ2D = 0, $eh$lpad$body43$index17Z2D = 0, $eh$lpad$body43$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(64|0);
 $5 = sp + 40|0;
 $6 = sp + 20|0;
 $7 = sp;
 HEAP32[$0>>2] = 1;
 $8 = ((($0)) + 4|0);
 ;HEAP32[$8>>2]=0|0;HEAP32[$8+4>>2]=0|0;HEAP32[$8+8>>2]=0|0;HEAP32[$8+12>>2]=0|0;
 $9 = ($3|0)==(0|0);
 L1: do {
  if ($9) {
   label = 32;
  } else {
   $10 = ((($3)) + 116|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = ($11|0)==(0|0);
   if ($12) {
    label = 32;
   } else {
    $13 = HEAP32[$11>>2]|0;
    $14 = ((($13)) + 4|0);
    $15 = HEAP32[$14>>2]|0;
    __THREW__ = 0;
    invoke_viiii($15|0,($5|0),($11|0),($2|0),($3|0));
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    L4: do {
     if ($17) {
      $58 = ___cxa_find_matching_catch_2()|0;
      $59 = tempRet0;
      $eh$lpad$body21$index3Z2D = $59;$eh$lpad$body21$indexZ2D = $58;
      label = 23;
     } else {
      $18 = ($5|0)==($0|0);
      do {
       if ($18) {
        $$pre51 = ((($5)) + 16|0);
        $$pre$phi52Z2D = $$pre51;
       } else {
        $19 = HEAP32[$5>>2]|0;
        HEAP32[$0>>2] = $19;
        $20 = ((($5)) + 4|0);
        __THREW__ = 0;
        (invoke_iii(3477,($8|0),($20|0))|0);
        $21 = __THREW__; __THREW__ = 0;
        $22 = $21&1;
        if (!($22)) {
         $23 = ((($0)) + 16|0);
         $24 = HEAP32[$23>>2]|0;
         $25 = ((($5)) + 16|0);
         $26 = HEAP32[$25>>2]|0;
         $27 = ($24|0)==($26|0);
         if ($27) {
          $$pre$phi52Z2D = $25;
          break;
         }
         HEAP32[$23>>2] = $26;
         $28 = ($26|0)==(0|0);
         if (!($28)) {
          $29 = ((($26)) + 8|0);
          $30 = HEAP32[$29>>2]|0;HEAP32[$29>>2] = (($30+1)|0);
         }
         $31 = ($24|0)==(0|0);
         if ($31) {
          $$pre$phi52Z2D = $25;
          break;
         }
         $32 = ((($24)) + 8|0);
         $33 = HEAP32[$32>>2]|0;HEAP32[$32>>2] = (($33-1)|0);
         $34 = ($33|0)==(1);
         if (!($34)) {
          $$pre$phi52Z2D = $25;
          break;
         }
         __THREW__ = 0;
         invoke_viii(3262,($24|0),1,1);
         $35 = __THREW__; __THREW__ = 0;
         $36 = $35&1;
         if (!($36)) {
          $$pre$phi52Z2D = $25;
          break;
         }
        }
        $60 = ___cxa_find_matching_catch_2()|0;
        $61 = tempRet0;
        $62 = ((($5)) + 16|0);
        $63 = HEAP32[$62>>2]|0;
        $64 = ($63|0)==(0|0);
        if (!($64)) {
         $65 = ((($63)) + 8|0);
         $66 = HEAP32[$65>>2]|0;HEAP32[$65>>2] = (($66-1)|0);
         $67 = ($66|0)==(1);
         if ($67) {
          __THREW__ = 0;
          invoke_viii(3262,($63|0),1,1);
          $68 = __THREW__; __THREW__ = 0;
          $69 = $68&1;
          if ($69) {
           $74 = ___cxa_find_matching_catch_3(0|0)|0;
           $75 = tempRet0;
           $76 = ((($20)) + 11|0);
           $77 = HEAP8[$76>>0]|0;
           $78 = ($77<<24>>24)<(0);
           if (!($78)) {
            $eh$lpad$body$indexZ2D = $74;
            ___clang_call_terminate($eh$lpad$body$indexZ2D);
            // unreachable;
           }
           $79 = HEAP32[$20>>2]|0;
           __ZdlPv($79);
           $eh$lpad$body$indexZ2D = $74;
           ___clang_call_terminate($eh$lpad$body$indexZ2D);
           // unreachable;
          }
         }
        }
        HEAP32[$62>>2] = 0;
        $70 = ((($20)) + 11|0);
        $71 = HEAP8[$70>>0]|0;
        $72 = ($71<<24>>24)<(0);
        if (!($72)) {
         $$0 = $61;$$014 = $60;
         break L4;
        }
        $73 = HEAP32[$20>>2]|0;
        __ZdlPv($73);
        $$0 = $61;$$014 = $60;
        break L4;
       }
      } while(0);
      $37 = HEAP32[$$pre$phi52Z2D>>2]|0;
      $38 = ($37|0)==(0|0);
      if (!($38)) {
       $39 = ((($37)) + 8|0);
       $40 = HEAP32[$39>>2]|0;HEAP32[$39>>2] = (($40-1)|0);
       $41 = ($40|0)==(1);
       if ($41) {
        __THREW__ = 0;
        invoke_viii(3262,($37|0),1,1);
        $42 = __THREW__; __THREW__ = 0;
        $43 = $42&1;
        if ($43) {
         $49 = ___cxa_find_matching_catch_2()|0;
         $50 = tempRet0;
         $51 = ((($5)) + 4|0);
         $52 = ((($51)) + 11|0);
         $53 = HEAP8[$52>>0]|0;
         $54 = ($53<<24>>24)<(0);
         if (!($54)) {
          $eh$lpad$body21$index3Z2D = $50;$eh$lpad$body21$indexZ2D = $49;
          label = 23;
          break;
         }
         $55 = HEAP32[$51>>2]|0;
         __ZdlPv($55);
         $eh$lpad$body21$index3Z2D = $50;$eh$lpad$body21$indexZ2D = $49;
         label = 23;
         break;
        }
       }
      }
      HEAP32[$$pre$phi52Z2D>>2] = 0;
      $44 = ((($5)) + 4|0);
      $45 = ((($44)) + 11|0);
      $46 = HEAP8[$45>>0]|0;
      $47 = ($46<<24>>24)<(0);
      if ($47) {
       $48 = HEAP32[$44>>2]|0;
       __ZdlPv($48);
      }
      label = 89;
      break L1;
     }
    } while(0);
    if ((label|0) == 23) {
     $$0 = $eh$lpad$body21$index3Z2D;$$014 = $eh$lpad$body21$indexZ2D;
    }
    $$3 = $$0;$$317 = $$014;
   }
  }
 } while(0);
 L42: do {
  if ((label|0) == 32) {
   $80 = ((($1)) + 48|0);
   $81 = HEAP32[$80>>2]|0;
   $82 = ($81|0)==(0|0);
   if ($82) {
    __THREW__ = 0;
    invoke_viiii(4174,($7|0),($1|0),($2|0),($3|0));
    $148 = __THREW__; __THREW__ = 0;
    $149 = $148&1;
    L46: do {
     if ($149) {
      $188 = ___cxa_find_matching_catch_2()|0;
      $189 = tempRet0;
      $eh$lpad$body43$index17Z2D = $189;$eh$lpad$body43$indexZ2D = $188;
      label = 80;
     } else {
      $150 = ($7|0)==($0|0);
      do {
       if ($150) {
        $$pre = ((($7)) + 16|0);
        $$pre$phiZ2D = $$pre;
       } else {
        $151 = HEAP32[$7>>2]|0;
        HEAP32[$0>>2] = $151;
        $152 = ((($7)) + 4|0);
        __THREW__ = 0;
        (invoke_iii(3477,($8|0),($152|0))|0);
        $153 = __THREW__; __THREW__ = 0;
        $154 = $153&1;
        if (!($154)) {
         $155 = ((($0)) + 16|0);
         $156 = HEAP32[$155>>2]|0;
         $157 = ((($7)) + 16|0);
         $158 = HEAP32[$157>>2]|0;
         $159 = ($156|0)==($158|0);
         if ($159) {
          $$pre$phiZ2D = $157;
          break;
         }
         HEAP32[$155>>2] = $158;
         $160 = ($158|0)==(0|0);
         if (!($160)) {
          $161 = ((($158)) + 8|0);
          $162 = HEAP32[$161>>2]|0;HEAP32[$161>>2] = (($162+1)|0);
         }
         $163 = ($156|0)==(0|0);
         if ($163) {
          $$pre$phiZ2D = $157;
          break;
         }
         $164 = ((($156)) + 8|0);
         $165 = HEAP32[$164>>2]|0;HEAP32[$164>>2] = (($165-1)|0);
         $166 = ($165|0)==(1);
         if (!($166)) {
          $$pre$phiZ2D = $157;
          break;
         }
         __THREW__ = 0;
         invoke_viii(3262,($156|0),1,1);
         $167 = __THREW__; __THREW__ = 0;
         $168 = $167&1;
         if (!($168)) {
          $$pre$phiZ2D = $157;
          break;
         }
        }
        $190 = ___cxa_find_matching_catch_2()|0;
        $191 = tempRet0;
        $192 = ((($7)) + 16|0);
        $193 = HEAP32[$192>>2]|0;
        $194 = ($193|0)==(0|0);
        if (!($194)) {
         $195 = ((($193)) + 8|0);
         $196 = HEAP32[$195>>2]|0;HEAP32[$195>>2] = (($196-1)|0);
         $197 = ($196|0)==(1);
         if ($197) {
          __THREW__ = 0;
          invoke_viii(3262,($193|0),1,1);
          $198 = __THREW__; __THREW__ = 0;
          $199 = $198&1;
          if ($199) {
           $204 = ___cxa_find_matching_catch_3(0|0)|0;
           $205 = tempRet0;
           $206 = ((($152)) + 11|0);
           $207 = HEAP8[$206>>0]|0;
           $208 = ($207<<24>>24)<(0);
           if (!($208)) {
            $eh$lpad$body$indexZ2D = $204;
            ___clang_call_terminate($eh$lpad$body$indexZ2D);
            // unreachable;
           }
           $209 = HEAP32[$152>>2]|0;
           __ZdlPv($209);
           $eh$lpad$body$indexZ2D = $204;
           ___clang_call_terminate($eh$lpad$body$indexZ2D);
           // unreachable;
          }
         }
        }
        HEAP32[$192>>2] = 0;
        $200 = ((($152)) + 11|0);
        $201 = HEAP8[$200>>0]|0;
        $202 = ($201<<24>>24)<(0);
        if (!($202)) {
         $$2 = $191;$$216 = $190;
         break L46;
        }
        $203 = HEAP32[$152>>2]|0;
        __ZdlPv($203);
        $$2 = $191;$$216 = $190;
        break L46;
       }
      } while(0);
      $169 = HEAP32[$$pre$phiZ2D>>2]|0;
      $170 = ($169|0)==(0|0);
      if (!($170)) {
       $171 = ((($169)) + 8|0);
       $172 = HEAP32[$171>>2]|0;HEAP32[$171>>2] = (($172-1)|0);
       $173 = ($172|0)==(1);
       if ($173) {
        __THREW__ = 0;
        invoke_viii(3262,($169|0),1,1);
        $174 = __THREW__; __THREW__ = 0;
        $175 = $174&1;
        if ($175) {
         $181 = ___cxa_find_matching_catch_2()|0;
         $182 = tempRet0;
         $183 = ((($7)) + 4|0);
         $184 = ((($183)) + 11|0);
         $185 = HEAP8[$184>>0]|0;
         $186 = ($185<<24>>24)<(0);
         if (!($186)) {
          $eh$lpad$body43$index17Z2D = $182;$eh$lpad$body43$indexZ2D = $181;
          label = 80;
          break;
         }
         $187 = HEAP32[$183>>2]|0;
         __ZdlPv($187);
         $eh$lpad$body43$index17Z2D = $182;$eh$lpad$body43$indexZ2D = $181;
         label = 80;
         break;
        }
       }
      }
      HEAP32[$$pre$phiZ2D>>2] = 0;
      $176 = ((($7)) + 4|0);
      $177 = ((($176)) + 11|0);
      $178 = HEAP8[$177>>0]|0;
      $179 = ($178<<24>>24)<(0);
      if ($179) {
       $180 = HEAP32[$176>>2]|0;
       __ZdlPv($180);
      }
      label = 89;
      break L42;
     }
    } while(0);
    if ((label|0) == 80) {
     $$2 = $eh$lpad$body43$index17Z2D;$$216 = $eh$lpad$body43$indexZ2D;
    }
    $$3 = $$2;$$317 = $$216;
    break;
   } else {
    $83 = HEAP32[$81>>2]|0;
    $84 = ((($83)) + 4|0);
    $85 = HEAP32[$84>>2]|0;
    __THREW__ = 0;
    invoke_viiii($85|0,($6|0),($81|0),($2|0),($3|0));
    $86 = __THREW__; __THREW__ = 0;
    $87 = $86&1;
    L85: do {
     if ($87) {
      $126 = ___cxa_find_matching_catch_2()|0;
      $127 = tempRet0;
      $eh$lpad$body32$index10Z2D = $127;$eh$lpad$body32$indexZ2D = $126;
      label = 52;
     } else {
      $88 = ($6|0)==($0|0);
      do {
       if ($88) {
        $$pre49 = ((($6)) + 16|0);
        $$pre$phi50Z2D = $$pre49;
       } else {
        $89 = HEAP32[$6>>2]|0;
        HEAP32[$0>>2] = $89;
        $90 = ((($6)) + 4|0);
        __THREW__ = 0;
        (invoke_iii(3477,($8|0),($90|0))|0);
        $91 = __THREW__; __THREW__ = 0;
        $92 = $91&1;
        if (!($92)) {
         $93 = ((($0)) + 16|0);
         $94 = HEAP32[$93>>2]|0;
         $95 = ((($6)) + 16|0);
         $96 = HEAP32[$95>>2]|0;
         $97 = ($94|0)==($96|0);
         if ($97) {
          $$pre$phi50Z2D = $95;
          break;
         }
         HEAP32[$93>>2] = $96;
         $98 = ($96|0)==(0|0);
         if (!($98)) {
          $99 = ((($96)) + 8|0);
          $100 = HEAP32[$99>>2]|0;HEAP32[$99>>2] = (($100+1)|0);
         }
         $101 = ($94|0)==(0|0);
         if ($101) {
          $$pre$phi50Z2D = $95;
          break;
         }
         $102 = ((($94)) + 8|0);
         $103 = HEAP32[$102>>2]|0;HEAP32[$102>>2] = (($103-1)|0);
         $104 = ($103|0)==(1);
         if (!($104)) {
          $$pre$phi50Z2D = $95;
          break;
         }
         __THREW__ = 0;
         invoke_viii(3262,($94|0),1,1);
         $105 = __THREW__; __THREW__ = 0;
         $106 = $105&1;
         if (!($106)) {
          $$pre$phi50Z2D = $95;
          break;
         }
        }
        $128 = ___cxa_find_matching_catch_2()|0;
        $129 = tempRet0;
        $130 = ((($6)) + 16|0);
        $131 = HEAP32[$130>>2]|0;
        $132 = ($131|0)==(0|0);
        if (!($132)) {
         $133 = ((($131)) + 8|0);
         $134 = HEAP32[$133>>2]|0;HEAP32[$133>>2] = (($134-1)|0);
         $135 = ($134|0)==(1);
         if ($135) {
          __THREW__ = 0;
          invoke_viii(3262,($131|0),1,1);
          $136 = __THREW__; __THREW__ = 0;
          $137 = $136&1;
          if ($137) {
           $142 = ___cxa_find_matching_catch_3(0|0)|0;
           $143 = tempRet0;
           $144 = ((($90)) + 11|0);
           $145 = HEAP8[$144>>0]|0;
           $146 = ($145<<24>>24)<(0);
           if (!($146)) {
            $eh$lpad$body$indexZ2D = $142;
            ___clang_call_terminate($eh$lpad$body$indexZ2D);
            // unreachable;
           }
           $147 = HEAP32[$90>>2]|0;
           __ZdlPv($147);
           $eh$lpad$body$indexZ2D = $142;
           ___clang_call_terminate($eh$lpad$body$indexZ2D);
           // unreachable;
          }
         }
        }
        HEAP32[$130>>2] = 0;
        $138 = ((($90)) + 11|0);
        $139 = HEAP8[$138>>0]|0;
        $140 = ($139<<24>>24)<(0);
        if (!($140)) {
         $$1 = $129;$$115 = $128;
         break L85;
        }
        $141 = HEAP32[$90>>2]|0;
        __ZdlPv($141);
        $$1 = $129;$$115 = $128;
        break L85;
       }
      } while(0);
      $107 = HEAP32[$$pre$phi50Z2D>>2]|0;
      $108 = ($107|0)==(0|0);
      if (!($108)) {
       $109 = ((($107)) + 8|0);
       $110 = HEAP32[$109>>2]|0;HEAP32[$109>>2] = (($110-1)|0);
       $111 = ($110|0)==(1);
       if ($111) {
        __THREW__ = 0;
        invoke_viii(3262,($107|0),1,1);
        $112 = __THREW__; __THREW__ = 0;
        $113 = $112&1;
        if ($113) {
         $119 = ___cxa_find_matching_catch_2()|0;
         $120 = tempRet0;
         $121 = ((($6)) + 4|0);
         $122 = ((($121)) + 11|0);
         $123 = HEAP8[$122>>0]|0;
         $124 = ($123<<24>>24)<(0);
         if (!($124)) {
          $eh$lpad$body32$index10Z2D = $120;$eh$lpad$body32$indexZ2D = $119;
          label = 52;
          break;
         }
         $125 = HEAP32[$121>>2]|0;
         __ZdlPv($125);
         $eh$lpad$body32$index10Z2D = $120;$eh$lpad$body32$indexZ2D = $119;
         label = 52;
         break;
        }
       }
      }
      HEAP32[$$pre$phi50Z2D>>2] = 0;
      $114 = ((($6)) + 4|0);
      $115 = ((($114)) + 11|0);
      $116 = HEAP8[$115>>0]|0;
      $117 = ($116<<24>>24)<(0);
      if ($117) {
       $118 = HEAP32[$114>>2]|0;
       __ZdlPv($118);
      }
      label = 89;
      break L42;
     }
    } while(0);
    if ((label|0) == 52) {
     $$1 = $eh$lpad$body32$index10Z2D;$$115 = $eh$lpad$body32$indexZ2D;
    }
    $$3 = $$1;$$317 = $$115;
    break;
   }
  }
 } while(0);
 do {
  if ((label|0) == 89) {
   if (!($4)) {
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   invoke_viii(4133,($1|0),($0|0),($3|0));
   $210 = __THREW__; __THREW__ = 0;
   $211 = $210&1;
   if ($211) {
    $56 = ___cxa_find_matching_catch_2()|0;
    $57 = tempRet0;
    $$3 = $57;$$317 = $56;
    break;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $212 = ((($0)) + 16|0);
 $213 = HEAP32[$212>>2]|0;
 $214 = ($213|0)==(0|0);
 if (!($214)) {
  $215 = ((($213)) + 8|0);
  $216 = HEAP32[$215>>2]|0;HEAP32[$215>>2] = (($216-1)|0);
  $217 = ($216|0)==(1);
  if ($217) {
   __THREW__ = 0;
   invoke_viii(3262,($213|0),1,1);
   $218 = __THREW__; __THREW__ = 0;
   $219 = $218&1;
   if ($219) {
    $224 = ___cxa_find_matching_catch_3(0|0)|0;
    $225 = tempRet0;
    $226 = ((($8)) + 11|0);
    $227 = HEAP8[$226>>0]|0;
    $228 = ($227<<24>>24)<(0);
    if (!($228)) {
     $eh$lpad$body$indexZ2D = $224;
     ___clang_call_terminate($eh$lpad$body$indexZ2D);
     // unreachable;
    }
    $229 = HEAP32[$8>>2]|0;
    __ZdlPv($229);
    $eh$lpad$body$indexZ2D = $224;
    ___clang_call_terminate($eh$lpad$body$indexZ2D);
    // unreachable;
   }
  }
 }
 HEAP32[$212>>2] = 0;
 $220 = ((($8)) + 11|0);
 $221 = HEAP8[$220>>0]|0;
 $222 = ($221<<24>>24)<(0);
 if (!($222)) {
  ___resumeException($$317|0);
  // unreachable;
 }
 $223 = HEAP32[$8>>2]|0;
 __ZdlPv($223);
 ___resumeException($$317|0);
 // unreachable;
}
function __ZN5osgDB16readRefImageFileERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEPKNS_7OptionsE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$04 = 0, $$1 = 0, $$15 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $3 = sp + 32|0;
 $4 = sp + 12|0;
 $5 = sp;
 $6 = (__ZN5osgDB8Registry8instanceEb(0)|0);
 $7 = ($2|0)==(0|0);
 if ($7) {
  label = 4;
 } else {
  $8 = ((($2)) + 116|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($9|0)==(0|0);
  if ($10) {
   label = 4;
  } else {
   $11 = HEAP32[$9>>2]|0;
   $12 = ((($11)) + 8|0);
   $13 = HEAP32[$12>>2]|0;
   FUNCTION_TABLE_viiii[$13 & 8191]($4,$9,$1,$2);
  }
 }
 do {
  if ((label|0) == 4) {
   $14 = ((($6)) + 48|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = ($15|0)==(0|0);
   if ($16) {
    __ZN5osgDB8Registry23readImageImplementationERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEPKNS_7OptionsE($4,$6,$1,$2);
    break;
   } else {
    $17 = HEAP32[$15>>2]|0;
    $18 = ((($17)) + 8|0);
    $19 = HEAP32[$18>>2]|0;
    FUNCTION_TABLE_viiii[$19 & 8191]($4,$15,$1,$2);
    break;
   }
  }
 } while(0);
 __THREW__ = 0;
 $20 = (invoke_ii(4175,($4|0))|0);
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 L10: do {
  if ($22) {
   label = 12;
  } else {
   $23 = ($20|0)==(0|0);
   if ($23) {
    $32 = HEAP32[$4>>2]|0;
    $33 = $32 | 1;
    $34 = ($33|0)==(5);
    L14: do {
     if (!($34)) {
      __THREW__ = 0;
      $35 = (invoke_ii(3265,2)|0);
      $36 = __THREW__; __THREW__ = 0;
      $37 = $36&1;
      if ($37) {
       label = 12;
       break L10;
      }
      if ($35) {
       __THREW__ = 0;
       $38 = (invoke_ii(3266,2)|0);
       $39 = __THREW__; __THREW__ = 0;
       $40 = $39&1;
       if ($40) {
        label = 12;
        break L10;
       }
       __THREW__ = 0;
       $41 = (invoke_iiii(3267,($38|0),(166826|0),19)|0);
       $42 = __THREW__; __THREW__ = 0;
       $43 = $42&1;
       if ($43) {
        label = 12;
        break L10;
       }
       $44 = ((($1)) + 11|0);
       $45 = HEAP8[$44>>0]|0;
       $46 = ($45<<24>>24)<(0);
       $47 = HEAP32[$1>>2]|0;
       $48 = $46 ? $47 : $1;
       $49 = ((($1)) + 4|0);
       $50 = HEAP32[$49>>2]|0;
       $51 = $45&255;
       $52 = $46 ? $50 : $51;
       __THREW__ = 0;
       $53 = (invoke_iiii(3267,($41|0),($48|0),($52|0))|0);
       $54 = __THREW__; __THREW__ = 0;
       $55 = $54&1;
       if ($55) {
        label = 12;
        break L10;
       }
       __THREW__ = 0;
       $56 = (invoke_iiii(3267,($53|0),(205152|0),2)|0);
       $57 = __THREW__; __THREW__ = 0;
       $58 = $57&1;
       if ($58) {
        label = 12;
        break L10;
       }
       __THREW__ = 0;
       invoke_vii(4127,($5|0),($4|0));
       $59 = __THREW__; __THREW__ = 0;
       $60 = $59&1;
       if ($60) {
        $103 = ___cxa_find_matching_catch_2()|0;
        $104 = tempRet0;
        $$0 = $104;$$04 = $103;
       } else {
        $61 = ((($5)) + 11|0);
        $62 = HEAP8[$61>>0]|0;
        $63 = ($62<<24>>24)<(0);
        $64 = HEAP32[$5>>2]|0;
        $65 = $63 ? $64 : $5;
        $66 = ((($5)) + 4|0);
        $67 = HEAP32[$66>>2]|0;
        $68 = $62&255;
        $69 = $63 ? $67 : $68;
        __THREW__ = 0;
        $70 = (invoke_iiii(3267,($56|0),($65|0),($69|0))|0);
        $71 = __THREW__; __THREW__ = 0;
        $72 = $71&1;
        L25: do {
         if ($72) {
          label = 35;
         } else {
          $73 = HEAP32[$70>>2]|0;
          $74 = ((($73)) + -12|0);
          $75 = HEAP32[$74>>2]|0;
          $76 = (($70) + ($75)|0);
          __THREW__ = 0;
          invoke_vii(3257,($3|0),($76|0));
          $77 = __THREW__; __THREW__ = 0;
          $78 = $77&1;
          if ($78) {
           label = 35;
          } else {
           __THREW__ = 0;
           $79 = (invoke_iii(3255,($3|0),(215188|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           do {
            if (!($81)) {
             $82 = HEAP32[$79>>2]|0;
             $83 = ((($82)) + 28|0);
             $84 = HEAP32[$83>>2]|0;
             __THREW__ = 0;
             $85 = (invoke_iii($84|0,($79|0),10)|0);
             $86 = __THREW__; __THREW__ = 0;
             $87 = $86&1;
             if ($87) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3263,($3|0));
             $94 = __THREW__; __THREW__ = 0;
             $95 = $94&1;
             if ($95) {
              label = 35;
              break L25;
             }
             __THREW__ = 0;
             (invoke_iii(3268,($70|0),($85|0))|0);
             $96 = __THREW__; __THREW__ = 0;
             $97 = $96&1;
             if ($97) {
              label = 35;
              break L25;
             }
             __THREW__ = 0;
             (invoke_ii(3269,($70|0))|0);
             $98 = __THREW__; __THREW__ = 0;
             $99 = $98&1;
             if ($99) {
              label = 35;
              break L25;
             }
             $100 = HEAP8[$61>>0]|0;
             $101 = ($100<<24>>24)<(0);
             if ($101) {
              $102 = HEAP32[$5>>2]|0;
              __ZdlPv($102);
             }
             break L14;
            }
           } while(0);
           $88 = ___cxa_find_matching_catch_2()|0;
           $89 = tempRet0;
           __THREW__ = 0;
           invoke_vi(3263,($3|0));
           $90 = __THREW__; __THREW__ = 0;
           $91 = $90&1;
           if ($91) {
            $92 = ___cxa_find_matching_catch_3(0|0)|0;
            $93 = tempRet0;
            ___clang_call_terminate($92);
            // unreachable;
           } else {
            $eh$lpad$body$index2Z2D = $89;$eh$lpad$body$indexZ2D = $88;
            break;
           }
          }
         }
        } while(0);
        if ((label|0) == 35) {
         $105 = ___cxa_find_matching_catch_2()|0;
         $106 = tempRet0;
         $eh$lpad$body$index2Z2D = $106;$eh$lpad$body$indexZ2D = $105;
        }
        $107 = HEAP8[$61>>0]|0;
        $108 = ($107<<24>>24)<(0);
        if ($108) {
         $109 = HEAP32[$5>>2]|0;
         __ZdlPv($109);
         $$0 = $eh$lpad$body$index2Z2D;$$04 = $eh$lpad$body$indexZ2D;
        } else {
         $$0 = $eh$lpad$body$index2Z2D;$$04 = $eh$lpad$body$indexZ2D;
        }
       }
       $$1 = $$0;$$15 = $$04;
       break L10;
      }
     }
    } while(0);
    HEAP32[$0>>2] = 0;
   } else {
    __THREW__ = 0;
    $24 = (invoke_ii(4175,($4|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if ($26) {
     label = 12;
     break;
    }
    HEAP32[$0>>2] = $24;
    $27 = ($24|0)==(0|0);
    if (!($27)) {
     $28 = ((($24)) + 8|0);
     $29 = HEAP32[$28>>2]|0;HEAP32[$28>>2] = (($29+1)|0);
    }
   }
   $110 = ((($4)) + 16|0);
   $111 = HEAP32[$110>>2]|0;
   $112 = ($111|0)==(0|0);
   if (!($112)) {
    $113 = ((($111)) + 8|0);
    $114 = HEAP32[$113>>2]|0;HEAP32[$113>>2] = (($114-1)|0);
    $115 = ($114|0)==(1);
    if ($115) {
     __THREW__ = 0;
     invoke_viii(3262,($111|0),1,1);
     $116 = __THREW__; __THREW__ = 0;
     $117 = $116&1;
     if ($117) {
      $123 = ___cxa_find_matching_catch_2()|0;
      $124 = tempRet0;
      $125 = ((($4)) + 4|0);
      $126 = ((($125)) + 11|0);
      $127 = HEAP8[$126>>0]|0;
      $128 = ($127<<24>>24)<(0);
      if (!($128)) {
       ___resumeException($123|0);
       // unreachable;
      }
      $129 = HEAP32[$125>>2]|0;
      __ZdlPv($129);
      ___resumeException($123|0);
      // unreachable;
     }
    }
   }
   HEAP32[$110>>2] = 0;
   $118 = ((($4)) + 4|0);
   $119 = ((($118)) + 11|0);
   $120 = HEAP8[$119>>0]|0;
   $121 = ($120<<24>>24)<(0);
   if (!($121)) {
    STACKTOP = sp;return;
   }
   $122 = HEAP32[$118>>2]|0;
   __ZdlPv($122);
   STACKTOP = sp;return;
  }
 } while(0);
 if ((label|0) == 12) {
  $30 = ___cxa_find_matching_catch_2()|0;
  $31 = tempRet0;
  $$1 = $31;$$15 = $30;
 }
 $130 = ((($4)) + 16|0);
 $131 = HEAP32[$130>>2]|0;
 $132 = ($131|0)==(0|0);
 if (!($132)) {
  $133 = ((($131)) + 8|0);
  $134 = HEAP32[$133>>2]|0;HEAP32[$133>>2] = (($134-1)|0);
  $135 = ($134|0)==(1);
  if ($135) {
   __THREW__ = 0;
   invoke_viii(3262,($131|0),1,1);
   $136 = __THREW__; __THREW__ = 0;
   $137 = $136&1;
   if ($137) {
    $143 = ___cxa_find_matching_catch_3(0|0)|0;
    $144 = tempRet0;
    $145 = ((($4)) + 4|0);
    $146 = ((($145)) + 11|0);
    $147 = HEAP8[$146>>0]|0;
    $148 = ($147<<24>>24)<(0);
    if (!($148)) {
     ___clang_call_terminate($143);
     // unreachable;
    }
    $149 = HEAP32[$145>>2]|0;
    __ZdlPv($149);
    ___clang_call_terminate($143);
    // unreachable;
   }
  }
 }
 HEAP32[$130>>2] = 0;
 $138 = ((($4)) + 4|0);
 $139 = ((($138)) + 11|0);
 $140 = HEAP8[$139>>0]|0;
 $141 = ($140<<24>>24)<(0);
 if (!($141)) {
  ___resumeException($$15|0);
  // unreachable;
 }
 $142 = HEAP32[$138>>2]|0;
 __ZdlPv($142);
 ___resumeException($$15|0);
 // unreachable;
}
function __ZN5osgDB17readRefObjectFileERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEPKNS_7OptionsE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$04 = 0, $$1 = 0, $$15 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body9$index2Z2D = 0, $eh$lpad$body9$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $3 = sp + 32|0;
 $4 = sp + 12|0;
 $5 = sp;
 $6 = (__ZN5osgDB8Registry8instanceEb(0)|0);
 __ZN5osgDB8Registry10readObjectERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEPKNS_7OptionsEb($4,$6,$1,$2,1);
 $7 = ((($4)) + 16|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 L1: do {
  if ($9) {
   $18 = HEAP32[$4>>2]|0;
   $19 = $18 | 1;
   $20 = ($19|0)==(5);
   L3: do {
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_ii(3265,2)|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      label = 5;
      break L1;
     }
     if ($21) {
      __THREW__ = 0;
      $24 = (invoke_ii(3266,2)|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if ($26) {
       label = 5;
       break L1;
      }
      __THREW__ = 0;
      $27 = (invoke_iiii(3267,($24|0),(166826|0),19)|0);
      $28 = __THREW__; __THREW__ = 0;
      $29 = $28&1;
      if ($29) {
       label = 5;
       break L1;
      }
      $30 = ((($1)) + 11|0);
      $31 = HEAP8[$30>>0]|0;
      $32 = ($31<<24>>24)<(0);
      $33 = HEAP32[$1>>2]|0;
      $34 = $32 ? $33 : $1;
      $35 = ((($1)) + 4|0);
      $36 = HEAP32[$35>>2]|0;
      $37 = $31&255;
      $38 = $32 ? $36 : $37;
      __THREW__ = 0;
      $39 = (invoke_iiii(3267,($27|0),($34|0),($38|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 5;
       break L1;
      }
      __THREW__ = 0;
      $42 = (invoke_iiii(3267,($39|0),(205152|0),2)|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 5;
       break L1;
      }
      __THREW__ = 0;
      invoke_vii(4127,($5|0),($4|0));
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       $89 = ___cxa_find_matching_catch_2()|0;
       $90 = tempRet0;
       $$0 = $90;$$04 = $89;
      } else {
       $47 = ((($5)) + 11|0);
       $48 = HEAP8[$47>>0]|0;
       $49 = ($48<<24>>24)<(0);
       $50 = HEAP32[$5>>2]|0;
       $51 = $49 ? $50 : $5;
       $52 = ((($5)) + 4|0);
       $53 = HEAP32[$52>>2]|0;
       $54 = $48&255;
       $55 = $49 ? $53 : $54;
       __THREW__ = 0;
       $56 = (invoke_iiii(3267,($42|0),($51|0),($55|0))|0);
       $57 = __THREW__; __THREW__ = 0;
       $58 = $57&1;
       do {
        if ($58) {
         label = 28;
        } else {
         $59 = HEAP32[$56>>2]|0;
         $60 = ((($59)) + -12|0);
         $61 = HEAP32[$60>>2]|0;
         $62 = (($56) + ($61)|0);
         __THREW__ = 0;
         invoke_vii(3257,($3|0),($62|0));
         $63 = __THREW__; __THREW__ = 0;
         $64 = $63&1;
         if ($64) {
          label = 28;
         } else {
          __THREW__ = 0;
          $65 = (invoke_iii(3255,($3|0),(215188|0))|0);
          $66 = __THREW__; __THREW__ = 0;
          $67 = $66&1;
          if (!($67)) {
           $68 = HEAP32[$65>>2]|0;
           $69 = ((($68)) + 28|0);
           $70 = HEAP32[$69>>2]|0;
           __THREW__ = 0;
           $71 = (invoke_iii($70|0,($65|0),10)|0);
           $72 = __THREW__; __THREW__ = 0;
           $73 = $72&1;
           if (!($73)) {
            __THREW__ = 0;
            invoke_vi(3263,($3|0));
            $80 = __THREW__; __THREW__ = 0;
            $81 = $80&1;
            if ($81) {
             label = 28;
             break;
            }
            __THREW__ = 0;
            (invoke_iii(3268,($56|0),($71|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if ($83) {
             label = 28;
             break;
            }
            __THREW__ = 0;
            (invoke_ii(3269,($56|0))|0);
            $84 = __THREW__; __THREW__ = 0;
            $85 = $84&1;
            if ($85) {
             label = 28;
             break;
            }
            $86 = HEAP8[$47>>0]|0;
            $87 = ($86<<24>>24)<(0);
            if ($87) {
             $88 = HEAP32[$5>>2]|0;
             __ZdlPv($88);
            }
            break L3;
           }
          }
          $74 = ___cxa_find_matching_catch_2()|0;
          $75 = tempRet0;
          __THREW__ = 0;
          invoke_vi(3263,($3|0));
          $76 = __THREW__; __THREW__ = 0;
          $77 = $76&1;
          if ($77) {
           $78 = ___cxa_find_matching_catch_3(0|0)|0;
           $79 = tempRet0;
           ___clang_call_terminate($78);
           // unreachable;
          } else {
           $eh$lpad$body9$index2Z2D = $75;$eh$lpad$body9$indexZ2D = $74;
           break;
          }
         }
        }
       } while(0);
       if ((label|0) == 28) {
        $91 = ___cxa_find_matching_catch_2()|0;
        $92 = tempRet0;
        $eh$lpad$body9$index2Z2D = $92;$eh$lpad$body9$indexZ2D = $91;
       }
       $93 = HEAP8[$47>>0]|0;
       $94 = ($93<<24>>24)<(0);
       if ($94) {
        $95 = HEAP32[$5>>2]|0;
        __ZdlPv($95);
        $$0 = $eh$lpad$body9$index2Z2D;$$04 = $eh$lpad$body9$indexZ2D;
       } else {
        $$0 = $eh$lpad$body9$index2Z2D;$$04 = $eh$lpad$body9$indexZ2D;
       }
      }
      $$1 = $$0;$$15 = $$04;
      break L1;
     }
    }
   } while(0);
   HEAP32[$0>>2] = 0;
   label = 33;
  } else {
   __THREW__ = 0;
   $10 = (invoke_ii(4176,($4|0))|0);
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if ($12) {
    label = 5;
   } else {
    HEAP32[$0>>2] = $10;
    $13 = ($10|0)==(0|0);
    if ($13) {
     label = 33;
    } else {
     $14 = ((($10)) + 8|0);
     $15 = HEAP32[$14>>2]|0;HEAP32[$14>>2] = (($15+1)|0);
     label = 33;
    }
   }
  }
 } while(0);
 if ((label|0) == 5) {
  $16 = ___cxa_find_matching_catch_2()|0;
  $17 = tempRet0;
  $$1 = $17;$$15 = $16;
 }
 else if ((label|0) == 33) {
  $96 = HEAP32[$7>>2]|0;
  $97 = ($96|0)==(0|0);
  if (!($97)) {
   $98 = ((($96)) + 8|0);
   $99 = HEAP32[$98>>2]|0;HEAP32[$98>>2] = (($99-1)|0);
   $100 = ($99|0)==(1);
   if ($100) {
    __THREW__ = 0;
    invoke_viii(3262,($96|0),1,1);
    $101 = __THREW__; __THREW__ = 0;
    $102 = $101&1;
    if ($102) {
     $108 = ___cxa_find_matching_catch_2()|0;
     $109 = tempRet0;
     $110 = ((($4)) + 4|0);
     $111 = ((($110)) + 11|0);
     $112 = HEAP8[$111>>0]|0;
     $113 = ($112<<24>>24)<(0);
     if (!($113)) {
      ___resumeException($108|0);
      // unreachable;
     }
     $114 = HEAP32[$110>>2]|0;
     __ZdlPv($114);
     ___resumeException($108|0);
     // unreachable;
    }
   }
  }
  HEAP32[$7>>2] = 0;
  $103 = ((($4)) + 4|0);
  $104 = ((($103)) + 11|0);
  $105 = HEAP8[$104>>0]|0;
  $106 = ($105<<24>>24)<(0);
  if (!($106)) {
   STACKTOP = sp;return;
  }
  $107 = HEAP32[$103>>2]|0;
  __ZdlPv($107);
  STACKTOP = sp;return;
 }
 $115 = HEAP32[$7>>2]|0;
 $116 = ($115|0)==(0|0);
 if (!($116)) {
  $117 = ((($115)) + 8|0);
  $118 = HEAP32[$117>>2]|0;HEAP32[$117>>2] = (($118-1)|0);
  $119 = ($118|0)==(1);
  if ($119) {
   __THREW__ = 0;
   invoke_viii(3262,($115|0),1,1);
   $120 = __THREW__; __THREW__ = 0;
   $121 = $120&1;
   if ($121) {
    $127 = ___cxa_find_matching_catch_3(0|0)|0;
    $128 = tempRet0;
    $129 = ((($4)) + 4|0);
    $130 = ((($129)) + 11|0);
    $131 = HEAP8[$130>>0]|0;
    $132 = ($131<<24>>24)<(0);
    if (!($132)) {
     ___clang_call_terminate($127);
     // unreachable;
    }
    $133 = HEAP32[$129>>2]|0;
    __ZdlPv($133);
    ___clang_call_terminate($127);
    // unreachable;
   }
  }
 }
 HEAP32[$7>>2] = 0;
 $122 = ((($4)) + 4|0);
 $123 = ((($122)) + 11|0);
 $124 = HEAP8[$123>>0]|0;
 $125 = ($124<<24>>24)<(0);
 if (!($125)) {
  ___resumeException($$15|0);
  // unreachable;
 }
 $126 = HEAP32[$122>>2]|0;
 __ZdlPv($126);
 ___resumeException($$15|0);
 // unreachable;
}
function __ZN5osgDB8RegistryD2Ev($0) {
 $0 = $0|0;
 var $$0 = 0, $$02 = 0, $$08$i = 0, $$08$i37 = 0, $$08$i80 = 0, $$08$i90 = 0, $$1 = 0, $$11 = 0, $$110 = 0, $$1120 = 0, $$15 = 0, $$1524 = 0, $$16 = 0, $$1625 = 0, $$17 = 0, $$1726 = 0, $$18 = 0, $$1827 = 0, $$19 = 0, $$1928 = 0;
 var $$2 = 0, $$21 = 0, $$211 = 0, $$2130 = 0, $$22 = 0, $$2231 = 0, $$23 = 0, $$2332 = 0, $$4 = 0, $$413 = 0, $$7 = 0, $$716 = 0, $$pre$i = 0, $$pre$i$i$i = 0, $$pre$i$i$i72 = 0, $$pre$i105 = 0, $$pre$i112 = 0, $$pre$i119 = 0, $$pre$i36 = 0, $$pre$i39 = 0;
 var $$pre$i50 = 0, $$pre$i53 = 0, $$pre$i56 = 0, $$pre$i74 = 0, $$pre$i82 = 0, $$pre$i92 = 0, $$pre9$i = 0, $$pre9$i40 = 0, $$pre9$i83 = 0, $$pre9$i93 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0;
 var $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0;
 var $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0;
 var $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0;
 var $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0;
 var $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0;
 var $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0;
 var $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0;
 var $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0;
 var $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0;
 var $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0;
 var $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0;
 var $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0;
 var $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0;
 var $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0;
 var $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0;
 var $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0;
 var $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0;
 var $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0;
 var $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0;
 var $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0;
 var $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i42 = 0, $scevgep$i$i$i$i$i85 = 0, $scevgep$i$i$i$i$i95 = 0, $scevgep5$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i43 = 0, $scevgep5$i$i$i$i$i86 = 0, $scevgep5$i$i$i$i$i96 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (75032);
 __THREW__ = 0;
 invoke_vi(4177,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 L1: do {
  if ($2) {
   $250 = ___cxa_find_matching_catch_2()|0;
   $251 = tempRet0;
   $252 = ((($0)) + 244|0);
   $253 = HEAP32[$252>>2]|0;
   $254 = ($253|0)==(0|0);
   if (!($254)) {
    $255 = ((($253)) + 8|0);
    $256 = HEAP32[$255>>2]|0;HEAP32[$255>>2] = (($256-1)|0);
    $257 = ($256|0)==(1);
    if ($257) {
     __THREW__ = 0;
     invoke_viii(3262,($253|0),1,1);
     $258 = __THREW__; __THREW__ = 0;
     $259 = $258&1;
     if ($259) {
      $529 = ___cxa_find_matching_catch_3(0|0)|0;
      $530 = tempRet0;
      ___clang_call_terminate($529);
      // unreachable;
     }
    }
   }
   HEAP32[$252>>2] = 0;
   $$0 = $251;$$02 = $250;
   label = 93;
  } else {
   $3 = ((($0)) + 244|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = ($4|0)==(0|0);
   if (!($5)) {
    $6 = ((($4)) + 8|0);
    $7 = HEAP32[$6>>2]|0;HEAP32[$6>>2] = (($7-1)|0);
    $8 = ($7|0)==(1);
    if ($8) {
     __THREW__ = 0;
     invoke_viii(3262,($4|0),1,1);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      $260 = ___cxa_find_matching_catch_2()|0;
      $261 = tempRet0;
      $$0 = $261;$$02 = $260;
      label = 93;
      break;
     }
    }
   }
   HEAP32[$3>>2] = 0;
   $11 = ((($0)) + 240|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = ($12|0)==(0|0);
   if (!($13)) {
    $14 = ((($12)) + 8|0);
    $15 = HEAP32[$14>>2]|0;HEAP32[$14>>2] = (($15-1)|0);
    $16 = ($15|0)==(1);
    if ($16) {
     __THREW__ = 0;
     invoke_viii(3262,($12|0),1,1);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      $262 = ___cxa_find_matching_catch_2()|0;
      $263 = tempRet0;
      $$1 = $263;$$110 = $262;
      label = 98;
      break;
     }
    }
   }
   HEAP32[$11>>2] = 0;
   $19 = ((($0)) + 236|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = ($20|0)==(0|0);
   if (!($21)) {
    $22 = HEAP32[$20>>2]|0;
    $23 = ((($22)) + -12|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = (($20) + ($24)|0);
    $26 = ((($25)) + 8|0);
    $27 = HEAP32[$26>>2]|0;HEAP32[$26>>2] = (($27-1)|0);
    $28 = ($27|0)==(1);
    if ($28) {
     __THREW__ = 0;
     invoke_viii(3262,($25|0),1,1);
     $29 = __THREW__; __THREW__ = 0;
     $30 = $29&1;
     if ($30) {
      $272 = ___cxa_find_matching_catch_2()|0;
      $273 = tempRet0;
      $$2 = $273;$$211 = $272;
      label = 102;
      break;
     }
    }
   }
   HEAP32[$19>>2] = 0;
   $31 = ((($0)) + 224|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ($32|0)==(0|0);
   if (!($33)) {
    $34 = ((($0)) + 228|0);
    $35 = HEAP32[$34>>2]|0;
    $36 = ($35|0)==($32|0);
    if ($36) {
     $45 = $32;
    } else {
     $38 = $35;
     while(1) {
      $37 = ((($38)) + -12|0);
      HEAP32[$34>>2] = $37;
      $39 = ((($37)) + 11|0);
      $40 = HEAP8[$39>>0]|0;
      $41 = ($40<<24>>24)<(0);
      if ($41) {
       $44 = HEAP32[$37>>2]|0;
       __ZdlPv($44);
       $$pre$i$i$i = HEAP32[$34>>2]|0;
       $42 = $$pre$i$i$i;
      } else {
       $42 = $37;
      }
      $43 = ($42|0)==($32|0);
      if ($43) {
       break;
      } else {
       $38 = $42;
      }
     }
     $$pre$i = HEAP32[$31>>2]|0;
     $45 = $$pre$i;
    }
    __ZdlPv($45);
   }
   $46 = ((($0)) + 212|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = ($47|0)==(0|0);
   if (!($48)) {
    $49 = ((($47)) + 8|0);
    $50 = HEAP32[$49>>2]|0;HEAP32[$49>>2] = (($50-1)|0);
    $51 = ($50|0)==(1);
    if ($51) {
     __THREW__ = 0;
     invoke_viii(3262,($47|0),1,1);
     $52 = __THREW__; __THREW__ = 0;
     $53 = $52&1;
     if ($53) {
      $301 = ___cxa_find_matching_catch_2()|0;
      $302 = tempRet0;
      $$4 = $302;$$413 = $301;
      label = 114;
      break;
     }
    }
   }
   HEAP32[$46>>2] = 0;
   $54 = ((($0)) + 188|0);
   __ZNSt3__212__deque_baseINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS4_IS6_EEE5clearEv($54);
   $55 = ((($0)) + 192|0);
   $56 = HEAP32[$55>>2]|0;
   $57 = ((($0)) + 196|0);
   $58 = HEAP32[$57>>2]|0;
   $59 = ($56|0)==($58|0);
   if (!($59)) {
    $$08$i = $56;
    while(1) {
     $60 = HEAP32[$$08$i>>2]|0;
     __ZdlPv($60);
     $61 = ((($$08$i)) + 4|0);
     $62 = ($61|0)==($58|0);
     if ($62) {
      break;
     } else {
      $$08$i = $61;
     }
    }
    $$pre$i36 = HEAP32[$55>>2]|0;
    $$pre9$i = HEAP32[$57>>2]|0;
    $63 = ($$pre9$i|0)==($$pre$i36|0);
    if (!($63)) {
     $scevgep$i$i$i$i$i = ((($$pre9$i)) + -4|0);
     $64 = $scevgep$i$i$i$i$i;
     $65 = $$pre$i36;
     $66 = (($64) - ($65))|0;
     $67 = $66 >>> 2;
     $68 = $67 ^ -1;
     $scevgep5$i$i$i$i$i = (($$pre9$i) + ($68<<2)|0);
     HEAP32[$57>>2] = $scevgep5$i$i$i$i$i;
    }
   }
   $69 = HEAP32[$54>>2]|0;
   $70 = ($69|0)==(0|0);
   if (!($70)) {
    __ZdlPv($69);
   }
   $71 = ((($0)) + 164|0);
   __ZNSt3__212__deque_baseINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS4_IS6_EEE5clearEv($71);
   $72 = ((($0)) + 168|0);
   $73 = HEAP32[$72>>2]|0;
   $74 = ((($0)) + 172|0);
   $75 = HEAP32[$74>>2]|0;
   $76 = ($73|0)==($75|0);
   if (!($76)) {
    $$08$i37 = $73;
    while(1) {
     $77 = HEAP32[$$08$i37>>2]|0;
     __ZdlPv($77);
     $78 = ((($$08$i37)) + 4|0);
     $79 = ($78|0)==($75|0);
     if ($79) {
      break;
     } else {
      $$08$i37 = $78;
     }
    }
    $$pre$i39 = HEAP32[$72>>2]|0;
    $$pre9$i40 = HEAP32[$74>>2]|0;
    $80 = ($$pre9$i40|0)==($$pre$i39|0);
    if (!($80)) {
     $scevgep$i$i$i$i$i42 = ((($$pre9$i40)) + -4|0);
     $81 = $scevgep$i$i$i$i$i42;
     $82 = $$pre$i39;
     $83 = (($81) - ($82))|0;
     $84 = $83 >>> 2;
     $85 = $84 ^ -1;
     $scevgep5$i$i$i$i$i43 = (($$pre9$i40) + ($85<<2)|0);
     HEAP32[$74>>2] = $scevgep5$i$i$i$i$i43;
    }
   }
   $86 = HEAP32[$71>>2]|0;
   $87 = ($86|0)==(0|0);
   if (!($87)) {
    __ZdlPv($86);
   }
   $88 = ((($0)) + 160|0);
   $89 = HEAP32[$88>>2]|0;
   $90 = ($89|0)==(0|0);
   if (!($90)) {
    $91 = ((($89)) + 8|0);
    $92 = HEAP32[$91>>2]|0;HEAP32[$91>>2] = (($92-1)|0);
    $93 = ($92|0)==(1);
    if ($93) {
     __THREW__ = 0;
     invoke_viii(3262,($89|0),1,1);
     $94 = __THREW__; __THREW__ = 0;
     $95 = $94&1;
     if ($95) {
      $345 = ___cxa_find_matching_catch_2()|0;
      $346 = tempRet0;
      $$7 = $346;$$716 = $345;
      label = 132;
      break;
     }
    }
   }
   HEAP32[$88>>2] = 0;
   $96 = ((($0)) + 148|0);
   $97 = ((($0)) + 152|0);
   $98 = HEAP32[$97>>2]|0;
   __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES7_EENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($96,$98);
   $99 = ((($0)) + 136|0);
   $100 = ((($0)) + 140|0);
   $101 = HEAP32[$100>>2]|0;
   __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES7_EENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($99,$101);
   $102 = ((($0)) + 120|0);
   $103 = ((($0)) + 124|0);
   $104 = HEAP32[$103>>2]|0;
   __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7ref_ptrIN5osgDB7ArchiveEEEEENS_19__map_value_compareIS7_SD_NS_4lessIS7_EELb1EEENS5_ISD_EEE7destroyEPNS_11__tree_nodeISD_PvEE($102,$104);
   $105 = ((($0)) + 108|0);
   __THREW__ = 0;
   invoke_vi(707,($105|0));
   $106 = __THREW__; __THREW__ = 0;
   $107 = $106&1;
   if ($107) {
    $355 = ___cxa_find_matching_catch_2()|0;
    $356 = tempRet0;
    $$11 = $356;$$1120 = $355;
    label = 133;
    break;
   }
   $108 = ((($0)) + 96|0);
   $109 = HEAP32[$108>>2]|0;
   $110 = ($109|0)==(0|0);
   if (!($110)) {
    $111 = ((($0)) + 100|0);
    $112 = HEAP32[$111>>2]|0;
    $113 = ($112|0)==($109|0);
    do {
     if ($113) {
      $127 = $109;
     } else {
      $115 = $112;
      L69: while(1) {
       $114 = ((($115)) + -4|0);
       HEAP32[$111>>2] = $114;
       $116 = HEAP32[$114>>2]|0;
       $117 = ($116|0)==(0|0);
       do {
        if (!($117)) {
         $118 = ((($116)) + 8|0);
         $119 = HEAP32[$118>>2]|0;HEAP32[$118>>2] = (($119-1)|0);
         $120 = ($119|0)==(1);
         if (!($120)) {
          break;
         }
         __THREW__ = 0;
         invoke_viii(3262,($116|0),1,1);
         $121 = __THREW__; __THREW__ = 0;
         $122 = $121&1;
         if ($122) {
          label = 43;
          break L69;
         }
        }
       } while(0);
       HEAP32[$114>>2] = 0;
       $123 = HEAP32[$111>>2]|0;
       $124 = ($123|0)==($109|0);
       if ($124) {
        label = 44;
        break;
       } else {
        $115 = $123;
       }
      }
      if ((label|0) == 43) {
       $125 = ___cxa_find_matching_catch_2()|0;
       $126 = tempRet0;
       ___cxa_call_unexpected(($125|0));
       // unreachable;
      }
      else if ((label|0) == 44) {
       $$pre$i50 = HEAP32[$108>>2]|0;
       $127 = $$pre$i50;
       break;
      }
     }
    } while(0);
    __ZdlPv($127);
   }
   $128 = ((($0)) + 84|0);
   $129 = HEAP32[$128>>2]|0;
   $130 = ($129|0)==(0|0);
   if (!($130)) {
    $131 = ((($0)) + 88|0);
    $132 = HEAP32[$131>>2]|0;
    $133 = ($132|0)==($129|0);
    do {
     if ($133) {
      $147 = $129;
     } else {
      $135 = $132;
      L83: while(1) {
       $134 = ((($135)) + -4|0);
       HEAP32[$131>>2] = $134;
       $136 = HEAP32[$134>>2]|0;
       $137 = ($136|0)==(0|0);
       do {
        if (!($137)) {
         $138 = ((($136)) + 8|0);
         $139 = HEAP32[$138>>2]|0;HEAP32[$138>>2] = (($139-1)|0);
         $140 = ($139|0)==(1);
         if (!($140)) {
          break;
         }
         __THREW__ = 0;
         invoke_viii(3262,($136|0),1,1);
         $141 = __THREW__; __THREW__ = 0;
         $142 = $141&1;
         if ($142) {
          label = 52;
          break L83;
         }
        }
       } while(0);
       HEAP32[$134>>2] = 0;
       $143 = HEAP32[$131>>2]|0;
       $144 = ($143|0)==($129|0);
       if ($144) {
        label = 53;
        break;
       } else {
        $135 = $143;
       }
      }
      if ((label|0) == 52) {
       $145 = ___cxa_find_matching_catch_2()|0;
       $146 = tempRet0;
       ___cxa_call_unexpected(($145|0));
       // unreachable;
      }
      else if ((label|0) == 53) {
       $$pre$i53 = HEAP32[$128>>2]|0;
       $147 = $$pre$i53;
       break;
      }
     }
    } while(0);
    __ZdlPv($147);
   }
   $148 = ((($0)) + 72|0);
   $149 = HEAP32[$148>>2]|0;
   $150 = ($149|0)==(0|0);
   if (!($150)) {
    $151 = ((($0)) + 76|0);
    $152 = HEAP32[$151>>2]|0;
    $153 = ($152|0)==($149|0);
    do {
     if ($153) {
      $167 = $149;
     } else {
      $155 = $152;
      L97: while(1) {
       $154 = ((($155)) + -4|0);
       HEAP32[$151>>2] = $154;
       $156 = HEAP32[$154>>2]|0;
       $157 = ($156|0)==(0|0);
       do {
        if (!($157)) {
         $158 = ((($156)) + 8|0);
         $159 = HEAP32[$158>>2]|0;HEAP32[$158>>2] = (($159-1)|0);
         $160 = ($159|0)==(1);
         if (!($160)) {
          break;
         }
         __THREW__ = 0;
         invoke_viii(3262,($156|0),1,1);
         $161 = __THREW__; __THREW__ = 0;
         $162 = $161&1;
         if ($162) {
          label = 61;
          break L97;
         }
        }
       } while(0);
       HEAP32[$154>>2] = 0;
       $163 = HEAP32[$151>>2]|0;
       $164 = ($163|0)==($149|0);
       if ($164) {
        label = 62;
        break;
       } else {
        $155 = $163;
       }
      }
      if ((label|0) == 61) {
       $165 = ___cxa_find_matching_catch_2()|0;
       $166 = tempRet0;
       ___cxa_call_unexpected(($165|0));
       // unreachable;
      }
      else if ((label|0) == 62) {
       $$pre$i56 = HEAP32[$148>>2]|0;
       $167 = $$pre$i56;
       break;
      }
     }
    } while(0);
    __ZdlPv($167);
   }
   $168 = ((($0)) + 60|0);
   __THREW__ = 0;
   invoke_vi(707,($168|0));
   $169 = __THREW__; __THREW__ = 0;
   $170 = $169&1;
   if ($170) {
    $429 = ___cxa_find_matching_catch_2()|0;
    $430 = tempRet0;
    $$15 = $430;$$1524 = $429;
    label = 163;
    break;
   }
   $171 = ((($0)) + 56|0);
   $172 = HEAP32[$171>>2]|0;
   $173 = ($172|0)==(0|0);
   do {
    if (!($173)) {
     $174 = HEAP32[$172>>2]|0;
     $175 = ((($174)) + -12|0);
     $176 = HEAP32[$175>>2]|0;
     $177 = (($172) + ($176)|0);
     $178 = ((($177)) + 8|0);
     $179 = HEAP32[$178>>2]|0;HEAP32[$178>>2] = (($179-1)|0);
     $180 = ($179|0)==(1);
     if ($180) {
      __THREW__ = 0;
      invoke_viii(3262,($177|0),1,1);
      $181 = __THREW__; __THREW__ = 0;
      $182 = $181&1;
      if (!($182)) {
       break;
      }
      $434 = ___cxa_find_matching_catch_2()|0;
      $435 = tempRet0;
      $$16 = $435;$$1625 = $434;
      label = 168;
      break L1;
     }
    }
   } while(0);
   HEAP32[$171>>2] = 0;
   $183 = ((($0)) + 52|0);
   $184 = HEAP32[$183>>2]|0;
   $185 = ($184|0)==(0|0);
   do {
    if (!($185)) {
     $186 = HEAP32[$184>>2]|0;
     $187 = ((($186)) + -12|0);
     $188 = HEAP32[$187>>2]|0;
     $189 = (($184) + ($188)|0);
     $190 = ((($189)) + 8|0);
     $191 = HEAP32[$190>>2]|0;HEAP32[$190>>2] = (($191-1)|0);
     $192 = ($191|0)==(1);
     if (!($192)) {
      break;
     }
     __THREW__ = 0;
     invoke_viii(3262,($189|0),1,1);
     $193 = __THREW__; __THREW__ = 0;
     $194 = $193&1;
     if (!($194)) {
      break;
     }
     $448 = ___cxa_find_matching_catch_2()|0;
     $449 = tempRet0;
     $$17 = $449;$$1726 = $448;
     label = 173;
     break L1;
    }
   } while(0);
   HEAP32[$183>>2] = 0;
   $195 = ((($0)) + 48|0);
   $196 = HEAP32[$195>>2]|0;
   $197 = ($196|0)==(0|0);
   do {
    if (!($197)) {
     $198 = HEAP32[$196>>2]|0;
     $199 = ((($198)) + -12|0);
     $200 = HEAP32[$199>>2]|0;
     $201 = (($196) + ($200)|0);
     $202 = ((($201)) + 8|0);
     $203 = HEAP32[$202>>2]|0;HEAP32[$202>>2] = (($203-1)|0);
     $204 = ($203|0)==(1);
     if (!($204)) {
      break;
     }
     __THREW__ = 0;
     invoke_viii(3262,($201|0),1,1);
     $205 = __THREW__; __THREW__ = 0;
     $206 = $205&1;
     if (!($206)) {
      break;
     }
     $462 = ___cxa_find_matching_catch_2()|0;
     $463 = tempRet0;
     $$18 = $463;$$1827 = $462;
     label = 178;
     break L1;
    }
   } while(0);
   HEAP32[$195>>2] = 0;
   $207 = ((($0)) + 44|0);
   $208 = HEAP32[$207>>2]|0;
   $209 = ($208|0)==(0|0);
   do {
    if (!($209)) {
     $210 = HEAP32[$208>>2]|0;
     $211 = ((($210)) + -12|0);
     $212 = HEAP32[$211>>2]|0;
     $213 = (($208) + ($212)|0);
     $214 = ((($213)) + 8|0);
     $215 = HEAP32[$214>>2]|0;HEAP32[$214>>2] = (($215-1)|0);
     $216 = ($215|0)==(1);
     if (!($216)) {
      break;
     }
     __THREW__ = 0;
     invoke_viii(3262,($213|0),1,1);
     $217 = __THREW__; __THREW__ = 0;
     $218 = $217&1;
     if (!($218)) {
      break;
     }
     $476 = ___cxa_find_matching_catch_2()|0;
     $477 = tempRet0;
     $$19 = $477;$$1928 = $476;
     label = 183;
     break L1;
    }
   } while(0);
   HEAP32[$207>>2] = 0;
   $219 = ((($0)) + 32|0);
   $220 = ((($0)) + 36|0);
   $221 = HEAP32[$220>>2]|0;
   __ZNSt3__26__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EENS4_IS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($219,$221);
   $222 = ((($0)) + 24|0);
   $223 = HEAP32[$222>>2]|0;
   $224 = ($223|0)==(0|0);
   do {
    if (!($224)) {
     $225 = ((($223)) + 8|0);
     $226 = HEAP32[$225>>2]|0;HEAP32[$225>>2] = (($226-1)|0);
     $227 = ($226|0)==(1);
     if (!($227)) {
      break;
     }
     __THREW__ = 0;
     invoke_viii(3262,($223|0),1,1);
     $228 = __THREW__; __THREW__ = 0;
     $229 = $228&1;
     if (!($229)) {
      break;
     }
     $490 = ___cxa_find_matching_catch_2()|0;
     $491 = tempRet0;
     $$21 = $491;$$2130 = $490;
     label = 188;
     break L1;
    }
   } while(0);
   HEAP32[$222>>2] = 0;
   $230 = ((($0)) + 20|0);
   $231 = HEAP32[$230>>2]|0;
   $232 = ($231|0)==(0|0);
   do {
    if (!($232)) {
     $233 = ((($231)) + 8|0);
     $234 = HEAP32[$233>>2]|0;HEAP32[$233>>2] = (($234-1)|0);
     $235 = ($234|0)==(1);
     if (!($235)) {
      break;
     }
     __THREW__ = 0;
     invoke_viii(3262,($231|0),1,1);
     $236 = __THREW__; __THREW__ = 0;
     $237 = $236&1;
     if (!($237)) {
      break;
     }
     $503 = ___cxa_find_matching_catch_2()|0;
     $504 = tempRet0;
     $$22 = $504;$$2231 = $503;
     label = 193;
     break L1;
    }
   } while(0);
   HEAP32[$230>>2] = 0;
   $238 = ((($0)) + 16|0);
   $239 = HEAP32[$238>>2]|0;
   $240 = ($239|0)==(0|0);
   if ($240) {
    HEAP32[$238>>2] = 0;
    __ZN3osg10ReferencedD2Ev($0);
    return;
   }
   $241 = HEAP32[$239>>2]|0;
   $242 = ((($241)) + -12|0);
   $243 = HEAP32[$242>>2]|0;
   $244 = (($239) + ($243)|0);
   $245 = ((($244)) + 8|0);
   $246 = HEAP32[$245>>2]|0;HEAP32[$245>>2] = (($246-1)|0);
   $247 = ($246|0)==(1);
   if (!($247)) {
    HEAP32[$238>>2] = 0;
    __ZN3osg10ReferencedD2Ev($0);
    return;
   }
   __THREW__ = 0;
   invoke_viii(3262,($244|0),1,1);
   $248 = __THREW__; __THREW__ = 0;
   $249 = $248&1;
   if ($249) {
    $513 = ___cxa_find_matching_catch_2()|0;
    $514 = tempRet0;
    $$23 = $514;$$2332 = $513;
    break;
   } else {
    HEAP32[$238>>2] = 0;
    __ZN3osg10ReferencedD2Ev($0);
    return;
   }
  }
 } while(0);
 if ((label|0) == 93) {
  $264 = ((($0)) + 240|0);
  $265 = HEAP32[$264>>2]|0;
  $266 = ($265|0)==(0|0);
  if (!($266)) {
   $267 = ((($265)) + 8|0);
   $268 = HEAP32[$267>>2]|0;HEAP32[$267>>2] = (($268-1)|0);
   $269 = ($268|0)==(1);
   if ($269) {
    __THREW__ = 0;
    invoke_viii(3262,($265|0),1,1);
    $270 = __THREW__; __THREW__ = 0;
    $271 = $270&1;
    if ($271) {
     $529 = ___cxa_find_matching_catch_3(0|0)|0;
     $530 = tempRet0;
     ___clang_call_terminate($529);
     // unreachable;
    }
   }
  }
  HEAP32[$264>>2] = 0;
  $$1 = $$0;$$110 = $$02;
  label = 98;
 }
 if ((label|0) == 98) {
  $274 = ((($0)) + 236|0);
  $275 = HEAP32[$274>>2]|0;
  $276 = ($275|0)==(0|0);
  if (!($276)) {
   $277 = HEAP32[$275>>2]|0;
   $278 = ((($277)) + -12|0);
   $279 = HEAP32[$278>>2]|0;
   $280 = (($275) + ($279)|0);
   $281 = ((($280)) + 8|0);
   $282 = HEAP32[$281>>2]|0;HEAP32[$281>>2] = (($282-1)|0);
   $283 = ($282|0)==(1);
   if ($283) {
    __THREW__ = 0;
    invoke_viii(3262,($280|0),1,1);
    $284 = __THREW__; __THREW__ = 0;
    $285 = $284&1;
    if ($285) {
     $529 = ___cxa_find_matching_catch_3(0|0)|0;
     $530 = tempRet0;
     ___clang_call_terminate($529);
     // unreachable;
    }
   }
  }
  HEAP32[$274>>2] = 0;
  $$2 = $$1;$$211 = $$110;
  label = 102;
 }
 if ((label|0) == 102) {
  $286 = ((($0)) + 224|0);
  $287 = HEAP32[$286>>2]|0;
  $288 = ($287|0)==(0|0);
  if (!($288)) {
   $289 = ((($0)) + 228|0);
   $290 = HEAP32[$289>>2]|0;
   $291 = ($290|0)==($287|0);
   if ($291) {
    $300 = $287;
   } else {
    $293 = $290;
    while(1) {
     $292 = ((($293)) + -12|0);
     HEAP32[$289>>2] = $292;
     $294 = ((($292)) + 11|0);
     $295 = HEAP8[$294>>0]|0;
     $296 = ($295<<24>>24)<(0);
     if ($296) {
      $299 = HEAP32[$292>>2]|0;
      __ZdlPv($299);
      $$pre$i$i$i72 = HEAP32[$289>>2]|0;
      $297 = $$pre$i$i$i72;
     } else {
      $297 = $292;
     }
     $298 = ($297|0)==($287|0);
     if ($298) {
      break;
     } else {
      $293 = $297;
     }
    }
    $$pre$i74 = HEAP32[$286>>2]|0;
    $300 = $$pre$i74;
   }
   __ZdlPv($300);
  }
  $303 = ((($0)) + 212|0);
  $304 = HEAP32[$303>>2]|0;
  $305 = ($304|0)==(0|0);
  if (!($305)) {
   $306 = ((($304)) + 8|0);
   $307 = HEAP32[$306>>2]|0;HEAP32[$306>>2] = (($307-1)|0);
   $308 = ($307|0)==(1);
   if ($308) {
    __THREW__ = 0;
    invoke_viii(3262,($304|0),1,1);
    $309 = __THREW__; __THREW__ = 0;
    $310 = $309&1;
    if ($310) {
     $529 = ___cxa_find_matching_catch_3(0|0)|0;
     $530 = tempRet0;
     ___clang_call_terminate($529);
     // unreachable;
    }
   }
  }
  HEAP32[$303>>2] = 0;
  $$4 = $$2;$$413 = $$211;
  label = 114;
 }
 if ((label|0) == 114) {
  $311 = ((($0)) + 188|0);
  __ZNSt3__212__deque_baseINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS4_IS6_EEE5clearEv($311);
  $312 = ((($0)) + 192|0);
  $313 = HEAP32[$312>>2]|0;
  $314 = ((($0)) + 196|0);
  $315 = HEAP32[$314>>2]|0;
  $316 = ($313|0)==($315|0);
  if (!($316)) {
   $$08$i80 = $313;
   while(1) {
    $317 = HEAP32[$$08$i80>>2]|0;
    __ZdlPv($317);
    $318 = ((($$08$i80)) + 4|0);
    $319 = ($318|0)==($315|0);
    if ($319) {
     break;
    } else {
     $$08$i80 = $318;
    }
   }
   $$pre$i82 = HEAP32[$312>>2]|0;
   $$pre9$i83 = HEAP32[$314>>2]|0;
   $320 = ($$pre9$i83|0)==($$pre$i82|0);
   if (!($320)) {
    $scevgep$i$i$i$i$i85 = ((($$pre9$i83)) + -4|0);
    $321 = $scevgep$i$i$i$i$i85;
    $322 = $$pre$i82;
    $323 = (($321) - ($322))|0;
    $324 = $323 >>> 2;
    $325 = $324 ^ -1;
    $scevgep5$i$i$i$i$i86 = (($$pre9$i83) + ($325<<2)|0);
    HEAP32[$314>>2] = $scevgep5$i$i$i$i$i86;
   }
  }
  $326 = HEAP32[$311>>2]|0;
  $327 = ($326|0)==(0|0);
  if (!($327)) {
   __ZdlPv($326);
  }
  $328 = ((($0)) + 164|0);
  __ZNSt3__212__deque_baseINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS4_IS6_EEE5clearEv($328);
  $329 = ((($0)) + 168|0);
  $330 = HEAP32[$329>>2]|0;
  $331 = ((($0)) + 172|0);
  $332 = HEAP32[$331>>2]|0;
  $333 = ($330|0)==($332|0);
  if (!($333)) {
   $$08$i90 = $330;
   while(1) {
    $334 = HEAP32[$$08$i90>>2]|0;
    __ZdlPv($334);
    $335 = ((($$08$i90)) + 4|0);
    $336 = ($335|0)==($332|0);
    if ($336) {
     break;
    } else {
     $$08$i90 = $335;
    }
   }
   $$pre$i92 = HEAP32[$329>>2]|0;
   $$pre9$i93 = HEAP32[$331>>2]|0;
   $337 = ($$pre9$i93|0)==($$pre$i92|0);
   if (!($337)) {
    $scevgep$i$i$i$i$i95 = ((($$pre9$i93)) + -4|0);
    $338 = $scevgep$i$i$i$i$i95;
    $339 = $$pre$i92;
    $340 = (($338) - ($339))|0;
    $341 = $340 >>> 2;
    $342 = $341 ^ -1;
    $scevgep5$i$i$i$i$i96 = (($$pre9$i93) + ($342<<2)|0);
    HEAP32[$331>>2] = $scevgep5$i$i$i$i$i96;
   }
  }
  $343 = HEAP32[$328>>2]|0;
  $344 = ($343|0)==(0|0);
  if (!($344)) {
   __ZdlPv($343);
  }
  $347 = ((($0)) + 160|0);
  $348 = HEAP32[$347>>2]|0;
  $349 = ($348|0)==(0|0);
  if (!($349)) {
   $350 = ((($348)) + 8|0);
   $351 = HEAP32[$350>>2]|0;HEAP32[$350>>2] = (($351-1)|0);
   $352 = ($351|0)==(1);
   if ($352) {
    __THREW__ = 0;
    invoke_viii(3262,($348|0),1,1);
    $353 = __THREW__; __THREW__ = 0;
    $354 = $353&1;
    if ($354) {
     $529 = ___cxa_find_matching_catch_3(0|0)|0;
     $530 = tempRet0;
     ___clang_call_terminate($529);
     // unreachable;
    }
   }
  }
  HEAP32[$347>>2] = 0;
  $$7 = $$4;$$716 = $$413;
  label = 132;
 }
 if ((label|0) == 132) {
  $357 = ((($0)) + 148|0);
  $358 = ((($0)) + 152|0);
  $359 = HEAP32[$358>>2]|0;
  __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES7_EENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($357,$359);
  $360 = ((($0)) + 136|0);
  $361 = ((($0)) + 140|0);
  $362 = HEAP32[$361>>2]|0;
  __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES7_EENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($360,$362);
  $363 = ((($0)) + 120|0);
  $364 = ((($0)) + 124|0);
  $365 = HEAP32[$364>>2]|0;
  __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7ref_ptrIN5osgDB7ArchiveEEEEENS_19__map_value_compareIS7_SD_NS_4lessIS7_EELb1EEENS5_ISD_EEE7destroyEPNS_11__tree_nodeISD_PvEE($363,$365);
  $366 = ((($0)) + 108|0);
  __THREW__ = 0;
  invoke_vi(707,($366|0));
  $367 = __THREW__; __THREW__ = 0;
  $368 = $367&1;
  if ($368) {
   $529 = ___cxa_find_matching_catch_3(0|0)|0;
   $530 = tempRet0;
   ___clang_call_terminate($529);
   // unreachable;
  } else {
   $$11 = $$7;$$1120 = $$716;
   label = 133;
  }
 }
 if ((label|0) == 133) {
  $369 = ((($0)) + 96|0);
  $370 = HEAP32[$369>>2]|0;
  $371 = ($370|0)==(0|0);
  if (!($371)) {
   $372 = ((($0)) + 100|0);
   $373 = HEAP32[$372>>2]|0;
   $374 = ($373|0)==($370|0);
   do {
    if ($374) {
     $388 = $370;
    } else {
     $376 = $373;
     while(1) {
      $375 = ((($376)) + -4|0);
      HEAP32[$372>>2] = $375;
      $377 = HEAP32[$375>>2]|0;
      $378 = ($377|0)==(0|0);
      if (!($378)) {
       $379 = ((($377)) + 8|0);
       $380 = HEAP32[$379>>2]|0;HEAP32[$379>>2] = (($380-1)|0);
       $381 = ($380|0)==(1);
       if ($381) {
        __THREW__ = 0;
        invoke_viii(3262,($377|0),1,1);
        $382 = __THREW__; __THREW__ = 0;
        $383 = $382&1;
        if ($383) {
         label = 139;
         break;
        }
       }
      }
      HEAP32[$375>>2] = 0;
      $384 = HEAP32[$372>>2]|0;
      $385 = ($384|0)==($370|0);
      if ($385) {
       label = 140;
       break;
      } else {
       $376 = $384;
      }
     }
     if ((label|0) == 139) {
      $386 = ___cxa_find_matching_catch_2()|0;
      $387 = tempRet0;
      ___cxa_call_unexpected(($386|0));
      // unreachable;
     }
     else if ((label|0) == 140) {
      $$pre$i105 = HEAP32[$369>>2]|0;
      $388 = $$pre$i105;
      break;
     }
    }
   } while(0);
   __ZdlPv($388);
  }
  $389 = ((($0)) + 84|0);
  $390 = HEAP32[$389>>2]|0;
  $391 = ($390|0)==(0|0);
  if (!($391)) {
   $392 = ((($0)) + 88|0);
   $393 = HEAP32[$392>>2]|0;
   $394 = ($393|0)==($390|0);
   do {
    if ($394) {
     $408 = $390;
    } else {
     $396 = $393;
     while(1) {
      $395 = ((($396)) + -4|0);
      HEAP32[$392>>2] = $395;
      $397 = HEAP32[$395>>2]|0;
      $398 = ($397|0)==(0|0);
      if (!($398)) {
       $399 = ((($397)) + 8|0);
       $400 = HEAP32[$399>>2]|0;HEAP32[$399>>2] = (($400-1)|0);
       $401 = ($400|0)==(1);
       if ($401) {
        __THREW__ = 0;
        invoke_viii(3262,($397|0),1,1);
        $402 = __THREW__; __THREW__ = 0;
        $403 = $402&1;
        if ($403) {
         label = 148;
         break;
        }
       }
      }
      HEAP32[$395>>2] = 0;
      $404 = HEAP32[$392>>2]|0;
      $405 = ($404|0)==($390|0);
      if ($405) {
       label = 149;
       break;
      } else {
       $396 = $404;
      }
     }
     if ((label|0) == 148) {
      $406 = ___cxa_find_matching_catch_2()|0;
      $407 = tempRet0;
      ___cxa_call_unexpected(($406|0));
      // unreachable;
     }
     else if ((label|0) == 149) {
      $$pre$i112 = HEAP32[$389>>2]|0;
      $408 = $$pre$i112;
      break;
     }
    }
   } while(0);
   __ZdlPv($408);
  }
  $409 = ((($0)) + 72|0);
  $410 = HEAP32[$409>>2]|0;
  $411 = ($410|0)==(0|0);
  if (!($411)) {
   $412 = ((($0)) + 76|0);
   $413 = HEAP32[$412>>2]|0;
   $414 = ($413|0)==($410|0);
   do {
    if ($414) {
     $428 = $410;
    } else {
     $416 = $413;
     while(1) {
      $415 = ((($416)) + -4|0);
      HEAP32[$412>>2] = $415;
      $417 = HEAP32[$415>>2]|0;
      $418 = ($417|0)==(0|0);
      if (!($418)) {
       $419 = ((($417)) + 8|0);
       $420 = HEAP32[$419>>2]|0;HEAP32[$419>>2] = (($420-1)|0);
       $421 = ($420|0)==(1);
       if ($421) {
        __THREW__ = 0;
        invoke_viii(3262,($417|0),1,1);
        $422 = __THREW__; __THREW__ = 0;
        $423 = $422&1;
        if ($423) {
         label = 157;
         break;
        }
       }
      }
      HEAP32[$415>>2] = 0;
      $424 = HEAP32[$412>>2]|0;
      $425 = ($424|0)==($410|0);
      if ($425) {
       label = 158;
       break;
      } else {
       $416 = $424;
      }
     }
     if ((label|0) == 157) {
      $426 = ___cxa_find_matching_catch_2()|0;
      $427 = tempRet0;
      ___cxa_call_unexpected(($426|0));
      // unreachable;
     }
     else if ((label|0) == 158) {
      $$pre$i119 = HEAP32[$409>>2]|0;
      $428 = $$pre$i119;
      break;
     }
    }
   } while(0);
   __ZdlPv($428);
  }
  $431 = ((($0)) + 60|0);
  __THREW__ = 0;
  invoke_vi(707,($431|0));
  $432 = __THREW__; __THREW__ = 0;
  $433 = $432&1;
  if ($433) {
   $529 = ___cxa_find_matching_catch_3(0|0)|0;
   $530 = tempRet0;
   ___clang_call_terminate($529);
   // unreachable;
  } else {
   $$15 = $$11;$$1524 = $$1120;
   label = 163;
  }
 }
 if ((label|0) == 163) {
  $436 = ((($0)) + 56|0);
  $437 = HEAP32[$436>>2]|0;
  $438 = ($437|0)==(0|0);
  if (!($438)) {
   $439 = HEAP32[$437>>2]|0;
   $440 = ((($439)) + -12|0);
   $441 = HEAP32[$440>>2]|0;
   $442 = (($437) + ($441)|0);
   $443 = ((($442)) + 8|0);
   $444 = HEAP32[$443>>2]|0;HEAP32[$443>>2] = (($444-1)|0);
   $445 = ($444|0)==(1);
   if ($445) {
    __THREW__ = 0;
    invoke_viii(3262,($442|0),1,1);
    $446 = __THREW__; __THREW__ = 0;
    $447 = $446&1;
    if ($447) {
     $529 = ___cxa_find_matching_catch_3(0|0)|0;
     $530 = tempRet0;
     ___clang_call_terminate($529);
     // unreachable;
    }
   }
  }
  HEAP32[$436>>2] = 0;
  $$16 = $$15;$$1625 = $$1524;
  label = 168;
 }
 if ((label|0) == 168) {
  $450 = ((($0)) + 52|0);
  $451 = HEAP32[$450>>2]|0;
  $452 = ($451|0)==(0|0);
  if (!($452)) {
   $453 = HEAP32[$451>>2]|0;
   $454 = ((($453)) + -12|0);
   $455 = HEAP32[$454>>2]|0;
   $456 = (($451) + ($455)|0);
   $457 = ((($456)) + 8|0);
   $458 = HEAP32[$457>>2]|0;HEAP32[$457>>2] = (($458-1)|0);
   $459 = ($458|0)==(1);
   if ($459) {
    __THREW__ = 0;
    invoke_viii(3262,($456|0),1,1);
    $460 = __THREW__; __THREW__ = 0;
    $461 = $460&1;
    if ($461) {
     $529 = ___cxa_find_matching_catch_3(0|0)|0;
     $530 = tempRet0;
     ___clang_call_terminate($529);
     // unreachable;
    }
   }
  }
  HEAP32[$450>>2] = 0;
  $$17 = $$16;$$1726 = $$1625;
  label = 173;
 }
 if ((label|0) == 173) {
  $464 = ((($0)) + 48|0);
  $465 = HEAP32[$464>>2]|0;
  $466 = ($465|0)==(0|0);
  if (!($466)) {
   $467 = HEAP32[$465>>2]|0;
   $468 = ((($467)) + -12|0);
   $469 = HEAP32[$468>>2]|0;
   $470 = (($465) + ($469)|0);
   $471 = ((($470)) + 8|0);
   $472 = HEAP32[$471>>2]|0;HEAP32[$471>>2] = (($472-1)|0);
   $473 = ($472|0)==(1);
   if ($473) {
    __THREW__ = 0;
    invoke_viii(3262,($470|0),1,1);
    $474 = __THREW__; __THREW__ = 0;
    $475 = $474&1;
    if ($475) {
     $529 = ___cxa_find_matching_catch_3(0|0)|0;
     $530 = tempRet0;
     ___clang_call_terminate($529);
     // unreachable;
    }
   }
  }
  HEAP32[$464>>2] = 0;
  $$18 = $$17;$$1827 = $$1726;
  label = 178;
 }
 if ((label|0) == 178) {
  $478 = ((($0)) + 44|0);
  $479 = HEAP32[$478>>2]|0;
  $480 = ($479|0)==(0|0);
  if (!($480)) {
   $481 = HEAP32[$479>>2]|0;
   $482 = ((($481)) + -12|0);
   $483 = HEAP32[$482>>2]|0;
   $484 = (($479) + ($483)|0);
   $485 = ((($484)) + 8|0);
   $486 = HEAP32[$485>>2]|0;HEAP32[$485>>2] = (($486-1)|0);
   $487 = ($486|0)==(1);
   if ($487) {
    __THREW__ = 0;
    invoke_viii(3262,($484|0),1,1);
    $488 = __THREW__; __THREW__ = 0;
    $489 = $488&1;
    if ($489) {
     $529 = ___cxa_find_matching_catch_3(0|0)|0;
     $530 = tempRet0;
     ___clang_call_terminate($529);
     // unreachable;
    }
   }
  }
  HEAP32[$478>>2] = 0;
  $$19 = $$18;$$1928 = $$1827;
  label = 183;
 }
 if ((label|0) == 183) {
  $492 = ((($0)) + 32|0);
  $493 = ((($0)) + 36|0);
  $494 = HEAP32[$493>>2]|0;
  __ZNSt3__26__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EENS4_IS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($492,$494);
  $495 = ((($0)) + 24|0);
  $496 = HEAP32[$495>>2]|0;
  $497 = ($496|0)==(0|0);
  if (!($497)) {
   $498 = ((($496)) + 8|0);
   $499 = HEAP32[$498>>2]|0;HEAP32[$498>>2] = (($499-1)|0);
   $500 = ($499|0)==(1);
   if ($500) {
    __THREW__ = 0;
    invoke_viii(3262,($496|0),1,1);
    $501 = __THREW__; __THREW__ = 0;
    $502 = $501&1;
    if ($502) {
     $529 = ___cxa_find_matching_catch_3(0|0)|0;
     $530 = tempRet0;
     ___clang_call_terminate($529);
     // unreachable;
    }
   }
  }
  HEAP32[$495>>2] = 0;
  $$21 = $$19;$$2130 = $$1928;
  label = 188;
 }
 if ((label|0) == 188) {
  $505 = ((($0)) + 20|0);
  $506 = HEAP32[$505>>2]|0;
  $507 = ($506|0)==(0|0);
  if (!($507)) {
   $508 = ((($506)) + 8|0);
   $509 = HEAP32[$508>>2]|0;HEAP32[$508>>2] = (($509-1)|0);
   $510 = ($509|0)==(1);
   if ($510) {
    __THREW__ = 0;
    invoke_viii(3262,($506|0),1,1);
    $511 = __THREW__; __THREW__ = 0;
    $512 = $511&1;
    if ($512) {
     $529 = ___cxa_find_matching_catch_3(0|0)|0;
     $530 = tempRet0;
     ___clang_call_terminate($529);
     // unreachable;
    }
   }
  }
  HEAP32[$505>>2] = 0;
  $$22 = $$21;$$2231 = $$2130;
  label = 193;
 }
 if ((label|0) == 193) {
  $515 = ((($0)) + 16|0);
  $516 = HEAP32[$515>>2]|0;
  $517 = ($516|0)==(0|0);
  if (!($517)) {
   $518 = HEAP32[$516>>2]|0;
   $519 = ((($518)) + -12|0);
   $520 = HEAP32[$519>>2]|0;
   $521 = (($516) + ($520)|0);
   $522 = ((($521)) + 8|0);
   $523 = HEAP32[$522>>2]|0;HEAP32[$522>>2] = (($523-1)|0);
   $524 = ($523|0)==(1);
   if ($524) {
    __THREW__ = 0;
    invoke_viii(3262,($521|0),1,1);
    $525 = __THREW__; __THREW__ = 0;
    $526 = $525&1;
    if ($526) {
     $529 = ___cxa_find_matching_catch_3(0|0)|0;
     $530 = tempRet0;
     ___clang_call_terminate($529);
     // unreachable;
    }
   }
  }
  HEAP32[$515>>2] = 0;
  $$23 = $$22;$$2332 = $$2231;
 }
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $527 = __THREW__; __THREW__ = 0;
 $528 = $527&1;
 if ($528) {
  $529 = ___cxa_find_matching_catch_3(0|0)|0;
  $530 = tempRet0;
  ___clang_call_terminate($529);
  // unreachable;
 } else {
  ___resumeException($$2332|0);
  // unreachable;
 }
}
function __ZN5osgDB8RegistryD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(2674,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZN5osgDB8Registry8destructEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 236|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  HEAP32[$1>>2] = 0;
  $4 = HEAP32[$2>>2]|0;
  $5 = ((($4)) + -12|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($2) + ($6)|0);
  $8 = ((($7)) + 8|0);
  $9 = HEAP32[$8>>2]|0;HEAP32[$8>>2] = (($9-1)|0);
  $10 = ($9|0)==(1);
  if ($10) {
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($7,1,1);
  }
 }
 $11 = ((($0)) + 20|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0|0);
 if (!($13)) {
  HEAP32[$11>>2] = 0;
  $14 = ((($12)) + 8|0);
  $15 = HEAP32[$14>>2]|0;HEAP32[$14>>2] = (($15-1)|0);
  $16 = ($15|0)==(1);
  if ($16) {
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($12,1,1);
  }
 }
 $17 = ((($0)) + 212|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ($18|0)==(0|0);
 if (!($19)) {
  __ZN5osgDB11ObjectCache5clearEv($18);
 }
 $20 = HEAP32[$11>>2]|0;
 $21 = ($20|0)==(0|0);
 if (!($21)) {
  HEAP32[$11>>2] = 0;
  $22 = ((($20)) + 8|0);
  $23 = HEAP32[$22>>2]|0;HEAP32[$22>>2] = (($23-1)|0);
  $24 = ($23|0)==(1);
  if ($24) {
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($20,1,1);
  }
 }
 $25 = ((($0)) + 108|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ((($26)) + 8|0);
 $28 = HEAP32[$27>>2]|0;
 (FUNCTION_TABLE_ii[$28 & 8191]($25)|0);
 $29 = ((($0)) + 120|0);
 $30 = ((($0)) + 124|0);
 $31 = HEAP32[$30>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7ref_ptrIN5osgDB7ArchiveEEEEENS_19__map_value_compareIS7_SD_NS_4lessIS7_EELb1EEENS5_ISD_EEE7destroyEPNS_11__tree_nodeISD_PvEE($29,$31);
 $32 = ((($0)) + 128|0);
 HEAP32[$32>>2] = 0;
 HEAP32[$29>>2] = $30;
 HEAP32[$30>>2] = 0;
 $33 = HEAP32[$25>>2]|0;
 $34 = ((($33)) + 12|0);
 $35 = HEAP32[$34>>2]|0;
 (FUNCTION_TABLE_ii[$35 & 8191]($25)|0);
 $36 = ((($0)) + 60|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = ((($37)) + 8|0);
 $39 = HEAP32[$38>>2]|0;
 (FUNCTION_TABLE_ii[$39 & 8191]($36)|0);
 $40 = ((($0)) + 96|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = ((($0)) + 100|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = ($43|0)==($41|0);
 if ($44) {
  $58 = HEAP32[$36>>2]|0;
  $59 = ((($58)) + 12|0);
  $60 = HEAP32[$59>>2]|0;
  (FUNCTION_TABLE_ii[$60 & 8191]($36)|0);
  return;
 } else {
  $46 = $43;
 }
 while(1) {
  $45 = ((($46)) + -4|0);
  HEAP32[$42>>2] = $45;
  $47 = HEAP32[$45>>2]|0;
  $48 = ($47|0)==(0|0);
  if (!($48)) {
   $49 = ((($47)) + 8|0);
   $50 = HEAP32[$49>>2]|0;HEAP32[$49>>2] = (($50-1)|0);
   $51 = ($50|0)==(1);
   if ($51) {
    __THREW__ = 0;
    invoke_viii(3262,($47|0),1,1);
    $52 = __THREW__; __THREW__ = 0;
    $53 = $52&1;
    if ($53) {
     label = 17;
     break;
    }
   }
  }
  HEAP32[$45>>2] = 0;
  $54 = HEAP32[$42>>2]|0;
  $55 = ($54|0)==($41|0);
  if ($55) {
   label = 18;
   break;
  } else {
   $46 = $54;
  }
 }
 if ((label|0) == 17) {
  $56 = ___cxa_find_matching_catch_2()|0;
  $57 = tempRet0;
  ___cxa_call_unexpected(($56|0));
  // unreachable;
 }
 else if ((label|0) == 18) {
  $58 = HEAP32[$36>>2]|0;
  $59 = ((($58)) + 12|0);
  $60 = HEAP32[$59>>2]|0;
  (FUNCTION_TABLE_ii[$60 & 8191]($36)|0);
  return;
 }
}
function __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7ref_ptrIN5osgDB7ArchiveEEEEENS_19__map_value_compareIS7_SD_NS_4lessIS7_EELb1EEENS5_ISD_EEE7destroyEPNS_11__tree_nodeISD_PvEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 }
 $3 = HEAP32[$1>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7ref_ptrIN5osgDB7ArchiveEEEEENS_19__map_value_compareIS7_SD_NS_4lessIS7_EELb1EEENS5_ISD_EEE7destroyEPNS_11__tree_nodeISD_PvEE($0,$3);
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7ref_ptrIN5osgDB7ArchiveEEEEENS_19__map_value_compareIS7_SD_NS_4lessIS7_EELb1EEENS5_ISD_EEE7destroyEPNS_11__tree_nodeISD_PvEE($0,$5);
 $6 = ((($1)) + 16|0);
 $7 = ((($1)) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if (!($9)) {
  $10 = ((($8)) + 8|0);
  $11 = HEAP32[$10>>2]|0;HEAP32[$10>>2] = (($11-1)|0);
  $12 = ($11|0)==(1);
  if ($12) {
   __THREW__ = 0;
   invoke_viii(3262,($8|0),1,1);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if ($14) {
    $19 = ___cxa_find_matching_catch_2()|0;
    $20 = tempRet0;
    $21 = ((($6)) + 11|0);
    $22 = HEAP8[$21>>0]|0;
    $23 = ($22<<24>>24)<(0);
    if (!($23)) {
     ___cxa_call_unexpected(($19|0));
     // unreachable;
    }
    $24 = HEAP32[$6>>2]|0;
    __ZdlPv($24);
    ___cxa_call_unexpected(($19|0));
    // unreachable;
   }
  }
 }
 HEAP32[$7>>2] = 0;
 $15 = ((($6)) + 11|0);
 $16 = HEAP8[$15>>0]|0;
 $17 = ($16<<24>>24)<(0);
 if ($17) {
  $18 = HEAP32[$6>>2]|0;
  __ZdlPv($18);
 }
 __ZdlPv($1);
 return;
}
function __GLOBAL__sub_I_Registry_cpp() {
 var $$0$i = 0, $$0$i14 = 0, $$0$i6 = 0, $$01$i = 0, $$01$i13 = 0, $$01$i5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, dest = 0, label = 0, sp = 0;
 var src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(80|0);
 $0 = sp + 60|0;
 $1 = sp + 48|0;
 $2 = sp + 36|0;
 $3 = sp + 24|0;
 $4 = sp + 12|0;
 $5 = sp;
 HEAPF32[52347] = 1.0;
 HEAPF32[(209392)>>2] = 0.0;
 HEAPF32[(209396)>>2] = 0.0;
 HEAPF32[52350] = 0.0;
 HEAPF32[(209404)>>2] = 1.0;
 HEAPF32[(209408)>>2] = 0.0;
 HEAPF32[52353] = 0.0;
 HEAPF32[(209416)>>2] = 0.0;
 HEAPF32[(209420)>>2] = 1.0;
 $6 = (__Znwj(32)|0);
 HEAP32[$2>>2] = $6;
 $7 = ((($2)) + 8|0);
 HEAP32[$7>>2] = -2147483616;
 $8 = ((($2)) + 4|0);
 HEAP32[$8>>2] = 29;
 dest=$6; src=166864; stop=dest+29|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $9 = ((($6)) + 29|0);
 HEAP8[$9>>0] = 0;
 ;HEAP32[$3>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;
 __THREW__ = 0;
 $10 = (invoke_ii(3276,32)|0);
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if ($12) {
  $29 = ___cxa_find_matching_catch_2()|0;
  $30 = tempRet0;
  $$0$i6 = $30;$$01$i5 = $29;
 } else {
  HEAP32[$3>>2] = $10;
  $13 = ((($3)) + 8|0);
  HEAP32[$13>>2] = -2147483616;
  $14 = ((($3)) + 4|0);
  HEAP32[$14>>2] = 28;
  dest=$10; src=166894; stop=dest+28|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
  $15 = ((($10)) + 28|0);
  HEAP8[$15>>0] = 0;
  __THREW__ = 0;
  $16 = (invoke_i(3459)|0);
  $17 = __THREW__; __THREW__ = 0;
  $18 = $17&1;
  if (!($18)) {
   __THREW__ = 0;
   invoke_viiii(3460,($16|0),2,($2|0),($3|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    $21 = ((($3)) + 11|0);
    $22 = HEAP8[$21>>0]|0;
    $23 = ($22<<24>>24)<(0);
    if ($23) {
     $24 = HEAP32[$3>>2]|0;
     __ZdlPv($24);
    }
    $25 = ((($2)) + 11|0);
    $26 = HEAP8[$25>>0]|0;
    $27 = ($26<<24>>24)<(0);
    if ($27) {
     $28 = HEAP32[$2>>2]|0;
     __ZdlPv($28);
    }
    $41 = (__Znwj(48)|0);
    HEAP32[$0>>2] = $41;
    $42 = ((($0)) + 8|0);
    HEAP32[$42>>2] = -2147483600;
    $43 = ((($0)) + 4|0);
    HEAP32[$43>>2] = 32;
    dest=$41; src=166923; stop=dest+32|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
    $44 = ((($41)) + 32|0);
    HEAP8[$44>>0] = 0;
    ;HEAP32[$1>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;
    __THREW__ = 0;
    $45 = (invoke_ii(3276,48)|0);
    $46 = __THREW__; __THREW__ = 0;
    $47 = $46&1;
    if ($47) {
     $64 = ___cxa_find_matching_catch_2()|0;
     $65 = tempRet0;
     $$0$i14 = $65;$$01$i13 = $64;
    } else {
     HEAP32[$1>>2] = $45;
     $48 = ((($1)) + 8|0);
     HEAP32[$48>>2] = -2147483600;
     $49 = ((($1)) + 4|0);
     HEAP32[$49>>2] = 37;
     dest=$45; src=166956; stop=dest+37|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
     $50 = ((($45)) + 37|0);
     HEAP8[$50>>0] = 0;
     __THREW__ = 0;
     $51 = (invoke_i(3459)|0);
     $52 = __THREW__; __THREW__ = 0;
     $53 = $52&1;
     if (!($53)) {
      __THREW__ = 0;
      invoke_viiii(3460,($51|0),2,($0|0),($1|0));
      $54 = __THREW__; __THREW__ = 0;
      $55 = $54&1;
      if (!($55)) {
       $56 = ((($1)) + 11|0);
       $57 = HEAP8[$56>>0]|0;
       $58 = ($57<<24>>24)<(0);
       if ($58) {
        $59 = HEAP32[$1>>2]|0;
        __ZdlPv($59);
       }
       $60 = ((($0)) + 11|0);
       $61 = HEAP8[$60>>0]|0;
       $62 = ($61<<24>>24)<(0);
       if ($62) {
        $63 = HEAP32[$0>>2]|0;
        __ZdlPv($63);
       }
       $76 = (__Znwj(32)|0);
       HEAP32[$4>>2] = $76;
       $77 = ((($4)) + 8|0);
       HEAP32[$77>>2] = -2147483616;
       $78 = ((($4)) + 4|0);
       HEAP32[$78>>2] = 24;
       dest=$76; src=166994; stop=dest+24|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
       $79 = ((($76)) + 24|0);
       HEAP8[$79>>0] = 0;
       ;HEAP32[$5>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;
       __THREW__ = 0;
       $80 = (invoke_ii(3276,80)|0);
       $81 = __THREW__; __THREW__ = 0;
       $82 = $81&1;
       if ($82) {
        $99 = ___cxa_find_matching_catch_2()|0;
        $100 = tempRet0;
        $$0$i = $100;$$01$i = $99;
       } else {
        HEAP32[$5>>2] = $80;
        $83 = ((($5)) + 8|0);
        HEAP32[$83>>2] = -2147483568;
        $84 = ((($5)) + 4|0);
        HEAP32[$84>>2] = 74;
        dest=$80; src=167019; stop=dest+74|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
        $85 = ((($80)) + 74|0);
        HEAP8[$85>>0] = 0;
        __THREW__ = 0;
        $86 = (invoke_i(3459)|0);
        $87 = __THREW__; __THREW__ = 0;
        $88 = $87&1;
        if (!($88)) {
         __THREW__ = 0;
         invoke_viiii(3460,($86|0),2,($4|0),($5|0));
         $89 = __THREW__; __THREW__ = 0;
         $90 = $89&1;
         if (!($90)) {
          $91 = ((($5)) + 11|0);
          $92 = HEAP8[$91>>0]|0;
          $93 = ($92<<24>>24)<(0);
          if ($93) {
           $94 = HEAP32[$5>>2]|0;
           __ZdlPv($94);
          }
          $95 = ((($4)) + 11|0);
          $96 = HEAP8[$95>>0]|0;
          $97 = ($96<<24>>24)<(0);
          if (!($97)) {
           (__ZN5osgDB8Registry8instanceEb(0)|0);
           STACKTOP = sp;return;
          }
          $98 = HEAP32[$4>>2]|0;
          __ZdlPv($98);
          (__ZN5osgDB8Registry8instanceEb(0)|0);
          STACKTOP = sp;return;
         }
        }
        $101 = ___cxa_find_matching_catch_2()|0;
        $102 = tempRet0;
        $103 = ((($5)) + 11|0);
        $104 = HEAP8[$103>>0]|0;
        $105 = ($104<<24>>24)<(0);
        if ($105) {
         $106 = HEAP32[$5>>2]|0;
         __ZdlPv($106);
         $$0$i = $102;$$01$i = $101;
        } else {
         $$0$i = $102;$$01$i = $101;
        }
       }
       $107 = ((($4)) + 11|0);
       $108 = HEAP8[$107>>0]|0;
       $109 = ($108<<24>>24)<(0);
       if (!($109)) {
        ___resumeException($$01$i|0);
        // unreachable;
       }
       $110 = HEAP32[$4>>2]|0;
       __ZdlPv($110);
       ___resumeException($$01$i|0);
       // unreachable;
      }
     }
     $66 = ___cxa_find_matching_catch_2()|0;
     $67 = tempRet0;
     $68 = ((($1)) + 11|0);
     $69 = HEAP8[$68>>0]|0;
     $70 = ($69<<24>>24)<(0);
     if ($70) {
      $71 = HEAP32[$1>>2]|0;
      __ZdlPv($71);
      $$0$i14 = $67;$$01$i13 = $66;
     } else {
      $$0$i14 = $67;$$01$i13 = $66;
     }
    }
    $72 = ((($0)) + 11|0);
    $73 = HEAP8[$72>>0]|0;
    $74 = ($73<<24>>24)<(0);
    if (!($74)) {
     ___resumeException($$01$i13|0);
     // unreachable;
    }
    $75 = HEAP32[$0>>2]|0;
    __ZdlPv($75);
    ___resumeException($$01$i13|0);
    // unreachable;
   }
  }
  $31 = ___cxa_find_matching_catch_2()|0;
  $32 = tempRet0;
  $33 = ((($3)) + 11|0);
  $34 = HEAP8[$33>>0]|0;
  $35 = ($34<<24>>24)<(0);
  if ($35) {
   $36 = HEAP32[$3>>2]|0;
   __ZdlPv($36);
   $$0$i6 = $32;$$01$i5 = $31;
  } else {
   $$0$i6 = $32;$$01$i5 = $31;
  }
 }
 $37 = ((($2)) + 11|0);
 $38 = HEAP8[$37>>0]|0;
 $39 = ($38<<24>>24)<(0);
 if (!($39)) {
  ___resumeException($$01$i5|0);
  // unreachable;
 }
 $40 = HEAP32[$2>>2]|0;
 __ZdlPv($40);
 ___resumeException($$01$i5|0);
 // unreachable;
}
function __ZN5osgDB8Registry8instanceEb($0) {
 $0 = $0|0;
 var $$0 = 0, $$02 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP8[206224]|0;
 $2 = ($1<<24>>24)==(0);
 do {
  if ($2) {
   $3 = (___cxa_guard_acquire(206224)|0);
   $4 = ($3|0)==(0);
   if (!($4)) {
    __THREW__ = 0;
    $5 = (invoke_ii(3276,248)|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     $18 = ___cxa_find_matching_catch_2()|0;
     $19 = tempRet0;
     $$0 = $19;$$02 = $18;
     ___resumeException($$02|0);
     // unreachable;
    }
    __THREW__ = 0;
    invoke_vi(4178,($5|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     HEAP32[52356] = $5;
     $10 = ((($5)) + 8|0);
     $11 = HEAP32[$10>>2]|0;HEAP32[$10>>2] = (($11+1)|0);
     (___cxa_atexit((4179|0),(209424|0),(___dso_handle|0))|0);
     break;
    }
    $20 = ___cxa_find_matching_catch_2()|0;
    $21 = tempRet0;
    __ZdlPv($5);
    $$0 = $21;$$02 = $20;
    ___resumeException($$02|0);
    // unreachable;
   }
  }
 } while(0);
 if (!($0)) {
  $22 = HEAP32[52356]|0;
  return ($22|0);
 }
 $12 = HEAP32[52356]|0;
 __ZN5osgDB8Registry8destructEv($12);
 $13 = HEAP32[52356]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  $22 = HEAP32[52356]|0;
  return ($22|0);
 }
 HEAP32[52356] = 0;
 $15 = ((($13)) + 8|0);
 $16 = HEAP32[$15>>2]|0;HEAP32[$15>>2] = (($16-1)|0);
 $17 = ($16|0)==(1);
 if (!($17)) {
  $22 = HEAP32[52356]|0;
  return ($22|0);
 }
 __ZNK3osg10Referenced24signalObserversAndDeleteEbb($13,1,1);
 $22 = HEAP32[52356]|0;
 return ($22|0);
}
function __ZN5osgDB8RegistryC2Ev($0) {
 $0 = $0|0;
 var $$016$i$i = 0, $$016$i$i1099 = 0, $$016$i$i999 = 0, $$017$i$i = 0, $$017$i$i1000 = 0, $$017$i$i1100 = 0, $$0311184 = 0, $$0321167 = 0, $$033 = 0, $$0351166 = 0, $$08$i = 0, $$08$i1156 = 0, $$48 = 0, $$4883 = 0, $$49 = 0, $$4984 = 0, $$50 = 0, $$5085 = 0, $$51 = 0, $$5186 = 0;
 var $$52 = 0, $$5287 = 0, $$53 = 0, $$5388 = 0, $$63 = 0, $$6398 = 0, $$70 = 0, $$70105 = 0, $$74 = 0, $$74109 = 0, $$pre$i = 0, $$pre$i$i$i = 0, $$pre$i1153 = 0, $$pre$i1155 = 0, $$pre$i1158 = 0, $$pre$i122 = 0, $$pre$i125 = 0, $$pre9$i = 0, $$pre9$i1159 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $1000 = 0, $1001 = 0, $1002 = 0, $1003 = 0, $1004 = 0, $1005 = 0, $1006 = 0, $1007 = 0, $1008 = 0, $1009 = 0, $101 = 0, $1010 = 0, $1011 = 0, $1012 = 0, $1013 = 0, $1014 = 0, $1015 = 0, $1016 = 0;
 var $1017 = 0, $1018 = 0, $1019 = 0, $102 = 0, $1020 = 0, $1021 = 0, $1022 = 0, $1023 = 0, $1024 = 0, $1025 = 0, $1026 = 0, $1027 = 0, $1028 = 0, $1029 = 0, $103 = 0, $1030 = 0, $1031 = 0, $1032 = 0, $1033 = 0, $1034 = 0;
 var $1035 = 0, $1036 = 0, $1037 = 0, $1038 = 0, $1039 = 0, $104 = 0, $1040 = 0, $1041 = 0, $1042 = 0, $1043 = 0, $1044 = 0, $1045 = 0, $1046 = 0, $1047 = 0, $1048 = 0, $1049 = 0, $105 = 0, $1050 = 0, $1051 = 0, $1052 = 0;
 var $1053 = 0, $1054 = 0, $1055 = 0, $1056 = 0, $1057 = 0, $1058 = 0, $1059 = 0, $106 = 0, $1060 = 0, $1061 = 0, $1062 = 0, $1063 = 0, $1064 = 0, $1065 = 0, $1066 = 0, $1067 = 0, $1068 = 0, $1069 = 0, $107 = 0, $1070 = 0;
 var $1071 = 0, $1072 = 0, $1073 = 0, $1074 = 0, $1075 = 0, $1076 = 0, $1077 = 0, $1078 = 0, $1079 = 0, $108 = 0, $1080 = 0, $1081 = 0, $1082 = 0, $1083 = 0, $1084 = 0, $1085 = 0, $1086 = 0, $1087 = 0, $1088 = 0, $1089 = 0;
 var $109 = 0, $1090 = 0, $1091 = 0, $1092 = 0, $1093 = 0, $1094 = 0, $1095 = 0, $1096 = 0, $1097 = 0, $1098 = 0, $1099 = 0, $11 = 0, $110 = 0, $1100 = 0, $1101 = 0, $1102 = 0, $1103 = 0, $1104 = 0, $1105 = 0, $1106 = 0;
 var $1107 = 0, $1108 = 0, $1109 = 0, $111 = 0, $1110 = 0, $1111 = 0, $1112 = 0, $1113 = 0, $1114 = 0, $1115 = 0, $1116 = 0, $1117 = 0, $1118 = 0, $1119 = 0, $112 = 0, $1120 = 0, $1121 = 0, $1122 = 0, $1123 = 0, $1124 = 0;
 var $1125 = 0, $1126 = 0, $1127 = 0, $1128 = 0, $1129 = 0, $113 = 0, $1130 = 0, $1131 = 0, $1132 = 0, $1133 = 0, $1134 = 0, $1135 = 0, $1136 = 0, $1137 = 0, $1138 = 0, $1139 = 0, $114 = 0, $1140 = 0, $1141 = 0, $1142 = 0;
 var $1143 = 0, $1144 = 0, $1145 = 0, $1146 = 0, $1147 = 0, $1148 = 0, $1149 = 0, $115 = 0, $1150 = 0, $1151 = 0, $1152 = 0, $1153 = 0, $1154 = 0, $1155 = 0, $1156 = 0, $1157 = 0, $1158 = 0, $1159 = 0, $116 = 0, $1160 = 0;
 var $1161 = 0, $1162 = 0, $1163 = 0, $1164 = 0, $1165 = 0, $1166 = 0, $1167 = 0, $1168 = 0, $1169 = 0, $117 = 0, $1170 = 0, $1171 = 0, $1172 = 0, $1173 = 0, $1174 = 0, $1175 = 0, $1176 = 0, $1177 = 0, $1178 = 0, $1179 = 0;
 var $118 = 0, $1180 = 0, $1181 = 0, $1182 = 0, $1183 = 0, $1184 = 0, $1185 = 0, $1186 = 0, $1187 = 0, $1188 = 0, $1189 = 0, $119 = 0, $1190 = 0, $1191 = 0, $1192 = 0, $1193 = 0, $1194 = 0, $1195 = 0, $1196 = 0, $1197 = 0;
 var $1198 = 0, $1199 = 0, $12 = 0, $120 = 0, $1200 = 0, $1201 = 0, $1202 = 0, $1203 = 0, $1204 = 0, $1205 = 0, $1206 = 0, $1207 = 0, $1208 = 0, $1209 = 0, $121 = 0, $1210 = 0, $1211 = 0, $1212 = 0, $1213 = 0, $1214 = 0;
 var $1215 = 0, $1216 = 0, $1217 = 0, $1218 = 0, $1219 = 0, $122 = 0, $1220 = 0, $1221 = 0, $1222 = 0, $1223 = 0, $1224 = 0, $1225 = 0, $1226 = 0, $1227 = 0, $1228 = 0, $1229 = 0, $123 = 0, $1230 = 0, $1231 = 0, $1232 = 0;
 var $1233 = 0, $1234 = 0, $1235 = 0, $1236 = 0, $1237 = 0, $1238 = 0, $1239 = 0, $124 = 0, $1240 = 0, $1241 = 0, $1242 = 0, $1243 = 0, $1244 = 0, $1245 = 0, $1246 = 0, $1247 = 0, $1248 = 0, $1249 = 0, $125 = 0, $1250 = 0;
 var $1251 = 0, $1252 = 0, $1253 = 0, $1254 = 0, $1255 = 0, $1256 = 0, $1257 = 0, $1258 = 0, $1259 = 0, $126 = 0, $1260 = 0, $1261 = 0, $1262 = 0, $1263 = 0, $1264 = 0, $1265 = 0, $1266 = 0, $1267 = 0, $1268 = 0, $1269 = 0;
 var $127 = 0, $1270 = 0, $1271 = 0, $1272 = 0, $1273 = 0, $1274 = 0, $1275 = 0, $1276 = 0, $1277 = 0, $1278 = 0, $1279 = 0, $128 = 0, $1280 = 0, $1281 = 0, $1282 = 0, $1283 = 0, $1284 = 0, $1285 = 0, $1286 = 0, $1287 = 0;
 var $1288 = 0, $1289 = 0, $129 = 0, $1290 = 0, $1291 = 0, $1292 = 0, $1293 = 0, $1294 = 0, $1295 = 0, $1296 = 0, $1297 = 0, $1298 = 0, $1299 = 0, $13 = 0, $130 = 0, $1300 = 0, $1301 = 0, $1302 = 0, $1303 = 0, $1304 = 0;
 var $1305 = 0, $1306 = 0, $1307 = 0, $1308 = 0, $1309 = 0, $131 = 0, $1310 = 0, $1311 = 0, $1312 = 0, $1313 = 0, $1314 = 0, $1315 = 0, $1316 = 0, $1317 = 0, $1318 = 0, $1319 = 0, $132 = 0, $1320 = 0, $1321 = 0, $1322 = 0;
 var $1323 = 0, $1324 = 0, $1325 = 0, $1326 = 0, $1327 = 0, $1328 = 0, $1329 = 0, $133 = 0, $1330 = 0, $1331 = 0, $1332 = 0, $1333 = 0, $1334 = 0, $1335 = 0, $1336 = 0, $1337 = 0, $1338 = 0, $1339 = 0, $134 = 0, $1340 = 0;
 var $1341 = 0, $1342 = 0, $1343 = 0, $1344 = 0, $1345 = 0, $1346 = 0, $1347 = 0, $1348 = 0, $1349 = 0, $135 = 0, $1350 = 0, $1351 = 0, $1352 = 0, $1353 = 0, $1354 = 0, $1355 = 0, $1356 = 0, $1357 = 0, $1358 = 0, $1359 = 0;
 var $136 = 0, $1360 = 0, $1361 = 0, $1362 = 0, $1363 = 0, $1364 = 0, $1365 = 0, $1366 = 0, $1367 = 0, $1368 = 0, $1369 = 0, $137 = 0, $1370 = 0, $1371 = 0, $1372 = 0, $1373 = 0, $1374 = 0, $1375 = 0, $1376 = 0, $1377 = 0;
 var $1378 = 0, $1379 = 0, $138 = 0, $1380 = 0, $1381 = 0, $1382 = 0, $1383 = 0, $1384 = 0, $1385 = 0, $1386 = 0, $1387 = 0, $1388 = 0, $1389 = 0, $139 = 0, $1390 = 0, $1391 = 0, $1392 = 0, $1393 = 0, $1394 = 0, $1395 = 0;
 var $1396 = 0, $1397 = 0, $1398 = 0, $1399 = 0, $14 = 0, $140 = 0, $1400 = 0, $1401 = 0, $1402 = 0, $1403 = 0, $1404 = 0, $1405 = 0, $1406 = 0, $1407 = 0, $1408 = 0, $1409 = 0, $141 = 0, $1410 = 0, $1411 = 0, $1412 = 0;
 var $1413 = 0, $1414 = 0, $1415 = 0, $1416 = 0, $1417 = 0, $1418 = 0, $1419 = 0, $142 = 0, $1420 = 0, $1421 = 0, $1422 = 0, $1423 = 0, $1424 = 0, $1425 = 0, $1426 = 0, $1427 = 0, $1428 = 0, $1429 = 0, $143 = 0, $1430 = 0;
 var $1431 = 0, $1432 = 0, $1433 = 0, $1434 = 0, $1435 = 0, $1436 = 0, $1437 = 0, $1438 = 0, $1439 = 0, $144 = 0, $1440 = 0, $1441 = 0, $1442 = 0, $1443 = 0, $1444 = 0, $1445 = 0, $1446 = 0, $1447 = 0, $1448 = 0, $1449 = 0;
 var $145 = 0, $1450 = 0, $1451 = 0, $1452 = 0, $1453 = 0, $1454 = 0, $1455 = 0, $1456 = 0, $1457 = 0, $1458 = 0, $1459 = 0, $146 = 0, $1460 = 0, $1461 = 0, $1462 = 0, $1463 = 0, $1464 = 0, $1465 = 0, $1466 = 0, $1467 = 0;
 var $1468 = 0, $1469 = 0, $147 = 0, $1470 = 0, $1471 = 0, $1472 = 0, $1473 = 0, $1474 = 0, $1475 = 0, $1476 = 0, $1477 = 0, $1478 = 0, $1479 = 0, $148 = 0, $1480 = 0, $1481 = 0, $1482 = 0, $1483 = 0, $1484 = 0, $1485 = 0;
 var $1486 = 0, $1487 = 0, $1488 = 0, $1489 = 0, $149 = 0, $1490 = 0, $1491 = 0, $1492 = 0, $1493 = 0, $1494 = 0, $1495 = 0, $1496 = 0, $1497 = 0, $1498 = 0, $1499 = 0, $15 = 0, $150 = 0, $1500 = 0, $1501 = 0, $1502 = 0;
 var $1503 = 0, $1504 = 0, $1505 = 0, $1506 = 0, $1507 = 0, $1508 = 0, $1509 = 0, $151 = 0, $1510 = 0, $1511 = 0, $1512 = 0, $1513 = 0, $1514 = 0, $1515 = 0, $1516 = 0, $1517 = 0, $1518 = 0, $1519 = 0, $152 = 0, $1520 = 0;
 var $1521 = 0, $1522 = 0, $1523 = 0, $1524 = 0, $1525 = 0, $1526 = 0, $1527 = 0, $1528 = 0, $1529 = 0, $153 = 0, $1530 = 0, $1531 = 0, $1532 = 0, $1533 = 0, $1534 = 0, $1535 = 0, $1536 = 0, $1537 = 0, $1538 = 0, $1539 = 0;
 var $154 = 0, $1540 = 0, $1541 = 0, $1542 = 0, $1543 = 0, $1544 = 0, $1545 = 0, $1546 = 0, $1547 = 0, $1548 = 0, $1549 = 0, $155 = 0, $1550 = 0, $1551 = 0, $1552 = 0, $1553 = 0, $1554 = 0, $1555 = 0, $1556 = 0, $1557 = 0;
 var $1558 = 0, $1559 = 0, $156 = 0, $1560 = 0, $1561 = 0, $1562 = 0, $1563 = 0, $1564 = 0, $1565 = 0, $1566 = 0, $1567 = 0, $1568 = 0, $1569 = 0, $157 = 0, $1570 = 0, $1571 = 0, $1572 = 0, $1573 = 0, $1574 = 0, $1575 = 0;
 var $1576 = 0, $1577 = 0, $1578 = 0, $1579 = 0, $158 = 0, $1580 = 0, $1581 = 0, $1582 = 0, $1583 = 0, $1584 = 0, $1585 = 0, $1586 = 0, $1587 = 0, $1588 = 0, $1589 = 0, $159 = 0, $1590 = 0, $1591 = 0, $1592 = 0, $1593 = 0;
 var $1594 = 0, $1595 = 0, $1596 = 0, $1597 = 0, $1598 = 0, $1599 = 0, $16 = 0, $160 = 0, $1600 = 0, $1601 = 0, $1602 = 0, $1603 = 0, $1604 = 0, $1605 = 0, $1606 = 0, $1607 = 0, $1608 = 0, $1609 = 0, $161 = 0, $1610 = 0;
 var $1611 = 0, $1612 = 0, $1613 = 0, $1614 = 0, $1615 = 0, $1616 = 0, $1617 = 0, $1618 = 0, $1619 = 0, $162 = 0, $1620 = 0, $1621 = 0, $1622 = 0, $1623 = 0, $1624 = 0, $1625 = 0, $1626 = 0, $1627 = 0, $1628 = 0, $1629 = 0;
 var $163 = 0, $1630 = 0, $1631 = 0, $1632 = 0, $1633 = 0, $1634 = 0, $1635 = 0, $1636 = 0, $1637 = 0, $1638 = 0, $1639 = 0, $164 = 0, $1640 = 0, $1641 = 0, $1642 = 0, $1643 = 0, $1644 = 0, $1645 = 0, $1646 = 0, $1647 = 0;
 var $1648 = 0, $1649 = 0, $165 = 0, $1650 = 0, $1651 = 0, $1652 = 0, $1653 = 0, $1654 = 0, $1655 = 0, $1656 = 0, $1657 = 0, $1658 = 0, $1659 = 0, $166 = 0, $1660 = 0, $1661 = 0, $1662 = 0, $1663 = 0, $1664 = 0, $1665 = 0;
 var $1666 = 0, $1667 = 0, $1668 = 0, $1669 = 0, $167 = 0, $1670 = 0, $1671 = 0, $1672 = 0, $1673 = 0, $1674 = 0, $1675 = 0, $1676 = 0, $1677 = 0, $1678 = 0, $1679 = 0, $168 = 0, $1680 = 0, $1681 = 0, $1682 = 0, $1683 = 0;
 var $1684 = 0, $1685 = 0, $1686 = 0, $1687 = 0, $1688 = 0, $1689 = 0, $169 = 0, $1690 = 0, $1691 = 0, $1692 = 0, $1693 = 0, $1694 = 0, $1695 = 0, $1696 = 0, $1697 = 0, $1698 = 0, $1699 = 0, $17 = 0, $170 = 0, $1700 = 0;
 var $1701 = 0, $1702 = 0, $1703 = 0, $1704 = 0, $1705 = 0, $1706 = 0, $1707 = 0, $1708 = 0, $1709 = 0, $171 = 0, $1710 = 0, $1711 = 0, $1712 = 0, $1713 = 0, $1714 = 0, $1715 = 0, $1716 = 0, $1717 = 0, $1718 = 0, $1719 = 0;
 var $172 = 0, $1720 = 0, $1721 = 0, $1722 = 0, $1723 = 0, $1724 = 0, $1725 = 0, $1726 = 0, $1727 = 0, $1728 = 0, $1729 = 0, $173 = 0, $1730 = 0, $1731 = 0, $1732 = 0, $1733 = 0, $1734 = 0, $1735 = 0, $1736 = 0, $1737 = 0;
 var $1738 = 0, $1739 = 0, $174 = 0, $1740 = 0, $1741 = 0, $1742 = 0, $1743 = 0, $1744 = 0, $1745 = 0, $1746 = 0, $1747 = 0, $1748 = 0, $1749 = 0, $175 = 0, $1750 = 0, $1751 = 0, $1752 = 0, $1753 = 0, $1754 = 0, $1755 = 0;
 var $1756 = 0, $1757 = 0, $1758 = 0, $1759 = 0, $176 = 0, $1760 = 0, $1761 = 0, $1762 = 0, $1763 = 0, $1764 = 0, $1765 = 0, $1766 = 0, $1767 = 0, $1768 = 0, $1769 = 0, $177 = 0, $1770 = 0, $1771 = 0, $1772 = 0, $1773 = 0;
 var $1774 = 0, $1775 = 0, $1776 = 0, $1777 = 0, $1778 = 0, $1779 = 0, $178 = 0, $1780 = 0, $1781 = 0, $1782 = 0, $1783 = 0, $1784 = 0, $1785 = 0, $1786 = 0, $1787 = 0, $1788 = 0, $1789 = 0, $179 = 0, $1790 = 0, $1791 = 0;
 var $1792 = 0, $1793 = 0, $1794 = 0, $1795 = 0, $1796 = 0, $1797 = 0, $1798 = 0, $1799 = 0, $18 = 0, $180 = 0, $1800 = 0, $1801 = 0, $1802 = 0, $1803 = 0, $1804 = 0, $1805 = 0, $1806 = 0, $1807 = 0, $1808 = 0, $1809 = 0;
 var $181 = 0, $1810 = 0, $1811 = 0, $1812 = 0, $1813 = 0, $1814 = 0, $1815 = 0, $1816 = 0, $1817 = 0, $1818 = 0, $1819 = 0, $182 = 0, $1820 = 0, $1821 = 0, $1822 = 0, $1823 = 0, $1824 = 0, $1825 = 0, $1826 = 0, $1827 = 0;
 var $1828 = 0, $1829 = 0, $183 = 0, $1830 = 0, $1831 = 0, $1832 = 0, $1833 = 0, $1834 = 0, $1835 = 0, $1836 = 0, $1837 = 0, $1838 = 0, $1839 = 0, $184 = 0, $1840 = 0, $1841 = 0, $1842 = 0, $1843 = 0, $1844 = 0, $1845 = 0;
 var $1846 = 0, $1847 = 0, $1848 = 0, $1849 = 0, $185 = 0, $1850 = 0, $1851 = 0, $1852 = 0, $1853 = 0, $1854 = 0, $1855 = 0, $1856 = 0, $1857 = 0, $1858 = 0, $1859 = 0, $186 = 0, $1860 = 0, $1861 = 0, $1862 = 0, $1863 = 0;
 var $1864 = 0, $1865 = 0, $1866 = 0, $1867 = 0, $1868 = 0, $1869 = 0, $187 = 0, $1870 = 0, $1871 = 0, $1872 = 0, $1873 = 0, $1874 = 0, $1875 = 0, $1876 = 0, $1877 = 0, $1878 = 0, $1879 = 0, $188 = 0, $1880 = 0, $1881 = 0;
 var $1882 = 0, $1883 = 0, $1884 = 0, $1885 = 0, $1886 = 0, $1887 = 0, $1888 = 0, $1889 = 0, $189 = 0, $1890 = 0, $1891 = 0, $1892 = 0, $1893 = 0, $1894 = 0, $1895 = 0, $1896 = 0, $1897 = 0, $1898 = 0, $1899 = 0, $19 = 0;
 var $190 = 0, $1900 = 0, $1901 = 0, $1902 = 0, $1903 = 0, $1904 = 0, $1905 = 0, $1906 = 0, $1907 = 0, $1908 = 0, $1909 = 0, $191 = 0, $1910 = 0, $1911 = 0, $1912 = 0, $1913 = 0, $1914 = 0, $1915 = 0, $1916 = 0, $1917 = 0;
 var $1918 = 0, $1919 = 0, $192 = 0, $1920 = 0, $1921 = 0, $1922 = 0, $1923 = 0, $1924 = 0, $1925 = 0, $1926 = 0, $1927 = 0, $1928 = 0, $1929 = 0, $193 = 0, $1930 = 0, $1931 = 0, $1932 = 0, $1933 = 0, $1934 = 0, $1935 = 0;
 var $1936 = 0, $1937 = 0, $1938 = 0, $1939 = 0, $194 = 0, $1940 = 0, $1941 = 0, $1942 = 0, $1943 = 0, $1944 = 0, $1945 = 0, $1946 = 0, $1947 = 0, $1948 = 0, $1949 = 0, $195 = 0, $1950 = 0, $1951 = 0, $1952 = 0, $1953 = 0;
 var $1954 = 0, $1955 = 0, $1956 = 0, $1957 = 0, $1958 = 0, $1959 = 0, $196 = 0, $1960 = 0, $1961 = 0, $1962 = 0, $1963 = 0, $1964 = 0, $1965 = 0, $1966 = 0, $1967 = 0, $1968 = 0, $1969 = 0, $197 = 0, $1970 = 0, $1971 = 0;
 var $1972 = 0, $1973 = 0, $1974 = 0, $1975 = 0, $1976 = 0, $1977 = 0, $1978 = 0, $1979 = 0, $198 = 0.0, $1980 = 0, $1981 = 0, $1982 = 0, $1983 = 0, $1984 = 0, $1985 = 0, $1986 = 0, $1987 = 0, $1988 = 0, $1989 = 0, $199 = 0;
 var $1990 = 0, $1991 = 0, $1992 = 0, $1993 = 0, $1994 = 0, $1995 = 0, $1996 = 0, $1997 = 0, $1998 = 0, $1999 = 0, $2 = 0, $20 = 0, $200 = 0, $2000 = 0, $2001 = 0, $2002 = 0, $2003 = 0, $2004 = 0, $2005 = 0, $2006 = 0;
 var $2007 = 0, $2008 = 0, $2009 = 0, $201 = 0, $2010 = 0, $2011 = 0, $2012 = 0, $2013 = 0, $2014 = 0, $2015 = 0, $2016 = 0, $2017 = 0, $2018 = 0, $2019 = 0, $202 = 0, $2020 = 0, $2021 = 0, $2022 = 0, $2023 = 0, $2024 = 0;
 var $2025 = 0, $2026 = 0, $2027 = 0, $2028 = 0, $2029 = 0, $203 = 0, $2030 = 0, $2031 = 0, $2032 = 0, $2033 = 0, $2034 = 0, $2035 = 0, $2036 = 0, $2037 = 0, $2038 = 0, $2039 = 0, $204 = 0, $2040 = 0, $2041 = 0, $2042 = 0;
 var $2043 = 0, $2044 = 0, $2045 = 0, $2046 = 0, $2047 = 0, $2048 = 0, $2049 = 0, $205 = 0, $2050 = 0, $2051 = 0, $2052 = 0, $2053 = 0, $2054 = 0, $2055 = 0, $2056 = 0, $2057 = 0, $2058 = 0, $2059 = 0, $206 = 0, $2060 = 0;
 var $2061 = 0, $2062 = 0, $2063 = 0, $2064 = 0, $2065 = 0, $2066 = 0, $2067 = 0, $2068 = 0, $2069 = 0, $207 = 0, $2070 = 0, $2071 = 0, $2072 = 0, $2073 = 0, $2074 = 0, $2075 = 0, $2076 = 0, $2077 = 0, $2078 = 0, $2079 = 0;
 var $208 = 0, $2080 = 0, $2081 = 0, $2082 = 0, $2083 = 0, $2084 = 0, $2085 = 0, $2086 = 0, $2087 = 0, $2088 = 0, $2089 = 0, $209 = 0, $2090 = 0, $2091 = 0, $2092 = 0, $2093 = 0, $2094 = 0, $2095 = 0, $2096 = 0, $2097 = 0;
 var $2098 = 0, $2099 = 0, $21 = 0, $210 = 0.0, $2100 = 0, $2101 = 0, $2102 = 0, $2103 = 0, $2104 = 0, $2105 = 0, $2106 = 0, $2107 = 0, $2108 = 0, $2109 = 0, $211 = 0, $2110 = 0, $2111 = 0, $2112 = 0, $2113 = 0, $2114 = 0;
 var $2115 = 0, $2116 = 0, $2117 = 0, $2118 = 0, $2119 = 0, $212 = 0, $2120 = 0, $2121 = 0, $2122 = 0, $2123 = 0, $2124 = 0, $2125 = 0, $2126 = 0, $2127 = 0, $2128 = 0, $2129 = 0, $213 = 0, $2130 = 0, $2131 = 0, $2132 = 0;
 var $2133 = 0, $2134 = 0, $2135 = 0, $2136 = 0, $2137 = 0, $2138 = 0, $2139 = 0, $214 = 0, $2140 = 0, $2141 = 0, $2142 = 0, $2143 = 0, $2144 = 0, $2145 = 0, $2146 = 0, $2147 = 0, $2148 = 0, $2149 = 0, $215 = 0, $2150 = 0;
 var $2151 = 0, $2152 = 0, $2153 = 0, $2154 = 0, $2155 = 0, $2156 = 0, $2157 = 0, $2158 = 0, $2159 = 0, $216 = 0, $2160 = 0, $2161 = 0, $2162 = 0, $2163 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0;
 var $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0;
 var $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0;
 var $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0;
 var $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0;
 var $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0;
 var $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0;
 var $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0;
 var $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0;
 var $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0;
 var $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0;
 var $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0;
 var $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0;
 var $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0;
 var $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0;
 var $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0;
 var $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0;
 var $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0;
 var $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0;
 var $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0;
 var $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0;
 var $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0;
 var $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0;
 var $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0;
 var $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0;
 var $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0;
 var $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0;
 var $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0;
 var $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0;
 var $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0;
 var $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0;
 var $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0;
 var $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0;
 var $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0;
 var $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = 0, $834 = 0;
 var $835 = 0, $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0, $850 = 0, $851 = 0, $852 = 0;
 var $853 = 0, $854 = 0, $855 = 0, $856 = 0, $857 = 0, $858 = 0, $859 = 0, $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0, $869 = 0, $87 = 0, $870 = 0;
 var $871 = 0, $872 = 0, $873 = 0, $874 = 0, $875 = 0, $876 = 0, $877 = 0, $878 = 0, $879 = 0, $88 = 0, $880 = 0, $881 = 0, $882 = 0, $883 = 0, $884 = 0, $885 = 0, $886 = 0, $887 = 0, $888 = 0, $889 = 0;
 var $89 = 0, $890 = 0, $891 = 0, $892 = 0, $893 = 0, $894 = 0, $895 = 0, $896 = 0, $897 = 0, $898 = 0, $899 = 0, $9 = 0, $90 = 0, $900 = 0, $901 = 0, $902 = 0, $903 = 0, $904 = 0, $905 = 0, $906 = 0;
 var $907 = 0, $908 = 0, $909 = 0, $91 = 0, $910 = 0, $911 = 0, $912 = 0, $913 = 0, $914 = 0, $915 = 0, $916 = 0, $917 = 0, $918 = 0, $919 = 0, $92 = 0, $920 = 0, $921 = 0, $922 = 0, $923 = 0, $924 = 0;
 var $925 = 0, $926 = 0, $927 = 0, $928 = 0, $929 = 0, $93 = 0, $930 = 0, $931 = 0, $932 = 0, $933 = 0, $934 = 0, $935 = 0, $936 = 0, $937 = 0, $938 = 0, $939 = 0, $94 = 0, $940 = 0, $941 = 0, $942 = 0;
 var $943 = 0, $944 = 0, $945 = 0, $946 = 0, $947 = 0, $948 = 0, $949 = 0, $95 = 0, $950 = 0, $951 = 0, $952 = 0, $953 = 0, $954 = 0, $955 = 0, $956 = 0, $957 = 0, $958 = 0, $959 = 0, $96 = 0, $960 = 0;
 var $961 = 0, $962 = 0, $963 = 0, $964 = 0, $965 = 0, $966 = 0, $967 = 0, $968 = 0, $969 = 0, $97 = 0, $970 = 0, $971 = 0, $972 = 0, $973 = 0, $974 = 0, $975 = 0, $976 = 0, $977 = 0, $978 = 0, $979 = 0;
 var $98 = 0, $980 = 0, $981 = 0, $982 = 0, $983 = 0, $984 = 0, $985 = 0, $986 = 0, $987 = 0, $988 = 0, $989 = 0, $99 = 0, $990 = 0, $991 = 0, $992 = 0, $993 = 0, $994 = 0, $995 = 0, $996 = 0, $997 = 0;
 var $998 = 0, $999 = 0, $eh$lpad$body$index6Z2D = 0, $eh$lpad$body$indexZ2D = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i1161 = 0, $scevgep5$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i1162 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1344|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(1344|0);
 $1 = sp + 1328|0;
 $2 = sp + 1316|0;
 $3 = sp + 1304|0;
 $4 = sp + 1292|0;
 $5 = sp + 1280|0;
 $6 = sp + 1268|0;
 $7 = sp + 1256|0;
 $8 = sp + 1244|0;
 $9 = sp + 1232|0;
 $10 = sp + 1220|0;
 $11 = sp + 1208|0;
 $12 = sp + 1196|0;
 $13 = sp + 1184|0;
 $14 = sp + 1172|0;
 $15 = sp + 1160|0;
 $16 = sp + 1148|0;
 $17 = sp + 1136|0;
 $18 = sp + 1124|0;
 $19 = sp + 1112|0;
 $20 = sp + 1100|0;
 $21 = sp + 1088|0;
 $22 = sp + 1076|0;
 $23 = sp + 1064|0;
 $24 = sp + 1052|0;
 $25 = sp + 1040|0;
 $26 = sp + 1028|0;
 $27 = sp + 1016|0;
 $28 = sp + 1004|0;
 $29 = sp + 992|0;
 $30 = sp + 980|0;
 $31 = sp + 968|0;
 $32 = sp + 956|0;
 $33 = sp + 944|0;
 $34 = sp + 932|0;
 $35 = sp + 920|0;
 $36 = sp + 908|0;
 $37 = sp + 896|0;
 $38 = sp + 884|0;
 $39 = sp + 872|0;
 $40 = sp + 860|0;
 $41 = sp + 848|0;
 $42 = sp + 836|0;
 $43 = sp + 824|0;
 $44 = sp + 812|0;
 $45 = sp + 800|0;
 $46 = sp + 788|0;
 $47 = sp + 776|0;
 $48 = sp + 764|0;
 $49 = sp + 752|0;
 $50 = sp + 740|0;
 $51 = sp + 728|0;
 $52 = sp + 716|0;
 $53 = sp + 704|0;
 $54 = sp + 692|0;
 $55 = sp + 680|0;
 $56 = sp + 668|0;
 $57 = sp + 656|0;
 $58 = sp + 644|0;
 $59 = sp + 632|0;
 $60 = sp + 620|0;
 $61 = sp + 608|0;
 $62 = sp + 596|0;
 $63 = sp + 584|0;
 $64 = sp + 572|0;
 $65 = sp + 560|0;
 $66 = sp + 128|0;
 $67 = sp + 548|0;
 $68 = sp + 112|0;
 $69 = sp + 536|0;
 $70 = sp + 96|0;
 $71 = sp + 524|0;
 $72 = sp + 80|0;
 $73 = sp + 512|0;
 $74 = sp + 64|0;
 $75 = sp + 500|0;
 $76 = sp + 48|0;
 $77 = sp + 488|0;
 $78 = sp + 32|0;
 $79 = sp + 476|0;
 $80 = sp + 16|0;
 $81 = sp + 464|0;
 $82 = sp + 452|0;
 $83 = sp + 440|0;
 $84 = sp + 428|0;
 $85 = sp + 416|0;
 $86 = sp + 404|0;
 $87 = sp + 392|0;
 $88 = sp + 380|0;
 $89 = sp + 368|0;
 $90 = sp + 356|0;
 $91 = sp + 344|0;
 $92 = sp + 332|0;
 $93 = sp;
 $94 = sp + 320|0;
 $95 = sp + 308|0;
 $96 = sp + 296|0;
 $97 = sp + 284|0;
 $98 = sp + 272|0;
 $99 = sp + 260|0;
 $100 = sp + 248|0;
 $101 = sp + 236|0;
 $102 = sp + 224|0;
 $103 = sp + 212|0;
 $104 = sp + 200|0;
 $105 = sp + 188|0;
 $106 = sp + 176|0;
 $107 = sp + 164|0;
 $108 = sp + 152|0;
 $109 = sp + 140|0;
 __ZN3osg10ReferencedC2Ev($0);
 HEAP32[$0>>2] = (75032);
 $110 = ((($0)) + 16|0);
 HEAP32[$110>>2] = 0;
 $111 = ((($0)) + 20|0);
 HEAP32[$111>>2] = 0;
 $112 = ((($0)) + 24|0);
 HEAP32[$112>>2] = 0;
 $113 = ((($0)) + 32|0);
 $114 = ((($0)) + 36|0);
 HEAP32[$114>>2] = 0;
 $115 = ((($0)) + 40|0);
 HEAP32[$115>>2] = 0;
 $116 = ((($0)) + 36|0);
 HEAP32[$113>>2] = $116;
 $117 = ((($0)) + 44|0);
 $118 = ((($0)) + 48|0);
 $119 = ((($0)) + 52|0);
 $120 = ((($0)) + 56|0);
 $121 = ((($0)) + 60|0);
 ;HEAP32[$117>>2]=0|0;HEAP32[$117+4>>2]=0|0;HEAP32[$117+8>>2]=0|0;HEAP32[$117+12>>2]=0|0;
 __THREW__ = 0;
 invoke_vii(3507,($121|0),1);
 $122 = __THREW__; __THREW__ = 0;
 $123 = $122&1;
 if ($123) {
  $187 = ___cxa_find_matching_catch_2()|0;
  $188 = tempRet0;
  $$74 = $187;$$74109 = $188;
 } else {
  HEAP32[$121>>2] = (41932);
  $124 = ((($0)) + 72|0);
  $125 = ((($0)) + 76|0);
  $126 = ((($0)) + 84|0);
  $127 = ((($0)) + 88|0);
  $128 = ((($0)) + 96|0);
  $129 = ((($0)) + 100|0);
  $130 = ((($0)) + 108|0);
  dest=$124; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
  __THREW__ = 0;
  invoke_vii(3507,($130|0),1);
  $131 = __THREW__; __THREW__ = 0;
  $132 = $131&1;
  if ($132) {
   $189 = ___cxa_find_matching_catch_2()|0;
   $190 = tempRet0;
   $$70 = $189;$$70105 = $190;
  } else {
   HEAP32[$130>>2] = (41932);
   $133 = ((($0)) + 120|0);
   $134 = ((($0)) + 124|0);
   HEAP32[$134>>2] = 0;
   $135 = ((($0)) + 128|0);
   HEAP32[$135>>2] = 0;
   $136 = ((($0)) + 124|0);
   HEAP32[$133>>2] = $136;
   $137 = ((($0)) + 136|0);
   $138 = ((($0)) + 140|0);
   HEAP32[$138>>2] = 0;
   $139 = ((($0)) + 144|0);
   HEAP32[$139>>2] = 0;
   $140 = ((($0)) + 140|0);
   HEAP32[$137>>2] = $140;
   $141 = ((($0)) + 148|0);
   $142 = ((($0)) + 152|0);
   HEAP32[$142>>2] = 0;
   $143 = ((($0)) + 156|0);
   HEAP32[$143>>2] = 0;
   $144 = ((($0)) + 152|0);
   HEAP32[$141>>2] = $144;
   $145 = ((($0)) + 160|0);
   $146 = ((($0)) + 164|0);
   $147 = ((($0)) + 188|0);
   $148 = ((($0)) + 212|0);
   $149 = ((($0)) + 224|0);
   $150 = ((($0)) + 228|0);
   $151 = ((($0)) + 236|0);
   $152 = ((($0)) + 240|0);
   $153 = ((($0)) + 244|0);
   $154 = ((($0)) + 12|0);
   HEAP32[$154>>2] = 0;
   dest=$145; stop=dest+56|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
   ;HEAP32[$149>>2]=0|0;HEAP32[$149+4>>2]=0|0;HEAP32[$149+8>>2]=0|0;HEAP32[$149+12>>2]=0|0;HEAP32[$149+16>>2]=0|0;HEAP32[$149+20>>2]=0|0;
   __THREW__ = 0;
   $155 = (invoke_ii(3276,104)|0);
   $156 = __THREW__; __THREW__ = 0;
   $157 = $156&1;
   L7: do {
    if ($157) {
     label = 17;
    } else {
     __THREW__ = 0;
     invoke_vi(4180,($155|0));
     $158 = __THREW__; __THREW__ = 0;
     $159 = $158&1;
     if ($159) {
      $193 = ___cxa_find_matching_catch_2()|0;
      $194 = tempRet0;
      __ZdlPv($155);
      $$63 = $193;$$6398 = $194;
      break;
     }
     $160 = HEAP32[$110>>2]|0;
     $161 = ($160|0)==($155|0);
     if (!($161)) {
      HEAP32[$110>>2] = $155;
      $162 = HEAP32[$155>>2]|0;
      $163 = ((($162)) + -12|0);
      $164 = HEAP32[$163>>2]|0;
      $165 = (($155) + ($164)|0);
      $166 = ((($165)) + 8|0);
      $167 = HEAP32[$166>>2]|0;HEAP32[$166>>2] = (($167+1)|0);
      $168 = ($160|0)==(0|0);
      if (!($168)) {
       $169 = HEAP32[$160>>2]|0;
       $170 = ((($169)) + -12|0);
       $171 = HEAP32[$170>>2]|0;
       $172 = (($160) + ($171)|0);
       $173 = ((($172)) + 8|0);
       $174 = HEAP32[$173>>2]|0;HEAP32[$173>>2] = (($174-1)|0);
       $175 = ($174|0)==(1);
       if ($175) {
        __THREW__ = 0;
        invoke_viii(3262,($172|0),1,1);
        $176 = __THREW__; __THREW__ = 0;
        $177 = $176&1;
        if ($177) {
         label = 17;
         break;
        }
       }
      }
     }
     $178 = (_getenv((167094|0))|0);
     $179 = ($178|0)==(0|0);
     if (!($179)) {
      $180 = (_strcmp($178,167112)|0);
      $181 = ($180|0)==(0);
      if ($181) {
       label = 13;
      } else {
       $182 = (_strcmp($178,167116)|0);
       $183 = ($182|0)==(0);
       if ($183) {
        label = 13;
       } else {
        $184 = (_strcmp($178,167120)|0);
        $185 = ($184|0)==(0);
        if ($185) {
         label = 13;
        } else {
         $186 = 2;
        }
       }
      }
      if ((label|0) == 13) {
       $186 = 1;
      }
      HEAP32[$154>>2] = $186;
     }
     $195 = ((($0)) + 216|0);
     HEAPF64[$195>>3] = 10.0;
     $196 = (_getenv((167124|0))|0);
     $197 = ($196|0)==(0|0);
     L26: do {
      if (!($197)) {
       __THREW__ = 0;
       $198 = (+invoke_di(4181,($196|0)));
       $199 = __THREW__; __THREW__ = 0;
       $200 = $199&1;
       L28: do {
        if ($200) {
         label = 35;
        } else {
         HEAPF64[$195>>3] = $198;
         __THREW__ = 0;
         $201 = (invoke_ii(3265,4)|0);
         $202 = __THREW__; __THREW__ = 0;
         $203 = $202&1;
         if ($203) {
          label = 35;
         } else {
          if (!($201)) {
           break L26;
          }
          __THREW__ = 0;
          $204 = (invoke_ii(3266,4)|0);
          $205 = __THREW__; __THREW__ = 0;
          $206 = $205&1;
          if ($206) {
           label = 35;
          } else {
           __THREW__ = 0;
           $207 = (invoke_iiii(3267,($204|0),(167141|0),26)|0);
           $208 = __THREW__; __THREW__ = 0;
           $209 = $208&1;
           if ($209) {
            label = 35;
           } else {
            $210 = +HEAPF64[$195>>3];
            __THREW__ = 0;
            $211 = (invoke_iid(3519,($207|0),(+$210))|0);
            $212 = __THREW__; __THREW__ = 0;
            $213 = $212&1;
            if ($213) {
             label = 35;
            } else {
             $214 = HEAP32[$211>>2]|0;
             $215 = ((($214)) + -12|0);
             $216 = HEAP32[$215>>2]|0;
             $217 = (($211) + ($216)|0);
             __THREW__ = 0;
             invoke_vii(3257,($1|0),($217|0));
             $218 = __THREW__; __THREW__ = 0;
             $219 = $218&1;
             if ($219) {
              label = 35;
             } else {
              __THREW__ = 0;
              $220 = (invoke_iii(3255,($1|0),(215188|0))|0);
              $221 = __THREW__; __THREW__ = 0;
              $222 = $221&1;
              do {
               if (!($222)) {
                $223 = HEAP32[$220>>2]|0;
                $224 = ((($223)) + 28|0);
                $225 = HEAP32[$224>>2]|0;
                __THREW__ = 0;
                $226 = (invoke_iii($225|0,($220|0),10)|0);
                $227 = __THREW__; __THREW__ = 0;
                $228 = $227&1;
                if ($228) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3263,($1|0));
                $235 = __THREW__; __THREW__ = 0;
                $236 = $235&1;
                if ($236) {
                 label = 35;
                 break L28;
                }
                __THREW__ = 0;
                (invoke_iii(3268,($211|0),($226|0))|0);
                $237 = __THREW__; __THREW__ = 0;
                $238 = $237&1;
                if ($238) {
                 label = 35;
                 break L28;
                }
                __THREW__ = 0;
                (invoke_ii(3269,($211|0))|0);
                $239 = __THREW__; __THREW__ = 0;
                $240 = $239&1;
                if ($240) {
                 label = 35;
                 break L28;
                } else {
                 break L26;
                }
               }
              } while(0);
              $229 = ___cxa_find_matching_catch_2()|0;
              $230 = tempRet0;
              __THREW__ = 0;
              invoke_vi(3263,($1|0));
              $231 = __THREW__; __THREW__ = 0;
              $232 = $231&1;
              if ($232) {
               $233 = ___cxa_find_matching_catch_3(0|0)|0;
               $234 = tempRet0;
               ___clang_call_terminate($233);
               // unreachable;
              } else {
               $eh$lpad$body$index6Z2D = $230;$eh$lpad$body$indexZ2D = $229;
               break;
              }
             }
            }
           }
          }
         }
        }
       } while(0);
       if ((label|0) == 35) {
        $241 = ___cxa_find_matching_catch_2()|0;
        $242 = tempRet0;
        $eh$lpad$body$index6Z2D = $242;$eh$lpad$body$indexZ2D = $241;
       }
       $$63 = $eh$lpad$body$indexZ2D;$$6398 = $eh$lpad$body$index6Z2D;
       break L7;
      }
     } while(0);
     $243 = (_getenv((167168|0))|0);
     $244 = ($243|0)==(0|0);
     L49: do {
      if ($244) {
       label = 60;
      } else {
       __THREW__ = 0;
       $245 = (invoke_ii(3276,36)|0);
       $246 = __THREW__; __THREW__ = 0;
       $247 = $246&1;
       if (!($247)) {
        ;HEAP32[$2>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;
        $248 = (_strlen($243)|0);
        $249 = ($248>>>0)>(4294967279);
        do {
         if ($249) {
          __THREW__ = 0;
          invoke_vi(3367,($2|0));
          $250 = __THREW__; __THREW__ = 0;
          label = 55;
         } else {
          $251 = ($248>>>0)<(11);
          if ($251) {
           $260 = $248&255;
           $261 = ((($2)) + 11|0);
           HEAP8[$261>>0] = $260;
           $262 = ($248|0)==(0);
           if ($262) {
            $$017$i$i = $2;
           } else {
            $$016$i$i = $2;
            label = 45;
           }
          } else {
           $252 = (($248) + 16)|0;
           $253 = $252 & -16;
           __THREW__ = 0;
           $254 = (invoke_ii(3276,($253|0))|0);
           $255 = __THREW__; __THREW__ = 0;
           $256 = $255&1;
           if ($256) {
            label = 55;
            break;
           }
           HEAP32[$2>>2] = $254;
           $257 = $253 | -2147483648;
           $258 = ((($2)) + 8|0);
           HEAP32[$258>>2] = $257;
           $259 = ((($2)) + 4|0);
           HEAP32[$259>>2] = $248;
           $$016$i$i = $254;
           label = 45;
          }
          if ((label|0) == 45) {
           _memcpy(($$016$i$i|0),($243|0),($248|0))|0;
           $$017$i$i = $$016$i$i;
          }
          $263 = (($$017$i$i) + ($248)|0);
          HEAP8[$263>>0] = 0;
          __THREW__ = 0;
          invoke_vii(4182,($245|0),($2|0));
          $264 = __THREW__; __THREW__ = 0;
          $265 = $264&1;
          L62: do {
           if ($265) {
            $$033 = 1;
           } else {
            $266 = HEAP32[$111>>2]|0;
            $267 = ($266|0)==($245|0);
            do {
             if (!($267)) {
              HEAP32[$111>>2] = $245;
              $268 = ((($245)) + 8|0);
              $269 = HEAP32[$268>>2]|0;HEAP32[$268>>2] = (($269+1)|0);
              $270 = ($266|0)==(0|0);
              if ($270) {
               break;
              }
              $271 = ((($266)) + 8|0);
              $272 = HEAP32[$271>>2]|0;HEAP32[$271>>2] = (($272-1)|0);
              $273 = ($272|0)==(1);
              if (!($273)) {
               break;
              }
              __THREW__ = 0;
              invoke_viii(3262,($266|0),1,1);
              $274 = __THREW__; __THREW__ = 0;
              $275 = $274&1;
              if ($275) {
               $$033 = 0;
               break L62;
              }
             }
            } while(0);
            $276 = ((($2)) + 11|0);
            $277 = HEAP8[$276>>0]|0;
            $278 = ($277<<24>>24)<(0);
            if ($278) {
             $279 = HEAP32[$2>>2]|0;
             __ZdlPv($279);
            }
            label = 60;
            break L49;
           }
          } while(0);
          $284 = ___cxa_find_matching_catch_2()|0;
          $285 = tempRet0;
          $286 = ((($2)) + 11|0);
          $287 = HEAP8[$286>>0]|0;
          $288 = ($287<<24>>24)<(0);
          if ($288) {
           $289 = HEAP32[$2>>2]|0;
           __ZdlPv($289);
           if ($$033) {
            $$0321167 = $284;$$0351166 = $285;
            break;
           } else {
            $$63 = $284;$$6398 = $285;
            break L7;
           }
          } else {
           if ($$033) {
            $$0321167 = $284;$$0351166 = $285;
            break;
           } else {
            $$63 = $284;$$6398 = $285;
            break L7;
           }
          }
         }
        } while(0);
        if ((label|0) == 55) {
         $282 = ___cxa_find_matching_catch_2()|0;
         $283 = tempRet0;
         $$0321167 = $282;$$0351166 = $283;
        }
        __ZdlPv($245);
        $$63 = $$0321167;$$6398 = $$0351166;
        break L7;
       }
      }
     } while(0);
     do {
      if ((label|0) == 60) {
       __THREW__ = 0;
       $290 = (invoke_ii(3276,36)|0);
       $291 = __THREW__; __THREW__ = 0;
       $292 = $291&1;
       if (!($292)) {
        __THREW__ = 0;
        invoke_vi(4124,($290|0));
        $293 = __THREW__; __THREW__ = 0;
        $294 = $293&1;
        if ($294) {
         $369 = ___cxa_find_matching_catch_2()|0;
         $370 = tempRet0;
         __ZdlPv($290);
         $$63 = $369;$$6398 = $370;
         break L7;
        }
        $295 = HEAP32[$148>>2]|0;
        $296 = ($295|0)==($290|0);
        if (!($296)) {
         HEAP32[$148>>2] = $290;
         $297 = ((($290)) + 8|0);
         $298 = HEAP32[$297>>2]|0;HEAP32[$297>>2] = (($298+1)|0);
         $299 = ($295|0)==(0|0);
         if (!($299)) {
          $300 = ((($295)) + 8|0);
          $301 = HEAP32[$300>>2]|0;HEAP32[$300>>2] = (($301-1)|0);
          $302 = ($301|0)==(1);
          if ($302) {
           __THREW__ = 0;
           invoke_viii(3262,($295|0),1,1);
           $303 = __THREW__; __THREW__ = 0;
           $304 = $303&1;
           if ($304) {
            break;
           }
          }
         }
        }
        $305 = ((($0)) + 28|0);
        HEAP8[$305>>0] = 0;
        $306 = ((($0)) + 132|0);
        HEAP8[$306>>0] = 0;
        ;HEAP32[$3>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;
        $307 = ((($3)) + 11|0);
        HEAP8[$307>>0] = 4;
        HEAP32[$3>>2] = 1634169711;
        $308 = ((($3)) + 4|0);
        HEAP8[$308>>0] = 0;
        $309 = HEAP32[$150>>2]|0;
        $310 = ((($0)) + 232|0);
        $311 = HEAP32[$310>>2]|0;
        $312 = ($309|0)==($311|0);
        if ($312) {
         __THREW__ = 0;
         invoke_vii(3747,($149|0),($3|0));
         $317 = __THREW__; __THREW__ = 0;
         $318 = $317&1;
         if ($318) {
          label = 89;
         }
        } else {
         __THREW__ = 0;
         invoke_vii(3457,($309|0),($3|0));
         $313 = __THREW__; __THREW__ = 0;
         $314 = $313&1;
         if ($314) {
          label = 89;
         } else {
          $315 = HEAP32[$150>>2]|0;
          $316 = ((($315)) + 12|0);
          HEAP32[$150>>2] = $316;
         }
        }
        if ((label|0) == 89) {
         $371 = ___cxa_find_matching_catch_2()|0;
         $372 = tempRet0;
         $373 = HEAP8[$307>>0]|0;
         $374 = ($373<<24>>24)<(0);
         if ($374) {
          $375 = HEAP32[$3>>2]|0;
          __ZdlPv($375);
         }
         $$63 = $371;$$6398 = $372;
         break L7;
        }
        $319 = HEAP8[$307>>0]|0;
        $320 = ($319<<24>>24)<(0);
        if ($320) {
         $321 = HEAP32[$3>>2]|0;
         __ZdlPv($321);
        }
        $322 = ((($4)) + 4|0);
        $323 = $322;
        $324 = $323;
        HEAP32[$324>>2] = 0;
        $325 = (($323) + 4)|0;
        $326 = $325;
        HEAP32[$326>>2] = 0;
        $327 = ((($4)) + 11|0);
        HEAP8[$327>>0] = 3;
        ;HEAP8[$4>>0]=HEAP8[173086>>0]|0;HEAP8[$4+1>>0]=HEAP8[173086+1>>0]|0;HEAP8[$4+2>>0]=HEAP8[173086+2>>0]|0;
        $328 = ((($4)) + 3|0);
        HEAP8[$328>>0] = 0;
        $329 = HEAP32[$150>>2]|0;
        $330 = HEAP32[$310>>2]|0;
        $331 = ($329|0)==($330|0);
        if ($331) {
         __THREW__ = 0;
         invoke_vii(3747,($149|0),($4|0));
         $336 = __THREW__; __THREW__ = 0;
         $337 = $336&1;
         if ($337) {
          label = 92;
         }
        } else {
         __THREW__ = 0;
         invoke_vii(3457,($329|0),($4|0));
         $332 = __THREW__; __THREW__ = 0;
         $333 = $332&1;
         if ($333) {
          label = 92;
         } else {
          $334 = HEAP32[$150>>2]|0;
          $335 = ((($334)) + 12|0);
          HEAP32[$150>>2] = $335;
         }
        }
        if ((label|0) == 92) {
         $376 = ___cxa_find_matching_catch_2()|0;
         $377 = tempRet0;
         $378 = HEAP8[$327>>0]|0;
         $379 = ($378<<24>>24)<(0);
         if ($379) {
          $380 = HEAP32[$4>>2]|0;
          __ZdlPv($380);
         }
         $$63 = $376;$$6398 = $377;
         break L7;
        }
        $338 = HEAP8[$327>>0]|0;
        $339 = ($338<<24>>24)<(0);
        if ($339) {
         $340 = HEAP32[$4>>2]|0;
         __ZdlPv($340);
        }
        __THREW__ = 0;
        invoke_vi(4183,($0|0));
        $341 = __THREW__; __THREW__ = 0;
        $342 = $341&1;
        if (!($342)) {
         __THREW__ = 0;
         invoke_vi(4184,($0|0));
         $343 = __THREW__; __THREW__ = 0;
         $344 = $343&1;
         if ($344) {
          break;
         }
         $345 = (_getenv((167183|0))|0);
         $346 = ($345|0)==(0|0);
         L118: do {
          if ($346) {
           $391 = ((($7)) + 4|0);
           $392 = $391;
           $393 = $392;
           HEAP32[$393>>2] = 0;
           $394 = (($392) + 4)|0;
           $395 = $394;
           HEAP32[$395>>2] = 0;
           $396 = ((($7)) + 11|0);
           HEAP8[$396>>0] = 3;
           ;HEAP8[$7>>0]=HEAP8[167210>>0]|0;HEAP8[$7+1>>0]=HEAP8[167210+1>>0]|0;HEAP8[$7+2>>0]=HEAP8[167210+2>>0]|0;
           $397 = ((($7)) + 3|0);
           HEAP8[$397>>0] = 0;
           $398 = ((($8)) + 11|0);
           HEAP8[$398>>0] = 10;
           dest=$8; src=167214; stop=dest+10|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
           $399 = ((($8)) + 10|0);
           HEAP8[$399>>0] = 0;
           __THREW__ = 0;
           $400 = (invoke_iii(3694,($137|0),($7|0))|0);
           $401 = __THREW__; __THREW__ = 0;
           $402 = $401&1;
           do {
            if (!($402)) {
             __THREW__ = 0;
             (invoke_iii(3477,($400|0),($8|0))|0);
             $403 = __THREW__; __THREW__ = 0;
             $404 = $403&1;
             if ($404) {
              break;
             }
             $405 = HEAP8[$398>>0]|0;
             $406 = ($405<<24>>24)<(0);
             if ($406) {
              $407 = HEAP32[$8>>2]|0;
              __ZdlPv($407);
             }
             $408 = HEAP8[$396>>0]|0;
             $409 = ($408<<24>>24)<(0);
             if (!($409)) {
              break L118;
             }
             $410 = HEAP32[$7>>2]|0;
             __ZdlPv($410);
             break L118;
            }
           } while(0);
           $411 = ___cxa_find_matching_catch_2()|0;
           $412 = tempRet0;
           $413 = HEAP8[$398>>0]|0;
           $414 = ($413<<24>>24)<(0);
           if ($414) {
            $415 = HEAP32[$8>>2]|0;
            __ZdlPv($415);
           }
           $416 = HEAP8[$396>>0]|0;
           $417 = ($416<<24>>24)<(0);
           if (!($417)) {
            $$63 = $411;$$6398 = $412;
            break L7;
           }
           $418 = HEAP32[$7>>2]|0;
           __ZdlPv($418);
           $$63 = $411;$$6398 = $412;
           break L7;
          } else {
           $347 = (_strcmp($345,167206)|0);
           $348 = ($347|0)==(0);
           if (!($348)) {
            break;
           }
           $349 = ((($5)) + 4|0);
           $350 = $349;
           $351 = $350;
           HEAP32[$351>>2] = 0;
           $352 = (($350) + 4)|0;
           $353 = $352;
           HEAP32[$353>>2] = 0;
           $354 = ((($5)) + 11|0);
           HEAP8[$354>>0] = 3;
           ;HEAP8[$5>>0]=HEAP8[167210>>0]|0;HEAP8[$5+1>>0]=HEAP8[167210+1>>0]|0;HEAP8[$5+2>>0]=HEAP8[167210+2>>0]|0;
           $355 = ((($5)) + 3|0);
           HEAP8[$355>>0] = 0;
           $356 = ((($6)) + 11|0);
           HEAP8[$356>>0] = 10;
           dest=$6; src=167214; stop=dest+10|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
           $357 = ((($6)) + 10|0);
           HEAP8[$357>>0] = 0;
           __THREW__ = 0;
           $358 = (invoke_iii(3694,($137|0),($5|0))|0);
           $359 = __THREW__; __THREW__ = 0;
           $360 = $359&1;
           do {
            if (!($360)) {
             __THREW__ = 0;
             (invoke_iii(3477,($358|0),($6|0))|0);
             $361 = __THREW__; __THREW__ = 0;
             $362 = $361&1;
             if ($362) {
              break;
             }
             $363 = HEAP8[$356>>0]|0;
             $364 = ($363<<24>>24)<(0);
             if ($364) {
              $365 = HEAP32[$6>>2]|0;
              __ZdlPv($365);
             }
             $366 = HEAP8[$354>>0]|0;
             $367 = ($366<<24>>24)<(0);
             if (!($367)) {
              break L118;
             }
             $368 = HEAP32[$5>>2]|0;
             __ZdlPv($368);
             break L118;
            }
           } while(0);
           $383 = ___cxa_find_matching_catch_2()|0;
           $384 = tempRet0;
           $385 = HEAP8[$356>>0]|0;
           $386 = ($385<<24>>24)<(0);
           if ($386) {
            $387 = HEAP32[$6>>2]|0;
            __ZdlPv($387);
           }
           $388 = HEAP8[$354>>0]|0;
           $389 = ($388<<24>>24)<(0);
           if (!($389)) {
            $$63 = $383;$$6398 = $384;
            break L7;
           }
           $390 = HEAP32[$5>>2]|0;
           __ZdlPv($390);
           $$63 = $383;$$6398 = $384;
           break L7;
          }
         } while(0);
         ;HEAP32[$9>>2]=0|0;HEAP32[$9+4>>2]=0|0;HEAP32[$9+8>>2]=0|0;
         $419 = ((($9)) + 11|0);
         HEAP8[$419>>0] = 4;
         HEAP32[$9>>2] = 1936159599;
         $420 = ((($9)) + 4|0);
         HEAP8[$420>>0] = 0;
         $421 = ((($10)) + 4|0);
         $422 = $421;
         $423 = $422;
         HEAP32[$423>>2] = 0;
         $424 = (($422) + 4)|0;
         $425 = $424;
         HEAP32[$425>>2] = 0;
         $426 = ((($10)) + 11|0);
         HEAP8[$426>>0] = 3;
         ;HEAP8[$10>>0]=HEAP8[175113>>0]|0;HEAP8[$10+1>>0]=HEAP8[175113+1>>0]|0;HEAP8[$10+2>>0]=HEAP8[175113+2>>0]|0;
         $427 = ((($10)) + 3|0);
         HEAP8[$427>>0] = 0;
         __THREW__ = 0;
         $428 = (invoke_iii(3694,($137|0),($9|0))|0);
         $429 = __THREW__; __THREW__ = 0;
         $430 = $429&1;
         do {
          if (!($430)) {
           __THREW__ = 0;
           (invoke_iii(3477,($428|0),($10|0))|0);
           $431 = __THREW__; __THREW__ = 0;
           $432 = $431&1;
           if ($432) {
            break;
           }
           $433 = HEAP8[$426>>0]|0;
           $434 = ($433<<24>>24)<(0);
           if ($434) {
            $435 = HEAP32[$10>>2]|0;
            __ZdlPv($435);
           }
           $436 = HEAP8[$419>>0]|0;
           $437 = ($436<<24>>24)<(0);
           if ($437) {
            $438 = HEAP32[$9>>2]|0;
            __ZdlPv($438);
           }
           ;HEAP32[$11>>2]=0|0;HEAP32[$11+4>>2]=0|0;HEAP32[$11+8>>2]=0|0;
           $439 = ((($11)) + 11|0);
           HEAP8[$439>>0] = 4;
           HEAP32[$11>>2] = 1952936815;
           $440 = ((($11)) + 4|0);
           HEAP8[$440>>0] = 0;
           $441 = ((($12)) + 4|0);
           $442 = $441;
           $443 = $442;
           HEAP32[$443>>2] = 0;
           $444 = (($442) + 4)|0;
           $445 = $444;
           HEAP32[$445>>2] = 0;
           $446 = ((($12)) + 11|0);
           HEAP8[$446>>0] = 3;
           ;HEAP8[$12>>0]=HEAP8[175113>>0]|0;HEAP8[$12+1>>0]=HEAP8[175113+1>>0]|0;HEAP8[$12+2>>0]=HEAP8[175113+2>>0]|0;
           $447 = ((($12)) + 3|0);
           HEAP8[$447>>0] = 0;
           __THREW__ = 0;
           $448 = (invoke_iii(3694,($137|0),($11|0))|0);
           $449 = __THREW__; __THREW__ = 0;
           $450 = $449&1;
           do {
            if (!($450)) {
             __THREW__ = 0;
             (invoke_iii(3477,($448|0),($12|0))|0);
             $451 = __THREW__; __THREW__ = 0;
             $452 = $451&1;
             if ($452) {
              break;
             }
             $453 = HEAP8[$446>>0]|0;
             $454 = ($453<<24>>24)<(0);
             if ($454) {
              $455 = HEAP32[$12>>2]|0;
              __ZdlPv($455);
             }
             $456 = HEAP8[$439>>0]|0;
             $457 = ($456<<24>>24)<(0);
             if ($457) {
              $458 = HEAP32[$11>>2]|0;
              __ZdlPv($458);
             }
             ;HEAP32[$13>>2]=0|0;HEAP32[$13+4>>2]=0|0;HEAP32[$13+8>>2]=0|0;
             $459 = ((($13)) + 11|0);
             HEAP8[$459>>0] = 4;
             HEAP32[$13>>2] = 1650946927;
             $460 = ((($13)) + 4|0);
             HEAP8[$460>>0] = 0;
             $461 = ((($14)) + 4|0);
             $462 = $461;
             $463 = $462;
             HEAP32[$463>>2] = 0;
             $464 = (($462) + 4)|0;
             $465 = $464;
             HEAP32[$465>>2] = 0;
             $466 = ((($14)) + 11|0);
             HEAP8[$466>>0] = 3;
             ;HEAP8[$14>>0]=HEAP8[175113>>0]|0;HEAP8[$14+1>>0]=HEAP8[175113+1>>0]|0;HEAP8[$14+2>>0]=HEAP8[175113+2>>0]|0;
             $467 = ((($14)) + 3|0);
             HEAP8[$467>>0] = 0;
             __THREW__ = 0;
             $468 = (invoke_iii(3694,($137|0),($13|0))|0);
             $469 = __THREW__; __THREW__ = 0;
             $470 = $469&1;
             do {
              if (!($470)) {
               __THREW__ = 0;
               (invoke_iii(3477,($468|0),($14|0))|0);
               $471 = __THREW__; __THREW__ = 0;
               $472 = $471&1;
               if ($472) {
                break;
               }
               $473 = HEAP8[$466>>0]|0;
               $474 = ($473<<24>>24)<(0);
               if ($474) {
                $475 = HEAP32[$14>>2]|0;
                __ZdlPv($475);
               }
               $476 = HEAP8[$459>>0]|0;
               $477 = ($476<<24>>24)<(0);
               if ($477) {
                $478 = HEAP32[$13>>2]|0;
                __ZdlPv($478);
               }
               ;HEAP32[$15>>2]=0|0;HEAP32[$15+4>>2]=0|0;HEAP32[$15+8>>2]=0|0;
               $479 = ((($15)) + 11|0);
               HEAP8[$479>>0] = 4;
               HEAP32[$15>>2] = 2020045679;
               $480 = ((($15)) + 4|0);
               HEAP8[$480>>0] = 0;
               $481 = ((($16)) + 4|0);
               $482 = $481;
               $483 = $482;
               HEAP32[$483>>2] = 0;
               $484 = (($482) + 4)|0;
               $485 = $484;
               HEAP32[$485>>2] = 0;
               $486 = ((($16)) + 11|0);
               HEAP8[$486>>0] = 3;
               ;HEAP8[$16>>0]=HEAP8[175113>>0]|0;HEAP8[$16+1>>0]=HEAP8[175113+1>>0]|0;HEAP8[$16+2>>0]=HEAP8[175113+2>>0]|0;
               $487 = ((($16)) + 3|0);
               HEAP8[$487>>0] = 0;
               __THREW__ = 0;
               $488 = (invoke_iii(3694,($137|0),($15|0))|0);
               $489 = __THREW__; __THREW__ = 0;
               $490 = $489&1;
               do {
                if (!($490)) {
                 __THREW__ = 0;
                 (invoke_iii(3477,($488|0),($16|0))|0);
                 $491 = __THREW__; __THREW__ = 0;
                 $492 = $491&1;
                 if ($492) {
                  break;
                 }
                 $493 = HEAP8[$486>>0]|0;
                 $494 = ($493<<24>>24)<(0);
                 if ($494) {
                  $495 = HEAP32[$16>>2]|0;
                  __ZdlPv($495);
                 }
                 $496 = HEAP8[$479>>0]|0;
                 $497 = ($496<<24>>24)<(0);
                 if ($497) {
                  $498 = HEAP32[$15>>2]|0;
                  __ZdlPv($498);
                 }
                 ;HEAP32[$17>>2]=0|0;HEAP32[$17+4>>2]=0|0;HEAP32[$17+8>>2]=0|0;
                 $499 = ((($17)) + 11|0);
                 HEAP8[$499>>0] = 6;
                 ;HEAP8[$17>>0]=HEAP8[167225>>0]|0;HEAP8[$17+1>>0]=HEAP8[167225+1>>0]|0;HEAP8[$17+2>>0]=HEAP8[167225+2>>0]|0;HEAP8[$17+3>>0]=HEAP8[167225+3>>0]|0;HEAP8[$17+4>>0]=HEAP8[167225+4>>0]|0;HEAP8[$17+5>>0]=HEAP8[167225+5>>0]|0;
                 $500 = ((($17)) + 6|0);
                 HEAP8[$500>>0] = 0;
                 ;HEAP32[$18>>2]=0|0;HEAP32[$18+4>>2]=0|0;HEAP32[$18+8>>2]=0|0;
                 $501 = ((($18)) + 11|0);
                 HEAP8[$501>>0] = 9;
                 dest=$18; src=167232; stop=dest+9|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                 $502 = ((($18)) + 9|0);
                 HEAP8[$502>>0] = 0;
                 __THREW__ = 0;
                 $503 = (invoke_iii(3694,($137|0),($17|0))|0);
                 $504 = __THREW__; __THREW__ = 0;
                 $505 = $504&1;
                 do {
                  if (!($505)) {
                   __THREW__ = 0;
                   (invoke_iii(3477,($503|0),($18|0))|0);
                   $506 = __THREW__; __THREW__ = 0;
                   $507 = $506&1;
                   if ($507) {
                    break;
                   }
                   $508 = HEAP8[$501>>0]|0;
                   $509 = ($508<<24>>24)<(0);
                   if ($509) {
                    $510 = HEAP32[$18>>2]|0;
                    __ZdlPv($510);
                   }
                   $511 = HEAP8[$499>>0]|0;
                   $512 = ($511<<24>>24)<(0);
                   if ($512) {
                    $513 = HEAP32[$17>>2]|0;
                    __ZdlPv($513);
                   }
                   $514 = ((($19)) + 8|0);
                   HEAP32[$514>>2] = 0;
                   $515 = ((($19)) + 11|0);
                   HEAP8[$515>>0] = 7;
                   ;HEAP8[$19>>0]=HEAP8[167242>>0]|0;HEAP8[$19+1>>0]=HEAP8[167242+1>>0]|0;HEAP8[$19+2>>0]=HEAP8[167242+2>>0]|0;HEAP8[$19+3>>0]=HEAP8[167242+3>>0]|0;HEAP8[$19+4>>0]=HEAP8[167242+4>>0]|0;HEAP8[$19+5>>0]=HEAP8[167242+5>>0]|0;HEAP8[$19+6>>0]=HEAP8[167242+6>>0]|0;
                   $516 = ((($19)) + 7|0);
                   HEAP8[$516>>0] = 0;
                   $517 = ((($20)) + 11|0);
                   HEAP8[$517>>0] = 10;
                   dest=$20; src=167250; stop=dest+10|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                   $518 = ((($20)) + 10|0);
                   HEAP8[$518>>0] = 0;
                   __THREW__ = 0;
                   $519 = (invoke_iii(3694,($137|0),($19|0))|0);
                   $520 = __THREW__; __THREW__ = 0;
                   $521 = $520&1;
                   do {
                    if (!($521)) {
                     __THREW__ = 0;
                     (invoke_iii(3477,($519|0),($20|0))|0);
                     $522 = __THREW__; __THREW__ = 0;
                     $523 = $522&1;
                     if ($523) {
                      break;
                     }
                     $524 = HEAP8[$517>>0]|0;
                     $525 = ($524<<24>>24)<(0);
                     if ($525) {
                      $526 = HEAP32[$20>>2]|0;
                      __ZdlPv($526);
                     }
                     $527 = HEAP8[$515>>0]|0;
                     $528 = ($527<<24>>24)<(0);
                     if ($528) {
                      $529 = HEAP32[$19>>2]|0;
                      __ZdlPv($529);
                     }
                     ;HEAP32[$21>>2]=0|0;HEAP32[$21+4>>2]=0|0;HEAP32[$21+8>>2]=0|0;
                     $530 = ((($21)) + 11|0);
                     HEAP8[$530>>0] = 4;
                     HEAP32[$21>>2] = 2003134838;
                     $531 = ((($21)) + 4|0);
                     HEAP8[$531>>0] = 0;
                     ;HEAP32[$22>>2]=0|0;HEAP32[$22+4>>2]=0|0;HEAP32[$22+8>>2]=0|0;
                     $532 = ((($22)) + 11|0);
                     HEAP8[$532>>0] = 9;
                     dest=$22; src=167261; stop=dest+9|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                     $533 = ((($22)) + 9|0);
                     HEAP8[$533>>0] = 0;
                     __THREW__ = 0;
                     $534 = (invoke_iii(3694,($137|0),($21|0))|0);
                     $535 = __THREW__; __THREW__ = 0;
                     $536 = $535&1;
                     do {
                      if (!($536)) {
                       __THREW__ = 0;
                       (invoke_iii(3477,($534|0),($22|0))|0);
                       $537 = __THREW__; __THREW__ = 0;
                       $538 = $537&1;
                       if ($538) {
                        break;
                       }
                       $539 = HEAP8[$532>>0]|0;
                       $540 = ($539<<24>>24)<(0);
                       if ($540) {
                        $541 = HEAP32[$22>>2]|0;
                        __ZdlPv($541);
                       }
                       $542 = HEAP8[$530>>0]|0;
                       $543 = ($542<<24>>24)<(0);
                       if ($543) {
                        $544 = HEAP32[$21>>2]|0;
                        __ZdlPv($544);
                       }
                       $545 = ((($23)) + 4|0);
                       $546 = $545;
                       $547 = $546;
                       HEAP32[$547>>2] = 0;
                       $548 = (($546) + 4)|0;
                       $549 = $548;
                       HEAP32[$549>>2] = 0;
                       $550 = ((($23)) + 11|0);
                       HEAP8[$550>>0] = 3;
                       ;HEAP8[$23>>0]=HEAP8[167271>>0]|0;HEAP8[$23+1>>0]=HEAP8[167271+1>>0]|0;HEAP8[$23+2>>0]=HEAP8[167271+2>>0]|0;
                       $551 = ((($23)) + 3|0);
                       HEAP8[$551>>0] = 0;
                       $552 = ((($24)) + 4|0);
                       $553 = $552;
                       $554 = $553;
                       HEAP32[$554>>2] = 0;
                       $555 = (($553) + 4)|0;
                       $556 = $555;
                       HEAP32[$556>>2] = 0;
                       $557 = ((($24)) + 11|0);
                       HEAP8[$557>>0] = 3;
                       ;HEAP8[$24>>0]=HEAP8[174031>>0]|0;HEAP8[$24+1>>0]=HEAP8[174031+1>>0]|0;HEAP8[$24+2>>0]=HEAP8[174031+2>>0]|0;
                       $558 = ((($24)) + 3|0);
                       HEAP8[$558>>0] = 0;
                       __THREW__ = 0;
                       $559 = (invoke_iii(3694,($137|0),($23|0))|0);
                       $560 = __THREW__; __THREW__ = 0;
                       $561 = $560&1;
                       do {
                        if (!($561)) {
                         __THREW__ = 0;
                         (invoke_iii(3477,($559|0),($24|0))|0);
                         $562 = __THREW__; __THREW__ = 0;
                         $563 = $562&1;
                         if ($563) {
                          break;
                         }
                         $564 = HEAP8[$557>>0]|0;
                         $565 = ($564<<24>>24)<(0);
                         if ($565) {
                          $566 = HEAP32[$24>>2]|0;
                          __ZdlPv($566);
                         }
                         $567 = HEAP8[$550>>0]|0;
                         $568 = ($567<<24>>24)<(0);
                         if ($568) {
                          $569 = HEAP32[$23>>2]|0;
                          __ZdlPv($569);
                         }
                         ;HEAP32[$25>>2]=0|0;HEAP32[$25+4>>2]=0|0;HEAP32[$25+8>>2]=0|0;
                         $570 = ((($25)) + 11|0);
                         HEAP8[$570>>0] = 4;
                         HEAP32[$25>>2] = 1633838962;
                         $571 = ((($25)) + 4|0);
                         HEAP8[$571>>0] = 0;
                         $572 = ((($26)) + 4|0);
                         $573 = $572;
                         $574 = $573;
                         HEAP32[$574>>2] = 0;
                         $575 = (($573) + 4)|0;
                         $576 = $575;
                         HEAP32[$576>>2] = 0;
                         $577 = ((($26)) + 11|0);
                         HEAP8[$577>>0] = 3;
                         ;HEAP8[$26>>0]=HEAP8[174031>>0]|0;HEAP8[$26+1>>0]=HEAP8[174031+1>>0]|0;HEAP8[$26+2>>0]=HEAP8[174031+2>>0]|0;
                         $578 = ((($26)) + 3|0);
                         HEAP8[$578>>0] = 0;
                         __THREW__ = 0;
                         $579 = (invoke_iii(3694,($137|0),($25|0))|0);
                         $580 = __THREW__; __THREW__ = 0;
                         $581 = $580&1;
                         do {
                          if (!($581)) {
                           __THREW__ = 0;
                           (invoke_iii(3477,($579|0),($26|0))|0);
                           $582 = __THREW__; __THREW__ = 0;
                           $583 = $582&1;
                           if ($583) {
                            break;
                           }
                           $584 = HEAP8[$577>>0]|0;
                           $585 = ($584<<24>>24)<(0);
                           if ($585) {
                            $586 = HEAP32[$26>>2]|0;
                            __ZdlPv($586);
                           }
                           $587 = HEAP8[$570>>0]|0;
                           $588 = ($587<<24>>24)<(0);
                           if ($588) {
                            $589 = HEAP32[$25>>2]|0;
                            __ZdlPv($589);
                           }
                           $590 = ((($27)) + 4|0);
                           $591 = $590;
                           $592 = $591;
                           HEAP32[$592>>2] = 0;
                           $593 = (($591) + 4)|0;
                           $594 = $593;
                           HEAP32[$594>>2] = 0;
                           $595 = ((($27)) + 11|0);
                           HEAP8[$595>>0] = 3;
                           ;HEAP8[$27>>0]=HEAP8[167275>>0]|0;HEAP8[$27+1>>0]=HEAP8[167275+1>>0]|0;HEAP8[$27+2>>0]=HEAP8[167275+2>>0]|0;
                           $596 = ((($27)) + 3|0);
                           HEAP8[$596>>0] = 0;
                           $597 = ((($28)) + 4|0);
                           $598 = $597;
                           $599 = $598;
                           HEAP32[$599>>2] = 0;
                           $600 = (($598) + 4)|0;
                           $601 = $600;
                           HEAP32[$601>>2] = 0;
                           $602 = ((($28)) + 11|0);
                           HEAP8[$602>>0] = 3;
                           ;HEAP8[$28>>0]=HEAP8[174031>>0]|0;HEAP8[$28+1>>0]=HEAP8[174031+1>>0]|0;HEAP8[$28+2>>0]=HEAP8[174031+2>>0]|0;
                           $603 = ((($28)) + 3|0);
                           HEAP8[$603>>0] = 0;
                           __THREW__ = 0;
                           $604 = (invoke_iii(3694,($137|0),($27|0))|0);
                           $605 = __THREW__; __THREW__ = 0;
                           $606 = $605&1;
                           do {
                            if (!($606)) {
                             __THREW__ = 0;
                             (invoke_iii(3477,($604|0),($28|0))|0);
                             $607 = __THREW__; __THREW__ = 0;
                             $608 = $607&1;
                             if ($608) {
                              break;
                             }
                             $609 = HEAP8[$602>>0]|0;
                             $610 = ($609<<24>>24)<(0);
                             if ($610) {
                              $611 = HEAP32[$28>>2]|0;
                              __ZdlPv($611);
                             }
                             $612 = HEAP8[$595>>0]|0;
                             $613 = ($612<<24>>24)<(0);
                             if ($613) {
                              $614 = HEAP32[$27>>2]|0;
                              __ZdlPv($614);
                             }
                             ;HEAP32[$29>>2]=0|0;HEAP32[$29+4>>2]=0|0;HEAP32[$29+8>>2]=0|0;
                             $615 = ((($29)) + 11|0);
                             HEAP8[$615>>0] = 4;
                             HEAP32[$29>>2] = 1635020393;
                             $616 = ((($29)) + 4|0);
                             HEAP8[$616>>0] = 0;
                             $617 = ((($30)) + 4|0);
                             $618 = $617;
                             $619 = $618;
                             HEAP32[$619>>2] = 0;
                             $620 = (($618) + 4)|0;
                             $621 = $620;
                             HEAP32[$621>>2] = 0;
                             $622 = ((($30)) + 11|0);
                             HEAP8[$622>>0] = 3;
                             ;HEAP8[$30>>0]=HEAP8[174031>>0]|0;HEAP8[$30+1>>0]=HEAP8[174031+1>>0]|0;HEAP8[$30+2>>0]=HEAP8[174031+2>>0]|0;
                             $623 = ((($30)) + 3|0);
                             HEAP8[$623>>0] = 0;
                             __THREW__ = 0;
                             $624 = (invoke_iii(3694,($137|0),($29|0))|0);
                             $625 = __THREW__; __THREW__ = 0;
                             $626 = $625&1;
                             do {
                              if (!($626)) {
                               __THREW__ = 0;
                               (invoke_iii(3477,($624|0),($30|0))|0);
                               $627 = __THREW__; __THREW__ = 0;
                               $628 = $627&1;
                               if ($628) {
                                break;
                               }
                               $629 = HEAP8[$622>>0]|0;
                               $630 = ($629<<24>>24)<(0);
                               if ($630) {
                                $631 = HEAP32[$30>>2]|0;
                                __ZdlPv($631);
                               }
                               $632 = HEAP8[$615>>0]|0;
                               $633 = ($632<<24>>24)<(0);
                               if ($633) {
                                $634 = HEAP32[$29>>2]|0;
                                __ZdlPv($634);
                               }
                               ;HEAP32[$31>>2]=0|0;HEAP32[$31+4>>2]=0|0;HEAP32[$31+8>>2]=0|0;
                               $635 = ((($31)) + 11|0);
                               HEAP8[$635>>0] = 2;
                               HEAP16[$31>>1] = 30562;
                               $636 = ((($31)) + 2|0);
                               HEAP8[$636>>0] = 0;
                               $637 = ((($32)) + 4|0);
                               $638 = $637;
                               $639 = $638;
                               HEAP32[$639>>2] = 0;
                               $640 = (($638) + 4)|0;
                               $641 = $640;
                               HEAP32[$641>>2] = 0;
                               $642 = ((($32)) + 11|0);
                               HEAP8[$642>>0] = 3;
                               ;HEAP8[$32>>0]=HEAP8[174031>>0]|0;HEAP8[$32+1>>0]=HEAP8[174031+1>>0]|0;HEAP8[$32+2>>0]=HEAP8[174031+2>>0]|0;
                               $643 = ((($32)) + 3|0);
                               HEAP8[$643>>0] = 0;
                               __THREW__ = 0;
                               $644 = (invoke_iii(3694,($137|0),($31|0))|0);
                               $645 = __THREW__; __THREW__ = 0;
                               $646 = $645&1;
                               do {
                                if (!($646)) {
                                 __THREW__ = 0;
                                 (invoke_iii(3477,($644|0),($32|0))|0);
                                 $647 = __THREW__; __THREW__ = 0;
                                 $648 = $647&1;
                                 if ($648) {
                                  break;
                                 }
                                 $649 = HEAP8[$642>>0]|0;
                                 $650 = ($649<<24>>24)<(0);
                                 if ($650) {
                                  $651 = HEAP32[$32>>2]|0;
                                  __ZdlPv($651);
                                 }
                                 $652 = HEAP8[$635>>0]|0;
                                 $653 = ($652<<24>>24)<(0);
                                 if ($653) {
                                  $654 = HEAP32[$31>>2]|0;
                                  __ZdlPv($654);
                                 }
                                 $655 = ((($33)) + 4|0);
                                 $656 = $655;
                                 $657 = $656;
                                 HEAP32[$657>>2] = 0;
                                 $658 = (($656) + 4)|0;
                                 $659 = $658;
                                 HEAP32[$659>>2] = 0;
                                 $660 = ((($33)) + 11|0);
                                 HEAP8[$660>>0] = 3;
                                 ;HEAP8[$33>>0]=HEAP8[167279>>0]|0;HEAP8[$33+1>>0]=HEAP8[167279+1>>0]|0;HEAP8[$33+2>>0]=HEAP8[167279+2>>0]|0;
                                 $661 = ((($33)) + 3|0);
                                 HEAP8[$661>>0] = 0;
                                 ;HEAP32[$34>>2]=0|0;HEAP32[$34+4>>2]=0|0;HEAP32[$34+8>>2]=0|0;
                                 $662 = ((($34)) + 11|0);
                                 HEAP8[$662>>0] = 2;
                                 HEAP16[$34>>1] = 31335;
                                 $663 = ((($34)) + 2|0);
                                 HEAP8[$663>>0] = 0;
                                 __THREW__ = 0;
                                 $664 = (invoke_iii(3694,($137|0),($33|0))|0);
                                 $665 = __THREW__; __THREW__ = 0;
                                 $666 = $665&1;
                                 do {
                                  if (!($666)) {
                                   __THREW__ = 0;
                                   (invoke_iii(3477,($664|0),($34|0))|0);
                                   $667 = __THREW__; __THREW__ = 0;
                                   $668 = $667&1;
                                   if ($668) {
                                    break;
                                   }
                                   $669 = HEAP8[$662>>0]|0;
                                   $670 = ($669<<24>>24)<(0);
                                   if ($670) {
                                    $671 = HEAP32[$34>>2]|0;
                                    __ZdlPv($671);
                                   }
                                   $672 = HEAP8[$660>>0]|0;
                                   $673 = ($672<<24>>24)<(0);
                                   if ($673) {
                                    $674 = HEAP32[$33>>2]|0;
                                    __ZdlPv($674);
                                   }
                                   $675 = ((($35)) + 4|0);
                                   $676 = $675;
                                   $677 = $676;
                                   HEAP32[$677>>2] = 0;
                                   $678 = (($676) + 4)|0;
                                   $679 = $678;
                                   HEAP32[$679>>2] = 0;
                                   $680 = ((($35)) + 11|0);
                                   HEAP8[$680>>0] = 3;
                                   ;HEAP8[$35>>0]=HEAP8[167283>>0]|0;HEAP8[$35+1>>0]=HEAP8[167283+1>>0]|0;HEAP8[$35+2>>0]=HEAP8[167283+2>>0]|0;
                                   $681 = ((($35)) + 3|0);
                                   HEAP8[$681>>0] = 0;
                                   ;HEAP32[$36>>2]=0|0;HEAP32[$36+4>>2]=0|0;HEAP32[$36+8>>2]=0|0;
                                   $682 = ((($36)) + 11|0);
                                   HEAP8[$682>>0] = 2;
                                   HEAP16[$36>>1] = 31335;
                                   $683 = ((($36)) + 2|0);
                                   HEAP8[$683>>0] = 0;
                                   __THREW__ = 0;
                                   $684 = (invoke_iii(3694,($137|0),($35|0))|0);
                                   $685 = __THREW__; __THREW__ = 0;
                                   $686 = $685&1;
                                   do {
                                    if (!($686)) {
                                     __THREW__ = 0;
                                     (invoke_iii(3477,($684|0),($36|0))|0);
                                     $687 = __THREW__; __THREW__ = 0;
                                     $688 = $687&1;
                                     if ($688) {
                                      break;
                                     }
                                     $689 = HEAP8[$682>>0]|0;
                                     $690 = ($689<<24>>24)<(0);
                                     if ($690) {
                                      $691 = HEAP32[$36>>2]|0;
                                      __ZdlPv($691);
                                     }
                                     $692 = HEAP8[$680>>0]|0;
                                     $693 = ($692<<24>>24)<(0);
                                     if ($693) {
                                      $694 = HEAP32[$35>>2]|0;
                                      __ZdlPv($694);
                                     }
                                     $695 = ((($37)) + 4|0);
                                     $696 = $695;
                                     $697 = $696;
                                     HEAP32[$697>>2] = 0;
                                     $698 = (($696) + 4)|0;
                                     $699 = $698;
                                     HEAP32[$699>>2] = 0;
                                     $700 = ((($37)) + 11|0);
                                     HEAP8[$700>>0] = 3;
                                     ;HEAP8[$37>>0]=HEAP8[167287>>0]|0;HEAP8[$37+1>>0]=HEAP8[167287+1>>0]|0;HEAP8[$37+2>>0]=HEAP8[167287+2>>0]|0;
                                     $701 = ((($37)) + 3|0);
                                     HEAP8[$701>>0] = 0;
                                     ;HEAP32[$38>>2]=0|0;HEAP32[$38+4>>2]=0|0;HEAP32[$38+8>>2]=0|0;
                                     $702 = ((($38)) + 11|0);
                                     HEAP8[$702>>0] = 5;
                                     ;HEAP8[$38>>0]=HEAP8[167291>>0]|0;HEAP8[$38+1>>0]=HEAP8[167291+1>>0]|0;HEAP8[$38+2>>0]=HEAP8[167291+2>>0]|0;HEAP8[$38+3>>0]=HEAP8[167291+3>>0]|0;HEAP8[$38+4>>0]=HEAP8[167291+4>>0]|0;
                                     $703 = ((($38)) + 5|0);
                                     HEAP8[$703>>0] = 0;
                                     __THREW__ = 0;
                                     $704 = (invoke_iii(3694,($137|0),($37|0))|0);
                                     $705 = __THREW__; __THREW__ = 0;
                                     $706 = $705&1;
                                     do {
                                      if (!($706)) {
                                       __THREW__ = 0;
                                       (invoke_iii(3477,($704|0),($38|0))|0);
                                       $707 = __THREW__; __THREW__ = 0;
                                       $708 = $707&1;
                                       if ($708) {
                                        break;
                                       }
                                       $709 = HEAP8[$702>>0]|0;
                                       $710 = ($709<<24>>24)<(0);
                                       if ($710) {
                                        $711 = HEAP32[$38>>2]|0;
                                        __ZdlPv($711);
                                       }
                                       $712 = HEAP8[$700>>0]|0;
                                       $713 = ($712<<24>>24)<(0);
                                       if ($713) {
                                        $714 = HEAP32[$37>>2]|0;
                                        __ZdlPv($714);
                                       }
                                       ;HEAP32[$39>>2]=0|0;HEAP32[$39+4>>2]=0|0;HEAP32[$39+8>>2]=0|0;
                                       $715 = ((($39)) + 11|0);
                                       HEAP8[$715>>0] = 2;
                                       HEAP16[$39>>1] = 26736;
                                       $716 = ((($39)) + 2|0);
                                       HEAP8[$716>>0] = 0;
                                       ;HEAP32[$40>>2]=0|0;HEAP32[$40+4>>2]=0|0;HEAP32[$40+8>>2]=0|0;
                                       $717 = ((($40)) + 11|0);
                                       HEAP8[$717>>0] = 5;
                                       ;HEAP8[$40>>0]=HEAP8[167291>>0]|0;HEAP8[$40+1>>0]=HEAP8[167291+1>>0]|0;HEAP8[$40+2>>0]=HEAP8[167291+2>>0]|0;HEAP8[$40+3>>0]=HEAP8[167291+3>>0]|0;HEAP8[$40+4>>0]=HEAP8[167291+4>>0]|0;
                                       $718 = ((($40)) + 5|0);
                                       HEAP8[$718>>0] = 0;
                                       __THREW__ = 0;
                                       $719 = (invoke_iii(3694,($137|0),($39|0))|0);
                                       $720 = __THREW__; __THREW__ = 0;
                                       $721 = $720&1;
                                       do {
                                        if (!($721)) {
                                         __THREW__ = 0;
                                         (invoke_iii(3477,($719|0),($40|0))|0);
                                         $722 = __THREW__; __THREW__ = 0;
                                         $723 = $722&1;
                                         if ($723) {
                                          break;
                                         }
                                         $724 = HEAP8[$717>>0]|0;
                                         $725 = ($724<<24>>24)<(0);
                                         if ($725) {
                                          $726 = HEAP32[$40>>2]|0;
                                          __ZdlPv($726);
                                         }
                                         $727 = HEAP8[$715>>0]|0;
                                         $728 = ($727<<24>>24)<(0);
                                         if ($728) {
                                          $729 = HEAP32[$39>>2]|0;
                                          __ZdlPv($729);
                                         }
                                         $730 = ((($41)) + 4|0);
                                         $731 = $730;
                                         $732 = $731;
                                         HEAP32[$732>>2] = 0;
                                         $733 = (($731) + 4)|0;
                                         $734 = $733;
                                         HEAP32[$734>>2] = 0;
                                         $735 = ((($41)) + 11|0);
                                         HEAP8[$735>>0] = 3;
                                         ;HEAP8[$41>>0]=HEAP8[167297>>0]|0;HEAP8[$41+1>>0]=HEAP8[167297+1>>0]|0;HEAP8[$41+2>>0]=HEAP8[167297+2>>0]|0;
                                         $736 = ((($41)) + 3|0);
                                         HEAP8[$736>>0] = 0;
                                         ;HEAP32[$42>>2]=0|0;HEAP32[$42+4>>2]=0|0;HEAP32[$42+8>>2]=0|0;
                                         $737 = ((($42)) + 11|0);
                                         HEAP8[$737>>0] = 5;
                                         ;HEAP8[$42>>0]=HEAP8[167291>>0]|0;HEAP8[$42+1>>0]=HEAP8[167291+1>>0]|0;HEAP8[$42+2>>0]=HEAP8[167291+2>>0]|0;HEAP8[$42+3>>0]=HEAP8[167291+3>>0]|0;HEAP8[$42+4>>0]=HEAP8[167291+4>>0]|0;
                                         $738 = ((($42)) + 5|0);
                                         HEAP8[$738>>0] = 0;
                                         __THREW__ = 0;
                                         $739 = (invoke_iii(3694,($137|0),($41|0))|0);
                                         $740 = __THREW__; __THREW__ = 0;
                                         $741 = $740&1;
                                         do {
                                          if (!($741)) {
                                           __THREW__ = 0;
                                           (invoke_iii(3477,($739|0),($42|0))|0);
                                           $742 = __THREW__; __THREW__ = 0;
                                           $743 = $742&1;
                                           if ($743) {
                                            break;
                                           }
                                           $744 = HEAP8[$737>>0]|0;
                                           $745 = ($744<<24>>24)<(0);
                                           if ($745) {
                                            $746 = HEAP32[$42>>2]|0;
                                            __ZdlPv($746);
                                           }
                                           $747 = HEAP8[$735>>0]|0;
                                           $748 = ($747<<24>>24)<(0);
                                           if ($748) {
                                            $749 = HEAP32[$41>>2]|0;
                                            __ZdlPv($749);
                                           }
                                           $750 = ((($43)) + 4|0);
                                           $751 = $750;
                                           $752 = $751;
                                           HEAP32[$752>>2] = 0;
                                           $753 = (($751) + 4)|0;
                                           $754 = $753;
                                           HEAP32[$754>>2] = 0;
                                           $755 = ((($43)) + 11|0);
                                           HEAP8[$755>>0] = 3;
                                           ;HEAP8[$43>>0]=HEAP8[167301>>0]|0;HEAP8[$43+1>>0]=HEAP8[167301+1>>0]|0;HEAP8[$43+2>>0]=HEAP8[167301+2>>0]|0;
                                           $756 = ((($43)) + 3|0);
                                           HEAP8[$756>>0] = 0;
                                           ;HEAP32[$44>>2]=0|0;HEAP32[$44+4>>2]=0|0;HEAP32[$44+8>>2]=0|0;
                                           $757 = ((($44)) + 11|0);
                                           HEAP8[$757>>0] = 5;
                                           ;HEAP8[$44>>0]=HEAP8[167291>>0]|0;HEAP8[$44+1>>0]=HEAP8[167291+1>>0]|0;HEAP8[$44+2>>0]=HEAP8[167291+2>>0]|0;HEAP8[$44+3>>0]=HEAP8[167291+3>>0]|0;HEAP8[$44+4>>0]=HEAP8[167291+4>>0]|0;
                                           $758 = ((($44)) + 5|0);
                                           HEAP8[$758>>0] = 0;
                                           __THREW__ = 0;
                                           $759 = (invoke_iii(3694,($137|0),($43|0))|0);
                                           $760 = __THREW__; __THREW__ = 0;
                                           $761 = $760&1;
                                           do {
                                            if (!($761)) {
                                             __THREW__ = 0;
                                             (invoke_iii(3477,($759|0),($44|0))|0);
                                             $762 = __THREW__; __THREW__ = 0;
                                             $763 = $762&1;
                                             if ($763) {
                                              break;
                                             }
                                             $764 = HEAP8[$757>>0]|0;
                                             $765 = ($764<<24>>24)<(0);
                                             if ($765) {
                                              $766 = HEAP32[$44>>2]|0;
                                              __ZdlPv($766);
                                             }
                                             $767 = HEAP8[$755>>0]|0;
                                             $768 = ($767<<24>>24)<(0);
                                             if ($768) {
                                              $769 = HEAP32[$43>>2]|0;
                                              __ZdlPv($769);
                                             }
                                             $770 = ((($45)) + 4|0);
                                             $771 = $770;
                                             $772 = $771;
                                             HEAP32[$772>>2] = 0;
                                             $773 = (($771) + 4)|0;
                                             $774 = $773;
                                             HEAP32[$774>>2] = 0;
                                             $775 = ((($45)) + 11|0);
                                             HEAP8[$775>>0] = 3;
                                             ;HEAP8[$45>>0]=HEAP8[167305>>0]|0;HEAP8[$45+1>>0]=HEAP8[167305+1>>0]|0;HEAP8[$45+2>>0]=HEAP8[167305+2>>0]|0;
                                             $776 = ((($45)) + 3|0);
                                             HEAP8[$776>>0] = 0;
                                             ;HEAP32[$46>>2]=0|0;HEAP32[$46+4>>2]=0|0;HEAP32[$46+8>>2]=0|0;
                                             $777 = ((($46)) + 11|0);
                                             HEAP8[$777>>0] = 5;
                                             ;HEAP8[$46>>0]=HEAP8[167291>>0]|0;HEAP8[$46+1>>0]=HEAP8[167291+1>>0]|0;HEAP8[$46+2>>0]=HEAP8[167291+2>>0]|0;HEAP8[$46+3>>0]=HEAP8[167291+3>>0]|0;HEAP8[$46+4>>0]=HEAP8[167291+4>>0]|0;
                                             $778 = ((($46)) + 5|0);
                                             HEAP8[$778>>0] = 0;
                                             __THREW__ = 0;
                                             $779 = (invoke_iii(3694,($137|0),($45|0))|0);
                                             $780 = __THREW__; __THREW__ = 0;
                                             $781 = $780&1;
                                             do {
                                              if (!($781)) {
                                               __THREW__ = 0;
                                               (invoke_iii(3477,($779|0),($46|0))|0);
                                               $782 = __THREW__; __THREW__ = 0;
                                               $783 = $782&1;
                                               if ($783) {
                                                break;
                                               }
                                               $784 = HEAP8[$777>>0]|0;
                                               $785 = ($784<<24>>24)<(0);
                                               if ($785) {
                                                $786 = HEAP32[$46>>2]|0;
                                                __ZdlPv($786);
                                               }
                                               $787 = HEAP8[$775>>0]|0;
                                               $788 = ($787<<24>>24)<(0);
                                               if ($788) {
                                                $789 = HEAP32[$45>>2]|0;
                                                __ZdlPv($789);
                                               }
                                               ;HEAP32[$47>>2]=0|0;HEAP32[$47+4>>2]=0|0;HEAP32[$47+8>>2]=0|0;
                                               $790 = ((($47)) + 11|0);
                                               HEAP8[$790>>0] = 2;
                                               HEAP16[$47>>1] = 27751;
                                               $791 = ((($47)) + 2|0);
                                               HEAP8[$791>>0] = 0;
                                               ;HEAP32[$48>>2]=0|0;HEAP32[$48+4>>2]=0|0;HEAP32[$48+8>>2]=0|0;
                                               $792 = ((($48)) + 11|0);
                                               HEAP8[$792>>0] = 4;
                                               HEAP32[$48>>2] = 1819503719;
                                               $793 = ((($48)) + 4|0);
                                               HEAP8[$793>>0] = 0;
                                               __THREW__ = 0;
                                               $794 = (invoke_iii(3694,($137|0),($47|0))|0);
                                               $795 = __THREW__; __THREW__ = 0;
                                               $796 = $795&1;
                                               do {
                                                if (!($796)) {
                                                 __THREW__ = 0;
                                                 (invoke_iii(3477,($794|0),($48|0))|0);
                                                 $797 = __THREW__; __THREW__ = 0;
                                                 $798 = $797&1;
                                                 if ($798) {
                                                  break;
                                                 }
                                                 $799 = HEAP8[$792>>0]|0;
                                                 $800 = ($799<<24>>24)<(0);
                                                 if ($800) {
                                                  $801 = HEAP32[$48>>2]|0;
                                                  __ZdlPv($801);
                                                 }
                                                 $802 = HEAP8[$790>>0]|0;
                                                 $803 = ($802<<24>>24)<(0);
                                                 if ($803) {
                                                  $804 = HEAP32[$47>>2]|0;
                                                  __ZdlPv($804);
                                                 }
                                                 ;HEAP32[$49>>2]=0|0;HEAP32[$49+4>>2]=0|0;HEAP32[$49+8>>2]=0|0;
                                                 $805 = ((($49)) + 11|0);
                                                 HEAP8[$805>>0] = 4;
                                                 HEAP32[$49>>2] = 1953654134;
                                                 $806 = ((($49)) + 4|0);
                                                 HEAP8[$806>>0] = 0;
                                                 ;HEAP32[$50>>2]=0|0;HEAP32[$50+4>>2]=0|0;HEAP32[$50+8>>2]=0|0;
                                                 $807 = ((($50)) + 11|0);
                                                 HEAP8[$807>>0] = 4;
                                                 HEAP32[$50>>2] = 1819503719;
                                                 $808 = ((($50)) + 4|0);
                                                 HEAP8[$808>>0] = 0;
                                                 __THREW__ = 0;
                                                 $809 = (invoke_iii(3694,($137|0),($49|0))|0);
                                                 $810 = __THREW__; __THREW__ = 0;
                                                 $811 = $810&1;
                                                 do {
                                                  if (!($811)) {
                                                   __THREW__ = 0;
                                                   (invoke_iii(3477,($809|0),($50|0))|0);
                                                   $812 = __THREW__; __THREW__ = 0;
                                                   $813 = $812&1;
                                                   if ($813) {
                                                    break;
                                                   }
                                                   $814 = HEAP8[$807>>0]|0;
                                                   $815 = ($814<<24>>24)<(0);
                                                   if ($815) {
                                                    $816 = HEAP32[$50>>2]|0;
                                                    __ZdlPv($816);
                                                   }
                                                   $817 = HEAP8[$805>>0]|0;
                                                   $818 = ($817<<24>>24)<(0);
                                                   if ($818) {
                                                    $819 = HEAP32[$49>>2]|0;
                                                    __ZdlPv($819);
                                                   }
                                                   ;HEAP32[$51>>2]=0|0;HEAP32[$51+4>>2]=0|0;HEAP32[$51+8>>2]=0|0;
                                                   $820 = ((($51)) + 11|0);
                                                   HEAP8[$820>>0] = 4;
                                                   HEAP32[$51>>2] = 1734439526;
                                                   $821 = ((($51)) + 4|0);
                                                   HEAP8[$821>>0] = 0;
                                                   ;HEAP32[$52>>2]=0|0;HEAP32[$52+4>>2]=0|0;HEAP32[$52+8>>2]=0|0;
                                                   $822 = ((($52)) + 11|0);
                                                   HEAP8[$822>>0] = 4;
                                                   HEAP32[$52>>2] = 1819503719;
                                                   $823 = ((($52)) + 4|0);
                                                   HEAP8[$823>>0] = 0;
                                                   __THREW__ = 0;
                                                   $824 = (invoke_iii(3694,($137|0),($51|0))|0);
                                                   $825 = __THREW__; __THREW__ = 0;
                                                   $826 = $825&1;
                                                   do {
                                                    if (!($826)) {
                                                     __THREW__ = 0;
                                                     (invoke_iii(3477,($824|0),($52|0))|0);
                                                     $827 = __THREW__; __THREW__ = 0;
                                                     $828 = $827&1;
                                                     if ($828) {
                                                      break;
                                                     }
                                                     $829 = HEAP8[$822>>0]|0;
                                                     $830 = ($829<<24>>24)<(0);
                                                     if ($830) {
                                                      $831 = HEAP32[$52>>2]|0;
                                                      __ZdlPv($831);
                                                     }
                                                     $832 = HEAP8[$820>>0]|0;
                                                     $833 = ($832<<24>>24)<(0);
                                                     if ($833) {
                                                      $834 = HEAP32[$51>>2]|0;
                                                      __ZdlPv($834);
                                                     }
                                                     ;HEAP32[$53>>2]=0|0;HEAP32[$53+4>>2]=0|0;HEAP32[$53+8>>2]=0|0;
                                                     $835 = ((($53)) + 11|0);
                                                     HEAP8[$835>>0] = 4;
                                                     HEAP32[$53>>2] = 1836016999;
                                                     $836 = ((($53)) + 4|0);
                                                     HEAP8[$836>>0] = 0;
                                                     ;HEAP32[$54>>2]=0|0;HEAP32[$54+4>>2]=0|0;HEAP32[$54+8>>2]=0|0;
                                                     $837 = ((($54)) + 11|0);
                                                     HEAP8[$837>>0] = 4;
                                                     HEAP32[$54>>2] = 1819503719;
                                                     $838 = ((($54)) + 4|0);
                                                     HEAP8[$838>>0] = 0;
                                                     __THREW__ = 0;
                                                     $839 = (invoke_iii(3694,($137|0),($53|0))|0);
                                                     $840 = __THREW__; __THREW__ = 0;
                                                     $841 = $840&1;
                                                     do {
                                                      if (!($841)) {
                                                       __THREW__ = 0;
                                                       (invoke_iii(3477,($839|0),($54|0))|0);
                                                       $842 = __THREW__; __THREW__ = 0;
                                                       $843 = $842&1;
                                                       if ($843) {
                                                        break;
                                                       }
                                                       $844 = HEAP8[$837>>0]|0;
                                                       $845 = ($844<<24>>24)<(0);
                                                       if ($845) {
                                                        $846 = HEAP32[$54>>2]|0;
                                                        __ZdlPv($846);
                                                       }
                                                       $847 = HEAP8[$835>>0]|0;
                                                       $848 = ($847<<24>>24)<(0);
                                                       if ($848) {
                                                        $849 = HEAP32[$53>>2]|0;
                                                        __ZdlPv($849);
                                                       }
                                                       ;HEAP32[$55>>2]=0|0;HEAP32[$55+4>>2]=0|0;HEAP32[$55+8>>2]=0|0;
                                                       $850 = ((($55)) + 11|0);
                                                       HEAP8[$850>>0] = 2;
                                                       HEAP16[$55>>1] = 29546;
                                                       $851 = ((($55)) + 2|0);
                                                       HEAP8[$851>>0] = 0;
                                                       ;HEAP32[$56>>2]=0|0;HEAP32[$56+4>>2]=0|0;HEAP32[$56+8>>2]=0|0;
                                                       $852 = ((($56)) + 11|0);
                                                       HEAP8[$852>>0] = 2;
                                                       HEAP16[$56>>1] = 14422;
                                                       $853 = ((($56)) + 2|0);
                                                       HEAP8[$853>>0] = 0;
                                                       __THREW__ = 0;
                                                       $854 = (invoke_iii(3694,($137|0),($55|0))|0);
                                                       $855 = __THREW__; __THREW__ = 0;
                                                       $856 = $855&1;
                                                       do {
                                                        if (!($856)) {
                                                         __THREW__ = 0;
                                                         (invoke_iii(3477,($854|0),($56|0))|0);
                                                         $857 = __THREW__; __THREW__ = 0;
                                                         $858 = $857&1;
                                                         if ($858) {
                                                          break;
                                                         }
                                                         $859 = HEAP8[$852>>0]|0;
                                                         $860 = ($859<<24>>24)<(0);
                                                         if ($860) {
                                                          $861 = HEAP32[$56>>2]|0;
                                                          __ZdlPv($861);
                                                         }
                                                         $862 = HEAP8[$850>>0]|0;
                                                         $863 = ($862<<24>>24)<(0);
                                                         if ($863) {
                                                          $864 = HEAP32[$55>>2]|0;
                                                          __ZdlPv($864);
                                                         }
                                                         $865 = ((($57)) + 4|0);
                                                         $866 = $865;
                                                         $867 = $866;
                                                         HEAP32[$867>>2] = 0;
                                                         $868 = (($866) + 4)|0;
                                                         $869 = $868;
                                                         HEAP32[$869>>2] = 0;
                                                         $870 = ((($57)) + 11|0);
                                                         HEAP8[$870>>0] = 3;
                                                         ;HEAP8[$57>>0]=HEAP8[173440>>0]|0;HEAP8[$57+1>>0]=HEAP8[173440+1>>0]|0;HEAP8[$57+2>>0]=HEAP8[173440+2>>0]|0;
                                                         $871 = ((($57)) + 3|0);
                                                         HEAP8[$871>>0] = 0;
                                                         ;HEAP32[$58>>2]=0|0;HEAP32[$58+4>>2]=0|0;HEAP32[$58+8>>2]=0|0;
                                                         $872 = ((($58)) + 11|0);
                                                         HEAP8[$872>>0] = 4;
                                                         HEAP32[$58>>2] = 1734701162;
                                                         $873 = ((($58)) + 4|0);
                                                         HEAP8[$873>>0] = 0;
                                                         __THREW__ = 0;
                                                         $874 = (invoke_iii(3694,($137|0),($57|0))|0);
                                                         $875 = __THREW__; __THREW__ = 0;
                                                         $876 = $875&1;
                                                         do {
                                                          if (!($876)) {
                                                           __THREW__ = 0;
                                                           (invoke_iii(3477,($874|0),($58|0))|0);
                                                           $877 = __THREW__; __THREW__ = 0;
                                                           $878 = $877&1;
                                                           if ($878) {
                                                            break;
                                                           }
                                                           $879 = HEAP8[$872>>0]|0;
                                                           $880 = ($879<<24>>24)<(0);
                                                           if ($880) {
                                                            $881 = HEAP32[$58>>2]|0;
                                                            __ZdlPv($881);
                                                           }
                                                           $882 = HEAP8[$870>>0]|0;
                                                           $883 = ($882<<24>>24)<(0);
                                                           if ($883) {
                                                            $884 = HEAP32[$57>>2]|0;
                                                            __ZdlPv($884);
                                                           }
                                                           $885 = ((($59)) + 4|0);
                                                           $886 = $885;
                                                           $887 = $886;
                                                           HEAP32[$887>>2] = 0;
                                                           $888 = (($886) + 4)|0;
                                                           $889 = $888;
                                                           HEAP32[$889>>2] = 0;
                                                           $890 = ((($59)) + 11|0);
                                                           HEAP8[$890>>0] = 3;
                                                           ;HEAP8[$59>>0]=HEAP8[167309>>0]|0;HEAP8[$59+1>>0]=HEAP8[167309+1>>0]|0;HEAP8[$59+2>>0]=HEAP8[167309+2>>0]|0;
                                                           $891 = ((($59)) + 3|0);
                                                           HEAP8[$891>>0] = 0;
                                                           ;HEAP32[$60>>2]=0|0;HEAP32[$60+4>>2]=0|0;HEAP32[$60+8>>2]=0|0;
                                                           $892 = ((($60)) + 11|0);
                                                           HEAP8[$892>>0] = 4;
                                                           HEAP32[$60>>2] = 1734701162;
                                                           $893 = ((($60)) + 4|0);
                                                           HEAP8[$893>>0] = 0;
                                                           __THREW__ = 0;
                                                           $894 = (invoke_iii(3694,($137|0),($59|0))|0);
                                                           $895 = __THREW__; __THREW__ = 0;
                                                           $896 = $895&1;
                                                           do {
                                                            if (!($896)) {
                                                             __THREW__ = 0;
                                                             (invoke_iii(3477,($894|0),($60|0))|0);
                                                             $897 = __THREW__; __THREW__ = 0;
                                                             $898 = $897&1;
                                                             if ($898) {
                                                              break;
                                                             }
                                                             $899 = HEAP8[$892>>0]|0;
                                                             $900 = ($899<<24>>24)<(0);
                                                             if ($900) {
                                                              $901 = HEAP32[$60>>2]|0;
                                                              __ZdlPv($901);
                                                             }
                                                             $902 = HEAP8[$890>>0]|0;
                                                             $903 = ($902<<24>>24)<(0);
                                                             if ($903) {
                                                              $904 = HEAP32[$59>>2]|0;
                                                              __ZdlPv($904);
                                                             }
                                                             $905 = ((($61)) + 4|0);
                                                             $906 = $905;
                                                             $907 = $906;
                                                             HEAP32[$907>>2] = 0;
                                                             $908 = (($906) + 4)|0;
                                                             $909 = $908;
                                                             HEAP32[$909>>2] = 0;
                                                             $910 = ((($61)) + 11|0);
                                                             HEAP8[$910>>0] = 3;
                                                             ;HEAP8[$61>>0]=HEAP8[173540>>0]|0;HEAP8[$61+1>>0]=HEAP8[173540+1>>0]|0;HEAP8[$61+2>>0]=HEAP8[173540+2>>0]|0;
                                                             $911 = ((($61)) + 3|0);
                                                             HEAP8[$911>>0] = 0;
                                                             ;HEAP32[$62>>2]=0|0;HEAP32[$62+4>>2]=0|0;HEAP32[$62+8>>2]=0|0;
                                                             $912 = ((($62)) + 11|0);
                                                             HEAP8[$912>>0] = 4;
                                                             HEAP32[$62>>2] = 1717987700;
                                                             $913 = ((($62)) + 4|0);
                                                             HEAP8[$913>>0] = 0;
                                                             __THREW__ = 0;
                                                             $914 = (invoke_iii(3694,($137|0),($61|0))|0);
                                                             $915 = __THREW__; __THREW__ = 0;
                                                             $916 = $915&1;
                                                             do {
                                                              if (!($916)) {
                                                               __THREW__ = 0;
                                                               (invoke_iii(3477,($914|0),($62|0))|0);
                                                               $917 = __THREW__; __THREW__ = 0;
                                                               $918 = $917&1;
                                                               if ($918) {
                                                                break;
                                                               }
                                                               $919 = HEAP8[$912>>0]|0;
                                                               $920 = ($919<<24>>24)<(0);
                                                               if ($920) {
                                                                $921 = HEAP32[$62>>2]|0;
                                                                __ZdlPv($921);
                                                               }
                                                               $922 = HEAP8[$910>>0]|0;
                                                               $923 = ($922<<24>>24)<(0);
                                                               if ($923) {
                                                                $924 = HEAP32[$61>>2]|0;
                                                                __ZdlPv($924);
                                                               }
                                                               ;HEAP32[$63>>2]=0|0;HEAP32[$63+4>>2]=0|0;HEAP32[$63+8>>2]=0|0;
                                                               $925 = ((($63)) + 11|0);
                                                               HEAP8[$925>>0] = 2;
                                                               HEAP16[$63>>1] = 30572;
                                                               $926 = ((($63)) + 2|0);
                                                               HEAP8[$926>>0] = 0;
                                                               $927 = ((($64)) + 4|0);
                                                               $928 = $927;
                                                               $929 = $928;
                                                               HEAP32[$929>>2] = 0;
                                                               $930 = (($928) + 4)|0;
                                                               $931 = $930;
                                                               HEAP32[$931>>2] = 0;
                                                               $932 = ((($64)) + 11|0);
                                                               HEAP8[$932>>0] = 3;
                                                               ;HEAP8[$64>>0]=HEAP8[167313>>0]|0;HEAP8[$64+1>>0]=HEAP8[167313+1>>0]|0;HEAP8[$64+2>>0]=HEAP8[167313+2>>0]|0;
                                                               $933 = ((($64)) + 3|0);
                                                               HEAP8[$933>>0] = 0;
                                                               __THREW__ = 0;
                                                               $934 = (invoke_iii(3694,($137|0),($63|0))|0);
                                                               $935 = __THREW__; __THREW__ = 0;
                                                               $936 = $935&1;
                                                               do {
                                                                if (!($936)) {
                                                                 __THREW__ = 0;
                                                                 (invoke_iii(3477,($934|0),($64|0))|0);
                                                                 $937 = __THREW__; __THREW__ = 0;
                                                                 $938 = $937&1;
                                                                 if ($938) {
                                                                  break;
                                                                 }
                                                                 $939 = HEAP8[$932>>0]|0;
                                                                 $940 = ($939<<24>>24)<(0);
                                                                 if ($940) {
                                                                  $941 = HEAP32[$64>>2]|0;
                                                                  __ZdlPv($941);
                                                                 }
                                                                 $942 = HEAP8[$925>>0]|0;
                                                                 $943 = ($942<<24>>24)<(0);
                                                                 if ($943) {
                                                                  $944 = HEAP32[$63>>2]|0;
                                                                  __ZdlPv($944);
                                                                 }
                                                                 $945 = ((($65)) + 4|0);
                                                                 $946 = $945;
                                                                 $947 = $946;
                                                                 HEAP32[$947>>2] = 0;
                                                                 $948 = (($946) + 4)|0;
                                                                 $949 = $948;
                                                                 HEAP32[$949>>2] = 0;
                                                                 $950 = ((($65)) + 11|0);
                                                                 HEAP8[$950>>0] = 3;
                                                                 ;HEAP8[$65>>0]=HEAP8[167317>>0]|0;HEAP8[$65+1>>0]=HEAP8[167317+1>>0]|0;HEAP8[$65+2>>0]=HEAP8[167317+2>>0]|0;
                                                                 $951 = ((($65)) + 3|0);
                                                                 HEAP8[$951>>0] = 0;
                                                                 ;HEAP32[$66>>2]=0|0;HEAP32[$66+4>>2]=0|0;HEAP32[$66+8>>2]=0|0;
                                                                 $952 = ((($66)) + 11|0);
                                                                 HEAP8[$952>>0] = 8;
                                                                 $953 = $66;
                                                                 $954 = $953;
                                                                 HEAP32[$954>>2] = 1701147238;
                                                                 $955 = (($953) + 4)|0;
                                                                 $956 = $955;
                                                                 HEAP32[$956>>2] = 1701869940;
                                                                 $957 = ((($66)) + 8|0);
                                                                 HEAP8[$957>>0] = 0;
                                                                 __THREW__ = 0;
                                                                 $958 = (invoke_iii(3694,($137|0),($65|0))|0);
                                                                 $959 = __THREW__; __THREW__ = 0;
                                                                 $960 = $959&1;
                                                                 do {
                                                                  if (!($960)) {
                                                                   __THREW__ = 0;
                                                                   (invoke_iii(3477,($958|0),($66|0))|0);
                                                                   $961 = __THREW__; __THREW__ = 0;
                                                                   $962 = $961&1;
                                                                   if ($962) {
                                                                    break;
                                                                   }
                                                                   $963 = HEAP8[$952>>0]|0;
                                                                   $964 = ($963<<24>>24)<(0);
                                                                   if ($964) {
                                                                    $965 = HEAP32[$66>>2]|0;
                                                                    __ZdlPv($965);
                                                                   }
                                                                   $966 = HEAP8[$950>>0]|0;
                                                                   $967 = ($966<<24>>24)<(0);
                                                                   if ($967) {
                                                                    $968 = HEAP32[$65>>2]|0;
                                                                    __ZdlPv($968);
                                                                   }
                                                                   $969 = ((($67)) + 4|0);
                                                                   $970 = $969;
                                                                   $971 = $970;
                                                                   HEAP32[$971>>2] = 0;
                                                                   $972 = (($970) + 4)|0;
                                                                   $973 = $972;
                                                                   HEAP32[$973>>2] = 0;
                                                                   $974 = ((($67)) + 11|0);
                                                                   HEAP8[$974>>0] = 3;
                                                                   ;HEAP8[$67>>0]=HEAP8[167321>>0]|0;HEAP8[$67+1>>0]=HEAP8[167321+1>>0]|0;HEAP8[$67+2>>0]=HEAP8[167321+2>>0]|0;
                                                                   $975 = ((($67)) + 3|0);
                                                                   HEAP8[$975>>0] = 0;
                                                                   ;HEAP32[$68>>2]=0|0;HEAP32[$68+4>>2]=0|0;HEAP32[$68+8>>2]=0|0;
                                                                   $976 = ((($68)) + 11|0);
                                                                   HEAP8[$976>>0] = 8;
                                                                   $977 = $68;
                                                                   $978 = $977;
                                                                   HEAP32[$978>>2] = 1701147238;
                                                                   $979 = (($977) + 4)|0;
                                                                   $980 = $979;
                                                                   HEAP32[$980>>2] = 1701869940;
                                                                   $981 = ((($68)) + 8|0);
                                                                   HEAP8[$981>>0] = 0;
                                                                   __THREW__ = 0;
                                                                   $982 = (invoke_iii(3694,($137|0),($67|0))|0);
                                                                   $983 = __THREW__; __THREW__ = 0;
                                                                   $984 = $983&1;
                                                                   do {
                                                                    if (!($984)) {
                                                                     __THREW__ = 0;
                                                                     (invoke_iii(3477,($982|0),($68|0))|0);
                                                                     $985 = __THREW__; __THREW__ = 0;
                                                                     $986 = $985&1;
                                                                     if ($986) {
                                                                      break;
                                                                     }
                                                                     $987 = HEAP8[$976>>0]|0;
                                                                     $988 = ($987<<24>>24)<(0);
                                                                     if ($988) {
                                                                      $989 = HEAP32[$68>>2]|0;
                                                                      __ZdlPv($989);
                                                                     }
                                                                     $990 = HEAP8[$974>>0]|0;
                                                                     $991 = ($990<<24>>24)<(0);
                                                                     if ($991) {
                                                                      $992 = HEAP32[$67>>2]|0;
                                                                      __ZdlPv($992);
                                                                     }
                                                                     $993 = ((($69)) + 4|0);
                                                                     $994 = $993;
                                                                     $995 = $994;
                                                                     HEAP32[$995>>2] = 0;
                                                                     $996 = (($994) + 4)|0;
                                                                     $997 = $996;
                                                                     HEAP32[$997>>2] = 0;
                                                                     $998 = ((($69)) + 11|0);
                                                                     HEAP8[$998>>0] = 3;
                                                                     ;HEAP8[$69>>0]=HEAP8[167325>>0]|0;HEAP8[$69+1>>0]=HEAP8[167325+1>>0]|0;HEAP8[$69+2>>0]=HEAP8[167325+2>>0]|0;
                                                                     $999 = ((($69)) + 3|0);
                                                                     HEAP8[$999>>0] = 0;
                                                                     ;HEAP32[$70>>2]=0|0;HEAP32[$70+4>>2]=0|0;HEAP32[$70+8>>2]=0|0;
                                                                     $1000 = ((($70)) + 11|0);
                                                                     HEAP8[$1000>>0] = 8;
                                                                     $1001 = $70;
                                                                     $1002 = $1001;
                                                                     HEAP32[$1002>>2] = 1701147238;
                                                                     $1003 = (($1001) + 4)|0;
                                                                     $1004 = $1003;
                                                                     HEAP32[$1004>>2] = 1701869940;
                                                                     $1005 = ((($70)) + 8|0);
                                                                     HEAP8[$1005>>0] = 0;
                                                                     __THREW__ = 0;
                                                                     $1006 = (invoke_iii(3694,($137|0),($69|0))|0);
                                                                     $1007 = __THREW__; __THREW__ = 0;
                                                                     $1008 = $1007&1;
                                                                     do {
                                                                      if (!($1008)) {
                                                                       __THREW__ = 0;
                                                                       (invoke_iii(3477,($1006|0),($70|0))|0);
                                                                       $1009 = __THREW__; __THREW__ = 0;
                                                                       $1010 = $1009&1;
                                                                       if ($1010) {
                                                                        break;
                                                                       }
                                                                       $1011 = HEAP8[$1000>>0]|0;
                                                                       $1012 = ($1011<<24>>24)<(0);
                                                                       if ($1012) {
                                                                        $1013 = HEAP32[$70>>2]|0;
                                                                        __ZdlPv($1013);
                                                                       }
                                                                       $1014 = HEAP8[$998>>0]|0;
                                                                       $1015 = ($1014<<24>>24)<(0);
                                                                       if ($1015) {
                                                                        $1016 = HEAP32[$69>>2]|0;
                                                                        __ZdlPv($1016);
                                                                       }
                                                                       $1017 = ((($71)) + 4|0);
                                                                       $1018 = $1017;
                                                                       $1019 = $1018;
                                                                       HEAP32[$1019>>2] = 0;
                                                                       $1020 = (($1018) + 4)|0;
                                                                       $1021 = $1020;
                                                                       HEAP32[$1021>>2] = 0;
                                                                       $1022 = ((($71)) + 11|0);
                                                                       HEAP8[$1022>>0] = 3;
                                                                       ;HEAP8[$71>>0]=HEAP8[167329>>0]|0;HEAP8[$71+1>>0]=HEAP8[167329+1>>0]|0;HEAP8[$71+2>>0]=HEAP8[167329+2>>0]|0;
                                                                       $1023 = ((($71)) + 3|0);
                                                                       HEAP8[$1023>>0] = 0;
                                                                       ;HEAP32[$72>>2]=0|0;HEAP32[$72+4>>2]=0|0;HEAP32[$72+8>>2]=0|0;
                                                                       $1024 = ((($72)) + 11|0);
                                                                       HEAP8[$1024>>0] = 8;
                                                                       $1025 = $72;
                                                                       $1026 = $1025;
                                                                       HEAP32[$1026>>2] = 1701147238;
                                                                       $1027 = (($1025) + 4)|0;
                                                                       $1028 = $1027;
                                                                       HEAP32[$1028>>2] = 1701869940;
                                                                       $1029 = ((($72)) + 8|0);
                                                                       HEAP8[$1029>>0] = 0;
                                                                       __THREW__ = 0;
                                                                       $1030 = (invoke_iii(3694,($137|0),($71|0))|0);
                                                                       $1031 = __THREW__; __THREW__ = 0;
                                                                       $1032 = $1031&1;
                                                                       do {
                                                                        if (!($1032)) {
                                                                         __THREW__ = 0;
                                                                         (invoke_iii(3477,($1030|0),($72|0))|0);
                                                                         $1033 = __THREW__; __THREW__ = 0;
                                                                         $1034 = $1033&1;
                                                                         if ($1034) {
                                                                          break;
                                                                         }
                                                                         $1035 = HEAP8[$1024>>0]|0;
                                                                         $1036 = ($1035<<24>>24)<(0);
                                                                         if ($1036) {
                                                                          $1037 = HEAP32[$72>>2]|0;
                                                                          __ZdlPv($1037);
                                                                         }
                                                                         $1038 = HEAP8[$1022>>0]|0;
                                                                         $1039 = ($1038<<24>>24)<(0);
                                                                         if ($1039) {
                                                                          $1040 = HEAP32[$71>>2]|0;
                                                                          __ZdlPv($1040);
                                                                         }
                                                                         $1041 = ((($73)) + 4|0);
                                                                         $1042 = $1041;
                                                                         $1043 = $1042;
                                                                         HEAP32[$1043>>2] = 0;
                                                                         $1044 = (($1042) + 4)|0;
                                                                         $1045 = $1044;
                                                                         HEAP32[$1045>>2] = 0;
                                                                         $1046 = ((($73)) + 11|0);
                                                                         HEAP8[$1046>>0] = 3;
                                                                         ;HEAP8[$73>>0]=HEAP8[167333>>0]|0;HEAP8[$73+1>>0]=HEAP8[167333+1>>0]|0;HEAP8[$73+2>>0]=HEAP8[167333+2>>0]|0;
                                                                         $1047 = ((($73)) + 3|0);
                                                                         HEAP8[$1047>>0] = 0;
                                                                         ;HEAP32[$74>>2]=0|0;HEAP32[$74+4>>2]=0|0;HEAP32[$74+8>>2]=0|0;
                                                                         $1048 = ((($74)) + 11|0);
                                                                         HEAP8[$1048>>0] = 8;
                                                                         $1049 = $74;
                                                                         $1050 = $1049;
                                                                         HEAP32[$1050>>2] = 1701147238;
                                                                         $1051 = (($1049) + 4)|0;
                                                                         $1052 = $1051;
                                                                         HEAP32[$1052>>2] = 1701869940;
                                                                         $1053 = ((($74)) + 8|0);
                                                                         HEAP8[$1053>>0] = 0;
                                                                         __THREW__ = 0;
                                                                         $1054 = (invoke_iii(3694,($137|0),($73|0))|0);
                                                                         $1055 = __THREW__; __THREW__ = 0;
                                                                         $1056 = $1055&1;
                                                                         do {
                                                                          if (!($1056)) {
                                                                           __THREW__ = 0;
                                                                           (invoke_iii(3477,($1054|0),($74|0))|0);
                                                                           $1057 = __THREW__; __THREW__ = 0;
                                                                           $1058 = $1057&1;
                                                                           if ($1058) {
                                                                            break;
                                                                           }
                                                                           $1059 = HEAP8[$1048>>0]|0;
                                                                           $1060 = ($1059<<24>>24)<(0);
                                                                           if ($1060) {
                                                                            $1061 = HEAP32[$74>>2]|0;
                                                                            __ZdlPv($1061);
                                                                           }
                                                                           $1062 = HEAP8[$1046>>0]|0;
                                                                           $1063 = ($1062<<24>>24)<(0);
                                                                           if ($1063) {
                                                                            $1064 = HEAP32[$73>>2]|0;
                                                                            __ZdlPv($1064);
                                                                           }
                                                                           $1065 = ((($75)) + 4|0);
                                                                           $1066 = $1065;
                                                                           $1067 = $1066;
                                                                           HEAP32[$1067>>2] = 0;
                                                                           $1068 = (($1066) + 4)|0;
                                                                           $1069 = $1068;
                                                                           HEAP32[$1069>>2] = 0;
                                                                           $1070 = ((($75)) + 11|0);
                                                                           HEAP8[$1070>>0] = 3;
                                                                           ;HEAP8[$75>>0]=HEAP8[167337>>0]|0;HEAP8[$75+1>>0]=HEAP8[167337+1>>0]|0;HEAP8[$75+2>>0]=HEAP8[167337+2>>0]|0;
                                                                           $1071 = ((($75)) + 3|0);
                                                                           HEAP8[$1071>>0] = 0;
                                                                           ;HEAP32[$76>>2]=0|0;HEAP32[$76+4>>2]=0|0;HEAP32[$76+8>>2]=0|0;
                                                                           $1072 = ((($76)) + 11|0);
                                                                           HEAP8[$1072>>0] = 8;
                                                                           $1073 = $76;
                                                                           $1074 = $1073;
                                                                           HEAP32[$1074>>2] = 1701147238;
                                                                           $1075 = (($1073) + 4)|0;
                                                                           $1076 = $1075;
                                                                           HEAP32[$1076>>2] = 1701869940;
                                                                           $1077 = ((($76)) + 8|0);
                                                                           HEAP8[$1077>>0] = 0;
                                                                           __THREW__ = 0;
                                                                           $1078 = (invoke_iii(3694,($137|0),($75|0))|0);
                                                                           $1079 = __THREW__; __THREW__ = 0;
                                                                           $1080 = $1079&1;
                                                                           do {
                                                                            if (!($1080)) {
                                                                             __THREW__ = 0;
                                                                             (invoke_iii(3477,($1078|0),($76|0))|0);
                                                                             $1081 = __THREW__; __THREW__ = 0;
                                                                             $1082 = $1081&1;
                                                                             if ($1082) {
                                                                              break;
                                                                             }
                                                                             $1083 = HEAP8[$1072>>0]|0;
                                                                             $1084 = ($1083<<24>>24)<(0);
                                                                             if ($1084) {
                                                                              $1085 = HEAP32[$76>>2]|0;
                                                                              __ZdlPv($1085);
                                                                             }
                                                                             $1086 = HEAP8[$1070>>0]|0;
                                                                             $1087 = ($1086<<24>>24)<(0);
                                                                             if ($1087) {
                                                                              $1088 = HEAP32[$75>>2]|0;
                                                                              __ZdlPv($1088);
                                                                             }
                                                                             $1089 = ((($77)) + 4|0);
                                                                             $1090 = $1089;
                                                                             $1091 = $1090;
                                                                             HEAP32[$1091>>2] = 0;
                                                                             $1092 = (($1090) + 4)|0;
                                                                             $1093 = $1092;
                                                                             HEAP32[$1093>>2] = 0;
                                                                             $1094 = ((($77)) + 11|0);
                                                                             HEAP8[$1094>>0] = 3;
                                                                             ;HEAP8[$77>>0]=HEAP8[167341>>0]|0;HEAP8[$77+1>>0]=HEAP8[167341+1>>0]|0;HEAP8[$77+2>>0]=HEAP8[167341+2>>0]|0;
                                                                             $1095 = ((($77)) + 3|0);
                                                                             HEAP8[$1095>>0] = 0;
                                                                             ;HEAP32[$78>>2]=0|0;HEAP32[$78+4>>2]=0|0;HEAP32[$78+8>>2]=0|0;
                                                                             $1096 = ((($78)) + 11|0);
                                                                             HEAP8[$1096>>0] = 8;
                                                                             $1097 = $78;
                                                                             $1098 = $1097;
                                                                             HEAP32[$1098>>2] = 1701147238;
                                                                             $1099 = (($1097) + 4)|0;
                                                                             $1100 = $1099;
                                                                             HEAP32[$1100>>2] = 1701869940;
                                                                             $1101 = ((($78)) + 8|0);
                                                                             HEAP8[$1101>>0] = 0;
                                                                             __THREW__ = 0;
                                                                             $1102 = (invoke_iii(3694,($137|0),($77|0))|0);
                                                                             $1103 = __THREW__; __THREW__ = 0;
                                                                             $1104 = $1103&1;
                                                                             do {
                                                                              if (!($1104)) {
                                                                               __THREW__ = 0;
                                                                               (invoke_iii(3477,($1102|0),($78|0))|0);
                                                                               $1105 = __THREW__; __THREW__ = 0;
                                                                               $1106 = $1105&1;
                                                                               if ($1106) {
                                                                                break;
                                                                               }
                                                                               $1107 = HEAP8[$1096>>0]|0;
                                                                               $1108 = ($1107<<24>>24)<(0);
                                                                               if ($1108) {
                                                                                $1109 = HEAP32[$78>>2]|0;
                                                                                __ZdlPv($1109);
                                                                               }
                                                                               $1110 = HEAP8[$1094>>0]|0;
                                                                               $1111 = ($1110<<24>>24)<(0);
                                                                               if ($1111) {
                                                                                $1112 = HEAP32[$77>>2]|0;
                                                                                __ZdlPv($1112);
                                                                               }
                                                                               ;HEAP32[$79>>2]=0|0;HEAP32[$79+4>>2]=0|0;HEAP32[$79+8>>2]=0|0;
                                                                               $1113 = ((($79)) + 11|0);
                                                                               HEAP8[$1113>>0] = 6;
                                                                               ;HEAP8[$79>>0]=HEAP8[167345>>0]|0;HEAP8[$79+1>>0]=HEAP8[167345+1>>0]|0;HEAP8[$79+2>>0]=HEAP8[167345+2>>0]|0;HEAP8[$79+3>>0]=HEAP8[167345+3>>0]|0;HEAP8[$79+4>>0]=HEAP8[167345+4>>0]|0;HEAP8[$79+5>>0]=HEAP8[167345+5>>0]|0;
                                                                               $1114 = ((($79)) + 6|0);
                                                                               HEAP8[$1114>>0] = 0;
                                                                               ;HEAP32[$80>>2]=0|0;HEAP32[$80+4>>2]=0|0;HEAP32[$80+8>>2]=0|0;
                                                                               $1115 = ((($80)) + 11|0);
                                                                               HEAP8[$1115>>0] = 8;
                                                                               $1116 = $80;
                                                                               $1117 = $1116;
                                                                               HEAP32[$1117>>2] = 1701147238;
                                                                               $1118 = (($1116) + 4)|0;
                                                                               $1119 = $1118;
                                                                               HEAP32[$1119>>2] = 1701869940;
                                                                               $1120 = ((($80)) + 8|0);
                                                                               HEAP8[$1120>>0] = 0;
                                                                               __THREW__ = 0;
                                                                               $1121 = (invoke_iii(3694,($137|0),($79|0))|0);
                                                                               $1122 = __THREW__; __THREW__ = 0;
                                                                               $1123 = $1122&1;
                                                                               do {
                                                                                if (!($1123)) {
                                                                                 __THREW__ = 0;
                                                                                 (invoke_iii(3477,($1121|0),($80|0))|0);
                                                                                 $1124 = __THREW__; __THREW__ = 0;
                                                                                 $1125 = $1124&1;
                                                                                 if ($1125) {
                                                                                  break;
                                                                                 }
                                                                                 $1126 = HEAP8[$1115>>0]|0;
                                                                                 $1127 = ($1126<<24>>24)<(0);
                                                                                 if ($1127) {
                                                                                  $1128 = HEAP32[$80>>2]|0;
                                                                                  __ZdlPv($1128);
                                                                                 }
                                                                                 $1129 = HEAP8[$1113>>0]|0;
                                                                                 $1130 = ($1129<<24>>24)<(0);
                                                                                 if ($1130) {
                                                                                  $1131 = HEAP32[$79>>2]|0;
                                                                                  __ZdlPv($1131);
                                                                                 }
                                                                                 ;HEAP32[$81>>2]=0|0;HEAP32[$81+4>>2]=0|0;HEAP32[$81+8>>2]=0|0;
                                                                                 $1132 = ((($81)) + 11|0);
                                                                                 HEAP8[$1132>>0] = 6;
                                                                                 ;HEAP8[$81>>0]=HEAP8[167352>>0]|0;HEAP8[$81+1>>0]=HEAP8[167352+1>>0]|0;HEAP8[$81+2>>0]=HEAP8[167352+2>>0]|0;HEAP8[$81+3>>0]=HEAP8[167352+3>>0]|0;HEAP8[$81+4>>0]=HEAP8[167352+4>>0]|0;HEAP8[$81+5>>0]=HEAP8[167352+5>>0]|0;
                                                                                 $1133 = ((($81)) + 6|0);
                                                                                 HEAP8[$1133>>0] = 0;
                                                                                 ;HEAP32[$82>>2]=0|0;HEAP32[$82+4>>2]=0|0;HEAP32[$82+8>>2]=0|0;
                                                                                 $1134 = ((($82)) + 11|0);
                                                                                 HEAP8[$1134>>0] = 2;
                                                                                 HEAP16[$82>>1] = 26228;
                                                                                 $1135 = ((($82)) + 2|0);
                                                                                 HEAP8[$1135>>0] = 0;
                                                                                 __THREW__ = 0;
                                                                                 $1136 = (invoke_iii(3694,($137|0),($81|0))|0);
                                                                                 $1137 = __THREW__; __THREW__ = 0;
                                                                                 $1138 = $1137&1;
                                                                                 do {
                                                                                  if (!($1138)) {
                                                                                   __THREW__ = 0;
                                                                                   (invoke_iii(3477,($1136|0),($82|0))|0);
                                                                                   $1139 = __THREW__; __THREW__ = 0;
                                                                                   $1140 = $1139&1;
                                                                                   if ($1140) {
                                                                                    break;
                                                                                   }
                                                                                   $1141 = HEAP8[$1134>>0]|0;
                                                                                   $1142 = ($1141<<24>>24)<(0);
                                                                                   if ($1142) {
                                                                                    $1143 = HEAP32[$82>>2]|0;
                                                                                    __ZdlPv($1143);
                                                                                   }
                                                                                   $1144 = HEAP8[$1132>>0]|0;
                                                                                   $1145 = ($1144<<24>>24)<(0);
                                                                                   if ($1145) {
                                                                                    $1146 = HEAP32[$81>>2]|0;
                                                                                    __ZdlPv($1146);
                                                                                   }
                                                                                   $1147 = ((($83)) + 4|0);
                                                                                   $1148 = $1147;
                                                                                   $1149 = $1148;
                                                                                   HEAP32[$1149>>2] = 0;
                                                                                   $1150 = (($1148) + 4)|0;
                                                                                   $1151 = $1150;
                                                                                   HEAP32[$1151>>2] = 0;
                                                                                   $1152 = ((($83)) + 11|0);
                                                                                   HEAP8[$1152>>0] = 3;
                                                                                   ;HEAP8[$83>>0]=HEAP8[173911>>0]|0;HEAP8[$83+1>>0]=HEAP8[173911+1>>0]|0;HEAP8[$83+2>>0]=HEAP8[173911+2>>0]|0;
                                                                                   $1153 = ((($83)) + 3|0);
                                                                                   HEAP8[$1153>>0] = 0;
                                                                                   $1154 = ((($84)) + 4|0);
                                                                                   $1155 = $1154;
                                                                                   $1156 = $1155;
                                                                                   HEAP32[$1156>>2] = 0;
                                                                                   $1157 = (($1155) + 4)|0;
                                                                                   $1158 = $1157;
                                                                                   HEAP32[$1158>>2] = 0;
                                                                                   $1159 = ((($84)) + 11|0);
                                                                                   HEAP8[$1159>>0] = 3;
                                                                                   ;HEAP8[$84>>0]=HEAP8[173883>>0]|0;HEAP8[$84+1>>0]=HEAP8[173883+1>>0]|0;HEAP8[$84+2>>0]=HEAP8[173883+2>>0]|0;
                                                                                   $1160 = ((($84)) + 3|0);
                                                                                   HEAP8[$1160>>0] = 0;
                                                                                   __THREW__ = 0;
                                                                                   $1161 = (invoke_iii(3694,($137|0),($83|0))|0);
                                                                                   $1162 = __THREW__; __THREW__ = 0;
                                                                                   $1163 = $1162&1;
                                                                                   do {
                                                                                    if (!($1163)) {
                                                                                     __THREW__ = 0;
                                                                                     (invoke_iii(3477,($1161|0),($84|0))|0);
                                                                                     $1164 = __THREW__; __THREW__ = 0;
                                                                                     $1165 = $1164&1;
                                                                                     if ($1165) {
                                                                                      break;
                                                                                     }
                                                                                     $1166 = HEAP8[$1159>>0]|0;
                                                                                     $1167 = ($1166<<24>>24)<(0);
                                                                                     if ($1167) {
                                                                                      $1168 = HEAP32[$84>>2]|0;
                                                                                      __ZdlPv($1168);
                                                                                     }
                                                                                     $1169 = HEAP8[$1152>>0]|0;
                                                                                     $1170 = ($1169<<24>>24)<(0);
                                                                                     if ($1170) {
                                                                                      $1171 = HEAP32[$83>>2]|0;
                                                                                      __ZdlPv($1171);
                                                                                     }
                                                                                     $1172 = ((($85)) + 4|0);
                                                                                     $1173 = $1172;
                                                                                     $1174 = $1173;
                                                                                     HEAP32[$1174>>2] = 0;
                                                                                     $1175 = (($1173) + 4)|0;
                                                                                     $1176 = $1175;
                                                                                     HEAP32[$1176>>2] = 0;
                                                                                     $1177 = ((($85)) + 11|0);
                                                                                     HEAP8[$1177>>0] = 3;
                                                                                     ;HEAP8[$85>>0]=HEAP8[173940>>0]|0;HEAP8[$85+1>>0]=HEAP8[173940+1>>0]|0;HEAP8[$85+2>>0]=HEAP8[173940+2>>0]|0;
                                                                                     $1178 = ((($85)) + 3|0);
                                                                                     HEAP8[$1178>>0] = 0;
                                                                                     $1179 = ((($86)) + 4|0);
                                                                                     $1180 = $1179;
                                                                                     $1181 = $1180;
                                                                                     HEAP32[$1181>>2] = 0;
                                                                                     $1182 = (($1180) + 4)|0;
                                                                                     $1183 = $1182;
                                                                                     HEAP32[$1183>>2] = 0;
                                                                                     $1184 = ((($86)) + 11|0);
                                                                                     HEAP8[$1184>>0] = 3;
                                                                                     ;HEAP8[$86>>0]=HEAP8[173883>>0]|0;HEAP8[$86+1>>0]=HEAP8[173883+1>>0]|0;HEAP8[$86+2>>0]=HEAP8[173883+2>>0]|0;
                                                                                     $1185 = ((($86)) + 3|0);
                                                                                     HEAP8[$1185>>0] = 0;
                                                                                     __THREW__ = 0;
                                                                                     $1186 = (invoke_iii(3694,($137|0),($85|0))|0);
                                                                                     $1187 = __THREW__; __THREW__ = 0;
                                                                                     $1188 = $1187&1;
                                                                                     do {
                                                                                      if (!($1188)) {
                                                                                       __THREW__ = 0;
                                                                                       (invoke_iii(3477,($1186|0),($86|0))|0);
                                                                                       $1189 = __THREW__; __THREW__ = 0;
                                                                                       $1190 = $1189&1;
                                                                                       if ($1190) {
                                                                                        break;
                                                                                       }
                                                                                       $1191 = HEAP8[$1184>>0]|0;
                                                                                       $1192 = ($1191<<24>>24)<(0);
                                                                                       if ($1192) {
                                                                                        $1193 = HEAP32[$86>>2]|0;
                                                                                        __ZdlPv($1193);
                                                                                       }
                                                                                       $1194 = HEAP8[$1177>>0]|0;
                                                                                       $1195 = ($1194<<24>>24)<(0);
                                                                                       if ($1195) {
                                                                                        $1196 = HEAP32[$85>>2]|0;
                                                                                        __ZdlPv($1196);
                                                                                       }
                                                                                       $1197 = ((($87)) + 4|0);
                                                                                       $1198 = $1197;
                                                                                       $1199 = $1198;
                                                                                       HEAP32[$1199>>2] = 0;
                                                                                       $1200 = (($1198) + 4)|0;
                                                                                       $1201 = $1200;
                                                                                       HEAP32[$1201>>2] = 0;
                                                                                       $1202 = ((($87)) + 11|0);
                                                                                       HEAP8[$1202>>0] = 3;
                                                                                       ;HEAP8[$87>>0]=HEAP8[173993>>0]|0;HEAP8[$87+1>>0]=HEAP8[173993+1>>0]|0;HEAP8[$87+2>>0]=HEAP8[173993+2>>0]|0;
                                                                                       $1203 = ((($87)) + 3|0);
                                                                                       HEAP8[$1203>>0] = 0;
                                                                                       $1204 = ((($88)) + 4|0);
                                                                                       $1205 = $1204;
                                                                                       $1206 = $1205;
                                                                                       HEAP32[$1206>>2] = 0;
                                                                                       $1207 = (($1205) + 4)|0;
                                                                                       $1208 = $1207;
                                                                                       HEAP32[$1208>>2] = 0;
                                                                                       $1209 = ((($88)) + 11|0);
                                                                                       HEAP8[$1209>>0] = 3;
                                                                                       ;HEAP8[$88>>0]=HEAP8[173883>>0]|0;HEAP8[$88+1>>0]=HEAP8[173883+1>>0]|0;HEAP8[$88+2>>0]=HEAP8[173883+2>>0]|0;
                                                                                       $1210 = ((($88)) + 3|0);
                                                                                       HEAP8[$1210>>0] = 0;
                                                                                       __THREW__ = 0;
                                                                                       $1211 = (invoke_iii(3694,($137|0),($87|0))|0);
                                                                                       $1212 = __THREW__; __THREW__ = 0;
                                                                                       $1213 = $1212&1;
                                                                                       do {
                                                                                        if (!($1213)) {
                                                                                         __THREW__ = 0;
                                                                                         (invoke_iii(3477,($1211|0),($88|0))|0);
                                                                                         $1214 = __THREW__; __THREW__ = 0;
                                                                                         $1215 = $1214&1;
                                                                                         if ($1215) {
                                                                                          break;
                                                                                         }
                                                                                         $1216 = HEAP8[$1209>>0]|0;
                                                                                         $1217 = ($1216<<24>>24)<(0);
                                                                                         if ($1217) {
                                                                                          $1218 = HEAP32[$88>>2]|0;
                                                                                          __ZdlPv($1218);
                                                                                         }
                                                                                         $1219 = HEAP8[$1202>>0]|0;
                                                                                         $1220 = ($1219<<24>>24)<(0);
                                                                                         if ($1220) {
                                                                                          $1221 = HEAP32[$87>>2]|0;
                                                                                          __ZdlPv($1221);
                                                                                         }
                                                                                         ;HEAP32[$89>>2]=0|0;HEAP32[$89+4>>2]=0|0;HEAP32[$89+8>>2]=0|0;
                                                                                         $1222 = ((($89)) + 11|0);
                                                                                         HEAP8[$1222>>0] = 5;
                                                                                         ;HEAP8[$89>>0]=HEAP8[167359>>0]|0;HEAP8[$89+1>>0]=HEAP8[167359+1>>0]|0;HEAP8[$89+2>>0]=HEAP8[167359+2>>0]|0;HEAP8[$89+3>>0]=HEAP8[167359+3>>0]|0;HEAP8[$89+4>>0]=HEAP8[167359+4>>0]|0;
                                                                                         $1223 = ((($89)) + 5|0);
                                                                                         HEAP8[$1223>>0] = 0;
                                                                                         ;HEAP32[$90>>2]=0|0;HEAP32[$90+4>>2]=0|0;HEAP32[$90+8>>2]=0|0;
                                                                                         $1224 = ((($90)) + 11|0);
                                                                                         HEAP8[$1224>>0] = 9;
                                                                                         dest=$90; src=167365; stop=dest+9|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                                                                                         $1225 = ((($90)) + 9|0);
                                                                                         HEAP8[$1225>>0] = 0;
                                                                                         __THREW__ = 0;
                                                                                         $1226 = (invoke_iii(3694,($137|0),($89|0))|0);
                                                                                         $1227 = __THREW__; __THREW__ = 0;
                                                                                         $1228 = $1227&1;
                                                                                         do {
                                                                                          if (!($1228)) {
                                                                                           __THREW__ = 0;
                                                                                           (invoke_iii(3477,($1226|0),($90|0))|0);
                                                                                           $1229 = __THREW__; __THREW__ = 0;
                                                                                           $1230 = $1229&1;
                                                                                           if ($1230) {
                                                                                            break;
                                                                                           }
                                                                                           $1231 = HEAP8[$1224>>0]|0;
                                                                                           $1232 = ($1231<<24>>24)<(0);
                                                                                           if ($1232) {
                                                                                            $1233 = HEAP32[$90>>2]|0;
                                                                                            __ZdlPv($1233);
                                                                                           }
                                                                                           $1234 = HEAP8[$1222>>0]|0;
                                                                                           $1235 = ($1234<<24>>24)<(0);
                                                                                           if ($1235) {
                                                                                            $1236 = HEAP32[$89>>2]|0;
                                                                                            __ZdlPv($1236);
                                                                                           }
                                                                                           $1237 = ((($91)) + 8|0);
                                                                                           HEAP32[$1237>>2] = 0;
                                                                                           $1238 = ((($91)) + 11|0);
                                                                                           HEAP8[$1238>>0] = 7;
                                                                                           ;HEAP8[$91>>0]=HEAP8[167375>>0]|0;HEAP8[$91+1>>0]=HEAP8[167375+1>>0]|0;HEAP8[$91+2>>0]=HEAP8[167375+2>>0]|0;HEAP8[$91+3>>0]=HEAP8[167375+3>>0]|0;HEAP8[$91+4>>0]=HEAP8[167375+4>>0]|0;HEAP8[$91+5>>0]=HEAP8[167375+5>>0]|0;HEAP8[$91+6>>0]=HEAP8[167375+6>>0]|0;
                                                                                           $1239 = ((($91)) + 7|0);
                                                                                           HEAP8[$1239>>0] = 0;
                                                                                           ;HEAP32[$92>>2]=0|0;HEAP32[$92+4>>2]=0|0;HEAP32[$92+8>>2]=0|0;
                                                                                           $1240 = ((($92)) + 11|0);
                                                                                           HEAP8[$1240>>0] = 9;
                                                                                           dest=$92; src=167365; stop=dest+9|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                                                                                           $1241 = ((($92)) + 9|0);
                                                                                           HEAP8[$1241>>0] = 0;
                                                                                           __THREW__ = 0;
                                                                                           $1242 = (invoke_iii(3694,($137|0),($91|0))|0);
                                                                                           $1243 = __THREW__; __THREW__ = 0;
                                                                                           $1244 = $1243&1;
                                                                                           do {
                                                                                            if (!($1244)) {
                                                                                             __THREW__ = 0;
                                                                                             (invoke_iii(3477,($1242|0),($92|0))|0);
                                                                                             $1245 = __THREW__; __THREW__ = 0;
                                                                                             $1246 = $1245&1;
                                                                                             if ($1246) {
                                                                                              break;
                                                                                             }
                                                                                             $1247 = HEAP8[$1240>>0]|0;
                                                                                             $1248 = ($1247<<24>>24)<(0);
                                                                                             if ($1248) {
                                                                                              $1249 = HEAP32[$92>>2]|0;
                                                                                              __ZdlPv($1249);
                                                                                             }
                                                                                             $1250 = HEAP8[$1238>>0]|0;
                                                                                             $1251 = ($1250<<24>>24)<(0);
                                                                                             if ($1251) {
                                                                                              $1252 = HEAP32[$91>>2]|0;
                                                                                              __ZdlPv($1252);
                                                                                             }
                                                                                             ;HEAP32[$93>>2]=0|0;HEAP32[$93+4>>2]=0|0;HEAP32[$93+8>>2]=0|0;
                                                                                             $1253 = ((($93)) + 11|0);
                                                                                             HEAP8[$1253>>0] = 8;
                                                                                             $1254 = $93;
                                                                                             $1255 = $1254;
                                                                                             HEAP32[$1255>>2] = 1768189805;
                                                                                             $1256 = (($1254) + 4)|0;
                                                                                             $1257 = $1256;
                                                                                             HEAP32[$1257>>2] = 1684367718;
                                                                                             $1258 = ((($93)) + 8|0);
                                                                                             HEAP8[$1258>>0] = 0;
                                                                                             ;HEAP32[$94>>2]=0|0;HEAP32[$94+4>>2]=0|0;HEAP32[$94+8>>2]=0|0;
                                                                                             $1259 = ((($94)) + 11|0);
                                                                                             HEAP8[$1259>>0] = 9;
                                                                                             dest=$94; src=167365; stop=dest+9|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                                                                                             $1260 = ((($94)) + 9|0);
                                                                                             HEAP8[$1260>>0] = 0;
                                                                                             __THREW__ = 0;
                                                                                             $1261 = (invoke_iii(3694,($137|0),($93|0))|0);
                                                                                             $1262 = __THREW__; __THREW__ = 0;
                                                                                             $1263 = $1262&1;
                                                                                             do {
                                                                                              if (!($1263)) {
                                                                                               __THREW__ = 0;
                                                                                               (invoke_iii(3477,($1261|0),($94|0))|0);
                                                                                               $1264 = __THREW__; __THREW__ = 0;
                                                                                               $1265 = $1264&1;
                                                                                               if ($1265) {
                                                                                                break;
                                                                                               }
                                                                                               $1266 = HEAP8[$1259>>0]|0;
                                                                                               $1267 = ($1266<<24>>24)<(0);
                                                                                               if ($1267) {
                                                                                                $1268 = HEAP32[$94>>2]|0;
                                                                                                __ZdlPv($1268);
                                                                                               }
                                                                                               $1269 = HEAP8[$1253>>0]|0;
                                                                                               $1270 = ($1269<<24>>24)<(0);
                                                                                               if ($1270) {
                                                                                                $1271 = HEAP32[$93>>2]|0;
                                                                                                __ZdlPv($1271);
                                                                                               }
                                                                                               $1272 = ((($95)) + 4|0);
                                                                                               $1273 = $1272;
                                                                                               $1274 = $1273;
                                                                                               HEAP32[$1274>>2] = 0;
                                                                                               $1275 = (($1273) + 4)|0;
                                                                                               $1276 = $1275;
                                                                                               HEAP32[$1276>>2] = 0;
                                                                                               $1277 = ((($95)) + 11|0);
                                                                                               HEAP8[$1277>>0] = 3;
                                                                                               ;HEAP8[$95>>0]=HEAP8[167383>>0]|0;HEAP8[$95+1>>0]=HEAP8[167383+1>>0]|0;HEAP8[$95+2>>0]=HEAP8[167383+2>>0]|0;
                                                                                               $1278 = ((($95)) + 3|0);
                                                                                               HEAP8[$1278>>0] = 0;
                                                                                               ;HEAP32[$96>>2]=0|0;HEAP32[$96+4>>2]=0|0;HEAP32[$96+8>>2]=0|0;
                                                                                               __THREW__ = 0;
                                                                                               $1279 = (invoke_ii(3276,16)|0);
                                                                                               $1280 = __THREW__; __THREW__ = 0;
                                                                                               $1281 = $1280&1;
                                                                                               do {
                                                                                                if ($1281) {
                                                                                                 $1735 = ___cxa_find_matching_catch_2()|0;
                                                                                                 $1736 = tempRet0;
                                                                                                 $$48 = $1735;$$4883 = $1736;
                                                                                                } else {
                                                                                                 HEAP32[$96>>2] = $1279;
                                                                                                 $1282 = ((($96)) + 8|0);
                                                                                                 HEAP32[$1282>>2] = -2147483632;
                                                                                                 $1283 = ((($96)) + 4|0);
                                                                                                 HEAP32[$1283>>2] = 11;
                                                                                                 dest=$1279; src=167387; stop=dest+11|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                                                                                                 $1284 = ((($1279)) + 11|0);
                                                                                                 HEAP8[$1284>>0] = 0;
                                                                                                 __THREW__ = 0;
                                                                                                 $1285 = (invoke_iii(3694,($137|0),($95|0))|0);
                                                                                                 $1286 = __THREW__; __THREW__ = 0;
                                                                                                 $1287 = $1286&1;
                                                                                                 do {
                                                                                                  if (!($1287)) {
                                                                                                   __THREW__ = 0;
                                                                                                   (invoke_iii(3477,($1285|0),($96|0))|0);
                                                                                                   $1288 = __THREW__; __THREW__ = 0;
                                                                                                   $1289 = $1288&1;
                                                                                                   if ($1289) {
                                                                                                    break;
                                                                                                   }
                                                                                                   $1290 = ((($96)) + 11|0);
                                                                                                   $1291 = HEAP8[$1290>>0]|0;
                                                                                                   $1292 = ($1291<<24>>24)<(0);
                                                                                                   if ($1292) {
                                                                                                    $1293 = HEAP32[$96>>2]|0;
                                                                                                    __ZdlPv($1293);
                                                                                                   }
                                                                                                   $1294 = HEAP8[$1277>>0]|0;
                                                                                                   $1295 = ($1294<<24>>24)<(0);
                                                                                                   if ($1295) {
                                                                                                    $1296 = HEAP32[$95>>2]|0;
                                                                                                    __ZdlPv($1296);
                                                                                                   }
                                                                                                   ;HEAP32[$97>>2]=0|0;HEAP32[$97+4>>2]=0|0;HEAP32[$97+8>>2]=0|0;
                                                                                                   $1297 = ((($97)) + 11|0);
                                                                                                   HEAP8[$1297>>0] = 4;
                                                                                                   HEAP32[$97>>2] = 1885697139;
                                                                                                   $1298 = ((($97)) + 4|0);
                                                                                                   HEAP8[$1298>>0] = 0;
                                                                                                   ;HEAP32[$98>>2]=0|0;HEAP32[$98+4>>2]=0|0;HEAP32[$98+8>>2]=0|0;
                                                                                                   __THREW__ = 0;
                                                                                                   $1299 = (invoke_ii(3276,16)|0);
                                                                                                   $1300 = __THREW__; __THREW__ = 0;
                                                                                                   $1301 = $1300&1;
                                                                                                   do {
                                                                                                    if ($1301) {
                                                                                                     $1746 = ___cxa_find_matching_catch_2()|0;
                                                                                                     $1747 = tempRet0;
                                                                                                     $$49 = $1746;$$4984 = $1747;
                                                                                                    } else {
                                                                                                     HEAP32[$98>>2] = $1299;
                                                                                                     $1302 = ((($98)) + 8|0);
                                                                                                     HEAP32[$1302>>2] = -2147483632;
                                                                                                     $1303 = ((($98)) + 4|0);
                                                                                                     HEAP32[$1303>>2] = 11;
                                                                                                     dest=$1299; src=167387; stop=dest+11|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                                                                                                     $1304 = ((($1299)) + 11|0);
                                                                                                     HEAP8[$1304>>0] = 0;
                                                                                                     __THREW__ = 0;
                                                                                                     $1305 = (invoke_iii(3694,($137|0),($97|0))|0);
                                                                                                     $1306 = __THREW__; __THREW__ = 0;
                                                                                                     $1307 = $1306&1;
                                                                                                     do {
                                                                                                      if (!($1307)) {
                                                                                                       __THREW__ = 0;
                                                                                                       (invoke_iii(3477,($1305|0),($98|0))|0);
                                                                                                       $1308 = __THREW__; __THREW__ = 0;
                                                                                                       $1309 = $1308&1;
                                                                                                       if ($1309) {
                                                                                                        break;
                                                                                                       }
                                                                                                       $1310 = ((($98)) + 11|0);
                                                                                                       $1311 = HEAP8[$1310>>0]|0;
                                                                                                       $1312 = ($1311<<24>>24)<(0);
                                                                                                       if ($1312) {
                                                                                                        $1313 = HEAP32[$98>>2]|0;
                                                                                                        __ZdlPv($1313);
                                                                                                       }
                                                                                                       $1314 = HEAP8[$1297>>0]|0;
                                                                                                       $1315 = ($1314<<24>>24)<(0);
                                                                                                       if ($1315) {
                                                                                                        $1316 = HEAP32[$97>>2]|0;
                                                                                                        __ZdlPv($1316);
                                                                                                       }
                                                                                                       $1317 = ((($99)) + 4|0);
                                                                                                       $1318 = $1317;
                                                                                                       $1319 = $1318;
                                                                                                       HEAP32[$1319>>2] = 0;
                                                                                                       $1320 = (($1318) + 4)|0;
                                                                                                       $1321 = $1320;
                                                                                                       HEAP32[$1321>>2] = 0;
                                                                                                       $1322 = ((($99)) + 11|0);
                                                                                                       HEAP8[$1322>>0] = 3;
                                                                                                       ;HEAP8[$99>>0]=HEAP8[174178>>0]|0;HEAP8[$99+1>>0]=HEAP8[174178+1>>0]|0;HEAP8[$99+2>>0]=HEAP8[174178+2>>0]|0;
                                                                                                       $1323 = ((($99)) + 3|0);
                                                                                                       HEAP8[$1323>>0] = 0;
                                                                                                       ;HEAP32[$100>>2]=0|0;HEAP32[$100+4>>2]=0|0;HEAP32[$100+8>>2]=0|0;
                                                                                                       __THREW__ = 0;
                                                                                                       $1324 = (invoke_ii(3276,16)|0);
                                                                                                       $1325 = __THREW__; __THREW__ = 0;
                                                                                                       $1326 = $1325&1;
                                                                                                       do {
                                                                                                        if ($1326) {
                                                                                                         $1757 = ___cxa_find_matching_catch_2()|0;
                                                                                                         $1758 = tempRet0;
                                                                                                         $$50 = $1757;$$5085 = $1758;
                                                                                                        } else {
                                                                                                         HEAP32[$100>>2] = $1324;
                                                                                                         $1327 = ((($100)) + 8|0);
                                                                                                         HEAP32[$1327>>2] = -2147483632;
                                                                                                         $1328 = ((($100)) + 4|0);
                                                                                                         HEAP32[$1328>>2] = 11;
                                                                                                         dest=$1324; src=167387; stop=dest+11|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                                                                                                         $1329 = ((($1324)) + 11|0);
                                                                                                         HEAP8[$1329>>0] = 0;
                                                                                                         __THREW__ = 0;
                                                                                                         $1330 = (invoke_iii(3694,($137|0),($99|0))|0);
                                                                                                         $1331 = __THREW__; __THREW__ = 0;
                                                                                                         $1332 = $1331&1;
                                                                                                         do {
                                                                                                          if (!($1332)) {
                                                                                                           __THREW__ = 0;
                                                                                                           (invoke_iii(3477,($1330|0),($100|0))|0);
                                                                                                           $1333 = __THREW__; __THREW__ = 0;
                                                                                                           $1334 = $1333&1;
                                                                                                           if ($1334) {
                                                                                                            break;
                                                                                                           }
                                                                                                           $1335 = ((($100)) + 11|0);
                                                                                                           $1336 = HEAP8[$1335>>0]|0;
                                                                                                           $1337 = ($1336<<24>>24)<(0);
                                                                                                           if ($1337) {
                                                                                                            $1338 = HEAP32[$100>>2]|0;
                                                                                                            __ZdlPv($1338);
                                                                                                           }
                                                                                                           $1339 = HEAP8[$1322>>0]|0;
                                                                                                           $1340 = ($1339<<24>>24)<(0);
                                                                                                           if ($1340) {
                                                                                                            $1341 = HEAP32[$99>>2]|0;
                                                                                                            __ZdlPv($1341);
                                                                                                           }
                                                                                                           ;HEAP32[$101>>2]=0|0;HEAP32[$101+4>>2]=0|0;HEAP32[$101+8>>2]=0|0;
                                                                                                           $1342 = ((($101)) + 11|0);
                                                                                                           HEAP8[$1342>>0] = 4;
                                                                                                           HEAP32[$101>>2] = 1936025449;
                                                                                                           $1343 = ((($101)) + 4|0);
                                                                                                           HEAP8[$1343>>0] = 0;
                                                                                                           ;HEAP32[$102>>2]=0|0;HEAP32[$102+4>>2]=0|0;HEAP32[$102+8>>2]=0|0;
                                                                                                           __THREW__ = 0;
                                                                                                           $1344 = (invoke_ii(3276,16)|0);
                                                                                                           $1345 = __THREW__; __THREW__ = 0;
                                                                                                           $1346 = $1345&1;
                                                                                                           do {
                                                                                                            if ($1346) {
                                                                                                             $1768 = ___cxa_find_matching_catch_2()|0;
                                                                                                             $1769 = tempRet0;
                                                                                                             $$51 = $1768;$$5186 = $1769;
                                                                                                            } else {
                                                                                                             HEAP32[$102>>2] = $1344;
                                                                                                             $1347 = ((($102)) + 8|0);
                                                                                                             HEAP32[$1347>>2] = -2147483632;
                                                                                                             $1348 = ((($102)) + 4|0);
                                                                                                             HEAP32[$1348>>2] = 11;
                                                                                                             dest=$1344; src=167387; stop=dest+11|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                                                                                                             $1349 = ((($1344)) + 11|0);
                                                                                                             HEAP8[$1349>>0] = 0;
                                                                                                             __THREW__ = 0;
                                                                                                             $1350 = (invoke_iii(3694,($137|0),($101|0))|0);
                                                                                                             $1351 = __THREW__; __THREW__ = 0;
                                                                                                             $1352 = $1351&1;
                                                                                                             do {
                                                                                                              if (!($1352)) {
                                                                                                               __THREW__ = 0;
                                                                                                               (invoke_iii(3477,($1350|0),($102|0))|0);
                                                                                                               $1353 = __THREW__; __THREW__ = 0;
                                                                                                               $1354 = $1353&1;
                                                                                                               if ($1354) {
                                                                                                                break;
                                                                                                               }
                                                                                                               $1355 = ((($102)) + 11|0);
                                                                                                               $1356 = HEAP8[$1355>>0]|0;
                                                                                                               $1357 = ($1356<<24>>24)<(0);
                                                                                                               if ($1357) {
                                                                                                                $1358 = HEAP32[$102>>2]|0;
                                                                                                                __ZdlPv($1358);
                                                                                                               }
                                                                                                               $1359 = HEAP8[$1342>>0]|0;
                                                                                                               $1360 = ($1359<<24>>24)<(0);
                                                                                                               if ($1360) {
                                                                                                                $1361 = HEAP32[$101>>2]|0;
                                                                                                                __ZdlPv($1361);
                                                                                                               }
                                                                                                               $1362 = HEAP32[18850]|0;
                                                                                                               ;HEAP32[$103>>2]=0|0;HEAP32[$103+4>>2]=0|0;HEAP32[$103+8>>2]=0|0;
                                                                                                               $1363 = (_strlen($1362)|0);
                                                                                                               $1364 = ($1363>>>0)>(4294967279);
                                                                                                               L582: do {
                                                                                                                if ($1364) {
                                                                                                                 label = 398;
                                                                                                                } else {
                                                                                                                 $1365 = ((($103)) + 11|0);
                                                                                                                 $1366 = ((($103)) + 4|0);
                                                                                                                 $1367 = ((($105)) + 11|0);
                                                                                                                 $1368 = ((($104)) + 11|0);
                                                                                                                 $1369 = ((($105)) + 8|0);
                                                                                                                 $1370 = ((($105)) + 4|0);
                                                                                                                 $1371 = ((($103)) + 8|0);
                                                                                                                 $$0311184 = 0;$1373 = $1363;$1383 = $1362;
                                                                                                                 while(1) {
                                                                                                                  $1374 = ($1373>>>0)<(11);
                                                                                                                  if ($1374) {
                                                                                                                   $1381 = $1373&255;
                                                                                                                   HEAP8[$1365>>0] = $1381;
                                                                                                                   $1382 = ($1373|0)==(0);
                                                                                                                   if ($1382) {
                                                                                                                    $$017$i$i1000 = $103;
                                                                                                                   } else {
                                                                                                                    $$016$i$i999 = $103;
                                                                                                                    label = 403;
                                                                                                                   }
                                                                                                                  } else {
                                                                                                                   $1375 = (($1373) + 16)|0;
                                                                                                                   $1376 = $1375 & -16;
                                                                                                                   __THREW__ = 0;
                                                                                                                   $1377 = (invoke_ii(3276,($1376|0))|0);
                                                                                                                   $1378 = __THREW__; __THREW__ = 0;
                                                                                                                   $1379 = $1378&1;
                                                                                                                   if ($1379) {
                                                                                                                    break L582;
                                                                                                                   }
                                                                                                                   HEAP32[$103>>2] = $1377;
                                                                                                                   $1380 = $1376 | -2147483648;
                                                                                                                   HEAP32[$1371>>2] = $1380;
                                                                                                                   HEAP32[$1366>>2] = $1373;
                                                                                                                   $$016$i$i999 = $1377;
                                                                                                                   label = 403;
                                                                                                                  }
                                                                                                                  if ((label|0) == 403) {
                                                                                                                   label = 0;
                                                                                                                   _memcpy(($$016$i$i999|0),($1383|0),($1373|0))|0;
                                                                                                                   $$017$i$i1000 = $$016$i$i999;
                                                                                                                  }
                                                                                                                  $1384 = (($$017$i$i1000) + ($1373)|0);
                                                                                                                  HEAP8[$1384>>0] = 0;
                                                                                                                  $1385 = HEAP8[$1365>>0]|0;
                                                                                                                  $1386 = ($1385<<24>>24)<(0);
                                                                                                                  $1387 = HEAP32[$1366>>2]|0;
                                                                                                                  $1388 = $1385&255;
                                                                                                                  $1389 = $1386 ? $1387 : $1388;
                                                                                                                  $1390 = ($1389|0)==(0);
                                                                                                                  if ($1390) {
                                                                                                                   label = 615;
                                                                                                                   break;
                                                                                                                  }
                                                                                                                  __THREW__ = 0;
                                                                                                                  invoke_vii(3457,($104|0),($103|0));
                                                                                                                  $1781 = __THREW__; __THREW__ = 0;
                                                                                                                  $1782 = $1781&1;
                                                                                                                  if ($1782) {
                                                                                                                   label = 618;
                                                                                                                   break;
                                                                                                                  }
                                                                                                                  $1783 = $$0311184 | 1;
                                                                                                                  $1784 = (75400 + ($1783<<2)|0);
                                                                                                                  $1785 = HEAP32[$1784>>2]|0;
                                                                                                                  ;HEAP32[$105>>2]=0|0;HEAP32[$105+4>>2]=0|0;HEAP32[$105+8>>2]=0|0;
                                                                                                                  $1786 = (_strlen($1785)|0);
                                                                                                                  $1787 = ($1786>>>0)>(4294967279);
                                                                                                                  if ($1787) {
                                                                                                                   label = 600;
                                                                                                                   break;
                                                                                                                  }
                                                                                                                  $1789 = ($1786>>>0)<(11);
                                                                                                                  if ($1789) {
                                                                                                                   $1796 = $1786&255;
                                                                                                                   HEAP8[$1367>>0] = $1796;
                                                                                                                   $1797 = ($1786|0)==(0);
                                                                                                                   if ($1797) {
                                                                                                                    $$017$i$i1100 = $105;
                                                                                                                   } else {
                                                                                                                    $$016$i$i1099 = $105;
                                                                                                                    label = 605;
                                                                                                                   }
                                                                                                                  } else {
                                                                                                                   $1790 = (($1786) + 16)|0;
                                                                                                                   $1791 = $1790 & -16;
                                                                                                                   __THREW__ = 0;
                                                                                                                   $1792 = (invoke_ii(3276,($1791|0))|0);
                                                                                                                   $1793 = __THREW__; __THREW__ = 0;
                                                                                                                   $1794 = $1793&1;
                                                                                                                   if ($1794) {
                                                                                                                    label = 619;
                                                                                                                    break;
                                                                                                                   }
                                                                                                                   HEAP32[$105>>2] = $1792;
                                                                                                                   $1795 = $1791 | -2147483648;
                                                                                                                   HEAP32[$1369>>2] = $1795;
                                                                                                                   HEAP32[$1370>>2] = $1786;
                                                                                                                   $$016$i$i1099 = $1792;
                                                                                                                   label = 605;
                                                                                                                  }
                                                                                                                  if ((label|0) == 605) {
                                                                                                                   label = 0;
                                                                                                                   _memcpy(($$016$i$i1099|0),($1785|0),($1786|0))|0;
                                                                                                                   $$017$i$i1100 = $$016$i$i1099;
                                                                                                                  }
                                                                                                                  $1798 = (($$017$i$i1100) + ($1786)|0);
                                                                                                                  HEAP8[$1798>>0] = 0;
                                                                                                                  __THREW__ = 0;
                                                                                                                  $1799 = (invoke_iii(3694,($141|0),($104|0))|0);
                                                                                                                  $1800 = __THREW__; __THREW__ = 0;
                                                                                                                  $1801 = $1800&1;
                                                                                                                  if ($1801) {
                                                                                                                   label = 620;
                                                                                                                   break;
                                                                                                                  }
                                                                                                                  __THREW__ = 0;
                                                                                                                  (invoke_iii(3477,($1799|0),($105|0))|0);
                                                                                                                  $1802 = __THREW__; __THREW__ = 0;
                                                                                                                  $1803 = $1802&1;
                                                                                                                  if ($1803) {
                                                                                                                   label = 620;
                                                                                                                   break;
                                                                                                                  }
                                                                                                                  $1804 = HEAP8[$1367>>0]|0;
                                                                                                                  $1805 = ($1804<<24>>24)<(0);
                                                                                                                  if ($1805) {
                                                                                                                   $1806 = HEAP32[$105>>2]|0;
                                                                                                                   __ZdlPv($1806);
                                                                                                                  }
                                                                                                                  $1807 = HEAP8[$1368>>0]|0;
                                                                                                                  $1808 = ($1807<<24>>24)<(0);
                                                                                                                  if ($1808) {
                                                                                                                   $1809 = HEAP32[$104>>2]|0;
                                                                                                                   __ZdlPv($1809);
                                                                                                                  }
                                                                                                                  $1810 = HEAP8[$1365>>0]|0;
                                                                                                                  $1811 = ($1810<<24>>24)<(0);
                                                                                                                  if ($1811) {
                                                                                                                   $1812 = HEAP32[$103>>2]|0;
                                                                                                                   __ZdlPv($1812);
                                                                                                                  }
                                                                                                                  $1813 = (($$0311184) + 2)|0;
                                                                                                                  $1814 = (75400 + ($1813<<2)|0);
                                                                                                                  $1815 = HEAP32[$1814>>2]|0;
                                                                                                                  ;HEAP32[$103>>2]=0|0;HEAP32[$103+4>>2]=0|0;HEAP32[$103+8>>2]=0|0;
                                                                                                                  $1816 = (_strlen($1815)|0);
                                                                                                                  $1817 = ($1816>>>0)>(4294967279);
                                                                                                                  if ($1817) {
                                                                                                                   label = 398;
                                                                                                                   break L582;
                                                                                                                  } else {
                                                                                                                   $$0311184 = $1813;$1373 = $1816;$1383 = $1815;
                                                                                                                  }
                                                                                                                 }
                                                                                                                 do {
                                                                                                                  if ((label|0) == 600) {
                                                                                                                   __THREW__ = 0;
                                                                                                                   invoke_vi(3367,($105|0));
                                                                                                                   $1788 = __THREW__; __THREW__ = 0;
                                                                                                                   label = 619;
                                                                                                                  }
                                                                                                                  else if ((label|0) == 615) {
                                                                                                                   if ($1386) {
                                                                                                                    $1818 = HEAP32[$103>>2]|0;
                                                                                                                    __ZdlPv($1818);
                                                                                                                   }
                                                                                                                   ;HEAP32[$106>>2]=0|0;HEAP32[$106+4>>2]=0|0;HEAP32[$106+8>>2]=0|0;
                                                                                                                   $1819 = ((($106)) + 11|0);
                                                                                                                   HEAP8[$1819>>0] = 4;
                                                                                                                   HEAP32[$106>>2] = 1886680168;
                                                                                                                   $1820 = ((($106)) + 4|0);
                                                                                                                   HEAP8[$1820>>0] = 0;
                                                                                                                   __THREW__ = 0;
                                                                                                                   invoke_vii(4185,($0|0),($106|0));
                                                                                                                   $1821 = __THREW__; __THREW__ = 0;
                                                                                                                   $1822 = $1821&1;
                                                                                                                   if ($1822) {
                                                                                                                    $1921 = ___cxa_find_matching_catch_2()|0;
                                                                                                                    $1922 = tempRet0;
                                                                                                                    $1923 = HEAP8[$1819>>0]|0;
                                                                                                                    $1924 = ($1923<<24>>24)<(0);
                                                                                                                    if ($1924) {
                                                                                                                     $1925 = HEAP32[$106>>2]|0;
                                                                                                                     __ZdlPv($1925);
                                                                                                                    }
                                                                                                                    $$63 = $1921;$$6398 = $1922;
                                                                                                                    break L7;
                                                                                                                   }
                                                                                                                   $1838 = HEAP8[$1819>>0]|0;
                                                                                                                   $1839 = ($1838<<24>>24)<(0);
                                                                                                                   if ($1839) {
                                                                                                                    $1840 = HEAP32[$106>>2]|0;
                                                                                                                    __ZdlPv($1840);
                                                                                                                   }
                                                                                                                   ;HEAP32[$107>>2]=0|0;HEAP32[$107+4>>2]=0|0;HEAP32[$107+8>>2]=0|0;
                                                                                                                   $1841 = ((($107)) + 11|0);
                                                                                                                   HEAP8[$1841>>0] = 5;
                                                                                                                   ;HEAP8[$107>>0]=HEAP8[167399>>0]|0;HEAP8[$107+1>>0]=HEAP8[167399+1>>0]|0;HEAP8[$107+2>>0]=HEAP8[167399+2>>0]|0;HEAP8[$107+3>>0]=HEAP8[167399+3>>0]|0;HEAP8[$107+4>>0]=HEAP8[167399+4>>0]|0;
                                                                                                                   $1842 = ((($107)) + 5|0);
                                                                                                                   HEAP8[$1842>>0] = 0;
                                                                                                                   __THREW__ = 0;
                                                                                                                   invoke_vii(4185,($0|0),($107|0));
                                                                                                                   $1843 = __THREW__; __THREW__ = 0;
                                                                                                                   $1844 = $1843&1;
                                                                                                                   if ($1844) {
                                                                                                                    $1926 = ___cxa_find_matching_catch_2()|0;
                                                                                                                    $1927 = tempRet0;
                                                                                                                    $1928 = HEAP8[$1841>>0]|0;
                                                                                                                    $1929 = ($1928<<24>>24)<(0);
                                                                                                                    if ($1929) {
                                                                                                                     $1930 = HEAP32[$107>>2]|0;
                                                                                                                     __ZdlPv($1930);
                                                                                                                    }
                                                                                                                    $$63 = $1926;$$6398 = $1927;
                                                                                                                    break L7;
                                                                                                                   }
                                                                                                                   $1845 = HEAP8[$1841>>0]|0;
                                                                                                                   $1846 = ($1845<<24>>24)<(0);
                                                                                                                   if ($1846) {
                                                                                                                    $1847 = HEAP32[$107>>2]|0;
                                                                                                                    __ZdlPv($1847);
                                                                                                                   }
                                                                                                                   $1848 = ((($108)) + 4|0);
                                                                                                                   $1849 = $1848;
                                                                                                                   $1850 = $1849;
                                                                                                                   HEAP32[$1850>>2] = 0;
                                                                                                                   $1851 = (($1849) + 4)|0;
                                                                                                                   $1852 = $1851;
                                                                                                                   HEAP32[$1852>>2] = 0;
                                                                                                                   $1853 = ((($108)) + 11|0);
                                                                                                                   HEAP8[$1853>>0] = 3;
                                                                                                                   ;HEAP8[$108>>0]=HEAP8[167405>>0]|0;HEAP8[$108+1>>0]=HEAP8[167405+1>>0]|0;HEAP8[$108+2>>0]=HEAP8[167405+2>>0]|0;
                                                                                                                   $1854 = ((($108)) + 3|0);
                                                                                                                   HEAP8[$1854>>0] = 0;
                                                                                                                   __THREW__ = 0;
                                                                                                                   invoke_vii(4185,($0|0),($108|0));
                                                                                                                   $1855 = __THREW__; __THREW__ = 0;
                                                                                                                   $1856 = $1855&1;
                                                                                                                   if ($1856) {
                                                                                                                    $1931 = ___cxa_find_matching_catch_2()|0;
                                                                                                                    $1932 = tempRet0;
                                                                                                                    $1933 = HEAP8[$1853>>0]|0;
                                                                                                                    $1934 = ($1933<<24>>24)<(0);
                                                                                                                    if ($1934) {
                                                                                                                     $1935 = HEAP32[$108>>2]|0;
                                                                                                                     __ZdlPv($1935);
                                                                                                                    }
                                                                                                                    $$63 = $1931;$$6398 = $1932;
                                                                                                                    break L7;
                                                                                                                   }
                                                                                                                   $1857 = HEAP8[$1853>>0]|0;
                                                                                                                   $1858 = ($1857<<24>>24)<(0);
                                                                                                                   if ($1858) {
                                                                                                                    $1859 = HEAP32[$108>>2]|0;
                                                                                                                    __ZdlPv($1859);
                                                                                                                   }
                                                                                                                   ;HEAP32[$109>>2]=0|0;HEAP32[$109+4>>2]=0|0;HEAP32[$109+8>>2]=0|0;
                                                                                                                   $1860 = ((($109)) + 11|0);
                                                                                                                   HEAP8[$1860>>0] = 4;
                                                                                                                   HEAP32[$109>>2] = 1936749670;
                                                                                                                   $1861 = ((($109)) + 4|0);
                                                                                                                   HEAP8[$1861>>0] = 0;
                                                                                                                   __THREW__ = 0;
                                                                                                                   invoke_vii(4185,($0|0),($109|0));
                                                                                                                   $1862 = __THREW__; __THREW__ = 0;
                                                                                                                   $1863 = $1862&1;
                                                                                                                   if ($1863) {
                                                                                                                    $1936 = ___cxa_find_matching_catch_2()|0;
                                                                                                                    $1937 = tempRet0;
                                                                                                                    $1938 = HEAP8[$1860>>0]|0;
                                                                                                                    $1939 = ($1938<<24>>24)<(0);
                                                                                                                    if ($1939) {
                                                                                                                     $1940 = HEAP32[$109>>2]|0;
                                                                                                                     __ZdlPv($1940);
                                                                                                                    }
                                                                                                                    $$63 = $1936;$$6398 = $1937;
                                                                                                                    break L7;
                                                                                                                   }
                                                                                                                   $1864 = HEAP8[$1860>>0]|0;
                                                                                                                   $1865 = ($1864<<24>>24)<(0);
                                                                                                                   if ($1865) {
                                                                                                                    $1866 = HEAP32[$109>>2]|0;
                                                                                                                    __ZdlPv($1866);
                                                                                                                   }
                                                                                                                   __THREW__ = 0;
                                                                                                                   $1867 = (invoke_ii(3276,60)|0);
                                                                                                                   $1868 = __THREW__; __THREW__ = 0;
                                                                                                                   $1869 = $1868&1;
                                                                                                                   L659: do {
                                                                                                                    if (!($1869)) {
                                                                                                                     __THREW__ = 0;
                                                                                                                     invoke_vi(4186,($1867|0));
                                                                                                                     $1870 = __THREW__; __THREW__ = 0;
                                                                                                                     $1871 = $1870&1;
                                                                                                                     if ($1871) {
                                                                                                                      $1941 = ___cxa_find_matching_catch_2()|0;
                                                                                                                      $1942 = tempRet0;
                                                                                                                      __ZdlPv($1867);
                                                                                                                      $$63 = $1941;$$6398 = $1942;
                                                                                                                      break L7;
                                                                                                                     }
                                                                                                                     $1872 = HEAP32[$152>>2]|0;
                                                                                                                     $1873 = ($1872|0)==($1867|0);
                                                                                                                     do {
                                                                                                                      if (!($1873)) {
                                                                                                                       HEAP32[$152>>2] = $1867;
                                                                                                                       $1874 = ((($1867)) + 8|0);
                                                                                                                       $1875 = HEAP32[$1874>>2]|0;HEAP32[$1874>>2] = (($1875+1)|0);
                                                                                                                       $1876 = ($1872|0)==(0|0);
                                                                                                                       if ($1876) {
                                                                                                                        break;
                                                                                                                       }
                                                                                                                       $1877 = ((($1872)) + 8|0);
                                                                                                                       $1878 = HEAP32[$1877>>2]|0;HEAP32[$1877>>2] = (($1878-1)|0);
                                                                                                                       $1879 = ($1878|0)==(1);
                                                                                                                       if (!($1879)) {
                                                                                                                        break;
                                                                                                                       }
                                                                                                                       __THREW__ = 0;
                                                                                                                       invoke_viii(3262,($1872|0),1,1);
                                                                                                                       $1880 = __THREW__; __THREW__ = 0;
                                                                                                                       $1881 = $1880&1;
                                                                                                                       if ($1881) {
                                                                                                                        break L659;
                                                                                                                       }
                                                                                                                      }
                                                                                                                     } while(0);
                                                                                                                     __THREW__ = 0;
                                                                                                                     $1882 = (invoke_ii(3276,108)|0);
                                                                                                                     $1883 = __THREW__; __THREW__ = 0;
                                                                                                                     $1884 = $1883&1;
                                                                                                                     if ($1884) {
                                                                                                                      break;
                                                                                                                     }
                                                                                                                     __THREW__ = 0;
                                                                                                                     invoke_vi(3282,($1882|0));
                                                                                                                     $1885 = __THREW__; __THREW__ = 0;
                                                                                                                     $1886 = $1885&1;
                                                                                                                     if ($1886) {
                                                                                                                      $1943 = ___cxa_find_matching_catch_2()|0;
                                                                                                                      $1944 = tempRet0;
                                                                                                                      __ZdlPv($1882);
                                                                                                                      $$63 = $1943;$$6398 = $1944;
                                                                                                                      break L7;
                                                                                                                     }
                                                                                                                     HEAP32[$1882>>2] = (75052);
                                                                                                                     $1887 = ((($1882)) + 16|0);
                                                                                                                     HEAP32[$1887>>2] = 0;
                                                                                                                     $1888 = ((($1882)) + 20|0);
                                                                                                                     HEAP32[$1888>>2] = 0;
                                                                                                                     $1889 = ((($1882)) + 12|0);
                                                                                                                     HEAP32[$1889>>2] = $1887;
                                                                                                                     $1890 = ((($1882)) + 28|0);
                                                                                                                     HEAP32[$1890>>2] = 0;
                                                                                                                     $1891 = ((($1882)) + 32|0);
                                                                                                                     HEAP32[$1891>>2] = 0;
                                                                                                                     $1892 = ((($1882)) + 24|0);
                                                                                                                     HEAP32[$1892>>2] = $1890;
                                                                                                                     $1893 = ((($1882)) + 40|0);
                                                                                                                     HEAP32[$1893>>2] = 0;
                                                                                                                     $1894 = ((($1882)) + 44|0);
                                                                                                                     HEAP32[$1894>>2] = 0;
                                                                                                                     $1895 = ((($1882)) + 36|0);
                                                                                                                     HEAP32[$1895>>2] = $1893;
                                                                                                                     $1896 = ((($1882)) + 52|0);
                                                                                                                     HEAP32[$1896>>2] = 0;
                                                                                                                     $1897 = ((($1882)) + 56|0);
                                                                                                                     HEAP32[$1897>>2] = 0;
                                                                                                                     $1898 = ((($1882)) + 48|0);
                                                                                                                     HEAP32[$1898>>2] = $1896;
                                                                                                                     $1899 = ((($1882)) + 64|0);
                                                                                                                     HEAP32[$1899>>2] = 0;
                                                                                                                     $1900 = ((($1882)) + 68|0);
                                                                                                                     HEAP32[$1900>>2] = 0;
                                                                                                                     $1901 = ((($1882)) + 60|0);
                                                                                                                     HEAP32[$1901>>2] = $1899;
                                                                                                                     $1902 = ((($1882)) + 76|0);
                                                                                                                     HEAP32[$1902>>2] = 0;
                                                                                                                     $1903 = ((($1882)) + 80|0);
                                                                                                                     HEAP32[$1903>>2] = 0;
                                                                                                                     $1904 = ((($1882)) + 72|0);
                                                                                                                     HEAP32[$1904>>2] = $1902;
                                                                                                                     $1905 = ((($1882)) + 88|0);
                                                                                                                     HEAP32[$1905>>2] = 0;
                                                                                                                     $1906 = ((($1882)) + 92|0);
                                                                                                                     HEAP32[$1906>>2] = 0;
                                                                                                                     $1907 = ((($1882)) + 84|0);
                                                                                                                     HEAP32[$1907>>2] = $1905;
                                                                                                                     $1908 = ((($1882)) + 100|0);
                                                                                                                     HEAP32[$1908>>2] = 0;
                                                                                                                     $1909 = ((($1882)) + 104|0);
                                                                                                                     HEAP32[$1909>>2] = 0;
                                                                                                                     $1910 = ((($1882)) + 96|0);
                                                                                                                     HEAP32[$1910>>2] = $1908;
                                                                                                                     $1911 = HEAP32[$153>>2]|0;
                                                                                                                     $1912 = ($1911|0)==($1882|0);
                                                                                                                     if ($1912) {
                                                                                                                      STACKTOP = sp;return;
                                                                                                                     }
                                                                                                                     HEAP32[$153>>2] = $1882;
                                                                                                                     $1913 = ((($1882)) + 8|0);
                                                                                                                     $1914 = HEAP32[$1913>>2]|0;HEAP32[$1913>>2] = (($1914+1)|0);
                                                                                                                     $1915 = ($1911|0)==(0|0);
                                                                                                                     if ($1915) {
                                                                                                                      STACKTOP = sp;return;
                                                                                                                     }
                                                                                                                     $1916 = ((($1911)) + 8|0);
                                                                                                                     $1917 = HEAP32[$1916>>2]|0;HEAP32[$1916>>2] = (($1917-1)|0);
                                                                                                                     $1918 = ($1917|0)==(1);
                                                                                                                     if (!($1918)) {
                                                                                                                      STACKTOP = sp;return;
                                                                                                                     }
                                                                                                                     __THREW__ = 0;
                                                                                                                     invoke_viii(3262,($1911|0),1,1);
                                                                                                                     $1919 = __THREW__; __THREW__ = 0;
                                                                                                                     $1920 = $1919&1;
                                                                                                                     if ($1920) {
                                                                                                                      break;
                                                                                                                     }
                                                                                                                     STACKTOP = sp;return;
                                                                                                                    }
                                                                                                                   } while(0);
                                                                                                                   $381 = ___cxa_find_matching_catch_2()|0;
                                                                                                                   $382 = tempRet0;
                                                                                                                   $$63 = $381;$$6398 = $382;
                                                                                                                   break L7;
                                                                                                                  }
                                                                                                                  else if ((label|0) == 618) {
                                                                                                                   $1823 = ___cxa_find_matching_catch_2()|0;
                                                                                                                   $1824 = tempRet0;
                                                                                                                   $$53 = $1823;$$5388 = $1824;
                                                                                                                  }
                                                                                                                  else if ((label|0) == 620) {
                                                                                                                   $1827 = ___cxa_find_matching_catch_2()|0;
                                                                                                                   $1828 = tempRet0;
                                                                                                                   $1829 = HEAP8[$1367>>0]|0;
                                                                                                                   $1830 = ($1829<<24>>24)<(0);
                                                                                                                   if (!($1830)) {
                                                                                                                    $$52 = $1827;$$5287 = $1828;
                                                                                                                    label = 622;
                                                                                                                    break;
                                                                                                                   }
                                                                                                                   $1831 = HEAP32[$105>>2]|0;
                                                                                                                   __ZdlPv($1831);
                                                                                                                   $$52 = $1827;$$5287 = $1828;
                                                                                                                   label = 622;
                                                                                                                  }
                                                                                                                 } while(0);
                                                                                                                 if ((label|0) == 619) {
                                                                                                                  $1825 = ___cxa_find_matching_catch_2()|0;
                                                                                                                  $1826 = tempRet0;
                                                                                                                  $$52 = $1825;$$5287 = $1826;
                                                                                                                  label = 622;
                                                                                                                 }
                                                                                                                 do {
                                                                                                                  if ((label|0) == 622) {
                                                                                                                   $1832 = HEAP8[$1368>>0]|0;
                                                                                                                   $1833 = ($1832<<24>>24)<(0);
                                                                                                                   if (!($1833)) {
                                                                                                                    $$53 = $$52;$$5388 = $$5287;
                                                                                                                    break;
                                                                                                                   }
                                                                                                                   $1834 = HEAP32[$104>>2]|0;
                                                                                                                   __ZdlPv($1834);
                                                                                                                   $$53 = $$52;$$5388 = $$5287;
                                                                                                                  }
                                                                                                                 } while(0);
                                                                                                                 $1835 = HEAP8[$1365>>0]|0;
                                                                                                                 $1836 = ($1835<<24>>24)<(0);
                                                                                                                 if ($1836) {
                                                                                                                  $1837 = HEAP32[$103>>2]|0;
                                                                                                                  __ZdlPv($1837);
                                                                                                                 }
                                                                                                                 $$63 = $$53;$$6398 = $$5388;
                                                                                                                 break L7;
                                                                                                                }
                                                                                                               } while(0);
                                                                                                               if ((label|0) == 398) {
                                                                                                                __THREW__ = 0;
                                                                                                                invoke_vi(3367,($103|0));
                                                                                                                $1372 = __THREW__; __THREW__ = 0;
                                                                                                               }
                                                                                                               $1779 = ___cxa_find_matching_catch_2()|0;
                                                                                                               $1780 = tempRet0;
                                                                                                               $$63 = $1779;$$6398 = $1780;
                                                                                                               break L7;
                                                                                                              }
                                                                                                             } while(0);
                                                                                                             $1770 = ___cxa_find_matching_catch_2()|0;
                                                                                                             $1771 = tempRet0;
                                                                                                             $1772 = ((($102)) + 11|0);
                                                                                                             $1773 = HEAP8[$1772>>0]|0;
                                                                                                             $1774 = ($1773<<24>>24)<(0);
                                                                                                             if (!($1774)) {
                                                                                                              $$51 = $1770;$$5186 = $1771;
                                                                                                              break;
                                                                                                             }
                                                                                                             $1775 = HEAP32[$102>>2]|0;
                                                                                                             __ZdlPv($1775);
                                                                                                             $$51 = $1770;$$5186 = $1771;
                                                                                                            }
                                                                                                           } while(0);
                                                                                                           $1776 = HEAP8[$1342>>0]|0;
                                                                                                           $1777 = ($1776<<24>>24)<(0);
                                                                                                           if (!($1777)) {
                                                                                                            $$63 = $$51;$$6398 = $$5186;
                                                                                                            break L7;
                                                                                                           }
                                                                                                           $1778 = HEAP32[$101>>2]|0;
                                                                                                           __ZdlPv($1778);
                                                                                                           $$63 = $$51;$$6398 = $$5186;
                                                                                                           break L7;
                                                                                                          }
                                                                                                         } while(0);
                                                                                                         $1759 = ___cxa_find_matching_catch_2()|0;
                                                                                                         $1760 = tempRet0;
                                                                                                         $1761 = ((($100)) + 11|0);
                                                                                                         $1762 = HEAP8[$1761>>0]|0;
                                                                                                         $1763 = ($1762<<24>>24)<(0);
                                                                                                         if (!($1763)) {
                                                                                                          $$50 = $1759;$$5085 = $1760;
                                                                                                          break;
                                                                                                         }
                                                                                                         $1764 = HEAP32[$100>>2]|0;
                                                                                                         __ZdlPv($1764);
                                                                                                         $$50 = $1759;$$5085 = $1760;
                                                                                                        }
                                                                                                       } while(0);
                                                                                                       $1765 = HEAP8[$1322>>0]|0;
                                                                                                       $1766 = ($1765<<24>>24)<(0);
                                                                                                       if (!($1766)) {
                                                                                                        $$63 = $$50;$$6398 = $$5085;
                                                                                                        break L7;
                                                                                                       }
                                                                                                       $1767 = HEAP32[$99>>2]|0;
                                                                                                       __ZdlPv($1767);
                                                                                                       $$63 = $$50;$$6398 = $$5085;
                                                                                                       break L7;
                                                                                                      }
                                                                                                     } while(0);
                                                                                                     $1748 = ___cxa_find_matching_catch_2()|0;
                                                                                                     $1749 = tempRet0;
                                                                                                     $1750 = ((($98)) + 11|0);
                                                                                                     $1751 = HEAP8[$1750>>0]|0;
                                                                                                     $1752 = ($1751<<24>>24)<(0);
                                                                                                     if (!($1752)) {
                                                                                                      $$49 = $1748;$$4984 = $1749;
                                                                                                      break;
                                                                                                     }
                                                                                                     $1753 = HEAP32[$98>>2]|0;
                                                                                                     __ZdlPv($1753);
                                                                                                     $$49 = $1748;$$4984 = $1749;
                                                                                                    }
                                                                                                   } while(0);
                                                                                                   $1754 = HEAP8[$1297>>0]|0;
                                                                                                   $1755 = ($1754<<24>>24)<(0);
                                                                                                   if (!($1755)) {
                                                                                                    $$63 = $$49;$$6398 = $$4984;
                                                                                                    break L7;
                                                                                                   }
                                                                                                   $1756 = HEAP32[$97>>2]|0;
                                                                                                   __ZdlPv($1756);
                                                                                                   $$63 = $$49;$$6398 = $$4984;
                                                                                                   break L7;
                                                                                                  }
                                                                                                 } while(0);
                                                                                                 $1737 = ___cxa_find_matching_catch_2()|0;
                                                                                                 $1738 = tempRet0;
                                                                                                 $1739 = ((($96)) + 11|0);
                                                                                                 $1740 = HEAP8[$1739>>0]|0;
                                                                                                 $1741 = ($1740<<24>>24)<(0);
                                                                                                 if (!($1741)) {
                                                                                                  $$48 = $1737;$$4883 = $1738;
                                                                                                  break;
                                                                                                 }
                                                                                                 $1742 = HEAP32[$96>>2]|0;
                                                                                                 __ZdlPv($1742);
                                                                                                 $$48 = $1737;$$4883 = $1738;
                                                                                                }
                                                                                               } while(0);
                                                                                               $1743 = HEAP8[$1277>>0]|0;
                                                                                               $1744 = ($1743<<24>>24)<(0);
                                                                                               if (!($1744)) {
                                                                                                $$63 = $$48;$$6398 = $$4883;
                                                                                                break L7;
                                                                                               }
                                                                                               $1745 = HEAP32[$95>>2]|0;
                                                                                               __ZdlPv($1745);
                                                                                               $$63 = $$48;$$6398 = $$4883;
                                                                                               break L7;
                                                                                              }
                                                                                             } while(0);
                                                                                             $1727 = ___cxa_find_matching_catch_2()|0;
                                                                                             $1728 = tempRet0;
                                                                                             $1729 = HEAP8[$1259>>0]|0;
                                                                                             $1730 = ($1729<<24>>24)<(0);
                                                                                             if ($1730) {
                                                                                              $1731 = HEAP32[$94>>2]|0;
                                                                                              __ZdlPv($1731);
                                                                                             }
                                                                                             $1732 = HEAP8[$1253>>0]|0;
                                                                                             $1733 = ($1732<<24>>24)<(0);
                                                                                             if (!($1733)) {
                                                                                              $$63 = $1727;$$6398 = $1728;
                                                                                              break L7;
                                                                                             }
                                                                                             $1734 = HEAP32[$93>>2]|0;
                                                                                             __ZdlPv($1734);
                                                                                             $$63 = $1727;$$6398 = $1728;
                                                                                             break L7;
                                                                                            }
                                                                                           } while(0);
                                                                                           $1719 = ___cxa_find_matching_catch_2()|0;
                                                                                           $1720 = tempRet0;
                                                                                           $1721 = HEAP8[$1240>>0]|0;
                                                                                           $1722 = ($1721<<24>>24)<(0);
                                                                                           if ($1722) {
                                                                                            $1723 = HEAP32[$92>>2]|0;
                                                                                            __ZdlPv($1723);
                                                                                           }
                                                                                           $1724 = HEAP8[$1238>>0]|0;
                                                                                           $1725 = ($1724<<24>>24)<(0);
                                                                                           if (!($1725)) {
                                                                                            $$63 = $1719;$$6398 = $1720;
                                                                                            break L7;
                                                                                           }
                                                                                           $1726 = HEAP32[$91>>2]|0;
                                                                                           __ZdlPv($1726);
                                                                                           $$63 = $1719;$$6398 = $1720;
                                                                                           break L7;
                                                                                          }
                                                                                         } while(0);
                                                                                         $1711 = ___cxa_find_matching_catch_2()|0;
                                                                                         $1712 = tempRet0;
                                                                                         $1713 = HEAP8[$1224>>0]|0;
                                                                                         $1714 = ($1713<<24>>24)<(0);
                                                                                         if ($1714) {
                                                                                          $1715 = HEAP32[$90>>2]|0;
                                                                                          __ZdlPv($1715);
                                                                                         }
                                                                                         $1716 = HEAP8[$1222>>0]|0;
                                                                                         $1717 = ($1716<<24>>24)<(0);
                                                                                         if (!($1717)) {
                                                                                          $$63 = $1711;$$6398 = $1712;
                                                                                          break L7;
                                                                                         }
                                                                                         $1718 = HEAP32[$89>>2]|0;
                                                                                         __ZdlPv($1718);
                                                                                         $$63 = $1711;$$6398 = $1712;
                                                                                         break L7;
                                                                                        }
                                                                                       } while(0);
                                                                                       $1703 = ___cxa_find_matching_catch_2()|0;
                                                                                       $1704 = tempRet0;
                                                                                       $1705 = HEAP8[$1209>>0]|0;
                                                                                       $1706 = ($1705<<24>>24)<(0);
                                                                                       if ($1706) {
                                                                                        $1707 = HEAP32[$88>>2]|0;
                                                                                        __ZdlPv($1707);
                                                                                       }
                                                                                       $1708 = HEAP8[$1202>>0]|0;
                                                                                       $1709 = ($1708<<24>>24)<(0);
                                                                                       if (!($1709)) {
                                                                                        $$63 = $1703;$$6398 = $1704;
                                                                                        break L7;
                                                                                       }
                                                                                       $1710 = HEAP32[$87>>2]|0;
                                                                                       __ZdlPv($1710);
                                                                                       $$63 = $1703;$$6398 = $1704;
                                                                                       break L7;
                                                                                      }
                                                                                     } while(0);
                                                                                     $1695 = ___cxa_find_matching_catch_2()|0;
                                                                                     $1696 = tempRet0;
                                                                                     $1697 = HEAP8[$1184>>0]|0;
                                                                                     $1698 = ($1697<<24>>24)<(0);
                                                                                     if ($1698) {
                                                                                      $1699 = HEAP32[$86>>2]|0;
                                                                                      __ZdlPv($1699);
                                                                                     }
                                                                                     $1700 = HEAP8[$1177>>0]|0;
                                                                                     $1701 = ($1700<<24>>24)<(0);
                                                                                     if (!($1701)) {
                                                                                      $$63 = $1695;$$6398 = $1696;
                                                                                      break L7;
                                                                                     }
                                                                                     $1702 = HEAP32[$85>>2]|0;
                                                                                     __ZdlPv($1702);
                                                                                     $$63 = $1695;$$6398 = $1696;
                                                                                     break L7;
                                                                                    }
                                                                                   } while(0);
                                                                                   $1687 = ___cxa_find_matching_catch_2()|0;
                                                                                   $1688 = tempRet0;
                                                                                   $1689 = HEAP8[$1159>>0]|0;
                                                                                   $1690 = ($1689<<24>>24)<(0);
                                                                                   if ($1690) {
                                                                                    $1691 = HEAP32[$84>>2]|0;
                                                                                    __ZdlPv($1691);
                                                                                   }
                                                                                   $1692 = HEAP8[$1152>>0]|0;
                                                                                   $1693 = ($1692<<24>>24)<(0);
                                                                                   if (!($1693)) {
                                                                                    $$63 = $1687;$$6398 = $1688;
                                                                                    break L7;
                                                                                   }
                                                                                   $1694 = HEAP32[$83>>2]|0;
                                                                                   __ZdlPv($1694);
                                                                                   $$63 = $1687;$$6398 = $1688;
                                                                                   break L7;
                                                                                  }
                                                                                 } while(0);
                                                                                 $1679 = ___cxa_find_matching_catch_2()|0;
                                                                                 $1680 = tempRet0;
                                                                                 $1681 = HEAP8[$1134>>0]|0;
                                                                                 $1682 = ($1681<<24>>24)<(0);
                                                                                 if ($1682) {
                                                                                  $1683 = HEAP32[$82>>2]|0;
                                                                                  __ZdlPv($1683);
                                                                                 }
                                                                                 $1684 = HEAP8[$1132>>0]|0;
                                                                                 $1685 = ($1684<<24>>24)<(0);
                                                                                 if (!($1685)) {
                                                                                  $$63 = $1679;$$6398 = $1680;
                                                                                  break L7;
                                                                                 }
                                                                                 $1686 = HEAP32[$81>>2]|0;
                                                                                 __ZdlPv($1686);
                                                                                 $$63 = $1679;$$6398 = $1680;
                                                                                 break L7;
                                                                                }
                                                                               } while(0);
                                                                               $1671 = ___cxa_find_matching_catch_2()|0;
                                                                               $1672 = tempRet0;
                                                                               $1673 = HEAP8[$1115>>0]|0;
                                                                               $1674 = ($1673<<24>>24)<(0);
                                                                               if ($1674) {
                                                                                $1675 = HEAP32[$80>>2]|0;
                                                                                __ZdlPv($1675);
                                                                               }
                                                                               $1676 = HEAP8[$1113>>0]|0;
                                                                               $1677 = ($1676<<24>>24)<(0);
                                                                               if (!($1677)) {
                                                                                $$63 = $1671;$$6398 = $1672;
                                                                                break L7;
                                                                               }
                                                                               $1678 = HEAP32[$79>>2]|0;
                                                                               __ZdlPv($1678);
                                                                               $$63 = $1671;$$6398 = $1672;
                                                                               break L7;
                                                                              }
                                                                             } while(0);
                                                                             $1663 = ___cxa_find_matching_catch_2()|0;
                                                                             $1664 = tempRet0;
                                                                             $1665 = HEAP8[$1096>>0]|0;
                                                                             $1666 = ($1665<<24>>24)<(0);
                                                                             if ($1666) {
                                                                              $1667 = HEAP32[$78>>2]|0;
                                                                              __ZdlPv($1667);
                                                                             }
                                                                             $1668 = HEAP8[$1094>>0]|0;
                                                                             $1669 = ($1668<<24>>24)<(0);
                                                                             if (!($1669)) {
                                                                              $$63 = $1663;$$6398 = $1664;
                                                                              break L7;
                                                                             }
                                                                             $1670 = HEAP32[$77>>2]|0;
                                                                             __ZdlPv($1670);
                                                                             $$63 = $1663;$$6398 = $1664;
                                                                             break L7;
                                                                            }
                                                                           } while(0);
                                                                           $1655 = ___cxa_find_matching_catch_2()|0;
                                                                           $1656 = tempRet0;
                                                                           $1657 = HEAP8[$1072>>0]|0;
                                                                           $1658 = ($1657<<24>>24)<(0);
                                                                           if ($1658) {
                                                                            $1659 = HEAP32[$76>>2]|0;
                                                                            __ZdlPv($1659);
                                                                           }
                                                                           $1660 = HEAP8[$1070>>0]|0;
                                                                           $1661 = ($1660<<24>>24)<(0);
                                                                           if (!($1661)) {
                                                                            $$63 = $1655;$$6398 = $1656;
                                                                            break L7;
                                                                           }
                                                                           $1662 = HEAP32[$75>>2]|0;
                                                                           __ZdlPv($1662);
                                                                           $$63 = $1655;$$6398 = $1656;
                                                                           break L7;
                                                                          }
                                                                         } while(0);
                                                                         $1647 = ___cxa_find_matching_catch_2()|0;
                                                                         $1648 = tempRet0;
                                                                         $1649 = HEAP8[$1048>>0]|0;
                                                                         $1650 = ($1649<<24>>24)<(0);
                                                                         if ($1650) {
                                                                          $1651 = HEAP32[$74>>2]|0;
                                                                          __ZdlPv($1651);
                                                                         }
                                                                         $1652 = HEAP8[$1046>>0]|0;
                                                                         $1653 = ($1652<<24>>24)<(0);
                                                                         if (!($1653)) {
                                                                          $$63 = $1647;$$6398 = $1648;
                                                                          break L7;
                                                                         }
                                                                         $1654 = HEAP32[$73>>2]|0;
                                                                         __ZdlPv($1654);
                                                                         $$63 = $1647;$$6398 = $1648;
                                                                         break L7;
                                                                        }
                                                                       } while(0);
                                                                       $1639 = ___cxa_find_matching_catch_2()|0;
                                                                       $1640 = tempRet0;
                                                                       $1641 = HEAP8[$1024>>0]|0;
                                                                       $1642 = ($1641<<24>>24)<(0);
                                                                       if ($1642) {
                                                                        $1643 = HEAP32[$72>>2]|0;
                                                                        __ZdlPv($1643);
                                                                       }
                                                                       $1644 = HEAP8[$1022>>0]|0;
                                                                       $1645 = ($1644<<24>>24)<(0);
                                                                       if (!($1645)) {
                                                                        $$63 = $1639;$$6398 = $1640;
                                                                        break L7;
                                                                       }
                                                                       $1646 = HEAP32[$71>>2]|0;
                                                                       __ZdlPv($1646);
                                                                       $$63 = $1639;$$6398 = $1640;
                                                                       break L7;
                                                                      }
                                                                     } while(0);
                                                                     $1631 = ___cxa_find_matching_catch_2()|0;
                                                                     $1632 = tempRet0;
                                                                     $1633 = HEAP8[$1000>>0]|0;
                                                                     $1634 = ($1633<<24>>24)<(0);
                                                                     if ($1634) {
                                                                      $1635 = HEAP32[$70>>2]|0;
                                                                      __ZdlPv($1635);
                                                                     }
                                                                     $1636 = HEAP8[$998>>0]|0;
                                                                     $1637 = ($1636<<24>>24)<(0);
                                                                     if (!($1637)) {
                                                                      $$63 = $1631;$$6398 = $1632;
                                                                      break L7;
                                                                     }
                                                                     $1638 = HEAP32[$69>>2]|0;
                                                                     __ZdlPv($1638);
                                                                     $$63 = $1631;$$6398 = $1632;
                                                                     break L7;
                                                                    }
                                                                   } while(0);
                                                                   $1623 = ___cxa_find_matching_catch_2()|0;
                                                                   $1624 = tempRet0;
                                                                   $1625 = HEAP8[$976>>0]|0;
                                                                   $1626 = ($1625<<24>>24)<(0);
                                                                   if ($1626) {
                                                                    $1627 = HEAP32[$68>>2]|0;
                                                                    __ZdlPv($1627);
                                                                   }
                                                                   $1628 = HEAP8[$974>>0]|0;
                                                                   $1629 = ($1628<<24>>24)<(0);
                                                                   if (!($1629)) {
                                                                    $$63 = $1623;$$6398 = $1624;
                                                                    break L7;
                                                                   }
                                                                   $1630 = HEAP32[$67>>2]|0;
                                                                   __ZdlPv($1630);
                                                                   $$63 = $1623;$$6398 = $1624;
                                                                   break L7;
                                                                  }
                                                                 } while(0);
                                                                 $1615 = ___cxa_find_matching_catch_2()|0;
                                                                 $1616 = tempRet0;
                                                                 $1617 = HEAP8[$952>>0]|0;
                                                                 $1618 = ($1617<<24>>24)<(0);
                                                                 if ($1618) {
                                                                  $1619 = HEAP32[$66>>2]|0;
                                                                  __ZdlPv($1619);
                                                                 }
                                                                 $1620 = HEAP8[$950>>0]|0;
                                                                 $1621 = ($1620<<24>>24)<(0);
                                                                 if (!($1621)) {
                                                                  $$63 = $1615;$$6398 = $1616;
                                                                  break L7;
                                                                 }
                                                                 $1622 = HEAP32[$65>>2]|0;
                                                                 __ZdlPv($1622);
                                                                 $$63 = $1615;$$6398 = $1616;
                                                                 break L7;
                                                                }
                                                               } while(0);
                                                               $1607 = ___cxa_find_matching_catch_2()|0;
                                                               $1608 = tempRet0;
                                                               $1609 = HEAP8[$932>>0]|0;
                                                               $1610 = ($1609<<24>>24)<(0);
                                                               if ($1610) {
                                                                $1611 = HEAP32[$64>>2]|0;
                                                                __ZdlPv($1611);
                                                               }
                                                               $1612 = HEAP8[$925>>0]|0;
                                                               $1613 = ($1612<<24>>24)<(0);
                                                               if (!($1613)) {
                                                                $$63 = $1607;$$6398 = $1608;
                                                                break L7;
                                                               }
                                                               $1614 = HEAP32[$63>>2]|0;
                                                               __ZdlPv($1614);
                                                               $$63 = $1607;$$6398 = $1608;
                                                               break L7;
                                                              }
                                                             } while(0);
                                                             $1599 = ___cxa_find_matching_catch_2()|0;
                                                             $1600 = tempRet0;
                                                             $1601 = HEAP8[$912>>0]|0;
                                                             $1602 = ($1601<<24>>24)<(0);
                                                             if ($1602) {
                                                              $1603 = HEAP32[$62>>2]|0;
                                                              __ZdlPv($1603);
                                                             }
                                                             $1604 = HEAP8[$910>>0]|0;
                                                             $1605 = ($1604<<24>>24)<(0);
                                                             if (!($1605)) {
                                                              $$63 = $1599;$$6398 = $1600;
                                                              break L7;
                                                             }
                                                             $1606 = HEAP32[$61>>2]|0;
                                                             __ZdlPv($1606);
                                                             $$63 = $1599;$$6398 = $1600;
                                                             break L7;
                                                            }
                                                           } while(0);
                                                           $1591 = ___cxa_find_matching_catch_2()|0;
                                                           $1592 = tempRet0;
                                                           $1593 = HEAP8[$892>>0]|0;
                                                           $1594 = ($1593<<24>>24)<(0);
                                                           if ($1594) {
                                                            $1595 = HEAP32[$60>>2]|0;
                                                            __ZdlPv($1595);
                                                           }
                                                           $1596 = HEAP8[$890>>0]|0;
                                                           $1597 = ($1596<<24>>24)<(0);
                                                           if (!($1597)) {
                                                            $$63 = $1591;$$6398 = $1592;
                                                            break L7;
                                                           }
                                                           $1598 = HEAP32[$59>>2]|0;
                                                           __ZdlPv($1598);
                                                           $$63 = $1591;$$6398 = $1592;
                                                           break L7;
                                                          }
                                                         } while(0);
                                                         $1583 = ___cxa_find_matching_catch_2()|0;
                                                         $1584 = tempRet0;
                                                         $1585 = HEAP8[$872>>0]|0;
                                                         $1586 = ($1585<<24>>24)<(0);
                                                         if ($1586) {
                                                          $1587 = HEAP32[$58>>2]|0;
                                                          __ZdlPv($1587);
                                                         }
                                                         $1588 = HEAP8[$870>>0]|0;
                                                         $1589 = ($1588<<24>>24)<(0);
                                                         if (!($1589)) {
                                                          $$63 = $1583;$$6398 = $1584;
                                                          break L7;
                                                         }
                                                         $1590 = HEAP32[$57>>2]|0;
                                                         __ZdlPv($1590);
                                                         $$63 = $1583;$$6398 = $1584;
                                                         break L7;
                                                        }
                                                       } while(0);
                                                       $1575 = ___cxa_find_matching_catch_2()|0;
                                                       $1576 = tempRet0;
                                                       $1577 = HEAP8[$852>>0]|0;
                                                       $1578 = ($1577<<24>>24)<(0);
                                                       if ($1578) {
                                                        $1579 = HEAP32[$56>>2]|0;
                                                        __ZdlPv($1579);
                                                       }
                                                       $1580 = HEAP8[$850>>0]|0;
                                                       $1581 = ($1580<<24>>24)<(0);
                                                       if (!($1581)) {
                                                        $$63 = $1575;$$6398 = $1576;
                                                        break L7;
                                                       }
                                                       $1582 = HEAP32[$55>>2]|0;
                                                       __ZdlPv($1582);
                                                       $$63 = $1575;$$6398 = $1576;
                                                       break L7;
                                                      }
                                                     } while(0);
                                                     $1567 = ___cxa_find_matching_catch_2()|0;
                                                     $1568 = tempRet0;
                                                     $1569 = HEAP8[$837>>0]|0;
                                                     $1570 = ($1569<<24>>24)<(0);
                                                     if ($1570) {
                                                      $1571 = HEAP32[$54>>2]|0;
                                                      __ZdlPv($1571);
                                                     }
                                                     $1572 = HEAP8[$835>>0]|0;
                                                     $1573 = ($1572<<24>>24)<(0);
                                                     if (!($1573)) {
                                                      $$63 = $1567;$$6398 = $1568;
                                                      break L7;
                                                     }
                                                     $1574 = HEAP32[$53>>2]|0;
                                                     __ZdlPv($1574);
                                                     $$63 = $1567;$$6398 = $1568;
                                                     break L7;
                                                    }
                                                   } while(0);
                                                   $1559 = ___cxa_find_matching_catch_2()|0;
                                                   $1560 = tempRet0;
                                                   $1561 = HEAP8[$822>>0]|0;
                                                   $1562 = ($1561<<24>>24)<(0);
                                                   if ($1562) {
                                                    $1563 = HEAP32[$52>>2]|0;
                                                    __ZdlPv($1563);
                                                   }
                                                   $1564 = HEAP8[$820>>0]|0;
                                                   $1565 = ($1564<<24>>24)<(0);
                                                   if (!($1565)) {
                                                    $$63 = $1559;$$6398 = $1560;
                                                    break L7;
                                                   }
                                                   $1566 = HEAP32[$51>>2]|0;
                                                   __ZdlPv($1566);
                                                   $$63 = $1559;$$6398 = $1560;
                                                   break L7;
                                                  }
                                                 } while(0);
                                                 $1551 = ___cxa_find_matching_catch_2()|0;
                                                 $1552 = tempRet0;
                                                 $1553 = HEAP8[$807>>0]|0;
                                                 $1554 = ($1553<<24>>24)<(0);
                                                 if ($1554) {
                                                  $1555 = HEAP32[$50>>2]|0;
                                                  __ZdlPv($1555);
                                                 }
                                                 $1556 = HEAP8[$805>>0]|0;
                                                 $1557 = ($1556<<24>>24)<(0);
                                                 if (!($1557)) {
                                                  $$63 = $1551;$$6398 = $1552;
                                                  break L7;
                                                 }
                                                 $1558 = HEAP32[$49>>2]|0;
                                                 __ZdlPv($1558);
                                                 $$63 = $1551;$$6398 = $1552;
                                                 break L7;
                                                }
                                               } while(0);
                                               $1543 = ___cxa_find_matching_catch_2()|0;
                                               $1544 = tempRet0;
                                               $1545 = HEAP8[$792>>0]|0;
                                               $1546 = ($1545<<24>>24)<(0);
                                               if ($1546) {
                                                $1547 = HEAP32[$48>>2]|0;
                                                __ZdlPv($1547);
                                               }
                                               $1548 = HEAP8[$790>>0]|0;
                                               $1549 = ($1548<<24>>24)<(0);
                                               if (!($1549)) {
                                                $$63 = $1543;$$6398 = $1544;
                                                break L7;
                                               }
                                               $1550 = HEAP32[$47>>2]|0;
                                               __ZdlPv($1550);
                                               $$63 = $1543;$$6398 = $1544;
                                               break L7;
                                              }
                                             } while(0);
                                             $1535 = ___cxa_find_matching_catch_2()|0;
                                             $1536 = tempRet0;
                                             $1537 = HEAP8[$777>>0]|0;
                                             $1538 = ($1537<<24>>24)<(0);
                                             if ($1538) {
                                              $1539 = HEAP32[$46>>2]|0;
                                              __ZdlPv($1539);
                                             }
                                             $1540 = HEAP8[$775>>0]|0;
                                             $1541 = ($1540<<24>>24)<(0);
                                             if (!($1541)) {
                                              $$63 = $1535;$$6398 = $1536;
                                              break L7;
                                             }
                                             $1542 = HEAP32[$45>>2]|0;
                                             __ZdlPv($1542);
                                             $$63 = $1535;$$6398 = $1536;
                                             break L7;
                                            }
                                           } while(0);
                                           $1527 = ___cxa_find_matching_catch_2()|0;
                                           $1528 = tempRet0;
                                           $1529 = HEAP8[$757>>0]|0;
                                           $1530 = ($1529<<24>>24)<(0);
                                           if ($1530) {
                                            $1531 = HEAP32[$44>>2]|0;
                                            __ZdlPv($1531);
                                           }
                                           $1532 = HEAP8[$755>>0]|0;
                                           $1533 = ($1532<<24>>24)<(0);
                                           if (!($1533)) {
                                            $$63 = $1527;$$6398 = $1528;
                                            break L7;
                                           }
                                           $1534 = HEAP32[$43>>2]|0;
                                           __ZdlPv($1534);
                                           $$63 = $1527;$$6398 = $1528;
                                           break L7;
                                          }
                                         } while(0);
                                         $1519 = ___cxa_find_matching_catch_2()|0;
                                         $1520 = tempRet0;
                                         $1521 = HEAP8[$737>>0]|0;
                                         $1522 = ($1521<<24>>24)<(0);
                                         if ($1522) {
                                          $1523 = HEAP32[$42>>2]|0;
                                          __ZdlPv($1523);
                                         }
                                         $1524 = HEAP8[$735>>0]|0;
                                         $1525 = ($1524<<24>>24)<(0);
                                         if (!($1525)) {
                                          $$63 = $1519;$$6398 = $1520;
                                          break L7;
                                         }
                                         $1526 = HEAP32[$41>>2]|0;
                                         __ZdlPv($1526);
                                         $$63 = $1519;$$6398 = $1520;
                                         break L7;
                                        }
                                       } while(0);
                                       $1511 = ___cxa_find_matching_catch_2()|0;
                                       $1512 = tempRet0;
                                       $1513 = HEAP8[$717>>0]|0;
                                       $1514 = ($1513<<24>>24)<(0);
                                       if ($1514) {
                                        $1515 = HEAP32[$40>>2]|0;
                                        __ZdlPv($1515);
                                       }
                                       $1516 = HEAP8[$715>>0]|0;
                                       $1517 = ($1516<<24>>24)<(0);
                                       if (!($1517)) {
                                        $$63 = $1511;$$6398 = $1512;
                                        break L7;
                                       }
                                       $1518 = HEAP32[$39>>2]|0;
                                       __ZdlPv($1518);
                                       $$63 = $1511;$$6398 = $1512;
                                       break L7;
                                      }
                                     } while(0);
                                     $1503 = ___cxa_find_matching_catch_2()|0;
                                     $1504 = tempRet0;
                                     $1505 = HEAP8[$702>>0]|0;
                                     $1506 = ($1505<<24>>24)<(0);
                                     if ($1506) {
                                      $1507 = HEAP32[$38>>2]|0;
                                      __ZdlPv($1507);
                                     }
                                     $1508 = HEAP8[$700>>0]|0;
                                     $1509 = ($1508<<24>>24)<(0);
                                     if (!($1509)) {
                                      $$63 = $1503;$$6398 = $1504;
                                      break L7;
                                     }
                                     $1510 = HEAP32[$37>>2]|0;
                                     __ZdlPv($1510);
                                     $$63 = $1503;$$6398 = $1504;
                                     break L7;
                                    }
                                   } while(0);
                                   $1495 = ___cxa_find_matching_catch_2()|0;
                                   $1496 = tempRet0;
                                   $1497 = HEAP8[$682>>0]|0;
                                   $1498 = ($1497<<24>>24)<(0);
                                   if ($1498) {
                                    $1499 = HEAP32[$36>>2]|0;
                                    __ZdlPv($1499);
                                   }
                                   $1500 = HEAP8[$680>>0]|0;
                                   $1501 = ($1500<<24>>24)<(0);
                                   if (!($1501)) {
                                    $$63 = $1495;$$6398 = $1496;
                                    break L7;
                                   }
                                   $1502 = HEAP32[$35>>2]|0;
                                   __ZdlPv($1502);
                                   $$63 = $1495;$$6398 = $1496;
                                   break L7;
                                  }
                                 } while(0);
                                 $1487 = ___cxa_find_matching_catch_2()|0;
                                 $1488 = tempRet0;
                                 $1489 = HEAP8[$662>>0]|0;
                                 $1490 = ($1489<<24>>24)<(0);
                                 if ($1490) {
                                  $1491 = HEAP32[$34>>2]|0;
                                  __ZdlPv($1491);
                                 }
                                 $1492 = HEAP8[$660>>0]|0;
                                 $1493 = ($1492<<24>>24)<(0);
                                 if (!($1493)) {
                                  $$63 = $1487;$$6398 = $1488;
                                  break L7;
                                 }
                                 $1494 = HEAP32[$33>>2]|0;
                                 __ZdlPv($1494);
                                 $$63 = $1487;$$6398 = $1488;
                                 break L7;
                                }
                               } while(0);
                               $1479 = ___cxa_find_matching_catch_2()|0;
                               $1480 = tempRet0;
                               $1481 = HEAP8[$642>>0]|0;
                               $1482 = ($1481<<24>>24)<(0);
                               if ($1482) {
                                $1483 = HEAP32[$32>>2]|0;
                                __ZdlPv($1483);
                               }
                               $1484 = HEAP8[$635>>0]|0;
                               $1485 = ($1484<<24>>24)<(0);
                               if (!($1485)) {
                                $$63 = $1479;$$6398 = $1480;
                                break L7;
                               }
                               $1486 = HEAP32[$31>>2]|0;
                               __ZdlPv($1486);
                               $$63 = $1479;$$6398 = $1480;
                               break L7;
                              }
                             } while(0);
                             $1471 = ___cxa_find_matching_catch_2()|0;
                             $1472 = tempRet0;
                             $1473 = HEAP8[$622>>0]|0;
                             $1474 = ($1473<<24>>24)<(0);
                             if ($1474) {
                              $1475 = HEAP32[$30>>2]|0;
                              __ZdlPv($1475);
                             }
                             $1476 = HEAP8[$615>>0]|0;
                             $1477 = ($1476<<24>>24)<(0);
                             if (!($1477)) {
                              $$63 = $1471;$$6398 = $1472;
                              break L7;
                             }
                             $1478 = HEAP32[$29>>2]|0;
                             __ZdlPv($1478);
                             $$63 = $1471;$$6398 = $1472;
                             break L7;
                            }
                           } while(0);
                           $1463 = ___cxa_find_matching_catch_2()|0;
                           $1464 = tempRet0;
                           $1465 = HEAP8[$602>>0]|0;
                           $1466 = ($1465<<24>>24)<(0);
                           if ($1466) {
                            $1467 = HEAP32[$28>>2]|0;
                            __ZdlPv($1467);
                           }
                           $1468 = HEAP8[$595>>0]|0;
                           $1469 = ($1468<<24>>24)<(0);
                           if (!($1469)) {
                            $$63 = $1463;$$6398 = $1464;
                            break L7;
                           }
                           $1470 = HEAP32[$27>>2]|0;
                           __ZdlPv($1470);
                           $$63 = $1463;$$6398 = $1464;
                           break L7;
                          }
                         } while(0);
                         $1455 = ___cxa_find_matching_catch_2()|0;
                         $1456 = tempRet0;
                         $1457 = HEAP8[$577>>0]|0;
                         $1458 = ($1457<<24>>24)<(0);
                         if ($1458) {
                          $1459 = HEAP32[$26>>2]|0;
                          __ZdlPv($1459);
                         }
                         $1460 = HEAP8[$570>>0]|0;
                         $1461 = ($1460<<24>>24)<(0);
                         if (!($1461)) {
                          $$63 = $1455;$$6398 = $1456;
                          break L7;
                         }
                         $1462 = HEAP32[$25>>2]|0;
                         __ZdlPv($1462);
                         $$63 = $1455;$$6398 = $1456;
                         break L7;
                        }
                       } while(0);
                       $1447 = ___cxa_find_matching_catch_2()|0;
                       $1448 = tempRet0;
                       $1449 = HEAP8[$557>>0]|0;
                       $1450 = ($1449<<24>>24)<(0);
                       if ($1450) {
                        $1451 = HEAP32[$24>>2]|0;
                        __ZdlPv($1451);
                       }
                       $1452 = HEAP8[$550>>0]|0;
                       $1453 = ($1452<<24>>24)<(0);
                       if (!($1453)) {
                        $$63 = $1447;$$6398 = $1448;
                        break L7;
                       }
                       $1454 = HEAP32[$23>>2]|0;
                       __ZdlPv($1454);
                       $$63 = $1447;$$6398 = $1448;
                       break L7;
                      }
                     } while(0);
                     $1439 = ___cxa_find_matching_catch_2()|0;
                     $1440 = tempRet0;
                     $1441 = HEAP8[$532>>0]|0;
                     $1442 = ($1441<<24>>24)<(0);
                     if ($1442) {
                      $1443 = HEAP32[$22>>2]|0;
                      __ZdlPv($1443);
                     }
                     $1444 = HEAP8[$530>>0]|0;
                     $1445 = ($1444<<24>>24)<(0);
                     if (!($1445)) {
                      $$63 = $1439;$$6398 = $1440;
                      break L7;
                     }
                     $1446 = HEAP32[$21>>2]|0;
                     __ZdlPv($1446);
                     $$63 = $1439;$$6398 = $1440;
                     break L7;
                    }
                   } while(0);
                   $1431 = ___cxa_find_matching_catch_2()|0;
                   $1432 = tempRet0;
                   $1433 = HEAP8[$517>>0]|0;
                   $1434 = ($1433<<24>>24)<(0);
                   if ($1434) {
                    $1435 = HEAP32[$20>>2]|0;
                    __ZdlPv($1435);
                   }
                   $1436 = HEAP8[$515>>0]|0;
                   $1437 = ($1436<<24>>24)<(0);
                   if (!($1437)) {
                    $$63 = $1431;$$6398 = $1432;
                    break L7;
                   }
                   $1438 = HEAP32[$19>>2]|0;
                   __ZdlPv($1438);
                   $$63 = $1431;$$6398 = $1432;
                   break L7;
                  }
                 } while(0);
                 $1423 = ___cxa_find_matching_catch_2()|0;
                 $1424 = tempRet0;
                 $1425 = HEAP8[$501>>0]|0;
                 $1426 = ($1425<<24>>24)<(0);
                 if ($1426) {
                  $1427 = HEAP32[$18>>2]|0;
                  __ZdlPv($1427);
                 }
                 $1428 = HEAP8[$499>>0]|0;
                 $1429 = ($1428<<24>>24)<(0);
                 if (!($1429)) {
                  $$63 = $1423;$$6398 = $1424;
                  break L7;
                 }
                 $1430 = HEAP32[$17>>2]|0;
                 __ZdlPv($1430);
                 $$63 = $1423;$$6398 = $1424;
                 break L7;
                }
               } while(0);
               $1415 = ___cxa_find_matching_catch_2()|0;
               $1416 = tempRet0;
               $1417 = HEAP8[$486>>0]|0;
               $1418 = ($1417<<24>>24)<(0);
               if ($1418) {
                $1419 = HEAP32[$16>>2]|0;
                __ZdlPv($1419);
               }
               $1420 = HEAP8[$479>>0]|0;
               $1421 = ($1420<<24>>24)<(0);
               if (!($1421)) {
                $$63 = $1415;$$6398 = $1416;
                break L7;
               }
               $1422 = HEAP32[$15>>2]|0;
               __ZdlPv($1422);
               $$63 = $1415;$$6398 = $1416;
               break L7;
              }
             } while(0);
             $1407 = ___cxa_find_matching_catch_2()|0;
             $1408 = tempRet0;
             $1409 = HEAP8[$466>>0]|0;
             $1410 = ($1409<<24>>24)<(0);
             if ($1410) {
              $1411 = HEAP32[$14>>2]|0;
              __ZdlPv($1411);
             }
             $1412 = HEAP8[$459>>0]|0;
             $1413 = ($1412<<24>>24)<(0);
             if (!($1413)) {
              $$63 = $1407;$$6398 = $1408;
              break L7;
             }
             $1414 = HEAP32[$13>>2]|0;
             __ZdlPv($1414);
             $$63 = $1407;$$6398 = $1408;
             break L7;
            }
           } while(0);
           $1399 = ___cxa_find_matching_catch_2()|0;
           $1400 = tempRet0;
           $1401 = HEAP8[$446>>0]|0;
           $1402 = ($1401<<24>>24)<(0);
           if ($1402) {
            $1403 = HEAP32[$12>>2]|0;
            __ZdlPv($1403);
           }
           $1404 = HEAP8[$439>>0]|0;
           $1405 = ($1404<<24>>24)<(0);
           if (!($1405)) {
            $$63 = $1399;$$6398 = $1400;
            break L7;
           }
           $1406 = HEAP32[$11>>2]|0;
           __ZdlPv($1406);
           $$63 = $1399;$$6398 = $1400;
           break L7;
          }
         } while(0);
         $1391 = ___cxa_find_matching_catch_2()|0;
         $1392 = tempRet0;
         $1393 = HEAP8[$426>>0]|0;
         $1394 = ($1393<<24>>24)<(0);
         if ($1394) {
          $1395 = HEAP32[$10>>2]|0;
          __ZdlPv($1395);
         }
         $1396 = HEAP8[$419>>0]|0;
         $1397 = ($1396<<24>>24)<(0);
         if (!($1397)) {
          $$63 = $1391;$$6398 = $1392;
          break L7;
         }
         $1398 = HEAP32[$9>>2]|0;
         __ZdlPv($1398);
         $$63 = $1391;$$6398 = $1392;
         break L7;
        }
       }
      }
     } while(0);
     $280 = ___cxa_find_matching_catch_2()|0;
     $281 = tempRet0;
     $$63 = $280;$$6398 = $281;
    }
   } while(0);
   if ((label|0) == 17) {
    $191 = ___cxa_find_matching_catch_2()|0;
    $192 = tempRet0;
    $$63 = $191;$$6398 = $192;
   }
   $1945 = HEAP32[$153>>2]|0;
   $1946 = ($1945|0)==(0|0);
   if (!($1946)) {
    $1947 = ((($1945)) + 8|0);
    $1948 = HEAP32[$1947>>2]|0;HEAP32[$1947>>2] = (($1948-1)|0);
    $1949 = ($1948|0)==(1);
    if ($1949) {
     __THREW__ = 0;
     invoke_viii(3262,($1945|0),1,1);
     $1950 = __THREW__; __THREW__ = 0;
     $1951 = $1950&1;
     if ($1951) {
      $2162 = ___cxa_find_matching_catch_3(0|0)|0;
      $2163 = tempRet0;
      ___clang_call_terminate($2162);
      // unreachable;
     }
    }
   }
   HEAP32[$153>>2] = 0;
   $1952 = HEAP32[$152>>2]|0;
   $1953 = ($1952|0)==(0|0);
   if (!($1953)) {
    $1954 = ((($1952)) + 8|0);
    $1955 = HEAP32[$1954>>2]|0;HEAP32[$1954>>2] = (($1955-1)|0);
    $1956 = ($1955|0)==(1);
    if ($1956) {
     __THREW__ = 0;
     invoke_viii(3262,($1952|0),1,1);
     $1957 = __THREW__; __THREW__ = 0;
     $1958 = $1957&1;
     if ($1958) {
      $2162 = ___cxa_find_matching_catch_3(0|0)|0;
      $2163 = tempRet0;
      ___clang_call_terminate($2162);
      // unreachable;
     }
    }
   }
   HEAP32[$152>>2] = 0;
   $1959 = HEAP32[$151>>2]|0;
   $1960 = ($1959|0)==(0|0);
   if (!($1960)) {
    $1961 = HEAP32[$1959>>2]|0;
    $1962 = ((($1961)) + -12|0);
    $1963 = HEAP32[$1962>>2]|0;
    $1964 = (($1959) + ($1963)|0);
    $1965 = ((($1964)) + 8|0);
    $1966 = HEAP32[$1965>>2]|0;HEAP32[$1965>>2] = (($1966-1)|0);
    $1967 = ($1966|0)==(1);
    if ($1967) {
     __THREW__ = 0;
     invoke_viii(3262,($1964|0),1,1);
     $1968 = __THREW__; __THREW__ = 0;
     $1969 = $1968&1;
     if ($1969) {
      $2162 = ___cxa_find_matching_catch_3(0|0)|0;
      $2163 = tempRet0;
      ___clang_call_terminate($2162);
      // unreachable;
     }
    }
   }
   HEAP32[$151>>2] = 0;
   $1970 = HEAP32[$149>>2]|0;
   $1971 = ($1970|0)==(0|0);
   if (!($1971)) {
    $1972 = HEAP32[$150>>2]|0;
    $1973 = ($1972|0)==($1970|0);
    if ($1973) {
     $1982 = $1970;
    } else {
     $1975 = $1972;
     while(1) {
      $1974 = ((($1975)) + -12|0);
      HEAP32[$150>>2] = $1974;
      $1976 = ((($1974)) + 11|0);
      $1977 = HEAP8[$1976>>0]|0;
      $1978 = ($1977<<24>>24)<(0);
      if ($1978) {
       $1981 = HEAP32[$1974>>2]|0;
       __ZdlPv($1981);
       $$pre$i$i$i = HEAP32[$150>>2]|0;
       $1979 = $$pre$i$i$i;
      } else {
       $1979 = $1974;
      }
      $1980 = ($1979|0)==($1970|0);
      if ($1980) {
       break;
      } else {
       $1975 = $1979;
      }
     }
     $$pre$i1153 = HEAP32[$149>>2]|0;
     $1982 = $$pre$i1153;
    }
    __ZdlPv($1982);
   }
   $1983 = HEAP32[$148>>2]|0;
   $1984 = ($1983|0)==(0|0);
   if (!($1984)) {
    $1985 = ((($1983)) + 8|0);
    $1986 = HEAP32[$1985>>2]|0;HEAP32[$1985>>2] = (($1986-1)|0);
    $1987 = ($1986|0)==(1);
    if ($1987) {
     __THREW__ = 0;
     invoke_viii(3262,($1983|0),1,1);
     $1988 = __THREW__; __THREW__ = 0;
     $1989 = $1988&1;
     if ($1989) {
      $2162 = ___cxa_find_matching_catch_3(0|0)|0;
      $2163 = tempRet0;
      ___clang_call_terminate($2162);
      // unreachable;
     }
    }
   }
   HEAP32[$148>>2] = 0;
   __ZNSt3__212__deque_baseINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS4_IS6_EEE5clearEv($147);
   $1990 = ((($0)) + 192|0);
   $1991 = HEAP32[$1990>>2]|0;
   $1992 = ((($0)) + 196|0);
   $1993 = HEAP32[$1992>>2]|0;
   $1994 = ($1991|0)==($1993|0);
   if (!($1994)) {
    $$08$i = $1991;
    while(1) {
     $1995 = HEAP32[$$08$i>>2]|0;
     __ZdlPv($1995);
     $1996 = ((($$08$i)) + 4|0);
     $1997 = ($1996|0)==($1993|0);
     if ($1997) {
      break;
     } else {
      $$08$i = $1996;
     }
    }
    $$pre$i1155 = HEAP32[$1990>>2]|0;
    $$pre9$i = HEAP32[$1992>>2]|0;
    $1998 = ($$pre9$i|0)==($$pre$i1155|0);
    if (!($1998)) {
     $scevgep$i$i$i$i$i = ((($$pre9$i)) + -4|0);
     $1999 = $scevgep$i$i$i$i$i;
     $2000 = $$pre$i1155;
     $2001 = (($1999) - ($2000))|0;
     $2002 = $2001 >>> 2;
     $2003 = $2002 ^ -1;
     $scevgep5$i$i$i$i$i = (($$pre9$i) + ($2003<<2)|0);
     HEAP32[$1992>>2] = $scevgep5$i$i$i$i$i;
    }
   }
   $2004 = HEAP32[$147>>2]|0;
   $2005 = ($2004|0)==(0|0);
   if (!($2005)) {
    __ZdlPv($2004);
   }
   __ZNSt3__212__deque_baseINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS4_IS6_EEE5clearEv($146);
   $2006 = ((($0)) + 168|0);
   $2007 = HEAP32[$2006>>2]|0;
   $2008 = ((($0)) + 172|0);
   $2009 = HEAP32[$2008>>2]|0;
   $2010 = ($2007|0)==($2009|0);
   if (!($2010)) {
    $$08$i1156 = $2007;
    while(1) {
     $2011 = HEAP32[$$08$i1156>>2]|0;
     __ZdlPv($2011);
     $2012 = ((($$08$i1156)) + 4|0);
     $2013 = ($2012|0)==($2009|0);
     if ($2013) {
      break;
     } else {
      $$08$i1156 = $2012;
     }
    }
    $$pre$i1158 = HEAP32[$2006>>2]|0;
    $$pre9$i1159 = HEAP32[$2008>>2]|0;
    $2014 = ($$pre9$i1159|0)==($$pre$i1158|0);
    if (!($2014)) {
     $scevgep$i$i$i$i$i1161 = ((($$pre9$i1159)) + -4|0);
     $2015 = $scevgep$i$i$i$i$i1161;
     $2016 = $$pre$i1158;
     $2017 = (($2015) - ($2016))|0;
     $2018 = $2017 >>> 2;
     $2019 = $2018 ^ -1;
     $scevgep5$i$i$i$i$i1162 = (($$pre9$i1159) + ($2019<<2)|0);
     HEAP32[$2008>>2] = $scevgep5$i$i$i$i$i1162;
    }
   }
   $2020 = HEAP32[$146>>2]|0;
   $2021 = ($2020|0)==(0|0);
   if (!($2021)) {
    __ZdlPv($2020);
   }
   $2022 = HEAP32[$145>>2]|0;
   $2023 = ($2022|0)==(0|0);
   if (!($2023)) {
    $2024 = ((($2022)) + 8|0);
    $2025 = HEAP32[$2024>>2]|0;HEAP32[$2024>>2] = (($2025-1)|0);
    $2026 = ($2025|0)==(1);
    if ($2026) {
     __THREW__ = 0;
     invoke_viii(3262,($2022|0),1,1);
     $2027 = __THREW__; __THREW__ = 0;
     $2028 = $2027&1;
     if ($2028) {
      $2162 = ___cxa_find_matching_catch_3(0|0)|0;
      $2163 = tempRet0;
      ___clang_call_terminate($2162);
      // unreachable;
     }
    }
   }
   HEAP32[$145>>2] = 0;
   $2029 = HEAP32[$144>>2]|0;
   __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES7_EENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($141,$2029);
   $2030 = HEAP32[$140>>2]|0;
   __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES7_EENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($137,$2030);
   $2031 = HEAP32[$136>>2]|0;
   __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7ref_ptrIN5osgDB7ArchiveEEEEENS_19__map_value_compareIS7_SD_NS_4lessIS7_EELb1EEENS5_ISD_EEE7destroyEPNS_11__tree_nodeISD_PvEE($133,$2031);
   __THREW__ = 0;
   invoke_vi(707,($130|0));
   $2032 = __THREW__; __THREW__ = 0;
   $2033 = $2032&1;
   if ($2033) {
    $2162 = ___cxa_find_matching_catch_3(0|0)|0;
    $2163 = tempRet0;
    ___clang_call_terminate($2162);
    // unreachable;
   } else {
    $$70 = $$63;$$70105 = $$6398;
   }
  }
  $2034 = HEAP32[$128>>2]|0;
  $2035 = ($2034|0)==(0|0);
  if (!($2035)) {
   $2036 = HEAP32[$129>>2]|0;
   $2037 = ($2036|0)==($2034|0);
   do {
    if ($2037) {
     $2051 = $2034;
    } else {
     $2039 = $2036;
     while(1) {
      $2038 = ((($2039)) + -4|0);
      HEAP32[$129>>2] = $2038;
      $2040 = HEAP32[$2038>>2]|0;
      $2041 = ($2040|0)==(0|0);
      if (!($2041)) {
       $2042 = ((($2040)) + 8|0);
       $2043 = HEAP32[$2042>>2]|0;HEAP32[$2042>>2] = (($2043-1)|0);
       $2044 = ($2043|0)==(1);
       if ($2044) {
        __THREW__ = 0;
        invoke_viii(3262,($2040|0),1,1);
        $2045 = __THREW__; __THREW__ = 0;
        $2046 = $2045&1;
        if ($2046) {
         label = 706;
         break;
        }
       }
      }
      HEAP32[$2038>>2] = 0;
      $2047 = HEAP32[$129>>2]|0;
      $2048 = ($2047|0)==($2034|0);
      if ($2048) {
       label = 707;
       break;
      } else {
       $2039 = $2047;
      }
     }
     if ((label|0) == 706) {
      $2049 = ___cxa_find_matching_catch_2()|0;
      $2050 = tempRet0;
      ___cxa_call_unexpected(($2049|0));
      // unreachable;
     }
     else if ((label|0) == 707) {
      $$pre$i125 = HEAP32[$128>>2]|0;
      $2051 = $$pre$i125;
      break;
     }
    }
   } while(0);
   __ZdlPv($2051);
  }
  $2052 = HEAP32[$126>>2]|0;
  $2053 = ($2052|0)==(0|0);
  if (!($2053)) {
   $2054 = HEAP32[$127>>2]|0;
   $2055 = ($2054|0)==($2052|0);
   do {
    if ($2055) {
     $2069 = $2052;
    } else {
     $2057 = $2054;
     while(1) {
      $2056 = ((($2057)) + -4|0);
      HEAP32[$127>>2] = $2056;
      $2058 = HEAP32[$2056>>2]|0;
      $2059 = ($2058|0)==(0|0);
      if (!($2059)) {
       $2060 = ((($2058)) + 8|0);
       $2061 = HEAP32[$2060>>2]|0;HEAP32[$2060>>2] = (($2061-1)|0);
       $2062 = ($2061|0)==(1);
       if ($2062) {
        __THREW__ = 0;
        invoke_viii(3262,($2058|0),1,1);
        $2063 = __THREW__; __THREW__ = 0;
        $2064 = $2063&1;
        if ($2064) {
         label = 715;
         break;
        }
       }
      }
      HEAP32[$2056>>2] = 0;
      $2065 = HEAP32[$127>>2]|0;
      $2066 = ($2065|0)==($2052|0);
      if ($2066) {
       label = 716;
       break;
      } else {
       $2057 = $2065;
      }
     }
     if ((label|0) == 715) {
      $2067 = ___cxa_find_matching_catch_2()|0;
      $2068 = tempRet0;
      ___cxa_call_unexpected(($2067|0));
      // unreachable;
     }
     else if ((label|0) == 716) {
      $$pre$i122 = HEAP32[$126>>2]|0;
      $2069 = $$pre$i122;
      break;
     }
    }
   } while(0);
   __ZdlPv($2069);
  }
  $2070 = HEAP32[$124>>2]|0;
  $2071 = ($2070|0)==(0|0);
  if (!($2071)) {
   $2072 = HEAP32[$125>>2]|0;
   $2073 = ($2072|0)==($2070|0);
   do {
    if ($2073) {
     $2087 = $2070;
    } else {
     $2075 = $2072;
     while(1) {
      $2074 = ((($2075)) + -4|0);
      HEAP32[$125>>2] = $2074;
      $2076 = HEAP32[$2074>>2]|0;
      $2077 = ($2076|0)==(0|0);
      if (!($2077)) {
       $2078 = ((($2076)) + 8|0);
       $2079 = HEAP32[$2078>>2]|0;HEAP32[$2078>>2] = (($2079-1)|0);
       $2080 = ($2079|0)==(1);
       if ($2080) {
        __THREW__ = 0;
        invoke_viii(3262,($2076|0),1,1);
        $2081 = __THREW__; __THREW__ = 0;
        $2082 = $2081&1;
        if ($2082) {
         label = 724;
         break;
        }
       }
      }
      HEAP32[$2074>>2] = 0;
      $2083 = HEAP32[$125>>2]|0;
      $2084 = ($2083|0)==($2070|0);
      if ($2084) {
       label = 725;
       break;
      } else {
       $2075 = $2083;
      }
     }
     if ((label|0) == 724) {
      $2085 = ___cxa_find_matching_catch_2()|0;
      $2086 = tempRet0;
      ___cxa_call_unexpected(($2085|0));
      // unreachable;
     }
     else if ((label|0) == 725) {
      $$pre$i = HEAP32[$124>>2]|0;
      $2087 = $$pre$i;
      break;
     }
    }
   } while(0);
   __ZdlPv($2087);
  }
  __THREW__ = 0;
  invoke_vi(707,($121|0));
  $2088 = __THREW__; __THREW__ = 0;
  $2089 = $2088&1;
  if ($2089) {
   $2162 = ___cxa_find_matching_catch_3(0|0)|0;
   $2163 = tempRet0;
   ___clang_call_terminate($2162);
   // unreachable;
  } else {
   $$74 = $$70;$$74109 = $$70105;
  }
 }
 $2090 = HEAP32[$120>>2]|0;
 $2091 = ($2090|0)==(0|0);
 if (!($2091)) {
  $2092 = HEAP32[$2090>>2]|0;
  $2093 = ((($2092)) + -12|0);
  $2094 = HEAP32[$2093>>2]|0;
  $2095 = (($2090) + ($2094)|0);
  $2096 = ((($2095)) + 8|0);
  $2097 = HEAP32[$2096>>2]|0;HEAP32[$2096>>2] = (($2097-1)|0);
  $2098 = ($2097|0)==(1);
  if ($2098) {
   __THREW__ = 0;
   invoke_viii(3262,($2095|0),1,1);
   $2099 = __THREW__; __THREW__ = 0;
   $2100 = $2099&1;
   if ($2100) {
    $2162 = ___cxa_find_matching_catch_3(0|0)|0;
    $2163 = tempRet0;
    ___clang_call_terminate($2162);
    // unreachable;
   }
  }
 }
 HEAP32[$120>>2] = 0;
 $2101 = HEAP32[$119>>2]|0;
 $2102 = ($2101|0)==(0|0);
 if (!($2102)) {
  $2103 = HEAP32[$2101>>2]|0;
  $2104 = ((($2103)) + -12|0);
  $2105 = HEAP32[$2104>>2]|0;
  $2106 = (($2101) + ($2105)|0);
  $2107 = ((($2106)) + 8|0);
  $2108 = HEAP32[$2107>>2]|0;HEAP32[$2107>>2] = (($2108-1)|0);
  $2109 = ($2108|0)==(1);
  if ($2109) {
   __THREW__ = 0;
   invoke_viii(3262,($2106|0),1,1);
   $2110 = __THREW__; __THREW__ = 0;
   $2111 = $2110&1;
   if ($2111) {
    $2162 = ___cxa_find_matching_catch_3(0|0)|0;
    $2163 = tempRet0;
    ___clang_call_terminate($2162);
    // unreachable;
   }
  }
 }
 HEAP32[$119>>2] = 0;
 $2112 = HEAP32[$118>>2]|0;
 $2113 = ($2112|0)==(0|0);
 if (!($2113)) {
  $2114 = HEAP32[$2112>>2]|0;
  $2115 = ((($2114)) + -12|0);
  $2116 = HEAP32[$2115>>2]|0;
  $2117 = (($2112) + ($2116)|0);
  $2118 = ((($2117)) + 8|0);
  $2119 = HEAP32[$2118>>2]|0;HEAP32[$2118>>2] = (($2119-1)|0);
  $2120 = ($2119|0)==(1);
  if ($2120) {
   __THREW__ = 0;
   invoke_viii(3262,($2117|0),1,1);
   $2121 = __THREW__; __THREW__ = 0;
   $2122 = $2121&1;
   if ($2122) {
    $2162 = ___cxa_find_matching_catch_3(0|0)|0;
    $2163 = tempRet0;
    ___clang_call_terminate($2162);
    // unreachable;
   }
  }
 }
 HEAP32[$118>>2] = 0;
 $2123 = HEAP32[$117>>2]|0;
 $2124 = ($2123|0)==(0|0);
 if (!($2124)) {
  $2125 = HEAP32[$2123>>2]|0;
  $2126 = ((($2125)) + -12|0);
  $2127 = HEAP32[$2126>>2]|0;
  $2128 = (($2123) + ($2127)|0);
  $2129 = ((($2128)) + 8|0);
  $2130 = HEAP32[$2129>>2]|0;HEAP32[$2129>>2] = (($2130-1)|0);
  $2131 = ($2130|0)==(1);
  if ($2131) {
   __THREW__ = 0;
   invoke_viii(3262,($2128|0),1,1);
   $2132 = __THREW__; __THREW__ = 0;
   $2133 = $2132&1;
   if ($2133) {
    $2162 = ___cxa_find_matching_catch_3(0|0)|0;
    $2163 = tempRet0;
    ___clang_call_terminate($2162);
    // unreachable;
   }
  }
 }
 HEAP32[$117>>2] = 0;
 $2134 = HEAP32[$116>>2]|0;
 __ZNSt3__26__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EENS4_IS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($113,$2134);
 $2135 = HEAP32[$112>>2]|0;
 $2136 = ($2135|0)==(0|0);
 if (!($2136)) {
  $2137 = ((($2135)) + 8|0);
  $2138 = HEAP32[$2137>>2]|0;HEAP32[$2137>>2] = (($2138-1)|0);
  $2139 = ($2138|0)==(1);
  if ($2139) {
   __THREW__ = 0;
   invoke_viii(3262,($2135|0),1,1);
   $2140 = __THREW__; __THREW__ = 0;
   $2141 = $2140&1;
   if ($2141) {
    $2162 = ___cxa_find_matching_catch_3(0|0)|0;
    $2163 = tempRet0;
    ___clang_call_terminate($2162);
    // unreachable;
   }
  }
 }
 HEAP32[$112>>2] = 0;
 $2142 = HEAP32[$111>>2]|0;
 $2143 = ($2142|0)==(0|0);
 if (!($2143)) {
  $2144 = ((($2142)) + 8|0);
  $2145 = HEAP32[$2144>>2]|0;HEAP32[$2144>>2] = (($2145-1)|0);
  $2146 = ($2145|0)==(1);
  if ($2146) {
   __THREW__ = 0;
   invoke_viii(3262,($2142|0),1,1);
   $2147 = __THREW__; __THREW__ = 0;
   $2148 = $2147&1;
   if ($2148) {
    $2162 = ___cxa_find_matching_catch_3(0|0)|0;
    $2163 = tempRet0;
    ___clang_call_terminate($2162);
    // unreachable;
   }
  }
 }
 HEAP32[$111>>2] = 0;
 $2149 = HEAP32[$110>>2]|0;
 $2150 = ($2149|0)==(0|0);
 if (!($2150)) {
  $2151 = HEAP32[$2149>>2]|0;
  $2152 = ((($2151)) + -12|0);
  $2153 = HEAP32[$2152>>2]|0;
  $2154 = (($2149) + ($2153)|0);
  $2155 = ((($2154)) + 8|0);
  $2156 = HEAP32[$2155>>2]|0;HEAP32[$2155>>2] = (($2156-1)|0);
  $2157 = ($2156|0)==(1);
  if ($2157) {
   __THREW__ = 0;
   invoke_viii(3262,($2154|0),1,1);
   $2158 = __THREW__; __THREW__ = 0;
   $2159 = $2158&1;
   if ($2159) {
    $2162 = ___cxa_find_matching_catch_3(0|0)|0;
    $2163 = tempRet0;
    ___clang_call_terminate($2162);
    // unreachable;
   }
  }
 }
 HEAP32[$110>>2] = 0;
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $2160 = __THREW__; __THREW__ = 0;
 $2161 = $2160&1;
 if ($2161) {
  $2162 = ___cxa_find_matching_catch_3(0|0)|0;
  $2163 = tempRet0;
  ___clang_call_terminate($2162);
  // unreachable;
 } else {
  ___resumeException($$74|0);
  // unreachable;
 }
}
function __ZN3osg7ref_ptrIN5osgDB8RegistryEED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = ((($1)) + 8|0);
  $4 = HEAP32[$3>>2]|0;HEAP32[$3>>2] = (($4-1)|0);
  $5 = ($4|0)==(1);
  if ($5) {
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($1,1,1);
  }
 }
 HEAP32[$0>>2] = 0;
 return;
}
function __ZN5osgDB8Registry20initDataFilePathListEv($0) {
 $0 = $0|0;
 var $$0 = 0, $$016$i$i = 0, $$016$i$i12 = 0, $$017$i$i = 0, $$017$i$i13 = 0, $$06 = 0, $$08$i = 0, $$08$i20 = 0, $$1 = 0, $$17 = 0, $$2 = 0, $$28 = 0, $$byval_copy = 0, $$byval_copy1 = 0, $$cast$i = 0, $$cast$i42 = 0, $$in = 0, $$in$i = 0, $$in$i41 = 0, $$in55 = 0;
 var $$lcssa$i = 0, $$lcssa$i44 = 0, $$pre = 0, $$pre$i = 0, $$pre$i22 = 0, $$pre$phi52Z2D = 0, $$pre$phi54Z2D = 0, $$pre51 = 0, $$pre53 = 0, $$pre9$i = 0, $$pre9$i23 = 0, $$sink$i = 0, $$sink$i46 = 0, $$sroa$011$0$ph$i = 0, $$sroa$011$0$ph$i35 = 0, $$sroa$6$0$i = 0, $$sroa$6$0$i38 = 0, $$sroa$6$0$ph$i = 0, $$sroa$6$0$ph$i36 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0;
 var $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0;
 var $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0;
 var $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0;
 var $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0;
 var $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0;
 var $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $phitmp$i = 0, $phitmp$i33 = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i25 = 0, $scevgep5$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i26 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(80|0);
 $$byval_copy1 = sp + 72|0;
 $$byval_copy = sp + 64|0;
 $1 = sp + 56|0;
 $2 = sp + 48|0;
 $3 = sp + 24|0;
 $4 = sp + 12|0;
 $5 = sp;
 ;HEAP32[$3>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;HEAP32[$3+12>>2]=0|0;HEAP32[$3+16>>2]=0|0;HEAP32[$3+20>>2]=0|0;
 $6 = (_getenv((167487|0))|0);
 $7 = ($6|0)==(0|0);
 L1: do {
  if ($7) {
   $40 = (_getenv((167501|0))|0);
   $41 = ($40|0)==(0|0);
   if ($41) {
    label = 34;
   } else {
    ;HEAP32[$5>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;
    $42 = (_strlen($40)|0);
    $43 = ($42>>>0)>(4294967279);
    do {
     if ($43) {
      __THREW__ = 0;
      invoke_vi(3367,($5|0));
      $44 = __THREW__; __THREW__ = 0;
      label = 30;
     } else {
      $45 = ($42>>>0)<(11);
      if ($45) {
       $54 = $42&255;
       $55 = ((($5)) + 11|0);
       HEAP8[$55>>0] = $54;
       $56 = ($42|0)==(0);
       if ($56) {
        $$017$i$i13 = $5;
       } else {
        $$016$i$i12 = $5;
        label = 25;
       }
      } else {
       $46 = (($42) + 16)|0;
       $47 = $46 & -16;
       __THREW__ = 0;
       $48 = (invoke_ii(3276,($47|0))|0);
       $49 = __THREW__; __THREW__ = 0;
       $50 = $49&1;
       if ($50) {
        label = 30;
        break;
       }
       HEAP32[$5>>2] = $48;
       $51 = $47 | -2147483648;
       $52 = ((($5)) + 8|0);
       HEAP32[$52>>2] = $51;
       $53 = ((($5)) + 4|0);
       HEAP32[$53>>2] = $42;
       $$016$i$i12 = $48;
       label = 25;
      }
      if ((label|0) == 25) {
       _memcpy(($$016$i$i12|0),($40|0),($42|0))|0;
       $$017$i$i13 = $$016$i$i12;
      }
      $57 = (($$017$i$i13) + ($42)|0);
      HEAP8[$57>>0] = 0;
      __THREW__ = 0;
      invoke_vii(4187,($5|0),($3|0));
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       $66 = ___cxa_find_matching_catch_2()|0;
       $67 = tempRet0;
       $68 = ((($5)) + 11|0);
       $69 = HEAP8[$68>>0]|0;
       $70 = ($69<<24>>24)<(0);
       if (!($70)) {
        $$1 = $67;$$17 = $66;
        break;
       }
       $71 = HEAP32[$5>>2]|0;
       __ZdlPv($71);
       $$1 = $67;$$17 = $66;
       break;
      }
      $60 = ((($5)) + 11|0);
      $61 = HEAP8[$60>>0]|0;
      $62 = ($61<<24>>24)<(0);
      if ($62) {
       $63 = HEAP32[$5>>2]|0;
       __ZdlPv($63);
      }
      label = 34;
      break L1;
     }
    } while(0);
    if ((label|0) == 30) {
     $64 = ___cxa_find_matching_catch_2()|0;
     $65 = tempRet0;
     $$1 = $65;$$17 = $64;
    }
    $$2 = $$1;$$28 = $$17;
   }
  } else {
   ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;
   $8 = (_strlen($6)|0);
   $9 = ($8>>>0)>(4294967279);
   do {
    if ($9) {
     __THREW__ = 0;
     invoke_vi(3367,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     label = 14;
    } else {
     $11 = ($8>>>0)<(11);
     if ($11) {
      $20 = $8&255;
      $21 = ((($4)) + 11|0);
      HEAP8[$21>>0] = $20;
      $22 = ($8|0)==(0);
      if ($22) {
       $$017$i$i = $4;
      } else {
       $$016$i$i = $4;
       label = 8;
      }
     } else {
      $12 = (($8) + 16)|0;
      $13 = $12 & -16;
      __THREW__ = 0;
      $14 = (invoke_ii(3276,($13|0))|0);
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if ($16) {
       label = 14;
       break;
      }
      HEAP32[$4>>2] = $14;
      $17 = $13 | -2147483648;
      $18 = ((($4)) + 8|0);
      HEAP32[$18>>2] = $17;
      $19 = ((($4)) + 4|0);
      HEAP32[$19>>2] = $8;
      $$016$i$i = $14;
      label = 8;
     }
     if ((label|0) == 8) {
      _memcpy(($$016$i$i|0),($6|0),($8|0))|0;
      $$017$i$i = $$016$i$i;
     }
     $23 = (($$017$i$i) + ($8)|0);
     HEAP8[$23>>0] = 0;
     __THREW__ = 0;
     invoke_vii(4187,($4|0),($3|0));
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if ($25) {
      $34 = ___cxa_find_matching_catch_2()|0;
      $35 = tempRet0;
      $36 = ((($4)) + 11|0);
      $37 = HEAP8[$36>>0]|0;
      $38 = ($37<<24>>24)<(0);
      if (!($38)) {
       $$0 = $35;$$06 = $34;
       break;
      }
      $39 = HEAP32[$4>>2]|0;
      __ZdlPv($39);
      $$0 = $35;$$06 = $34;
      break;
     }
     $26 = ((($4)) + 11|0);
     $27 = HEAP8[$26>>0]|0;
     $28 = ($27<<24>>24)<(0);
     if ($28) {
      $29 = HEAP32[$4>>2]|0;
      __ZdlPv($29);
     }
     label = 34;
     break L1;
    }
   } while(0);
   if ((label|0) == 14) {
    $32 = ___cxa_find_matching_catch_2()|0;
    $33 = tempRet0;
    $$0 = $33;$$06 = $32;
   }
   $$2 = $$0;$$28 = $$06;
  }
 } while(0);
 if ((label|0) == 34) {
  __THREW__ = 0;
  $72 = __THREW__; __THREW__ = 0;
  $73 = $72&1;
  do {
   if (!($73)) {
    $74 = ((($0)) + 164|0);
    $75 = ($74|0)==($3|0);
    $$pre = ((($3)) + 4|0);
    if ($75) {
     $$pre51 = ((($3)) + 16|0);
     $$pre53 = ((($3)) + 8|0);
     $$pre$phi52Z2D = $$pre51;$$pre$phi54Z2D = $$pre53;
    } else {
     $76 = HEAP32[$$pre>>2]|0;
     $77 = ((($3)) + 16|0);
     $78 = HEAP32[$77>>2]|0;
     $79 = (($78>>>0) / 341)&-1;
     $80 = (($76) + ($79<<2)|0);
     $81 = ((($3)) + 8|0);
     $82 = HEAP32[$81>>2]|0;
     $83 = ($82|0)==($76|0);
     if ($83) {
      $88 = 0;
     } else {
      $84 = HEAP32[$80>>2]|0;
      $85 = (($78>>>0) % 341)&-1;
      $86 = (($84) + (($85*12)|0)|0);
      $88 = $86;
     }
     HEAP32[$1>>2] = $80;
     $87 = ((($1)) + 4|0);
     HEAP32[$87>>2] = $88;
     $89 = ((($3)) + 20|0);
     $90 = HEAP32[$89>>2]|0;
     $91 = (($90) + ($78))|0;
     $92 = (($91>>>0) / 341)&-1;
     $93 = (($76) + ($92<<2)|0);
     if ($83) {
      $98 = 0;
     } else {
      $94 = HEAP32[$93>>2]|0;
      $95 = (($91>>>0) % 341)&-1;
      $96 = (($94) + (($95*12)|0)|0);
      $98 = $96;
     }
     HEAP32[$2>>2] = $93;
     $97 = ((($2)) + 4|0);
     HEAP32[$97>>2] = $98;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy>>2]=HEAP32[$1>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;
     ;HEAP32[$$byval_copy1>>2]=HEAP32[$2>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$2+4>>2]|0;
     invoke_viiii(4188,($74|0),($$byval_copy|0),($$byval_copy1|0),(0|0));
     $99 = __THREW__; __THREW__ = 0;
     $100 = $99&1;
     if ($100) {
      break;
     } else {
      $$pre$phi52Z2D = $77;$$pre$phi54Z2D = $81;
     }
    }
    $101 = HEAP32[$$pre>>2]|0;
    $102 = HEAP32[$$pre$phi52Z2D>>2]|0;
    $103 = (($102>>>0) / 341)&-1;
    $104 = (($101) + ($103<<2)|0);
    $105 = HEAP32[$$pre$phi54Z2D>>2]|0;
    $106 = ($105|0)==($101|0);
    if ($106) {
     $107 = ((($3)) + 20|0);
     $121 = 0;$122 = $107;$228 = 0;
    } else {
     $108 = HEAP32[$104>>2]|0;
     $109 = (($102>>>0) % 341)&-1;
     $110 = (($108) + (($109*12)|0)|0);
     $phitmp$i = $110;
     $111 = ((($3)) + 20|0);
     $112 = HEAP32[$111>>2]|0;
     $113 = (($112) + ($102))|0;
     $114 = (($113>>>0) / 341)&-1;
     $115 = (($101) + ($114<<2)|0);
     $116 = HEAP32[$115>>2]|0;
     $117 = (($113>>>0) % 341)&-1;
     $118 = (($116) + (($117*12)|0)|0);
     $121 = $118;$122 = $111;$228 = $phitmp$i;
    }
    $$sroa$011$0$ph$i = $104;$$sroa$6$0$ph$i = $228;
    L63: while(1) {
     $$sroa$6$0$i = $$sroa$6$0$ph$i;
     while(1) {
      $119 = $$sroa$6$0$i;
      $120 = ($119|0)==($121|0);
      if ($120) {
       break L63;
      }
      $129 = $$sroa$6$0$i;
      $130 = ((($129)) + 11|0);
      $131 = HEAP8[$130>>0]|0;
      $132 = ($131<<24>>24)<(0);
      if ($132) {
       $133 = HEAP32[$119>>2]|0;
       __ZdlPv($133);
      }
      $134 = ((($119)) + 12|0);
      $135 = $134;
      $136 = HEAP32[$$sroa$011$0$ph$i>>2]|0;
      $137 = (($135) - ($136))|0;
      $138 = ($137|0)==(4092);
      if ($138) {
       break;
      } else {
       $$sroa$6$0$i = $135;
      }
     }
     $139 = ((($$sroa$011$0$ph$i)) + 4|0);
     $140 = HEAP32[$139>>2]|0;
     $$sroa$011$0$ph$i = $139;$$sroa$6$0$ph$i = $140;
    }
    HEAP32[$122>>2] = 0;
    $123 = HEAP32[$$pre$phi54Z2D>>2]|0;
    $124 = HEAP32[$$pre>>2]|0;
    $125 = (($123) - ($124))|0;
    $126 = $125 >> 2;
    $127 = ($126>>>0)>(2);
    $128 = $124;
    if ($127) {
     $$in$i = $124;
     while(1) {
      $141 = $$in$i;
      $142 = HEAP32[$141>>2]|0;
      __ZdlPv($142);
      $143 = HEAP32[$$pre>>2]|0;
      $144 = ((($143)) + 4|0);
      HEAP32[$$pre>>2] = $144;
      $145 = HEAP32[$$pre$phi54Z2D>>2]|0;
      $$cast$i = $144;
      $146 = (($145) - ($$cast$i))|0;
      $147 = $146 >> 2;
      $148 = ($147>>>0)>(2);
      if ($148) {
       $$in$i = $$cast$i;
      } else {
       $$in55 = $145;$$lcssa$i = $147;$150 = $144;
       break;
      }
     }
    } else {
     $$in55 = $123;$$lcssa$i = $126;$150 = $128;
    }
    $149 = $$in55;
    switch ($$lcssa$i|0) {
    case 1:  {
     $$sink$i = 170;
     label = 56;
     break;
    }
    case 2:  {
     $$sink$i = 341;
     label = 56;
     break;
    }
    default: {
    }
    }
    if ((label|0) == 56) {
     HEAP32[$$pre$phi52Z2D>>2] = $$sink$i;
    }
    $151 = ($150|0)==($149|0);
    if (!($151)) {
     $$08$i = $150;
     while(1) {
      $152 = HEAP32[$$08$i>>2]|0;
      __ZdlPv($152);
      $153 = ((($$08$i)) + 4|0);
      $154 = ($153|0)==($149|0);
      if ($154) {
       break;
      } else {
       $$08$i = $153;
      }
     }
     $$pre$i = HEAP32[$$pre>>2]|0;
     $$pre9$i = HEAP32[$$pre$phi54Z2D>>2]|0;
     $155 = ($$pre9$i|0)==($$pre$i|0);
     if (!($155)) {
      $scevgep$i$i$i$i$i = ((($$pre9$i)) + -4|0);
      $156 = $scevgep$i$i$i$i$i;
      $157 = $$pre$i;
      $158 = (($156) - ($157))|0;
      $159 = $158 >>> 2;
      $160 = $159 ^ -1;
      $scevgep5$i$i$i$i$i = (($$pre9$i) + ($160<<2)|0);
      HEAP32[$$pre$phi54Z2D>>2] = $scevgep5$i$i$i$i$i;
     }
    }
    $161 = HEAP32[$3>>2]|0;
    $162 = ($161|0)==(0|0);
    if ($162) {
     STACKTOP = sp;return;
    }
    __ZdlPv($161);
    STACKTOP = sp;return;
   }
  } while(0);
  $30 = ___cxa_find_matching_catch_2()|0;
  $31 = tempRet0;
  $$2 = $31;$$28 = $30;
 }
 $163 = ((($3)) + 4|0);
 $164 = HEAP32[$163>>2]|0;
 $165 = ((($3)) + 16|0);
 $166 = HEAP32[$165>>2]|0;
 $167 = (($166>>>0) / 341)&-1;
 $168 = (($164) + ($167<<2)|0);
 $169 = ((($3)) + 8|0);
 $170 = HEAP32[$169>>2]|0;
 $171 = ($170|0)==($164|0);
 if ($171) {
  $172 = ((($3)) + 20|0);
  $186 = 0;$187 = $172;$229 = 0;
 } else {
  $173 = HEAP32[$168>>2]|0;
  $174 = (($166>>>0) % 341)&-1;
  $175 = (($173) + (($174*12)|0)|0);
  $phitmp$i33 = $175;
  $176 = ((($3)) + 20|0);
  $177 = HEAP32[$176>>2]|0;
  $178 = (($177) + ($166))|0;
  $179 = (($178>>>0) / 341)&-1;
  $180 = (($164) + ($179<<2)|0);
  $181 = HEAP32[$180>>2]|0;
  $182 = (($178>>>0) % 341)&-1;
  $183 = (($181) + (($182*12)|0)|0);
  $186 = $183;$187 = $176;$229 = $phitmp$i33;
 }
 $$sroa$011$0$ph$i35 = $168;$$sroa$6$0$ph$i36 = $229;
 L98: while(1) {
  $$sroa$6$0$i38 = $$sroa$6$0$ph$i36;
  while(1) {
   $184 = $$sroa$6$0$i38;
   $185 = ($184|0)==($186|0);
   if ($185) {
    break L98;
   }
   $194 = $$sroa$6$0$i38;
   $195 = ((($194)) + 11|0);
   $196 = HEAP8[$195>>0]|0;
   $197 = ($196<<24>>24)<(0);
   if ($197) {
    $198 = HEAP32[$184>>2]|0;
    __ZdlPv($198);
   }
   $199 = ((($184)) + 12|0);
   $200 = $199;
   $201 = HEAP32[$$sroa$011$0$ph$i35>>2]|0;
   $202 = (($200) - ($201))|0;
   $203 = ($202|0)==(4092);
   if ($203) {
    break;
   } else {
    $$sroa$6$0$i38 = $200;
   }
  }
  $204 = ((($$sroa$011$0$ph$i35)) + 4|0);
  $205 = HEAP32[$204>>2]|0;
  $$sroa$011$0$ph$i35 = $204;$$sroa$6$0$ph$i36 = $205;
 }
 HEAP32[$187>>2] = 0;
 $188 = HEAP32[$169>>2]|0;
 $189 = HEAP32[$163>>2]|0;
 $190 = (($188) - ($189))|0;
 $191 = $190 >> 2;
 $192 = ($191>>>0)>(2);
 $193 = $189;
 if ($192) {
  $$in$i41 = $189;
  while(1) {
   $206 = $$in$i41;
   $207 = HEAP32[$206>>2]|0;
   __ZdlPv($207);
   $208 = HEAP32[$163>>2]|0;
   $209 = ((($208)) + 4|0);
   HEAP32[$163>>2] = $209;
   $210 = HEAP32[$169>>2]|0;
   $$cast$i42 = $209;
   $211 = (($210) - ($$cast$i42))|0;
   $212 = $211 >> 2;
   $213 = ($212>>>0)>(2);
   if ($213) {
    $$in$i41 = $$cast$i42;
   } else {
    $$in = $210;$$lcssa$i44 = $212;$215 = $209;
    break;
   }
  }
 } else {
  $$in = $188;$$lcssa$i44 = $191;$215 = $193;
 }
 $214 = $$in;
 switch ($$lcssa$i44|0) {
 case 1:  {
  $$sink$i46 = 170;
  label = 78;
  break;
 }
 case 2:  {
  $$sink$i46 = 341;
  label = 78;
  break;
 }
 default: {
 }
 }
 if ((label|0) == 78) {
  HEAP32[$165>>2] = $$sink$i46;
 }
 $216 = ($215|0)==($214|0);
 if (!($216)) {
  $$08$i20 = $215;
  while(1) {
   $217 = HEAP32[$$08$i20>>2]|0;
   __ZdlPv($217);
   $218 = ((($$08$i20)) + 4|0);
   $219 = ($218|0)==($214|0);
   if ($219) {
    break;
   } else {
    $$08$i20 = $218;
   }
  }
  $$pre$i22 = HEAP32[$163>>2]|0;
  $$pre9$i23 = HEAP32[$169>>2]|0;
  $220 = ($$pre9$i23|0)==($$pre$i22|0);
  if (!($220)) {
   $scevgep$i$i$i$i$i25 = ((($$pre9$i23)) + -4|0);
   $221 = $scevgep$i$i$i$i$i25;
   $222 = $$pre$i22;
   $223 = (($221) - ($222))|0;
   $224 = $223 >>> 2;
   $225 = $224 ^ -1;
   $scevgep5$i$i$i$i$i26 = (($$pre9$i23) + ($225<<2)|0);
   HEAP32[$169>>2] = $scevgep5$i$i$i$i$i26;
  }
 }
 $226 = HEAP32[$3>>2]|0;
 $227 = ($226|0)==(0|0);
 if ($227) {
  ___resumeException($$28|0);
  // unreachable;
 }
 __ZdlPv($226);
 ___resumeException($$28|0);
 // unreachable;
}
function __ZN5osgDB8Registry23initLibraryFilePathListEv($0) {
 $0 = $0|0;
 var $$0 = 0, $$016$i$i = 0, $$016$i$i9 = 0, $$017$i$i = 0, $$017$i$i10 = 0, $$06 = 0, $$pre = 0, $$pre$phiZ2D = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $1 = sp + 12|0;
 $2 = sp;
 $3 = (_getenv((167450|0))|0);
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  ;HEAP32[$1>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;
  $5 = (_strlen($3)|0);
  $6 = ($5>>>0)>(4294967279);
  if ($6) {
   __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv($1);
   // unreachable;
  }
  $7 = ($5>>>0)<(11);
  if ($7) {
   $14 = $5&255;
   $15 = ((($1)) + 11|0);
   HEAP8[$15>>0] = $14;
   $16 = ($5|0)==(0);
   if ($16) {
    $$017$i$i = $1;
   } else {
    $$016$i$i = $1;
    label = 7;
   }
  } else {
   $8 = (($5) + 16)|0;
   $9 = $8 & -16;
   $10 = (__Znwj($9)|0);
   HEAP32[$1>>2] = $10;
   $11 = $9 | -2147483648;
   $12 = ((($1)) + 8|0);
   HEAP32[$12>>2] = $11;
   $13 = ((($1)) + 4|0);
   HEAP32[$13>>2] = $5;
   $$016$i$i = $10;
   label = 7;
  }
  if ((label|0) == 7) {
   _memcpy(($$016$i$i|0),($3|0),($5|0))|0;
   $$017$i$i = $$016$i$i;
  }
  $17 = (($$017$i$i) + ($5)|0);
  HEAP8[$17>>0] = 0;
  $18 = ((($0)) + 188|0);
  __ZNSt3__212__deque_baseINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS4_IS6_EEE5clearEv($18);
  __THREW__ = 0;
  invoke_vii(4187,($1|0),($18|0));
  $19 = __THREW__; __THREW__ = 0;
  $20 = $19&1;
  if ($20) {
   $25 = ___cxa_find_matching_catch_2()|0;
   $26 = tempRet0;
   $27 = ((($1)) + 11|0);
   $28 = HEAP8[$27>>0]|0;
   $29 = ($28<<24>>24)<(0);
   if ($29) {
    $30 = HEAP32[$1>>2]|0;
    __ZdlPv($30);
   }
   $$0 = $26;$$06 = $25;
   ___resumeException($$06|0);
   // unreachable;
  } else {
   $21 = ((($1)) + 11|0);
   $22 = HEAP8[$21>>0]|0;
   $23 = ($22<<24>>24)<(0);
   if ($23) {
    $24 = HEAP32[$1>>2]|0;
    __ZdlPv($24);
   }
   $$pre$phiZ2D = $18;
   __ZN5osgDB38appendPlatformSpecificLibraryFilePathsERNSt3__25dequeINS0_12basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEENS5_IS7_EEEE($$pre$phiZ2D);
   STACKTOP = sp;return;
  }
 }
 $31 = (_getenv((167467|0))|0);
 $32 = ($31|0)==(0|0);
 if ($32) {
  $$pre = ((($0)) + 188|0);
  $$pre$phiZ2D = $$pre;
  __ZN5osgDB38appendPlatformSpecificLibraryFilePathsERNSt3__25dequeINS0_12basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEENS5_IS7_EEEE($$pre$phiZ2D);
  STACKTOP = sp;return;
 }
 ;HEAP32[$2>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;
 $33 = (_strlen($31)|0);
 $34 = ($33>>>0)>(4294967279);
 if ($34) {
  __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv($2);
  // unreachable;
 }
 $35 = ($33>>>0)<(11);
 if ($35) {
  $42 = $33&255;
  $43 = ((($2)) + 11|0);
  HEAP8[$43>>0] = $42;
  $44 = ($33|0)==(0);
  if ($44) {
   $$017$i$i10 = $2;
  } else {
   $$016$i$i9 = $2;
   label = 22;
  }
 } else {
  $36 = (($33) + 16)|0;
  $37 = $36 & -16;
  $38 = (__Znwj($37)|0);
  HEAP32[$2>>2] = $38;
  $39 = $37 | -2147483648;
  $40 = ((($2)) + 8|0);
  HEAP32[$40>>2] = $39;
  $41 = ((($2)) + 4|0);
  HEAP32[$41>>2] = $33;
  $$016$i$i9 = $38;
  label = 22;
 }
 if ((label|0) == 22) {
  _memcpy(($$016$i$i9|0),($31|0),($33|0))|0;
  $$017$i$i10 = $$016$i$i9;
 }
 $45 = (($$017$i$i10) + ($33)|0);
 HEAP8[$45>>0] = 0;
 $46 = ((($0)) + 188|0);
 __ZNSt3__212__deque_baseINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS4_IS6_EEE5clearEv($46);
 __THREW__ = 0;
 invoke_vii(4187,($2|0),($46|0));
 $47 = __THREW__; __THREW__ = 0;
 $48 = $47&1;
 if ($48) {
  $53 = ___cxa_find_matching_catch_2()|0;
  $54 = tempRet0;
  $55 = ((($2)) + 11|0);
  $56 = HEAP8[$55>>0]|0;
  $57 = ($56<<24>>24)<(0);
  if ($57) {
   $58 = HEAP32[$2>>2]|0;
   __ZdlPv($58);
  }
  $$0 = $54;$$06 = $53;
  ___resumeException($$06|0);
  // unreachable;
 } else {
  $49 = ((($2)) + 11|0);
  $50 = HEAP8[$49>>0]|0;
  $51 = ($50<<24>>24)<(0);
  if ($51) {
   $52 = HEAP32[$2>>2]|0;
   __ZdlPv($52);
  }
  $$pre$phiZ2D = $46;
  __ZN5osgDB38appendPlatformSpecificLibraryFilePathsERNSt3__25dequeINS0_12basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEENS5_IS7_EEEE($$pre$phiZ2D);
  STACKTOP = sp;return;
 }
}
function __ZN5osgDB8Registry16registerProtocolERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$pre$i$i$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp + 12|0;
 $3 = sp;
 $4 = ((($0)) + 32|0);
 __ZN5osgDB18convertToLowerCaseERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE($3,$1);
 __THREW__ = 0;
 $5 = (invoke_iiii(3784,($4|0),($2|0),($3|0))|0);
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 do {
  if ($7) {
   label = 12;
  } else {
   $8 = HEAP32[$5>>2]|0;
   $9 = ($8|0)==(0|0);
   if ($9) {
    __THREW__ = 0;
    $10 = (invoke_ii(3276,28)|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     label = 12;
     break;
    }
    $13 = ((($10)) + 16|0);
    __THREW__ = 0;
    invoke_vii(3457,($13|0),($3|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     $16 = ___cxa_find_matching_catch_2()|0;
     $17 = tempRet0;
     __ZdlPv($10);
     $eh$lpad$body$index2Z2D = $17;$eh$lpad$body$indexZ2D = $16;
     break;
    }
    $18 = HEAP32[$2>>2]|0;
    HEAP32[$10>>2] = 0;
    $19 = ((($10)) + 4|0);
    HEAP32[$19>>2] = 0;
    $20 = ((($10)) + 8|0);
    HEAP32[$20>>2] = $18;
    HEAP32[$5>>2] = $10;
    $21 = HEAP32[$4>>2]|0;
    $22 = HEAP32[$21>>2]|0;
    $23 = ($22|0)==(0|0);
    if ($23) {
     $27 = $10;
    } else {
     $24 = $22;
     HEAP32[$4>>2] = $24;
     $$pre$i$i$i$i = HEAP32[$5>>2]|0;
     $27 = $$pre$i$i$i$i;
    }
    $25 = ((($0)) + 36|0);
    $26 = HEAP32[$25>>2]|0;
    __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($26,$27);
    $28 = ((($0)) + 40|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = (($29) + 1)|0;
    HEAP32[$28>>2] = $30;
   }
   $31 = ((($3)) + 11|0);
   $32 = HEAP8[$31>>0]|0;
   $33 = ($32<<24>>24)<(0);
   if (!($33)) {
    STACKTOP = sp;return;
   }
   $34 = HEAP32[$3>>2]|0;
   __ZdlPv($34);
   STACKTOP = sp;return;
  }
 } while(0);
 if ((label|0) == 12) {
  $35 = ___cxa_find_matching_catch_2()|0;
  $36 = tempRet0;
  $eh$lpad$body$index2Z2D = $36;$eh$lpad$body$indexZ2D = $35;
 }
 $37 = ((($3)) + 11|0);
 $38 = HEAP8[$37>>0]|0;
 $39 = ($38<<24>>24)<(0);
 if (!($39)) {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 $40 = HEAP32[$3>>2]|0;
 __ZdlPv($40);
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
}
function __ZN5osgDB30DeprecatedDotOsgWrapperManagerD2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (75052);
 $1 = ((($0)) + 96|0);
 $2 = ((($0)) + 100|0);
 $3 = HEAP32[$2>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7ref_ptrIN5osgDB13DotOsgWrapperEEEEENS_19__map_value_compareIS7_SD_NS_4lessIS7_EELb1EEENS5_ISD_EEE7destroyEPNS_11__tree_nodeISD_PvEE($1,$3);
 $4 = ((($0)) + 84|0);
 $5 = ((($0)) + 88|0);
 $6 = HEAP32[$5>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7ref_ptrIN5osgDB13DotOsgWrapperEEEEENS_19__map_value_compareIS7_SD_NS_4lessIS7_EELb1EEENS5_ISD_EEE7destroyEPNS_11__tree_nodeISD_PvEE($4,$6);
 $7 = ((($0)) + 72|0);
 $8 = ((($0)) + 76|0);
 $9 = HEAP32[$8>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7ref_ptrIN5osgDB13DotOsgWrapperEEEEENS_19__map_value_compareIS7_SD_NS_4lessIS7_EELb1EEENS5_ISD_EEE7destroyEPNS_11__tree_nodeISD_PvEE($7,$9);
 $10 = ((($0)) + 60|0);
 $11 = ((($0)) + 64|0);
 $12 = HEAP32[$11>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7ref_ptrIN5osgDB13DotOsgWrapperEEEEENS_19__map_value_compareIS7_SD_NS_4lessIS7_EELb1EEENS5_ISD_EEE7destroyEPNS_11__tree_nodeISD_PvEE($10,$12);
 $13 = ((($0)) + 48|0);
 $14 = ((($0)) + 52|0);
 $15 = HEAP32[$14>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7ref_ptrIN5osgDB13DotOsgWrapperEEEEENS_19__map_value_compareIS7_SD_NS_4lessIS7_EELb1EEENS5_ISD_EEE7destroyEPNS_11__tree_nodeISD_PvEE($13,$15);
 $16 = ((($0)) + 36|0);
 $17 = ((($0)) + 40|0);
 $18 = HEAP32[$17>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7ref_ptrIN5osgDB13DotOsgWrapperEEEEENS_19__map_value_compareIS7_SD_NS_4lessIS7_EELb1EEENS5_ISD_EEE7destroyEPNS_11__tree_nodeISD_PvEE($16,$18);
 $19 = ((($0)) + 24|0);
 $20 = ((($0)) + 28|0);
 $21 = HEAP32[$20>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7ref_ptrIN5osgDB13DotOsgWrapperEEEEENS_19__map_value_compareIS7_SD_NS_4lessIS7_EELb1EEENS5_ISD_EEE7destroyEPNS_11__tree_nodeISD_PvEE($19,$21);
 $22 = ((($0)) + 12|0);
 $23 = ((($0)) + 16|0);
 $24 = HEAP32[$23>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7ref_ptrIN5osgDB13DotOsgWrapperEEEEENS_19__map_value_compareIS7_SD_NS_4lessIS7_EELb1EEENS5_ISD_EEE7destroyEPNS_11__tree_nodeISD_PvEE($22,$24);
 __ZN3osg10ReferencedD2Ev($0);
 return;
}
function __ZN5osgDB30DeprecatedDotOsgWrapperManagerD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (75052);
 $1 = ((($0)) + 96|0);
 $2 = ((($0)) + 100|0);
 $3 = HEAP32[$2>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7ref_ptrIN5osgDB13DotOsgWrapperEEEEENS_19__map_value_compareIS7_SD_NS_4lessIS7_EELb1EEENS5_ISD_EEE7destroyEPNS_11__tree_nodeISD_PvEE($1,$3);
 $4 = ((($0)) + 84|0);
 $5 = ((($0)) + 88|0);
 $6 = HEAP32[$5>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7ref_ptrIN5osgDB13DotOsgWrapperEEEEENS_19__map_value_compareIS7_SD_NS_4lessIS7_EELb1EEENS5_ISD_EEE7destroyEPNS_11__tree_nodeISD_PvEE($4,$6);
 $7 = ((($0)) + 72|0);
 $8 = ((($0)) + 76|0);
 $9 = HEAP32[$8>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7ref_ptrIN5osgDB13DotOsgWrapperEEEEENS_19__map_value_compareIS7_SD_NS_4lessIS7_EELb1EEENS5_ISD_EEE7destroyEPNS_11__tree_nodeISD_PvEE($7,$9);
 $10 = ((($0)) + 60|0);
 $11 = ((($0)) + 64|0);
 $12 = HEAP32[$11>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7ref_ptrIN5osgDB13DotOsgWrapperEEEEENS_19__map_value_compareIS7_SD_NS_4lessIS7_EELb1EEENS5_ISD_EEE7destroyEPNS_11__tree_nodeISD_PvEE($10,$12);
 $13 = ((($0)) + 48|0);
 $14 = ((($0)) + 52|0);
 $15 = HEAP32[$14>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7ref_ptrIN5osgDB13DotOsgWrapperEEEEENS_19__map_value_compareIS7_SD_NS_4lessIS7_EELb1EEENS5_ISD_EEE7destroyEPNS_11__tree_nodeISD_PvEE($13,$15);
 $16 = ((($0)) + 36|0);
 $17 = ((($0)) + 40|0);
 $18 = HEAP32[$17>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7ref_ptrIN5osgDB13DotOsgWrapperEEEEENS_19__map_value_compareIS7_SD_NS_4lessIS7_EELb1EEENS5_ISD_EEE7destroyEPNS_11__tree_nodeISD_PvEE($16,$18);
 $19 = ((($0)) + 24|0);
 $20 = ((($0)) + 28|0);
 $21 = HEAP32[$20>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7ref_ptrIN5osgDB13DotOsgWrapperEEEEENS_19__map_value_compareIS7_SD_NS_4lessIS7_EELb1EEENS5_ISD_EEE7destroyEPNS_11__tree_nodeISD_PvEE($19,$21);
 $22 = ((($0)) + 12|0);
 $23 = ((($0)) + 16|0);
 $24 = HEAP32[$23>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7ref_ptrIN5osgDB13DotOsgWrapperEEEEENS_19__map_value_compareIS7_SD_NS_4lessIS7_EELb1EEENS5_ISD_EEE7destroyEPNS_11__tree_nodeISD_PvEE($22,$24);
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $25 = __THREW__; __THREW__ = 0;
 $26 = $25&1;
 if ($26) {
  $27 = ___cxa_find_matching_catch_2()|0;
  $28 = tempRet0;
  __ZdlPv($0);
  ___resumeException($27|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7ref_ptrIN5osgDB13DotOsgWrapperEEEEENS_19__map_value_compareIS7_SD_NS_4lessIS7_EELb1EEENS5_ISD_EEE7destroyEPNS_11__tree_nodeISD_PvEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 }
 $3 = HEAP32[$1>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7ref_ptrIN5osgDB13DotOsgWrapperEEEEENS_19__map_value_compareIS7_SD_NS_4lessIS7_EELb1EEENS5_ISD_EEE7destroyEPNS_11__tree_nodeISD_PvEE($0,$3);
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7ref_ptrIN5osgDB13DotOsgWrapperEEEEENS_19__map_value_compareIS7_SD_NS_4lessIS7_EELb1EEENS5_ISD_EEE7destroyEPNS_11__tree_nodeISD_PvEE($0,$5);
 $6 = ((($1)) + 16|0);
 $7 = ((($1)) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if (!($9)) {
  $10 = ((($8)) + 8|0);
  $11 = HEAP32[$10>>2]|0;HEAP32[$10>>2] = (($11-1)|0);
  $12 = ($11|0)==(1);
  if ($12) {
   __THREW__ = 0;
   invoke_viii(3262,($8|0),1,1);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if ($14) {
    $19 = ___cxa_find_matching_catch_2()|0;
    $20 = tempRet0;
    $21 = ((($6)) + 11|0);
    $22 = HEAP8[$21>>0]|0;
    $23 = ($22<<24>>24)<(0);
    if (!($23)) {
     ___cxa_call_unexpected(($19|0));
     // unreachable;
    }
    $24 = HEAP32[$6>>2]|0;
    __ZdlPv($24);
    ___cxa_call_unexpected(($19|0));
    // unreachable;
   }
  }
 }
 HEAP32[$7>>2] = 0;
 $15 = ((($6)) + 11|0);
 $16 = HEAP8[$15>>0]|0;
 $17 = ($16<<24>>24)<(0);
 if ($17) {
  $18 = HEAP32[$6>>2]|0;
  __ZdlPv($18);
 }
 __ZdlPv($1);
 return;
}
function __ZNSt3__25dequeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS4_IS6_EEE6assignINS_16__deque_iteratorIS6_PKS6_RSB_PKSC_iLi0EEEEEvT_SH_PNS_9enable_ifIXsr27__is_random_access_iteratorISH_EE5valueEvE4typeE($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $$byval_copy2 = 0, $$neg$i = 0, $$sink$i$i = 0, $$sroa$0$0 = 0, $$sroa$0$0$in = 0, $$sroa$0$1 = 0, $$sroa$7$0 = 0, $$sroa_raw_idx11 = 0, $$sroa_raw_idx19 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $tmpcast$byval_copy = 0;
 var $tmpcast1$byval_copy = 0, $tmpcast2$byval_copy = 0, $tmpcast3$byval_copy = 0, $tmpcast5$byval_copy = 0, $tmpcast6$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(160|0);
 $$byval_copy2 = sp + 152|0;
 $$byval_copy1 = sp + 144|0;
 $tmpcast1$byval_copy = sp + 136|0;
 $tmpcast$byval_copy = sp + 128|0;
 $tmpcast6$byval_copy = sp + 120|0;
 $tmpcast5$byval_copy = sp + 112|0;
 $$byval_copy = sp + 104|0;
 $tmpcast3$byval_copy = sp + 96|0;
 $tmpcast2$byval_copy = sp + 88|0;
 $4 = sp + 40|0;
 $5 = sp + 32|0;
 $6 = sp + 80|0;
 $7 = sp + 72|0;
 $8 = sp + 24|0;
 $9 = sp + 16|0;
 $10 = sp + 64|0;
 $11 = sp + 56|0;
 $12 = sp + 8|0;
 $13 = sp;
 $14 = sp + 48|0;
 $15 = ((($2)) + 4|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ((($1)) + 4|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ($16|0)==($18|0);
 $20 = $18;
 if (!($19)) {
  $21 = $16;
  $22 = HEAP32[$2>>2]|0;
  $23 = HEAP32[$1>>2]|0;
  $24 = $22;
  $25 = $23;
  $26 = (($24) - ($25))|0;
  $27 = $26 >> 2;
  $28 = ($27*341)|0;
  $29 = HEAP32[$22>>2]|0;
  $30 = (($21) - ($29))|0;
  $31 = (($30|0) / 12)&-1;
  $32 = (($28) + ($31))|0;
  $33 = HEAP32[$23>>2]|0;
  $34 = (($20) - ($33))|0;
  $$neg$i = (($34|0) / -12)&-1;
  $35 = (($32) + ($$neg$i))|0;
  $36 = ((($0)) + 20|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = ($35>>>0)>($37>>>0);
  if ($38) {
   $39 = $1;
   $40 = $39;
   $41 = HEAP32[$40>>2]|0;
   $42 = (($39) + 4)|0;
   $43 = $42;
   $44 = HEAP32[$43>>2]|0;
   $45 = ($37|0)==(0);
   $46 = $41;
   if ($45) {
    $$sroa$0$1 = $25;$$sroa$7$0 = $20;
   } else {
    $47 = $41;
    $48 = HEAP32[$47>>2]|0;
    $49 = (($44) - ($48))|0;
    $50 = (($49|0) / 12)&-1;
    $51 = (($50) + ($37))|0;
    $52 = ($51|0)>(0);
    if ($52) {
     $53 = (($51>>>0) / 341)&-1;
     $54 = (($46) + ($53<<2)|0);
     $55 = HEAP32[$54>>2]|0;
     $56 = (($51>>>0) % 341)&-1;
     $57 = (($55) + (($56*12)|0)|0);
     $$sink$i$i = $57;$$sroa$0$0$in = $54;
    } else {
     $58 = (340 - ($51))|0;
     $59 = (($58|0) / -341)&-1;
     $60 = (($46) + ($59<<2)|0);
     $61 = HEAP32[$60>>2]|0;
     $62 = (($58|0) % 341)&-1;
     $63 = (340 - ($62))|0;
     $64 = (($61) + (($63*12)|0)|0);
     $$sink$i$i = $64;$$sroa$0$0$in = $60;
    }
    $$sroa$0$0 = $$sroa$0$0$in;
    $65 = $$sink$i$i;
    $$sroa$0$1 = $$sroa$0$0;$$sroa$7$0 = $65;
   }
   $66 = $4;
   $67 = $66;
   HEAP32[$67>>2] = $41;
   $68 = (($66) + 4)|0;
   $69 = $68;
   HEAP32[$69>>2] = $44;
   HEAP32[$5>>2] = $$sroa$0$1;
   $$sroa_raw_idx11 = ((($5)) + 4|0);
   HEAP32[$$sroa_raw_idx11>>2] = $$sroa$7$0;
   $70 = ((($0)) + 4|0);
   $71 = HEAP32[$70>>2]|0;
   $72 = ((($0)) + 16|0);
   $73 = HEAP32[$72>>2]|0;
   $74 = (($73>>>0) / 341)&-1;
   $75 = (($71) + ($74<<2)|0);
   $76 = ((($0)) + 8|0);
   $77 = HEAP32[$76>>2]|0;
   $78 = ($77|0)==($71|0);
   if ($78) {
    $83 = 0;
   } else {
    $79 = HEAP32[$75>>2]|0;
    $80 = (($73>>>0) % 341)&-1;
    $81 = (($79) + (($80*12)|0)|0);
    $83 = $81;
   }
   HEAP32[$6>>2] = $75;
   $82 = ((($6)) + 4|0);
   HEAP32[$82>>2] = $83;
   ;HEAP32[$tmpcast2$byval_copy>>2]=HEAP32[$4>>2]|0;HEAP32[$tmpcast2$byval_copy+4>>2]=HEAP32[$4+4>>2]|0;
   ;HEAP32[$tmpcast3$byval_copy>>2]=HEAP32[$5>>2]|0;HEAP32[$tmpcast3$byval_copy+4>>2]=HEAP32[$5+4>>2]|0;
   ;HEAP32[$$byval_copy>>2]=HEAP32[$6>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$6+4>>2]|0;
   __ZNSt3__24copyINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPKS6_RS7_PKS8_iLi0ES6_PS6_RS6_PSC_iLi0EEENS_16__deque_iteratorIT5_T6_T7_T8_T9_XT10_EEENSF_IT_T0_T1_T2_T3_XT4_EEESR_SL_($7,$tmpcast2$byval_copy,$tmpcast3$byval_copy,$$byval_copy);
   HEAP32[$8>>2] = $$sroa$0$1;
   $$sroa_raw_idx19 = ((($8)) + 4|0);
   HEAP32[$$sroa_raw_idx19>>2] = $$sroa$7$0;
   $84 = $2;
   $85 = $84;
   $86 = HEAP32[$85>>2]|0;
   $87 = (($84) + 4)|0;
   $88 = $87;
   $89 = HEAP32[$88>>2]|0;
   $90 = $9;
   $91 = $90;
   HEAP32[$91>>2] = $86;
   $92 = (($90) + 4)|0;
   $93 = $92;
   HEAP32[$93>>2] = $89;
   ;HEAP32[$tmpcast5$byval_copy>>2]=HEAP32[$8>>2]|0;HEAP32[$tmpcast5$byval_copy+4>>2]=HEAP32[$8+4>>2]|0;
   ;HEAP32[$tmpcast6$byval_copy>>2]=HEAP32[$9>>2]|0;HEAP32[$tmpcast6$byval_copy+4>>2]=HEAP32[$9+4>>2]|0;
   __ZNSt3__25dequeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS4_IS6_EEE8__appendINS_16__deque_iteratorIS6_PKS6_RSB_PKSC_iLi0EEEEEvT_SH_PNS_9enable_ifIXsr21__is_forward_iteratorISH_EE5valueEvE4typeE($0,$tmpcast5$byval_copy,$tmpcast6$byval_copy,0);
   STACKTOP = sp;return;
  }
 }
 $94 = $1;
 $95 = $94;
 $96 = HEAP32[$95>>2]|0;
 $97 = (($94) + 4)|0;
 $98 = $97;
 $99 = HEAP32[$98>>2]|0;
 $100 = $12;
 $101 = $100;
 HEAP32[$101>>2] = $96;
 $102 = (($100) + 4)|0;
 $103 = $102;
 HEAP32[$103>>2] = $99;
 $104 = $2;
 $105 = $104;
 $106 = HEAP32[$105>>2]|0;
 $107 = (($104) + 4)|0;
 $108 = $107;
 $109 = HEAP32[$108>>2]|0;
 $110 = $13;
 $111 = $110;
 HEAP32[$111>>2] = $106;
 $112 = (($110) + 4)|0;
 $113 = $112;
 HEAP32[$113>>2] = $109;
 $114 = ((($0)) + 4|0);
 $115 = HEAP32[$114>>2]|0;
 $116 = ((($0)) + 16|0);
 $117 = HEAP32[$116>>2]|0;
 $118 = (($117>>>0) / 341)&-1;
 $119 = (($115) + ($118<<2)|0);
 $120 = ((($0)) + 8|0);
 $121 = HEAP32[$120>>2]|0;
 $122 = ($121|0)==($115|0);
 if ($122) {
  $127 = 0;
 } else {
  $123 = HEAP32[$119>>2]|0;
  $124 = (($117>>>0) % 341)&-1;
  $125 = (($123) + (($124*12)|0)|0);
  $127 = $125;
 }
 HEAP32[$14>>2] = $119;
 $126 = ((($14)) + 4|0);
 HEAP32[$126>>2] = $127;
 ;HEAP32[$tmpcast$byval_copy>>2]=HEAP32[$12>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$12+4>>2]|0;
 ;HEAP32[$tmpcast1$byval_copy>>2]=HEAP32[$13>>2]|0;HEAP32[$tmpcast1$byval_copy+4>>2]=HEAP32[$13+4>>2]|0;
 ;HEAP32[$$byval_copy1>>2]=HEAP32[$14>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$14+4>>2]|0;
 __ZNSt3__24copyINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPKS6_RS7_PKS8_iLi0ES6_PS6_RS6_PSC_iLi0EEENS_16__deque_iteratorIT5_T6_T7_T8_T9_XT10_EEENSF_IT_T0_T1_T2_T3_XT4_EEESR_SL_($11,$tmpcast$byval_copy,$tmpcast1$byval_copy,$$byval_copy1);
 $128 = HEAP32[$11>>2]|0;
 HEAP32[$10>>2] = $128;
 $129 = ((($10)) + 4|0);
 $130 = ((($11)) + 4|0);
 $131 = HEAP32[$130>>2]|0;
 HEAP32[$129>>2] = $131;
 ;HEAP32[$$byval_copy2>>2]=HEAP32[$10>>2]|0;HEAP32[$$byval_copy2+4>>2]=HEAP32[$10+4>>2]|0;
 __ZNSt3__25dequeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS4_IS6_EEE14__erase_to_endENS_16__deque_iteratorIS6_PKS6_RSA_PKSB_iLi0EEE($0,$$byval_copy2);
 STACKTOP = sp;return;
}
function __ZNSt3__24copyINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPKS6_RS7_PKS8_iLi0ES6_PS6_RS6_PSC_iLi0EEENS_16__deque_iteratorIT5_T6_T7_T8_T9_XT10_EEENSF_IT_T0_T1_T2_T3_XT4_EEESR_SL_($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$ = 0, $$$i = 0, $$022$ = 0, $$02241 = 0, $$02830$i = 0, $$078$i$i$i = 0, $$09$i$i$i = 0, $$29$i = 0, $$neg$i = 0, $$off0 = 0, $$off32 = 0, $$pre = 0, $$sink$i = 0, $$sink$i$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $tmpcast24$sroa$0$0 = 0;
 var $tmpcast24$sroa$0$1 = 0, $tmpcast24$sroa$0$2 = 0, $tmpcast24$sroa$0$2$in = 0, $tmpcast24$sroa$0$3 = 0, $tmpcast24$sroa$7$0 = 0, $tmpcast24$sroa$7$1 = 0, $tmpcast24$sroa$7$2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ((($2)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($1)) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5|0)==($7|0);
 $9 = $7;
 if (!($8)) {
  $10 = $5;
  $11 = HEAP32[$2>>2]|0;
  $12 = HEAP32[$1>>2]|0;
  $13 = $11;
  $14 = $12;
  $15 = (($13) - ($14))|0;
  $16 = $15 >> 2;
  $17 = ($16*341)|0;
  $18 = HEAP32[$11>>2]|0;
  $19 = (($10) - ($18))|0;
  $20 = (($19|0) / 12)&-1;
  $21 = (($17) + ($20))|0;
  $22 = HEAP32[$12>>2]|0;
  $23 = (($9) - ($22))|0;
  $$neg$i = (($23|0) / -12)&-1;
  $24 = (($21) + ($$neg$i))|0;
  $25 = ($24|0)>(0);
  if ($25) {
   $$pre = HEAP32[$1>>2]|0;
   $32 = $3;
   $33 = $32;
   $34 = HEAP32[$33>>2]|0;
   $35 = (($32) + 4)|0;
   $36 = $35;
   $37 = HEAP32[$36>>2]|0;
   $$02241 = $24;$$off0 = $34;$$off32 = $37;$39 = $$pre;$42 = $7;$99 = $9;
   while(1) {
    $38 = HEAP32[$39>>2]|0;
    $40 = ((($38)) + 4092|0);
    $41 = $40;
    $43 = $42;
    $44 = (($41) - ($43))|0;
    $45 = (($44|0) / 12)&-1;
    $46 = ($45|0)>($$02241|0);
    $47 = (($42) + (($$02241*12)|0)|0);
    $$ = $46 ? $47 : $40;
    $$022$ = $46 ? $$02241 : $45;
    $48 = ($42|0)==($$|0);
    if ($48) {
     $tmpcast24$sroa$0$3 = $$off0;$tmpcast24$sroa$7$2 = $$off32;
    } else {
     $49 = $$;
     $50 = $$off32;
     $51 = $$off0;
     $$02830$i = $42;$53 = $51;$56 = $50;$73 = $$off32;$tmpcast24$sroa$0$0 = $$off0;$tmpcast24$sroa$7$0 = $$off32;
     while(1) {
      $52 = HEAP32[$53>>2]|0;
      $54 = ((($52)) + 4092|0);
      $55 = $54;
      $57 = $56;
      $58 = (($55) - ($57))|0;
      $59 = (($58|0) / 12)&-1;
      $60 = $$02830$i;
      $61 = (($49) - ($60))|0;
      $62 = (($61|0) / 12)&-1;
      $63 = ($62|0)>($59|0);
      $64 = (($$02830$i) + (($59*12)|0)|0);
      $$$i = $63 ? $59 : $62;
      $$29$i = $63 ? $64 : $$;
      $65 = ($$02830$i|0)==($$29$i|0);
      if (!($65)) {
       $$078$i$i$i = $$02830$i;$$09$i$i$i = $56;
       while(1) {
        (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEaSERKS5_($$09$i$i$i,$$078$i$i$i)|0);
        $66 = ((($$078$i$i$i)) + 12|0);
        $67 = ((($$09$i$i$i)) + 12|0);
        $68 = ($66|0)==($$29$i|0);
        if ($68) {
         break;
        } else {
         $$078$i$i$i = $66;$$09$i$i$i = $67;
        }
       }
      }
      $69 = ($$$i|0)==(0);
      if ($69) {
       $122 = $73;$123 = $53;$124 = $56;$tmpcast24$sroa$0$1 = $tmpcast24$sroa$0$0;$tmpcast24$sroa$7$1 = $tmpcast24$sroa$7$0;
      } else {
       $71 = HEAP32[$53>>2]|0;
       $72 = (($73) - ($71))|0;
       $74 = (($72|0) / 12)&-1;
       $75 = (($74) + ($$$i))|0;
       $76 = ($75|0)>(0);
       if ($76) {
        $77 = (($75>>>0) / 341)&-1;
        $78 = (($53) + ($77<<2)|0);
        $79 = HEAP32[$78>>2]|0;
        $80 = (($75>>>0) % 341)&-1;
        $81 = (($79) + (($80*12)|0)|0);
        $$sink$i$i = $81;$tmpcast24$sroa$0$2$in = $78;
       } else {
        $82 = (340 - ($75))|0;
        $83 = (($82|0) / -341)&-1;
        $84 = (($53) + ($83<<2)|0);
        $85 = HEAP32[$84>>2]|0;
        $86 = (($82|0) % 341)&-1;
        $87 = (340 - ($86))|0;
        $88 = (($85) + (($87*12)|0)|0);
        $$sink$i$i = $88;$tmpcast24$sroa$0$2$in = $84;
       }
       $tmpcast24$sroa$0$2 = $tmpcast24$sroa$0$2$in;
       $89 = $$sink$i$i;
       $122 = $89;$123 = $tmpcast24$sroa$0$2$in;$124 = $$sink$i$i;$tmpcast24$sroa$0$1 = $tmpcast24$sroa$0$2;$tmpcast24$sroa$7$1 = $89;
      }
      $70 = ($$29$i|0)==($$|0);
      if ($70) {
       $tmpcast24$sroa$0$3 = $tmpcast24$sroa$0$1;$tmpcast24$sroa$7$2 = $tmpcast24$sroa$7$1;
       break;
      } else {
       $$02830$i = $$29$i;$53 = $123;$56 = $124;$73 = $122;$tmpcast24$sroa$0$0 = $tmpcast24$sroa$0$1;$tmpcast24$sroa$7$0 = $tmpcast24$sroa$7$1;
      }
     }
    }
    $90 = $3;
    $91 = $90;
    HEAP32[$91>>2] = $tmpcast24$sroa$0$3;
    $92 = (($90) + 4)|0;
    $93 = $92;
    HEAP32[$93>>2] = $tmpcast24$sroa$7$2;
    $94 = (($$02241) - ($$022$))|0;
    $95 = ($$022$|0)==(0);
    if ($95) {
     $125 = $99;$126 = $39;$127 = $42;
    } else {
     $97 = HEAP32[$39>>2]|0;
     $98 = (($99) - ($97))|0;
     $100 = (($98|0) / 12)&-1;
     $101 = (($100) + ($$022$))|0;
     $102 = ($101|0)>(0);
     if ($102) {
      $103 = (($101>>>0) / 341)&-1;
      $104 = (($39) + ($103<<2)|0);
      HEAP32[$1>>2] = $104;
      $105 = HEAP32[$104>>2]|0;
      $106 = (($101>>>0) % 341)&-1;
      $107 = (($105) + (($106*12)|0)|0);
      $$sink$i = $107;$128 = $104;
     } else {
      $108 = (340 - ($101))|0;
      $109 = (($108|0) / -341)&-1;
      $110 = (($39) + ($109<<2)|0);
      HEAP32[$1>>2] = $110;
      $111 = HEAP32[$110>>2]|0;
      $112 = (($108|0) % 341)&-1;
      $113 = (340 - ($112))|0;
      $114 = (($111) + (($113*12)|0)|0);
      $$sink$i = $114;$128 = $110;
     }
     HEAP32[$6>>2] = $$sink$i;
     $115 = $$sink$i;
     $125 = $115;$126 = $128;$127 = $$sink$i;
    }
    $96 = ($94|0)>(0);
    if ($96) {
     $$02241 = $94;$$off0 = $tmpcast24$sroa$0$3;$$off32 = $tmpcast24$sroa$7$2;$39 = $126;$42 = $127;$99 = $125;
    } else {
     $118 = $tmpcast24$sroa$0$3;$121 = $tmpcast24$sroa$7$2;
     break;
    }
   }
   $116 = $0;
   $117 = $116;
   HEAP32[$117>>2] = $118;
   $119 = (($116) + 4)|0;
   $120 = $119;
   HEAP32[$120>>2] = $121;
   return;
  }
 }
 $26 = $3;
 $27 = $26;
 $28 = HEAP32[$27>>2]|0;
 $29 = (($26) + 4)|0;
 $30 = $29;
 $31 = HEAP32[$30>>2]|0;
 $118 = $28;$121 = $31;
 $116 = $0;
 $117 = $116;
 HEAP32[$117>>2] = $118;
 $119 = (($116) + 4)|0;
 $120 = $119;
 HEAP32[$120>>2] = $121;
 return;
}
function __ZNSt3__25dequeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS4_IS6_EEE14__erase_to_endENS_16__deque_iteratorIS6_PKS6_RSA_PKSB_iLi0EEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$$i$i = 0, $$$i$i41 = 0, $$cast = 0, $$neg$i = 0, $$neg$i10 = 0, $$sink$i$i = 0, $$sroa$0$0 = 0, $$sroa$0$0$in = 0, $$sroa$0$2$ph40 = 0, $$sroa$7$1 = 0, $$sroa$7$1$ph39 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $sum = 0, $sum45 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 20|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 16|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + ($3))|0;
 $7 = ((($0)) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($6>>>0) / 341)&-1;
 $10 = (($8) + ($9<<2)|0);
 $11 = ((($0)) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==($8|0);
 if ($13) {
  $19 = 0;
 } else {
  $14 = HEAP32[$10>>2]|0;
  $15 = (($6>>>0) % 341)&-1;
  $16 = (($14) + (($15*12)|0)|0);
  $19 = $16;
 }
 $17 = ((($1)) + 4|0);
 $18 = HEAP32[$17>>2]|0;
 $20 = ($19|0)==($18|0);
 if ($20) {
  return;
 }
 $21 = $19;
 $22 = $10;
 $23 = $18;
 $24 = HEAP32[$1>>2]|0;
 $25 = $24;
 $26 = (($22) - ($25))|0;
 $27 = $26 >> 2;
 $28 = ($27*341)|0;
 $29 = HEAP32[$10>>2]|0;
 $30 = (($21) - ($29))|0;
 $31 = (($30|0) / 12)&-1;
 $32 = (($28) + ($31))|0;
 $33 = HEAP32[$24>>2]|0;
 $34 = (($23) - ($33))|0;
 $$neg$i = (($34|0) / -12)&-1;
 $35 = (($32) + ($$neg$i))|0;
 $36 = ($35|0)>(0);
 if (!($36)) {
  return;
 }
 $37 = (($5>>>0) / 341)&-1;
 $38 = (($8) + ($37<<2)|0);
 if ($13) {
  $43 = 0;
 } else {
  $39 = HEAP32[$38>>2]|0;
  $40 = (($5>>>0) % 341)&-1;
  $41 = (($39) + (($40*12)|0)|0);
  $43 = $41;
 }
 $42 = $38;
 $44 = $43;
 $45 = ($18|0)==($43|0);
 if ($45) {
  $$sroa$0$2$ph40 = $42;$$sroa$7$1$ph39 = $44;
 } else {
  $46 = (($25) - ($42))|0;
  $47 = $46 >> 2;
  $48 = ($47*341)|0;
  $49 = (($34|0) / 12)&-1;
  $50 = (($48) + ($49))|0;
  $51 = HEAP32[$38>>2]|0;
  $52 = (($44) - ($51))|0;
  $$neg$i10 = (($52|0) / -12)&-1;
  $53 = (($50) + ($$neg$i10))|0;
  $54 = ($53|0)==(0);
  if ($54) {
   $$sroa$0$2$ph40 = $42;$$sroa$7$1$ph39 = $44;
  } else {
   $55 = HEAP32[$38>>2]|0;
   $56 = (($44) - ($55))|0;
   $57 = (($56|0) / 12)&-1;
   $58 = (($57) + ($53))|0;
   $59 = ($58|0)>(0);
   if ($59) {
    $60 = (($58>>>0) / 341)&-1;
    $61 = (($38) + ($60<<2)|0);
    $62 = HEAP32[$61>>2]|0;
    $63 = (($58>>>0) % 341)&-1;
    $64 = (($62) + (($63*12)|0)|0);
    $$sink$i$i = $64;$$sroa$0$0$in = $61;
   } else {
    $65 = (340 - ($58))|0;
    $66 = (($65|0) / -341)&-1;
    $67 = (($38) + ($66<<2)|0);
    $68 = HEAP32[$67>>2]|0;
    $69 = (($65|0) % 341)&-1;
    $70 = (340 - ($69))|0;
    $71 = (($68) + (($70*12)|0)|0);
    $$sink$i$i = $71;$$sroa$0$0$in = $67;
   }
   $$sroa$0$0 = $$sroa$0$0$in;
   $72 = $$sink$i$i;
   $$sroa$0$2$ph40 = $$sroa$0$0;$$sroa$7$1$ph39 = $72;
  }
 }
 L20: while(1) {
  $73 = $$sroa$0$2$ph40;
  $$sroa$7$1 = $$sroa$7$1$ph39;
  while(1) {
   $74 = $$sroa$7$1;
   $75 = ($74|0)==($19|0);
   if ($75) {
    break L20;
   }
   $89 = $$sroa$7$1;
   $90 = ((($89)) + 11|0);
   $91 = HEAP8[$90>>0]|0;
   $92 = ($91<<24>>24)<(0);
   if ($92) {
    $93 = HEAP32[$74>>2]|0;
    __ZdlPv($93);
   }
   $94 = ((($74)) + 12|0);
   $95 = $94;
   $96 = HEAP32[$73>>2]|0;
   $97 = (($95) - ($96))|0;
   $98 = ($97|0)==(4092);
   if ($98) {
    break;
   } else {
    $$sroa$7$1 = $95;
   }
  }
  $99 = $$sroa$0$2$ph40;
  $100 = ((($99)) + 4|0);
  $101 = $100;
  $102 = HEAP32[$100>>2]|0;
  $$sroa$0$2$ph40 = $101;$$sroa$7$1$ph39 = $102;
 }
 $76 = HEAP32[$2>>2]|0;
 $77 = (($76) - ($35))|0;
 HEAP32[$2>>2] = $77;
 $78 = HEAP32[$11>>2]|0;
 $79 = HEAP32[$7>>2]|0;
 $80 = (($78) - ($79))|0;
 $81 = $80 >> 2;
 $82 = ($81|0)==(0);
 $83 = ($81*341)|0;
 $84 = (($83) + -1)|0;
 $$$i$i41 = $82 ? 0 : $84;
 $85 = HEAP32[$4>>2]|0;
 $sum = (($77) + ($85))|0;
 $86 = (($$$i$i41) - ($sum))|0;
 $87 = ($86>>>0)>(681);
 if (!($87)) {
  return;
 }
 $88 = $78;
 $104 = $88;
 while(1) {
  $103 = ((($104)) + -4|0);
  $105 = HEAP32[$103>>2]|0;
  __ZdlPv($105);
  $106 = HEAP32[$11>>2]|0;
  $107 = ((($106)) + -4|0);
  HEAP32[$11>>2] = $107;
  $$cast = $107;
  $108 = HEAP32[$7>>2]|0;
  $109 = (($$cast) - ($108))|0;
  $110 = $109 >> 2;
  $111 = ($110|0)==(0);
  $112 = ($110*341)|0;
  $113 = (($112) + -1)|0;
  $$$i$i = $111 ? 0 : $113;
  $114 = HEAP32[$4>>2]|0;
  $115 = HEAP32[$2>>2]|0;
  $sum45 = (($115) + ($114))|0;
  $116 = (($$$i$i) - ($sum45))|0;
  $117 = ($116>>>0)>(681);
  if ($117) {
   $104 = $107;
  } else {
   break;
  }
 }
 return;
}
function __ZN5osgDB8Registry11loadLibraryERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$011 = 0, $$02026$i$i29 = 0, $$02125$i$i30 = 0, $$027$i$i28 = 0, $$09 = 0, $$1 = 0, $$110 = 0, $$112 = 0, $$pre$i = 0, $$pre$i14 = 0, $$sroa$0$0$i = 0, $$sroa$03$011$i = 0, $$sroa$03$011$i$us = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $phitmp$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = ((($0)) + 60|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($4)) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 (FUNCTION_TABLE_ii[$6 & 8191]($3)|0);
 $7 = ((($0)) + 96|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($0)) + 100|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8|0)==($10|0);
 L1: do {
  if ($11) {
   $$sroa$0$0$i = $8;
   label = 13;
  } else {
   $12 = ((($1)) + 11|0);
   $13 = HEAP8[$12>>0]|0;
   $14 = ($13<<24>>24)<(0);
   $15 = ((($1)) + 4|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = $13&255;
   $18 = $14 ? $16 : $17;
   $19 = HEAP32[$1>>2]|0;
   $20 = $14 ? $19 : $1;
   $21 = ($18|0)==(0);
   if ($21) {
    $$sroa$03$011$i$us = $8;
    while(1) {
     $22 = HEAP32[$$sroa$03$011$i$us>>2]|0;
     $23 = ((($22)) + 16|0);
     $24 = ((($23)) + 11|0);
     $25 = HEAP8[$24>>0]|0;
     $26 = ($25<<24>>24)<(0);
     $27 = ((($22)) + 20|0);
     $28 = HEAP32[$27>>2]|0;
     $29 = $25&255;
     $30 = $26 ? $28 : $29;
     $31 = ($30|0)==(0);
     if ($31) {
      $$sroa$0$0$i = $$sroa$03$011$i$us;
      label = 13;
      break L1;
     }
     $32 = ((($$sroa$03$011$i$us)) + 4|0);
     $33 = ($32|0)==($10|0);
     if ($33) {
      break L1;
     } else {
      $$sroa$03$011$i$us = $32;
     }
    }
   } else {
    $$sroa$03$011$i = $8;
   }
   while(1) {
    $34 = HEAP32[$$sroa$03$011$i>>2]|0;
    $35 = ((($34)) + 16|0);
    $36 = ((($35)) + 11|0);
    $37 = HEAP8[$36>>0]|0;
    $38 = ($37<<24>>24)<(0);
    $39 = ((($34)) + 20|0);
    $40 = HEAP32[$39>>2]|0;
    $41 = $37&255;
    $42 = $38 ? $40 : $41;
    $43 = ($42|0)==($18|0);
    do {
     if ($43) {
      $44 = HEAP32[$35>>2]|0;
      if ($38) {
       $55 = (_memcmp($44,$20,$18)|0);
       $phitmp$i$i = ($55|0)==(0);
       if ($phitmp$i$i) {
        $$sroa$0$0$i = $$sroa$03$011$i;
        label = 13;
        break L1;
       } else {
        break;
       }
      }
      $45 = $44;
      $46 = $45&255;
      $47 = HEAP8[$20>>0]|0;
      $48 = ($46<<24>>24)==($47<<24>>24);
      if ($48) {
       $$02026$i$i29 = $35;$$02125$i$i30 = $41;$$027$i$i28 = $20;
       while(1) {
        $49 = (($$02125$i$i30) + -1)|0;
        $50 = ((($$02026$i$i29)) + 1|0);
        $51 = ($49|0)==(0);
        if ($51) {
         $$sroa$0$0$i = $$sroa$03$011$i;
         label = 13;
         break L1;
        }
        $52 = ((($$027$i$i28)) + 1|0);
        $$pre$i = HEAP8[$50>>0]|0;
        $53 = HEAP8[$52>>0]|0;
        $54 = ($$pre$i<<24>>24)==($53<<24>>24);
        if ($54) {
         $$02026$i$i29 = $50;$$02125$i$i30 = $49;$$027$i$i28 = $52;
        } else {
         break;
        }
       }
      }
     }
    } while(0);
    $56 = ((($$sroa$03$011$i)) + 4|0);
    $57 = ($56|0)==($10|0);
    if ($57) {
     break;
    } else {
     $$sroa$03$011$i = $56;
    }
   }
  }
 } while(0);
 if ((label|0) == 13) {
  $58 = ($$sroa$0$0$i|0)==($10|0);
  if (!($58)) {
   $$1 = 1;
   $99 = HEAP32[$3>>2]|0;
   $100 = ((($99)) + 12|0);
   $101 = HEAP32[$100>>2]|0;
   (FUNCTION_TABLE_ii[$101 & 8191]($3)|0);
   STACKTOP = sp;return ($$1|0);
  }
 }
 $59 = ((($0)) + 96|0);
 $60 = ((($0)) + 132|0);
 HEAP8[$60>>0] = 1;
 __THREW__ = 0;
 $61 = (invoke_ii(4189,($1|0))|0);
 $62 = __THREW__; __THREW__ = 0;
 $63 = $62&1;
 if ($63) {
  $86 = ___cxa_find_matching_catch_2()|0;
  $87 = tempRet0;
  $$110 = $87;$$112 = $86;
 } else {
  HEAP8[$60>>0] = 0;
  $64 = ($61|0)==(0|0);
  if ($64) {
   $$1 = 0;
   $99 = HEAP32[$3>>2]|0;
   $100 = ((($99)) + 12|0);
   $101 = HEAP32[$100>>2]|0;
   (FUNCTION_TABLE_ii[$101 & 8191]($3)|0);
   STACKTOP = sp;return ($$1|0);
  }
  HEAP32[$2>>2] = $61;
  $65 = ((($61)) + 8|0);
  $66 = HEAP32[$65>>2]|0;HEAP32[$65>>2] = (($66+1)|0);
  $67 = HEAP32[$9>>2]|0;
  $68 = ((($0)) + 104|0);
  $69 = HEAP32[$68>>2]|0;
  $70 = ($67|0)==($69|0);
  if ($70) {
   __THREW__ = 0;
   invoke_vii(4190,($59|0),($2|0));
   $77 = __THREW__; __THREW__ = 0;
   $78 = $77&1;
   if ($78) {
    $90 = ___cxa_find_matching_catch_2()|0;
    $91 = tempRet0;
    $92 = HEAP32[$2>>2]|0;
    $93 = ($92|0)==(0|0);
    if (!($93)) {
     $94 = ((($92)) + 8|0);
     $95 = HEAP32[$94>>2]|0;HEAP32[$94>>2] = (($95-1)|0);
     $96 = ($95|0)==(1);
     if ($96) {
      __THREW__ = 0;
      invoke_viii(3262,($92|0),1,1);
      $97 = __THREW__; __THREW__ = 0;
      $98 = $97&1;
      if ($98) {
       $107 = ___cxa_find_matching_catch_3(0|0)|0;
       $108 = tempRet0;
       ___clang_call_terminate($107);
       // unreachable;
      }
     }
    }
    HEAP32[$2>>2] = 0;
    $$011 = $90;$$09 = $91;
   } else {
    label = 21;
   }
  } else {
   $71 = HEAP32[$2>>2]|0;
   HEAP32[$67>>2] = $71;
   $72 = ($71|0)==(0|0);
   if ($72) {
    $76 = $67;
   } else {
    $73 = ((($71)) + 8|0);
    $74 = HEAP32[$73>>2]|0;HEAP32[$73>>2] = (($74+1)|0);
    $$pre$i14 = HEAP32[$9>>2]|0;
    $76 = $$pre$i14;
   }
   $75 = ((($76)) + 4|0);
   HEAP32[$9>>2] = $75;
   label = 21;
  }
  do {
   if ((label|0) == 21) {
    $79 = HEAP32[$2>>2]|0;
    $80 = ($79|0)==(0|0);
    if (!($80)) {
     $81 = ((($79)) + 8|0);
     $82 = HEAP32[$81>>2]|0;HEAP32[$81>>2] = (($82-1)|0);
     $83 = ($82|0)==(1);
     if ($83) {
      __THREW__ = 0;
      invoke_viii(3262,($79|0),1,1);
      $84 = __THREW__; __THREW__ = 0;
      $85 = $84&1;
      if ($85) {
       $88 = ___cxa_find_matching_catch_2()|0;
       $89 = tempRet0;
       $$011 = $88;$$09 = $89;
       break;
      }
     }
    }
    $$1 = 2;
    $99 = HEAP32[$3>>2]|0;
    $100 = ((($99)) + 12|0);
    $101 = HEAP32[$100>>2]|0;
    (FUNCTION_TABLE_ii[$101 & 8191]($3)|0);
    STACKTOP = sp;return ($$1|0);
   }
  } while(0);
  $$110 = $$09;$$112 = $$011;
 }
 $102 = HEAP32[$3>>2]|0;
 $103 = ((($102)) + 12|0);
 $104 = HEAP32[$103>>2]|0;
 __THREW__ = 0;
 (invoke_ii($104|0,($3|0))|0);
 $105 = __THREW__; __THREW__ = 0;
 $106 = $105&1;
 if ($106) {
  $107 = ___cxa_find_matching_catch_3(0|0)|0;
  $108 = tempRet0;
  ___clang_call_terminate($107);
  // unreachable;
 } else {
  ___resumeException($$112|0);
  // unreachable;
 }
 return (0)|0;
}
function __ZN5osgDB8Registry29createLibraryNameForExtensionERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$016$i$i25 = 0, $$017$i$i26 = 0, $$02026$i$i62 = 0, $$02125$i$i63 = 0, $$027$i$i61 = 0, $$1 = 0, $$16 = 0, $$2 = 0, $$27 = 0, $$3 = 0, $$38 = 0, $$4 = 0, $$49 = 0, $$5 = 0, $$510 = 0, $$6 = 0, $$611 = 0, $$8 = 0, $$813 = 0, $$pre$i = 0;
 var $$sroa$054$0$ph = 0, $$sroa$054$064 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $phitmp$i = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(112|0);
 $3 = sp + 96|0;
 $4 = sp + 84|0;
 $5 = sp + 72|0;
 $6 = sp + 60|0;
 $7 = sp + 48|0;
 $8 = sp + 36|0;
 $9 = sp + 24|0;
 $10 = sp + 12|0;
 $11 = sp;
 ;HEAP32[$3>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;
 $12 = ((($2)) + 11|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = ($13<<24>>24)<(0);
 $15 = ((($2)) + 4|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $13&255;
 $18 = $14 ? $16 : $17;
 $19 = ($18|0)==(0);
 L1: do {
  if ($19) {
   label = 3;
  } else {
   $20 = HEAP32[$2>>2]|0;
   $$sroa$054$0$ph = $14 ? $20 : $2;
   $$sroa$054$064 = $$sroa$054$0$ph;
   while(1) {
    $25 = HEAP8[$$sroa$054$064>>0]|0;
    $26 = $25 << 24 >> 24;
    $27 = (_tolower($26)|0);
    $28 = $27&255;
    __THREW__ = 0;
    invoke_vii(3433,($3|0),($28|0));
    $29 = __THREW__; __THREW__ = 0;
    $30 = $29&1;
    if ($30) {
     break;
    }
    $31 = ((($$sroa$054$064)) + 1|0);
    $32 = HEAP8[$12>>0]|0;
    $33 = ($32<<24>>24)<(0);
    $34 = HEAP32[$2>>2]|0;
    $35 = HEAP32[$15>>2]|0;
    $36 = $32&255;
    $37 = $33 ? $34 : $2;
    $38 = $33 ? $35 : $36;
    $39 = (($37) + ($38)|0);
    $40 = ($31|0)==($39|0);
    if ($40) {
     label = 3;
     break L1;
    } else {
     $$sroa$054$064 = $31;
    }
   }
   $41 = ___cxa_find_matching_catch_2()|0;
   $42 = tempRet0;
   $$8 = $42;$$813 = $41;
  }
 } while(0);
 L7: do {
  if ((label|0) == 3) {
   $21 = ((($1)) + 136|0);
   __THREW__ = 0;
   $22 = (invoke_iii(4191,($21|0),($3|0))|0);
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if ($24) {
    $77 = ___cxa_find_matching_catch_2()|0;
    $78 = tempRet0;
    $$8 = $78;$$813 = $77;
    break;
   }
   $43 = ((($1)) + 140|0);
   $44 = ($22|0)==($43|0);
   L12: do {
    if ($44) {
     label = 19;
    } else {
     $45 = ((($22)) + 28|0);
     $46 = HEAP8[$12>>0]|0;
     $47 = ($46<<24>>24)<(0);
     $48 = HEAP32[$15>>2]|0;
     $49 = $46&255;
     $50 = $47 ? $48 : $49;
     $51 = ((($45)) + 11|0);
     $52 = HEAP8[$51>>0]|0;
     $53 = ($52<<24>>24)<(0);
     $54 = ((($22)) + 32|0);
     $55 = HEAP32[$54>>2]|0;
     $56 = $52&255;
     $57 = $53 ? $55 : $56;
     $58 = ($50|0)==($57|0);
     do {
      if ($58) {
       $59 = HEAP32[$2>>2]|0;
       $60 = $47 ? $59 : $2;
       $61 = HEAP32[$45>>2]|0;
       $62 = $53 ? $61 : $45;
       $63 = ($50|0)==(0);
       if ($47) {
        if ($63) {
         label = 19;
         break L12;
        }
        $74 = (_memcmp($60,$62,$50)|0);
        $phitmp$i = ($74|0)==(0);
        if ($phitmp$i) {
         label = 19;
         break L12;
        } else {
         break;
        }
       }
       if ($63) {
        label = 19;
        break L12;
       }
       $64 = $59;
       $65 = $64&255;
       $66 = HEAP8[$62>>0]|0;
       $67 = ($65<<24>>24)==($66<<24>>24);
       if ($67) {
        $$02026$i$i62 = $2;$$02125$i$i63 = $49;$$027$i$i61 = $62;
        while(1) {
         $68 = (($$02125$i$i63) + -1)|0;
         $69 = ((($$02026$i$i62)) + 1|0);
         $70 = ($68|0)==(0);
         if ($70) {
          label = 19;
          break L12;
         }
         $71 = ((($$027$i$i61)) + 1|0);
         $$pre$i = HEAP8[$69>>0]|0;
         $72 = HEAP8[$71>>0]|0;
         $73 = ($$pre$i<<24>>24)==($72<<24>>24);
         if ($73) {
          $$02026$i$i62 = $69;$$02125$i$i63 = $68;$$027$i$i61 = $71;
         } else {
          break;
         }
        }
       }
      }
     } while(0);
     __THREW__ = 0;
     invoke_viii(4192,($0|0),($1|0),($45|0));
     $75 = __THREW__; __THREW__ = 0;
     $76 = $75&1;
     if ($76) {
      $79 = ___cxa_find_matching_catch_2()|0;
      $80 = tempRet0;
      $$8 = $80;$$813 = $79;
      break L7;
     }
    }
   } while(0);
   L26: do {
    if ((label|0) == 19) {
     ;HEAP32[$6>>2]=0|0;HEAP32[$6+4>>2]=0|0;HEAP32[$6+8>>2]=0|0;
     __THREW__ = 0;
     $81 = (invoke_ii(3276,16)|0);
     $82 = __THREW__; __THREW__ = 0;
     $83 = $82&1;
     if ($83) {
      $151 = ___cxa_find_matching_catch_2()|0;
      $152 = tempRet0;
      $$3 = $152;$$38 = $151;
     } else {
      HEAP32[$6>>2] = $81;
      $84 = ((($6)) + 8|0);
      HEAP32[$84>>2] = -2147483632;
      $85 = ((($6)) + 4|0);
      HEAP32[$85>>2] = 11;
      dest=$81; src=167513; stop=dest+11|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
      $86 = ((($81)) + 11|0);
      HEAP8[$86>>0] = 0;
      __THREW__ = 0;
      $87 = (invoke_i(4193)|0);
      $88 = __THREW__; __THREW__ = 0;
      $89 = $88&1;
      do {
       if ($89) {
        label = 52;
       } else {
        ;HEAP32[$7>>2]=0|0;HEAP32[$7+4>>2]=0|0;HEAP32[$7+8>>2]=0|0;
        $90 = (_strlen($87)|0);
        $91 = ($90>>>0)>(4294967279);
        if ($91) {
         __THREW__ = 0;
         invoke_vi(3367,($7|0));
         $92 = __THREW__; __THREW__ = 0;
         label = 52;
         break;
        }
        $93 = ($90>>>0)<(11);
        if ($93) {
         $102 = $90&255;
         $103 = ((($7)) + 11|0);
         HEAP8[$103>>0] = $102;
         $104 = ($90|0)==(0);
         if ($104) {
          $$017$i$i26 = $7;
         } else {
          $$016$i$i25 = $7;
          label = 27;
         }
        } else {
         $94 = (($90) + 16)|0;
         $95 = $94 & -16;
         __THREW__ = 0;
         $96 = (invoke_ii(3276,($95|0))|0);
         $97 = __THREW__; __THREW__ = 0;
         $98 = $97&1;
         if ($98) {
          label = 52;
          break;
         }
         HEAP32[$7>>2] = $96;
         $99 = $95 | -2147483648;
         $100 = ((($7)) + 8|0);
         HEAP32[$100>>2] = $99;
         $101 = ((($7)) + 4|0);
         HEAP32[$101>>2] = $90;
         $$016$i$i25 = $96;
         label = 27;
        }
        if ((label|0) == 27) {
         _memcpy(($$016$i$i25|0),($87|0),($90|0))|0;
         $$017$i$i26 = $$016$i$i25;
        }
        $105 = (($$017$i$i26) + ($90)|0);
        HEAP8[$105>>0] = 0;
        __THREW__ = 0;
        invoke_viii(3550,($5|0),($6|0),($7|0));
        $106 = __THREW__; __THREW__ = 0;
        $107 = $106&1;
        do {
         if ($107) {
          $155 = ___cxa_find_matching_catch_2()|0;
          $156 = tempRet0;
          $$1 = $156;$$16 = $155;
         } else {
          ;HEAP32[$8>>2]=0|0;HEAP32[$8+4>>2]=0|0;HEAP32[$8+8>>2]=0|0;
          $108 = ((($8)) + 11|0);
          HEAP8[$108>>0] = 1;
          HEAP8[$8>>0] = 47;
          $109 = ((($8)) + 1|0);
          HEAP8[$109>>0] = 0;
          __THREW__ = 0;
          invoke_viii(3550,($4|0),($5|0),($8|0));
          $110 = __THREW__; __THREW__ = 0;
          $111 = $110&1;
          if ($111) {
           $157 = ___cxa_find_matching_catch_2()|0;
           $158 = tempRet0;
           $159 = HEAP8[$108>>0]|0;
           $160 = ($159<<24>>24)<(0);
           if ($160) {
            $161 = HEAP32[$8>>2]|0;
            __ZdlPv($161);
           }
           $162 = ((($5)) + 11|0);
           $163 = HEAP8[$162>>0]|0;
           $164 = ($163<<24>>24)<(0);
           if (!($164)) {
            $$1 = $158;$$16 = $157;
            break;
           }
           $165 = HEAP32[$5>>2]|0;
           __ZdlPv($165);
           $$1 = $158;$$16 = $157;
           break;
          }
          $112 = HEAP8[$108>>0]|0;
          $113 = ($112<<24>>24)<(0);
          if ($113) {
           $114 = HEAP32[$8>>2]|0;
           __ZdlPv($114);
          }
          $115 = ((($5)) + 11|0);
          $116 = HEAP8[$115>>0]|0;
          $117 = ($116<<24>>24)<(0);
          if ($117) {
           $118 = HEAP32[$5>>2]|0;
           __ZdlPv($118);
          }
          $119 = ((($7)) + 11|0);
          $120 = HEAP8[$119>>0]|0;
          $121 = ($120<<24>>24)<(0);
          if ($121) {
           $122 = HEAP32[$7>>2]|0;
           __ZdlPv($122);
          }
          $123 = ((($6)) + 11|0);
          $124 = HEAP8[$123>>0]|0;
          $125 = ($124<<24>>24)<(0);
          if ($125) {
           $126 = HEAP32[$6>>2]|0;
           __ZdlPv($126);
          }
          __THREW__ = 0;
          invoke_viii(3542,($11|0),($4|0),(167525|0));
          $127 = __THREW__; __THREW__ = 0;
          $128 = $127&1;
          do {
           if ($128) {
            $174 = ___cxa_find_matching_catch_2()|0;
            $175 = tempRet0;
            $$6 = $175;$$611 = $174;
           } else {
            __THREW__ = 0;
            invoke_viii(3550,($10|0),($11|0),($3|0));
            $129 = __THREW__; __THREW__ = 0;
            $130 = $129&1;
            do {
             if ($130) {
              $176 = ___cxa_find_matching_catch_2()|0;
              $177 = tempRet0;
              $$5 = $177;$$510 = $176;
             } else {
              __THREW__ = 0;
              invoke_viii(3542,($9|0),($10|0),(221531|0));
              $131 = __THREW__; __THREW__ = 0;
              $132 = $131&1;
              do {
               if ($132) {
                $178 = ___cxa_find_matching_catch_2()|0;
                $179 = tempRet0;
                $$4 = $179;$$49 = $178;
               } else {
                __THREW__ = 0;
                invoke_viii(3542,($0|0),($9|0),(167532|0));
                $133 = __THREW__; __THREW__ = 0;
                $134 = $133&1;
                if ($134) {
                 $180 = ___cxa_find_matching_catch_2()|0;
                 $181 = tempRet0;
                 $182 = ((($9)) + 11|0);
                 $183 = HEAP8[$182>>0]|0;
                 $184 = ($183<<24>>24)<(0);
                 if (!($184)) {
                  $$4 = $181;$$49 = $180;
                  break;
                 }
                 $185 = HEAP32[$9>>2]|0;
                 __ZdlPv($185);
                 $$4 = $181;$$49 = $180;
                 break;
                }
                $135 = ((($9)) + 11|0);
                $136 = HEAP8[$135>>0]|0;
                $137 = ($136<<24>>24)<(0);
                if ($137) {
                 $138 = HEAP32[$9>>2]|0;
                 __ZdlPv($138);
                }
                $139 = ((($10)) + 11|0);
                $140 = HEAP8[$139>>0]|0;
                $141 = ($140<<24>>24)<(0);
                if ($141) {
                 $142 = HEAP32[$10>>2]|0;
                 __ZdlPv($142);
                }
                $143 = ((($11)) + 11|0);
                $144 = HEAP8[$143>>0]|0;
                $145 = ($144<<24>>24)<(0);
                if ($145) {
                 $146 = HEAP32[$11>>2]|0;
                 __ZdlPv($146);
                }
                $147 = ((($4)) + 11|0);
                $148 = HEAP8[$147>>0]|0;
                $149 = ($148<<24>>24)<(0);
                if ($149) {
                 $150 = HEAP32[$4>>2]|0;
                 __ZdlPv($150);
                }
                break L26;
               }
              } while(0);
              $186 = ((($10)) + 11|0);
              $187 = HEAP8[$186>>0]|0;
              $188 = ($187<<24>>24)<(0);
              if (!($188)) {
               $$5 = $$4;$$510 = $$49;
               break;
              }
              $189 = HEAP32[$10>>2]|0;
              __ZdlPv($189);
              $$5 = $$4;$$510 = $$49;
             }
            } while(0);
            $190 = ((($11)) + 11|0);
            $191 = HEAP8[$190>>0]|0;
            $192 = ($191<<24>>24)<(0);
            if (!($192)) {
             $$6 = $$5;$$611 = $$510;
             break;
            }
            $193 = HEAP32[$11>>2]|0;
            __ZdlPv($193);
            $$6 = $$5;$$611 = $$510;
           }
          } while(0);
          $194 = ((($4)) + 11|0);
          $195 = HEAP8[$194>>0]|0;
          $196 = ($195<<24>>24)<(0);
          if ($196) {
           $197 = HEAP32[$4>>2]|0;
           __ZdlPv($197);
          }
          $$8 = $$6;$$813 = $$611;
          break L7;
         }
        } while(0);
        $166 = ((($7)) + 11|0);
        $167 = HEAP8[$166>>0]|0;
        $168 = ($167<<24>>24)<(0);
        if ($168) {
         $169 = HEAP32[$7>>2]|0;
         __ZdlPv($169);
         $$2 = $$1;$$27 = $$16;
        } else {
         $$2 = $$1;$$27 = $$16;
        }
       }
      } while(0);
      if ((label|0) == 52) {
       $153 = ___cxa_find_matching_catch_2()|0;
       $154 = tempRet0;
       $$2 = $154;$$27 = $153;
      }
      $170 = ((($6)) + 11|0);
      $171 = HEAP8[$170>>0]|0;
      $172 = ($171<<24>>24)<(0);
      if ($172) {
       $173 = HEAP32[$6>>2]|0;
       __ZdlPv($173);
       $$3 = $$2;$$38 = $$27;
      } else {
       $$3 = $$2;$$38 = $$27;
      }
     }
     $$8 = $$3;$$813 = $$38;
     break L7;
    }
   } while(0);
   $198 = ((($3)) + 11|0);
   $199 = HEAP8[$198>>0]|0;
   $200 = ($199<<24>>24)<(0);
   if (!($200)) {
    STACKTOP = sp;return;
   }
   $201 = HEAP32[$3>>2]|0;
   __ZdlPv($201);
   STACKTOP = sp;return;
  }
 } while(0);
 $202 = ((($3)) + 11|0);
 $203 = HEAP8[$202>>0]|0;
 $204 = ($203<<24>>24)<(0);
 if (!($204)) {
  ___resumeException($$813|0);
  // unreachable;
 }
 $205 = HEAP32[$3>>2]|0;
 __ZdlPv($205);
 ___resumeException($$813|0);
 // unreachable;
}
function __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES7_EENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE4findIS7_EENS_15__tree_iteratorIS8_PNS_11__tree_nodeIS8_PvEEiEERKT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$ph$lcssa$i = 0, $$0$ph15$i = 0, $$07$ph14$i = 0, $$0711$i = 0, $$sroa$0$0 = 0, $$sroa$speculated$i$i$i$i$i = 0, $$sroa$speculated$i$i$i$i$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 do {
  if (!($4)) {
   $5 = ((($1)) + 11|0);
   $6 = HEAP8[$5>>0]|0;
   $7 = ($6<<24>>24)<(0);
   $8 = ((($1)) + 4|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = $6&255;
   $11 = $7 ? $9 : $10;
   $12 = HEAP32[$1>>2]|0;
   $13 = $7 ? $12 : $1;
   $$0$ph15$i = $2;$$07$ph14$i = $3;
   L3: while(1) {
    $$0711$i = $$07$ph14$i;
    while(1) {
     $14 = ((($$0711$i)) + 16|0);
     $15 = ((($14)) + 11|0);
     $16 = HEAP8[$15>>0]|0;
     $17 = ($16<<24>>24)<(0);
     $18 = ((($$0711$i)) + 20|0);
     $19 = HEAP32[$18>>2]|0;
     $20 = $16&255;
     $21 = $17 ? $19 : $20;
     $22 = ($11>>>0)<($21>>>0);
     $$sroa$speculated$i$i$i$i$i$i = $22 ? $11 : $21;
     $23 = ($$sroa$speculated$i$i$i$i$i$i|0)==(0);
     if ($23) {
      label = 6;
     } else {
      $24 = HEAP32[$14>>2]|0;
      $25 = $17 ? $24 : $14;
      $26 = (_memcmp($25,$13,$$sroa$speculated$i$i$i$i$i$i)|0);
      $27 = ($26|0)==(0);
      if ($27) {
       label = 6;
      } else {
       $29 = ($26|0)<(0);
       if (!($29)) {
        break;
       }
      }
     }
     if ((label|0) == 6) {
      label = 0;
      $28 = ($21>>>0)<($11>>>0);
      if (!($28)) {
       break;
      }
     }
     $32 = ((($$0711$i)) + 4|0);
     $33 = HEAP32[$32>>2]|0;
     $34 = ($33|0)==(0|0);
     if ($34) {
      $$0$ph$lcssa$i = $$0$ph15$i;
      break L3;
     } else {
      $$0711$i = $33;
     }
    }
    $30 = HEAP32[$$0711$i>>2]|0;
    $31 = ($30|0)==(0|0);
    if ($31) {
     $$0$ph$lcssa$i = $$0711$i;
     break;
    } else {
     $$0$ph15$i = $$0711$i;$$07$ph14$i = $30;
    }
   }
   $35 = ($$0$ph$lcssa$i|0)==($2|0);
   if (!($35)) {
    $36 = ((($$0$ph$lcssa$i)) + 16|0);
    $37 = ((($36)) + 11|0);
    $38 = HEAP8[$37>>0]|0;
    $39 = ($38<<24>>24)<(0);
    $40 = ((($$0$ph$lcssa$i)) + 20|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = $38&255;
    $43 = $39 ? $41 : $42;
    $44 = ($43>>>0)<($11>>>0);
    $$sroa$speculated$i$i$i$i$i = $44 ? $43 : $11;
    $45 = ($$sroa$speculated$i$i$i$i$i|0)==(0);
    if (!($45)) {
     $46 = HEAP32[$36>>2]|0;
     $47 = $39 ? $46 : $36;
     $48 = (_memcmp($13,$47,$$sroa$speculated$i$i$i$i$i)|0);
     $49 = ($48|0)==(0);
     if (!($49)) {
      $51 = ($48|0)<(0);
      if ($51) {
       break;
      } else {
       $$sroa$0$0 = $$0$ph$lcssa$i;
      }
      return ($$sroa$0$0|0);
     }
    }
    $50 = ($11>>>0)<($43>>>0);
    if (!($50)) {
     $$sroa$0$0 = $$0$ph$lcssa$i;
     return ($$sroa$0$0|0);
    }
   }
  }
 } while(0);
 $$sroa$0$0 = $2;
 return ($$sroa$0$0|0);
}
function __ZNSt3__26vectorIN3osg7ref_ptrIN5osgDB14DynamicLibraryEEENS_9allocatorIS5_EEE21__push_back_slow_pathIKS5_EEvRT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$06$i$i = 0, $$pre = 0, $$pre$i = 0, $$pre38 = 0, $$pre39 = 0, $$sroa$7$0 = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(1073741823);
 $9 = $4;
 $10 = $3;
 if ($8) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $11 = ((($0)) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) - ($4))|0;
 $14 = $13 >> 2;
 $15 = ($14>>>0)<(536870911);
 $16 = $13 >> 1;
 $17 = ($16>>>0)<($7>>>0);
 $$sroa$speculated$i = $17 ? $7 : $16;
 $$sroa$speculated$$i = $15 ? $$sroa$speculated$i : 1073741823;
 $18 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($18) {
   $28 = 0;
  } else {
   $19 = ($$sroa$speculated$$i>>>0)>(1073741823);
   if (!($19)) {
    $25 = $$sroa$speculated$$i << 2;
    $26 = (__Znwj($25)|0);
    $28 = $26;
    break;
   }
   $20 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($20|0),(204840|0));
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if ($22) {
    $23 = ___cxa_find_matching_catch_2()|0;
    $24 = tempRet0;
    ___cxa_free_exception(($20|0));
    ___resumeException($23|0);
    // unreachable;
   } else {
    HEAP32[$20>>2] = (99824);
    ___cxa_throw(($20|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $27 = (($28) + ($6<<2)|0);
 $29 = $27;
 $30 = (($28) + ($$sroa$speculated$$i<<2)|0);
 $31 = $30;
 $32 = HEAP32[$1>>2]|0;
 HEAP32[$27>>2] = $32;
 $33 = ($32|0)==(0|0);
 if ($33) {
  $38 = $10;$40 = $9;
 } else {
  $34 = ((($32)) + 8|0);
  $35 = HEAP32[$34>>2]|0;HEAP32[$34>>2] = (($35+1)|0);
  $$pre = HEAP32[$0>>2]|0;
  $$pre38 = HEAP32[$2>>2]|0;
  $38 = $$pre38;$40 = $$pre;
 }
 $36 = ((($27)) + 4|0);
 $37 = $36;
 $39 = ($38|0)==($40|0);
 if ($39) {
  $41 = $38;
  $53 = $29;$54 = $41;$56 = $38;
 } else {
  $$06$i$i = $38;$$sroa$7$0 = $29;$44 = $27;
  while(1) {
   $42 = ((($$06$i$i)) + -4|0);
   $43 = ((($44)) + -4|0);
   $45 = HEAP32[$42>>2]|0;
   HEAP32[$43>>2] = $45;
   $46 = ($45|0)==(0|0);
   if (!($46)) {
    $47 = ((($45)) + 8|0);
    $48 = HEAP32[$47>>2]|0;HEAP32[$47>>2] = (($48+1)|0);
   }
   $49 = $$sroa$7$0;
   $50 = ((($49)) + -4|0);
   $51 = $50;
   $52 = ($42|0)==($40|0);
   if ($52) {
    break;
   } else {
    $$06$i$i = $42;$$sroa$7$0 = $51;$44 = $50;
   }
  }
  $$pre$i = HEAP32[$0>>2]|0;
  $$pre39 = HEAP32[$2>>2]|0;
  $53 = $51;$54 = $$pre$i;$56 = $$pre39;
 }
 HEAP32[$0>>2] = $53;
 HEAP32[$2>>2] = $37;
 HEAP32[$11>>2] = $31;
 $55 = $54;
 $57 = ($56|0)==($55|0);
 L25: do {
  if (!($57)) {
   $59 = $56;
   while(1) {
    $58 = ((($59)) + -4|0);
    $60 = HEAP32[$58>>2]|0;
    $61 = ($60|0)==(0|0);
    if (!($61)) {
     $62 = ((($60)) + 8|0);
     $63 = HEAP32[$62>>2]|0;HEAP32[$62>>2] = (($63-1)|0);
     $64 = ($63|0)==(1);
     if ($64) {
      __THREW__ = 0;
      invoke_viii(3262,($60|0),1,1);
      $65 = __THREW__; __THREW__ = 0;
      $66 = $65&1;
      if ($66) {
       break;
      }
     }
    }
    HEAP32[$58>>2] = 0;
    $67 = ($58|0)==($55|0);
    if ($67) {
     break L25;
    } else {
     $59 = $58;
    }
   }
   $68 = ___cxa_find_matching_catch_2()|0;
   $69 = tempRet0;
   ___cxa_call_unexpected(($68|0));
   // unreachable;
  }
 } while(0);
 $70 = ($54|0)==(0);
 if ($70) {
  return;
 }
 $71 = $54;
 __ZdlPv($71);
 return;
}
function __ZNSt3__26vectorIN3osg7ref_ptrIN5osgDB12ReaderWriterEEENS_9allocatorIS5_EEE21__push_back_slow_pathIKS5_EEvRT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$06$i$i = 0, $$pre = 0, $$pre$i = 0, $$pre38 = 0, $$pre39 = 0, $$sroa$7$0 = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(1073741823);
 $9 = $4;
 $10 = $3;
 if ($8) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $11 = ((($0)) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) - ($4))|0;
 $14 = $13 >> 2;
 $15 = ($14>>>0)<(536870911);
 $16 = $13 >> 1;
 $17 = ($16>>>0)<($7>>>0);
 $$sroa$speculated$i = $17 ? $7 : $16;
 $$sroa$speculated$$i = $15 ? $$sroa$speculated$i : 1073741823;
 $18 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($18) {
   $28 = 0;
  } else {
   $19 = ($$sroa$speculated$$i>>>0)>(1073741823);
   if (!($19)) {
    $25 = $$sroa$speculated$$i << 2;
    $26 = (__Znwj($25)|0);
    $28 = $26;
    break;
   }
   $20 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($20|0),(204840|0));
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if ($22) {
    $23 = ___cxa_find_matching_catch_2()|0;
    $24 = tempRet0;
    ___cxa_free_exception(($20|0));
    ___resumeException($23|0);
    // unreachable;
   } else {
    HEAP32[$20>>2] = (99824);
    ___cxa_throw(($20|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $27 = (($28) + ($6<<2)|0);
 $29 = $27;
 $30 = (($28) + ($$sroa$speculated$$i<<2)|0);
 $31 = $30;
 $32 = HEAP32[$1>>2]|0;
 HEAP32[$27>>2] = $32;
 $33 = ($32|0)==(0|0);
 if ($33) {
  $38 = $10;$40 = $9;
 } else {
  $34 = ((($32)) + 8|0);
  $35 = HEAP32[$34>>2]|0;HEAP32[$34>>2] = (($35+1)|0);
  $$pre = HEAP32[$0>>2]|0;
  $$pre38 = HEAP32[$2>>2]|0;
  $38 = $$pre38;$40 = $$pre;
 }
 $36 = ((($27)) + 4|0);
 $37 = $36;
 $39 = ($38|0)==($40|0);
 if ($39) {
  $41 = $38;
  $53 = $29;$54 = $41;$56 = $38;
 } else {
  $$06$i$i = $38;$$sroa$7$0 = $29;$44 = $27;
  while(1) {
   $42 = ((($$06$i$i)) + -4|0);
   $43 = ((($44)) + -4|0);
   $45 = HEAP32[$42>>2]|0;
   HEAP32[$43>>2] = $45;
   $46 = ($45|0)==(0|0);
   if (!($46)) {
    $47 = ((($45)) + 8|0);
    $48 = HEAP32[$47>>2]|0;HEAP32[$47>>2] = (($48+1)|0);
   }
   $49 = $$sroa$7$0;
   $50 = ((($49)) + -4|0);
   $51 = $50;
   $52 = ($42|0)==($40|0);
   if ($52) {
    break;
   } else {
    $$06$i$i = $42;$$sroa$7$0 = $51;$44 = $50;
   }
  }
  $$pre$i = HEAP32[$0>>2]|0;
  $$pre39 = HEAP32[$2>>2]|0;
  $53 = $51;$54 = $$pre$i;$56 = $$pre39;
 }
 HEAP32[$0>>2] = $53;
 HEAP32[$2>>2] = $37;
 HEAP32[$11>>2] = $31;
 $55 = $54;
 $57 = ($56|0)==($55|0);
 L25: do {
  if (!($57)) {
   $59 = $56;
   while(1) {
    $58 = ((($59)) + -4|0);
    $60 = HEAP32[$58>>2]|0;
    $61 = ($60|0)==(0|0);
    if (!($61)) {
     $62 = ((($60)) + 8|0);
     $63 = HEAP32[$62>>2]|0;HEAP32[$62>>2] = (($63-1)|0);
     $64 = ($63|0)==(1);
     if ($64) {
      __THREW__ = 0;
      invoke_viii(3262,($60|0),1,1);
      $65 = __THREW__; __THREW__ = 0;
      $66 = $65&1;
      if ($66) {
       break;
      }
     }
    }
    HEAP32[$58>>2] = 0;
    $67 = ($58|0)==($55|0);
    if ($67) {
     break L25;
    } else {
     $59 = $58;
    }
   }
   $68 = ___cxa_find_matching_catch_2()|0;
   $69 = tempRet0;
   ___cxa_call_unexpected(($68|0));
   // unreachable;
  }
 } while(0);
 $70 = ($54|0)==(0);
 if ($70) {
  return;
 }
 $71 = $54;
 __ZdlPv($71);
 return;
}
function __ZN5osgDB8Registry27getReaderWriterForExtensionERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i$i$i = 0, $$0$ph$i$i$i$i = 0, $$0$ph$lcssa$i$i$i = 0, $$0$ph13$i$i$i = 0, $$024$i$i$i$i = 0, $$025$i$i$i$i = 0, $$036$i$i$i = 0, $$07$ph12$i$i$i = 0, $$0710$i$i$i = 0, $$219 = 0, $$3 = 0, $$314 = 0, $$320 = 0, $$5 = 0, $$516 = 0, $$in$i$i$i$i = 0, $$pre = 0, $$pre$i$i$i$i = 0, $$pre104 = 0, $$sink65$index = 0;
 var $$sink65$index3 = 0, $$sroa$038$084 = 0, $$sroa$053$085 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $2 = sp + 24|0;
 $3 = sp + 12|0;
 $4 = sp;
 $5 = ((($3)) + 4|0);
 HEAP32[$5>>2] = 0;
 $6 = ((($3)) + 8|0);
 HEAP32[$6>>2] = 0;
 $7 = ((($3)) + 4|0);
 HEAP32[$3>>2] = $7;
 $8 = ((($0)) + 60|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($9)) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 __THREW__ = 0;
 (invoke_ii($11|0,($8|0))|0);
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $22 = ___cxa_find_matching_catch_2()|0;
  $23 = tempRet0;
  $$5 = $23;$$516 = $22;
  $174 = HEAP32[$7>>2]|0;
  __ZNSt3__26__treeIPN5osgDB12ReaderWriterENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($3,$174);
  ___resumeException($$516|0);
  // unreachable;
 }
 $14 = ((($0)) + 72|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ((($0)) + 76|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($15|0)==($17|0);
 L5: do {
  if ($18) {
   label = 25;
  } else {
   $$sroa$053$085 = $15;
   while(1) {
    $24 = HEAP32[$$sroa$053$085>>2]|0;
    $25 = $24;
    $26 = HEAP32[$7>>2]|0;
    $27 = ($26|0)==(0|0);
    do {
     if ($27) {
      $$025$i$i$i$i = $7;$$036$i$i$i = $7;
     } else {
      $$0$i$i$i$i = $5;$$024$i$i$i$i = $26;
      while(1) {
       $28 = ((($$024$i$i$i$i)) + 16|0);
       $29 = HEAP32[$28>>2]|0;
       $30 = ($24>>>0)<($29>>>0);
       if ($30) {
        $31 = HEAP32[$$024$i$i$i$i>>2]|0;
        $32 = ($31|0)==(0|0);
        if ($32) {
         label = 10;
         break;
        } else {
         $$0$ph$i$i$i$i = $$024$i$i$i$i;$$in$i$i$i$i = $31;
        }
       } else {
        $33 = ($29>>>0)<($24>>>0);
        if (!($33)) {
         label = 14;
         break;
        }
        $34 = ((($$024$i$i$i$i)) + 4|0);
        $35 = HEAP32[$34>>2]|0;
        $36 = ($35|0)==(0|0);
        if ($36) {
         label = 13;
         break;
        } else {
         $$0$ph$i$i$i$i = $34;$$in$i$i$i$i = $35;
        }
       }
       $$0$i$i$i$i = $$0$ph$i$i$i$i;$$024$i$i$i$i = $$in$i$i$i$i;
      }
      if ((label|0) == 10) {
       label = 0;
       $$025$i$i$i$i = $$024$i$i$i$i;$$036$i$i$i = $$024$i$i$i$i;
       break;
      }
      else if ((label|0) == 13) {
       label = 0;
       $$025$i$i$i$i = $34;$$036$i$i$i = $$024$i$i$i$i;
       break;
      }
      else if ((label|0) == 14) {
       label = 0;
       $$025$i$i$i$i = $$0$i$i$i$i;$$036$i$i$i = $$024$i$i$i$i;
       break;
      }
     }
    } while(0);
    $37 = HEAP32[$$025$i$i$i$i>>2]|0;
    $38 = ($37|0)==(0|0);
    if ($38) {
     __THREW__ = 0;
     $39 = (invoke_ii(3276,20)|0);
     $40 = __THREW__; __THREW__ = 0;
     $41 = $40&1;
     if ($41) {
      label = 22;
      break;
     }
     $42 = ((($39)) + 16|0);
     HEAP32[$42>>2] = $25;
     HEAP32[$39>>2] = 0;
     $43 = ((($39)) + 4|0);
     HEAP32[$43>>2] = 0;
     $44 = ((($39)) + 8|0);
     HEAP32[$44>>2] = $$036$i$i$i;
     HEAP32[$$025$i$i$i$i>>2] = $39;
     $45 = HEAP32[$3>>2]|0;
     $46 = HEAP32[$45>>2]|0;
     $47 = ($46|0)==(0|0);
     if ($47) {
      $50 = $39;
     } else {
      $48 = $46;
      HEAP32[$3>>2] = $48;
      $$pre$i$i$i$i = HEAP32[$$025$i$i$i$i>>2]|0;
      $50 = $$pre$i$i$i$i;
     }
     $49 = HEAP32[$5>>2]|0;
     __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($49,$50);
     $51 = HEAP32[$6>>2]|0;
     $52 = (($51) + 1)|0;
     HEAP32[$6>>2] = $52;
     $$pre = HEAP32[$$sroa$053$085>>2]|0;
     $54 = $$pre;
    } else {
     $54 = $24;
    }
    $53 = HEAP32[$54>>2]|0;
    $55 = ((($53)) + 152|0);
    $56 = HEAP32[$55>>2]|0;
    __THREW__ = 0;
    $57 = (invoke_iii($56|0,($54|0),($1|0))|0);
    $58 = __THREW__; __THREW__ = 0;
    $59 = $58&1;
    if ($59) {
     label = 23;
     break;
    }
    $20 = ((($$sroa$053$085)) + 4|0);
    if ($57) {
     label = 24;
     break;
    }
    $19 = HEAP32[$16>>2]|0;
    $21 = ($20|0)==($19|0);
    if ($21) {
     label = 25;
     break L5;
    } else {
     $$sroa$053$085 = $20;
    }
   }
   if ((label|0) == 22) {
    $60 = ___cxa_find_matching_catch_2()|0;
    $61 = tempRet0;
    $$3 = $61;$$314 = $60;
    label = 68;
    break;
   }
   else if ((label|0) == 23) {
    $62 = ___cxa_find_matching_catch_2()|0;
    $63 = tempRet0;
    $$3 = $63;$$314 = $62;
    label = 68;
    break;
   }
   else if ((label|0) == 24) {
    $64 = HEAP32[$$sroa$053$085>>2]|0;
    $$320 = $64;
    break;
   }
  }
 } while(0);
 L35: do {
  if ((label|0) == 25) {
   __THREW__ = 0;
   invoke_viii(4192,($4|0),($0|0),($1|0));
   $65 = __THREW__; __THREW__ = 0;
   $66 = $65&1;
   if ($66) {
    $115 = ___cxa_find_matching_catch_2()|0;
    $116 = tempRet0;
    $$3 = $116;$$314 = $115;
    label = 68;
    break;
   }
   __THREW__ = 0;
   $67 = (invoke_ii(3265,4)|0);
   $68 = __THREW__; __THREW__ = 0;
   $69 = $68&1;
   L40: do {
    if ($69) {
     label = 41;
    } else {
     do {
      if ($67) {
       __THREW__ = 0;
       $70 = (invoke_ii(3266,4)|0);
       $71 = __THREW__; __THREW__ = 0;
       $72 = $71&1;
       if ($72) {
        label = 41;
        break L40;
       }
       __THREW__ = 0;
       $73 = (invoke_iiii(3267,($70|0),(167536|0),25)|0);
       $74 = __THREW__; __THREW__ = 0;
       $75 = $74&1;
       if ($75) {
        label = 41;
        break L40;
       }
       $76 = ((($4)) + 11|0);
       $77 = HEAP8[$76>>0]|0;
       $78 = ($77<<24>>24)<(0);
       $79 = HEAP32[$4>>2]|0;
       $80 = $78 ? $79 : $4;
       $81 = ((($4)) + 4|0);
       $82 = HEAP32[$81>>2]|0;
       $83 = $77&255;
       $84 = $78 ? $82 : $83;
       __THREW__ = 0;
       $85 = (invoke_iiii(3267,($73|0),($80|0),($84|0))|0);
       $86 = __THREW__; __THREW__ = 0;
       $87 = $86&1;
       if ($87) {
        label = 41;
        break L40;
       }
       $88 = HEAP32[$85>>2]|0;
       $89 = ((($88)) + -12|0);
       $90 = HEAP32[$89>>2]|0;
       $91 = (($85) + ($90)|0);
       __THREW__ = 0;
       invoke_vii(3257,($2|0),($91|0));
       $92 = __THREW__; __THREW__ = 0;
       $93 = $92&1;
       if ($93) {
        label = 41;
        break L40;
       }
       __THREW__ = 0;
       $94 = (invoke_iii(3255,($2|0),(215188|0))|0);
       $95 = __THREW__; __THREW__ = 0;
       $96 = $95&1;
       if (!($96)) {
        $97 = HEAP32[$94>>2]|0;
        $98 = ((($97)) + 28|0);
        $99 = HEAP32[$98>>2]|0;
        __THREW__ = 0;
        $100 = (invoke_iii($99|0,($94|0),10)|0);
        $101 = __THREW__; __THREW__ = 0;
        $102 = $101&1;
        if (!($102)) {
         __THREW__ = 0;
         invoke_vi(3263,($2|0));
         $109 = __THREW__; __THREW__ = 0;
         $110 = $109&1;
         if ($110) {
          label = 41;
          break L40;
         }
         __THREW__ = 0;
         (invoke_iii(3268,($85|0),($100|0))|0);
         $111 = __THREW__; __THREW__ = 0;
         $112 = $111&1;
         if ($112) {
          label = 41;
          break L40;
         }
         __THREW__ = 0;
         (invoke_ii(3269,($85|0))|0);
         $113 = __THREW__; __THREW__ = 0;
         $114 = $113&1;
         if ($114) {
          label = 41;
          break L40;
         } else {
          break;
         }
        }
       }
       $103 = ___cxa_find_matching_catch_2()|0;
       $104 = tempRet0;
       __THREW__ = 0;
       invoke_vi(3263,($2|0));
       $105 = __THREW__; __THREW__ = 0;
       $106 = $105&1;
       if ($106) {
        $107 = ___cxa_find_matching_catch_3(0|0)|0;
        $108 = tempRet0;
        ___clang_call_terminate($107);
        // unreachable;
       } else {
        $$sink65$index = $103;$$sink65$index3 = $104;
        break L40;
       }
      }
     } while(0);
     __THREW__ = 0;
     $119 = (invoke_iii(4194,($0|0),($4|0))|0);
     $120 = __THREW__; __THREW__ = 0;
     $121 = $120&1;
     if ($121) {
      label = 41;
     } else {
      $122 = ($119|0)==(2);
      L59: do {
       if ($122) {
        $123 = HEAP32[$14>>2]|0;
        $124 = HEAP32[$16>>2]|0;
        $125 = ($123|0)==($124|0);
        if ($125) {
         $$219 = 0;
        } else {
         $$sroa$038$084 = $123;$177 = $124;
         while(1) {
          $126 = HEAP32[$$sroa$038$084>>2]|0;
          $127 = HEAP32[$7>>2]|0;
          $128 = ($127|0)==(0|0);
          if ($128) {
           label = 53;
          } else {
           $$0$ph13$i$i$i = $7;$$07$ph12$i$i$i = $127;
           L65: while(1) {
            $$0710$i$i$i = $$07$ph12$i$i$i;
            while(1) {
             $129 = ((($$0710$i$i$i)) + 16|0);
             $130 = HEAP32[$129>>2]|0;
             $131 = ($130>>>0)<($126>>>0);
             if (!($131)) {
              break;
             }
             $134 = ((($$0710$i$i$i)) + 4|0);
             $135 = HEAP32[$134>>2]|0;
             $136 = ($135|0)==(0|0);
             if ($136) {
              $$0$ph$lcssa$i$i$i = $$0$ph13$i$i$i;
              break L65;
             } else {
              $$0710$i$i$i = $135;
             }
            }
            $132 = HEAP32[$$0710$i$i$i>>2]|0;
            $133 = ($132|0)==(0|0);
            if ($133) {
             $$0$ph$lcssa$i$i$i = $$0710$i$i$i;
             break;
            } else {
             $$0$ph13$i$i$i = $$0710$i$i$i;$$07$ph12$i$i$i = $132;
            }
           }
           $137 = ($$0$ph$lcssa$i$i$i|0)==($7|0);
           if ($137) {
            label = 53;
           } else {
            $138 = ((($$0$ph$lcssa$i$i$i)) + 16|0);
            $139 = HEAP32[$138>>2]|0;
            $140 = ($126>>>0)<($139>>>0);
            if ($140) {
             label = 53;
            } else {
             $149 = $177;
            }
           }
          }
          if ((label|0) == 53) {
           label = 0;
           $141 = HEAP32[$126>>2]|0;
           $142 = ((($141)) + 152|0);
           $143 = HEAP32[$142>>2]|0;
           __THREW__ = 0;
           $144 = (invoke_iii($143|0,($126|0),($1|0))|0);
           $145 = __THREW__; __THREW__ = 0;
           $146 = $145&1;
           if ($146) {
            label = 58;
            break;
           }
           if ($144) {
            label = 57;
            break;
           }
           $$pre104 = HEAP32[$16>>2]|0;
           $149 = $$pre104;
          }
          $147 = ((($$sroa$038$084)) + 4|0);
          $148 = ($147|0)==($149|0);
          if ($148) {
           $$219 = 0;
           break L59;
          } else {
           $$sroa$038$084 = $147;$177 = $149;
          }
         }
         if ((label|0) == 57) {
          $150 = HEAP32[$$sroa$038$084>>2]|0;
          $$219 = $150;
          break;
         }
         else if ((label|0) == 58) {
          $151 = ___cxa_find_matching_catch_2()|0;
          $152 = tempRet0;
          $$sink65$index = $151;$$sink65$index3 = $152;
          break L40;
         }
        }
       } else {
        $$219 = 0;
       }
      } while(0);
      $153 = ((($4)) + 11|0);
      $154 = HEAP8[$153>>0]|0;
      $155 = ($154<<24>>24)<(0);
      if ($155) {
       $156 = HEAP32[$4>>2]|0;
       __ZdlPv($156);
      }
      $$320 = $$219;
      break L35;
     }
    }
   } while(0);
   if ((label|0) == 41) {
    $117 = ___cxa_find_matching_catch_2()|0;
    $118 = tempRet0;
    $$sink65$index = $117;$$sink65$index3 = $118;
   }
   $157 = ((($4)) + 11|0);
   $158 = HEAP8[$157>>0]|0;
   $159 = ($158<<24>>24)<(0);
   if ($159) {
    $160 = HEAP32[$4>>2]|0;
    __ZdlPv($160);
   }
   $$3 = $$sink65$index3;$$314 = $$sink65$index;
   label = 68;
  }
 } while(0);
 if ((label|0) == 68) {
  $169 = HEAP32[$8>>2]|0;
  $170 = ((($169)) + 12|0);
  $171 = HEAP32[$170>>2]|0;
  __THREW__ = 0;
  (invoke_ii($171|0,($8|0))|0);
  $172 = __THREW__; __THREW__ = 0;
  $173 = $172&1;
  if ($173) {
   $175 = ___cxa_find_matching_catch_3(0|0)|0;
   $176 = tempRet0;
   ___clang_call_terminate($175);
   // unreachable;
  } else {
   $$5 = $$3;$$516 = $$314;
   $174 = HEAP32[$7>>2]|0;
   __ZNSt3__26__treeIPN5osgDB12ReaderWriterENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($3,$174);
   ___resumeException($$516|0);
   // unreachable;
  }
 }
 $161 = HEAP32[$8>>2]|0;
 $162 = ((($161)) + 12|0);
 $163 = HEAP32[$162>>2]|0;
 __THREW__ = 0;
 (invoke_ii($163|0,($8|0))|0);
 $164 = __THREW__; __THREW__ = 0;
 $165 = $164&1;
 if (!($165)) {
  $166 = HEAP32[$7>>2]|0;
  __ZNSt3__26__treeIPN5osgDB12ReaderWriterENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($3,$166);
  STACKTOP = sp;return ($$320|0);
 }
 $167 = ___cxa_find_matching_catch_2()|0;
 $168 = tempRet0;
 $$5 = $168;$$516 = $167;
 $174 = HEAP32[$7>>2]|0;
 __ZNSt3__26__treeIPN5osgDB12ReaderWriterENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($3,$174);
 ___resumeException($$516|0);
 // unreachable;
 return (0)|0;
}
function __ZNSt3__26__treeIPN5osgDB12ReaderWriterENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 } else {
  $3 = HEAP32[$1>>2]|0;
  __ZNSt3__26__treeIPN5osgDB12ReaderWriterENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($0,$3);
  $4 = ((($1)) + 4|0);
  $5 = HEAP32[$4>>2]|0;
  __ZNSt3__26__treeIPN5osgDB12ReaderWriterENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($0,$5);
  __ZdlPv($1);
  return;
 }
}
function __ZN5osgDB8Registry29findLibraryFileImplementationERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEPKNS_7OptionsENS_15CaseSensitivityE($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0 = 0, $$017 = 0, $$02026$i$i35 = 0, $$02125$i$i36 = 0, $$027$i$i34 = 0, $$1 = 0, $$118 = 0, $$2 = 0, $$219 = 0, $$pre$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0;
 var $163 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $5 = sp + 36|0;
 $6 = sp + 24|0;
 $7 = sp + 12|0;
 $8 = sp;
 $9 = ((($2)) + 11|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = ($10<<24>>24)<(0);
 $12 = ((($2)) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $10&255;
 $15 = $11 ? $13 : $14;
 $16 = ($15|0)==(0);
 if ($16) {
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_($0,$2);
  STACKTOP = sp;return;
 }
 $17 = (__ZN5osgDB8Registry8instanceEb(0)|0);
 $18 = ((($17)) + 188|0);
 __ZN5osgDB14findFileInPathERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEERKNS0_5dequeIS6_NS4_IS6_EEEENS_15CaseSensitivityE($6,$2,$18,$4);
 $19 = ((($6)) + 11|0);
 $20 = HEAP8[$19>>0]|0;
 $21 = ($20<<24>>24)<(0);
 $22 = ((($6)) + 4|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = $20&255;
 $25 = $21 ? $23 : $24;
 $26 = ($25|0)==(0);
 L5: do {
  if ($26) {
   __THREW__ = 0;
   $31 = (invoke_ii(4195,($2|0))|0);
   $32 = __THREW__; __THREW__ = 0;
   $33 = $32&1;
   if ($33) {
    label = 5;
   } else {
    if ($31) {
     __THREW__ = 0;
     $34 = (invoke_ii(3265,5)|0);
     $35 = __THREW__; __THREW__ = 0;
     $36 = $35&1;
     if ($36) {
      label = 5;
      break;
     }
     do {
      if ($34) {
       __THREW__ = 0;
       $37 = (invoke_ii(3266,5)|0);
       $38 = __THREW__; __THREW__ = 0;
       $39 = $38&1;
       if ($39) {
        label = 5;
        break L5;
       }
       __THREW__ = 0;
       $40 = (invoke_iiii(3267,($37|0),(167565|0),15)|0);
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if ($42) {
        label = 5;
        break L5;
       }
       $43 = HEAP8[$9>>0]|0;
       $44 = ($43<<24>>24)<(0);
       $45 = HEAP32[$2>>2]|0;
       $46 = $44 ? $45 : $2;
       $47 = HEAP32[$12>>2]|0;
       $48 = $43&255;
       $49 = $44 ? $47 : $48;
       __THREW__ = 0;
       $50 = (invoke_iiii(3267,($40|0),($46|0),($49|0))|0);
       $51 = __THREW__; __THREW__ = 0;
       $52 = $51&1;
       if ($52) {
        label = 5;
        break L5;
       }
       __THREW__ = 0;
       $53 = (invoke_iiii(3267,($50|0),(167581|0),13)|0);
       $54 = __THREW__; __THREW__ = 0;
       $55 = $54&1;
       if ($55) {
        label = 5;
        break L5;
       }
       $56 = HEAP8[$9>>0]|0;
       $57 = ($56<<24>>24)<(0);
       $58 = HEAP32[$2>>2]|0;
       $59 = $57 ? $58 : $2;
       $60 = HEAP32[$12>>2]|0;
       $61 = $56&255;
       $62 = $57 ? $60 : $61;
       __THREW__ = 0;
       $63 = (invoke_iiii(3267,($53|0),($59|0),($62|0))|0);
       $64 = __THREW__; __THREW__ = 0;
       $65 = $64&1;
       if ($65) {
        label = 5;
        break L5;
       }
       $66 = HEAP32[$63>>2]|0;
       $67 = ((($66)) + -12|0);
       $68 = HEAP32[$67>>2]|0;
       $69 = (($63) + ($68)|0);
       __THREW__ = 0;
       invoke_vii(3257,($5|0),($69|0));
       $70 = __THREW__; __THREW__ = 0;
       $71 = $70&1;
       if ($71) {
        label = 5;
        break L5;
       }
       __THREW__ = 0;
       $72 = (invoke_iii(3255,($5|0),(215188|0))|0);
       $73 = __THREW__; __THREW__ = 0;
       $74 = $73&1;
       if (!($74)) {
        $75 = HEAP32[$72>>2]|0;
        $76 = ((($75)) + 28|0);
        $77 = HEAP32[$76>>2]|0;
        __THREW__ = 0;
        $78 = (invoke_iii($77|0,($72|0),10)|0);
        $79 = __THREW__; __THREW__ = 0;
        $80 = $79&1;
        if (!($80)) {
         __THREW__ = 0;
         invoke_vi(3263,($5|0));
         $87 = __THREW__; __THREW__ = 0;
         $88 = $87&1;
         if ($88) {
          label = 5;
          break L5;
         }
         __THREW__ = 0;
         (invoke_iii(3268,($63|0),($78|0))|0);
         $89 = __THREW__; __THREW__ = 0;
         $90 = $89&1;
         if ($90) {
          label = 5;
          break L5;
         }
         __THREW__ = 0;
         (invoke_ii(3269,($63|0))|0);
         $91 = __THREW__; __THREW__ = 0;
         $92 = $91&1;
         if ($92) {
          label = 5;
          break L5;
         } else {
          break;
         }
        }
       }
       $81 = ___cxa_find_matching_catch_2()|0;
       $82 = tempRet0;
       __THREW__ = 0;
       invoke_vi(3263,($5|0));
       $83 = __THREW__; __THREW__ = 0;
       $84 = $83&1;
       if ($84) {
        $85 = ___cxa_find_matching_catch_3(0|0)|0;
        $86 = tempRet0;
        ___clang_call_terminate($85);
        // unreachable;
       } else {
        $eh$lpad$body$index2Z2D = $82;$eh$lpad$body$indexZ2D = $81;
        label = 6;
        break L5;
       }
      }
     } while(0);
     __THREW__ = 0;
     invoke_vii(3457,($0|0),($2|0));
     $93 = __THREW__; __THREW__ = 0;
     $94 = $93&1;
     if ($94) {
      label = 5;
      break;
     } else {
      label = 53;
      break;
     }
    }
    __THREW__ = 0;
    invoke_vii(4196,($7|0),($2|0));
    $95 = __THREW__; __THREW__ = 0;
    $96 = $95&1;
    if ($96) {
     label = 5;
    } else {
     $97 = ((($7)) + 11|0);
     $98 = HEAP8[$97>>0]|0;
     $99 = ($98<<24>>24)<(0);
     $100 = ((($7)) + 4|0);
     $101 = HEAP32[$100>>2]|0;
     $102 = $98&255;
     $103 = $99 ? $101 : $102;
     $104 = HEAP8[$9>>0]|0;
     $105 = ($104<<24>>24)<(0);
     $106 = HEAP32[$12>>2]|0;
     $107 = $104&255;
     $108 = $105 ? $106 : $107;
     $109 = ($103|0)==($108|0);
     L31: do {
      if ($109) {
       $110 = HEAP32[$7>>2]|0;
       $111 = $99 ? $110 : $7;
       $112 = HEAP32[$2>>2]|0;
       $113 = $105 ? $112 : $2;
       $114 = ($103|0)==(0);
       if ($99) {
        if ($114) {
         label = 46;
         break;
        }
        $125 = (_memcmp($111,$113,$103)|0);
        $phitmp$i = ($125|0)==(0);
        if ($phitmp$i) {
         label = 46;
         break;
        } else {
         label = 35;
         break;
        }
       }
       if ($114) {
        label = 46;
       } else {
        $115 = $110;
        $116 = $115&255;
        $117 = HEAP8[$113>>0]|0;
        $118 = ($116<<24>>24)==($117<<24>>24);
        if ($118) {
         $$02026$i$i35 = $7;$$02125$i$i36 = $102;$$027$i$i34 = $113;
         while(1) {
          $119 = (($$02125$i$i36) + -1)|0;
          $120 = ((($$02026$i$i35)) + 1|0);
          $121 = ($119|0)==(0);
          if ($121) {
           label = 46;
           break L31;
          }
          $122 = ((($$027$i$i34)) + 1|0);
          $$pre$i = HEAP8[$120>>0]|0;
          $123 = HEAP8[$122>>0]|0;
          $124 = ($$pre$i<<24>>24)==($123<<24>>24);
          if ($124) {
           $$02026$i$i35 = $120;$$02125$i$i36 = $119;$$027$i$i34 = $122;
          } else {
           label = 35;
           break;
          }
         }
        } else {
         label = 35;
        }
       }
      } else {
       label = 35;
      }
     } while(0);
     L41: do {
      if ((label|0) == 35) {
       __THREW__ = 0;
       invoke_viiii(4197,($8|0),($7|0),($18|0),($4|0));
       $126 = __THREW__; __THREW__ = 0;
       $127 = $126&1;
       do {
        if ($127) {
         $142 = ___cxa_find_matching_catch_2()|0;
         $143 = tempRet0;
         $$0 = $143;$$017 = $142;
         label = 44;
        } else {
         __THREW__ = 0;
         (invoke_iii(3477,($6|0),($8|0))|0);
         $128 = __THREW__; __THREW__ = 0;
         $129 = $128&1;
         if ($129) {
          $144 = ___cxa_find_matching_catch_2()|0;
          $145 = tempRet0;
          $146 = ((($8)) + 11|0);
          $147 = HEAP8[$146>>0]|0;
          $148 = ($147<<24>>24)<(0);
          if (!($148)) {
           $$0 = $145;$$017 = $144;
           label = 44;
           break;
          }
          $149 = HEAP32[$8>>2]|0;
          __ZdlPv($149);
          $$0 = $145;$$017 = $144;
          label = 44;
          break;
         }
         $130 = ((($8)) + 11|0);
         $131 = HEAP8[$130>>0]|0;
         $132 = ($131<<24>>24)<(0);
         if ($132) {
          $133 = HEAP32[$8>>2]|0;
          __ZdlPv($133);
         }
         $134 = HEAP8[$19>>0]|0;
         $135 = ($134<<24>>24)<(0);
         $136 = HEAP32[$22>>2]|0;
         $137 = $134&255;
         $138 = $135 ? $136 : $137;
         $139 = ($138|0)==(0);
         if ($139) {
          label = 46;
          break L41;
         }
         __THREW__ = 0;
         invoke_vii(3457,($0|0),($6|0));
         $140 = __THREW__; __THREW__ = 0;
         $141 = $140&1;
         if (!($141)) {
          break L41;
         }
         $150 = ___cxa_find_matching_catch_2()|0;
         $151 = tempRet0;
         $$1 = $151;$$118 = $150;
        }
       } while(0);
       if ((label|0) == 44) {
        $$1 = $$0;$$118 = $$017;
       }
       $155 = HEAP8[$97>>0]|0;
       $156 = ($155<<24>>24)<(0);
       if ($156) {
        $157 = HEAP32[$7>>2]|0;
        __ZdlPv($157);
       }
       $$2 = $$1;$$219 = $$118;
       break L5;
      }
     } while(0);
     if ((label|0) == 46) {
      ;HEAP32[$0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;
     }
     $152 = HEAP8[$97>>0]|0;
     $153 = ($152<<24>>24)<(0);
     if ($153) {
      $154 = HEAP32[$7>>2]|0;
      __ZdlPv($154);
     }
     label = 53;
    }
   }
  } else {
   __THREW__ = 0;
   invoke_vii(3457,($0|0),($6|0));
   $27 = __THREW__; __THREW__ = 0;
   $28 = $27&1;
   if ($28) {
    label = 5;
   } else {
    label = 53;
   }
  }
 } while(0);
 if ((label|0) == 5) {
  $29 = ___cxa_find_matching_catch_2()|0;
  $30 = tempRet0;
  $eh$lpad$body$index2Z2D = $30;$eh$lpad$body$indexZ2D = $29;
  label = 6;
 }
 else if ((label|0) == 53) {
  $158 = HEAP8[$19>>0]|0;
  $159 = ($158<<24>>24)<(0);
  if ($159) {
   $160 = HEAP32[$6>>2]|0;
   __ZdlPv($160);
  }
  STACKTOP = sp;return;
 }
 if ((label|0) == 6) {
  $$2 = $eh$lpad$body$index2Z2D;$$219 = $eh$lpad$body$indexZ2D;
 }
 $161 = HEAP8[$19>>0]|0;
 $162 = ($161<<24>>24)<(0);
 if (!($162)) {
  ___resumeException($$219|0);
  // unreachable;
 }
 $163 = HEAP32[$6>>2]|0;
 __ZdlPv($163);
 ___resumeException($$219|0);
 // unreachable;
}
function __ZN5osgDB8Registry4readERKNS0_11ReadFunctorE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$$i$i$i$i = 0, $$0 = 0, $$0$i$i = 0, $$0$i$i$i$i$i$i = 0, $$0$i$i$i$i$i$i218 = 0, $$0$i$i115 = 0, $$0$i$i162 = 0, $$0$i$i177 = 0, $$0$i$i253 = 0, $$0$i$i270 = 0, $$0$ph$lcssa$i$i$i$i$i = 0, $$0$ph$lcssa$i$i$i$i$i175 = 0, $$0$ph$lcssa$i$i$i$i$i199 = 0, $$0$ph$lcssa$i$i$i$i$i213 = 0, $$0$ph$lcssa$i$i$i$i$i251 = 0, $$0$ph$lcssa$i$i$i$i$i268 = 0, $$0$ph13$i$i$i$i$i = 0, $$0$ph13$i$i$i$i$i170 = 0, $$0$ph13$i$i$i$i$i195 = 0, $$0$ph13$i$i$i$i$i208 = 0;
 var $$0$ph13$i$i$i$i$i246 = 0, $$0$ph13$i$i$i$i$i263 = 0, $$02729$i$i$i = 0, $$02729$i$i$i110 = 0, $$04$i$i = 0, $$04$i$i222 = 0, $$065378 = 0, $$07$ph12$i$i$i$i$i = 0, $$07$ph12$i$i$i$i$i171 = 0, $$07$ph12$i$i$i$i$i196 = 0, $$07$ph12$i$i$i$i$i209 = 0, $$07$ph12$i$i$i$i$i247 = 0, $$07$ph12$i$i$i$i$i264 = 0, $$0710$i$i$i$i$i = 0, $$0710$i$i$i$i$i173 = 0, $$0710$i$i$i$i$i197 = 0, $$0710$i$i$i$i$i211 = 0, $$0710$i$i$i$i$i249 = 0, $$0710$i$i$i$i$i266 = 0, $$079 = 0;
 var $$1$i$i = 0, $$1$i$i117 = 0, $$11 = 0, $$1192 = 0, $$12 = 0, $$1293 = 0, $$13 = 0, $$1385 = 0, $$1394 = 0, $$14 = 0, $$1495 = 0, $$16 = 0, $$1697 = 0, $$17 = 0, $$173 = 0, $$1798 = 0, $$18 = 0, $$182 = 0, $$1899 = 0, $$19 = 0;
 var $$19100 = 0, $$2 = 0, $$2$i$i$i = 0, $$2$i$i$i114 = 0, $$20 = 0, $$20101 = 0, $$22 = 0, $$22103 = 0, $$25 = 0, $$25106 = 0, $$274389 = 0, $$283387 = 0, $$375 = 0, $$375393 = 0, $$384 = 0, $$384391 = 0, $$678 = 0, $$687 = 0, $$7 = 0, $$788 = 0;
 var $$8 = 0, $$889 = 0, $$pr = 0, $$pre = 0, $$pre$i$i = 0, $$pre$i$i161 = 0, $$pre$i$i166 = 0, $$pre$i$i192 = 0, $$pre$i$i204 = 0, $$pre$i$i242 = 0, $$pre$i$i259 = 0, $$pre$phi634Z2D = 0, $$pre$phi638Z2D = 0, $$pre$phi640Z2D = 0, $$pre$phi642Z2D = 0, $$pre$phiZ2D = 0, $$pre4$i$i = 0, $$pre5$i$i = 0, $$pre6$i$i = 0, $$pre630 = 0;
 var $$pre631 = 0, $$pre632 = 0, $$pre633 = 0, $$pre637 = 0, $$sroa$011$025$i$i = 0, $$sroa$011$025$i$i168 = 0, $$sroa$011$025$i$i244 = 0, $$sroa$011$025$i$i261 = 0, $$sroa$015$0$be$i$i = 0, $$sroa$015$0$be$i$i216 = 0, $$sroa$015$030$i$i = 0, $$sroa$015$030$i$i206 = 0, $$sroa$0369$0572 = 0, $10 = 0, $100 = 0, $1000 = 0, $1001 = 0, $1002 = 0, $1003 = 0, $1004 = 0;
 var $1005 = 0, $1006 = 0, $1007 = 0, $1008 = 0, $1009 = 0, $101 = 0, $1010 = 0, $1011 = 0, $1012 = 0, $1013 = 0, $1014 = 0, $1015 = 0, $1016 = 0, $1017 = 0, $1018 = 0, $1019 = 0, $102 = 0, $1020 = 0, $1021 = 0, $1022 = 0;
 var $1023 = 0, $1024 = 0, $1025 = 0, $1026 = 0, $1027 = 0, $1028 = 0, $1029 = 0, $103 = 0, $1030 = 0, $1031 = 0, $1032 = 0, $1033 = 0, $1034 = 0, $1035 = 0, $1036 = 0, $1037 = 0, $1038 = 0, $1039 = 0, $104 = 0, $1040 = 0;
 var $1041 = 0, $1042 = 0, $1043 = 0, $1044 = 0, $1045 = 0, $1046 = 0, $1047 = 0, $1048 = 0, $1049 = 0, $105 = 0, $1050 = 0, $1051 = 0, $1052 = 0, $1053 = 0, $1054 = 0, $1055 = 0, $1056 = 0, $1057 = 0, $1058 = 0, $1059 = 0;
 var $106 = 0, $1060 = 0, $1061 = 0, $1062 = 0, $1063 = 0, $1064 = 0, $1065 = 0, $1066 = 0, $1067 = 0, $1068 = 0, $1069 = 0, $107 = 0, $1070 = 0, $1071 = 0, $1072 = 0, $1073 = 0, $1074 = 0, $1075 = 0, $1076 = 0, $1077 = 0;
 var $1078 = 0, $1079 = 0, $108 = 0, $1080 = 0, $1081 = 0, $1082 = 0, $1083 = 0, $1084 = 0, $1085 = 0, $1086 = 0, $1087 = 0, $1088 = 0, $1089 = 0, $109 = 0, $1090 = 0, $1091 = 0, $1092 = 0, $1093 = 0, $1094 = 0, $1095 = 0;
 var $1096 = 0, $1097 = 0, $1098 = 0, $1099 = 0, $11 = 0, $110 = 0, $1100 = 0, $1101 = 0, $1102 = 0, $1103 = 0, $1104 = 0, $1105 = 0, $1106 = 0, $1107 = 0, $1108 = 0, $1109 = 0, $111 = 0, $1110 = 0, $1111 = 0, $1112 = 0;
 var $1113 = 0, $1114 = 0, $1115 = 0, $1116 = 0, $1117 = 0, $1118 = 0, $1119 = 0, $112 = 0, $1120 = 0, $1121 = 0, $1122 = 0, $1123 = 0, $1124 = 0, $1125 = 0, $1126 = 0, $1127 = 0, $1128 = 0, $1129 = 0, $113 = 0, $1130 = 0;
 var $1131 = 0, $1132 = 0, $1133 = 0, $1134 = 0, $1135 = 0, $1136 = 0, $1137 = 0, $1138 = 0, $1139 = 0, $114 = 0, $1140 = 0, $1141 = 0, $1142 = 0, $1143 = 0, $1144 = 0, $1145 = 0, $1146 = 0, $1147 = 0, $1148 = 0, $1149 = 0;
 var $115 = 0, $1150 = 0, $1151 = 0, $1152 = 0, $1153 = 0, $1154 = 0, $1155 = 0, $1156 = 0, $1157 = 0, $1158 = 0, $1159 = 0, $116 = 0, $1160 = 0, $1161 = 0, $1162 = 0, $1163 = 0, $1164 = 0, $1165 = 0, $1166 = 0, $1167 = 0;
 var $1168 = 0, $1169 = 0, $117 = 0, $1170 = 0, $1171 = 0, $1172 = 0, $1173 = 0, $1174 = 0, $1175 = 0, $1176 = 0, $1177 = 0, $1178 = 0, $1179 = 0, $118 = 0, $1180 = 0, $1181 = 0, $1182 = 0, $1183 = 0, $1184 = 0, $1185 = 0;
 var $1186 = 0, $1187 = 0, $1188 = 0, $1189 = 0, $119 = 0, $1190 = 0, $1191 = 0, $1192 = 0, $1193 = 0, $1194 = 0, $1195 = 0, $1196 = 0, $1197 = 0, $1198 = 0, $1199 = 0, $12 = 0, $120 = 0, $1200 = 0, $1201 = 0, $1202 = 0;
 var $1203 = 0, $1204 = 0, $1205 = 0, $1206 = 0, $1207 = 0, $1208 = 0, $1209 = 0, $121 = 0, $1210 = 0, $1211 = 0, $1212 = 0, $1213 = 0, $1214 = 0, $1215 = 0, $1216 = 0, $1217 = 0, $1218 = 0, $1219 = 0, $122 = 0, $1220 = 0;
 var $1221 = 0, $1222 = 0, $1223 = 0, $1224 = 0, $1225 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0;
 var $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0;
 var $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0;
 var $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0;
 var $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0;
 var $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0;
 var $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0;
 var $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0;
 var $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0;
 var $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0;
 var $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0;
 var $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0;
 var $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0;
 var $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0;
 var $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0;
 var $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0;
 var $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0;
 var $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0;
 var $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0;
 var $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0;
 var $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0;
 var $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0;
 var $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0;
 var $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0;
 var $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0;
 var $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0;
 var $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0;
 var $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0;
 var $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0;
 var $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0;
 var $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0;
 var $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0;
 var $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0;
 var $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0;
 var $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0;
 var $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0;
 var $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0;
 var $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0;
 var $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0;
 var $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = 0, $834 = 0, $835 = 0, $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = 0;
 var $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0, $850 = 0, $851 = 0, $852 = 0, $853 = 0, $854 = 0, $855 = 0, $856 = 0, $857 = 0, $858 = 0;
 var $859 = 0, $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0, $869 = 0, $87 = 0, $870 = 0, $871 = 0, $872 = 0, $873 = 0, $874 = 0, $875 = 0, $876 = 0;
 var $877 = 0, $878 = 0, $879 = 0, $88 = 0, $880 = 0, $881 = 0, $882 = 0, $883 = 0, $884 = 0, $885 = 0, $886 = 0, $887 = 0, $888 = 0, $889 = 0, $89 = 0, $890 = 0, $891 = 0, $892 = 0, $893 = 0, $894 = 0;
 var $895 = 0, $896 = 0, $897 = 0, $898 = 0, $899 = 0, $9 = 0, $90 = 0, $900 = 0, $901 = 0, $902 = 0, $903 = 0, $904 = 0, $905 = 0, $906 = 0, $907 = 0, $908 = 0, $909 = 0, $91 = 0, $910 = 0, $911 = 0;
 var $912 = 0, $913 = 0, $914 = 0, $915 = 0, $916 = 0, $917 = 0, $918 = 0, $919 = 0, $92 = 0, $920 = 0, $921 = 0, $922 = 0, $923 = 0, $924 = 0, $925 = 0, $926 = 0, $927 = 0, $928 = 0, $929 = 0, $93 = 0;
 var $930 = 0, $931 = 0, $932 = 0, $933 = 0, $934 = 0, $935 = 0, $936 = 0, $937 = 0, $938 = 0, $939 = 0, $94 = 0, $940 = 0, $941 = 0, $942 = 0, $943 = 0, $944 = 0, $945 = 0, $946 = 0, $947 = 0, $948 = 0;
 var $949 = 0, $95 = 0, $950 = 0, $951 = 0, $952 = 0, $953 = 0, $954 = 0, $955 = 0, $956 = 0, $957 = 0, $958 = 0, $959 = 0, $96 = 0, $960 = 0, $961 = 0, $962 = 0, $963 = 0, $964 = 0, $965 = 0, $966 = 0;
 var $967 = 0, $968 = 0, $969 = 0, $97 = 0, $970 = 0, $971 = 0, $972 = 0, $973 = 0, $974 = 0, $975 = 0, $976 = 0, $977 = 0, $978 = 0, $979 = 0, $98 = 0, $980 = 0, $981 = 0, $982 = 0, $983 = 0, $984 = 0;
 var $985 = 0, $986 = 0, $987 = 0, $988 = 0, $989 = 0, $99 = 0, $990 = 0, $991 = 0, $992 = 0, $993 = 0, $994 = 0, $995 = 0, $996 = 0, $997 = 0, $998 = 0, $999 = 0, $cond3 = 0, $cond4 = 0, $eh$lpad$body$index16Z2D = 0, $eh$lpad$body$indexZ2D = 0;
 var $eh$lpad$body137$indexZ2D = 0, $eh$lpad$body146$index6Z2D = 0, $eh$lpad$body146$indexZ2D = 0, $eh$lpad$body189$index30Z2D = 0, $eh$lpad$body189$indexZ2D = 0, $eh$lpad$body236$index39Z2D = 0, $eh$lpad$body236$indexZ2D = 0, $eh$lpad$body285$index49Z2D = 0, $eh$lpad$body285$indexZ2D = 0, $eh$lpad$body341$index23Z2D = 0, $eh$lpad$body341$indexZ2D = 0, $sum$i$i$i = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 272|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(272|0);
 $3 = sp + 264|0;
 $4 = sp + 260|0;
 $5 = sp + 256|0;
 $6 = sp + 252|0;
 $7 = sp + 248|0;
 $8 = sp;
 $9 = sp + 236|0;
 $10 = sp + 224|0;
 $11 = sp + 212|0;
 $12 = sp + 200|0;
 $13 = sp + 188|0;
 $14 = sp + 176|0;
 $15 = sp + 168|0;
 $16 = sp + 148|0;
 $17 = sp + 136|0;
 $18 = sp + 116|0;
 $19 = sp + 96|0;
 $20 = sp + 84|0;
 $21 = sp + 72|0;
 $22 = sp + 60|0;
 $23 = sp + 48|0;
 $24 = sp + 36|0;
 $25 = sp + 24|0;
 $26 = sp + 4|0;
 $27 = ((($1)) + 224|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = ((($1)) + 228|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ($28|0)==($30|0);
 L1: do {
  if ($31) {
   $$pre632 = ((($0)) + 16|0);
   $$pre633 = ((($0)) + 4|0);
   $$pre637 = ((($$pre633)) + 11|0);
   $$pre$phi634Z2D = $$pre633;$$pre$phi638Z2D = $$pre637;$$pre$phi640Z2D = $$pre633;$$pre$phi642Z2D = $0;$$pre$phiZ2D = $$pre632;
   label = 204;
  } else {
   $32 = ((($2)) + 4|0);
   $33 = ((($32)) + 11|0);
   $34 = ((($11)) + 11|0);
   $35 = ((($11)) + 4|0);
   $36 = ((($12)) + 11|0);
   $37 = ((($12)) + 4|0);
   $38 = ((($2)) + 8|0);
   $39 = ((($10)) + 11|0);
   $40 = ((($10)) + 4|0);
   $41 = ((($13)) + 11|0);
   $42 = ((($13)) + 4|0);
   $43 = ((($14)) + 11|0);
   $44 = ((($14)) + 4|0);
   $45 = ((($2)) + 16|0);
   $46 = ($16|0)==($0|0);
   $47 = ((($16)) + 16|0);
   $48 = ((($16)) + 4|0);
   $49 = ((($48)) + 11|0);
   $50 = ((($0)) + 16|0);
   $51 = ((($0)) + 4|0);
   $52 = ((($51)) + 11|0);
   $53 = ((($15)) + 4|0);
   $$sroa$0369$0572 = $28;
   L4: while(1) {
    __ZNSt3__2plIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_12basic_stringIT_T0_T1_EEPKS6_RKS9_($10,199839,$$sroa$0369$0572);
    __THREW__ = 0;
    invoke_viii(4198,($11|0),($10|0),47);
    $57 = __THREW__; __THREW__ = 0;
    $58 = $57&1;
    if ($58) {
     label = 28;
     break;
    }
    $59 = HEAP8[$33>>0]|0;
    $60 = ($59<<24>>24)<(0);
    $61 = HEAP32[$32>>2]|0;
    $62 = $60 ? $61 : $32;
    $63 = HEAP8[$34>>0]|0;
    $64 = ($63<<24>>24)<(0);
    $65 = HEAP32[$11>>2]|0;
    $66 = $64 ? $65 : $11;
    $67 = HEAP32[$35>>2]|0;
    $68 = $63&255;
    $69 = $64 ? $67 : $68;
    $70 = ($69|0)==(0);
    if ($70) {
     $$1$i$i = 0;
    } else {
     $71 = HEAP32[$38>>2]|0;
     $72 = $59&255;
     $73 = $60 ? $71 : $72;
     $74 = (($62) + ($73)|0);
     $75 = $74;
     $76 = $62;
     $77 = ($73|0)<($69|0);
     L9: do {
      if ($77) {
       $$2$i$i$i = $74;
      } else {
       $78 = HEAP8[$66>>0]|0;
       $79 = $78&255;
       $$02729$i$i$i = $62;$81 = $73;
       while(1) {
        $80 = (($81) - ($69))|0;
        $82 = (($80) + 1)|0;
        $83 = ($82|0)==(0);
        if ($83) {
         $$2$i$i$i = $74;
         break L9;
        }
        $84 = (_memchr($$02729$i$i$i,$79,$82)|0);
        $85 = ($84|0)==(0|0);
        if ($85) {
         $$2$i$i$i = $74;
         break L9;
        }
        $86 = (_memcmp($84,$66,$69)|0);
        $87 = ($86|0)==(0);
        if ($87) {
         $$2$i$i$i = $84;
         break L9;
        }
        $88 = ((($84)) + 1|0);
        $89 = $88;
        $90 = (($75) - ($89))|0;
        $91 = ($90|0)<($69|0);
        if ($91) {
         $$2$i$i$i = $74;
         break;
        } else {
         $$02729$i$i$i = $88;$81 = $90;
        }
       }
      }
     } while(0);
     $92 = ($$2$i$i$i|0)==($74|0);
     $93 = $$2$i$i$i;
     $94 = (($93) - ($76))|0;
     $$0$i$i = $92 ? -1 : $94;
     $$1$i$i = $$0$i$i;
    }
    if ($64) {
     __ZdlPv($65);
    }
    $95 = ($$1$i$i|0)==(-1);
    if ($95) {
     __THREW__ = 0;
     invoke_viii(4198,($12|0),($10|0),92);
     $96 = __THREW__; __THREW__ = 0;
     $97 = $96&1;
     if ($97) {
      label = 29;
      break;
     }
     $98 = HEAP8[$33>>0]|0;
     $99 = ($98<<24>>24)<(0);
     $100 = HEAP32[$32>>2]|0;
     $101 = $99 ? $100 : $32;
     $102 = HEAP8[$36>>0]|0;
     $103 = ($102<<24>>24)<(0);
     $104 = HEAP32[$12>>2]|0;
     $105 = $103 ? $104 : $12;
     $106 = HEAP32[$37>>2]|0;
     $107 = $102&255;
     $108 = $103 ? $106 : $107;
     $109 = ($108|0)==(0);
     if ($109) {
      $$1$i$i117 = 0;
     } else {
      $110 = HEAP32[$38>>2]|0;
      $111 = $98&255;
      $112 = $99 ? $110 : $111;
      $113 = (($101) + ($112)|0);
      $114 = $113;
      $115 = $101;
      $116 = ($112|0)<($108|0);
      L26: do {
       if ($116) {
        $$2$i$i$i114 = $113;
       } else {
        $117 = HEAP8[$105>>0]|0;
        $118 = $117&255;
        $$02729$i$i$i110 = $101;$120 = $112;
        while(1) {
         $119 = (($120) - ($108))|0;
         $121 = (($119) + 1)|0;
         $122 = ($121|0)==(0);
         if ($122) {
          $$2$i$i$i114 = $113;
          break L26;
         }
         $123 = (_memchr($$02729$i$i$i110,$118,$121)|0);
         $124 = ($123|0)==(0|0);
         if ($124) {
          $$2$i$i$i114 = $113;
          break L26;
         }
         $125 = (_memcmp($123,$105,$108)|0);
         $126 = ($125|0)==(0);
         if ($126) {
          $$2$i$i$i114 = $123;
          break L26;
         }
         $127 = ((($123)) + 1|0);
         $128 = $127;
         $129 = (($114) - ($128))|0;
         $130 = ($129|0)<($108|0);
         if ($130) {
          $$2$i$i$i114 = $113;
          break;
         } else {
          $$02729$i$i$i110 = $127;$120 = $129;
         }
        }
       }
      } while(0);
      $131 = ($$2$i$i$i114|0)==($113|0);
      $132 = $$2$i$i$i114;
      $133 = (($132) - ($115))|0;
      $$0$i$i115 = $131 ? -1 : $133;
      $$1$i$i117 = $$0$i$i115;
     }
     if ($103) {
      __ZdlPv($104);
     }
     $138 = ($$1$i$i117|0)==(-1);
     if ($138) {
      label = 197;
     } else {
      $$065378 = $$1$i$i117;
      label = 31;
     }
    } else {
     $$065378 = $$1$i$i;
     label = 31;
    }
    if ((label|0) == 31) {
     label = 0;
     $139 = HEAP8[$39>>0]|0;
     $140 = ($139<<24>>24)<(0);
     $141 = HEAP32[$40>>2]|0;
     $142 = $139&255;
     $143 = $140 ? $141 : $142;
     $144 = (($143) + ($$065378))|0;
     __THREW__ = 0;
     invoke_viiiii(3746,($13|0),($32|0),0,($144|0),($32|0));
     $145 = __THREW__; __THREW__ = 0;
     $146 = $145&1;
     if ($146) {
      label = 47;
      break;
     }
     $147 = (($144) + 1)|0;
     __THREW__ = 0;
     invoke_viiiii(3746,($14|0),($32|0),($147|0),-1,($32|0));
     $148 = __THREW__; __THREW__ = 0;
     $149 = $148&1;
     if ($149) {
      label = 48;
      break;
     }
     __THREW__ = 0;
     $150 = (invoke_ii(3265,4)|0);
     $151 = __THREW__; __THREW__ = 0;
     $152 = $151&1;
     if ($152) {
      label = 49;
      break;
     }
     if ($150) {
      __THREW__ = 0;
      $153 = (invoke_ii(3266,4)|0);
      $154 = __THREW__; __THREW__ = 0;
      $155 = $154&1;
      if ($155) {
       label = 49;
       break;
      }
      __THREW__ = 0;
      $156 = (invoke_iiii(3267,($153|0),(167595|0),19)|0);
      $157 = __THREW__; __THREW__ = 0;
      $158 = $157&1;
      if ($158) {
       label = 49;
       break;
      }
      $159 = HEAP8[$33>>0]|0;
      $160 = ($159<<24>>24)<(0);
      $161 = HEAP32[$32>>2]|0;
      $162 = $160 ? $161 : $32;
      $163 = HEAP32[$38>>2]|0;
      $164 = $159&255;
      $165 = $160 ? $163 : $164;
      __THREW__ = 0;
      $166 = (invoke_iiii(3267,($156|0),($162|0),($165|0))|0);
      $167 = __THREW__; __THREW__ = 0;
      $168 = $167&1;
      if ($168) {
       label = 49;
       break;
      }
      $169 = HEAP32[$166>>2]|0;
      $170 = ((($169)) + -12|0);
      $171 = HEAP32[$170>>2]|0;
      $172 = (($166) + ($171)|0);
      __THREW__ = 0;
      invoke_vii(3257,($7|0),($172|0));
      $173 = __THREW__; __THREW__ = 0;
      $174 = $173&1;
      if ($174) {
       label = 49;
       break;
      }
      __THREW__ = 0;
      $175 = (invoke_iii(3255,($7|0),(215188|0))|0);
      $176 = __THREW__; __THREW__ = 0;
      $177 = $176&1;
      if ($177) {
       label = 41;
       break;
      }
      $178 = HEAP32[$175>>2]|0;
      $179 = ((($178)) + 28|0);
      $180 = HEAP32[$179>>2]|0;
      __THREW__ = 0;
      $181 = (invoke_iii($180|0,($175|0),10)|0);
      $182 = __THREW__; __THREW__ = 0;
      $183 = $182&1;
      if ($183) {
       label = 41;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3263,($7|0));
      $190 = __THREW__; __THREW__ = 0;
      $191 = $190&1;
      if ($191) {
       label = 49;
       break;
      }
      __THREW__ = 0;
      (invoke_iii(3268,($166|0),($181|0))|0);
      $192 = __THREW__; __THREW__ = 0;
      $193 = $192&1;
      if ($193) {
       label = 49;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(3269,($166|0))|0);
      $194 = __THREW__; __THREW__ = 0;
      $195 = $194&1;
      if ($195) {
       label = 49;
       break;
      }
     }
     __THREW__ = 0;
     $202 = (invoke_ii(3265,4)|0);
     $203 = __THREW__; __THREW__ = 0;
     $204 = $203&1;
     if ($204) {
      label = 49;
      break;
     }
     if ($202) {
      __THREW__ = 0;
      $205 = (invoke_ii(3266,4)|0);
      $206 = __THREW__; __THREW__ = 0;
      $207 = $206&1;
      if ($207) {
       label = 49;
       break;
      }
      __THREW__ = 0;
      $208 = (invoke_iiii(3267,($205|0),(167615|0),19)|0);
      $209 = __THREW__; __THREW__ = 0;
      $210 = $209&1;
      if ($210) {
       label = 49;
       break;
      }
      $211 = HEAP8[$41>>0]|0;
      $212 = ($211<<24>>24)<(0);
      $213 = HEAP32[$13>>2]|0;
      $214 = $212 ? $213 : $13;
      $215 = HEAP32[$42>>2]|0;
      $216 = $211&255;
      $217 = $212 ? $215 : $216;
      __THREW__ = 0;
      $218 = (invoke_iiii(3267,($208|0),($214|0),($217|0))|0);
      $219 = __THREW__; __THREW__ = 0;
      $220 = $219&1;
      if ($220) {
       label = 49;
       break;
      }
      $221 = HEAP32[$218>>2]|0;
      $222 = ((($221)) + -12|0);
      $223 = HEAP32[$222>>2]|0;
      $224 = (($218) + ($223)|0);
      __THREW__ = 0;
      invoke_vii(3257,($6|0),($224|0));
      $225 = __THREW__; __THREW__ = 0;
      $226 = $225&1;
      if ($226) {
       label = 49;
       break;
      }
      __THREW__ = 0;
      $227 = (invoke_iii(3255,($6|0),(215188|0))|0);
      $228 = __THREW__; __THREW__ = 0;
      $229 = $228&1;
      if ($229) {
       label = 59;
       break;
      }
      $230 = HEAP32[$227>>2]|0;
      $231 = ((($230)) + 28|0);
      $232 = HEAP32[$231>>2]|0;
      __THREW__ = 0;
      $233 = (invoke_iii($232|0,($227|0),10)|0);
      $234 = __THREW__; __THREW__ = 0;
      $235 = $234&1;
      if ($235) {
       label = 59;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3263,($6|0));
      $242 = __THREW__; __THREW__ = 0;
      $243 = $242&1;
      if ($243) {
       label = 49;
       break;
      }
      __THREW__ = 0;
      (invoke_iii(3268,($218|0),($233|0))|0);
      $244 = __THREW__; __THREW__ = 0;
      $245 = $244&1;
      if ($245) {
       label = 49;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(3269,($218|0))|0);
      $246 = __THREW__; __THREW__ = 0;
      $247 = $246&1;
      if ($247) {
       label = 49;
       break;
      }
     }
     __THREW__ = 0;
     $248 = (invoke_ii(3265,4)|0);
     $249 = __THREW__; __THREW__ = 0;
     $250 = $249&1;
     if ($250) {
      label = 49;
      break;
     }
     if ($248) {
      __THREW__ = 0;
      $251 = (invoke_ii(3266,4)|0);
      $252 = __THREW__; __THREW__ = 0;
      $253 = $252&1;
      if ($253) {
       label = 49;
       break;
      }
      __THREW__ = 0;
      $254 = (invoke_iiii(3267,($251|0),(167635|0),20)|0);
      $255 = __THREW__; __THREW__ = 0;
      $256 = $255&1;
      if ($256) {
       label = 49;
       break;
      }
      $257 = HEAP8[$43>>0]|0;
      $258 = ($257<<24>>24)<(0);
      $259 = HEAP32[$14>>2]|0;
      $260 = $258 ? $259 : $14;
      $261 = HEAP32[$44>>2]|0;
      $262 = $257&255;
      $263 = $258 ? $261 : $262;
      __THREW__ = 0;
      $264 = (invoke_iiii(3267,($254|0),($260|0),($263|0))|0);
      $265 = __THREW__; __THREW__ = 0;
      $266 = $265&1;
      if ($266) {
       label = 49;
       break;
      }
      $267 = HEAP32[$264>>2]|0;
      $268 = ((($267)) + -12|0);
      $269 = HEAP32[$268>>2]|0;
      $270 = (($264) + ($269)|0);
      __THREW__ = 0;
      invoke_vii(3257,($5|0),($270|0));
      $271 = __THREW__; __THREW__ = 0;
      $272 = $271&1;
      if ($272) {
       label = 49;
       break;
      }
      __THREW__ = 0;
      $273 = (invoke_iii(3255,($5|0),(215188|0))|0);
      $274 = __THREW__; __THREW__ = 0;
      $275 = $274&1;
      if ($275) {
       label = 73;
       break;
      }
      $276 = HEAP32[$273>>2]|0;
      $277 = ((($276)) + 28|0);
      $278 = HEAP32[$277>>2]|0;
      __THREW__ = 0;
      $279 = (invoke_iii($278|0,($273|0),10)|0);
      $280 = __THREW__; __THREW__ = 0;
      $281 = $280&1;
      if ($281) {
       label = 73;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3263,($5|0));
      $288 = __THREW__; __THREW__ = 0;
      $289 = $288&1;
      if ($289) {
       label = 49;
       break;
      }
      __THREW__ = 0;
      (invoke_iii(3268,($264|0),($279|0))|0);
      $290 = __THREW__; __THREW__ = 0;
      $291 = $290&1;
      if ($291) {
       label = 49;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(3269,($264|0))|0);
      $292 = __THREW__; __THREW__ = 0;
      $293 = $292&1;
      if ($293) {
       label = 49;
       break;
      }
     }
     $294 = HEAP32[$45>>2]|0;
     __THREW__ = 0;
     invoke_viiiiii(4199,($0|0),($1|0),($13|0),0,4096,($294|0));
     $295 = __THREW__; __THREW__ = 0;
     $296 = $295&1;
     if ($296) {
      label = 49;
      break;
     }
     __THREW__ = 0;
     $297 = (invoke_ii(4200,($0|0))|0);
     $298 = __THREW__; __THREW__ = 0;
     $299 = $298&1;
     if ($299) {
      label = 82;
      break;
     }
     $300 = ($297|0)==(0|0);
     do {
      if ($300) {
       $$1385 = 1;
      } else {
       __THREW__ = 0;
       $303 = (invoke_ii(4200,($0|0))|0);
       $304 = __THREW__; __THREW__ = 0;
       $305 = $304&1;
       if ($305) {
        label = 82;
        break L4;
       }
       $306 = HEAP32[$45>>2]|0;
       $307 = ($306|0)==(0|0);
       if ($307) {
        __THREW__ = 0;
        $314 = (invoke_ii(3276,148)|0);
        $315 = __THREW__; __THREW__ = 0;
        $316 = $315&1;
        if ($316) {
         label = 132;
         break L4;
        }
        __THREW__ = 0;
        invoke_vii(3435,($314|0),1);
        $317 = __THREW__; __THREW__ = 0;
        $318 = $317&1;
        if ($318) {
         label = 131;
         break L4;
        }
        $322 = ((($314)) + 12|0);
        ;HEAP32[$322>>2]=0|0;HEAP32[$322+4>>2]=0|0;HEAP32[$322+8>>2]=0|0;
        $323 = ((($314)) + 24|0);
        HEAP32[$323>>2] = 2;
        $324 = ((($314)) + 28|0);
        HEAP32[$324>>2] = 0;
        HEAP32[$314>>2] = (37212);
        $325 = ((($314)) + 32|0);
        $326 = ((($314)) + 68|0);
        dest=$325; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
        HEAP32[$326>>2] = 8;
        $327 = ((($314)) + 72|0);
        $328 = ((($314)) + 92|0);
        HEAP32[$328>>2] = 0;
        $329 = ((($314)) + 96|0);
        HEAP32[$329>>2] = 0;
        $330 = ((($314)) + 88|0);
        ;HEAP32[$327>>2]=0|0;HEAP32[$327+4>>2]=0|0;HEAP32[$327+8>>2]=0|0;HEAP32[$327+12>>2]=0|0;
        HEAP32[$330>>2] = $328;
        $331 = ((($314)) + 104|0);
        HEAP32[$331>>2] = 0;
        $332 = ((($314)) + 108|0);
        HEAP32[$332>>2] = 0;
        $333 = ((($314)) + 100|0);
        HEAP32[$333>>2] = $331;
        $334 = ((($314)) + 112|0);
        dest=$334; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
        $335 = ((($314)) + 8|0);
        $336 = HEAP32[$335>>2]|0;HEAP32[$335>>2] = (($336+1)|0);
        $1225 = 0;$338 = $314;
       } else {
        HEAP32[$15>>2] = (58136);
        HEAP32[$53>>2] = 0;
        $308 = HEAP32[$306>>2]|0;
        $309 = ((($308)) + 16|0);
        $310 = HEAP32[$309>>2]|0;
        __THREW__ = 0;
        $311 = (invoke_iii($310|0,($306|0),($15|0))|0);
        $312 = __THREW__; __THREW__ = 0;
        $313 = $312&1;
        if ($313) {
         label = 133;
         break L4;
        }
        $319 = ($311|0)==(0|0);
        if (!($319)) {
         $320 = ((($311)) + 8|0);
         $321 = HEAP32[$320>>2]|0;HEAP32[$320>>2] = (($321+1)|0);
        }
        $1225 = $319;$338 = $311;
       }
       $337 = ((($338)) + 44|0);
       __ZNSt3__212__deque_baseINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS4_IS6_EEE5clearEv($337);
       $339 = ((($338)) + 52|0);
       $340 = HEAP32[$339>>2]|0;
       $341 = ((($338)) + 48|0);
       $342 = HEAP32[$341>>2]|0;
       $343 = (($340) - ($342))|0;
       $344 = $343 >> 2;
       $345 = ($344|0)==(0);
       $346 = ($344*341)|0;
       $347 = (($346) + -1)|0;
       $$$i$i$i$i = $345 ? 0 : $347;
       $348 = ((($338)) + 60|0);
       $349 = HEAP32[$348>>2]|0;
       $350 = ((($338)) + 64|0);
       $351 = HEAP32[$350>>2]|0;
       $sum$i$i$i = (($351) + ($349))|0;
       $352 = ($$$i$i$i$i|0)==($sum$i$i$i|0);
       $353 = $342;
       $354 = $340;
       if ($352) {
        __THREW__ = 0;
        invoke_vi(4201,($337|0));
        $355 = __THREW__; __THREW__ = 0;
        $356 = $355&1;
        if ($356) {
         label = 134;
         break L4;
        }
        $$pre$i$i = HEAP32[$350>>2]|0;
        $$pre4$i$i = HEAP32[$348>>2]|0;
        $$pre5$i$i = HEAP32[$341>>2]|0;
        $$pre6$i$i = HEAP32[$339>>2]|0;
        $358 = $$pre4$i$i;$359 = $$pre$i$i;$360 = $$pre6$i$i;$362 = $$pre5$i$i;
       } else {
        $358 = $349;$359 = $351;$360 = $354;$362 = $353;
       }
       $357 = (($359) + ($358))|0;
       $361 = ($360|0)==($362|0);
       if ($361) {
        $368 = 0;
       } else {
        $363 = (($357>>>0) / 341)&-1;
        $364 = (($362) + ($363<<2)|0);
        $365 = HEAP32[$364>>2]|0;
        $366 = (($357>>>0) % 341)&-1;
        $367 = (($365) + (($366*12)|0)|0);
        $368 = $367;
       }
       __THREW__ = 0;
       invoke_vii(3457,($368|0),($13|0));
       $369 = __THREW__; __THREW__ = 0;
       $370 = $369&1;
       if ($370) {
        label = 134;
        break L4;
       }
       $371 = HEAP32[$350>>2]|0;
       $372 = (($371) + 1)|0;
       HEAP32[$350>>2] = $372;
       $373 = HEAP32[$2>>2]|0;
       $374 = ((($373)) + 20|0);
       $375 = HEAP32[$374>>2]|0;
       __THREW__ = 0;
       $376 = (invoke_iiii($375|0,($2|0),($14|0),($338|0))|0);
       $377 = __THREW__; __THREW__ = 0;
       $378 = $377&1;
       if ($378) {
        label = 134;
        break L4;
       }
       $379 = HEAP32[$376>>2]|0;
       $380 = ((($379)) + 8|0);
       $381 = HEAP32[$380>>2]|0;
       __THREW__ = 0;
       invoke_viii($381|0,($16|0),($376|0),($303|0));
       $382 = __THREW__; __THREW__ = 0;
       $383 = $382&1;
       if ($383) {
        label = 135;
        break L4;
       }
       do {
        if ($46) {
         label = 108;
        } else {
         $384 = HEAP32[$16>>2]|0;
         HEAP32[$0>>2] = $384;
         __THREW__ = 0;
         (invoke_iii(3477,($51|0),($48|0))|0);
         $385 = __THREW__; __THREW__ = 0;
         $386 = $385&1;
         if ($386) {
          label = 137;
          break L4;
         }
         $387 = HEAP32[$50>>2]|0;
         $388 = HEAP32[$47>>2]|0;
         $389 = ($387|0)==($388|0);
         if ($389) {
          $399 = $388;
          break;
         }
         HEAP32[$50>>2] = $388;
         $390 = ($388|0)==(0|0);
         if (!($390)) {
          $391 = ((($388)) + 8|0);
          $392 = HEAP32[$391>>2]|0;HEAP32[$391>>2] = (($392+1)|0);
         }
         $393 = ($387|0)==(0|0);
         if ($393) {
          label = 108;
          break;
         }
         $394 = ((($387)) + 8|0);
         $395 = HEAP32[$394>>2]|0;HEAP32[$394>>2] = (($395-1)|0);
         $396 = ($395|0)==(1);
         if (!($396)) {
          label = 108;
          break;
         }
         __THREW__ = 0;
         invoke_viii(3262,($387|0),1,1);
         $397 = __THREW__; __THREW__ = 0;
         $398 = $397&1;
         if ($398) {
          label = 137;
          break L4;
         } else {
          label = 108;
         }
        }
       } while(0);
       if ((label|0) == 108) {
        label = 0;
        $$pr = HEAP32[$47>>2]|0;
        $399 = $$pr;
       }
       $400 = ($399|0)==(0|0);
       do {
        if (!($400)) {
         $401 = ((($399)) + 8|0);
         $402 = HEAP32[$401>>2]|0;HEAP32[$401>>2] = (($402-1)|0);
         $403 = ($402|0)==(1);
         if (!($403)) {
          break;
         }
         __THREW__ = 0;
         invoke_viii(3262,($399|0),1,1);
         $404 = __THREW__; __THREW__ = 0;
         $405 = $404&1;
         if ($405) {
          label = 114;
          break L4;
         }
        }
       } while(0);
       HEAP32[$47>>2] = 0;
       $406 = HEAP8[$49>>0]|0;
       $407 = ($406<<24>>24)<(0);
       if ($407) {
        $408 = HEAP32[$48>>2]|0;
        __ZdlPv($408);
       }
       $414 = HEAP32[$376>>2]|0;
       $415 = ((($414)) + 12|0);
       $416 = HEAP32[$415>>2]|0;
       __THREW__ = 0;
       $417 = (invoke_iii($416|0,($376|0),($0|0))|0);
       $418 = __THREW__; __THREW__ = 0;
       $419 = $418&1;
       if ($419) {
        label = 144;
        break L4;
       }
       do {
        if ($417) {
         __THREW__ = 0;
         $420 = (invoke_ii(3265,4)|0);
         $421 = __THREW__; __THREW__ = 0;
         $422 = $421&1;
         if ($422) {
          label = 144;
          break L4;
         }
         if (!($420)) {
          $$0 = 1;$$079 = 1;
          break;
         }
         __THREW__ = 0;
         $423 = (invoke_ii(3266,4)|0);
         $424 = __THREW__; __THREW__ = 0;
         $425 = $424&1;
         if ($425) {
          label = 144;
          break L4;
         }
         __THREW__ = 0;
         $426 = (invoke_iiii(3267,($423|0),(167656|0),24)|0);
         $427 = __THREW__; __THREW__ = 0;
         $428 = $427&1;
         if ($428) {
          label = 144;
          break L4;
         }
         $429 = HEAP32[$426>>2]|0;
         $430 = ((($429)) + -12|0);
         $431 = HEAP32[$430>>2]|0;
         $432 = (($426) + ($431)|0);
         __THREW__ = 0;
         invoke_vii(3257,($4|0),($432|0));
         $433 = __THREW__; __THREW__ = 0;
         $434 = $433&1;
         if ($434) {
          label = 144;
          break L4;
         }
         __THREW__ = 0;
         $435 = (invoke_iii(3255,($4|0),(215188|0))|0);
         $436 = __THREW__; __THREW__ = 0;
         $437 = $436&1;
         if ($437) {
          label = 125;
          break L4;
         }
         $438 = HEAP32[$435>>2]|0;
         $439 = ((($438)) + 28|0);
         $440 = HEAP32[$439>>2]|0;
         __THREW__ = 0;
         $441 = (invoke_iii($440|0,($435|0),10)|0);
         $442 = __THREW__; __THREW__ = 0;
         $443 = $442&1;
         if ($443) {
          label = 125;
          break L4;
         }
         __THREW__ = 0;
         invoke_vi(3263,($4|0));
         $450 = __THREW__; __THREW__ = 0;
         $451 = $450&1;
         if ($451) {
          label = 144;
          break L4;
         }
         __THREW__ = 0;
         (invoke_iii(3268,($426|0),($441|0))|0);
         $452 = __THREW__; __THREW__ = 0;
         $453 = $452&1;
         if ($453) {
          label = 144;
          break L4;
         }
         __THREW__ = 0;
         (invoke_ii(3269,($426|0))|0);
         $454 = __THREW__; __THREW__ = 0;
         $455 = $454&1;
         if ($455) {
          label = 144;
          break L4;
         } else {
          $$0 = 1;$$079 = 1;
         }
        } else {
         __THREW__ = 0;
         $485 = (invoke_ii(3265,4)|0);
         $486 = __THREW__; __THREW__ = 0;
         $487 = $486&1;
         if ($487) {
          label = 144;
          break L4;
         }
         if (!($485)) {
          $$0 = 0;$$079 = 0;
          break;
         }
         __THREW__ = 0;
         $488 = (invoke_ii(3266,4)|0);
         $489 = __THREW__; __THREW__ = 0;
         $490 = $489&1;
         if ($490) {
          label = 144;
          break L4;
         }
         __THREW__ = 0;
         $491 = (invoke_iiii(3267,($488|0),(167681|0),34)|0);
         $492 = __THREW__; __THREW__ = 0;
         $493 = $492&1;
         if ($493) {
          label = 144;
          break L4;
         }
         $494 = HEAP32[$491>>2]|0;
         $495 = ((($494)) + -12|0);
         $496 = HEAP32[$495>>2]|0;
         $497 = (($491) + ($496)|0);
         __THREW__ = 0;
         invoke_vii(3257,($3|0),($497|0));
         $498 = __THREW__; __THREW__ = 0;
         $499 = $498&1;
         if ($499) {
          label = 144;
          break L4;
         }
         __THREW__ = 0;
         $500 = (invoke_iii(3255,($3|0),(215188|0))|0);
         $501 = __THREW__; __THREW__ = 0;
         $502 = $501&1;
         if ($502) {
          label = 153;
          break L4;
         }
         $503 = HEAP32[$500>>2]|0;
         $504 = ((($503)) + 28|0);
         $505 = HEAP32[$504>>2]|0;
         __THREW__ = 0;
         $506 = (invoke_iii($505|0,($500|0),10)|0);
         $507 = __THREW__; __THREW__ = 0;
         $508 = $507&1;
         if ($508) {
          label = 153;
          break L4;
         }
         __THREW__ = 0;
         invoke_vi(3263,($3|0));
         $515 = __THREW__; __THREW__ = 0;
         $516 = $515&1;
         if ($516) {
          label = 144;
          break L4;
         }
         __THREW__ = 0;
         (invoke_iii(3268,($491|0),($506|0))|0);
         $517 = __THREW__; __THREW__ = 0;
         $518 = $517&1;
         if ($518) {
          label = 144;
          break L4;
         }
         __THREW__ = 0;
         (invoke_ii(3269,($491|0))|0);
         $519 = __THREW__; __THREW__ = 0;
         $520 = $519&1;
         if ($520) {
          label = 144;
          break L4;
         } else {
          $$0 = 0;$$079 = 0;
         }
        }
       } while(0);
       $521 = HEAP32[$376>>2]|0;
       $522 = ((($521)) + 4|0);
       $523 = HEAP32[$522>>2]|0;
       __THREW__ = 0;
       invoke_vi($523|0,($376|0));
       $524 = __THREW__; __THREW__ = 0;
       $525 = $524&1;
       if ($525) {
        label = 160;
        break L4;
       }
       do {
        if (!($1225)) {
         $528 = ((($338)) + 8|0);
         $529 = HEAP32[$528>>2]|0;HEAP32[$528>>2] = (($529-1)|0);
         $530 = ($529|0)==(1);
         if (!($530)) {
          break;
         }
         __THREW__ = 0;
         invoke_viii(3262,($338|0),1,1);
         $531 = __THREW__; __THREW__ = 0;
         $532 = $531&1;
         if ($532) {
          label = 180;
          break L4;
         }
        }
       } while(0);
       if ($$079) {
        $$1385 = $$0;
        break;
       }
       $533 = HEAP32[$50>>2]|0;
       $534 = ($533|0)==(0|0);
       do {
        if (!($534)) {
         $535 = ((($533)) + 8|0);
         $536 = HEAP32[$535>>2]|0;HEAP32[$535>>2] = (($536-1)|0);
         $537 = ($536|0)==(1);
         if (!($537)) {
          break;
         }
         __THREW__ = 0;
         invoke_viii(3262,($533|0),1,1);
         $538 = __THREW__; __THREW__ = 0;
         $539 = $538&1;
         if ($539) {
          label = 170;
          break L4;
         }
        }
       } while(0);
       HEAP32[$50>>2] = 0;
       $540 = HEAP8[$52>>0]|0;
       $541 = ($540<<24>>24)<(0);
       if (!($541)) {
        $$1385 = $$0;
        break;
       }
       $542 = HEAP32[$51>>2]|0;
       __ZdlPv($542);
       $$1385 = $$0;
      }
     } while(0);
     $548 = HEAP8[$43>>0]|0;
     $549 = ($548<<24>>24)<(0);
     if ($549) {
      $550 = HEAP32[$14>>2]|0;
      __ZdlPv($550);
     }
     $551 = HEAP8[$41>>0]|0;
     $552 = ($551<<24>>24)<(0);
     if ($552) {
      $553 = HEAP32[$13>>2]|0;
      __ZdlPv($553);
     }
     $cond4 = ($$1385|0)==(0);
     if ($cond4) {
      label = 197;
     } else {
      $$2 = $$1385;
     }
    }
    if ((label|0) == 197) {
     label = 0;
     $$2 = 0;
    }
    $590 = HEAP8[$39>>0]|0;
    $591 = ($590<<24>>24)<(0);
    if ($591) {
     $592 = HEAP32[$10>>2]|0;
     __ZdlPv($592);
    }
    $cond3 = ($$2|0)==(0);
    $55 = ((($$sroa$0369$0572)) + 12|0);
    if (!($cond3)) {
     label = 467;
     break;
    }
    $54 = HEAP32[$29>>2]|0;
    $56 = ($55|0)==($54|0);
    if ($56) {
     $$pre$phi634Z2D = $51;$$pre$phi638Z2D = $52;$$pre$phi640Z2D = $51;$$pre$phi642Z2D = $0;$$pre$phiZ2D = $50;
     label = 204;
     break L1;
    } else {
     $$sroa$0369$0572 = $55;
    }
   }
   switch (label|0) {
    case 28: {
     $134 = ___cxa_find_matching_catch_2()|0;
     $135 = tempRet0;
     $$11 = $134;$$1192 = $135;
     break;
    }
    case 29: {
     $136 = ___cxa_find_matching_catch_2()|0;
     $137 = tempRet0;
     $$11 = $136;$$1192 = $137;
     break;
    }
    case 41: {
     $184 = ___cxa_find_matching_catch_2()|0;
     $185 = tempRet0;
     __THREW__ = 0;
     invoke_vi(3263,($7|0));
     $186 = __THREW__; __THREW__ = 0;
     $187 = $186&1;
     if ($187) {
      $188 = ___cxa_find_matching_catch_3(0|0)|0;
      $189 = tempRet0;
      ___clang_call_terminate($188);
      // unreachable;
     } else {
      $eh$lpad$body146$index6Z2D = $185;$eh$lpad$body146$indexZ2D = $184;
      label = 50;
      break;
     }
     break;
    }
    case 47: {
     $196 = ___cxa_find_matching_catch_2()|0;
     $197 = tempRet0;
     $$11 = $196;$$1192 = $197;
     break;
    }
    case 48: {
     $198 = ___cxa_find_matching_catch_2()|0;
     $199 = tempRet0;
     $$8 = $198;$$889 = $199;
     label = 194;
     break;
    }
    case 49: {
     $200 = ___cxa_find_matching_catch_2()|0;
     $201 = tempRet0;
     $eh$lpad$body146$index6Z2D = $201;$eh$lpad$body146$indexZ2D = $200;
     label = 50;
     break;
    }
    case 59: {
     $236 = ___cxa_find_matching_catch_2()|0;
     $237 = tempRet0;
     __THREW__ = 0;
     invoke_vi(3263,($6|0));
     $238 = __THREW__; __THREW__ = 0;
     $239 = $238&1;
     if ($239) {
      $240 = ___cxa_find_matching_catch_3(0|0)|0;
      $241 = tempRet0;
      ___clang_call_terminate($240);
      // unreachable;
     } else {
      $eh$lpad$body146$index6Z2D = $237;$eh$lpad$body146$indexZ2D = $236;
      label = 50;
      break;
     }
     break;
    }
    case 73: {
     $282 = ___cxa_find_matching_catch_2()|0;
     $283 = tempRet0;
     __THREW__ = 0;
     invoke_vi(3263,($5|0));
     $284 = __THREW__; __THREW__ = 0;
     $285 = $284&1;
     if ($285) {
      $286 = ___cxa_find_matching_catch_3(0|0)|0;
      $287 = tempRet0;
      ___clang_call_terminate($286);
      // unreachable;
     } else {
      $eh$lpad$body146$index6Z2D = $283;$eh$lpad$body146$indexZ2D = $282;
      label = 50;
      break;
     }
     break;
    }
    case 82: {
     $301 = ___cxa_find_matching_catch_2()|0;
     $302 = tempRet0;
     $$678 = $301;$$687 = $302;
     label = 184;
     break;
    }
    case 114: {
     $409 = ___cxa_find_matching_catch_2()|0;
     $410 = tempRet0;
     $411 = HEAP8[$49>>0]|0;
     $412 = ($411<<24>>24)<(0);
     if ($412) {
      $413 = HEAP32[$48>>2]|0;
      __ZdlPv($413);
      $eh$lpad$body$index16Z2D = $410;$eh$lpad$body$indexZ2D = $409;
      label = 136;
     } else {
      $eh$lpad$body$index16Z2D = $410;$eh$lpad$body$indexZ2D = $409;
      label = 136;
     }
     break;
    }
    case 125: {
     $444 = ___cxa_find_matching_catch_2()|0;
     $445 = tempRet0;
     __THREW__ = 0;
     invoke_vi(3263,($4|0));
     $446 = __THREW__; __THREW__ = 0;
     $447 = $446&1;
     if ($447) {
      $448 = ___cxa_find_matching_catch_3(0|0)|0;
      $449 = tempRet0;
      ___clang_call_terminate($448);
      // unreachable;
     } else {
      $eh$lpad$body341$index23Z2D = $445;$eh$lpad$body341$indexZ2D = $444;
      label = 145;
      break;
     }
     break;
    }
    case 131: {
     $456 = ___cxa_find_matching_catch_2()|0;
     $457 = tempRet0;
     __ZdlPv($314);
     $$678 = $456;$$687 = $457;
     label = 184;
     break;
    }
    case 132: {
     $458 = ___cxa_find_matching_catch_2()|0;
     $459 = tempRet0;
     $$678 = $458;$$687 = $459;
     label = 184;
     break;
    }
    case 133: {
     $460 = ___cxa_find_matching_catch_2()|0;
     $461 = tempRet0;
     $$678 = $460;$$687 = $461;
     label = 184;
     break;
    }
    case 134: {
     $462 = ___cxa_find_matching_catch_2()|0;
     $463 = tempRet0;
     if ($1225) {
      $$678 = $462;$$687 = $463;
      label = 184;
     } else {
      $$375393 = $462;$$384391 = $463;
      label = 182;
     }
     break;
    }
    case 135: {
     $464 = ___cxa_find_matching_catch_2()|0;
     $465 = tempRet0;
     $eh$lpad$body$index16Z2D = $465;$eh$lpad$body$indexZ2D = $464;
     label = 136;
     break;
    }
    case 137: {
     $466 = ___cxa_find_matching_catch_2()|0;
     $467 = tempRet0;
     $468 = HEAP32[$47>>2]|0;
     $469 = ($468|0)==(0|0);
     if (!($469)) {
      $470 = ((($468)) + 8|0);
      $471 = HEAP32[$470>>2]|0;HEAP32[$470>>2] = (($471-1)|0);
      $472 = ($471|0)==(1);
      if ($472) {
       __THREW__ = 0;
       invoke_viii(3262,($468|0),1,1);
       $473 = __THREW__; __THREW__ = 0;
       $474 = $473&1;
       if ($474) {
        $478 = ___cxa_find_matching_catch_3(0|0)|0;
        $479 = tempRet0;
        $480 = HEAP8[$49>>0]|0;
        $481 = ($480<<24>>24)<(0);
        if (!($481)) {
         $eh$lpad$body137$indexZ2D = $478;
         ___clang_call_terminate($eh$lpad$body137$indexZ2D);
         // unreachable;
        }
        $482 = HEAP32[$48>>2]|0;
        __ZdlPv($482);
        $eh$lpad$body137$indexZ2D = $478;
        ___clang_call_terminate($eh$lpad$body137$indexZ2D);
        // unreachable;
       }
      }
     }
     HEAP32[$47>>2] = 0;
     $475 = HEAP8[$49>>0]|0;
     $476 = ($475<<24>>24)<(0);
     if ($476) {
      $477 = HEAP32[$48>>2]|0;
      __ZdlPv($477);
      $$173 = $466;$$182 = $467;
      label = 177;
     } else {
      $$173 = $466;$$182 = $467;
      label = 177;
     }
     break;
    }
    case 144: {
     $483 = ___cxa_find_matching_catch_2()|0;
     $484 = tempRet0;
     $eh$lpad$body341$index23Z2D = $484;$eh$lpad$body341$indexZ2D = $483;
     label = 145;
     break;
    }
    case 153: {
     $509 = ___cxa_find_matching_catch_2()|0;
     $510 = tempRet0;
     __THREW__ = 0;
     invoke_vi(3263,($3|0));
     $511 = __THREW__; __THREW__ = 0;
     $512 = $511&1;
     if ($512) {
      $513 = ___cxa_find_matching_catch_3(0|0)|0;
      $514 = tempRet0;
      ___clang_call_terminate($513);
      // unreachable;
     } else {
      $eh$lpad$body341$index23Z2D = $510;$eh$lpad$body341$indexZ2D = $509;
      label = 145;
      break;
     }
     break;
    }
    case 160: {
     $526 = ___cxa_find_matching_catch_2()|0;
     $527 = tempRet0;
     ___cxa_call_unexpected(($526|0));
     // unreachable;
     break;
    }
    case 170: {
     $543 = ___cxa_find_matching_catch_2()|0;
     $544 = tempRet0;
     $545 = HEAP8[$52>>0]|0;
     $546 = ($545<<24>>24)<(0);
     if ($546) {
      $547 = HEAP32[$51>>2]|0;
      __ZdlPv($547);
      $eh$lpad$body146$index6Z2D = $544;$eh$lpad$body146$indexZ2D = $543;
      label = 50;
     } else {
      $eh$lpad$body146$index6Z2D = $544;$eh$lpad$body146$indexZ2D = $543;
      label = 50;
     }
     break;
    }
    case 180: {
     $562 = ___cxa_find_matching_catch_2()|0;
     $563 = tempRet0;
     $$678 = $562;$$687 = $563;
     label = 184;
     break;
    }
    case 467: {
     STACKTOP = sp;return;
     break;
    }
   }
   if ((label|0) == 50) {
    $$7 = $eh$lpad$body146$indexZ2D;$$788 = $eh$lpad$body146$index6Z2D;
    label = 191;
   }
   else if ((label|0) == 136) {
    $$173 = $eh$lpad$body$indexZ2D;$$182 = $eh$lpad$body$index16Z2D;
    label = 177;
   }
   else if ((label|0) == 145) {
    $$274389 = $eh$lpad$body341$indexZ2D;$$283387 = $eh$lpad$body341$index23Z2D;
    label = 178;
   }
   if ((label|0) == 177) {
    $554 = ($376|0)==(0|0);
    if ($554) {
     $$375 = $$173;$$384 = $$182;
     label = 181;
    } else {
     $$274389 = $$173;$$283387 = $$182;
     label = 178;
    }
   }
   if ((label|0) == 178) {
    $555 = HEAP32[$376>>2]|0;
    $556 = ((($555)) + 4|0);
    $557 = HEAP32[$556>>2]|0;
    __THREW__ = 0;
    invoke_vi($557|0,($376|0));
    $558 = __THREW__; __THREW__ = 0;
    $559 = $558&1;
    if ($559) {
     $560 = ___cxa_find_matching_catch_2()|0;
     $561 = tempRet0;
     ___cxa_call_unexpected(($560|0));
     // unreachable;
    } else {
     $$375 = $$274389;$$384 = $$283387;
     label = 181;
    }
   }
   if ((label|0) == 181) {
    if ($1225) {
     $$678 = $$375;$$687 = $$384;
     label = 184;
    } else {
     $$375393 = $$375;$$384391 = $$384;
     label = 182;
    }
   }
   if ((label|0) == 182) {
    $564 = ((($338)) + 8|0);
    $565 = HEAP32[$564>>2]|0;HEAP32[$564>>2] = (($565-1)|0);
    $566 = ($565|0)==(1);
    if ($566) {
     __THREW__ = 0;
     invoke_viii(3262,($338|0),1,1);
     $567 = __THREW__; __THREW__ = 0;
     $568 = $567&1;
     if ($568) {
      break;
     } else {
      $$678 = $$375393;$$687 = $$384391;
      label = 184;
     }
    } else {
     $$678 = $$375393;$$687 = $$384391;
     label = 184;
    }
   }
   if ((label|0) == 184) {
    $569 = HEAP32[$50>>2]|0;
    $570 = ($569|0)==(0|0);
    if (!($570)) {
     $571 = ((($569)) + 8|0);
     $572 = HEAP32[$571>>2]|0;HEAP32[$571>>2] = (($572-1)|0);
     $573 = ($572|0)==(1);
     if ($573) {
      __THREW__ = 0;
      invoke_viii(3262,($569|0),1,1);
      $574 = __THREW__; __THREW__ = 0;
      $575 = $574&1;
      if ($575) {
       $579 = ___cxa_find_matching_catch_3(0|0)|0;
       $580 = tempRet0;
       $581 = HEAP8[$52>>0]|0;
       $582 = ($581<<24>>24)<(0);
       if (!($582)) {
        $eh$lpad$body137$indexZ2D = $579;
        ___clang_call_terminate($eh$lpad$body137$indexZ2D);
        // unreachable;
       }
       $583 = HEAP32[$51>>2]|0;
       __ZdlPv($583);
       $eh$lpad$body137$indexZ2D = $579;
       ___clang_call_terminate($eh$lpad$body137$indexZ2D);
       // unreachable;
      }
     }
    }
    HEAP32[$50>>2] = 0;
    $576 = HEAP8[$52>>0]|0;
    $577 = ($576<<24>>24)<(0);
    if ($577) {
     $578 = HEAP32[$51>>2]|0;
     __ZdlPv($578);
     $$7 = $$678;$$788 = $$687;
     label = 191;
    } else {
     $$7 = $$678;$$788 = $$687;
     label = 191;
    }
   }
   if ((label|0) == 191) {
    $584 = HEAP8[$43>>0]|0;
    $585 = ($584<<24>>24)<(0);
    if ($585) {
     $586 = HEAP32[$14>>2]|0;
     __ZdlPv($586);
    }
    $$8 = $$7;$$889 = $$788;
    label = 194;
   }
   if ((label|0) == 194) {
    $587 = HEAP8[$41>>0]|0;
    $588 = ($587<<24>>24)<(0);
    if ($588) {
     $589 = HEAP32[$13>>2]|0;
     __ZdlPv($589);
    }
    $$11 = $$8;$$1192 = $$889;
   }
   $593 = HEAP8[$39>>0]|0;
   $594 = ($593<<24>>24)<(0);
   if ($594) {
    $595 = HEAP32[$10>>2]|0;
    __ZdlPv($595);
   }
   $$25 = $$11;$$25106 = $$1192;
   ___resumeException($$25|0);
   // unreachable;
  }
 } while(0);
 if ((label|0) == 204) {
  HEAP32[$17>>2] = 0;
  $596 = ((($17)) + 4|0);
  HEAP32[$596>>2] = 0;
  $597 = ((($17)) + 8|0);
  HEAP32[$597>>2] = 0;
  $598 = ((($1)) + 72|0);
  $599 = ((($1)) + 60|0);
  HEAP32[$18>>2] = $598;
  $600 = ((($18)) + 4|0);
  HEAP32[$600>>2] = $599;
  $601 = ((($18)) + 12|0);
  HEAP32[$601>>2] = 0;
  $602 = ((($18)) + 16|0);
  HEAP32[$602>>2] = 0;
  $603 = ((($18)) + 12|0);
  $604 = ((($18)) + 8|0);
  HEAP32[$604>>2] = $603;
  $605 = ((($17)) + 8|0);
  $607 = $599;
  while(1) {
   $606 = HEAP32[$607>>2]|0;
   $608 = ((($606)) + 8|0);
   $609 = HEAP32[$608>>2]|0;
   __THREW__ = 0;
   (invoke_ii($609|0,($607|0))|0);
   $610 = __THREW__; __THREW__ = 0;
   $611 = $610&1;
   if ($611) {
    label = 235;
    break;
   }
   $612 = HEAP32[$18>>2]|0;
   $613 = HEAP32[$612>>2]|0;
   $614 = ((($612)) + 4|0);
   $615 = HEAP32[$614>>2]|0;
   $616 = ($613|0)==($615|0);
   L267: do {
    if ($616) {
     $$0$i$i162 = 0;
    } else {
     $617 = HEAP32[$603>>2]|0;
     $618 = ($617|0)==(0|0);
     if ($618) {
      $$pre$i$i161 = HEAP32[$613>>2]|0;
      $$0$i$i162 = $$pre$i$i161;
      break;
     } else {
      $$sroa$011$025$i$i = $613;
     }
     while(1) {
      $621 = HEAP32[$$sroa$011$025$i$i>>2]|0;
      $$0$ph13$i$i$i$i$i = $603;$$07$ph12$i$i$i$i$i = $617;
      L273: while(1) {
       $$0710$i$i$i$i$i = $$07$ph12$i$i$i$i$i;
       while(1) {
        $622 = ((($$0710$i$i$i$i$i)) + 16|0);
        $623 = HEAP32[$622>>2]|0;
        $624 = ($623>>>0)<($621>>>0);
        if (!($624)) {
         break;
        }
        $627 = ((($$0710$i$i$i$i$i)) + 4|0);
        $628 = HEAP32[$627>>2]|0;
        $629 = ($628|0)==(0|0);
        if ($629) {
         $$0$ph$lcssa$i$i$i$i$i = $$0$ph13$i$i$i$i$i;
         break L273;
        } else {
         $$0710$i$i$i$i$i = $628;
        }
       }
       $625 = HEAP32[$$0710$i$i$i$i$i>>2]|0;
       $626 = ($625|0)==(0|0);
       if ($626) {
        $$0$ph$lcssa$i$i$i$i$i = $$0710$i$i$i$i$i;
        break;
       } else {
        $$0$ph13$i$i$i$i$i = $$0710$i$i$i$i$i;$$07$ph12$i$i$i$i$i = $625;
       }
      }
      $630 = ($$0$ph$lcssa$i$i$i$i$i|0)==($603|0);
      if ($630) {
       $$0$i$i162 = $621;
       break L267;
      }
      $631 = ((($$0$ph$lcssa$i$i$i$i$i)) + 16|0);
      $632 = HEAP32[$631>>2]|0;
      $633 = ($621>>>0)<($632>>>0);
      $619 = ((($$sroa$011$025$i$i)) + 4|0);
      if ($633) {
       $$0$i$i162 = $621;
       break L267;
      }
      $620 = ($619|0)==($615|0);
      if ($620) {
       $$0$i$i162 = 0;
       break;
      } else {
       $$sroa$011$025$i$i = $619;
      }
     }
    }
   } while(0);
   $634 = HEAP32[$607>>2]|0;
   $635 = ((($634)) + 12|0);
   $636 = HEAP32[$635>>2]|0;
   __THREW__ = 0;
   (invoke_ii($636|0,($607|0))|0);
   $637 = __THREW__; __THREW__ = 0;
   $638 = $637&1;
   if ($638) {
    label = 235;
    break;
   }
   $639 = ($$0$i$i162|0)==(0|0);
   if ($639) {
    label = 259;
    break;
   }
   $640 = HEAP32[$2>>2]|0;
   $641 = ((($640)) + 8|0);
   $642 = HEAP32[$641>>2]|0;
   $643 = HEAP32[$600>>2]|0;
   $644 = HEAP32[$643>>2]|0;
   $645 = ((($644)) + 8|0);
   $646 = HEAP32[$645>>2]|0;
   __THREW__ = 0;
   (invoke_ii($646|0,($643|0))|0);
   $647 = __THREW__; __THREW__ = 0;
   $648 = $647&1;
   if ($648) {
    label = 235;
    break;
   }
   $649 = HEAP32[$18>>2]|0;
   $650 = HEAP32[$649>>2]|0;
   $651 = ((($649)) + 4|0);
   $652 = HEAP32[$651>>2]|0;
   $653 = ($650|0)==($652|0);
   L286: do {
    if ($653) {
     $$0$i$i177 = 0;
    } else {
     $654 = HEAP32[$603>>2]|0;
     $655 = ($654|0)==(0|0);
     if ($655) {
      $$pre$i$i166 = HEAP32[$650>>2]|0;
      $$0$i$i177 = $$pre$i$i166;
      break;
     } else {
      $$sroa$011$025$i$i168 = $650;
     }
     while(1) {
      $658 = HEAP32[$$sroa$011$025$i$i168>>2]|0;
      $$0$ph13$i$i$i$i$i170 = $603;$$07$ph12$i$i$i$i$i171 = $654;
      L292: while(1) {
       $$0710$i$i$i$i$i173 = $$07$ph12$i$i$i$i$i171;
       while(1) {
        $659 = ((($$0710$i$i$i$i$i173)) + 16|0);
        $660 = HEAP32[$659>>2]|0;
        $661 = ($660>>>0)<($658>>>0);
        if (!($661)) {
         break;
        }
        $664 = ((($$0710$i$i$i$i$i173)) + 4|0);
        $665 = HEAP32[$664>>2]|0;
        $666 = ($665|0)==(0|0);
        if ($666) {
         $$0$ph$lcssa$i$i$i$i$i175 = $$0$ph13$i$i$i$i$i170;
         break L292;
        } else {
         $$0710$i$i$i$i$i173 = $665;
        }
       }
       $662 = HEAP32[$$0710$i$i$i$i$i173>>2]|0;
       $663 = ($662|0)==(0|0);
       if ($663) {
        $$0$ph$lcssa$i$i$i$i$i175 = $$0710$i$i$i$i$i173;
        break;
       } else {
        $$0$ph13$i$i$i$i$i170 = $$0710$i$i$i$i$i173;$$07$ph12$i$i$i$i$i171 = $662;
       }
      }
      $667 = ($$0$ph$lcssa$i$i$i$i$i175|0)==($603|0);
      if ($667) {
       $$0$i$i177 = $658;
       break L286;
      }
      $668 = ((($$0$ph$lcssa$i$i$i$i$i175)) + 16|0);
      $669 = HEAP32[$668>>2]|0;
      $670 = ($658>>>0)<($669>>>0);
      $656 = ((($$sroa$011$025$i$i168)) + 4|0);
      if ($670) {
       $$0$i$i177 = $658;
       break L286;
      }
      $657 = ($656|0)==($652|0);
      if ($657) {
       $$0$i$i177 = 0;
       break;
      } else {
       $$sroa$011$025$i$i168 = $656;
      }
     }
    }
   } while(0);
   $671 = HEAP32[$643>>2]|0;
   $672 = ((($671)) + 12|0);
   $673 = HEAP32[$672>>2]|0;
   __THREW__ = 0;
   (invoke_ii($673|0,($643|0))|0);
   $674 = __THREW__; __THREW__ = 0;
   $675 = $674&1;
   if ($675) {
    label = 235;
    break;
   }
   __THREW__ = 0;
   invoke_viii($642|0,($0|0),($2|0),($$0$i$i177|0));
   $676 = __THREW__; __THREW__ = 0;
   $677 = $676&1;
   if ($677) {
    label = 235;
    break;
   }
   $678 = HEAP32[$2>>2]|0;
   $679 = ((($678)) + 12|0);
   $680 = HEAP32[$679>>2]|0;
   __THREW__ = 0;
   $681 = (invoke_iii($680|0,($2|0),($0|0))|0);
   $682 = __THREW__; __THREW__ = 0;
   $683 = $682&1;
   if ($683) {
    label = 237;
    break;
   }
   if ($681) {
    label = 464;
    break;
   }
   $703 = HEAP32[$596>>2]|0;
   $704 = HEAP32[$605>>2]|0;
   $705 = ($703|0)==($704|0);
   if ($705) {
    __THREW__ = 0;
    invoke_vii(4202,($17|0),($0|0));
    $717 = __THREW__; __THREW__ = 0;
    $718 = $717&1;
    if ($718) {
     label = 237;
     break;
    }
   } else {
    $706 = HEAP32[$$pre$phi642Z2D>>2]|0;
    HEAP32[$703>>2] = $706;
    $707 = ((($703)) + 4|0);
    __THREW__ = 0;
    invoke_vii(3457,($707|0),($$pre$phi634Z2D|0));
    $708 = __THREW__; __THREW__ = 0;
    $709 = $708&1;
    if ($709) {
     label = 237;
     break;
    }
    $710 = ((($703)) + 16|0);
    $711 = HEAP32[$$pre$phiZ2D>>2]|0;
    HEAP32[$710>>2] = $711;
    $712 = ($711|0)==(0|0);
    if (!($712)) {
     $713 = ((($711)) + 8|0);
     $714 = HEAP32[$713>>2]|0;HEAP32[$713>>2] = (($714+1)|0);
    }
    $715 = HEAP32[$596>>2]|0;
    $716 = ((($715)) + 20|0);
    HEAP32[$596>>2] = $716;
   }
   $719 = HEAP32[$$pre$phiZ2D>>2]|0;
   $720 = ($719|0)==(0|0);
   if (!($720)) {
    $721 = ((($719)) + 8|0);
    $722 = HEAP32[$721>>2]|0;HEAP32[$721>>2] = (($722-1)|0);
    $723 = ($722|0)==(1);
    if ($723) {
     __THREW__ = 0;
     invoke_viii(3262,($719|0),1,1);
     $724 = __THREW__; __THREW__ = 0;
     $725 = $724&1;
     if ($725) {
      label = 255;
      break;
     }
    }
   }
   HEAP32[$$pre$phiZ2D>>2] = 0;
   $726 = HEAP8[$$pre$phi638Z2D>>0]|0;
   $727 = ($726<<24>>24)<(0);
   if ($727) {
    $728 = HEAP32[$$pre$phi640Z2D>>2]|0;
    __ZdlPv($728);
   }
   __THREW__ = 0;
   invoke_vi(4203,($18|0));
   $734 = __THREW__; __THREW__ = 0;
   $735 = $734&1;
   if ($735) {
    label = 235;
    break;
   }
   $$pre = HEAP32[$600>>2]|0;
   $607 = $$pre;
  }
  do {
   if ((label|0) == 235) {
    $684 = ___cxa_find_matching_catch_2()|0;
    $685 = tempRet0;
    $eh$lpad$body189$index30Z2D = $685;$eh$lpad$body189$indexZ2D = $684;
    label = 236;
   }
   else if ((label|0) == 237) {
    $686 = ___cxa_find_matching_catch_2()|0;
    $687 = tempRet0;
    $688 = HEAP32[$$pre$phiZ2D>>2]|0;
    $689 = ($688|0)==(0|0);
    if (!($689)) {
     $690 = ((($688)) + 8|0);
     $691 = HEAP32[$690>>2]|0;HEAP32[$690>>2] = (($691-1)|0);
     $692 = ($691|0)==(1);
     if ($692) {
      __THREW__ = 0;
      invoke_viii(3262,($688|0),1,1);
      $693 = __THREW__; __THREW__ = 0;
      $694 = $693&1;
      if ($694) {
       $698 = ___cxa_find_matching_catch_3(0|0)|0;
       $699 = tempRet0;
       $700 = HEAP8[$$pre$phi638Z2D>>0]|0;
       $701 = ($700<<24>>24)<(0);
       if (!($701)) {
        $eh$lpad$body137$indexZ2D = $698;
        ___clang_call_terminate($eh$lpad$body137$indexZ2D);
        // unreachable;
       }
       $702 = HEAP32[$$pre$phi640Z2D>>2]|0;
       __ZdlPv($702);
       $eh$lpad$body137$indexZ2D = $698;
       ___clang_call_terminate($eh$lpad$body137$indexZ2D);
       // unreachable;
      }
     }
    }
    HEAP32[$$pre$phiZ2D>>2] = 0;
    $695 = HEAP8[$$pre$phi638Z2D>>0]|0;
    $696 = ($695<<24>>24)<(0);
    if ($696) {
     $697 = HEAP32[$$pre$phi640Z2D>>2]|0;
     __ZdlPv($697);
     $$22 = $686;$$22103 = $687;
    } else {
     $$22 = $686;$$22103 = $687;
    }
   }
   else if ((label|0) == 255) {
    $729 = ___cxa_find_matching_catch_2()|0;
    $730 = tempRet0;
    $731 = HEAP8[$$pre$phi638Z2D>>0]|0;
    $732 = ($731<<24>>24)<(0);
    if ($732) {
     $733 = HEAP32[$$pre$phi640Z2D>>2]|0;
     __ZdlPv($733);
     $eh$lpad$body189$index30Z2D = $730;$eh$lpad$body189$indexZ2D = $729;
     label = 236;
    } else {
     $eh$lpad$body189$index30Z2D = $730;$eh$lpad$body189$indexZ2D = $729;
     label = 236;
    }
   }
   else if ((label|0) == 259) {
    $736 = ((($1)) + 120|0);
    $737 = ((($1)) + 108|0);
    HEAP32[$19>>2] = $736;
    $738 = ((($19)) + 4|0);
    HEAP32[$738>>2] = $737;
    $739 = ((($19)) + 12|0);
    HEAP32[$739>>2] = 0;
    $740 = ((($19)) + 16|0);
    HEAP32[$740>>2] = 0;
    $741 = ((($19)) + 12|0);
    $742 = ((($19)) + 8|0);
    HEAP32[$742>>2] = $741;
    $744 = $737;
    L338: while(1) {
     $743 = HEAP32[$744>>2]|0;
     $745 = ((($743)) + 8|0);
     $746 = HEAP32[$745>>2]|0;
     __THREW__ = 0;
     (invoke_ii($746|0,($744|0))|0);
     $747 = __THREW__; __THREW__ = 0;
     $748 = $747&1;
     if ($748) {
      label = 300;
      break;
     }
     $749 = HEAP32[$19>>2]|0;
     $750 = HEAP32[$749>>2]|0;
     $751 = ((($749)) + 4|0);
     $752 = ($750|0)==($751|0);
     L341: do {
      if ($752) {
       $$04$i$i = 0;
      } else {
       $753 = HEAP32[$741>>2]|0;
       $754 = ($753|0)==(0|0);
       if ($754) {
        $755 = ((($750)) + 28|0);
        $$pre$i$i192 = HEAP32[$755>>2]|0;
        $$04$i$i = $$pre$i$i192;
        break;
       } else {
        $$sroa$015$030$i$i = $750;
       }
       while(1) {
        $756 = ((($$sroa$015$030$i$i)) + 28|0);
        $757 = HEAP32[$756>>2]|0;
        $$0$ph13$i$i$i$i$i195 = $741;$$07$ph12$i$i$i$i$i196 = $753;
        L347: while(1) {
         $$0710$i$i$i$i$i197 = $$07$ph12$i$i$i$i$i196;
         while(1) {
          $758 = ((($$0710$i$i$i$i$i197)) + 16|0);
          $759 = HEAP32[$758>>2]|0;
          $760 = ($759>>>0)<($757>>>0);
          if (!($760)) {
           break;
          }
          $763 = ((($$0710$i$i$i$i$i197)) + 4|0);
          $764 = HEAP32[$763>>2]|0;
          $765 = ($764|0)==(0|0);
          if ($765) {
           $$0$ph$lcssa$i$i$i$i$i199 = $$0$ph13$i$i$i$i$i195;
           break L347;
          } else {
           $$0710$i$i$i$i$i197 = $764;
          }
         }
         $761 = HEAP32[$$0710$i$i$i$i$i197>>2]|0;
         $762 = ($761|0)==(0|0);
         if ($762) {
          $$0$ph$lcssa$i$i$i$i$i199 = $$0710$i$i$i$i$i197;
          break;
         } else {
          $$0$ph13$i$i$i$i$i195 = $$0710$i$i$i$i$i197;$$07$ph12$i$i$i$i$i196 = $761;
         }
        }
        $766 = ($$0$ph$lcssa$i$i$i$i$i199|0)==($741|0);
        if ($766) {
         $$04$i$i = $757;
         break L341;
        }
        $767 = ((($$0$ph$lcssa$i$i$i$i$i199)) + 16|0);
        $768 = HEAP32[$767>>2]|0;
        $769 = ($757>>>0)<($768>>>0);
        if ($769) {
         $$04$i$i = $757;
         break L341;
        }
        $770 = ((($$sroa$015$030$i$i)) + 4|0);
        $771 = HEAP32[$770>>2]|0;
        $772 = ($771|0)==(0|0);
        if ($772) {
         $773 = ((($$sroa$015$030$i$i)) + 8|0);
         $774 = HEAP32[$773>>2]|0;
         $775 = HEAP32[$774>>2]|0;
         $776 = ($775|0)==($$sroa$015$030$i$i|0);
         if ($776) {
          $$sroa$015$0$be$i$i = $774;
         } else {
          $781 = $773;
          while(1) {
           $780 = HEAP32[$781>>2]|0;
           $782 = ((($780)) + 8|0);
           $783 = HEAP32[$782>>2]|0;
           $784 = HEAP32[$783>>2]|0;
           $785 = ($784|0)==($780|0);
           if ($785) {
            $$sroa$015$0$be$i$i = $783;
            break;
           } else {
            $781 = $782;
           }
          }
         }
        } else {
         $$0$i$i$i$i$i$i = $771;
         while(1) {
          $778 = HEAP32[$$0$i$i$i$i$i$i>>2]|0;
          $779 = ($778|0)==(0|0);
          if ($779) {
           break;
          } else {
           $$0$i$i$i$i$i$i = $778;
          }
         }
         $$sroa$015$0$be$i$i = $$0$i$i$i$i$i$i;
        }
        $777 = ($$sroa$015$0$be$i$i|0)==($751|0);
        if ($777) {
         $$04$i$i = 0;
         break;
        } else {
         $$sroa$015$030$i$i = $$sroa$015$0$be$i$i;
        }
       }
      }
     } while(0);
     $786 = HEAP32[$744>>2]|0;
     $787 = ((($786)) + 12|0);
     $788 = HEAP32[$787>>2]|0;
     __THREW__ = 0;
     (invoke_ii($788|0,($744|0))|0);
     $789 = __THREW__; __THREW__ = 0;
     $790 = $789&1;
     if ($790) {
      label = 300;
      break;
     }
     $791 = ($$04$i$i|0)==(0|0);
     if ($791) {
      label = 326;
      break;
     }
     $792 = HEAP32[$2>>2]|0;
     $793 = ((($792)) + 8|0);
     $794 = HEAP32[$793>>2]|0;
     $795 = HEAP32[$738>>2]|0;
     $796 = HEAP32[$795>>2]|0;
     $797 = ((($796)) + 8|0);
     $798 = HEAP32[$797>>2]|0;
     __THREW__ = 0;
     (invoke_ii($798|0,($795|0))|0);
     $799 = __THREW__; __THREW__ = 0;
     $800 = $799&1;
     if ($800) {
      label = 300;
      break;
     }
     $801 = HEAP32[$19>>2]|0;
     $802 = HEAP32[$801>>2]|0;
     $803 = ((($801)) + 4|0);
     $804 = ($802|0)==($803|0);
     L368: do {
      if ($804) {
       $$04$i$i222 = 0;
      } else {
       $805 = HEAP32[$741>>2]|0;
       $806 = ($805|0)==(0|0);
       if ($806) {
        $807 = ((($802)) + 28|0);
        $$pre$i$i204 = HEAP32[$807>>2]|0;
        $$04$i$i222 = $$pre$i$i204;
        break;
       } else {
        $$sroa$015$030$i$i206 = $802;
       }
       while(1) {
        $808 = ((($$sroa$015$030$i$i206)) + 28|0);
        $809 = HEAP32[$808>>2]|0;
        $$0$ph13$i$i$i$i$i208 = $741;$$07$ph12$i$i$i$i$i209 = $805;
        L374: while(1) {
         $$0710$i$i$i$i$i211 = $$07$ph12$i$i$i$i$i209;
         while(1) {
          $810 = ((($$0710$i$i$i$i$i211)) + 16|0);
          $811 = HEAP32[$810>>2]|0;
          $812 = ($811>>>0)<($809>>>0);
          if (!($812)) {
           break;
          }
          $815 = ((($$0710$i$i$i$i$i211)) + 4|0);
          $816 = HEAP32[$815>>2]|0;
          $817 = ($816|0)==(0|0);
          if ($817) {
           $$0$ph$lcssa$i$i$i$i$i213 = $$0$ph13$i$i$i$i$i208;
           break L374;
          } else {
           $$0710$i$i$i$i$i211 = $816;
          }
         }
         $813 = HEAP32[$$0710$i$i$i$i$i211>>2]|0;
         $814 = ($813|0)==(0|0);
         if ($814) {
          $$0$ph$lcssa$i$i$i$i$i213 = $$0710$i$i$i$i$i211;
          break;
         } else {
          $$0$ph13$i$i$i$i$i208 = $$0710$i$i$i$i$i211;$$07$ph12$i$i$i$i$i209 = $813;
         }
        }
        $818 = ($$0$ph$lcssa$i$i$i$i$i213|0)==($741|0);
        if ($818) {
         $$04$i$i222 = $809;
         break L368;
        }
        $819 = ((($$0$ph$lcssa$i$i$i$i$i213)) + 16|0);
        $820 = HEAP32[$819>>2]|0;
        $821 = ($809>>>0)<($820>>>0);
        if ($821) {
         $$04$i$i222 = $809;
         break L368;
        }
        $822 = ((($$sroa$015$030$i$i206)) + 4|0);
        $823 = HEAP32[$822>>2]|0;
        $824 = ($823|0)==(0|0);
        if ($824) {
         $825 = ((($$sroa$015$030$i$i206)) + 8|0);
         $826 = HEAP32[$825>>2]|0;
         $827 = HEAP32[$826>>2]|0;
         $828 = ($827|0)==($$sroa$015$030$i$i206|0);
         if ($828) {
          $$sroa$015$0$be$i$i216 = $826;
         } else {
          $833 = $825;
          while(1) {
           $832 = HEAP32[$833>>2]|0;
           $834 = ((($832)) + 8|0);
           $835 = HEAP32[$834>>2]|0;
           $836 = HEAP32[$835>>2]|0;
           $837 = ($836|0)==($832|0);
           if ($837) {
            $$sroa$015$0$be$i$i216 = $835;
            break;
           } else {
            $833 = $834;
           }
          }
         }
        } else {
         $$0$i$i$i$i$i$i218 = $823;
         while(1) {
          $830 = HEAP32[$$0$i$i$i$i$i$i218>>2]|0;
          $831 = ($830|0)==(0|0);
          if ($831) {
           break;
          } else {
           $$0$i$i$i$i$i$i218 = $830;
          }
         }
         $$sroa$015$0$be$i$i216 = $$0$i$i$i$i$i$i218;
        }
        $829 = ($$sroa$015$0$be$i$i216|0)==($803|0);
        if ($829) {
         $$04$i$i222 = 0;
         break;
        } else {
         $$sroa$015$030$i$i206 = $$sroa$015$0$be$i$i216;
        }
       }
      }
     } while(0);
     $838 = HEAP32[$795>>2]|0;
     $839 = ((($838)) + 12|0);
     $840 = HEAP32[$839>>2]|0;
     __THREW__ = 0;
     (invoke_ii($840|0,($795|0))|0);
     $841 = __THREW__; __THREW__ = 0;
     $842 = $841&1;
     if ($842) {
      label = 300;
      break;
     }
     __THREW__ = 0;
     invoke_viii($794|0,($0|0),($2|0),($$04$i$i222|0));
     $843 = __THREW__; __THREW__ = 0;
     $844 = $843&1;
     if ($844) {
      label = 300;
      break;
     }
     $845 = HEAP32[$2>>2]|0;
     $846 = ((($845)) + 12|0);
     $847 = HEAP32[$846>>2]|0;
     __THREW__ = 0;
     $848 = (invoke_iii($847|0,($2|0),($0|0))|0);
     $849 = __THREW__; __THREW__ = 0;
     $850 = $849&1;
     if ($850) {
      label = 303;
      break;
     }
     if ($848) {
      label = 462;
      break;
     }
     $872 = HEAP32[$$pre$phi642Z2D>>2]|0;
     $873 = ($872|0)==(2);
     do {
      if (!($873)) {
       $874 = HEAP32[$596>>2]|0;
       $875 = HEAP32[$605>>2]|0;
       $876 = ($874|0)==($875|0);
       if ($876) {
        __THREW__ = 0;
        invoke_vii(4202,($17|0),($0|0));
        $887 = __THREW__; __THREW__ = 0;
        $888 = $887&1;
        if ($888) {
         label = 303;
         break L338;
        } else {
         break;
        }
       }
       HEAP32[$874>>2] = $872;
       $877 = ((($874)) + 4|0);
       __THREW__ = 0;
       invoke_vii(3457,($877|0),($$pre$phi634Z2D|0));
       $878 = __THREW__; __THREW__ = 0;
       $879 = $878&1;
       if ($879) {
        label = 303;
        break L338;
       }
       $880 = ((($874)) + 16|0);
       $881 = HEAP32[$$pre$phiZ2D>>2]|0;
       HEAP32[$880>>2] = $881;
       $882 = ($881|0)==(0|0);
       if (!($882)) {
        $883 = ((($881)) + 8|0);
        $884 = HEAP32[$883>>2]|0;HEAP32[$883>>2] = (($884+1)|0);
       }
       $885 = HEAP32[$596>>2]|0;
       $886 = ((($885)) + 20|0);
       HEAP32[$596>>2] = $886;
      }
     } while(0);
     $889 = HEAP32[$$pre$phiZ2D>>2]|0;
     $890 = ($889|0)==(0|0);
     if (!($890)) {
      $891 = ((($889)) + 8|0);
      $892 = HEAP32[$891>>2]|0;HEAP32[$891>>2] = (($892-1)|0);
      $893 = ($892|0)==(1);
      if ($893) {
       __THREW__ = 0;
       invoke_viii(3262,($889|0),1,1);
       $894 = __THREW__; __THREW__ = 0;
       $895 = $894&1;
       if ($895) {
        label = 322;
        break;
       }
      }
     }
     HEAP32[$$pre$phiZ2D>>2] = 0;
     $896 = HEAP8[$$pre$phi638Z2D>>0]|0;
     $897 = ($896<<24>>24)<(0);
     if ($897) {
      $898 = HEAP32[$$pre$phi640Z2D>>2]|0;
      __ZdlPv($898);
     }
     __THREW__ = 0;
     invoke_vi(4204,($19|0));
     $904 = __THREW__; __THREW__ = 0;
     $905 = $904&1;
     if ($905) {
      label = 300;
      break;
     }
     $$pre630 = HEAP32[$738>>2]|0;
     $744 = $$pre630;
    }
    L414: do {
     if ((label|0) == 300) {
      $851 = ___cxa_find_matching_catch_2()|0;
      $852 = tempRet0;
      $eh$lpad$body236$index39Z2D = $852;$eh$lpad$body236$indexZ2D = $851;
      label = 302;
     }
     else if ((label|0) == 303) {
      $855 = ___cxa_find_matching_catch_2()|0;
      $856 = tempRet0;
      $857 = HEAP32[$$pre$phiZ2D>>2]|0;
      $858 = ($857|0)==(0|0);
      if (!($858)) {
       $859 = ((($857)) + 8|0);
       $860 = HEAP32[$859>>2]|0;HEAP32[$859>>2] = (($860-1)|0);
       $861 = ($860|0)==(1);
       if ($861) {
        __THREW__ = 0;
        invoke_viii(3262,($857|0),1,1);
        $862 = __THREW__; __THREW__ = 0;
        $863 = $862&1;
        if ($863) {
         $867 = ___cxa_find_matching_catch_3(0|0)|0;
         $868 = tempRet0;
         $869 = HEAP8[$$pre$phi638Z2D>>0]|0;
         $870 = ($869<<24>>24)<(0);
         if (!($870)) {
          $eh$lpad$body137$indexZ2D = $867;
          ___clang_call_terminate($eh$lpad$body137$indexZ2D);
          // unreachable;
         }
         $871 = HEAP32[$$pre$phi640Z2D>>2]|0;
         __ZdlPv($871);
         $eh$lpad$body137$indexZ2D = $867;
         ___clang_call_terminate($eh$lpad$body137$indexZ2D);
         // unreachable;
        }
       }
      }
      HEAP32[$$pre$phiZ2D>>2] = 0;
      $864 = HEAP8[$$pre$phi638Z2D>>0]|0;
      $865 = ($864<<24>>24)<(0);
      if ($865) {
       $866 = HEAP32[$$pre$phi640Z2D>>2]|0;
       __ZdlPv($866);
       $$20 = $855;$$20101 = $856;
      } else {
       $$20 = $855;$$20101 = $856;
      }
     }
     else if ((label|0) == 322) {
      $899 = ___cxa_find_matching_catch_2()|0;
      $900 = tempRet0;
      $901 = HEAP8[$$pre$phi638Z2D>>0]|0;
      $902 = ($901<<24>>24)<(0);
      if ($902) {
       $903 = HEAP32[$$pre$phi640Z2D>>2]|0;
       __ZdlPv($903);
       $eh$lpad$body236$index39Z2D = $900;$eh$lpad$body236$indexZ2D = $899;
       label = 302;
      } else {
       $eh$lpad$body236$index39Z2D = $900;$eh$lpad$body236$indexZ2D = $899;
       label = 302;
      }
     }
     else if ((label|0) == 326) {
      $906 = ((($2)) + 4|0);
      __THREW__ = 0;
      invoke_vii(4205,($9|0),($906|0));
      $907 = __THREW__; __THREW__ = 0;
      $908 = $907&1;
      if ($908) {
       $853 = ___cxa_find_matching_catch_2()|0;
       $854 = tempRet0;
       $eh$lpad$body236$index39Z2D = $854;$eh$lpad$body236$indexZ2D = $853;
       label = 302;
       break;
      }
      __THREW__ = 0;
      invoke_viii(4192,($20|0),($1|0),($9|0));
      $909 = __THREW__; __THREW__ = 0;
      $910 = $909&1;
      if ($910) {
       $915 = ___cxa_find_matching_catch_2()|0;
       $916 = tempRet0;
       $917 = ((($9)) + 11|0);
       $918 = HEAP8[$917>>0]|0;
       $919 = ($918<<24>>24)<(0);
       if ($919) {
        $920 = HEAP32[$9>>2]|0;
        __ZdlPv($920);
       }
       $eh$lpad$body236$index39Z2D = $916;$eh$lpad$body236$indexZ2D = $915;
       label = 302;
       break;
      }
      $911 = ((($9)) + 11|0);
      $912 = HEAP8[$911>>0]|0;
      $913 = ($912<<24>>24)<(0);
      if ($913) {
       $914 = HEAP32[$9>>2]|0;
       __ZdlPv($914);
      }
      __THREW__ = 0;
      $921 = (invoke_iii(4194,($1|0),($20|0))|0);
      $922 = __THREW__; __THREW__ = 0;
      $923 = $922&1;
      L442: do {
       if ($923) {
        label = 366;
       } else {
        $924 = ($921|0)==(0);
        L444: do {
         if ($924) {
          label = 389;
         } else {
          L445: while(1) {
           $925 = HEAP32[$600>>2]|0;
           $926 = HEAP32[$925>>2]|0;
           $927 = ((($926)) + 8|0);
           $928 = HEAP32[$927>>2]|0;
           __THREW__ = 0;
           (invoke_ii($928|0,($925|0))|0);
           $929 = __THREW__; __THREW__ = 0;
           $930 = $929&1;
           if ($930) {
            label = 365;
            break;
           }
           $931 = HEAP32[$18>>2]|0;
           $932 = HEAP32[$931>>2]|0;
           $933 = ((($931)) + 4|0);
           $934 = HEAP32[$933>>2]|0;
           $935 = ($932|0)==($934|0);
           L448: do {
            if ($935) {
             $$0$i$i253 = 0;
            } else {
             $936 = HEAP32[$603>>2]|0;
             $937 = ($936|0)==(0|0);
             if ($937) {
              $$pre$i$i242 = HEAP32[$932>>2]|0;
              $$0$i$i253 = $$pre$i$i242;
              break;
             } else {
              $$sroa$011$025$i$i244 = $932;
             }
             while(1) {
              $940 = HEAP32[$$sroa$011$025$i$i244>>2]|0;
              $$0$ph13$i$i$i$i$i246 = $603;$$07$ph12$i$i$i$i$i247 = $936;
              L454: while(1) {
               $$0710$i$i$i$i$i249 = $$07$ph12$i$i$i$i$i247;
               while(1) {
                $941 = ((($$0710$i$i$i$i$i249)) + 16|0);
                $942 = HEAP32[$941>>2]|0;
                $943 = ($942>>>0)<($940>>>0);
                if (!($943)) {
                 break;
                }
                $946 = ((($$0710$i$i$i$i$i249)) + 4|0);
                $947 = HEAP32[$946>>2]|0;
                $948 = ($947|0)==(0|0);
                if ($948) {
                 $$0$ph$lcssa$i$i$i$i$i251 = $$0$ph13$i$i$i$i$i246;
                 break L454;
                } else {
                 $$0710$i$i$i$i$i249 = $947;
                }
               }
               $944 = HEAP32[$$0710$i$i$i$i$i249>>2]|0;
               $945 = ($944|0)==(0|0);
               if ($945) {
                $$0$ph$lcssa$i$i$i$i$i251 = $$0710$i$i$i$i$i249;
                break;
               } else {
                $$0$ph13$i$i$i$i$i246 = $$0710$i$i$i$i$i249;$$07$ph12$i$i$i$i$i247 = $944;
               }
              }
              $949 = ($$0$ph$lcssa$i$i$i$i$i251|0)==($603|0);
              if ($949) {
               $$0$i$i253 = $940;
               break L448;
              }
              $950 = ((($$0$ph$lcssa$i$i$i$i$i251)) + 16|0);
              $951 = HEAP32[$950>>2]|0;
              $952 = ($940>>>0)<($951>>>0);
              $938 = ((($$sroa$011$025$i$i244)) + 4|0);
              if ($952) {
               $$0$i$i253 = $940;
               break L448;
              }
              $939 = ($938|0)==($934|0);
              if ($939) {
               $$0$i$i253 = 0;
               break;
              } else {
               $$sroa$011$025$i$i244 = $938;
              }
             }
            }
           } while(0);
           $953 = HEAP32[$925>>2]|0;
           $954 = ((($953)) + 12|0);
           $955 = HEAP32[$954>>2]|0;
           __THREW__ = 0;
           (invoke_ii($955|0,($925|0))|0);
           $956 = __THREW__; __THREW__ = 0;
           $957 = $956&1;
           if ($957) {
            label = 365;
            break;
           }
           $958 = ($$0$i$i253|0)==(0|0);
           if ($958) {
            label = 389;
            break L444;
           }
           $959 = HEAP32[$2>>2]|0;
           $960 = ((($959)) + 8|0);
           $961 = HEAP32[$960>>2]|0;
           $962 = HEAP32[$600>>2]|0;
           $963 = HEAP32[$962>>2]|0;
           $964 = ((($963)) + 8|0);
           $965 = HEAP32[$964>>2]|0;
           __THREW__ = 0;
           (invoke_ii($965|0,($962|0))|0);
           $966 = __THREW__; __THREW__ = 0;
           $967 = $966&1;
           if ($967) {
            label = 365;
            break;
           }
           $968 = HEAP32[$18>>2]|0;
           $969 = HEAP32[$968>>2]|0;
           $970 = ((($968)) + 4|0);
           $971 = HEAP32[$970>>2]|0;
           $972 = ($969|0)==($971|0);
           L467: do {
            if ($972) {
             $$0$i$i270 = 0;
            } else {
             $973 = HEAP32[$603>>2]|0;
             $974 = ($973|0)==(0|0);
             if ($974) {
              $$pre$i$i259 = HEAP32[$969>>2]|0;
              $$0$i$i270 = $$pre$i$i259;
              break;
             } else {
              $$sroa$011$025$i$i261 = $969;
             }
             while(1) {
              $977 = HEAP32[$$sroa$011$025$i$i261>>2]|0;
              $$0$ph13$i$i$i$i$i263 = $603;$$07$ph12$i$i$i$i$i264 = $973;
              L473: while(1) {
               $$0710$i$i$i$i$i266 = $$07$ph12$i$i$i$i$i264;
               while(1) {
                $978 = ((($$0710$i$i$i$i$i266)) + 16|0);
                $979 = HEAP32[$978>>2]|0;
                $980 = ($979>>>0)<($977>>>0);
                if (!($980)) {
                 break;
                }
                $983 = ((($$0710$i$i$i$i$i266)) + 4|0);
                $984 = HEAP32[$983>>2]|0;
                $985 = ($984|0)==(0|0);
                if ($985) {
                 $$0$ph$lcssa$i$i$i$i$i268 = $$0$ph13$i$i$i$i$i263;
                 break L473;
                } else {
                 $$0710$i$i$i$i$i266 = $984;
                }
               }
               $981 = HEAP32[$$0710$i$i$i$i$i266>>2]|0;
               $982 = ($981|0)==(0|0);
               if ($982) {
                $$0$ph$lcssa$i$i$i$i$i268 = $$0710$i$i$i$i$i266;
                break;
               } else {
                $$0$ph13$i$i$i$i$i263 = $$0710$i$i$i$i$i266;$$07$ph12$i$i$i$i$i264 = $981;
               }
              }
              $986 = ($$0$ph$lcssa$i$i$i$i$i268|0)==($603|0);
              if ($986) {
               $$0$i$i270 = $977;
               break L467;
              }
              $987 = ((($$0$ph$lcssa$i$i$i$i$i268)) + 16|0);
              $988 = HEAP32[$987>>2]|0;
              $989 = ($977>>>0)<($988>>>0);
              $975 = ((($$sroa$011$025$i$i261)) + 4|0);
              if ($989) {
               $$0$i$i270 = $977;
               break L467;
              }
              $976 = ($975|0)==($971|0);
              if ($976) {
               $$0$i$i270 = 0;
               break;
              } else {
               $$sroa$011$025$i$i261 = $975;
              }
             }
            }
           } while(0);
           $990 = HEAP32[$962>>2]|0;
           $991 = ((($990)) + 12|0);
           $992 = HEAP32[$991>>2]|0;
           __THREW__ = 0;
           (invoke_ii($992|0,($962|0))|0);
           $993 = __THREW__; __THREW__ = 0;
           $994 = $993&1;
           if ($994) {
            label = 365;
            break;
           }
           __THREW__ = 0;
           invoke_viii($961|0,($0|0),($2|0),($$0$i$i270|0));
           $995 = __THREW__; __THREW__ = 0;
           $996 = $995&1;
           if ($996) {
            label = 365;
            break;
           }
           $997 = HEAP32[$2>>2]|0;
           $998 = ((($997)) + 12|0);
           $999 = HEAP32[$998>>2]|0;
           __THREW__ = 0;
           $1000 = (invoke_iii($999|0,($2|0),($0|0))|0);
           $1001 = __THREW__; __THREW__ = 0;
           $1002 = $1001&1;
           if ($1002) {
            label = 368;
            break;
           }
           if ($1000) {
            break L444;
           }
           $1024 = HEAP32[$596>>2]|0;
           $1025 = HEAP32[$605>>2]|0;
           $1026 = ($1024|0)==($1025|0);
           if ($1026) {
            __THREW__ = 0;
            invoke_vii(4202,($17|0),($0|0));
            $1038 = __THREW__; __THREW__ = 0;
            $1039 = $1038&1;
            if ($1039) {
             label = 368;
             break;
            }
           } else {
            $1027 = HEAP32[$$pre$phi642Z2D>>2]|0;
            HEAP32[$1024>>2] = $1027;
            $1028 = ((($1024)) + 4|0);
            __THREW__ = 0;
            invoke_vii(3457,($1028|0),($$pre$phi634Z2D|0));
            $1029 = __THREW__; __THREW__ = 0;
            $1030 = $1029&1;
            if ($1030) {
             label = 368;
             break;
            }
            $1031 = ((($1024)) + 16|0);
            $1032 = HEAP32[$$pre$phiZ2D>>2]|0;
            HEAP32[$1031>>2] = $1032;
            $1033 = ($1032|0)==(0|0);
            if (!($1033)) {
             $1034 = ((($1032)) + 8|0);
             $1035 = HEAP32[$1034>>2]|0;HEAP32[$1034>>2] = (($1035+1)|0);
            }
            $1036 = HEAP32[$596>>2]|0;
            $1037 = ((($1036)) + 20|0);
            HEAP32[$596>>2] = $1037;
           }
           $1040 = HEAP32[$$pre$phiZ2D>>2]|0;
           $1041 = ($1040|0)==(0|0);
           do {
            if (!($1041)) {
             $1042 = ((($1040)) + 8|0);
             $1043 = HEAP32[$1042>>2]|0;HEAP32[$1042>>2] = (($1043-1)|0);
             $1044 = ($1043|0)==(1);
             if (!($1044)) {
              break;
             }
             __THREW__ = 0;
             invoke_viii(3262,($1040|0),1,1);
             $1045 = __THREW__; __THREW__ = 0;
             $1046 = $1045&1;
             if ($1046) {
              label = 386;
              break L445;
             }
            }
           } while(0);
           HEAP32[$$pre$phiZ2D>>2] = 0;
           $1047 = HEAP8[$$pre$phi638Z2D>>0]|0;
           $1048 = ($1047<<24>>24)<(0);
           if ($1048) {
            $1049 = HEAP32[$$pre$phi640Z2D>>2]|0;
            __ZdlPv($1049);
           }
           __THREW__ = 0;
           invoke_vi(4203,($18|0));
           $1055 = __THREW__; __THREW__ = 0;
           $1056 = $1055&1;
           if ($1056) {
            label = 365;
            break;
           }
          }
          if ((label|0) == 365) {
           $1003 = ___cxa_find_matching_catch_2()|0;
           $1004 = tempRet0;
           $eh$lpad$body285$index49Z2D = $1004;$eh$lpad$body285$indexZ2D = $1003;
           label = 367;
           break L442;
          }
          else if ((label|0) == 368) {
           $1007 = ___cxa_find_matching_catch_2()|0;
           $1008 = tempRet0;
           $1009 = HEAP32[$$pre$phiZ2D>>2]|0;
           $1010 = ($1009|0)==(0|0);
           if (!($1010)) {
            $1011 = ((($1009)) + 8|0);
            $1012 = HEAP32[$1011>>2]|0;HEAP32[$1011>>2] = (($1012-1)|0);
            $1013 = ($1012|0)==(1);
            if ($1013) {
             __THREW__ = 0;
             invoke_viii(3262,($1009|0),1,1);
             $1014 = __THREW__; __THREW__ = 0;
             $1015 = $1014&1;
             if ($1015) {
              $1019 = ___cxa_find_matching_catch_3(0|0)|0;
              $1020 = tempRet0;
              $1021 = HEAP8[$$pre$phi638Z2D>>0]|0;
              $1022 = ($1021<<24>>24)<(0);
              if (!($1022)) {
               $eh$lpad$body137$indexZ2D = $1019;
               ___clang_call_terminate($eh$lpad$body137$indexZ2D);
               // unreachable;
              }
              $1023 = HEAP32[$$pre$phi640Z2D>>2]|0;
              __ZdlPv($1023);
              $eh$lpad$body137$indexZ2D = $1019;
              ___clang_call_terminate($eh$lpad$body137$indexZ2D);
              // unreachable;
             }
            }
           }
           HEAP32[$$pre$phiZ2D>>2] = 0;
           $1016 = HEAP8[$$pre$phi638Z2D>>0]|0;
           $1017 = ($1016<<24>>24)<(0);
           if (!($1017)) {
            $$19 = $1007;$$19100 = $1008;
            break L442;
           }
           $1018 = HEAP32[$$pre$phi640Z2D>>2]|0;
           __ZdlPv($1018);
           $$19 = $1007;$$19100 = $1008;
           break L442;
          }
          else if ((label|0) == 386) {
           $1050 = ___cxa_find_matching_catch_2()|0;
           $1051 = tempRet0;
           $1052 = HEAP8[$$pre$phi638Z2D>>0]|0;
           $1053 = ($1052<<24>>24)<(0);
           if (!($1053)) {
            $eh$lpad$body285$index49Z2D = $1051;$eh$lpad$body285$indexZ2D = $1050;
            label = 367;
            break L442;
           }
           $1054 = HEAP32[$$pre$phi640Z2D>>2]|0;
           __ZdlPv($1054);
           $eh$lpad$body285$index49Z2D = $1051;$eh$lpad$body285$indexZ2D = $1050;
           label = 367;
           break L442;
          }
         }
        } while(0);
        L517: do {
         if ((label|0) == 389) {
          __THREW__ = 0;
          $1057 = (invoke_ii(4206,($906|0))|0);
          $1058 = __THREW__; __THREW__ = 0;
          $1059 = $1058&1;
          if ($1059) {
           label = 366;
           break L442;
          }
          if ($1057) {
           __THREW__ = 0;
           invoke_vii(4207,($21|0),($906|0));
           $1060 = __THREW__; __THREW__ = 0;
           $1061 = $1060&1;
           if ($1061) {
            $1081 = ___cxa_find_matching_catch_2()|0;
            $1082 = tempRet0;
            $$13 = $1081;$$1394 = $1082;
           } else {
            __THREW__ = 0;
            invoke_vii(4205,($22|0),($906|0));
            $1062 = __THREW__; __THREW__ = 0;
            $1063 = $1062&1;
            do {
             if ($1063) {
              $1083 = ___cxa_find_matching_catch_2()|0;
              $1084 = tempRet0;
              $$12 = $1083;$$1293 = $1084;
             } else {
              __THREW__ = 0;
              $1064 = (invoke_iiii(4208,($1|0),($21|0),($22|0))|0);
              $1065 = __THREW__; __THREW__ = 0;
              $1066 = $1065&1;
              if ($1066) {
               $1085 = ___cxa_find_matching_catch_2()|0;
               $1086 = tempRet0;
               $1087 = ((($22)) + 11|0);
               $1088 = HEAP8[$1087>>0]|0;
               $1089 = ($1088<<24>>24)<(0);
               if (!($1089)) {
                $$12 = $1085;$$1293 = $1086;
                break;
               }
               $1090 = HEAP32[$22>>2]|0;
               __ZdlPv($1090);
               $$12 = $1085;$$1293 = $1086;
               break;
              }
              $1067 = ((($22)) + 11|0);
              $1068 = HEAP8[$1067>>0]|0;
              $1069 = ($1068<<24>>24)<(0);
              if ($1069) {
               $1070 = HEAP32[$22>>2]|0;
               __ZdlPv($1070);
              }
              $1071 = ((($21)) + 11|0);
              $1072 = HEAP8[$1071>>0]|0;
              $1073 = ($1072<<24>>24)<(0);
              if ($1073) {
               $1074 = HEAP32[$21>>2]|0;
               __ZdlPv($1074);
              }
              $1075 = ($1064|0)==(0|0);
              if (!($1075)) {
               $1076 = HEAP32[$2>>2]|0;
               $1077 = ((($1076)) + 8|0);
               $1078 = HEAP32[$1077>>2]|0;
               __THREW__ = 0;
               invoke_viii($1078|0,($0|0),($2|0),($1064|0));
               $1079 = __THREW__; __THREW__ = 0;
               $1080 = $1079&1;
               if (!($1080)) {
                break L517;
               }
               $1095 = ___cxa_find_matching_catch_2()|0;
               $1096 = tempRet0;
               $$19 = $1095;$$19100 = $1096;
               break L442;
              }
              ;HEAP32[$23>>2]=0|0;HEAP32[$23+4>>2]=0|0;HEAP32[$23+8>>2]=0|0;
              __THREW__ = 0;
              $1097 = (invoke_ii(3276,64)|0);
              $1098 = __THREW__; __THREW__ = 0;
              $1099 = $1098&1;
              do {
               if ($1099) {
                $1109 = ___cxa_find_matching_catch_2()|0;
                $1110 = tempRet0;
                $$14 = $1109;$$1495 = $1110;
               } else {
                HEAP32[$23>>2] = $1097;
                $1100 = ((($23)) + 8|0);
                HEAP32[$1100>>2] = -2147483584;
                $1101 = ((($23)) + 4|0);
                HEAP32[$1101>>2] = 52;
                dest=$1097; src=167716; stop=dest+52|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                $1102 = ((($1097)) + 52|0);
                HEAP8[$1102>>0] = 0;
                HEAP32[$$pre$phi642Z2D>>2] = 3;
                __THREW__ = 0;
                invoke_vii(3457,($$pre$phi634Z2D|0),($23|0));
                $1103 = __THREW__; __THREW__ = 0;
                $1104 = $1103&1;
                if ($1104) {
                 $1111 = ___cxa_find_matching_catch_2()|0;
                 $1112 = tempRet0;
                 $1113 = ((($23)) + 11|0);
                 $1114 = HEAP8[$1113>>0]|0;
                 $1115 = ($1114<<24>>24)<(0);
                 if (!($1115)) {
                  $$14 = $1111;$$1495 = $1112;
                  break;
                 }
                 $1116 = HEAP32[$23>>2]|0;
                 __ZdlPv($1116);
                 $$14 = $1111;$$1495 = $1112;
                 break;
                }
                HEAP32[$$pre$phiZ2D>>2] = 0;
                $1105 = ((($23)) + 11|0);
                $1106 = HEAP8[$1105>>0]|0;
                $1107 = ($1106<<24>>24)<(0);
                if ($1107) {
                 $1108 = HEAP32[$23>>2]|0;
                 __ZdlPv($1108);
                }
                break L517;
               }
              } while(0);
              $$19 = $$14;$$19100 = $$1495;
              break L442;
             }
            } while(0);
            $1091 = ((($21)) + 11|0);
            $1092 = HEAP8[$1091>>0]|0;
            $1093 = ($1092<<24>>24)<(0);
            if ($1093) {
             $1094 = HEAP32[$21>>2]|0;
             __ZdlPv($1094);
             $$13 = $$12;$$1394 = $$1293;
            } else {
             $$13 = $$12;$$1394 = $$1293;
            }
           }
           $$19 = $$13;$$19100 = $$1394;
           break L442;
          }
          $1117 = HEAP32[$17>>2]|0;
          $1118 = HEAP32[$596>>2]|0;
          $1119 = ($1117|0)==($1118|0);
          if ($1119) {
           __THREW__ = 0;
           invoke_viii(4173,($25|0),(167769|0),($906|0));
           $1120 = __THREW__; __THREW__ = 0;
           $1121 = $1120&1;
           if ($1121) {
            $1134 = ___cxa_find_matching_catch_2()|0;
            $1135 = tempRet0;
            $$17 = $1134;$$1798 = $1135;
           } else {
            __THREW__ = 0;
            invoke_viii(3542,($24|0),($25|0),(167562|0));
            $1122 = __THREW__; __THREW__ = 0;
            $1123 = $1122&1;
            do {
             if ($1123) {
              $1136 = ___cxa_find_matching_catch_2()|0;
              $1137 = tempRet0;
              $$16 = $1136;$$1697 = $1137;
             } else {
              HEAP32[$$pre$phi642Z2D>>2] = 3;
              __THREW__ = 0;
              invoke_vii(3457,($$pre$phi634Z2D|0),($24|0));
              $1124 = __THREW__; __THREW__ = 0;
              $1125 = $1124&1;
              if ($1125) {
               $1138 = ___cxa_find_matching_catch_2()|0;
               $1139 = tempRet0;
               $1140 = ((($24)) + 11|0);
               $1141 = HEAP8[$1140>>0]|0;
               $1142 = ($1141<<24>>24)<(0);
               if (!($1142)) {
                $$16 = $1138;$$1697 = $1139;
                break;
               }
               $1143 = HEAP32[$24>>2]|0;
               __ZdlPv($1143);
               $$16 = $1138;$$1697 = $1139;
               break;
              }
              HEAP32[$$pre$phiZ2D>>2] = 0;
              $1126 = ((($24)) + 11|0);
              $1127 = HEAP8[$1126>>0]|0;
              $1128 = ($1127<<24>>24)<(0);
              if ($1128) {
               $1129 = HEAP32[$24>>2]|0;
               __ZdlPv($1129);
              }
              $1130 = ((($25)) + 11|0);
              $1131 = HEAP8[$1130>>0]|0;
              $1132 = ($1131<<24>>24)<(0);
              if ($1132) {
               $1133 = HEAP32[$25>>2]|0;
               __ZdlPv($1133);
              }
              break L517;
             }
            } while(0);
            $1144 = ((($25)) + 11|0);
            $1145 = HEAP8[$1144>>0]|0;
            $1146 = ($1145<<24>>24)<(0);
            if ($1146) {
             $1147 = HEAP32[$25>>2]|0;
             __ZdlPv($1147);
             $$17 = $$16;$$1798 = $$1697;
            } else {
             $$17 = $$16;$$1798 = $$1697;
            }
           }
           $$19 = $$17;$$19100 = $$1798;
           break L442;
          }
          __THREW__ = 0;
          invoke_viii(4209,($1117|0),($1118|0),($8|0));
          $1148 = __THREW__; __THREW__ = 0;
          $1149 = $1148&1;
          if ($1149) {
           label = 366;
           break L442;
          }
          $1150 = HEAP32[$596>>2]|0;
          $1151 = ((($1150)) + -20|0);
          $1152 = HEAP32[$1151>>2]|0;
          HEAP32[$26>>2] = $1152;
          $1153 = ((($26)) + 4|0);
          $1154 = ((($1150)) + -16|0);
          __THREW__ = 0;
          invoke_vii(3457,($1153|0),($1154|0));
          $1155 = __THREW__; __THREW__ = 0;
          $1156 = $1155&1;
          if ($1156) {
           label = 366;
           break L442;
          }
          $1157 = ((($26)) + 16|0);
          $1158 = ((($1150)) + -4|0);
          $1159 = HEAP32[$1158>>2]|0;
          HEAP32[$1157>>2] = $1159;
          $1160 = ($1159|0)==(0|0);
          if (!($1160)) {
           $1161 = ((($1159)) + 8|0);
           $1162 = HEAP32[$1161>>2]|0;HEAP32[$1161>>2] = (($1162+1)|0);
          }
          $1163 = HEAP32[$26>>2]|0;
          HEAP32[$$pre$phi642Z2D>>2] = $1163;
          __THREW__ = 0;
          invoke_vii(3457,($$pre$phi634Z2D|0),($1153|0));
          $1164 = __THREW__; __THREW__ = 0;
          $1165 = $1164&1;
          L584: do {
           if ($1165) {
            $1186 = ___cxa_find_matching_catch_2()|0;
            $1187 = tempRet0;
            $1188 = HEAP32[$1157>>2]|0;
            $1189 = ($1188|0)==(0|0);
            do {
             if (!($1189)) {
              $1190 = ((($1188)) + 8|0);
              $1191 = HEAP32[$1190>>2]|0;HEAP32[$1190>>2] = (($1191-1)|0);
              $1192 = ($1191|0)==(1);
              if (!($1192)) {
               break;
              }
              __THREW__ = 0;
              invoke_viii(3262,($1188|0),1,1);
              $1193 = __THREW__; __THREW__ = 0;
              $1194 = $1193&1;
              if (!($1194)) {
               break;
              }
              $1199 = ___cxa_find_matching_catch_3(0|0)|0;
              $1200 = tempRet0;
              $1201 = ((($1153)) + 11|0);
              $1202 = HEAP8[$1201>>0]|0;
              $1203 = ($1202<<24>>24)<(0);
              if (!($1203)) {
               $eh$lpad$body137$indexZ2D = $1199;
               ___clang_call_terminate($eh$lpad$body137$indexZ2D);
               // unreachable;
              }
              $1204 = HEAP32[$1153>>2]|0;
              __ZdlPv($1204);
              $eh$lpad$body137$indexZ2D = $1199;
              ___clang_call_terminate($eh$lpad$body137$indexZ2D);
              // unreachable;
             }
            } while(0);
            HEAP32[$1157>>2] = 0;
            $1195 = ((($1153)) + 11|0);
            $1196 = HEAP8[$1195>>0]|0;
            $1197 = ($1196<<24>>24)<(0);
            if (!($1197)) {
             $$18 = $1186;$$1899 = $1187;
             break;
            }
            $1198 = HEAP32[$1153>>2]|0;
            __ZdlPv($1198);
            $$18 = $1186;$$1899 = $1187;
           } else {
            $1166 = HEAP32[$1157>>2]|0;
            HEAP32[$$pre$phiZ2D>>2] = $1166;
            $1167 = ($1166|0)==(0|0);
            do {
             if (!($1167)) {
              $1168 = ((($1166)) + 8|0);
              $1169 = HEAP32[$1168>>2]|0;HEAP32[$1168>>2] = (($1169+1)|0);
              $$pre631 = HEAP32[$1157>>2]|0;
              $1170 = ($$pre631|0)==(0|0);
              if ($1170) {
               break;
              }
              $1171 = ((($$pre631)) + 8|0);
              $1172 = HEAP32[$1171>>2]|0;HEAP32[$1171>>2] = (($1172-1)|0);
              $1173 = ($1172|0)==(1);
              if (!($1173)) {
               break;
              }
              __THREW__ = 0;
              invoke_viii(3262,($$pre631|0),1,1);
              $1174 = __THREW__; __THREW__ = 0;
              $1175 = $1174&1;
              if (!($1175)) {
               break;
              }
              $1180 = ___cxa_find_matching_catch_2()|0;
              $1181 = tempRet0;
              $1182 = ((($1153)) + 11|0);
              $1183 = HEAP8[$1182>>0]|0;
              $1184 = ($1183<<24>>24)<(0);
              if ($1184) {
               $1185 = HEAP32[$1153>>2]|0;
               __ZdlPv($1185);
              }
              $$18 = $1180;$$1899 = $1181;
              break L584;
             }
            } while(0);
            HEAP32[$1157>>2] = 0;
            $1176 = ((($1153)) + 11|0);
            $1177 = HEAP8[$1176>>0]|0;
            $1178 = ($1177<<24>>24)<(0);
            if ($1178) {
             $1179 = HEAP32[$1153>>2]|0;
             __ZdlPv($1179);
            }
            break L517;
           }
          } while(0);
          $$19 = $$18;$$19100 = $$1899;
          break L442;
         }
        } while(0);
        $1205 = ((($20)) + 11|0);
        $1206 = HEAP8[$1205>>0]|0;
        $1207 = ($1206<<24>>24)<(0);
        if ($1207) {
         $1208 = HEAP32[$20>>2]|0;
         __ZdlPv($1208);
        }
        label = 462;
        break L414;
       }
      } while(0);
      if ((label|0) == 366) {
       $1005 = ___cxa_find_matching_catch_2()|0;
       $1006 = tempRet0;
       $eh$lpad$body285$index49Z2D = $1006;$eh$lpad$body285$indexZ2D = $1005;
       label = 367;
      }
      if ((label|0) == 367) {
       $$19 = $eh$lpad$body285$indexZ2D;$$19100 = $eh$lpad$body285$index49Z2D;
      }
      $1209 = ((($20)) + 11|0);
      $1210 = HEAP8[$1209>>0]|0;
      $1211 = ($1210<<24>>24)<(0);
      if ($1211) {
       $1212 = HEAP32[$20>>2]|0;
       __ZdlPv($1212);
      }
      $$20 = $$19;$$20101 = $$19100;
     }
    } while(0);
    if ((label|0) == 302) {
     $$20 = $eh$lpad$body236$indexZ2D;$$20101 = $eh$lpad$body236$index39Z2D;
    }
    else if ((label|0) == 462) {
     $1213 = ((($19)) + 8|0);
     $1214 = HEAP32[$741>>2]|0;
     __ZNSt3__26__treeIPN5osgDB7ArchiveENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($1213,$1214);
     label = 464;
     break;
    }
    $1215 = ((($19)) + 8|0);
    $1216 = HEAP32[$741>>2]|0;
    __ZNSt3__26__treeIPN5osgDB7ArchiveENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($1215,$1216);
    $$22 = $$20;$$22103 = $$20101;
   }
  } while(0);
  if ((label|0) == 236) {
   $$22 = $eh$lpad$body189$indexZ2D;$$22103 = $eh$lpad$body189$index30Z2D;
  }
  else if ((label|0) == 464) {
   $1217 = ((($18)) + 8|0);
   $1218 = HEAP32[$603>>2]|0;
   __ZNSt3__26__treeIPN5osgDB12ReaderWriterENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($1217,$1218);
   __ZNSt3__213__vector_baseIN5osgDB12ReaderWriter10ReadResultENS_9allocatorIS3_EEED2Ev($17);
   STACKTOP = sp;return;
  }
  $1219 = ((($18)) + 8|0);
  $1220 = HEAP32[$603>>2]|0;
  __ZNSt3__26__treeIPN5osgDB12ReaderWriterENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($1219,$1220);
  __THREW__ = 0;
  invoke_vi(4210,($17|0));
  $1221 = __THREW__; __THREW__ = 0;
  $1222 = $1221&1;
  if (!($1222)) {
   $$25 = $$22;$$25106 = $$22103;
   ___resumeException($$25|0);
   // unreachable;
  }
 }
 $1223 = ___cxa_find_matching_catch_3(0|0)|0;
 $1224 = tempRet0;
 $eh$lpad$body137$indexZ2D = $1223;
 ___clang_call_terminate($eh$lpad$body137$indexZ2D);
 // unreachable;
}
function __ZNSt3__2plIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_12basic_stringIT_T0_T1_EERKS9_S6_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$i11 = 0, $$0$i12 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 ;HEAP32[$0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;
 $3 = ((($1)) + 11|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)<(0);
 $6 = ((($1)) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $4&255;
 $9 = $5 ? $7 : $8;
 $10 = HEAP32[$1>>2]|0;
 $11 = $5 ? $10 : $1;
 $12 = (($9) + 1)|0;
 $13 = ($12>>>0)>(4294967279);
 do {
  if ($13) {
   __THREW__ = 0;
   invoke_vi(3367,($0|0));
   $14 = __THREW__; __THREW__ = 0;
  } else {
   $15 = ($12>>>0)<(11);
   if ($15) {
    $24 = $9&255;
    $25 = ((($0)) + 11|0);
    HEAP8[$25>>0] = $24;
    $26 = ($9|0)==(0);
    if ($26) {
     $$0$i12 = $0;
    } else {
     $$0$i11 = $0;
     label = 7;
    }
   } else {
    $16 = (($9) + 17)|0;
    $17 = $16 & -16;
    __THREW__ = 0;
    $18 = (invoke_ii(3276,($17|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    HEAP32[$0>>2] = $18;
    $21 = $17 | -2147483648;
    $22 = ((($0)) + 8|0);
    HEAP32[$22>>2] = $21;
    $23 = ((($0)) + 4|0);
    HEAP32[$23>>2] = $9;
    $$0$i11 = $18;
    label = 7;
   }
   if ((label|0) == 7) {
    _memcpy(($$0$i11|0),($11|0),($9|0))|0;
    $$0$i12 = $$0$i11;
   }
   $27 = (($$0$i12) + ($9)|0);
   HEAP8[$27>>0] = 0;
   __THREW__ = 0;
   invoke_vii(3433,($0|0),($2|0));
   $28 = __THREW__; __THREW__ = 0;
   $29 = $28&1;
   if (!($29)) {
    return;
   }
  }
 } while(0);
 $30 = ___cxa_find_matching_catch_2()|0;
 $31 = tempRet0;
 $32 = ((($0)) + 11|0);
 $33 = HEAP8[$32>>0]|0;
 $34 = ($33<<24>>24)<(0);
 if (!($34)) {
  ___resumeException($30|0);
  // unreachable;
 }
 $35 = HEAP32[$0>>2]|0;
 __ZdlPv($35);
 ___resumeException($30|0);
 // unreachable;
}
function __ZN5osgDB8Registry25openArchiveImplementationERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEENS_12ReaderWriter13ArchiveStatusEjPKNS_7OptionsE($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$0 = 0, $$010 = 0, $$21230 = 0, $$231 = 0, $$pre = 0, $$sroa$0$0 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $6 = sp + 28|0;
 $7 = sp;
 $8 = ((($1)) + 108|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($9)) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 (FUNCTION_TABLE_ii[$11 & 8191]($8)|0);
 $12 = ((($1)) + 120|0);
 __THREW__ = 0;
 $13 = (invoke_iii(4211,($12|0),($2|0))|0);
 $14 = __THREW__; __THREW__ = 0;
 $15 = $14&1;
 if ($15) {
  $23 = ___cxa_find_matching_catch_2()|0;
  $24 = tempRet0;
  $25 = HEAP32[$8>>2]|0;
  $26 = ((($25)) + 12|0);
  $27 = HEAP32[$26>>2]|0;
  __THREW__ = 0;
  (invoke_ii($27|0,($8|0))|0);
  $28 = __THREW__; __THREW__ = 0;
  $29 = $28&1;
  if ($29) {
   $30 = ___cxa_find_matching_catch_3(0|0)|0;
   $31 = tempRet0;
   ___clang_call_terminate($30);
   // unreachable;
  } else {
   ___resumeException($23|0);
   // unreachable;
  }
 }
 $16 = ((($1)) + 124|0);
 $17 = ($13|0)==($16|0);
 if ($17) {
  $$sroa$0$0 = 0;
 } else {
  $18 = ((($13)) + 28|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = ($19|0)==(0|0);
  if ($20) {
   $$sroa$0$0 = 0;
  } else {
   $21 = ((($19)) + 8|0);
   $22 = HEAP32[$21>>2]|0;HEAP32[$21>>2] = (($22+1)|0);
   $$sroa$0$0 = $19;
  }
 }
 $32 = HEAP32[$8>>2]|0;
 $33 = ((($32)) + 12|0);
 $34 = HEAP32[$33>>2]|0;
 (FUNCTION_TABLE_ii[$34 & 8191]($8)|0);
 $35 = ($$sroa$0$0|0)==(0|0);
 if (!($35)) {
  HEAP32[$0>>2] = 4;
  $36 = ((($0)) + 4|0);
  ;HEAP32[$36>>2]=0|0;HEAP32[$36+4>>2]=0|0;HEAP32[$36+8>>2]=0|0;
  $37 = ((($0)) + 16|0);
  HEAP32[$37>>2] = $$sroa$0$0;
  $38 = ((($$sroa$0$0)) + 8|0);
  $39 = HEAP32[$38>>2]|0;HEAP32[$38>>2] = (($39+1)|0);
  $40 = HEAP32[$38>>2]|0;HEAP32[$38>>2] = (($40-1)|0);
  $41 = ($40|0)==(1);
  if (!($41)) {
   STACKTOP = sp;return;
  }
  __ZNK3osg10Referenced24signalObserversAndDeleteEbb($$sroa$0$0,1,1);
  STACKTOP = sp;return;
 }
 HEAP32[$7>>2] = (75072);
 $42 = ((($7)) + 4|0);
 __THREW__ = 0;
 invoke_vii(3457,($42|0),($2|0));
 $43 = __THREW__; __THREW__ = 0;
 $44 = $43&1;
 do {
  if ($44) {
   $100 = ___cxa_find_matching_catch_2()|0;
   $101 = tempRet0;
   $$0 = $101;$$010 = $100;
  } else {
   $45 = ((($7)) + 16|0);
   HEAP32[$45>>2] = $5;
   HEAP32[$7>>2] = (75104);
   $46 = ((($7)) + 20|0);
   HEAP32[$46>>2] = $3;
   $47 = ((($7)) + 24|0);
   HEAP32[$47>>2] = $4;
   __THREW__ = 0;
   invoke_viiii(4212,($6|0),($1|0),($7|0),8);
   $48 = __THREW__; __THREW__ = 0;
   $49 = $48&1;
   if ($49) {
    $102 = ___cxa_find_matching_catch_2()|0;
    $103 = tempRet0;
    HEAP32[$7>>2] = (75072);
    $104 = ((($42)) + 11|0);
    $105 = HEAP8[$104>>0]|0;
    $106 = ($105<<24>>24)<(0);
    if (!($106)) {
     $$0 = $103;$$010 = $102;
     break;
    }
    $107 = HEAP32[$42>>2]|0;
    __ZdlPv($107);
    $$0 = $103;$$010 = $102;
    break;
   }
   HEAP32[$7>>2] = (75072);
   $50 = ((($42)) + 11|0);
   $51 = HEAP8[$50>>0]|0;
   $52 = ($51<<24>>24)<(0);
   if ($52) {
    $53 = HEAP32[$42>>2]|0;
    __ZdlPv($53);
   }
   __THREW__ = 0;
   $54 = (invoke_ii(4200,($6|0))|0);
   $55 = __THREW__; __THREW__ = 0;
   $56 = $55&1;
   L28: do {
    if ($56) {
     label = 34;
    } else {
     $57 = ($54|0)==(0|0);
     L30: do {
      if (!($57)) {
       $58 = ($5|0)==(0|0);
       if (!($58)) {
        $59 = ((($5)) + 68|0);
        $60 = HEAP32[$59>>2]|0;
        $61 = $60 & 8;
        $62 = ($61|0)==(0);
        if ($62) {
         break;
        }
       }
       __THREW__ = 0;
       $63 = (invoke_ii(4200,($6|0))|0);
       $64 = __THREW__; __THREW__ = 0;
       $65 = $64&1;
       if ($65) {
        label = 34;
        break L28;
       }
       $66 = HEAP32[$8>>2]|0;
       $67 = ((($66)) + 8|0);
       $68 = HEAP32[$67>>2]|0;
       __THREW__ = 0;
       (invoke_ii($68|0,($8|0))|0);
       $69 = __THREW__; __THREW__ = 0;
       $70 = $69&1;
       if ($70) {
        label = 34;
        break L28;
       }
       $71 = ((($1)) + 120|0);
       __THREW__ = 0;
       $72 = (invoke_iii(4213,($71|0),($2|0))|0);
       $73 = __THREW__; __THREW__ = 0;
       $74 = $73&1;
       L37: do {
        if (!($74)) {
         $75 = HEAP32[$72>>2]|0;
         $76 = ($75|0)==($63|0);
         do {
          if (!($76)) {
           HEAP32[$72>>2] = $63;
           $77 = ($63|0)==(0|0);
           if (!($77)) {
            $78 = ((($63)) + 8|0);
            $79 = HEAP32[$78>>2]|0;HEAP32[$78>>2] = (($79+1)|0);
           }
           $80 = ($75|0)==(0|0);
           if (!($80)) {
            $81 = ((($75)) + 8|0);
            $82 = HEAP32[$81>>2]|0;HEAP32[$81>>2] = (($82-1)|0);
            $83 = ($82|0)==(1);
            if (!($83)) {
             break;
            }
            __THREW__ = 0;
            invoke_viii(3262,($75|0),1,1);
            $84 = __THREW__; __THREW__ = 0;
            $85 = $84&1;
            if ($85) {
             break L37;
            }
           }
          }
         } while(0);
         $86 = HEAP32[$8>>2]|0;
         $87 = ((($86)) + 12|0);
         $88 = HEAP32[$87>>2]|0;
         __THREW__ = 0;
         (invoke_ii($88|0,($8|0))|0);
         $89 = __THREW__; __THREW__ = 0;
         $90 = $89&1;
         if ($90) {
          label = 34;
          break L28;
         } else {
          break L30;
         }
        }
       } while(0);
       $91 = ___cxa_find_matching_catch_2()|0;
       $92 = tempRet0;
       $93 = HEAP32[$8>>2]|0;
       $94 = ((($93)) + 12|0);
       $95 = HEAP32[$94>>2]|0;
       __THREW__ = 0;
       (invoke_ii($95|0,($8|0))|0);
       $96 = __THREW__; __THREW__ = 0;
       $97 = $96&1;
       if (!($97)) {
        $eh$lpad$body$index2Z2D = $92;$eh$lpad$body$indexZ2D = $91;
        break L28;
       }
       $98 = ___cxa_find_matching_catch_3(0|0)|0;
       $99 = tempRet0;
       ___clang_call_terminate($98);
       // unreachable;
      }
     } while(0);
     $130 = HEAP32[$6>>2]|0;
     HEAP32[$0>>2] = $130;
     $131 = ((($0)) + 4|0);
     $132 = ((($6)) + 4|0);
     __THREW__ = 0;
     invoke_vii(3457,($131|0),($132|0));
     $133 = __THREW__; __THREW__ = 0;
     $134 = $133&1;
     if ($134) {
      label = 34;
     } else {
      $135 = ((($0)) + 16|0);
      $136 = ((($6)) + 16|0);
      $137 = HEAP32[$136>>2]|0;
      HEAP32[$135>>2] = $137;
      $138 = ($137|0)==(0|0);
      if (!($138)) {
       $139 = ((($137)) + 8|0);
       $140 = HEAP32[$139>>2]|0;HEAP32[$139>>2] = (($140+1)|0);
       $$pre = HEAP32[$136>>2]|0;
       $141 = ($$pre|0)==(0|0);
       if (!($141)) {
        $142 = ((($$pre)) + 8|0);
        $143 = HEAP32[$142>>2]|0;HEAP32[$142>>2] = (($143-1)|0);
        $144 = ($143|0)==(1);
        if ($144) {
         __THREW__ = 0;
         invoke_viii(3262,($$pre|0),1,1);
         $145 = __THREW__; __THREW__ = 0;
         $146 = $145&1;
         if ($146) {
          $151 = ___cxa_find_matching_catch_2()|0;
          $152 = tempRet0;
          $153 = ((($132)) + 11|0);
          $154 = HEAP8[$153>>0]|0;
          $155 = ($154<<24>>24)<(0);
          if ($155) {
           $156 = HEAP32[$132>>2]|0;
           __ZdlPv($156);
           $$21230 = $151;$$231 = $152;
           ___resumeException($$21230|0);
           // unreachable;
          } else {
           $$21230 = $151;$$231 = $152;
           ___resumeException($$21230|0);
           // unreachable;
          }
         }
        }
       }
      }
      HEAP32[$136>>2] = 0;
      $147 = ((($132)) + 11|0);
      $148 = HEAP8[$147>>0]|0;
      $149 = ($148<<24>>24)<(0);
      if ($149) {
       $150 = HEAP32[$132>>2]|0;
       __ZdlPv($150);
      }
      STACKTOP = sp;return;
     }
    }
   } while(0);
   if ((label|0) == 34) {
    $108 = ___cxa_find_matching_catch_2()|0;
    $109 = tempRet0;
    $eh$lpad$body$index2Z2D = $109;$eh$lpad$body$indexZ2D = $108;
   }
   $110 = ((($6)) + 16|0);
   $111 = HEAP32[$110>>2]|0;
   $112 = ($111|0)==(0|0);
   if (!($112)) {
    $113 = ((($111)) + 8|0);
    $114 = HEAP32[$113>>2]|0;HEAP32[$113>>2] = (($114-1)|0);
    $115 = ($114|0)==(1);
    if ($115) {
     __THREW__ = 0;
     invoke_viii(3262,($111|0),1,1);
     $116 = __THREW__; __THREW__ = 0;
     $117 = $116&1;
     if ($117) {
      $123 = ___cxa_find_matching_catch_3(0|0)|0;
      $124 = tempRet0;
      $125 = ((($6)) + 4|0);
      $126 = ((($125)) + 11|0);
      $127 = HEAP8[$126>>0]|0;
      $128 = ($127<<24>>24)<(0);
      if (!($128)) {
       ___clang_call_terminate($123);
       // unreachable;
      }
      $129 = HEAP32[$125>>2]|0;
      __ZdlPv($129);
      ___clang_call_terminate($123);
      // unreachable;
     }
    }
   }
   HEAP32[$110>>2] = 0;
   $118 = ((($6)) + 4|0);
   $119 = ((($118)) + 11|0);
   $120 = HEAP8[$119>>0]|0;
   $121 = ($120<<24>>24)<(0);
   if ($121) {
    $122 = HEAP32[$118>>2]|0;
    __ZdlPv($122);
   }
   $$21230 = $eh$lpad$body$indexZ2D;$$231 = $eh$lpad$body$index2Z2D;
   ___resumeException($$21230|0);
   // unreachable;
  }
 } while(0);
 $$21230 = $$010;$$231 = $$0;
 ___resumeException($$21230|0);
 // unreachable;
}
function __ZNSt3__25dequeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS4_IS6_EEE19__add_back_capacityEv($0) {
 $0 = $0|0;
 var $$0 = 0, $$1 = 0, $$115 = 0, $$in = 0, $$in$i = 0, $$in$i26 = 0, $$in$i40 = 0, $$pre$i = 0, $$pre$i28 = 0, $$pre$i42 = 0, $$pre47$i = 0, $$pre47$i21 = 0, $$pre47$i35 = 0, $$pre48$i = 0, $$pre48$i33 = 0, $$pre48$i47 = 0, $$sink97$ph$index = 0, $$sink97$ph$index2 = 0, $$sroa$13$0$i = 0, $$sroa$13$0$i25 = 0;
 var $$sroa$13$0$i39 = 0, $$sroa$13$1$i = 0, $$sroa$13$1$i30 = 0, $$sroa$13$1$i44 = 0, $$sroa$speculated = 0, $$sroa$speculated$i = 0, $$sroa$speculated$i23 = 0, $$sroa$speculated$i37 = 0, $$sroa$speculated$i51 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0;
 var $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0;
 var $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0;
 var $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0;
 var $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0;
 var $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0;
 var $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0;
 var $271 = 0, $272 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i$i$i16 = 0, $scevgep5$i$i$i$i = 0, $scevgep5$i$i$i$i17 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $1 = sp + 20|0;
 $2 = sp;
 $3 = ((($0)) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4>>>0)>(340);
 if ($5) {
  $6 = (($4) + -341)|0;
  HEAP32[$3>>2] = $6;
  $7 = ((($0)) + 4|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = HEAP32[$8>>2]|0;
  $10 = ((($8)) + 4|0);
  HEAP32[$7>>2] = $10;
  $11 = ((($0)) + 8|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ((($0)) + 12|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = ($12|0)==($14|0);
  $16 = $14;
  $17 = $12;
  do {
   if ($15) {
    $18 = HEAP32[$0>>2]|0;
    $19 = ($10>>>0)>($18>>>0);
    $20 = $18;
    if ($19) {
     $21 = $10;
     $22 = (($21) - ($20))|0;
     $23 = $22 >> 2;
     $24 = (($23) + 1)|0;
     $25 = (($24|0) / -2)&-1;
     $26 = (($10) + ($25<<2)|0);
     $27 = (($17) - ($21))|0;
     $28 = $27 >> 2;
     $29 = ($28|0)==(0);
     if ($29) {
      $32 = $10;
     } else {
      _memmove(($26|0),($10|0),($27|0))|0;
      $$pre47$i = HEAP32[$7>>2]|0;
      $32 = $$pre47$i;
     }
     $30 = (($26) + ($28<<2)|0);
     HEAP32[$11>>2] = $30;
     $31 = (($32) + ($25<<2)|0);
     HEAP32[$7>>2] = $31;
     $61 = $30;
     break;
    }
    $33 = (($16) - ($20))|0;
    $34 = $33 >> 1;
    $35 = ($34|0)==(0);
    $$sroa$speculated$i = $35 ? 1 : $34;
    $36 = ($$sroa$speculated$i>>>0)>(1073741823);
    if ($36) {
     $37 = (___cxa_allocate_exception(8)|0);
     __THREW__ = 0;
     invoke_vii(3366,($37|0),(204840|0));
     $38 = __THREW__; __THREW__ = 0;
     $39 = $38&1;
     if ($39) {
      $40 = ___cxa_find_matching_catch_2()|0;
      $41 = tempRet0;
      ___cxa_free_exception(($37|0));
      ___resumeException($40|0);
      // unreachable;
     } else {
      HEAP32[$37>>2] = (99824);
      ___cxa_throw(($37|0),(34608|0),(3230|0));
      // unreachable;
     }
    }
    $42 = $$sroa$speculated$i >>> 2;
    $43 = $$sroa$speculated$i << 2;
    $44 = (__Znwj($43)|0);
    $45 = $44;
    $46 = (($44) + ($42<<2)|0);
    $47 = $46;
    $48 = (($44) + ($$sroa$speculated$i<<2)|0);
    $49 = $48;
    $50 = ($10|0)==($12|0);
    if ($50) {
     $$sroa$13$1$i = $47;$58 = $18;
    } else {
     $$in$i = $46;$$sroa$13$0$i = $47;$52 = $10;
     while(1) {
      $51 = HEAP32[$52>>2]|0;
      HEAP32[$$in$i>>2] = $51;
      $53 = $$sroa$13$0$i;
      $54 = ((($53)) + 4|0);
      $55 = $54;
      $56 = ((($52)) + 4|0);
      $57 = ($56|0)==($12|0);
      if ($57) {
       break;
      } else {
       $$in$i = $54;$$sroa$13$0$i = $55;$52 = $56;
      }
     }
     $$pre$i = HEAP32[$0>>2]|0;
     $$sroa$13$1$i = $55;$58 = $$pre$i;
    }
    HEAP32[$0>>2] = $45;
    HEAP32[$7>>2] = $47;
    HEAP32[$11>>2] = $$sroa$13$1$i;
    HEAP32[$13>>2] = $49;
    $59 = ($58|0)==(0|0);
    $60 = $$sroa$13$1$i;
    if ($59) {
     $61 = $60;
    } else {
     __ZdlPv($58);
     $$pre48$i = HEAP32[$11>>2]|0;
     $61 = $$pre48$i;
    }
   } else {
    $61 = $12;
   }
  } while(0);
  HEAP32[$61>>2] = $9;
  $62 = HEAP32[$11>>2]|0;
  $63 = ((($62)) + 4|0);
  HEAP32[$11>>2] = $63;
  STACKTOP = sp;return;
 }
 $64 = ((($0)) + 8|0);
 $65 = HEAP32[$64>>2]|0;
 $66 = ((($0)) + 4|0);
 $67 = HEAP32[$66>>2]|0;
 $68 = (($65) - ($67))|0;
 $69 = ((($0)) + 12|0);
 $70 = HEAP32[$69>>2]|0;
 $71 = HEAP32[$0>>2]|0;
 $72 = (($70) - ($71))|0;
 $73 = ($68>>>0)<($72>>>0);
 $74 = $65;
 $75 = $70;
 $76 = $67;
 $77 = $71;
 if ($73) {
  $78 = ($70|0)==($65|0);
  if ($78) {
   $125 = (__Znwj(4092)|0);
   HEAP32[$1>>2] = $125;
   __ZNSt3__214__split_bufferIPNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS4_IS7_EEE10push_frontERKS7_($0,$1);
   $126 = HEAP32[$66>>2]|0;
   $127 = HEAP32[$126>>2]|0;
   $128 = ((($126)) + 4|0);
   HEAP32[$66>>2] = $128;
   $129 = HEAP32[$64>>2]|0;
   $130 = HEAP32[$69>>2]|0;
   $131 = ($129|0)==($130|0);
   $132 = $130;
   $133 = $129;
   do {
    if ($131) {
     $134 = HEAP32[$0>>2]|0;
     $135 = ($128>>>0)>($134>>>0);
     $136 = $134;
     if ($135) {
      $137 = $128;
      $138 = (($137) - ($136))|0;
      $139 = $138 >> 2;
      $140 = (($139) + 1)|0;
      $141 = (($140|0) / -2)&-1;
      $142 = (($128) + ($141<<2)|0);
      $143 = (($133) - ($137))|0;
      $144 = $143 >> 2;
      $145 = ($144|0)==(0);
      if ($145) {
       $148 = $128;
      } else {
       _memmove(($142|0),($128|0),($143|0))|0;
       $$pre47$i35 = HEAP32[$66>>2]|0;
       $148 = $$pre47$i35;
      }
      $146 = (($142) + ($144<<2)|0);
      HEAP32[$64>>2] = $146;
      $147 = (($148) + ($141<<2)|0);
      HEAP32[$66>>2] = $147;
      $177 = $146;
      break;
     }
     $149 = (($132) - ($136))|0;
     $150 = $149 >> 1;
     $151 = ($150|0)==(0);
     $$sroa$speculated$i37 = $151 ? 1 : $150;
     $152 = ($$sroa$speculated$i37>>>0)>(1073741823);
     if ($152) {
      $153 = (___cxa_allocate_exception(8)|0);
      __THREW__ = 0;
      invoke_vii(3366,($153|0),(204840|0));
      $154 = __THREW__; __THREW__ = 0;
      $155 = $154&1;
      if ($155) {
       $156 = ___cxa_find_matching_catch_2()|0;
       $157 = tempRet0;
       ___cxa_free_exception(($153|0));
       ___resumeException($156|0);
       // unreachable;
      } else {
       HEAP32[$153>>2] = (99824);
       ___cxa_throw(($153|0),(34608|0),(3230|0));
       // unreachable;
      }
     }
     $158 = $$sroa$speculated$i37 >>> 2;
     $159 = $$sroa$speculated$i37 << 2;
     $160 = (__Znwj($159)|0);
     $161 = $160;
     $162 = (($160) + ($158<<2)|0);
     $163 = $162;
     $164 = (($160) + ($$sroa$speculated$i37<<2)|0);
     $165 = $164;
     $166 = ($128|0)==($129|0);
     if ($166) {
      $$sroa$13$1$i44 = $163;$174 = $134;
     } else {
      $$in$i40 = $162;$$sroa$13$0$i39 = $163;$168 = $128;
      while(1) {
       $167 = HEAP32[$168>>2]|0;
       HEAP32[$$in$i40>>2] = $167;
       $169 = $$sroa$13$0$i39;
       $170 = ((($169)) + 4|0);
       $171 = $170;
       $172 = ((($168)) + 4|0);
       $173 = ($172|0)==($129|0);
       if ($173) {
        break;
       } else {
        $$in$i40 = $170;$$sroa$13$0$i39 = $171;$168 = $172;
       }
      }
      $$pre$i42 = HEAP32[$0>>2]|0;
      $$sroa$13$1$i44 = $171;$174 = $$pre$i42;
     }
     HEAP32[$0>>2] = $161;
     HEAP32[$66>>2] = $163;
     HEAP32[$64>>2] = $$sroa$13$1$i44;
     HEAP32[$69>>2] = $165;
     $175 = ($174|0)==(0|0);
     $176 = $$sroa$13$1$i44;
     if ($175) {
      $177 = $176;
     } else {
      __ZdlPv($174);
      $$pre48$i47 = HEAP32[$64>>2]|0;
      $177 = $$pre48$i47;
     }
    } else {
     $177 = $129;
    }
   } while(0);
   HEAP32[$177>>2] = $127;
   $178 = HEAP32[$64>>2]|0;
   $179 = ((($178)) + 4|0);
   HEAP32[$64>>2] = $179;
   STACKTOP = sp;return;
  } else {
   $79 = (__Znwj(4092)|0);
   $80 = $79;
   $81 = ($74|0)==($75|0);
   $82 = $65;
   do {
    if ($81) {
     $83 = ($76>>>0)>($77>>>0);
     if ($83) {
      $84 = (($67) - ($71))|0;
      $85 = $84 >> 2;
      $86 = (($85) + 1)|0;
      $87 = (($86|0) / -2)&-1;
      $88 = (($76) + ($87<<2)|0);
      $89 = $68 >> 2;
      $90 = ($89|0)==(0);
      if ($90) {
       $94 = $76;
      } else {
       $91 = $67;
       _memmove(($88|0),($91|0),($68|0))|0;
       $$pre47$i21 = HEAP32[$66>>2]|0;
       $94 = $$pre47$i21;
      }
      $92 = (($88) + ($89<<2)|0);
      HEAP32[$64>>2] = $92;
      $93 = (($94) + ($87<<2)|0);
      HEAP32[$66>>2] = $93;
      $122 = $92;
      break;
     }
     $95 = $72 >> 1;
     $96 = ($95|0)==(0);
     $$sroa$speculated$i23 = $96 ? 1 : $95;
     $97 = ($$sroa$speculated$i23>>>0)>(1073741823);
     if ($97) {
      $98 = (___cxa_allocate_exception(8)|0);
      __THREW__ = 0;
      invoke_vii(3366,($98|0),(204840|0));
      $99 = __THREW__; __THREW__ = 0;
      $100 = $99&1;
      if ($100) {
       $101 = ___cxa_find_matching_catch_2()|0;
       $102 = tempRet0;
       ___cxa_free_exception(($98|0));
       ___resumeException($101|0);
       // unreachable;
      } else {
       HEAP32[$98>>2] = (99824);
       ___cxa_throw(($98|0),(34608|0),(3230|0));
       // unreachable;
      }
     }
     $103 = $$sroa$speculated$i23 >>> 2;
     $104 = $$sroa$speculated$i23 << 2;
     $105 = (__Znwj($104)|0);
     $106 = $105;
     $107 = (($105) + ($103<<2)|0);
     $108 = $107;
     $109 = (($105) + ($$sroa$speculated$i23<<2)|0);
     $110 = $109;
     $111 = ($76|0)==($74|0);
     if ($111) {
      $$sroa$13$1$i30 = $108;$119 = $77;
     } else {
      $$in$i26 = $107;$$sroa$13$0$i25 = $108;$113 = $76;
      while(1) {
       $112 = HEAP32[$113>>2]|0;
       HEAP32[$$in$i26>>2] = $112;
       $114 = $$sroa$13$0$i25;
       $115 = ((($114)) + 4|0);
       $116 = $115;
       $117 = ((($113)) + 4|0);
       $118 = ($117|0)==($74|0);
       if ($118) {
        break;
       } else {
        $$in$i26 = $115;$$sroa$13$0$i25 = $116;$113 = $117;
       }
      }
      $$pre$i28 = HEAP32[$0>>2]|0;
      $$sroa$13$1$i30 = $116;$119 = $$pre$i28;
     }
     HEAP32[$0>>2] = $106;
     HEAP32[$66>>2] = $108;
     HEAP32[$64>>2] = $$sroa$13$1$i30;
     HEAP32[$69>>2] = $110;
     $120 = ($119|0)==(0|0);
     $121 = $$sroa$13$1$i30;
     if ($120) {
      $122 = $121;
     } else {
      __ZdlPv($119);
      $$pre48$i33 = HEAP32[$64>>2]|0;
      $122 = $$pre48$i33;
     }
    } else {
     $122 = $82;
    }
   } while(0);
   HEAP32[$122>>2] = $80;
   $123 = HEAP32[$64>>2]|0;
   $124 = ((($123)) + 4|0);
   HEAP32[$64>>2] = $124;
   STACKTOP = sp;return;
  }
 } else {
  $180 = $72 >> 1;
  $181 = ($180|0)==(0);
  $$sroa$speculated = $181 ? 1 : $180;
  $182 = ((($0)) + 12|0);
  $183 = ((($2)) + 12|0);
  HEAP32[$183>>2] = 0;
  $184 = ((($2)) + 16|0);
  HEAP32[$184>>2] = $182;
  $185 = ($$sroa$speculated>>>0)>(1073741823);
  if ($185) {
   $186 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($186|0),(204840|0));
   $187 = __THREW__; __THREW__ = 0;
   $188 = $187&1;
   if ($188) {
    $189 = ___cxa_find_matching_catch_2()|0;
    $190 = tempRet0;
    ___cxa_free_exception(($186|0));
    ___resumeException($189|0);
    // unreachable;
   } else {
    HEAP32[$186>>2] = (99824);
    ___cxa_throw(($186|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
  $191 = $68 >> 2;
  $192 = $$sroa$speculated << 2;
  $193 = (__Znwj($192)|0);
  HEAP32[$2>>2] = $193;
  $194 = (($193) + ($191<<2)|0);
  $195 = ((($2)) + 8|0);
  HEAP32[$195>>2] = $194;
  $196 = ((($2)) + 4|0);
  HEAP32[$196>>2] = $194;
  $197 = (($193) + ($$sroa$speculated<<2)|0);
  $198 = ((($2)) + 12|0);
  HEAP32[$198>>2] = $197;
  $199 = $193;
  __THREW__ = 0;
  $200 = (invoke_ii(3276,4092)|0);
  $201 = __THREW__; __THREW__ = 0;
  $202 = $201&1;
  L82: do {
   if ($202) {
    $238 = ___cxa_find_matching_catch_2()|0;
    $239 = tempRet0;
    $$1 = $239;$$115 = $238;
   } else {
    $203 = $200;
    $204 = ($191|0)==($$sroa$speculated|0);
    $205 = $197;
    $206 = $194;
    L85: do {
     if ($204) {
      $207 = ($194>>>0)>($193>>>0);
      if ($207) {
       $208 = (($206) - ($199))|0;
       $209 = $208 >> 2;
       $210 = (($209) + 1)|0;
       $211 = (($210|0) / -2)&-1;
       $212 = (($194) + ($211<<2)|0);
       HEAP32[$195>>2] = $212;
       HEAP32[$196>>2] = $212;
       $$in = $212;
       break;
      }
      $213 = (($205) - ($199))|0;
      $214 = $213 >> 1;
      $215 = ($214|0)==(0);
      $$sroa$speculated$i51 = $215 ? 1 : $214;
      $216 = ($$sroa$speculated$i51>>>0)>(1073741823);
      do {
       if ($216) {
        $217 = (___cxa_allocate_exception(8)|0);
        __THREW__ = 0;
        invoke_vii(3366,($217|0),(204840|0));
        $218 = __THREW__; __THREW__ = 0;
        $219 = $218&1;
        if ($219) {
         $221 = ___cxa_find_matching_catch_2()|0;
         $222 = tempRet0;
         ___cxa_free_exception(($217|0));
         $$sink97$ph$index = $221;$$sink97$ph$index2 = $222;
         break;
        } else {
         HEAP32[$217>>2] = (99824);
         __THREW__ = 0;
         invoke_viii(3695,($217|0),(34608|0),(3230|0));
         $220 = __THREW__; __THREW__ = 0;
         label = 66;
         break;
        }
       } else {
        $223 = $$sroa$speculated$i51 << 2;
        __THREW__ = 0;
        $224 = (invoke_ii(3276,($223|0))|0);
        $225 = __THREW__; __THREW__ = 0;
        $226 = $225&1;
        if ($226) {
         label = 66;
        } else {
         $227 = $$sroa$speculated$i51 >>> 2;
         $228 = $224;
         $229 = (($224) + ($227<<2)|0);
         $230 = $229;
         $231 = (($224) + ($$sroa$speculated$i51<<2)|0);
         $232 = $231;
         HEAP32[$2>>2] = $228;
         HEAP32[$196>>2] = $230;
         HEAP32[$195>>2] = $230;
         HEAP32[$198>>2] = $232;
         __ZdlPv($193);
         $$in = $229;
         break L85;
        }
       }
      } while(0);
      if ((label|0) == 66) {
       $240 = ___cxa_find_matching_catch_2()|0;
       $241 = tempRet0;
       $$sink97$ph$index = $240;$$sink97$ph$index2 = $241;
      }
      __ZdlPv($200);
      $$1 = $$sink97$ph$index2;$$115 = $$sink97$ph$index;
      break L82;
     } else {
      $$in = $194;
     }
    } while(0);
    HEAP32[$$in>>2] = $203;
    $233 = HEAP32[$195>>2]|0;
    $234 = ((($233)) + 4|0);
    HEAP32[$195>>2] = $234;
    $235 = HEAP32[$64>>2]|0;
    $$0 = $235;
    while(1) {
     $236 = HEAP32[$66>>2]|0;
     $237 = ($$0|0)==($236|0);
     if ($237) {
      break;
     }
     $242 = ((($$0)) + -4|0);
     __THREW__ = 0;
     invoke_vii(4172,($2|0),($242|0));
     $243 = __THREW__; __THREW__ = 0;
     $244 = $243&1;
     if ($244) {
      label = 73;
      break;
     } else {
      $$0 = $242;
     }
    }
    if ((label|0) == 73) {
     $261 = ___cxa_find_matching_catch_2()|0;
     $262 = tempRet0;
     $$1 = $262;$$115 = $261;
     break;
    }
    $245 = $236;
    $246 = HEAP32[$0>>2]|0;
    $247 = HEAP32[$2>>2]|0;
    HEAP32[$0>>2] = $247;
    HEAP32[$2>>2] = $246;
    $248 = HEAP32[$196>>2]|0;
    HEAP32[$66>>2] = $248;
    HEAP32[$196>>2] = $245;
    $249 = HEAP32[$64>>2]|0;
    $250 = HEAP32[$195>>2]|0;
    HEAP32[$64>>2] = $250;
    HEAP32[$195>>2] = $249;
    $251 = HEAP32[$69>>2]|0;
    $252 = HEAP32[$198>>2]|0;
    HEAP32[$69>>2] = $252;
    HEAP32[$198>>2] = $251;
    $253 = $249;
    $254 = ($253|0)==($$0|0);
    if (!($254)) {
     $scevgep$i$i$i$i16 = ((($253)) + -4|0);
     $255 = $scevgep$i$i$i$i16;
     $256 = (($255) - ($245))|0;
     $257 = $256 >>> 2;
     $258 = $257 ^ -1;
     $scevgep5$i$i$i$i17 = (($253) + ($258<<2)|0);
     HEAP32[$195>>2] = $scevgep5$i$i$i$i17;
    }
    $259 = ($246|0)==(0);
    if (!($259)) {
     $260 = $246;
     __ZdlPv($260);
    }
    STACKTOP = sp;return;
   }
  } while(0);
  $263 = HEAP32[$196>>2]|0;
  $264 = HEAP32[$195>>2]|0;
  $265 = ($264|0)==($263|0);
  if (!($265)) {
   $scevgep$i$i$i$i = ((($264)) + -4|0);
   $266 = $scevgep$i$i$i$i;
   $267 = $263;
   $268 = (($266) - ($267))|0;
   $269 = $268 >>> 2;
   $270 = $269 ^ -1;
   $scevgep5$i$i$i$i = (($264) + ($270<<2)|0);
   HEAP32[$195>>2] = $scevgep5$i$i$i$i;
  }
  $271 = HEAP32[$2>>2]|0;
  $272 = ($271|0)==(0|0);
  if ($272) {
   ___resumeException($$115|0);
   // unreachable;
  }
  __ZdlPv($271);
  ___resumeException($$115|0);
  // unreachable;
 }
}
function __ZNSt3__26vectorIN5osgDB12ReaderWriter10ReadResultENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$06$i$i = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$phi11$iZ2D = 0, $$pre8$i = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $2 = sp;
 $3 = ((($0)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$0>>2]|0;
 $6 = (($4) - ($5))|0;
 $7 = (($6|0) / 20)&-1;
 $8 = (($7) + 1)|0;
 $9 = ($8>>>0)>(214748364);
 if ($9) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $10 = ((($0)) + 8|0);
 $11 = ((($0)) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) - ($5))|0;
 $14 = (($13|0) / 20)&-1;
 $15 = ($14>>>0)<(107374182);
 $16 = $14 << 1;
 $17 = ($16>>>0)<($8>>>0);
 $$sroa$speculated$i = $17 ? $8 : $16;
 $$sroa$speculated$$i = $15 ? $$sroa$speculated$i : 214748364;
 $18 = ((($2)) + 12|0);
 HEAP32[$18>>2] = 0;
 $19 = ((($2)) + 16|0);
 HEAP32[$19>>2] = $10;
 $20 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($20) {
   $29 = 0;
  } else {
   $21 = ($$sroa$speculated$$i>>>0)>(214748364);
   if (!($21)) {
    $27 = ($$sroa$speculated$$i*20)|0;
    $28 = (__Znwj($27)|0);
    $29 = $28;
    break;
   }
   $22 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($22|0),(204840|0));
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if ($24) {
    $25 = ___cxa_find_matching_catch_2()|0;
    $26 = tempRet0;
    ___cxa_free_exception(($22|0));
    ___resumeException($25|0);
    // unreachable;
   } else {
    HEAP32[$22>>2] = (99824);
    ___cxa_throw(($22|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 HEAP32[$2>>2] = $29;
 $30 = (($29) + (($7*20)|0)|0);
 $31 = ((($2)) + 8|0);
 HEAP32[$31>>2] = $30;
 $32 = ((($2)) + 4|0);
 HEAP32[$32>>2] = $30;
 $33 = (($29) + (($$sroa$speculated$$i*20)|0)|0);
 $34 = ((($2)) + 12|0);
 HEAP32[$34>>2] = $33;
 $35 = HEAP32[$1>>2]|0;
 HEAP32[$30>>2] = $35;
 $36 = (((($29) + (($7*20)|0)|0)) + 4|0);
 $37 = ((($1)) + 4|0);
 __THREW__ = 0;
 invoke_vii(3457,($36|0),($37|0));
 $38 = __THREW__; __THREW__ = 0;
 $39 = $38&1;
 L13: do {
  if (!($39)) {
   $40 = (((($29) + (($7*20)|0)|0)) + 16|0);
   $41 = ((($1)) + 16|0);
   $42 = HEAP32[$41>>2]|0;
   HEAP32[$40>>2] = $42;
   $43 = ($42|0)==(0|0);
   if (!($43)) {
    $44 = ((($42)) + 8|0);
    $45 = HEAP32[$44>>2]|0;HEAP32[$44>>2] = (($45+1)|0);
   }
   $46 = HEAP32[$31>>2]|0;
   $47 = ((($46)) + 20|0);
   HEAP32[$31>>2] = $47;
   $48 = HEAP32[$0>>2]|0;
   $49 = HEAP32[$3>>2]|0;
   $50 = ($49|0)==($48|0);
   if ($50) {
    $51 = $49;
    $52 = $48;
    $$pre8$i = HEAP32[$32>>2]|0;
    $$pre$phi11$iZ2D = $32;$71 = $$pre8$i;$72 = $52;$74 = $51;
    HEAP32[$0>>2] = $71;
    HEAP32[$$pre$phi11$iZ2D>>2] = $72;
    $73 = HEAP32[$31>>2]|0;
    HEAP32[$3>>2] = $73;
    HEAP32[$31>>2] = $74;
    $75 = HEAP32[$11>>2]|0;
    $76 = HEAP32[$34>>2]|0;
    HEAP32[$11>>2] = $76;
    HEAP32[$34>>2] = $75;
    $77 = HEAP32[$$pre$phi11$iZ2D>>2]|0;
    HEAP32[$2>>2] = $77;
    __ZNSt3__214__split_bufferIN5osgDB12ReaderWriter10ReadResultERNS_9allocatorIS3_EEED2Ev($2);
    STACKTOP = sp;return;
   }
   $$pre$i$i = HEAP32[$32>>2]|0;
   $$06$i$i = $49;$55 = $$pre$i$i;
   while(1) {
    $53 = ((($$06$i$i)) + -20|0);
    $54 = ((($55)) + -20|0);
    $56 = HEAP32[$53>>2]|0;
    HEAP32[$54>>2] = $56;
    $57 = ((($55)) + -16|0);
    $58 = ((($$06$i$i)) + -16|0);
    __THREW__ = 0;
    invoke_vii(3457,($57|0),($58|0));
    $59 = __THREW__; __THREW__ = 0;
    $60 = $59&1;
    if ($60) {
     break L13;
    }
    $61 = ((($55)) + -4|0);
    $62 = ((($$06$i$i)) + -4|0);
    $63 = HEAP32[$62>>2]|0;
    HEAP32[$61>>2] = $63;
    $64 = ($63|0)==(0|0);
    if (!($64)) {
     $65 = ((($63)) + 8|0);
     $66 = HEAP32[$65>>2]|0;HEAP32[$65>>2] = (($66+1)|0);
    }
    $67 = HEAP32[$32>>2]|0;
    $68 = ((($67)) + -20|0);
    HEAP32[$32>>2] = $68;
    $69 = ($53|0)==($48|0);
    if ($69) {
     break;
    } else {
     $$06$i$i = $53;$55 = $68;
    }
   }
   $70 = $68;
   $$pre$i = HEAP32[$0>>2]|0;
   $$pre = HEAP32[$3>>2]|0;
   $$pre$phi11$iZ2D = $32;$71 = $70;$72 = $$pre$i;$74 = $$pre;
   HEAP32[$0>>2] = $71;
   HEAP32[$$pre$phi11$iZ2D>>2] = $72;
   $73 = HEAP32[$31>>2]|0;
   HEAP32[$3>>2] = $73;
   HEAP32[$31>>2] = $74;
   $75 = HEAP32[$11>>2]|0;
   $76 = HEAP32[$34>>2]|0;
   HEAP32[$11>>2] = $76;
   HEAP32[$34>>2] = $75;
   $77 = HEAP32[$$pre$phi11$iZ2D>>2]|0;
   HEAP32[$2>>2] = $77;
   __ZNSt3__214__split_bufferIN5osgDB12ReaderWriter10ReadResultERNS_9allocatorIS3_EEED2Ev($2);
   STACKTOP = sp;return;
  }
 } while(0);
 $78 = ___cxa_find_matching_catch_2()|0;
 $79 = tempRet0;
 __THREW__ = 0;
 invoke_vi(4214,($2|0));
 $80 = __THREW__; __THREW__ = 0;
 $81 = $80&1;
 if ($81) {
  $82 = ___cxa_find_matching_catch_3(0|0)|0;
  $83 = tempRet0;
  ___clang_call_terminate($82);
  // unreachable;
 } else {
  ___resumeException($78|0);
  // unreachable;
 }
}
function __ZN5osgDB8Registry29AvailableReaderWriterIteratorppEv($0) {
 $0 = $0|0;
 var $$0$i = 0, $$0$i$i$i$i = 0, $$0$ph$i$i$i$i = 0, $$0$ph$lcssa$i$i$i$i = 0, $$0$ph13$i$i$i$i = 0, $$024$i$i$i$i = 0, $$025$i$i$i$i = 0, $$036$i$i$i = 0, $$07$ph12$i$i$i$i = 0, $$0710$i$i$i$i = 0, $$in$i$i$i$i = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i$i$i = 0, $$sroa$011$025$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 8|0);
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($4)) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 (FUNCTION_TABLE_ii[$6 & 8191]($3)|0);
 $7 = HEAP32[$0>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($7)) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8|0)==($10|0);
 $$pre = ((($0)) + 12|0);
 L1: do {
  if ($11) {
   $$0$i = 0;
  } else {
   $12 = HEAP32[$$pre>>2]|0;
   $13 = ($12|0)==(0|0);
   if ($13) {
    $$pre$i = HEAP32[$8>>2]|0;
    $$0$i = $$pre$i;
    break;
   } else {
    $$sroa$011$025$i = $8;
   }
   while(1) {
    $16 = HEAP32[$$sroa$011$025$i>>2]|0;
    $$0$ph13$i$i$i$i = $$pre;$$07$ph12$i$i$i$i = $12;
    L7: while(1) {
     $$0710$i$i$i$i = $$07$ph12$i$i$i$i;
     while(1) {
      $17 = ((($$0710$i$i$i$i)) + 16|0);
      $18 = HEAP32[$17>>2]|0;
      $19 = ($18>>>0)<($16>>>0);
      if (!($19)) {
       break;
      }
      $22 = ((($$0710$i$i$i$i)) + 4|0);
      $23 = HEAP32[$22>>2]|0;
      $24 = ($23|0)==(0|0);
      if ($24) {
       $$0$ph$lcssa$i$i$i$i = $$0$ph13$i$i$i$i;
       break L7;
      } else {
       $$0710$i$i$i$i = $23;
      }
     }
     $20 = HEAP32[$$0710$i$i$i$i>>2]|0;
     $21 = ($20|0)==(0|0);
     if ($21) {
      $$0$ph$lcssa$i$i$i$i = $$0710$i$i$i$i;
      break;
     } else {
      $$0$ph13$i$i$i$i = $$0710$i$i$i$i;$$07$ph12$i$i$i$i = $20;
     }
    }
    $25 = ($$0$ph$lcssa$i$i$i$i|0)==($$pre|0);
    if ($25) {
     $$0$i = $16;
     break L1;
    }
    $26 = ((($$0$ph$lcssa$i$i$i$i)) + 16|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = ($16>>>0)<($27>>>0);
    $14 = ((($$sroa$011$025$i)) + 4|0);
    if ($28) {
     $$0$i = $16;
     break L1;
    }
    $15 = ($14|0)==($10|0);
    if ($15) {
     $$0$i = 0;
     break;
    } else {
     $$sroa$011$025$i = $14;
    }
   }
  }
 } while(0);
 $29 = HEAP32[$3>>2]|0;
 $30 = ((($29)) + 12|0);
 $31 = HEAP32[$30>>2]|0;
 (FUNCTION_TABLE_ii[$31 & 8191]($3)|0);
 $32 = $$0$i;
 $33 = HEAP32[$$pre>>2]|0;
 $34 = ($33|0)==(0|0);
 $35 = ((($0)) + 12|0);
 do {
  if ($34) {
   $$025$i$i$i$i = $35;$$036$i$i$i = $$pre;
  } else {
   $$0$i$i$i$i = $35;$$024$i$i$i$i = $33;
   while(1) {
    $36 = ((($$024$i$i$i$i)) + 16|0);
    $37 = HEAP32[$36>>2]|0;
    $38 = ($$0$i>>>0)<($37>>>0);
    if ($38) {
     $39 = HEAP32[$$024$i$i$i$i>>2]|0;
     $40 = ($39|0)==(0|0);
     if ($40) {
      label = 16;
      break;
     } else {
      $$0$ph$i$i$i$i = $$024$i$i$i$i;$$in$i$i$i$i = $39;
     }
    } else {
     $41 = ($37>>>0)<($$0$i>>>0);
     if (!($41)) {
      label = 20;
      break;
     }
     $42 = ((($$024$i$i$i$i)) + 4|0);
     $43 = HEAP32[$42>>2]|0;
     $44 = ($43|0)==(0|0);
     if ($44) {
      label = 19;
      break;
     } else {
      $$0$ph$i$i$i$i = $42;$$in$i$i$i$i = $43;
     }
    }
    $$0$i$i$i$i = $$0$ph$i$i$i$i;$$024$i$i$i$i = $$in$i$i$i$i;
   }
   if ((label|0) == 16) {
    $$025$i$i$i$i = $$024$i$i$i$i;$$036$i$i$i = $$024$i$i$i$i;
    break;
   }
   else if ((label|0) == 19) {
    $$025$i$i$i$i = $42;$$036$i$i$i = $$024$i$i$i$i;
    break;
   }
   else if ((label|0) == 20) {
    $$025$i$i$i$i = $$0$i$i$i$i;$$036$i$i$i = $$024$i$i$i$i;
    break;
   }
  }
 } while(0);
 $45 = HEAP32[$$025$i$i$i$i>>2]|0;
 $46 = ($45|0)==(0|0);
 if (!($46)) {
  return;
 }
 $47 = (__Znwj(20)|0);
 $48 = ((($47)) + 16|0);
 HEAP32[$48>>2] = $32;
 HEAP32[$47>>2] = 0;
 $49 = ((($47)) + 4|0);
 HEAP32[$49>>2] = 0;
 $50 = ((($47)) + 8|0);
 HEAP32[$50>>2] = $$036$i$i$i;
 HEAP32[$$025$i$i$i$i>>2] = $47;
 $51 = HEAP32[$1>>2]|0;
 $52 = HEAP32[$51>>2]|0;
 $53 = ($52|0)==(0|0);
 if ($53) {
  $57 = $47;
 } else {
  $54 = $52;
  HEAP32[$1>>2] = $54;
  $$pre$i$i$i$i = HEAP32[$$025$i$i$i$i>>2]|0;
  $57 = $$pre$i$i$i$i;
 }
 $55 = ((($0)) + 12|0);
 $56 = HEAP32[$55>>2]|0;
 __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($56,$57);
 $58 = ((($0)) + 16|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = (($59) + 1)|0;
 HEAP32[$58>>2] = $60;
 return;
}
function __ZN5osgDB8Registry24AvailableArchiveIteratorppEv($0) {
 $0 = $0|0;
 var $$0$i$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$ph$i$i$i$i = 0, $$0$ph$lcssa$i$i$i$i = 0, $$0$ph13$i$i$i$i = 0, $$024$i$i$i$i = 0, $$025$i$i$i$i = 0, $$036$i$i$i = 0, $$04$i = 0, $$07$ph12$i$i$i$i = 0, $$0710$i$i$i$i = 0, $$in$i$i$i$i = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i$i$i = 0, $$sroa$015$0$be$i = 0, $$sroa$015$030$i = 0, $1 = 0, $10 = 0, $11 = 0;
 var $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 8|0);
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($4)) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 (FUNCTION_TABLE_ii[$6 & 8191]($3)|0);
 $7 = HEAP32[$0>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($7)) + 4|0);
 $10 = ($8|0)==($9|0);
 $$pre = ((($0)) + 12|0);
 L1: do {
  if ($10) {
   $$04$i = 0;
  } else {
   $11 = HEAP32[$$pre>>2]|0;
   $12 = ($11|0)==(0|0);
   if ($12) {
    $13 = ((($8)) + 28|0);
    $$pre$i = HEAP32[$13>>2]|0;
    $$04$i = $$pre$i;
    break;
   } else {
    $$sroa$015$030$i = $8;
   }
   while(1) {
    $14 = ((($$sroa$015$030$i)) + 28|0);
    $15 = HEAP32[$14>>2]|0;
    $$0$ph13$i$i$i$i = $$pre;$$07$ph12$i$i$i$i = $11;
    L7: while(1) {
     $$0710$i$i$i$i = $$07$ph12$i$i$i$i;
     while(1) {
      $16 = ((($$0710$i$i$i$i)) + 16|0);
      $17 = HEAP32[$16>>2]|0;
      $18 = ($17>>>0)<($15>>>0);
      if (!($18)) {
       break;
      }
      $21 = ((($$0710$i$i$i$i)) + 4|0);
      $22 = HEAP32[$21>>2]|0;
      $23 = ($22|0)==(0|0);
      if ($23) {
       $$0$ph$lcssa$i$i$i$i = $$0$ph13$i$i$i$i;
       break L7;
      } else {
       $$0710$i$i$i$i = $22;
      }
     }
     $19 = HEAP32[$$0710$i$i$i$i>>2]|0;
     $20 = ($19|0)==(0|0);
     if ($20) {
      $$0$ph$lcssa$i$i$i$i = $$0710$i$i$i$i;
      break;
     } else {
      $$0$ph13$i$i$i$i = $$0710$i$i$i$i;$$07$ph12$i$i$i$i = $19;
     }
    }
    $24 = ($$0$ph$lcssa$i$i$i$i|0)==($$pre|0);
    if ($24) {
     $$04$i = $15;
     break L1;
    }
    $25 = ((($$0$ph$lcssa$i$i$i$i)) + 16|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = ($15>>>0)<($26>>>0);
    if ($27) {
     $$04$i = $15;
     break L1;
    }
    $28 = ((($$sroa$015$030$i)) + 4|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = ($29|0)==(0|0);
    if ($30) {
     $31 = ((($$sroa$015$030$i)) + 8|0);
     $32 = HEAP32[$31>>2]|0;
     $33 = HEAP32[$32>>2]|0;
     $34 = ($33|0)==($$sroa$015$030$i|0);
     if ($34) {
      $$sroa$015$0$be$i = $32;
     } else {
      $39 = $31;
      while(1) {
       $38 = HEAP32[$39>>2]|0;
       $40 = ((($38)) + 8|0);
       $41 = HEAP32[$40>>2]|0;
       $42 = HEAP32[$41>>2]|0;
       $43 = ($42|0)==($38|0);
       if ($43) {
        $$sroa$015$0$be$i = $41;
        break;
       } else {
        $39 = $40;
       }
      }
     }
    } else {
     $$0$i$i$i$i$i = $29;
     while(1) {
      $36 = HEAP32[$$0$i$i$i$i$i>>2]|0;
      $37 = ($36|0)==(0|0);
      if ($37) {
       break;
      } else {
       $$0$i$i$i$i$i = $36;
      }
     }
     $$sroa$015$0$be$i = $$0$i$i$i$i$i;
    }
    $35 = ($$sroa$015$0$be$i|0)==($9|0);
    if ($35) {
     $$04$i = 0;
     break;
    } else {
     $$sroa$015$030$i = $$sroa$015$0$be$i;
    }
   }
  }
 } while(0);
 $44 = HEAP32[$3>>2]|0;
 $45 = ((($44)) + 12|0);
 $46 = HEAP32[$45>>2]|0;
 (FUNCTION_TABLE_ii[$46 & 8191]($3)|0);
 $47 = $$04$i;
 $48 = HEAP32[$$pre>>2]|0;
 $49 = ($48|0)==(0|0);
 $50 = ((($0)) + 12|0);
 do {
  if ($49) {
   $$025$i$i$i$i = $50;$$036$i$i$i = $$pre;
  } else {
   $$0$i$i$i$i = $50;$$024$i$i$i$i = $48;
   while(1) {
    $51 = ((($$024$i$i$i$i)) + 16|0);
    $52 = HEAP32[$51>>2]|0;
    $53 = ($$04$i>>>0)<($52>>>0);
    if ($53) {
     $54 = HEAP32[$$024$i$i$i$i>>2]|0;
     $55 = ($54|0)==(0|0);
     if ($55) {
      label = 21;
      break;
     } else {
      $$0$ph$i$i$i$i = $$024$i$i$i$i;$$in$i$i$i$i = $54;
     }
    } else {
     $56 = ($52>>>0)<($$04$i>>>0);
     if (!($56)) {
      label = 25;
      break;
     }
     $57 = ((($$024$i$i$i$i)) + 4|0);
     $58 = HEAP32[$57>>2]|0;
     $59 = ($58|0)==(0|0);
     if ($59) {
      label = 24;
      break;
     } else {
      $$0$ph$i$i$i$i = $57;$$in$i$i$i$i = $58;
     }
    }
    $$0$i$i$i$i = $$0$ph$i$i$i$i;$$024$i$i$i$i = $$in$i$i$i$i;
   }
   if ((label|0) == 21) {
    $$025$i$i$i$i = $$024$i$i$i$i;$$036$i$i$i = $$024$i$i$i$i;
    break;
   }
   else if ((label|0) == 24) {
    $$025$i$i$i$i = $57;$$036$i$i$i = $$024$i$i$i$i;
    break;
   }
   else if ((label|0) == 25) {
    $$025$i$i$i$i = $$0$i$i$i$i;$$036$i$i$i = $$024$i$i$i$i;
    break;
   }
  }
 } while(0);
 $60 = HEAP32[$$025$i$i$i$i>>2]|0;
 $61 = ($60|0)==(0|0);
 if (!($61)) {
  return;
 }
 $62 = (__Znwj(20)|0);
 $63 = ((($62)) + 16|0);
 HEAP32[$63>>2] = $47;
 HEAP32[$62>>2] = 0;
 $64 = ((($62)) + 4|0);
 HEAP32[$64>>2] = 0;
 $65 = ((($62)) + 8|0);
 HEAP32[$65>>2] = $$036$i$i$i;
 HEAP32[$$025$i$i$i$i>>2] = $62;
 $66 = HEAP32[$1>>2]|0;
 $67 = HEAP32[$66>>2]|0;
 $68 = ($67|0)==(0|0);
 if ($68) {
  $72 = $62;
 } else {
  $69 = $67;
  HEAP32[$1>>2] = $69;
  $$pre$i$i$i$i = HEAP32[$$025$i$i$i$i>>2]|0;
  $72 = $$pre$i$i$i$i;
 }
 $70 = ((($0)) + 12|0);
 $71 = HEAP32[$70>>2]|0;
 __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($71,$72);
 $73 = ((($0)) + 16|0);
 $74 = HEAP32[$73>>2]|0;
 $75 = (($74) + 1)|0;
 HEAP32[$73>>2] = $75;
 return;
}
function __ZN5osgDB8Registry38getReaderWriterForProtocolAndExtensionERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEES9_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$02670 = 0, $$127 = 0, $$129 = 0, $$230 = 0, $$3 = 0, $$324 = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i35 = 0, $$pre74 = 0, $$sink69 = 0, $$sroa$04$09$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $3 = sp + 24|0;
 $4 = sp + 12|0;
 $5 = sp;
 $6 = (__ZN5osgDB8Registry27getReaderWriterForExtensionERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE($0,$2)|0);
 $7 = ($6|0)==(0|0);
 if (!($7)) {
  $8 = HEAP32[$6>>2]|0;
  $9 = ((($8)) + 156|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (FUNCTION_TABLE_iii[$10 & 8191]($6,$1)|0);
  if ($11) {
   $$230 = $6;
   STACKTOP = sp;return ($$230|0);
  }
 }
 HEAP32[$3>>2] = 0;
 $12 = ((($3)) + 4|0);
 HEAP32[$12>>2] = 0;
 $13 = ((($3)) + 8|0);
 HEAP32[$13>>2] = 0;
 $14 = ((($0)) + 72|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ((($0)) + 76|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($15|0)==($17|0);
 do {
  if ($18) {
   label = 29;
  } else {
   $19 = ((($3)) + 8|0);
   $$sroa$04$09$i = $15;
   L7: while(1) {
    $20 = HEAP32[$$sroa$04$09$i>>2]|0;
    $21 = HEAP32[$20>>2]|0;
    $22 = ((($21)) + 156|0);
    $23 = HEAP32[$22>>2]|0;
    __THREW__ = 0;
    $24 = (invoke_iii($23|0,($20|0),($1|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if ($26) {
     label = 15;
     break;
    }
    do {
     if ($24) {
      $27 = HEAP32[$12>>2]|0;
      $28 = HEAP32[$19>>2]|0;
      $29 = ($27|0)==($28|0);
      if ($29) {
       __THREW__ = 0;
       invoke_vii(4215,($3|0),($$sroa$04$09$i|0));
       $36 = __THREW__; __THREW__ = 0;
       $37 = $36&1;
       if ($37) {
        label = 15;
        break L7;
       } else {
        break;
       }
      }
      $30 = HEAP32[$$sroa$04$09$i>>2]|0;
      HEAP32[$27>>2] = $30;
      $31 = ($30|0)==(0|0);
      if ($31) {
       $35 = $27;
      } else {
       $32 = ((($30)) + 8|0);
       $33 = HEAP32[$32>>2]|0;HEAP32[$32>>2] = (($33+1)|0);
       $$pre$i$i = HEAP32[$12>>2]|0;
       $35 = $$pre$i$i;
      }
      $34 = ((($35)) + 4|0);
      HEAP32[$12>>2] = $34;
     }
    } while(0);
    $38 = ((($$sroa$04$09$i)) + 4|0);
    $39 = HEAP32[$16>>2]|0;
    $40 = ($38|0)==($39|0);
    if ($40) {
     break;
    } else {
     $$sroa$04$09$i = $38;
    }
   }
   if ((label|0) == 15) {
    $44 = ___cxa_find_matching_catch_2()|0;
    $45 = tempRet0;
    $$3 = $45;$$324 = $44;
    label = 46;
    break;
   }
   $$pre = HEAP32[$3>>2]|0;
   $$pre74 = HEAP32[$12>>2]|0;
   $41 = ($$pre|0)==($$pre74|0);
   if ($41) {
    label = 29;
   } else {
    $42 = ((($4)) + 11|0);
    $43 = ((($4)) + 1|0);
    $$02670 = 0;$$sink69 = $$pre;
    while(1) {
     $46 = HEAP32[$$sink69>>2]|0;
     $47 = HEAP32[$46>>2]|0;
     $48 = ((($47)) + 152|0);
     $49 = HEAP32[$48>>2]|0;
     ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;
     HEAP8[$42>>0] = 1;
     HEAP8[$4>>0] = 42;
     HEAP8[$43>>0] = 0;
     __THREW__ = 0;
     $50 = (invoke_iii($49|0,($46|0),($4|0))|0);
     $51 = __THREW__; __THREW__ = 0;
     $52 = $51&1;
     if ($52) {
      label = 21;
      break;
     }
     $53 = HEAP8[$42>>0]|0;
     $54 = ($53<<24>>24)<(0);
     if ($54) {
      $55 = HEAP32[$4>>2]|0;
      __ZdlPv($55);
     }
     $56 = HEAP32[$$sink69>>2]|0;
     if ($50) {
      $$127 = $56;
     } else {
      $64 = HEAP32[$56>>2]|0;
      $65 = ((($64)) + 152|0);
      $66 = HEAP32[$65>>2]|0;
      __THREW__ = 0;
      $67 = (invoke_iii($66|0,($56|0),($2|0))|0);
      $68 = __THREW__; __THREW__ = 0;
      $69 = $68&1;
      if ($69) {
       label = 20;
       break;
      }
      if ($67) {
       label = 27;
       break;
      } else {
       $$127 = $$02670;
      }
     }
     $70 = ((($$sink69)) + 4|0);
     $71 = HEAP32[$12>>2]|0;
     $72 = ($70|0)==($71|0);
     if ($72) {
      label = 28;
      break;
     } else {
      $$02670 = $$127;$$sink69 = $70;
     }
    }
    if ((label|0) == 20) {
     $57 = ___cxa_find_matching_catch_2()|0;
     $58 = tempRet0;
     $$3 = $58;$$324 = $57;
     label = 46;
     break;
    }
    else if ((label|0) == 21) {
     $59 = ___cxa_find_matching_catch_2()|0;
     $60 = tempRet0;
     $61 = HEAP8[$42>>0]|0;
     $62 = ($61<<24>>24)<(0);
     if ($62) {
      $63 = HEAP32[$4>>2]|0;
      __ZdlPv($63);
     }
     $$3 = $60;$$324 = $59;
     label = 46;
     break;
    }
    else if ((label|0) == 27) {
     $73 = HEAP32[$$sink69>>2]|0;
     $$129 = $73;
     label = 36;
     break;
    }
    else if ((label|0) == 28) {
     $74 = ($$127|0)==(0|0);
     if ($74) {
      label = 29;
      break;
     } else {
      $$129 = $$127;
      label = 36;
      break;
     }
    }
   }
  }
 } while(0);
 do {
  if ((label|0) == 29) {
   ;HEAP32[$5>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;
   $75 = ((($5)) + 11|0);
   HEAP8[$75>>0] = 4;
   HEAP32[$5>>2] = 1819440483;
   $76 = ((($5)) + 4|0);
   HEAP8[$76>>0] = 0;
   __THREW__ = 0;
   $77 = (invoke_iii(4216,($0|0),($5|0))|0);
   $78 = __THREW__; __THREW__ = 0;
   $79 = $78&1;
   if ($79) {
    $83 = ___cxa_find_matching_catch_2()|0;
    $84 = tempRet0;
    $85 = HEAP8[$75>>0]|0;
    $86 = ($85<<24>>24)<(0);
    if ($86) {
     $87 = HEAP32[$5>>2]|0;
     __ZdlPv($87);
    }
    $$3 = $84;$$324 = $83;
    label = 46;
    break;
   } else {
    $80 = HEAP8[$75>>0]|0;
    $81 = ($80<<24>>24)<(0);
    if ($81) {
     $82 = HEAP32[$5>>2]|0;
     __ZdlPv($82);
    }
    $$129 = $77;
    label = 36;
    break;
   }
  }
 } while(0);
 if ((label|0) == 36) {
  $88 = HEAP32[$3>>2]|0;
  $89 = ($88|0)==(0|0);
  if (!($89)) {
   $90 = HEAP32[$12>>2]|0;
   $91 = ($90|0)==($88|0);
   do {
    if ($91) {
     $105 = $88;
    } else {
     $93 = $90;
     while(1) {
      $92 = ((($93)) + -4|0);
      HEAP32[$12>>2] = $92;
      $94 = HEAP32[$92>>2]|0;
      $95 = ($94|0)==(0|0);
      if (!($95)) {
       $96 = ((($94)) + 8|0);
       $97 = HEAP32[$96>>2]|0;HEAP32[$96>>2] = (($97-1)|0);
       $98 = ($97|0)==(1);
       if ($98) {
        __THREW__ = 0;
        invoke_viii(3262,($94|0),1,1);
        $99 = __THREW__; __THREW__ = 0;
        $100 = $99&1;
        if ($100) {
         label = 42;
         break;
        }
       }
      }
      HEAP32[$92>>2] = 0;
      $101 = HEAP32[$12>>2]|0;
      $102 = ($101|0)==($88|0);
      if ($102) {
       label = 43;
       break;
      } else {
       $93 = $101;
      }
     }
     if ((label|0) == 42) {
      $103 = ___cxa_find_matching_catch_2()|0;
      $104 = tempRet0;
      ___cxa_call_unexpected(($103|0));
      // unreachable;
     }
     else if ((label|0) == 43) {
      $$pre$i35 = HEAP32[$3>>2]|0;
      $105 = $$pre$i35;
      break;
     }
    }
   } while(0);
   __ZdlPv($105);
  }
  $$230 = $$129;
  STACKTOP = sp;return ($$230|0);
 }
 else if ((label|0) == 46) {
  $106 = HEAP32[$3>>2]|0;
  $107 = ($106|0)==(0|0);
  if ($107) {
   ___resumeException($$324|0);
   // unreachable;
  }
  $108 = HEAP32[$12>>2]|0;
  $109 = ($108|0)==($106|0);
  do {
   if ($109) {
    $123 = $106;
   } else {
    $111 = $108;
    while(1) {
     $110 = ((($111)) + -4|0);
     HEAP32[$12>>2] = $110;
     $112 = HEAP32[$110>>2]|0;
     $113 = ($112|0)==(0|0);
     if (!($113)) {
      $114 = ((($112)) + 8|0);
      $115 = HEAP32[$114>>2]|0;HEAP32[$114>>2] = (($115-1)|0);
      $116 = ($115|0)==(1);
      if ($116) {
       __THREW__ = 0;
       invoke_viii(3262,($112|0),1,1);
       $117 = __THREW__; __THREW__ = 0;
       $118 = $117&1;
       if ($118) {
        label = 52;
        break;
       }
      }
     }
     HEAP32[$110>>2] = 0;
     $119 = HEAP32[$12>>2]|0;
     $120 = ($119|0)==($106|0);
     if ($120) {
      label = 53;
      break;
     } else {
      $111 = $119;
     }
    }
    if ((label|0) == 52) {
     $121 = ___cxa_find_matching_catch_2()|0;
     $122 = tempRet0;
     ___cxa_call_unexpected(($121|0));
     // unreachable;
    }
    else if ((label|0) == 53) {
     $$pre$i = HEAP32[$3>>2]|0;
     $123 = $$pre$i;
     break;
    }
   }
  } while(0);
  __ZdlPv($123);
  ___resumeException($$324|0);
  // unreachable;
 }
 return (0)|0;
}
function __ZNSt3__26__sortIRNS_6__lessIN5osgDB12ReaderWriter10ReadResultES4_EEPS4_EEvT0_S8_T_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$$0174 = 0, $$0 = 0, $$0$ph = 0, $$0154 = 0, $$0160375 = 0, $$0167 = 0, $$0174 = 0, $$0180$ph = 0, $$1 = 0, $$1155 = 0, $$1161 = 0, $$2156 = 0, $$2162 = 0, $$2176 = 0, $$3157 = 0, $$3163 = 0, $$3170 = 0, $$4158 = 0, $$4164 = 0, $$4171 = 0;
 var $$5159 = 0, $$5165 = 0, $$5172 = 0, $$6166 = 0, $$6173 = 0, $$pr$i = 0, $$pr$i192 = 0, $$pr$i203 = 0, $$pr$i214 = 0, $$pr$i225 = 0, $$pr$i236 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0;
 var $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0;
 var $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0;
 var $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0;
 var $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0;
 var $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0;
 var $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0;
 var $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0;
 var $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0;
 var $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0;
 var $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0;
 var $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0;
 var $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0;
 var $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0;
 var $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0;
 var $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0;
 var $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0;
 var $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0;
 var $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0;
 var $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0;
 var $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0;
 var $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(128|0);
 $3 = sp + 100|0;
 $4 = sp + 80|0;
 $5 = sp + 60|0;
 $6 = sp + 40|0;
 $7 = sp + 20|0;
 $8 = sp;
 $9 = ((($6)) + 4|0);
 $10 = ((($6)) + 16|0);
 $11 = ((($9)) + 11|0);
 $12 = ((($7)) + 4|0);
 $13 = ((($7)) + 16|0);
 $14 = ((($12)) + 11|0);
 $15 = ((($3)) + 4|0);
 $16 = ((($3)) + 16|0);
 $17 = ((($15)) + 11|0);
 $18 = ((($4)) + 4|0);
 $19 = ((($4)) + 16|0);
 $20 = ((($18)) + 11|0);
 $21 = ((($5)) + 4|0);
 $22 = ((($5)) + 16|0);
 $23 = ((($21)) + 11|0);
 $$0$ph = $0;$$0180$ph = $1;
 L1: while(1) {
  $24 = $$0180$ph;
  $25 = ((($$0180$ph)) + -20|0);
  $26 = ((($$0180$ph)) + -16|0);
  $27 = ((($$0180$ph)) + -4|0);
  $28 = ($7|0)==($25|0);
  $$0 = $$0$ph;
  while(1) {
   $$1 = $$0;
   L5: while(1) {
    $29 = $$1;
    $30 = (($24) - ($29))|0;
    $31 = (($30|0) / 20)&-1;
    switch ($31|0) {
    case 2:  {
     label = 5;
     break L1;
     break;
    }
    case 3:  {
     label = 43;
     break L1;
     break;
    }
    case 4:  {
     label = 44;
     break L1;
     break;
    }
    case 5:  {
     label = 45;
     break L1;
     break;
    }
    case 1: case 0:  {
     label = 259;
     break L1;
     break;
    }
    default: {
    }
    }
    $117 = ($30|0)<(140);
    if ($117) {
     label = 47;
     break L1;
    }
    $118 = ($30|0)>(19980);
    $119 = (($30>>>0) / 40)&-1;
    $120 = (($$1) + (($119*20)|0)|0);
    if ($118) {
     $121 = (($30>>>0) / 80)&-1;
     $122 = (($$1) + (($121*20)|0)|0);
     $123 = (($120) + (($121*20)|0)|0);
     $124 = (__ZNSt3__27__sort5IRNS_6__lessIN5osgDB12ReaderWriter10ReadResultES4_EEPS4_EEjT0_S8_S8_S8_S8_T_($$1,$122,$120,$123,$25,$2)|0);
     $$0167 = $124;
    } else {
     $125 = (__ZNSt3__27__sort3IRNS_6__lessIN5osgDB12ReaderWriter10ReadResultES4_EEPS4_EEjT0_S8_S8_T_($$1,$120,$25,$2)|0);
     $$0167 = $125;
    }
    $126 = HEAP32[$$1>>2]|0;
    $127 = HEAP32[$120>>2]|0;
    $128 = ($126|0)<($127|0);
    if ($128) {
     $$3157 = $25;$$3170 = $$0167;
     break;
    } else {
     $$0154 = $25;
    }
    while(1) {
     $129 = ((($$0154)) + -20|0);
     $130 = ($$1|0)==($129|0);
     if ($130) {
      break;
     }
     $291 = HEAP32[$129>>2]|0;
     $292 = ($291|0)<($127|0);
     if ($292) {
      label = 136;
      break L5;
     } else {
      $$0154 = $129;
     }
    }
    $131 = ((($$1)) + 20|0);
    $132 = HEAP32[$25>>2]|0;
    $133 = ($126|0)<($132|0);
    if ($133) {
     $$1161 = $131;
    } else {
     $134 = ($131|0)==($25|0);
     if ($134) {
      label = 259;
      break L1;
     } else {
      $$0160375 = $131;
     }
     while(1) {
      $135 = HEAP32[$$0160375>>2]|0;
      $136 = ($126|0)<($135|0);
      if ($136) {
       break;
      }
      $206 = ((($$0160375)) + 20|0);
      $207 = ($206|0)==($25|0);
      if ($207) {
       label = 259;
       break L1;
      } else {
       $$0160375 = $206;
      }
     }
     HEAP32[$7>>2] = $135;
     $137 = ((($$0160375)) + 4|0);
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_($12,$137);
     $138 = ((($$0160375)) + 16|0);
     $139 = HEAP32[$138>>2]|0;
     HEAP32[$13>>2] = $139;
     $140 = ($139|0)==(0|0);
     if (!($140)) {
      $141 = ((($139)) + 8|0);
      $142 = HEAP32[$141>>2]|0;HEAP32[$141>>2] = (($142+1)|0);
     }
     $143 = HEAP32[$25>>2]|0;
     HEAP32[$$0160375>>2] = $143;
     __THREW__ = 0;
     (invoke_iii(3477,($137|0),($26|0))|0);
     $144 = __THREW__; __THREW__ = 0;
     $145 = $144&1;
     if ($145) {
      label = 82;
      break L1;
     }
     $146 = HEAP32[$138>>2]|0;
     $147 = HEAP32[$27>>2]|0;
     $148 = ($146|0)==($147|0);
     if (!($148)) {
      HEAP32[$138>>2] = $147;
      $149 = ($147|0)==(0|0);
      if (!($149)) {
       $150 = ((($147)) + 8|0);
       $151 = HEAP32[$150>>2]|0;HEAP32[$150>>2] = (($151+1)|0);
      }
      $152 = ($146|0)==(0|0);
      if (!($152)) {
       $153 = ((($146)) + 8|0);
       $154 = HEAP32[$153>>2]|0;HEAP32[$153>>2] = (($154-1)|0);
       $155 = ($154|0)==(1);
       if ($155) {
        __THREW__ = 0;
        invoke_viii(3262,($146|0),1,1);
        $156 = __THREW__; __THREW__ = 0;
        $157 = $156&1;
        if ($157) {
         label = 82;
         break L1;
        }
       }
      }
     }
     if ($28) {
      label = 73;
     } else {
      $158 = HEAP32[$7>>2]|0;
      HEAP32[$25>>2] = $158;
      __THREW__ = 0;
      (invoke_iii(3477,($26|0),($12|0))|0);
      $159 = __THREW__; __THREW__ = 0;
      $160 = $159&1;
      if ($160) {
       label = 82;
       break L1;
      }
      $161 = HEAP32[$27>>2]|0;
      $162 = HEAP32[$13>>2]|0;
      $163 = ($161|0)==($162|0);
      if ($163) {
       $173 = $161;
      } else {
       HEAP32[$27>>2] = $162;
       $164 = ($162|0)==(0|0);
       if (!($164)) {
        $165 = ((($162)) + 8|0);
        $166 = HEAP32[$165>>2]|0;HEAP32[$165>>2] = (($166+1)|0);
       }
       $167 = ($161|0)==(0|0);
       if ($167) {
        label = 73;
       } else {
        $168 = ((($161)) + 8|0);
        $169 = HEAP32[$168>>2]|0;HEAP32[$168>>2] = (($169-1)|0);
        $170 = ($169|0)==(1);
        if ($170) {
         __THREW__ = 0;
         invoke_viii(3262,($161|0),1,1);
         $171 = __THREW__; __THREW__ = 0;
         $172 = $171&1;
         if ($172) {
          label = 82;
          break L1;
         } else {
          label = 73;
         }
        } else {
         label = 73;
        }
       }
      }
     }
     if ((label|0) == 73) {
      label = 0;
      $$pr$i192 = HEAP32[$13>>2]|0;
      $173 = $$pr$i192;
     }
     $174 = ($173|0)==(0|0);
     if (!($174)) {
      $175 = ((($173)) + 8|0);
      $176 = HEAP32[$175>>2]|0;HEAP32[$175>>2] = (($176-1)|0);
      $177 = ($176|0)==(1);
      if ($177) {
       __THREW__ = 0;
       invoke_viii(3262,($173|0),1,1);
       $178 = __THREW__; __THREW__ = 0;
       $179 = $178&1;
       if ($179) {
        label = 79;
        break L1;
       }
      }
     }
     HEAP32[$13>>2] = 0;
     $180 = HEAP8[$14>>0]|0;
     $181 = ($180<<24>>24)<(0);
     if ($181) {
      $182 = HEAP32[$12>>2]|0;
      __ZdlPv($182);
     }
     $205 = ((($$0160375)) + 20|0);
     $$1161 = $205;
    }
    $208 = ($$1161|0)==($25|0);
    if ($208) {
     label = 259;
     break L1;
    } else {
     $$1155 = $25;$$2162 = $$1161;
    }
    while(1) {
     $209 = HEAP32[$$1>>2]|0;
     $$3163 = $$2162;
     while(1) {
      $210 = HEAP32[$$3163>>2]|0;
      $211 = ($209|0)<($210|0);
      $212 = ((($$3163)) + 20|0);
      if ($211) {
       $$2156 = $$1155;
       break;
      } else {
       $$3163 = $212;
      }
     }
     while(1) {
      $213 = ((($$2156)) + -20|0);
      $214 = HEAP32[$213>>2]|0;
      $215 = ($209|0)<($214|0);
      if ($215) {
       $$2156 = $213;
      } else {
       break;
      }
     }
     $216 = ($$3163>>>0)<($213>>>0);
     if (!($216)) {
      $$1 = $$3163;
      continue L5;
     }
     HEAP32[$6>>2] = $210;
     $217 = ((($$3163)) + 4|0);
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_($9,$217);
     $218 = ((($$3163)) + 16|0);
     $219 = HEAP32[$218>>2]|0;
     HEAP32[$10>>2] = $219;
     $220 = ($219|0)==(0|0);
     if (!($220)) {
      $221 = ((($219)) + 8|0);
      $222 = HEAP32[$221>>2]|0;HEAP32[$221>>2] = (($222+1)|0);
     }
     $223 = ($$3163|0)==($213|0);
     if (!($223)) {
      $224 = HEAP32[$213>>2]|0;
      HEAP32[$$3163>>2] = $224;
      $225 = ((($$2156)) + -16|0);
      __THREW__ = 0;
      (invoke_iii(3477,($217|0),($225|0))|0);
      $226 = __THREW__; __THREW__ = 0;
      $227 = $226&1;
      if ($227) {
       label = 125;
       break L1;
      }
      $228 = HEAP32[$218>>2]|0;
      $229 = ((($$2156)) + -4|0);
      $230 = HEAP32[$229>>2]|0;
      $231 = ($228|0)==($230|0);
      if (!($231)) {
       HEAP32[$218>>2] = $230;
       $232 = ($230|0)==(0|0);
       if (!($232)) {
        $233 = ((($230)) + 8|0);
        $234 = HEAP32[$233>>2]|0;HEAP32[$233>>2] = (($234+1)|0);
       }
       $235 = ($228|0)==(0|0);
       if (!($235)) {
        $236 = ((($228)) + 8|0);
        $237 = HEAP32[$236>>2]|0;HEAP32[$236>>2] = (($237-1)|0);
        $238 = ($237|0)==(1);
        if ($238) {
         __THREW__ = 0;
         invoke_viii(3262,($228|0),1,1);
         $239 = __THREW__; __THREW__ = 0;
         $240 = $239&1;
         if ($240) {
          label = 125;
          break L1;
         }
        }
       }
      }
     }
     $241 = ($6|0)==($213|0);
     if ($241) {
      label = 116;
     } else {
      $242 = HEAP32[$6>>2]|0;
      HEAP32[$213>>2] = $242;
      $243 = ((($$2156)) + -16|0);
      __THREW__ = 0;
      (invoke_iii(3477,($243|0),($9|0))|0);
      $244 = __THREW__; __THREW__ = 0;
      $245 = $244&1;
      if ($245) {
       label = 125;
       break L1;
      }
      $246 = ((($$2156)) + -4|0);
      $247 = HEAP32[$246>>2]|0;
      $248 = HEAP32[$10>>2]|0;
      $249 = ($247|0)==($248|0);
      if ($249) {
       $259 = $247;
      } else {
       HEAP32[$246>>2] = $248;
       $250 = ($248|0)==(0|0);
       if (!($250)) {
        $251 = ((($248)) + 8|0);
        $252 = HEAP32[$251>>2]|0;HEAP32[$251>>2] = (($252+1)|0);
       }
       $253 = ($247|0)==(0|0);
       if ($253) {
        label = 116;
       } else {
        $254 = ((($247)) + 8|0);
        $255 = HEAP32[$254>>2]|0;HEAP32[$254>>2] = (($255-1)|0);
        $256 = ($255|0)==(1);
        if ($256) {
         __THREW__ = 0;
         invoke_viii(3262,($247|0),1,1);
         $257 = __THREW__; __THREW__ = 0;
         $258 = $257&1;
         if ($258) {
          label = 125;
          break L1;
         } else {
          label = 116;
         }
        } else {
         label = 116;
        }
       }
      }
     }
     if ((label|0) == 116) {
      label = 0;
      $$pr$i203 = HEAP32[$10>>2]|0;
      $259 = $$pr$i203;
     }
     $260 = ($259|0)==(0|0);
     if (!($260)) {
      $261 = ((($259)) + 8|0);
      $262 = HEAP32[$261>>2]|0;HEAP32[$261>>2] = (($262-1)|0);
      $263 = ($262|0)==(1);
      if ($263) {
       __THREW__ = 0;
       invoke_viii(3262,($259|0),1,1);
       $264 = __THREW__; __THREW__ = 0;
       $265 = $264&1;
       if ($265) {
        label = 122;
        break L1;
       }
      }
     }
     HEAP32[$10>>2] = 0;
     $266 = HEAP8[$11>>0]|0;
     $267 = ($266<<24>>24)<(0);
     if ($267) {
      $268 = HEAP32[$9>>2]|0;
      __ZdlPv($268);
     }
     $$1155 = $213;$$2162 = $212;
    }
   }
   if ((label|0) == 136) {
    label = 0;
    HEAP32[$5>>2] = $126;
    $293 = ((($$1)) + 4|0);
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_($21,$293);
    $294 = ((($$1)) + 16|0);
    $295 = HEAP32[$294>>2]|0;
    HEAP32[$22>>2] = $295;
    $296 = ($295|0)==(0|0);
    if (!($296)) {
     $297 = ((($295)) + 8|0);
     $298 = HEAP32[$297>>2]|0;HEAP32[$297>>2] = (($298+1)|0);
    }
    $299 = HEAP32[$129>>2]|0;
    HEAP32[$$1>>2] = $299;
    $300 = ((($$0154)) + -16|0);
    __THREW__ = 0;
    (invoke_iii(3477,($293|0),($300|0))|0);
    $301 = __THREW__; __THREW__ = 0;
    $302 = $301&1;
    if ($302) {
     label = 162;
     break L1;
    }
    $303 = HEAP32[$294>>2]|0;
    $304 = ((($$0154)) + -4|0);
    $305 = HEAP32[$304>>2]|0;
    $306 = ($303|0)==($305|0);
    if (!($306)) {
     HEAP32[$294>>2] = $305;
     $307 = ($305|0)==(0|0);
     if (!($307)) {
      $308 = ((($305)) + 8|0);
      $309 = HEAP32[$308>>2]|0;HEAP32[$308>>2] = (($309+1)|0);
     }
     $310 = ($303|0)==(0|0);
     if (!($310)) {
      $311 = ((($303)) + 8|0);
      $312 = HEAP32[$311>>2]|0;HEAP32[$311>>2] = (($312-1)|0);
      $313 = ($312|0)==(1);
      if ($313) {
       __THREW__ = 0;
       invoke_viii(3262,($303|0),1,1);
       $314 = __THREW__; __THREW__ = 0;
       $315 = $314&1;
       if ($315) {
        label = 162;
        break L1;
       }
      }
     }
    }
    $316 = ($5|0)==($129|0);
    if ($316) {
     label = 153;
    } else {
     $317 = HEAP32[$5>>2]|0;
     HEAP32[$129>>2] = $317;
     __THREW__ = 0;
     (invoke_iii(3477,($300|0),($21|0))|0);
     $318 = __THREW__; __THREW__ = 0;
     $319 = $318&1;
     if ($319) {
      label = 162;
      break L1;
     }
     $320 = HEAP32[$304>>2]|0;
     $321 = HEAP32[$22>>2]|0;
     $322 = ($320|0)==($321|0);
     if ($322) {
      $332 = $320;
     } else {
      HEAP32[$304>>2] = $321;
      $323 = ($321|0)==(0|0);
      if (!($323)) {
       $324 = ((($321)) + 8|0);
       $325 = HEAP32[$324>>2]|0;HEAP32[$324>>2] = (($325+1)|0);
      }
      $326 = ($320|0)==(0|0);
      if ($326) {
       label = 153;
      } else {
       $327 = ((($320)) + 8|0);
       $328 = HEAP32[$327>>2]|0;HEAP32[$327>>2] = (($328-1)|0);
       $329 = ($328|0)==(1);
       if ($329) {
        __THREW__ = 0;
        invoke_viii(3262,($320|0),1,1);
        $330 = __THREW__; __THREW__ = 0;
        $331 = $330&1;
        if ($331) {
         label = 162;
         break L1;
        } else {
         label = 153;
        }
       } else {
        label = 153;
       }
      }
     }
    }
    if ((label|0) == 153) {
     label = 0;
     $$pr$i214 = HEAP32[$22>>2]|0;
     $332 = $$pr$i214;
    }
    $333 = ($332|0)==(0|0);
    if (!($333)) {
     $334 = ((($332)) + 8|0);
     $335 = HEAP32[$334>>2]|0;HEAP32[$334>>2] = (($335-1)|0);
     $336 = ($335|0)==(1);
     if ($336) {
      __THREW__ = 0;
      invoke_viii(3262,($332|0),1,1);
      $337 = __THREW__; __THREW__ = 0;
      $338 = $337&1;
      if ($338) {
       label = 159;
       break L1;
      }
     }
    }
    HEAP32[$22>>2] = 0;
    $339 = HEAP8[$23>>0]|0;
    $340 = ($339<<24>>24)<(0);
    if ($340) {
     $341 = HEAP32[$21>>2]|0;
     __ZdlPv($341);
    }
    $364 = (($$0167) + 1)|0;
    $$3157 = $129;$$3170 = $364;
   }
   $365 = ((($$1)) + 20|0);
   $366 = ($365>>>0)<($$3157>>>0);
   L129: do {
    if ($366) {
     $$0174 = $120;$$4158 = $$3157;$$4164 = $365;$$4171 = $$3170;
     while(1) {
      $367 = HEAP32[$$0174>>2]|0;
      $$5165 = $$4164;
      while(1) {
       $368 = HEAP32[$$5165>>2]|0;
       $369 = ($368|0)<($367|0);
       $370 = ((($$5165)) + 20|0);
       if ($369) {
        $$5165 = $370;
       } else {
        $$5159 = $$4158;
        break;
       }
      }
      while(1) {
       $371 = ((($$5159)) + -20|0);
       $372 = HEAP32[$371>>2]|0;
       $373 = ($372|0)<($367|0);
       if ($373) {
        break;
       } else {
        $$5159 = $371;
       }
      }
      $374 = ($$5165>>>0)>($371>>>0);
      if ($374) {
       $$2176 = $$0174;$$5172 = $$4171;$$6166 = $$5165;
       break L129;
      }
      HEAP32[$4>>2] = $368;
      $375 = ((($$5165)) + 4|0);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_($18,$375);
      $376 = ((($$5165)) + 16|0);
      $377 = HEAP32[$376>>2]|0;
      HEAP32[$19>>2] = $377;
      $378 = ($377|0)==(0|0);
      if (!($378)) {
       $379 = ((($377)) + 8|0);
       $380 = HEAP32[$379>>2]|0;HEAP32[$379>>2] = (($380+1)|0);
      }
      $381 = ($$5165|0)==($371|0);
      if (!($381)) {
       $382 = HEAP32[$371>>2]|0;
       HEAP32[$$5165>>2] = $382;
       $383 = ((($$5159)) + -16|0);
       __THREW__ = 0;
       (invoke_iii(3477,($375|0),($383|0))|0);
       $384 = __THREW__; __THREW__ = 0;
       $385 = $384&1;
       if ($385) {
        label = 204;
        break L1;
       }
       $386 = HEAP32[$376>>2]|0;
       $387 = ((($$5159)) + -4|0);
       $388 = HEAP32[$387>>2]|0;
       $389 = ($386|0)==($388|0);
       if (!($389)) {
        HEAP32[$376>>2] = $388;
        $390 = ($388|0)==(0|0);
        if (!($390)) {
         $391 = ((($388)) + 8|0);
         $392 = HEAP32[$391>>2]|0;HEAP32[$391>>2] = (($392+1)|0);
        }
        $393 = ($386|0)==(0|0);
        if (!($393)) {
         $394 = ((($386)) + 8|0);
         $395 = HEAP32[$394>>2]|0;HEAP32[$394>>2] = (($395-1)|0);
         $396 = ($395|0)==(1);
         if ($396) {
          __THREW__ = 0;
          invoke_viii(3262,($386|0),1,1);
          $397 = __THREW__; __THREW__ = 0;
          $398 = $397&1;
          if ($398) {
           label = 204;
           break L1;
          }
         }
        }
       }
      }
      $399 = ($4|0)==($371|0);
      if ($399) {
       label = 195;
      } else {
       $400 = HEAP32[$4>>2]|0;
       HEAP32[$371>>2] = $400;
       $401 = ((($$5159)) + -16|0);
       __THREW__ = 0;
       (invoke_iii(3477,($401|0),($18|0))|0);
       $402 = __THREW__; __THREW__ = 0;
       $403 = $402&1;
       if ($403) {
        label = 204;
        break L1;
       }
       $404 = ((($$5159)) + -4|0);
       $405 = HEAP32[$404>>2]|0;
       $406 = HEAP32[$19>>2]|0;
       $407 = ($405|0)==($406|0);
       if ($407) {
        $417 = $405;
       } else {
        HEAP32[$404>>2] = $406;
        $408 = ($406|0)==(0|0);
        if (!($408)) {
         $409 = ((($406)) + 8|0);
         $410 = HEAP32[$409>>2]|0;HEAP32[$409>>2] = (($410+1)|0);
        }
        $411 = ($405|0)==(0|0);
        if ($411) {
         label = 195;
        } else {
         $412 = ((($405)) + 8|0);
         $413 = HEAP32[$412>>2]|0;HEAP32[$412>>2] = (($413-1)|0);
         $414 = ($413|0)==(1);
         if ($414) {
          __THREW__ = 0;
          invoke_viii(3262,($405|0),1,1);
          $415 = __THREW__; __THREW__ = 0;
          $416 = $415&1;
          if ($416) {
           label = 204;
           break L1;
          } else {
           label = 195;
          }
         } else {
          label = 195;
         }
        }
       }
      }
      if ((label|0) == 195) {
       label = 0;
       $$pr$i225 = HEAP32[$19>>2]|0;
       $417 = $$pr$i225;
      }
      $418 = ($417|0)==(0|0);
      if (!($418)) {
       $419 = ((($417)) + 8|0);
       $420 = HEAP32[$419>>2]|0;HEAP32[$419>>2] = (($420-1)|0);
       $421 = ($420|0)==(1);
       if ($421) {
        __THREW__ = 0;
        invoke_viii(3262,($417|0),1,1);
        $422 = __THREW__; __THREW__ = 0;
        $423 = $422&1;
        if ($423) {
         label = 201;
         break L1;
        }
       }
      }
      HEAP32[$19>>2] = 0;
      $424 = HEAP8[$20>>0]|0;
      $425 = ($424<<24>>24)<(0);
      if ($425) {
       $426 = HEAP32[$18>>2]|0;
       __ZdlPv($426);
      }
      $449 = (($$4171) + 1)|0;
      $450 = ($$0174|0)==($$5165|0);
      $$$0174 = $450 ? $371 : $$0174;
      $$0174 = $$$0174;$$4158 = $371;$$4164 = $370;$$4171 = $449;
     }
    } else {
     $$2176 = $120;$$5172 = $$3170;$$6166 = $365;
    }
   } while(0);
   $451 = ($$6166|0)==($$2176|0);
   if ($451) {
    $$6173 = $$5172;
   } else {
    $452 = HEAP32[$$2176>>2]|0;
    $453 = HEAP32[$$6166>>2]|0;
    $454 = ($452|0)<($453|0);
    if ($454) {
     HEAP32[$3>>2] = $453;
     $455 = ((($$6166)) + 4|0);
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_($15,$455);
     $456 = ((($$6166)) + 16|0);
     $457 = HEAP32[$456>>2]|0;
     HEAP32[$16>>2] = $457;
     $458 = ($457|0)==(0|0);
     if (!($458)) {
      $459 = ((($457)) + 8|0);
      $460 = HEAP32[$459>>2]|0;HEAP32[$459>>2] = (($460+1)|0);
     }
     $461 = HEAP32[$$2176>>2]|0;
     HEAP32[$$6166>>2] = $461;
     $462 = ((($$2176)) + 4|0);
     __THREW__ = 0;
     (invoke_iii(3477,($455|0),($462|0))|0);
     $463 = __THREW__; __THREW__ = 0;
     $464 = $463&1;
     if ($464) {
      label = 242;
      break L1;
     }
     $465 = HEAP32[$456>>2]|0;
     $466 = ((($$2176)) + 16|0);
     $467 = HEAP32[$466>>2]|0;
     $468 = ($465|0)==($467|0);
     if (!($468)) {
      HEAP32[$456>>2] = $467;
      $469 = ($467|0)==(0|0);
      if (!($469)) {
       $470 = ((($467)) + 8|0);
       $471 = HEAP32[$470>>2]|0;HEAP32[$470>>2] = (($471+1)|0);
      }
      $472 = ($465|0)==(0|0);
      if (!($472)) {
       $473 = ((($465)) + 8|0);
       $474 = HEAP32[$473>>2]|0;HEAP32[$473>>2] = (($474-1)|0);
       $475 = ($474|0)==(1);
       if ($475) {
        __THREW__ = 0;
        invoke_viii(3262,($465|0),1,1);
        $476 = __THREW__; __THREW__ = 0;
        $477 = $476&1;
        if ($477) {
         label = 242;
         break L1;
        }
       }
      }
     }
     $478 = ($3|0)==($$2176|0);
     if ($478) {
      label = 233;
     } else {
      $479 = HEAP32[$3>>2]|0;
      HEAP32[$$2176>>2] = $479;
      __THREW__ = 0;
      (invoke_iii(3477,($462|0),($15|0))|0);
      $480 = __THREW__; __THREW__ = 0;
      $481 = $480&1;
      if ($481) {
       label = 242;
       break L1;
      }
      $482 = HEAP32[$466>>2]|0;
      $483 = HEAP32[$16>>2]|0;
      $484 = ($482|0)==($483|0);
      if ($484) {
       $494 = $482;
      } else {
       HEAP32[$466>>2] = $483;
       $485 = ($483|0)==(0|0);
       if (!($485)) {
        $486 = ((($483)) + 8|0);
        $487 = HEAP32[$486>>2]|0;HEAP32[$486>>2] = (($487+1)|0);
       }
       $488 = ($482|0)==(0|0);
       if ($488) {
        label = 233;
       } else {
        $489 = ((($482)) + 8|0);
        $490 = HEAP32[$489>>2]|0;HEAP32[$489>>2] = (($490-1)|0);
        $491 = ($490|0)==(1);
        if ($491) {
         __THREW__ = 0;
         invoke_viii(3262,($482|0),1,1);
         $492 = __THREW__; __THREW__ = 0;
         $493 = $492&1;
         if ($493) {
          label = 242;
          break L1;
         } else {
          label = 233;
         }
        } else {
         label = 233;
        }
       }
      }
     }
     if ((label|0) == 233) {
      label = 0;
      $$pr$i236 = HEAP32[$16>>2]|0;
      $494 = $$pr$i236;
     }
     $495 = ($494|0)==(0|0);
     if (!($495)) {
      $496 = ((($494)) + 8|0);
      $497 = HEAP32[$496>>2]|0;HEAP32[$496>>2] = (($497-1)|0);
      $498 = ($497|0)==(1);
      if ($498) {
       __THREW__ = 0;
       invoke_viii(3262,($494|0),1,1);
       $499 = __THREW__; __THREW__ = 0;
       $500 = $499&1;
       if ($500) {
        label = 239;
        break L1;
       }
      }
     }
     HEAP32[$16>>2] = 0;
     $501 = HEAP8[$17>>0]|0;
     $502 = ($501<<24>>24)<(0);
     if ($502) {
      $503 = HEAP32[$15>>2]|0;
      __ZdlPv($503);
     }
     $526 = (($$5172) + 1)|0;
     $$6173 = $526;
    } else {
     $$6173 = $$5172;
    }
   }
   $527 = ($$6173|0)==(0);
   if ($527) {
    $528 = (__ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIN5osgDB12ReaderWriter10ReadResultES4_EEPS4_EEbT0_S8_T_($$1,$$6166,$2)|0);
    $529 = ((($$6166)) + 20|0);
    $530 = (__ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIN5osgDB12ReaderWriter10ReadResultES4_EEPS4_EEbT0_S8_T_($529,$$0180$ph,$2)|0);
    if ($530) {
     label = 258;
     break;
    }
    if ($528) {
     $$0 = $529;
     continue;
    }
   }
   $531 = $$6166;
   $532 = (($531) - ($29))|0;
   $533 = (($24) - ($531))|0;
   $534 = ($532|0)<($533|0);
   if (!($534)) {
    label = 257;
    break;
   }
   __ZNSt3__26__sortIRNS_6__lessIN5osgDB12ReaderWriter10ReadResultES4_EEPS4_EEvT0_S8_T_($$1,$$6166,$2);
   $535 = ((($$6166)) + 20|0);
   $$0 = $535;
  }
  if ((label|0) == 257) {
   label = 0;
   $536 = ((($$6166)) + 20|0);
   __ZNSt3__26__sortIRNS_6__lessIN5osgDB12ReaderWriter10ReadResultES4_EEPS4_EEvT0_S8_T_($536,$$0180$ph,$2);
   $$0$ph = $$1;$$0180$ph = $$6166;
   continue;
  }
  else if ((label|0) == 258) {
   label = 0;
   if ($528) {
    label = 259;
    break;
   } else {
    $$0$ph = $$1;$$0180$ph = $$6166;
    continue;
   }
  }
 }
 switch (label|0) {
  case 5: {
   $32 = HEAP32[$25>>2]|0;
   $33 = HEAP32[$$1>>2]|0;
   $34 = ($32|0)<($33|0);
   if (!($34)) {
    STACKTOP = sp;return;
   }
   HEAP32[$8>>2] = $33;
   $35 = ((($8)) + 4|0);
   $36 = ((($$1)) + 4|0);
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_($35,$36);
   $37 = ((($8)) + 16|0);
   $38 = ((($$1)) + 16|0);
   $39 = HEAP32[$38>>2]|0;
   HEAP32[$37>>2] = $39;
   $40 = ($39|0)==(0|0);
   if (!($40)) {
    $41 = ((($39)) + 8|0);
    $42 = HEAP32[$41>>2]|0;HEAP32[$41>>2] = (($42+1)|0);
   }
   $43 = ($$1|0)==($25|0);
   if ($43) {
    label = 16;
   } else {
    $44 = HEAP32[$25>>2]|0;
    HEAP32[$$1>>2] = $44;
    __THREW__ = 0;
    (invoke_iii(3477,($36|0),($26|0))|0);
    $45 = __THREW__; __THREW__ = 0;
    $46 = $45&1;
    if (!($46)) {
     $47 = HEAP32[$38>>2]|0;
     $48 = HEAP32[$27>>2]|0;
     $49 = ($47|0)==($48|0);
     if ($49) {
      label = 16;
     } else {
      HEAP32[$38>>2] = $48;
      $50 = ($48|0)==(0|0);
      if (!($50)) {
       $51 = ((($48)) + 8|0);
       $52 = HEAP32[$51>>2]|0;HEAP32[$51>>2] = (($52+1)|0);
      }
      $53 = ($47|0)==(0|0);
      if ($53) {
       label = 16;
      } else {
       $54 = ((($47)) + 8|0);
       $55 = HEAP32[$54>>2]|0;HEAP32[$54>>2] = (($55-1)|0);
       $56 = ($55|0)==(1);
       if ($56) {
        __THREW__ = 0;
        invoke_viii(3262,($47|0),1,1);
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if (!($58)) {
         label = 16;
        }
       } else {
        label = 16;
       }
      }
     }
    }
   }
   do {
    if ((label|0) == 16) {
     $59 = ($8|0)==($25|0);
     if ($59) {
      label = 24;
     } else {
      $60 = HEAP32[$8>>2]|0;
      HEAP32[$25>>2] = $60;
      __THREW__ = 0;
      (invoke_iii(3477,($26|0),($35|0))|0);
      $61 = __THREW__; __THREW__ = 0;
      $62 = $61&1;
      if ($62) {
       break;
      }
      $63 = HEAP32[$27>>2]|0;
      $64 = HEAP32[$37>>2]|0;
      $65 = ($63|0)==($64|0);
      if ($65) {
       $75 = $63;
      } else {
       HEAP32[$27>>2] = $64;
       $66 = ($64|0)==(0|0);
       if (!($66)) {
        $67 = ((($64)) + 8|0);
        $68 = HEAP32[$67>>2]|0;HEAP32[$67>>2] = (($68+1)|0);
       }
       $69 = ($63|0)==(0|0);
       if ($69) {
        label = 24;
       } else {
        $70 = ((($63)) + 8|0);
        $71 = HEAP32[$70>>2]|0;HEAP32[$70>>2] = (($71-1)|0);
        $72 = ($71|0)==(1);
        if ($72) {
         __THREW__ = 0;
         invoke_viii(3262,($63|0),1,1);
         $73 = __THREW__; __THREW__ = 0;
         $74 = $73&1;
         if ($74) {
          break;
         } else {
          label = 24;
         }
        } else {
         label = 24;
        }
       }
      }
     }
     if ((label|0) == 24) {
      $$pr$i = HEAP32[$37>>2]|0;
      $75 = $$pr$i;
     }
     $76 = ($75|0)==(0|0);
     if (!($76)) {
      $77 = ((($75)) + 8|0);
      $78 = HEAP32[$77>>2]|0;HEAP32[$77>>2] = (($78-1)|0);
      $79 = ($78|0)==(1);
      if ($79) {
       __THREW__ = 0;
       invoke_viii(3262,($75|0),1,1);
       $80 = __THREW__; __THREW__ = 0;
       $81 = $80&1;
       if ($81) {
        $86 = ___cxa_find_matching_catch_2()|0;
        $87 = tempRet0;
        $88 = ((($35)) + 11|0);
        $89 = HEAP8[$88>>0]|0;
        $90 = ($89<<24>>24)<(0);
        if (!($90)) {
         ___resumeException($86|0);
         // unreachable;
        }
        $91 = HEAP32[$35>>2]|0;
        __ZdlPv($91);
        ___resumeException($86|0);
        // unreachable;
       }
      }
     }
     HEAP32[$37>>2] = 0;
     $82 = ((($35)) + 11|0);
     $83 = HEAP8[$82>>0]|0;
     $84 = ($83<<24>>24)<(0);
     if ($84) {
      $85 = HEAP32[$35>>2]|0;
      __ZdlPv($85);
     }
     STACKTOP = sp;return;
    }
   } while(0);
   $92 = ___cxa_find_matching_catch_2()|0;
   $93 = tempRet0;
   $94 = HEAP32[$37>>2]|0;
   $95 = ($94|0)==(0|0);
   if (!($95)) {
    $96 = ((($94)) + 8|0);
    $97 = HEAP32[$96>>2]|0;HEAP32[$96>>2] = (($97-1)|0);
    $98 = ($97|0)==(1);
    if ($98) {
     __THREW__ = 0;
     invoke_viii(3262,($94|0),1,1);
     $99 = __THREW__; __THREW__ = 0;
     $100 = $99&1;
     if ($100) {
      $105 = ___cxa_find_matching_catch_3(0|0)|0;
      $106 = tempRet0;
      $107 = ((($35)) + 11|0);
      $108 = HEAP8[$107>>0]|0;
      $109 = ($108<<24>>24)<(0);
      if (!($109)) {
       ___clang_call_terminate($105);
       // unreachable;
      }
      $110 = HEAP32[$35>>2]|0;
      __ZdlPv($110);
      ___clang_call_terminate($105);
      // unreachable;
     }
    }
   }
   HEAP32[$37>>2] = 0;
   $101 = ((($35)) + 11|0);
   $102 = HEAP8[$101>>0]|0;
   $103 = ($102<<24>>24)<(0);
   if (!($103)) {
    ___resumeException($92|0);
    // unreachable;
   }
   $104 = HEAP32[$35>>2]|0;
   __ZdlPv($104);
   ___resumeException($92|0);
   // unreachable;
   break;
  }
  case 43: {
   $111 = ((($$1)) + 20|0);
   (__ZNSt3__27__sort3IRNS_6__lessIN5osgDB12ReaderWriter10ReadResultES4_EEPS4_EEjT0_S8_S8_T_($$1,$111,$25,$2)|0);
   STACKTOP = sp;return;
   break;
  }
  case 44: {
   $112 = ((($$1)) + 20|0);
   $113 = ((($$1)) + 40|0);
   (__ZNSt3__27__sort4IRNS_6__lessIN5osgDB12ReaderWriter10ReadResultES4_EEPS4_EEjT0_S8_S8_S8_T_($$1,$112,$113,$25,$2)|0);
   STACKTOP = sp;return;
   break;
  }
  case 45: {
   $114 = ((($$1)) + 20|0);
   $115 = ((($$1)) + 40|0);
   $116 = ((($$1)) + 60|0);
   (__ZNSt3__27__sort5IRNS_6__lessIN5osgDB12ReaderWriter10ReadResultES4_EEPS4_EEjT0_S8_S8_S8_S8_T_($$1,$114,$115,$116,$25,$2)|0);
   STACKTOP = sp;return;
   break;
  }
  case 47: {
   __ZNSt3__218__insertion_sort_3IRNS_6__lessIN5osgDB12ReaderWriter10ReadResultES4_EEPS4_EEvT0_S8_T_($$1,$$0180$ph,$2);
   STACKTOP = sp;return;
   break;
  }
  case 79: {
   $183 = ___cxa_find_matching_catch_2()|0;
   $184 = tempRet0;
   $185 = HEAP8[$14>>0]|0;
   $186 = ($185<<24>>24)<(0);
   if (!($186)) {
    ___resumeException($183|0);
    // unreachable;
   }
   $187 = HEAP32[$12>>2]|0;
   __ZdlPv($187);
   ___resumeException($183|0);
   // unreachable;
   break;
  }
  case 82: {
   $188 = ___cxa_find_matching_catch_2()|0;
   $189 = tempRet0;
   $190 = HEAP32[$13>>2]|0;
   $191 = ($190|0)==(0|0);
   if (!($191)) {
    $192 = ((($190)) + 8|0);
    $193 = HEAP32[$192>>2]|0;HEAP32[$192>>2] = (($193-1)|0);
    $194 = ($193|0)==(1);
    if ($194) {
     __THREW__ = 0;
     invoke_viii(3262,($190|0),1,1);
     $195 = __THREW__; __THREW__ = 0;
     $196 = $195&1;
     if ($196) {
      $200 = ___cxa_find_matching_catch_3(0|0)|0;
      $201 = tempRet0;
      $202 = HEAP8[$14>>0]|0;
      $203 = ($202<<24>>24)<(0);
      if (!($203)) {
       ___clang_call_terminate($200);
       // unreachable;
      }
      $204 = HEAP32[$12>>2]|0;
      __ZdlPv($204);
      ___clang_call_terminate($200);
      // unreachable;
     }
    }
   }
   HEAP32[$13>>2] = 0;
   $197 = HEAP8[$14>>0]|0;
   $198 = ($197<<24>>24)<(0);
   if (!($198)) {
    ___resumeException($188|0);
    // unreachable;
   }
   $199 = HEAP32[$12>>2]|0;
   __ZdlPv($199);
   ___resumeException($188|0);
   // unreachable;
   break;
  }
  case 122: {
   $269 = ___cxa_find_matching_catch_2()|0;
   $270 = tempRet0;
   $271 = HEAP8[$11>>0]|0;
   $272 = ($271<<24>>24)<(0);
   if (!($272)) {
    ___resumeException($269|0);
    // unreachable;
   }
   $273 = HEAP32[$9>>2]|0;
   __ZdlPv($273);
   ___resumeException($269|0);
   // unreachable;
   break;
  }
  case 125: {
   $274 = ___cxa_find_matching_catch_2()|0;
   $275 = tempRet0;
   $276 = HEAP32[$10>>2]|0;
   $277 = ($276|0)==(0|0);
   if (!($277)) {
    $278 = ((($276)) + 8|0);
    $279 = HEAP32[$278>>2]|0;HEAP32[$278>>2] = (($279-1)|0);
    $280 = ($279|0)==(1);
    if ($280) {
     __THREW__ = 0;
     invoke_viii(3262,($276|0),1,1);
     $281 = __THREW__; __THREW__ = 0;
     $282 = $281&1;
     if ($282) {
      $286 = ___cxa_find_matching_catch_3(0|0)|0;
      $287 = tempRet0;
      $288 = HEAP8[$11>>0]|0;
      $289 = ($288<<24>>24)<(0);
      if (!($289)) {
       ___clang_call_terminate($286);
       // unreachable;
      }
      $290 = HEAP32[$9>>2]|0;
      __ZdlPv($290);
      ___clang_call_terminate($286);
      // unreachable;
     }
    }
   }
   HEAP32[$10>>2] = 0;
   $283 = HEAP8[$11>>0]|0;
   $284 = ($283<<24>>24)<(0);
   if (!($284)) {
    ___resumeException($274|0);
    // unreachable;
   }
   $285 = HEAP32[$9>>2]|0;
   __ZdlPv($285);
   ___resumeException($274|0);
   // unreachable;
   break;
  }
  case 159: {
   $342 = ___cxa_find_matching_catch_2()|0;
   $343 = tempRet0;
   $344 = HEAP8[$23>>0]|0;
   $345 = ($344<<24>>24)<(0);
   if (!($345)) {
    ___resumeException($342|0);
    // unreachable;
   }
   $346 = HEAP32[$21>>2]|0;
   __ZdlPv($346);
   ___resumeException($342|0);
   // unreachable;
   break;
  }
  case 162: {
   $347 = ___cxa_find_matching_catch_2()|0;
   $348 = tempRet0;
   $349 = HEAP32[$22>>2]|0;
   $350 = ($349|0)==(0|0);
   if (!($350)) {
    $351 = ((($349)) + 8|0);
    $352 = HEAP32[$351>>2]|0;HEAP32[$351>>2] = (($352-1)|0);
    $353 = ($352|0)==(1);
    if ($353) {
     __THREW__ = 0;
     invoke_viii(3262,($349|0),1,1);
     $354 = __THREW__; __THREW__ = 0;
     $355 = $354&1;
     if ($355) {
      $359 = ___cxa_find_matching_catch_3(0|0)|0;
      $360 = tempRet0;
      $361 = HEAP8[$23>>0]|0;
      $362 = ($361<<24>>24)<(0);
      if (!($362)) {
       ___clang_call_terminate($359);
       // unreachable;
      }
      $363 = HEAP32[$21>>2]|0;
      __ZdlPv($363);
      ___clang_call_terminate($359);
      // unreachable;
     }
    }
   }
   HEAP32[$22>>2] = 0;
   $356 = HEAP8[$23>>0]|0;
   $357 = ($356<<24>>24)<(0);
   if (!($357)) {
    ___resumeException($347|0);
    // unreachable;
   }
   $358 = HEAP32[$21>>2]|0;
   __ZdlPv($358);
   ___resumeException($347|0);
   // unreachable;
   break;
  }
  case 201: {
   $427 = ___cxa_find_matching_catch_2()|0;
   $428 = tempRet0;
   $429 = HEAP8[$20>>0]|0;
   $430 = ($429<<24>>24)<(0);
   if (!($430)) {
    ___resumeException($427|0);
    // unreachable;
   }
   $431 = HEAP32[$18>>2]|0;
   __ZdlPv($431);
   ___resumeException($427|0);
   // unreachable;
   break;
  }
  case 204: {
   $432 = ___cxa_find_matching_catch_2()|0;
   $433 = tempRet0;
   $434 = HEAP32[$19>>2]|0;
   $435 = ($434|0)==(0|0);
   if (!($435)) {
    $436 = ((($434)) + 8|0);
    $437 = HEAP32[$436>>2]|0;HEAP32[$436>>2] = (($437-1)|0);
    $438 = ($437|0)==(1);
    if ($438) {
     __THREW__ = 0;
     invoke_viii(3262,($434|0),1,1);
     $439 = __THREW__; __THREW__ = 0;
     $440 = $439&1;
     if ($440) {
      $444 = ___cxa_find_matching_catch_3(0|0)|0;
      $445 = tempRet0;
      $446 = HEAP8[$20>>0]|0;
      $447 = ($446<<24>>24)<(0);
      if (!($447)) {
       ___clang_call_terminate($444);
       // unreachable;
      }
      $448 = HEAP32[$18>>2]|0;
      __ZdlPv($448);
      ___clang_call_terminate($444);
      // unreachable;
     }
    }
   }
   HEAP32[$19>>2] = 0;
   $441 = HEAP8[$20>>0]|0;
   $442 = ($441<<24>>24)<(0);
   if (!($442)) {
    ___resumeException($432|0);
    // unreachable;
   }
   $443 = HEAP32[$18>>2]|0;
   __ZdlPv($443);
   ___resumeException($432|0);
   // unreachable;
   break;
  }
  case 239: {
   $504 = ___cxa_find_matching_catch_2()|0;
   $505 = tempRet0;
   $506 = HEAP8[$17>>0]|0;
   $507 = ($506<<24>>24)<(0);
   if (!($507)) {
    ___resumeException($504|0);
    // unreachable;
   }
   $508 = HEAP32[$15>>2]|0;
   __ZdlPv($508);
   ___resumeException($504|0);
   // unreachable;
   break;
  }
  case 242: {
   $509 = ___cxa_find_matching_catch_2()|0;
   $510 = tempRet0;
   $511 = HEAP32[$16>>2]|0;
   $512 = ($511|0)==(0|0);
   if (!($512)) {
    $513 = ((($511)) + 8|0);
    $514 = HEAP32[$513>>2]|0;HEAP32[$513>>2] = (($514-1)|0);
    $515 = ($514|0)==(1);
    if ($515) {
     __THREW__ = 0;
     invoke_viii(3262,($511|0),1,1);
     $516 = __THREW__; __THREW__ = 0;
     $517 = $516&1;
     if ($517) {
      $521 = ___cxa_find_matching_catch_3(0|0)|0;
      $522 = tempRet0;
      $523 = HEAP8[$17>>0]|0;
      $524 = ($523<<24>>24)<(0);
      if (!($524)) {
       ___clang_call_terminate($521);
       // unreachable;
      }
      $525 = HEAP32[$15>>2]|0;
      __ZdlPv($525);
      ___clang_call_terminate($521);
      // unreachable;
     }
    }
   }
   HEAP32[$16>>2] = 0;
   $518 = HEAP8[$17>>0]|0;
   $519 = ($518<<24>>24)<(0);
   if (!($519)) {
    ___resumeException($509|0);
    // unreachable;
   }
   $520 = HEAP32[$15>>2]|0;
   __ZdlPv($520);
   ___resumeException($509|0);
   // unreachable;
   break;
  }
  case 259: {
   STACKTOP = sp;return;
   break;
  }
 }
}
function __ZNSt3__26__treeIPN5osgDB7ArchiveENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 } else {
  $3 = HEAP32[$1>>2]|0;
  __ZNSt3__26__treeIPN5osgDB7ArchiveENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($0,$3);
  $4 = ((($1)) + 4|0);
  $5 = HEAP32[$4>>2]|0;
  __ZNSt3__26__treeIPN5osgDB7ArchiveENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($0,$5);
  __ZdlPv($1);
  return;
 }
}
function __ZNSt3__213__vector_baseIN5osgDB12ReaderWriter10ReadResultENS_9allocatorIS3_EEED2Ev($0) {
 $0 = $0|0;
 var $$pre = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 }
 $3 = ((($0)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==($1|0);
 do {
  if ($5) {
   $30 = $1;
  } else {
   $7 = $4;
   while(1) {
    $6 = ((($7)) + -20|0);
    HEAP32[$3>>2] = $6;
    $8 = ((($7)) + -4|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = ($9|0)==(0|0);
    if (!($10)) {
     $11 = ((($9)) + 8|0);
     $12 = HEAP32[$11>>2]|0;HEAP32[$11>>2] = (($12-1)|0);
     $13 = ($12|0)==(1);
     if ($13) {
      __THREW__ = 0;
      invoke_viii(3262,($9|0),1,1);
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if ($15) {
       break;
      }
     }
    }
    HEAP32[$8>>2] = 0;
    $16 = ((($7)) + -16|0);
    $17 = ((($16)) + 11|0);
    $18 = HEAP8[$17>>0]|0;
    $19 = ($18<<24>>24)<(0);
    if ($19) {
     $22 = HEAP32[$16>>2]|0;
     __ZdlPv($22);
    }
    $20 = HEAP32[$3>>2]|0;
    $21 = ($20|0)==($1|0);
    if ($21) {
     label = 12;
     break;
    } else {
     $7 = $20;
    }
   }
   if ((label|0) == 12) {
    $$pre = HEAP32[$0>>2]|0;
    $30 = $$pre;
    break;
   }
   $23 = ___cxa_find_matching_catch_2()|0;
   $24 = tempRet0;
   $25 = ((($7)) + -16|0);
   $26 = ((($25)) + 11|0);
   $27 = HEAP8[$26>>0]|0;
   $28 = ($27<<24>>24)<(0);
   if (!($28)) {
    ___cxa_call_unexpected(($23|0));
    // unreachable;
   }
   $29 = HEAP32[$25>>2]|0;
   __ZdlPv($29);
   ___cxa_call_unexpected(($23|0));
   // unreachable;
  }
 } while(0);
 __ZdlPv($30);
 return;
}
function __ZNSt3__27__sort3IRNS_6__lessIN5osgDB12ReaderWriter10ReadResultES4_EEPS4_EEjT0_S8_S8_T_($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$026 = 0, $$pr$i = 0, $$pr$i31 = 0, $$pr$i42 = 0, $$pr$i53 = 0, $$pr$i64 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0;
 var $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0;
 var $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0;
 var $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0;
 var $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0;
 var $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0;
 var $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0;
 var $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0;
 var $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0;
 var $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0;
 var $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0;
 var $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0;
 var $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(112|0);
 $4 = sp + 80|0;
 $5 = sp + 60|0;
 $6 = sp + 40|0;
 $7 = sp + 20|0;
 $8 = sp;
 $9 = HEAP32[$1>>2]|0;
 $10 = HEAP32[$0>>2]|0;
 $11 = ($9|0)<($10|0);
 $12 = HEAP32[$2>>2]|0;
 $13 = ($12|0)<($9|0);
 if (!($11)) {
  if (!($13)) {
   $$026 = 0;
   STACKTOP = sp;return ($$026|0);
  }
  HEAP32[$7>>2] = $9;
  $14 = ((($7)) + 4|0);
  $15 = ((($1)) + 4|0);
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_($14,$15);
  $16 = ((($7)) + 16|0);
  $17 = ((($1)) + 16|0);
  $18 = HEAP32[$17>>2]|0;
  HEAP32[$16>>2] = $18;
  $19 = ($18|0)==(0|0);
  if (!($19)) {
   $20 = ((($18)) + 8|0);
   $21 = HEAP32[$20>>2]|0;HEAP32[$20>>2] = (($21+1)|0);
  }
  $22 = ($1|0)==($2|0);
  if ($22) {
   label = 13;
  } else {
   $23 = HEAP32[$2>>2]|0;
   HEAP32[$1>>2] = $23;
   $24 = ((($2)) + 4|0);
   __THREW__ = 0;
   (invoke_iii(3477,($15|0),($24|0))|0);
   $25 = __THREW__; __THREW__ = 0;
   $26 = $25&1;
   if (!($26)) {
    $27 = HEAP32[$17>>2]|0;
    $28 = ((($2)) + 16|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = ($27|0)==($29|0);
    if ($30) {
     label = 13;
    } else {
     HEAP32[$17>>2] = $29;
     $31 = ($29|0)==(0|0);
     if (!($31)) {
      $32 = ((($29)) + 8|0);
      $33 = HEAP32[$32>>2]|0;HEAP32[$32>>2] = (($33+1)|0);
     }
     $34 = ($27|0)==(0|0);
     if ($34) {
      label = 13;
     } else {
      $35 = ((($27)) + 8|0);
      $36 = HEAP32[$35>>2]|0;HEAP32[$35>>2] = (($36-1)|0);
      $37 = ($36|0)==(1);
      if ($37) {
       __THREW__ = 0;
       invoke_viii(3262,($27|0),1,1);
       $38 = __THREW__; __THREW__ = 0;
       $39 = $38&1;
       if (!($39)) {
        label = 13;
       }
      } else {
       label = 13;
      }
     }
    }
   }
  }
  do {
   if ((label|0) == 13) {
    $40 = ($7|0)==($2|0);
    if ($40) {
     label = 21;
    } else {
     $41 = HEAP32[$7>>2]|0;
     HEAP32[$2>>2] = $41;
     $42 = ((($2)) + 4|0);
     __THREW__ = 0;
     (invoke_iii(3477,($42|0),($14|0))|0);
     $43 = __THREW__; __THREW__ = 0;
     $44 = $43&1;
     if ($44) {
      break;
     }
     $45 = ((($2)) + 16|0);
     $46 = HEAP32[$45>>2]|0;
     $47 = HEAP32[$16>>2]|0;
     $48 = ($46|0)==($47|0);
     if ($48) {
      $58 = $46;
     } else {
      HEAP32[$45>>2] = $47;
      $49 = ($47|0)==(0|0);
      if (!($49)) {
       $50 = ((($47)) + 8|0);
       $51 = HEAP32[$50>>2]|0;HEAP32[$50>>2] = (($51+1)|0);
      }
      $52 = ($46|0)==(0|0);
      if ($52) {
       label = 21;
      } else {
       $53 = ((($46)) + 8|0);
       $54 = HEAP32[$53>>2]|0;HEAP32[$53>>2] = (($54-1)|0);
       $55 = ($54|0)==(1);
       if ($55) {
        __THREW__ = 0;
        invoke_viii(3262,($46|0),1,1);
        $56 = __THREW__; __THREW__ = 0;
        $57 = $56&1;
        if ($57) {
         break;
        } else {
         label = 21;
        }
       } else {
        label = 21;
       }
      }
     }
    }
    if ((label|0) == 21) {
     $$pr$i31 = HEAP32[$16>>2]|0;
     $58 = $$pr$i31;
    }
    $59 = ($58|0)==(0|0);
    if (!($59)) {
     $60 = ((($58)) + 8|0);
     $61 = HEAP32[$60>>2]|0;HEAP32[$60>>2] = (($61-1)|0);
     $62 = ($61|0)==(1);
     if ($62) {
      __THREW__ = 0;
      invoke_viii(3262,($58|0),1,1);
      $63 = __THREW__; __THREW__ = 0;
      $64 = $63&1;
      if ($64) {
       $69 = ___cxa_find_matching_catch_2()|0;
       $70 = tempRet0;
       $71 = ((($14)) + 11|0);
       $72 = HEAP8[$71>>0]|0;
       $73 = ($72<<24>>24)<(0);
       if (!($73)) {
        ___resumeException($69|0);
        // unreachable;
       }
       $74 = HEAP32[$14>>2]|0;
       __ZdlPv($74);
       ___resumeException($69|0);
       // unreachable;
      }
     }
    }
    HEAP32[$16>>2] = 0;
    $65 = ((($14)) + 11|0);
    $66 = HEAP8[$65>>0]|0;
    $67 = ($66<<24>>24)<(0);
    if ($67) {
     $68 = HEAP32[$14>>2]|0;
     __ZdlPv($68);
    }
    $94 = HEAP32[$1>>2]|0;
    $95 = HEAP32[$0>>2]|0;
    $96 = ($94|0)<($95|0);
    if (!($96)) {
     $$026 = 1;
     STACKTOP = sp;return ($$026|0);
    }
    HEAP32[$6>>2] = $95;
    $97 = ((($6)) + 4|0);
    $98 = ((($0)) + 4|0);
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_($97,$98);
    $99 = ((($6)) + 16|0);
    $100 = ((($0)) + 16|0);
    $101 = HEAP32[$100>>2]|0;
    HEAP32[$99>>2] = $101;
    $102 = ($101|0)==(0|0);
    if (!($102)) {
     $103 = ((($101)) + 8|0);
     $104 = HEAP32[$103>>2]|0;HEAP32[$103>>2] = (($104+1)|0);
    }
    $105 = ($0|0)==($1|0);
    if ($105) {
     label = 50;
    } else {
     $106 = HEAP32[$1>>2]|0;
     HEAP32[$0>>2] = $106;
     __THREW__ = 0;
     (invoke_iii(3477,($98|0),($15|0))|0);
     $107 = __THREW__; __THREW__ = 0;
     $108 = $107&1;
     if (!($108)) {
      $109 = HEAP32[$100>>2]|0;
      $110 = HEAP32[$17>>2]|0;
      $111 = ($109|0)==($110|0);
      if ($111) {
       label = 50;
      } else {
       HEAP32[$100>>2] = $110;
       $112 = ($110|0)==(0|0);
       if (!($112)) {
        $113 = ((($110)) + 8|0);
        $114 = HEAP32[$113>>2]|0;HEAP32[$113>>2] = (($114+1)|0);
       }
       $115 = ($109|0)==(0|0);
       if ($115) {
        label = 50;
       } else {
        $116 = ((($109)) + 8|0);
        $117 = HEAP32[$116>>2]|0;HEAP32[$116>>2] = (($117-1)|0);
        $118 = ($117|0)==(1);
        if ($118) {
         __THREW__ = 0;
         invoke_viii(3262,($109|0),1,1);
         $119 = __THREW__; __THREW__ = 0;
         $120 = $119&1;
         if (!($120)) {
          label = 50;
         }
        } else {
         label = 50;
        }
       }
      }
     }
    }
    do {
     if ((label|0) == 50) {
      $121 = ($6|0)==($1|0);
      if ($121) {
       label = 58;
      } else {
       $122 = HEAP32[$6>>2]|0;
       HEAP32[$1>>2] = $122;
       __THREW__ = 0;
       (invoke_iii(3477,($15|0),($97|0))|0);
       $123 = __THREW__; __THREW__ = 0;
       $124 = $123&1;
       if ($124) {
        break;
       }
       $125 = HEAP32[$17>>2]|0;
       $126 = HEAP32[$99>>2]|0;
       $127 = ($125|0)==($126|0);
       if ($127) {
        $137 = $125;
       } else {
        HEAP32[$17>>2] = $126;
        $128 = ($126|0)==(0|0);
        if (!($128)) {
         $129 = ((($126)) + 8|0);
         $130 = HEAP32[$129>>2]|0;HEAP32[$129>>2] = (($130+1)|0);
        }
        $131 = ($125|0)==(0|0);
        if ($131) {
         label = 58;
        } else {
         $132 = ((($125)) + 8|0);
         $133 = HEAP32[$132>>2]|0;HEAP32[$132>>2] = (($133-1)|0);
         $134 = ($133|0)==(1);
         if ($134) {
          __THREW__ = 0;
          invoke_viii(3262,($125|0),1,1);
          $135 = __THREW__; __THREW__ = 0;
          $136 = $135&1;
          if ($136) {
           break;
          } else {
           label = 58;
          }
         } else {
          label = 58;
         }
        }
       }
      }
      if ((label|0) == 58) {
       $$pr$i42 = HEAP32[$99>>2]|0;
       $137 = $$pr$i42;
      }
      $138 = ($137|0)==(0|0);
      if (!($138)) {
       $139 = ((($137)) + 8|0);
       $140 = HEAP32[$139>>2]|0;HEAP32[$139>>2] = (($140-1)|0);
       $141 = ($140|0)==(1);
       if ($141) {
        __THREW__ = 0;
        invoke_viii(3262,($137|0),1,1);
        $142 = __THREW__; __THREW__ = 0;
        $143 = $142&1;
        if ($143) {
         $148 = ___cxa_find_matching_catch_2()|0;
         $149 = tempRet0;
         $150 = ((($97)) + 11|0);
         $151 = HEAP8[$150>>0]|0;
         $152 = ($151<<24>>24)<(0);
         if (!($152)) {
          ___resumeException($148|0);
          // unreachable;
         }
         $153 = HEAP32[$97>>2]|0;
         __ZdlPv($153);
         ___resumeException($148|0);
         // unreachable;
        }
       }
      }
      HEAP32[$99>>2] = 0;
      $144 = ((($97)) + 11|0);
      $145 = HEAP8[$144>>0]|0;
      $146 = ($145<<24>>24)<(0);
      if ($146) {
       $147 = HEAP32[$97>>2]|0;
       __ZdlPv($147);
      }
      $$026 = 2;
      STACKTOP = sp;return ($$026|0);
     }
    } while(0);
    $154 = ___cxa_find_matching_catch_2()|0;
    $155 = tempRet0;
    $156 = HEAP32[$99>>2]|0;
    $157 = ($156|0)==(0|0);
    if (!($157)) {
     $158 = ((($156)) + 8|0);
     $159 = HEAP32[$158>>2]|0;HEAP32[$158>>2] = (($159-1)|0);
     $160 = ($159|0)==(1);
     if ($160) {
      __THREW__ = 0;
      invoke_viii(3262,($156|0),1,1);
      $161 = __THREW__; __THREW__ = 0;
      $162 = $161&1;
      if ($162) {
       $167 = ___cxa_find_matching_catch_3(0|0)|0;
       $168 = tempRet0;
       $169 = ((($97)) + 11|0);
       $170 = HEAP8[$169>>0]|0;
       $171 = ($170<<24>>24)<(0);
       if (!($171)) {
        ___clang_call_terminate($167);
        // unreachable;
       }
       $172 = HEAP32[$97>>2]|0;
       __ZdlPv($172);
       ___clang_call_terminate($167);
       // unreachable;
      }
     }
    }
    HEAP32[$99>>2] = 0;
    $163 = ((($97)) + 11|0);
    $164 = HEAP8[$163>>0]|0;
    $165 = ($164<<24>>24)<(0);
    if (!($165)) {
     ___resumeException($154|0);
     // unreachable;
    }
    $166 = HEAP32[$97>>2]|0;
    __ZdlPv($166);
    ___resumeException($154|0);
    // unreachable;
   }
  } while(0);
  $75 = ___cxa_find_matching_catch_2()|0;
  $76 = tempRet0;
  $77 = HEAP32[$16>>2]|0;
  $78 = ($77|0)==(0|0);
  if (!($78)) {
   $79 = ((($77)) + 8|0);
   $80 = HEAP32[$79>>2]|0;HEAP32[$79>>2] = (($80-1)|0);
   $81 = ($80|0)==(1);
   if ($81) {
    __THREW__ = 0;
    invoke_viii(3262,($77|0),1,1);
    $82 = __THREW__; __THREW__ = 0;
    $83 = $82&1;
    if ($83) {
     $88 = ___cxa_find_matching_catch_3(0|0)|0;
     $89 = tempRet0;
     $90 = ((($14)) + 11|0);
     $91 = HEAP8[$90>>0]|0;
     $92 = ($91<<24>>24)<(0);
     if (!($92)) {
      ___clang_call_terminate($88);
      // unreachable;
     }
     $93 = HEAP32[$14>>2]|0;
     __ZdlPv($93);
     ___clang_call_terminate($88);
     // unreachable;
    }
   }
  }
  HEAP32[$16>>2] = 0;
  $84 = ((($14)) + 11|0);
  $85 = HEAP8[$84>>0]|0;
  $86 = ($85<<24>>24)<(0);
  if (!($86)) {
   ___resumeException($75|0);
   // unreachable;
  }
  $87 = HEAP32[$14>>2]|0;
  __ZdlPv($87);
  ___resumeException($75|0);
  // unreachable;
 }
 if ($13) {
  HEAP32[$5>>2] = $10;
  $173 = ((($5)) + 4|0);
  $174 = ((($0)) + 4|0);
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_($173,$174);
  $175 = ((($5)) + 16|0);
  $176 = ((($0)) + 16|0);
  $177 = HEAP32[$176>>2]|0;
  HEAP32[$175>>2] = $177;
  $178 = ($177|0)==(0|0);
  if (!($178)) {
   $179 = ((($177)) + 8|0);
   $180 = HEAP32[$179>>2]|0;HEAP32[$179>>2] = (($180+1)|0);
  }
  $181 = ($0|0)==($2|0);
  if ($181) {
   label = 88;
  } else {
   $182 = HEAP32[$2>>2]|0;
   HEAP32[$0>>2] = $182;
   $183 = ((($2)) + 4|0);
   __THREW__ = 0;
   (invoke_iii(3477,($174|0),($183|0))|0);
   $184 = __THREW__; __THREW__ = 0;
   $185 = $184&1;
   if (!($185)) {
    $186 = HEAP32[$176>>2]|0;
    $187 = ((($2)) + 16|0);
    $188 = HEAP32[$187>>2]|0;
    $189 = ($186|0)==($188|0);
    if ($189) {
     label = 88;
    } else {
     HEAP32[$176>>2] = $188;
     $190 = ($188|0)==(0|0);
     if (!($190)) {
      $191 = ((($188)) + 8|0);
      $192 = HEAP32[$191>>2]|0;HEAP32[$191>>2] = (($192+1)|0);
     }
     $193 = ($186|0)==(0|0);
     if ($193) {
      label = 88;
     } else {
      $194 = ((($186)) + 8|0);
      $195 = HEAP32[$194>>2]|0;HEAP32[$194>>2] = (($195-1)|0);
      $196 = ($195|0)==(1);
      if ($196) {
       __THREW__ = 0;
       invoke_viii(3262,($186|0),1,1);
       $197 = __THREW__; __THREW__ = 0;
       $198 = $197&1;
       if (!($198)) {
        label = 88;
       }
      } else {
       label = 88;
      }
     }
    }
   }
  }
  do {
   if ((label|0) == 88) {
    $199 = ($5|0)==($2|0);
    if ($199) {
     label = 96;
    } else {
     $200 = HEAP32[$5>>2]|0;
     HEAP32[$2>>2] = $200;
     $201 = ((($2)) + 4|0);
     __THREW__ = 0;
     (invoke_iii(3477,($201|0),($173|0))|0);
     $202 = __THREW__; __THREW__ = 0;
     $203 = $202&1;
     if ($203) {
      break;
     }
     $204 = ((($2)) + 16|0);
     $205 = HEAP32[$204>>2]|0;
     $206 = HEAP32[$175>>2]|0;
     $207 = ($205|0)==($206|0);
     if ($207) {
      $217 = $205;
     } else {
      HEAP32[$204>>2] = $206;
      $208 = ($206|0)==(0|0);
      if (!($208)) {
       $209 = ((($206)) + 8|0);
       $210 = HEAP32[$209>>2]|0;HEAP32[$209>>2] = (($210+1)|0);
      }
      $211 = ($205|0)==(0|0);
      if ($211) {
       label = 96;
      } else {
       $212 = ((($205)) + 8|0);
       $213 = HEAP32[$212>>2]|0;HEAP32[$212>>2] = (($213-1)|0);
       $214 = ($213|0)==(1);
       if ($214) {
        __THREW__ = 0;
        invoke_viii(3262,($205|0),1,1);
        $215 = __THREW__; __THREW__ = 0;
        $216 = $215&1;
        if ($216) {
         break;
        } else {
         label = 96;
        }
       } else {
        label = 96;
       }
      }
     }
    }
    if ((label|0) == 96) {
     $$pr$i53 = HEAP32[$175>>2]|0;
     $217 = $$pr$i53;
    }
    $218 = ($217|0)==(0|0);
    if (!($218)) {
     $219 = ((($217)) + 8|0);
     $220 = HEAP32[$219>>2]|0;HEAP32[$219>>2] = (($220-1)|0);
     $221 = ($220|0)==(1);
     if ($221) {
      __THREW__ = 0;
      invoke_viii(3262,($217|0),1,1);
      $222 = __THREW__; __THREW__ = 0;
      $223 = $222&1;
      if ($223) {
       $228 = ___cxa_find_matching_catch_2()|0;
       $229 = tempRet0;
       $230 = ((($173)) + 11|0);
       $231 = HEAP8[$230>>0]|0;
       $232 = ($231<<24>>24)<(0);
       if (!($232)) {
        ___resumeException($228|0);
        // unreachable;
       }
       $233 = HEAP32[$173>>2]|0;
       __ZdlPv($233);
       ___resumeException($228|0);
       // unreachable;
      }
     }
    }
    HEAP32[$175>>2] = 0;
    $224 = ((($173)) + 11|0);
    $225 = HEAP8[$224>>0]|0;
    $226 = ($225<<24>>24)<(0);
    if ($226) {
     $227 = HEAP32[$173>>2]|0;
     __ZdlPv($227);
    }
    $$026 = 1;
    STACKTOP = sp;return ($$026|0);
   }
  } while(0);
  $234 = ___cxa_find_matching_catch_2()|0;
  $235 = tempRet0;
  $236 = HEAP32[$175>>2]|0;
  $237 = ($236|0)==(0|0);
  if (!($237)) {
   $238 = ((($236)) + 8|0);
   $239 = HEAP32[$238>>2]|0;HEAP32[$238>>2] = (($239-1)|0);
   $240 = ($239|0)==(1);
   if ($240) {
    __THREW__ = 0;
    invoke_viii(3262,($236|0),1,1);
    $241 = __THREW__; __THREW__ = 0;
    $242 = $241&1;
    if ($242) {
     $247 = ___cxa_find_matching_catch_3(0|0)|0;
     $248 = tempRet0;
     $249 = ((($173)) + 11|0);
     $250 = HEAP8[$249>>0]|0;
     $251 = ($250<<24>>24)<(0);
     if (!($251)) {
      ___clang_call_terminate($247);
      // unreachable;
     }
     $252 = HEAP32[$173>>2]|0;
     __ZdlPv($252);
     ___clang_call_terminate($247);
     // unreachable;
    }
   }
  }
  HEAP32[$175>>2] = 0;
  $243 = ((($173)) + 11|0);
  $244 = HEAP8[$243>>0]|0;
  $245 = ($244<<24>>24)<(0);
  if (!($245)) {
   ___resumeException($234|0);
   // unreachable;
  }
  $246 = HEAP32[$173>>2]|0;
  __ZdlPv($246);
  ___resumeException($234|0);
  // unreachable;
 }
 HEAP32[$4>>2] = $10;
 $253 = ((($4)) + 4|0);
 $254 = ((($0)) + 4|0);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_($253,$254);
 $255 = ((($4)) + 16|0);
 $256 = ((($0)) + 16|0);
 $257 = HEAP32[$256>>2]|0;
 HEAP32[$255>>2] = $257;
 $258 = ($257|0)==(0|0);
 if (!($258)) {
  $259 = ((($257)) + 8|0);
  $260 = HEAP32[$259>>2]|0;HEAP32[$259>>2] = (($260+1)|0);
 }
 $261 = ($0|0)==($1|0);
 if ($261) {
  label = 125;
 } else {
  $262 = HEAP32[$1>>2]|0;
  HEAP32[$0>>2] = $262;
  $263 = ((($1)) + 4|0);
  __THREW__ = 0;
  (invoke_iii(3477,($254|0),($263|0))|0);
  $264 = __THREW__; __THREW__ = 0;
  $265 = $264&1;
  if (!($265)) {
   $266 = HEAP32[$256>>2]|0;
   $267 = ((($1)) + 16|0);
   $268 = HEAP32[$267>>2]|0;
   $269 = ($266|0)==($268|0);
   if ($269) {
    label = 125;
   } else {
    HEAP32[$256>>2] = $268;
    $270 = ($268|0)==(0|0);
    if (!($270)) {
     $271 = ((($268)) + 8|0);
     $272 = HEAP32[$271>>2]|0;HEAP32[$271>>2] = (($272+1)|0);
    }
    $273 = ($266|0)==(0|0);
    if ($273) {
     label = 125;
    } else {
     $274 = ((($266)) + 8|0);
     $275 = HEAP32[$274>>2]|0;HEAP32[$274>>2] = (($275-1)|0);
     $276 = ($275|0)==(1);
     if ($276) {
      __THREW__ = 0;
      invoke_viii(3262,($266|0),1,1);
      $277 = __THREW__; __THREW__ = 0;
      $278 = $277&1;
      if (!($278)) {
       label = 125;
      }
     } else {
      label = 125;
     }
    }
   }
  }
 }
 do {
  if ((label|0) == 125) {
   $279 = ($4|0)==($1|0);
   if ($279) {
    label = 133;
   } else {
    $280 = HEAP32[$4>>2]|0;
    HEAP32[$1>>2] = $280;
    $281 = ((($1)) + 4|0);
    __THREW__ = 0;
    (invoke_iii(3477,($281|0),($253|0))|0);
    $282 = __THREW__; __THREW__ = 0;
    $283 = $282&1;
    if ($283) {
     break;
    }
    $284 = ((($1)) + 16|0);
    $285 = HEAP32[$284>>2]|0;
    $286 = HEAP32[$255>>2]|0;
    $287 = ($285|0)==($286|0);
    if ($287) {
     $297 = $285;
    } else {
     HEAP32[$284>>2] = $286;
     $288 = ($286|0)==(0|0);
     if (!($288)) {
      $289 = ((($286)) + 8|0);
      $290 = HEAP32[$289>>2]|0;HEAP32[$289>>2] = (($290+1)|0);
     }
     $291 = ($285|0)==(0|0);
     if ($291) {
      label = 133;
     } else {
      $292 = ((($285)) + 8|0);
      $293 = HEAP32[$292>>2]|0;HEAP32[$292>>2] = (($293-1)|0);
      $294 = ($293|0)==(1);
      if ($294) {
       __THREW__ = 0;
       invoke_viii(3262,($285|0),1,1);
       $295 = __THREW__; __THREW__ = 0;
       $296 = $295&1;
       if ($296) {
        break;
       } else {
        label = 133;
       }
      } else {
       label = 133;
      }
     }
    }
   }
   if ((label|0) == 133) {
    $$pr$i64 = HEAP32[$255>>2]|0;
    $297 = $$pr$i64;
   }
   $298 = ($297|0)==(0|0);
   if (!($298)) {
    $299 = ((($297)) + 8|0);
    $300 = HEAP32[$299>>2]|0;HEAP32[$299>>2] = (($300-1)|0);
    $301 = ($300|0)==(1);
    if ($301) {
     __THREW__ = 0;
     invoke_viii(3262,($297|0),1,1);
     $302 = __THREW__; __THREW__ = 0;
     $303 = $302&1;
     if ($303) {
      $308 = ___cxa_find_matching_catch_2()|0;
      $309 = tempRet0;
      $310 = ((($253)) + 11|0);
      $311 = HEAP8[$310>>0]|0;
      $312 = ($311<<24>>24)<(0);
      if (!($312)) {
       ___resumeException($308|0);
       // unreachable;
      }
      $313 = HEAP32[$253>>2]|0;
      __ZdlPv($313);
      ___resumeException($308|0);
      // unreachable;
     }
    }
   }
   HEAP32[$255>>2] = 0;
   $304 = ((($253)) + 11|0);
   $305 = HEAP8[$304>>0]|0;
   $306 = ($305<<24>>24)<(0);
   if ($306) {
    $307 = HEAP32[$253>>2]|0;
    __ZdlPv($307);
   }
   $333 = HEAP32[$2>>2]|0;
   $334 = HEAP32[$1>>2]|0;
   $335 = ($333|0)<($334|0);
   if (!($335)) {
    $$026 = 1;
    STACKTOP = sp;return ($$026|0);
   }
   HEAP32[$8>>2] = $334;
   $336 = ((($8)) + 4|0);
   $337 = ((($1)) + 4|0);
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_($336,$337);
   $338 = ((($8)) + 16|0);
   $339 = ((($1)) + 16|0);
   $340 = HEAP32[$339>>2]|0;
   HEAP32[$338>>2] = $340;
   $341 = ($340|0)==(0|0);
   if (!($341)) {
    $342 = ((($340)) + 8|0);
    $343 = HEAP32[$342>>2]|0;HEAP32[$342>>2] = (($343+1)|0);
   }
   $344 = ($1|0)==($2|0);
   if ($344) {
    label = 162;
   } else {
    $345 = HEAP32[$2>>2]|0;
    HEAP32[$1>>2] = $345;
    $346 = ((($2)) + 4|0);
    __THREW__ = 0;
    (invoke_iii(3477,($337|0),($346|0))|0);
    $347 = __THREW__; __THREW__ = 0;
    $348 = $347&1;
    if (!($348)) {
     $349 = HEAP32[$339>>2]|0;
     $350 = ((($2)) + 16|0);
     $351 = HEAP32[$350>>2]|0;
     $352 = ($349|0)==($351|0);
     if ($352) {
      label = 162;
     } else {
      HEAP32[$339>>2] = $351;
      $353 = ($351|0)==(0|0);
      if (!($353)) {
       $354 = ((($351)) + 8|0);
       $355 = HEAP32[$354>>2]|0;HEAP32[$354>>2] = (($355+1)|0);
      }
      $356 = ($349|0)==(0|0);
      if ($356) {
       label = 162;
      } else {
       $357 = ((($349)) + 8|0);
       $358 = HEAP32[$357>>2]|0;HEAP32[$357>>2] = (($358-1)|0);
       $359 = ($358|0)==(1);
       if ($359) {
        __THREW__ = 0;
        invoke_viii(3262,($349|0),1,1);
        $360 = __THREW__; __THREW__ = 0;
        $361 = $360&1;
        if (!($361)) {
         label = 162;
        }
       } else {
        label = 162;
       }
      }
     }
    }
   }
   do {
    if ((label|0) == 162) {
     $362 = ($8|0)==($2|0);
     if ($362) {
      label = 170;
     } else {
      $363 = HEAP32[$8>>2]|0;
      HEAP32[$2>>2] = $363;
      $364 = ((($2)) + 4|0);
      __THREW__ = 0;
      (invoke_iii(3477,($364|0),($336|0))|0);
      $365 = __THREW__; __THREW__ = 0;
      $366 = $365&1;
      if ($366) {
       break;
      }
      $367 = ((($2)) + 16|0);
      $368 = HEAP32[$367>>2]|0;
      $369 = HEAP32[$338>>2]|0;
      $370 = ($368|0)==($369|0);
      if ($370) {
       $380 = $368;
      } else {
       HEAP32[$367>>2] = $369;
       $371 = ($369|0)==(0|0);
       if (!($371)) {
        $372 = ((($369)) + 8|0);
        $373 = HEAP32[$372>>2]|0;HEAP32[$372>>2] = (($373+1)|0);
       }
       $374 = ($368|0)==(0|0);
       if ($374) {
        label = 170;
       } else {
        $375 = ((($368)) + 8|0);
        $376 = HEAP32[$375>>2]|0;HEAP32[$375>>2] = (($376-1)|0);
        $377 = ($376|0)==(1);
        if ($377) {
         __THREW__ = 0;
         invoke_viii(3262,($368|0),1,1);
         $378 = __THREW__; __THREW__ = 0;
         $379 = $378&1;
         if ($379) {
          break;
         } else {
          label = 170;
         }
        } else {
         label = 170;
        }
       }
      }
     }
     if ((label|0) == 170) {
      $$pr$i = HEAP32[$338>>2]|0;
      $380 = $$pr$i;
     }
     $381 = ($380|0)==(0|0);
     if (!($381)) {
      $382 = ((($380)) + 8|0);
      $383 = HEAP32[$382>>2]|0;HEAP32[$382>>2] = (($383-1)|0);
      $384 = ($383|0)==(1);
      if ($384) {
       __THREW__ = 0;
       invoke_viii(3262,($380|0),1,1);
       $385 = __THREW__; __THREW__ = 0;
       $386 = $385&1;
       if ($386) {
        $391 = ___cxa_find_matching_catch_2()|0;
        $392 = tempRet0;
        $393 = ((($336)) + 11|0);
        $394 = HEAP8[$393>>0]|0;
        $395 = ($394<<24>>24)<(0);
        if (!($395)) {
         ___resumeException($391|0);
         // unreachable;
        }
        $396 = HEAP32[$336>>2]|0;
        __ZdlPv($396);
        ___resumeException($391|0);
        // unreachable;
       }
      }
     }
     HEAP32[$338>>2] = 0;
     $387 = ((($336)) + 11|0);
     $388 = HEAP8[$387>>0]|0;
     $389 = ($388<<24>>24)<(0);
     if ($389) {
      $390 = HEAP32[$336>>2]|0;
      __ZdlPv($390);
     }
     $$026 = 2;
     STACKTOP = sp;return ($$026|0);
    }
   } while(0);
   $397 = ___cxa_find_matching_catch_2()|0;
   $398 = tempRet0;
   $399 = HEAP32[$338>>2]|0;
   $400 = ($399|0)==(0|0);
   if (!($400)) {
    $401 = ((($399)) + 8|0);
    $402 = HEAP32[$401>>2]|0;HEAP32[$401>>2] = (($402-1)|0);
    $403 = ($402|0)==(1);
    if ($403) {
     __THREW__ = 0;
     invoke_viii(3262,($399|0),1,1);
     $404 = __THREW__; __THREW__ = 0;
     $405 = $404&1;
     if ($405) {
      $410 = ___cxa_find_matching_catch_3(0|0)|0;
      $411 = tempRet0;
      $412 = ((($336)) + 11|0);
      $413 = HEAP8[$412>>0]|0;
      $414 = ($413<<24>>24)<(0);
      if (!($414)) {
       ___clang_call_terminate($410);
       // unreachable;
      }
      $415 = HEAP32[$336>>2]|0;
      __ZdlPv($415);
      ___clang_call_terminate($410);
      // unreachable;
     }
    }
   }
   HEAP32[$338>>2] = 0;
   $406 = ((($336)) + 11|0);
   $407 = HEAP8[$406>>0]|0;
   $408 = ($407<<24>>24)<(0);
   if (!($408)) {
    ___resumeException($397|0);
    // unreachable;
   }
   $409 = HEAP32[$336>>2]|0;
   __ZdlPv($409);
   ___resumeException($397|0);
   // unreachable;
  }
 } while(0);
 $314 = ___cxa_find_matching_catch_2()|0;
 $315 = tempRet0;
 $316 = HEAP32[$255>>2]|0;
 $317 = ($316|0)==(0|0);
 if (!($317)) {
  $318 = ((($316)) + 8|0);
  $319 = HEAP32[$318>>2]|0;HEAP32[$318>>2] = (($319-1)|0);
  $320 = ($319|0)==(1);
  if ($320) {
   __THREW__ = 0;
   invoke_viii(3262,($316|0),1,1);
   $321 = __THREW__; __THREW__ = 0;
   $322 = $321&1;
   if ($322) {
    $327 = ___cxa_find_matching_catch_3(0|0)|0;
    $328 = tempRet0;
    $329 = ((($253)) + 11|0);
    $330 = HEAP8[$329>>0]|0;
    $331 = ($330<<24>>24)<(0);
    if (!($331)) {
     ___clang_call_terminate($327);
     // unreachable;
    }
    $332 = HEAP32[$253>>2]|0;
    __ZdlPv($332);
    ___clang_call_terminate($327);
    // unreachable;
   }
  }
 }
 HEAP32[$255>>2] = 0;
 $323 = ((($253)) + 11|0);
 $324 = HEAP8[$323>>0]|0;
 $325 = ($324<<24>>24)<(0);
 if (!($325)) {
  ___resumeException($314|0);
  // unreachable;
 }
 $326 = HEAP32[$253>>2]|0;
 __ZdlPv($326);
 ___resumeException($314|0);
 // unreachable;
 return (0)|0;
}
function __ZNSt3__27__sort4IRNS_6__lessIN5osgDB12ReaderWriter10ReadResultES4_EEPS4_EEjT0_S8_S8_S8_T_($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0 = 0, $$pr$i = 0, $$pr$i27 = 0, $$pr$i38 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0;
 var $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0;
 var $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0;
 var $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(64|0);
 $5 = sp + 40|0;
 $6 = sp + 20|0;
 $7 = sp;
 $8 = (__ZNSt3__27__sort3IRNS_6__lessIN5osgDB12ReaderWriter10ReadResultES4_EEPS4_EEjT0_S8_S8_T_($0,$1,$2,$4)|0);
 $9 = HEAP32[$3>>2]|0;
 $10 = HEAP32[$2>>2]|0;
 $11 = ($9|0)<($10|0);
 if (!($11)) {
  $$0 = $8;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$6>>2] = $10;
 $12 = ((($6)) + 4|0);
 $13 = ((($2)) + 4|0);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_($12,$13);
 $14 = ((($6)) + 16|0);
 $15 = ((($2)) + 16|0);
 $16 = HEAP32[$15>>2]|0;
 HEAP32[$14>>2] = $16;
 $17 = ($16|0)==(0|0);
 if (!($17)) {
  $18 = ((($16)) + 8|0);
  $19 = HEAP32[$18>>2]|0;HEAP32[$18>>2] = (($19+1)|0);
 }
 $20 = ($2|0)==($3|0);
 if ($20) {
  label = 12;
 } else {
  $21 = HEAP32[$3>>2]|0;
  HEAP32[$2>>2] = $21;
  $22 = ((($3)) + 4|0);
  __THREW__ = 0;
  (invoke_iii(3477,($13|0),($22|0))|0);
  $23 = __THREW__; __THREW__ = 0;
  $24 = $23&1;
  if (!($24)) {
   $25 = HEAP32[$15>>2]|0;
   $26 = ((($3)) + 16|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = ($25|0)==($27|0);
   if ($28) {
    label = 12;
   } else {
    HEAP32[$15>>2] = $27;
    $29 = ($27|0)==(0|0);
    if (!($29)) {
     $30 = ((($27)) + 8|0);
     $31 = HEAP32[$30>>2]|0;HEAP32[$30>>2] = (($31+1)|0);
    }
    $32 = ($25|0)==(0|0);
    if ($32) {
     label = 12;
    } else {
     $33 = ((($25)) + 8|0);
     $34 = HEAP32[$33>>2]|0;HEAP32[$33>>2] = (($34-1)|0);
     $35 = ($34|0)==(1);
     if ($35) {
      __THREW__ = 0;
      invoke_viii(3262,($25|0),1,1);
      $36 = __THREW__; __THREW__ = 0;
      $37 = $36&1;
      if (!($37)) {
       label = 12;
      }
     } else {
      label = 12;
     }
    }
   }
  }
 }
 do {
  if ((label|0) == 12) {
   $38 = ($6|0)==($3|0);
   if ($38) {
    label = 20;
   } else {
    $39 = HEAP32[$6>>2]|0;
    HEAP32[$3>>2] = $39;
    $40 = ((($3)) + 4|0);
    __THREW__ = 0;
    (invoke_iii(3477,($40|0),($12|0))|0);
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     break;
    }
    $43 = ((($3)) + 16|0);
    $44 = HEAP32[$43>>2]|0;
    $45 = HEAP32[$14>>2]|0;
    $46 = ($44|0)==($45|0);
    if ($46) {
     $56 = $44;
    } else {
     HEAP32[$43>>2] = $45;
     $47 = ($45|0)==(0|0);
     if (!($47)) {
      $48 = ((($45)) + 8|0);
      $49 = HEAP32[$48>>2]|0;HEAP32[$48>>2] = (($49+1)|0);
     }
     $50 = ($44|0)==(0|0);
     if ($50) {
      label = 20;
     } else {
      $51 = ((($44)) + 8|0);
      $52 = HEAP32[$51>>2]|0;HEAP32[$51>>2] = (($52-1)|0);
      $53 = ($52|0)==(1);
      if ($53) {
       __THREW__ = 0;
       invoke_viii(3262,($44|0),1,1);
       $54 = __THREW__; __THREW__ = 0;
       $55 = $54&1;
       if ($55) {
        break;
       } else {
        label = 20;
       }
      } else {
       label = 20;
      }
     }
    }
   }
   if ((label|0) == 20) {
    $$pr$i27 = HEAP32[$14>>2]|0;
    $56 = $$pr$i27;
   }
   $57 = ($56|0)==(0|0);
   if (!($57)) {
    $58 = ((($56)) + 8|0);
    $59 = HEAP32[$58>>2]|0;HEAP32[$58>>2] = (($59-1)|0);
    $60 = ($59|0)==(1);
    if ($60) {
     __THREW__ = 0;
     invoke_viii(3262,($56|0),1,1);
     $61 = __THREW__; __THREW__ = 0;
     $62 = $61&1;
     if ($62) {
      $67 = ___cxa_find_matching_catch_2()|0;
      $68 = tempRet0;
      $69 = ((($12)) + 11|0);
      $70 = HEAP8[$69>>0]|0;
      $71 = ($70<<24>>24)<(0);
      if (!($71)) {
       ___resumeException($67|0);
       // unreachable;
      }
      $72 = HEAP32[$12>>2]|0;
      __ZdlPv($72);
      ___resumeException($67|0);
      // unreachable;
     }
    }
   }
   HEAP32[$14>>2] = 0;
   $63 = ((($12)) + 11|0);
   $64 = HEAP8[$63>>0]|0;
   $65 = ($64<<24>>24)<(0);
   if ($65) {
    $66 = HEAP32[$12>>2]|0;
    __ZdlPv($66);
   }
   $92 = (($8) + 1)|0;
   $93 = HEAP32[$2>>2]|0;
   $94 = HEAP32[$1>>2]|0;
   $95 = ($93|0)<($94|0);
   if (!($95)) {
    $$0 = $92;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$5>>2] = $94;
   $96 = ((($5)) + 4|0);
   $97 = ((($1)) + 4|0);
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_($96,$97);
   $98 = ((($5)) + 16|0);
   $99 = ((($1)) + 16|0);
   $100 = HEAP32[$99>>2]|0;
   HEAP32[$98>>2] = $100;
   $101 = ($100|0)==(0|0);
   if (!($101)) {
    $102 = ((($100)) + 8|0);
    $103 = HEAP32[$102>>2]|0;HEAP32[$102>>2] = (($103+1)|0);
   }
   $104 = ($1|0)==($2|0);
   if ($104) {
    label = 49;
   } else {
    $105 = HEAP32[$2>>2]|0;
    HEAP32[$1>>2] = $105;
    __THREW__ = 0;
    (invoke_iii(3477,($97|0),($13|0))|0);
    $106 = __THREW__; __THREW__ = 0;
    $107 = $106&1;
    if (!($107)) {
     $108 = HEAP32[$99>>2]|0;
     $109 = HEAP32[$15>>2]|0;
     $110 = ($108|0)==($109|0);
     if ($110) {
      label = 49;
     } else {
      HEAP32[$99>>2] = $109;
      $111 = ($109|0)==(0|0);
      if (!($111)) {
       $112 = ((($109)) + 8|0);
       $113 = HEAP32[$112>>2]|0;HEAP32[$112>>2] = (($113+1)|0);
      }
      $114 = ($108|0)==(0|0);
      if ($114) {
       label = 49;
      } else {
       $115 = ((($108)) + 8|0);
       $116 = HEAP32[$115>>2]|0;HEAP32[$115>>2] = (($116-1)|0);
       $117 = ($116|0)==(1);
       if ($117) {
        __THREW__ = 0;
        invoke_viii(3262,($108|0),1,1);
        $118 = __THREW__; __THREW__ = 0;
        $119 = $118&1;
        if (!($119)) {
         label = 49;
        }
       } else {
        label = 49;
       }
      }
     }
    }
   }
   do {
    if ((label|0) == 49) {
     $120 = ($5|0)==($2|0);
     if ($120) {
      label = 57;
     } else {
      $121 = HEAP32[$5>>2]|0;
      HEAP32[$2>>2] = $121;
      __THREW__ = 0;
      (invoke_iii(3477,($13|0),($96|0))|0);
      $122 = __THREW__; __THREW__ = 0;
      $123 = $122&1;
      if ($123) {
       break;
      }
      $124 = HEAP32[$15>>2]|0;
      $125 = HEAP32[$98>>2]|0;
      $126 = ($124|0)==($125|0);
      if ($126) {
       $136 = $124;
      } else {
       HEAP32[$15>>2] = $125;
       $127 = ($125|0)==(0|0);
       if (!($127)) {
        $128 = ((($125)) + 8|0);
        $129 = HEAP32[$128>>2]|0;HEAP32[$128>>2] = (($129+1)|0);
       }
       $130 = ($124|0)==(0|0);
       if ($130) {
        label = 57;
       } else {
        $131 = ((($124)) + 8|0);
        $132 = HEAP32[$131>>2]|0;HEAP32[$131>>2] = (($132-1)|0);
        $133 = ($132|0)==(1);
        if ($133) {
         __THREW__ = 0;
         invoke_viii(3262,($124|0),1,1);
         $134 = __THREW__; __THREW__ = 0;
         $135 = $134&1;
         if ($135) {
          break;
         } else {
          label = 57;
         }
        } else {
         label = 57;
        }
       }
      }
     }
     if ((label|0) == 57) {
      $$pr$i38 = HEAP32[$98>>2]|0;
      $136 = $$pr$i38;
     }
     $137 = ($136|0)==(0|0);
     if (!($137)) {
      $138 = ((($136)) + 8|0);
      $139 = HEAP32[$138>>2]|0;HEAP32[$138>>2] = (($139-1)|0);
      $140 = ($139|0)==(1);
      if ($140) {
       __THREW__ = 0;
       invoke_viii(3262,($136|0),1,1);
       $141 = __THREW__; __THREW__ = 0;
       $142 = $141&1;
       if ($142) {
        $147 = ___cxa_find_matching_catch_2()|0;
        $148 = tempRet0;
        $149 = ((($96)) + 11|0);
        $150 = HEAP8[$149>>0]|0;
        $151 = ($150<<24>>24)<(0);
        if (!($151)) {
         ___resumeException($147|0);
         // unreachable;
        }
        $152 = HEAP32[$96>>2]|0;
        __ZdlPv($152);
        ___resumeException($147|0);
        // unreachable;
       }
      }
     }
     HEAP32[$98>>2] = 0;
     $143 = ((($96)) + 11|0);
     $144 = HEAP8[$143>>0]|0;
     $145 = ($144<<24>>24)<(0);
     if ($145) {
      $146 = HEAP32[$96>>2]|0;
      __ZdlPv($146);
     }
     $172 = (($8) + 2)|0;
     $173 = HEAP32[$1>>2]|0;
     $174 = HEAP32[$0>>2]|0;
     $175 = ($173|0)<($174|0);
     if (!($175)) {
      $$0 = $172;
      STACKTOP = sp;return ($$0|0);
     }
     HEAP32[$7>>2] = $174;
     $176 = ((($7)) + 4|0);
     $177 = ((($0)) + 4|0);
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_($176,$177);
     $178 = ((($7)) + 16|0);
     $179 = ((($0)) + 16|0);
     $180 = HEAP32[$179>>2]|0;
     HEAP32[$178>>2] = $180;
     $181 = ($180|0)==(0|0);
     if (!($181)) {
      $182 = ((($180)) + 8|0);
      $183 = HEAP32[$182>>2]|0;HEAP32[$182>>2] = (($183+1)|0);
     }
     $184 = ($0|0)==($1|0);
     do {
      if ($184) {
       label = 86;
      } else {
       $185 = HEAP32[$1>>2]|0;
       HEAP32[$0>>2] = $185;
       __THREW__ = 0;
       (invoke_iii(3477,($177|0),($97|0))|0);
       $186 = __THREW__; __THREW__ = 0;
       $187 = $186&1;
       if (!($187)) {
        $188 = HEAP32[$179>>2]|0;
        $189 = HEAP32[$99>>2]|0;
        $190 = ($188|0)==($189|0);
        if ($190) {
         label = 86;
        } else {
         HEAP32[$179>>2] = $189;
         $191 = ($189|0)==(0|0);
         if (!($191)) {
          $192 = ((($189)) + 8|0);
          $193 = HEAP32[$192>>2]|0;HEAP32[$192>>2] = (($193+1)|0);
         }
         $194 = ($188|0)==(0|0);
         if ($194) {
          label = 86;
          break;
         }
         $195 = ((($188)) + 8|0);
         $196 = HEAP32[$195>>2]|0;HEAP32[$195>>2] = (($196-1)|0);
         $197 = ($196|0)==(1);
         if (!($197)) {
          label = 86;
          break;
         }
         __THREW__ = 0;
         invoke_viii(3262,($188|0),1,1);
         $198 = __THREW__; __THREW__ = 0;
         $199 = $198&1;
         if (!($199)) {
          label = 86;
         }
        }
       }
      }
     } while(0);
     L98: do {
      if ((label|0) == 86) {
       $200 = ($7|0)==($1|0);
       do {
        if ($200) {
         label = 94;
        } else {
         $201 = HEAP32[$7>>2]|0;
         HEAP32[$1>>2] = $201;
         __THREW__ = 0;
         (invoke_iii(3477,($97|0),($176|0))|0);
         $202 = __THREW__; __THREW__ = 0;
         $203 = $202&1;
         if ($203) {
          break L98;
         }
         $204 = HEAP32[$99>>2]|0;
         $205 = HEAP32[$178>>2]|0;
         $206 = ($204|0)==($205|0);
         if ($206) {
          $216 = $204;
          break;
         }
         HEAP32[$99>>2] = $205;
         $207 = ($205|0)==(0|0);
         if (!($207)) {
          $208 = ((($205)) + 8|0);
          $209 = HEAP32[$208>>2]|0;HEAP32[$208>>2] = (($209+1)|0);
         }
         $210 = ($204|0)==(0|0);
         if ($210) {
          label = 94;
          break;
         }
         $211 = ((($204)) + 8|0);
         $212 = HEAP32[$211>>2]|0;HEAP32[$211>>2] = (($212-1)|0);
         $213 = ($212|0)==(1);
         if (!($213)) {
          label = 94;
          break;
         }
         __THREW__ = 0;
         invoke_viii(3262,($204|0),1,1);
         $214 = __THREW__; __THREW__ = 0;
         $215 = $214&1;
         if ($215) {
          break L98;
         } else {
          label = 94;
         }
        }
       } while(0);
       if ((label|0) == 94) {
        $$pr$i = HEAP32[$178>>2]|0;
        $216 = $$pr$i;
       }
       $217 = ($216|0)==(0|0);
       do {
        if (!($217)) {
         $218 = ((($216)) + 8|0);
         $219 = HEAP32[$218>>2]|0;HEAP32[$218>>2] = (($219-1)|0);
         $220 = ($219|0)==(1);
         if (!($220)) {
          break;
         }
         __THREW__ = 0;
         invoke_viii(3262,($216|0),1,1);
         $221 = __THREW__; __THREW__ = 0;
         $222 = $221&1;
         if (!($222)) {
          break;
         }
         $227 = ___cxa_find_matching_catch_2()|0;
         $228 = tempRet0;
         $229 = ((($176)) + 11|0);
         $230 = HEAP8[$229>>0]|0;
         $231 = ($230<<24>>24)<(0);
         if (!($231)) {
          ___resumeException($227|0);
          // unreachable;
         }
         $232 = HEAP32[$176>>2]|0;
         __ZdlPv($232);
         ___resumeException($227|0);
         // unreachable;
        }
       } while(0);
       HEAP32[$178>>2] = 0;
       $223 = ((($176)) + 11|0);
       $224 = HEAP8[$223>>0]|0;
       $225 = ($224<<24>>24)<(0);
       if ($225) {
        $226 = HEAP32[$176>>2]|0;
        __ZdlPv($226);
       }
       $252 = (($8) + 3)|0;
       $$0 = $252;
       STACKTOP = sp;return ($$0|0);
      }
     } while(0);
     $233 = ___cxa_find_matching_catch_2()|0;
     $234 = tempRet0;
     $235 = HEAP32[$178>>2]|0;
     $236 = ($235|0)==(0|0);
     do {
      if (!($236)) {
       $237 = ((($235)) + 8|0);
       $238 = HEAP32[$237>>2]|0;HEAP32[$237>>2] = (($238-1)|0);
       $239 = ($238|0)==(1);
       if ($239) {
        __THREW__ = 0;
        invoke_viii(3262,($235|0),1,1);
        $240 = __THREW__; __THREW__ = 0;
        $241 = $240&1;
        if (!($241)) {
         break;
        }
        $246 = ___cxa_find_matching_catch_3(0|0)|0;
        $247 = tempRet0;
        $248 = ((($176)) + 11|0);
        $249 = HEAP8[$248>>0]|0;
        $250 = ($249<<24>>24)<(0);
        if (!($250)) {
         ___clang_call_terminate($246);
         // unreachable;
        }
        $251 = HEAP32[$176>>2]|0;
        __ZdlPv($251);
        ___clang_call_terminate($246);
        // unreachable;
       }
      }
     } while(0);
     HEAP32[$178>>2] = 0;
     $242 = ((($176)) + 11|0);
     $243 = HEAP8[$242>>0]|0;
     $244 = ($243<<24>>24)<(0);
     if (!($244)) {
      ___resumeException($233|0);
      // unreachable;
     }
     $245 = HEAP32[$176>>2]|0;
     __ZdlPv($245);
     ___resumeException($233|0);
     // unreachable;
    }
   } while(0);
   $153 = ___cxa_find_matching_catch_2()|0;
   $154 = tempRet0;
   $155 = HEAP32[$98>>2]|0;
   $156 = ($155|0)==(0|0);
   if (!($156)) {
    $157 = ((($155)) + 8|0);
    $158 = HEAP32[$157>>2]|0;HEAP32[$157>>2] = (($158-1)|0);
    $159 = ($158|0)==(1);
    if ($159) {
     __THREW__ = 0;
     invoke_viii(3262,($155|0),1,1);
     $160 = __THREW__; __THREW__ = 0;
     $161 = $160&1;
     if ($161) {
      $166 = ___cxa_find_matching_catch_3(0|0)|0;
      $167 = tempRet0;
      $168 = ((($96)) + 11|0);
      $169 = HEAP8[$168>>0]|0;
      $170 = ($169<<24>>24)<(0);
      if (!($170)) {
       ___clang_call_terminate($166);
       // unreachable;
      }
      $171 = HEAP32[$96>>2]|0;
      __ZdlPv($171);
      ___clang_call_terminate($166);
      // unreachable;
     }
    }
   }
   HEAP32[$98>>2] = 0;
   $162 = ((($96)) + 11|0);
   $163 = HEAP8[$162>>0]|0;
   $164 = ($163<<24>>24)<(0);
   if (!($164)) {
    ___resumeException($153|0);
    // unreachable;
   }
   $165 = HEAP32[$96>>2]|0;
   __ZdlPv($165);
   ___resumeException($153|0);
   // unreachable;
  }
 } while(0);
 $73 = ___cxa_find_matching_catch_2()|0;
 $74 = tempRet0;
 $75 = HEAP32[$14>>2]|0;
 $76 = ($75|0)==(0|0);
 if (!($76)) {
  $77 = ((($75)) + 8|0);
  $78 = HEAP32[$77>>2]|0;HEAP32[$77>>2] = (($78-1)|0);
  $79 = ($78|0)==(1);
  if ($79) {
   __THREW__ = 0;
   invoke_viii(3262,($75|0),1,1);
   $80 = __THREW__; __THREW__ = 0;
   $81 = $80&1;
   if ($81) {
    $86 = ___cxa_find_matching_catch_3(0|0)|0;
    $87 = tempRet0;
    $88 = ((($12)) + 11|0);
    $89 = HEAP8[$88>>0]|0;
    $90 = ($89<<24>>24)<(0);
    if (!($90)) {
     ___clang_call_terminate($86);
     // unreachable;
    }
    $91 = HEAP32[$12>>2]|0;
    __ZdlPv($91);
    ___clang_call_terminate($86);
    // unreachable;
   }
  }
 }
 HEAP32[$14>>2] = 0;
 $82 = ((($12)) + 11|0);
 $83 = HEAP8[$82>>0]|0;
 $84 = ($83<<24>>24)<(0);
 if (!($84)) {
  ___resumeException($73|0);
  // unreachable;
 }
 $85 = HEAP32[$12>>2]|0;
 __ZdlPv($85);
 ___resumeException($73|0);
 // unreachable;
 return (0)|0;
}
function __ZNSt3__27__sort5IRNS_6__lessIN5osgDB12ReaderWriter10ReadResultES4_EEPS4_EEjT0_S8_S8_S8_S8_T_($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$0 = 0, $$pr$i = 0, $$pr$i34 = 0, $$pr$i45 = 0, $$pr$i56 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0;
 var $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0;
 var $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0;
 var $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0;
 var $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0;
 var $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0;
 var $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0;
 var $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0;
 var $331 = 0, $332 = 0, $333 = 0, $334 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(80|0);
 $6 = sp + 60|0;
 $7 = sp + 40|0;
 $8 = sp + 20|0;
 $9 = sp;
 $10 = (__ZNSt3__27__sort4IRNS_6__lessIN5osgDB12ReaderWriter10ReadResultES4_EEPS4_EEjT0_S8_S8_S8_T_($0,$1,$2,$3,$5)|0);
 $11 = HEAP32[$4>>2]|0;
 $12 = HEAP32[$3>>2]|0;
 $13 = ($11|0)<($12|0);
 if (!($13)) {
  $$0 = $10;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$8>>2] = $12;
 $14 = ((($8)) + 4|0);
 $15 = ((($3)) + 4|0);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_($14,$15);
 $16 = ((($8)) + 16|0);
 $17 = ((($3)) + 16|0);
 $18 = HEAP32[$17>>2]|0;
 HEAP32[$16>>2] = $18;
 $19 = ($18|0)==(0|0);
 if (!($19)) {
  $20 = ((($18)) + 8|0);
  $21 = HEAP32[$20>>2]|0;HEAP32[$20>>2] = (($21+1)|0);
 }
 $22 = ($3|0)==($4|0);
 if ($22) {
  label = 12;
 } else {
  $23 = HEAP32[$4>>2]|0;
  HEAP32[$3>>2] = $23;
  $24 = ((($4)) + 4|0);
  __THREW__ = 0;
  (invoke_iii(3477,($15|0),($24|0))|0);
  $25 = __THREW__; __THREW__ = 0;
  $26 = $25&1;
  if (!($26)) {
   $27 = HEAP32[$17>>2]|0;
   $28 = ((($4)) + 16|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = ($27|0)==($29|0);
   if ($30) {
    label = 12;
   } else {
    HEAP32[$17>>2] = $29;
    $31 = ($29|0)==(0|0);
    if (!($31)) {
     $32 = ((($29)) + 8|0);
     $33 = HEAP32[$32>>2]|0;HEAP32[$32>>2] = (($33+1)|0);
    }
    $34 = ($27|0)==(0|0);
    if ($34) {
     label = 12;
    } else {
     $35 = ((($27)) + 8|0);
     $36 = HEAP32[$35>>2]|0;HEAP32[$35>>2] = (($36-1)|0);
     $37 = ($36|0)==(1);
     if ($37) {
      __THREW__ = 0;
      invoke_viii(3262,($27|0),1,1);
      $38 = __THREW__; __THREW__ = 0;
      $39 = $38&1;
      if (!($39)) {
       label = 12;
      }
     } else {
      label = 12;
     }
    }
   }
  }
 }
 do {
  if ((label|0) == 12) {
   $40 = ($8|0)==($4|0);
   if ($40) {
    label = 20;
   } else {
    $41 = HEAP32[$8>>2]|0;
    HEAP32[$4>>2] = $41;
    $42 = ((($4)) + 4|0);
    __THREW__ = 0;
    (invoke_iii(3477,($42|0),($14|0))|0);
    $43 = __THREW__; __THREW__ = 0;
    $44 = $43&1;
    if ($44) {
     break;
    }
    $45 = ((($4)) + 16|0);
    $46 = HEAP32[$45>>2]|0;
    $47 = HEAP32[$16>>2]|0;
    $48 = ($46|0)==($47|0);
    if ($48) {
     $58 = $46;
    } else {
     HEAP32[$45>>2] = $47;
     $49 = ($47|0)==(0|0);
     if (!($49)) {
      $50 = ((($47)) + 8|0);
      $51 = HEAP32[$50>>2]|0;HEAP32[$50>>2] = (($51+1)|0);
     }
     $52 = ($46|0)==(0|0);
     if ($52) {
      label = 20;
     } else {
      $53 = ((($46)) + 8|0);
      $54 = HEAP32[$53>>2]|0;HEAP32[$53>>2] = (($54-1)|0);
      $55 = ($54|0)==(1);
      if ($55) {
       __THREW__ = 0;
       invoke_viii(3262,($46|0),1,1);
       $56 = __THREW__; __THREW__ = 0;
       $57 = $56&1;
       if ($57) {
        break;
       } else {
        label = 20;
       }
      } else {
       label = 20;
      }
     }
    }
   }
   if ((label|0) == 20) {
    $$pr$i34 = HEAP32[$16>>2]|0;
    $58 = $$pr$i34;
   }
   $59 = ($58|0)==(0|0);
   if (!($59)) {
    $60 = ((($58)) + 8|0);
    $61 = HEAP32[$60>>2]|0;HEAP32[$60>>2] = (($61-1)|0);
    $62 = ($61|0)==(1);
    if ($62) {
     __THREW__ = 0;
     invoke_viii(3262,($58|0),1,1);
     $63 = __THREW__; __THREW__ = 0;
     $64 = $63&1;
     if ($64) {
      $69 = ___cxa_find_matching_catch_2()|0;
      $70 = tempRet0;
      $71 = ((($14)) + 11|0);
      $72 = HEAP8[$71>>0]|0;
      $73 = ($72<<24>>24)<(0);
      if (!($73)) {
       ___resumeException($69|0);
       // unreachable;
      }
      $74 = HEAP32[$14>>2]|0;
      __ZdlPv($74);
      ___resumeException($69|0);
      // unreachable;
     }
    }
   }
   HEAP32[$16>>2] = 0;
   $65 = ((($14)) + 11|0);
   $66 = HEAP8[$65>>0]|0;
   $67 = ($66<<24>>24)<(0);
   if ($67) {
    $68 = HEAP32[$14>>2]|0;
    __ZdlPv($68);
   }
   $94 = (($10) + 1)|0;
   $95 = HEAP32[$3>>2]|0;
   $96 = HEAP32[$2>>2]|0;
   $97 = ($95|0)<($96|0);
   if (!($97)) {
    $$0 = $94;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$7>>2] = $96;
   $98 = ((($7)) + 4|0);
   $99 = ((($2)) + 4|0);
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_($98,$99);
   $100 = ((($7)) + 16|0);
   $101 = ((($2)) + 16|0);
   $102 = HEAP32[$101>>2]|0;
   HEAP32[$100>>2] = $102;
   $103 = ($102|0)==(0|0);
   if (!($103)) {
    $104 = ((($102)) + 8|0);
    $105 = HEAP32[$104>>2]|0;HEAP32[$104>>2] = (($105+1)|0);
   }
   $106 = ($2|0)==($3|0);
   if ($106) {
    label = 49;
   } else {
    $107 = HEAP32[$3>>2]|0;
    HEAP32[$2>>2] = $107;
    __THREW__ = 0;
    (invoke_iii(3477,($99|0),($15|0))|0);
    $108 = __THREW__; __THREW__ = 0;
    $109 = $108&1;
    if (!($109)) {
     $110 = HEAP32[$101>>2]|0;
     $111 = HEAP32[$17>>2]|0;
     $112 = ($110|0)==($111|0);
     if ($112) {
      label = 49;
     } else {
      HEAP32[$101>>2] = $111;
      $113 = ($111|0)==(0|0);
      if (!($113)) {
       $114 = ((($111)) + 8|0);
       $115 = HEAP32[$114>>2]|0;HEAP32[$114>>2] = (($115+1)|0);
      }
      $116 = ($110|0)==(0|0);
      if ($116) {
       label = 49;
      } else {
       $117 = ((($110)) + 8|0);
       $118 = HEAP32[$117>>2]|0;HEAP32[$117>>2] = (($118-1)|0);
       $119 = ($118|0)==(1);
       if ($119) {
        __THREW__ = 0;
        invoke_viii(3262,($110|0),1,1);
        $120 = __THREW__; __THREW__ = 0;
        $121 = $120&1;
        if (!($121)) {
         label = 49;
        }
       } else {
        label = 49;
       }
      }
     }
    }
   }
   do {
    if ((label|0) == 49) {
     $122 = ($7|0)==($3|0);
     if ($122) {
      label = 57;
     } else {
      $123 = HEAP32[$7>>2]|0;
      HEAP32[$3>>2] = $123;
      __THREW__ = 0;
      (invoke_iii(3477,($15|0),($98|0))|0);
      $124 = __THREW__; __THREW__ = 0;
      $125 = $124&1;
      if ($125) {
       break;
      }
      $126 = HEAP32[$17>>2]|0;
      $127 = HEAP32[$100>>2]|0;
      $128 = ($126|0)==($127|0);
      if ($128) {
       $138 = $126;
      } else {
       HEAP32[$17>>2] = $127;
       $129 = ($127|0)==(0|0);
       if (!($129)) {
        $130 = ((($127)) + 8|0);
        $131 = HEAP32[$130>>2]|0;HEAP32[$130>>2] = (($131+1)|0);
       }
       $132 = ($126|0)==(0|0);
       if ($132) {
        label = 57;
       } else {
        $133 = ((($126)) + 8|0);
        $134 = HEAP32[$133>>2]|0;HEAP32[$133>>2] = (($134-1)|0);
        $135 = ($134|0)==(1);
        if ($135) {
         __THREW__ = 0;
         invoke_viii(3262,($126|0),1,1);
         $136 = __THREW__; __THREW__ = 0;
         $137 = $136&1;
         if ($137) {
          break;
         } else {
          label = 57;
         }
        } else {
         label = 57;
        }
       }
      }
     }
     if ((label|0) == 57) {
      $$pr$i45 = HEAP32[$100>>2]|0;
      $138 = $$pr$i45;
     }
     $139 = ($138|0)==(0|0);
     if (!($139)) {
      $140 = ((($138)) + 8|0);
      $141 = HEAP32[$140>>2]|0;HEAP32[$140>>2] = (($141-1)|0);
      $142 = ($141|0)==(1);
      if ($142) {
       __THREW__ = 0;
       invoke_viii(3262,($138|0),1,1);
       $143 = __THREW__; __THREW__ = 0;
       $144 = $143&1;
       if ($144) {
        $149 = ___cxa_find_matching_catch_2()|0;
        $150 = tempRet0;
        $151 = ((($98)) + 11|0);
        $152 = HEAP8[$151>>0]|0;
        $153 = ($152<<24>>24)<(0);
        if (!($153)) {
         ___resumeException($149|0);
         // unreachable;
        }
        $154 = HEAP32[$98>>2]|0;
        __ZdlPv($154);
        ___resumeException($149|0);
        // unreachable;
       }
      }
     }
     HEAP32[$100>>2] = 0;
     $145 = ((($98)) + 11|0);
     $146 = HEAP8[$145>>0]|0;
     $147 = ($146<<24>>24)<(0);
     if ($147) {
      $148 = HEAP32[$98>>2]|0;
      __ZdlPv($148);
     }
     $174 = (($10) + 2)|0;
     $175 = HEAP32[$2>>2]|0;
     $176 = HEAP32[$1>>2]|0;
     $177 = ($175|0)<($176|0);
     if (!($177)) {
      $$0 = $174;
      STACKTOP = sp;return ($$0|0);
     }
     HEAP32[$6>>2] = $176;
     $178 = ((($6)) + 4|0);
     $179 = ((($1)) + 4|0);
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_($178,$179);
     $180 = ((($6)) + 16|0);
     $181 = ((($1)) + 16|0);
     $182 = HEAP32[$181>>2]|0;
     HEAP32[$180>>2] = $182;
     $183 = ($182|0)==(0|0);
     if (!($183)) {
      $184 = ((($182)) + 8|0);
      $185 = HEAP32[$184>>2]|0;HEAP32[$184>>2] = (($185+1)|0);
     }
     $186 = ($1|0)==($2|0);
     do {
      if ($186) {
       label = 86;
      } else {
       $187 = HEAP32[$2>>2]|0;
       HEAP32[$1>>2] = $187;
       __THREW__ = 0;
       (invoke_iii(3477,($179|0),($99|0))|0);
       $188 = __THREW__; __THREW__ = 0;
       $189 = $188&1;
       if (!($189)) {
        $190 = HEAP32[$181>>2]|0;
        $191 = HEAP32[$101>>2]|0;
        $192 = ($190|0)==($191|0);
        if ($192) {
         label = 86;
        } else {
         HEAP32[$181>>2] = $191;
         $193 = ($191|0)==(0|0);
         if (!($193)) {
          $194 = ((($191)) + 8|0);
          $195 = HEAP32[$194>>2]|0;HEAP32[$194>>2] = (($195+1)|0);
         }
         $196 = ($190|0)==(0|0);
         if ($196) {
          label = 86;
          break;
         }
         $197 = ((($190)) + 8|0);
         $198 = HEAP32[$197>>2]|0;HEAP32[$197>>2] = (($198-1)|0);
         $199 = ($198|0)==(1);
         if (!($199)) {
          label = 86;
          break;
         }
         __THREW__ = 0;
         invoke_viii(3262,($190|0),1,1);
         $200 = __THREW__; __THREW__ = 0;
         $201 = $200&1;
         if (!($201)) {
          label = 86;
         }
        }
       }
      }
     } while(0);
     L98: do {
      if ((label|0) == 86) {
       $202 = ($6|0)==($2|0);
       do {
        if ($202) {
         label = 94;
        } else {
         $203 = HEAP32[$6>>2]|0;
         HEAP32[$2>>2] = $203;
         __THREW__ = 0;
         (invoke_iii(3477,($99|0),($178|0))|0);
         $204 = __THREW__; __THREW__ = 0;
         $205 = $204&1;
         if ($205) {
          break L98;
         }
         $206 = HEAP32[$101>>2]|0;
         $207 = HEAP32[$180>>2]|0;
         $208 = ($206|0)==($207|0);
         if ($208) {
          $218 = $206;
          break;
         }
         HEAP32[$101>>2] = $207;
         $209 = ($207|0)==(0|0);
         if (!($209)) {
          $210 = ((($207)) + 8|0);
          $211 = HEAP32[$210>>2]|0;HEAP32[$210>>2] = (($211+1)|0);
         }
         $212 = ($206|0)==(0|0);
         if ($212) {
          label = 94;
          break;
         }
         $213 = ((($206)) + 8|0);
         $214 = HEAP32[$213>>2]|0;HEAP32[$213>>2] = (($214-1)|0);
         $215 = ($214|0)==(1);
         if (!($215)) {
          label = 94;
          break;
         }
         __THREW__ = 0;
         invoke_viii(3262,($206|0),1,1);
         $216 = __THREW__; __THREW__ = 0;
         $217 = $216&1;
         if ($217) {
          break L98;
         } else {
          label = 94;
         }
        }
       } while(0);
       if ((label|0) == 94) {
        $$pr$i56 = HEAP32[$180>>2]|0;
        $218 = $$pr$i56;
       }
       $219 = ($218|0)==(0|0);
       do {
        if (!($219)) {
         $220 = ((($218)) + 8|0);
         $221 = HEAP32[$220>>2]|0;HEAP32[$220>>2] = (($221-1)|0);
         $222 = ($221|0)==(1);
         if (!($222)) {
          break;
         }
         __THREW__ = 0;
         invoke_viii(3262,($218|0),1,1);
         $223 = __THREW__; __THREW__ = 0;
         $224 = $223&1;
         if (!($224)) {
          break;
         }
         $229 = ___cxa_find_matching_catch_2()|0;
         $230 = tempRet0;
         $231 = ((($178)) + 11|0);
         $232 = HEAP8[$231>>0]|0;
         $233 = ($232<<24>>24)<(0);
         if (!($233)) {
          ___resumeException($229|0);
          // unreachable;
         }
         $234 = HEAP32[$178>>2]|0;
         __ZdlPv($234);
         ___resumeException($229|0);
         // unreachable;
        }
       } while(0);
       HEAP32[$180>>2] = 0;
       $225 = ((($178)) + 11|0);
       $226 = HEAP8[$225>>0]|0;
       $227 = ($226<<24>>24)<(0);
       if ($227) {
        $228 = HEAP32[$178>>2]|0;
        __ZdlPv($228);
       }
       $254 = (($10) + 3)|0;
       $255 = HEAP32[$1>>2]|0;
       $256 = HEAP32[$0>>2]|0;
       $257 = ($255|0)<($256|0);
       if (!($257)) {
        $$0 = $254;
        STACKTOP = sp;return ($$0|0);
       }
       HEAP32[$9>>2] = $256;
       $258 = ((($9)) + 4|0);
       $259 = ((($0)) + 4|0);
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_($258,$259);
       $260 = ((($9)) + 16|0);
       $261 = ((($0)) + 16|0);
       $262 = HEAP32[$261>>2]|0;
       HEAP32[$260>>2] = $262;
       $263 = ($262|0)==(0|0);
       if (!($263)) {
        $264 = ((($262)) + 8|0);
        $265 = HEAP32[$264>>2]|0;HEAP32[$264>>2] = (($265+1)|0);
       }
       $266 = ($0|0)==($1|0);
       do {
        if ($266) {
         label = 123;
        } else {
         $267 = HEAP32[$1>>2]|0;
         HEAP32[$0>>2] = $267;
         __THREW__ = 0;
         (invoke_iii(3477,($259|0),($179|0))|0);
         $268 = __THREW__; __THREW__ = 0;
         $269 = $268&1;
         if ($269) {
          break;
         }
         $270 = HEAP32[$261>>2]|0;
         $271 = HEAP32[$181>>2]|0;
         $272 = ($270|0)==($271|0);
         if ($272) {
          label = 123;
          break;
         }
         HEAP32[$261>>2] = $271;
         $273 = ($271|0)==(0|0);
         if (!($273)) {
          $274 = ((($271)) + 8|0);
          $275 = HEAP32[$274>>2]|0;HEAP32[$274>>2] = (($275+1)|0);
         }
         $276 = ($270|0)==(0|0);
         if ($276) {
          label = 123;
          break;
         }
         $277 = ((($270)) + 8|0);
         $278 = HEAP32[$277>>2]|0;HEAP32[$277>>2] = (($278-1)|0);
         $279 = ($278|0)==(1);
         if (!($279)) {
          label = 123;
          break;
         }
         __THREW__ = 0;
         invoke_viii(3262,($270|0),1,1);
         $280 = __THREW__; __THREW__ = 0;
         $281 = $280&1;
         if (!($281)) {
          label = 123;
         }
        }
       } while(0);
       L139: do {
        if ((label|0) == 123) {
         $282 = ($9|0)==($1|0);
         do {
          if ($282) {
           label = 131;
          } else {
           $283 = HEAP32[$9>>2]|0;
           HEAP32[$1>>2] = $283;
           __THREW__ = 0;
           (invoke_iii(3477,($179|0),($258|0))|0);
           $284 = __THREW__; __THREW__ = 0;
           $285 = $284&1;
           if ($285) {
            break L139;
           }
           $286 = HEAP32[$181>>2]|0;
           $287 = HEAP32[$260>>2]|0;
           $288 = ($286|0)==($287|0);
           if ($288) {
            $298 = $286;
            break;
           }
           HEAP32[$181>>2] = $287;
           $289 = ($287|0)==(0|0);
           if (!($289)) {
            $290 = ((($287)) + 8|0);
            $291 = HEAP32[$290>>2]|0;HEAP32[$290>>2] = (($291+1)|0);
           }
           $292 = ($286|0)==(0|0);
           if ($292) {
            label = 131;
            break;
           }
           $293 = ((($286)) + 8|0);
           $294 = HEAP32[$293>>2]|0;HEAP32[$293>>2] = (($294-1)|0);
           $295 = ($294|0)==(1);
           if (!($295)) {
            label = 131;
            break;
           }
           __THREW__ = 0;
           invoke_viii(3262,($286|0),1,1);
           $296 = __THREW__; __THREW__ = 0;
           $297 = $296&1;
           if ($297) {
            break L139;
           } else {
            label = 131;
           }
          }
         } while(0);
         if ((label|0) == 131) {
          $$pr$i = HEAP32[$260>>2]|0;
          $298 = $$pr$i;
         }
         $299 = ($298|0)==(0|0);
         do {
          if (!($299)) {
           $300 = ((($298)) + 8|0);
           $301 = HEAP32[$300>>2]|0;HEAP32[$300>>2] = (($301-1)|0);
           $302 = ($301|0)==(1);
           if (!($302)) {
            break;
           }
           __THREW__ = 0;
           invoke_viii(3262,($298|0),1,1);
           $303 = __THREW__; __THREW__ = 0;
           $304 = $303&1;
           if (!($304)) {
            break;
           }
           $309 = ___cxa_find_matching_catch_2()|0;
           $310 = tempRet0;
           $311 = ((($258)) + 11|0);
           $312 = HEAP8[$311>>0]|0;
           $313 = ($312<<24>>24)<(0);
           if (!($313)) {
            ___resumeException($309|0);
            // unreachable;
           }
           $314 = HEAP32[$258>>2]|0;
           __ZdlPv($314);
           ___resumeException($309|0);
           // unreachable;
          }
         } while(0);
         HEAP32[$260>>2] = 0;
         $305 = ((($258)) + 11|0);
         $306 = HEAP8[$305>>0]|0;
         $307 = ($306<<24>>24)<(0);
         if ($307) {
          $308 = HEAP32[$258>>2]|0;
          __ZdlPv($308);
         }
         $334 = (($10) + 4)|0;
         $$0 = $334;
         STACKTOP = sp;return ($$0|0);
        }
       } while(0);
       $315 = ___cxa_find_matching_catch_2()|0;
       $316 = tempRet0;
       $317 = HEAP32[$260>>2]|0;
       $318 = ($317|0)==(0|0);
       do {
        if (!($318)) {
         $319 = ((($317)) + 8|0);
         $320 = HEAP32[$319>>2]|0;HEAP32[$319>>2] = (($320-1)|0);
         $321 = ($320|0)==(1);
         if (!($321)) {
          break;
         }
         __THREW__ = 0;
         invoke_viii(3262,($317|0),1,1);
         $322 = __THREW__; __THREW__ = 0;
         $323 = $322&1;
         if (!($323)) {
          break;
         }
         $328 = ___cxa_find_matching_catch_3(0|0)|0;
         $329 = tempRet0;
         $330 = ((($258)) + 11|0);
         $331 = HEAP8[$330>>0]|0;
         $332 = ($331<<24>>24)<(0);
         if (!($332)) {
          ___clang_call_terminate($328);
          // unreachable;
         }
         $333 = HEAP32[$258>>2]|0;
         __ZdlPv($333);
         ___clang_call_terminate($328);
         // unreachable;
        }
       } while(0);
       HEAP32[$260>>2] = 0;
       $324 = ((($258)) + 11|0);
       $325 = HEAP8[$324>>0]|0;
       $326 = ($325<<24>>24)<(0);
       if (!($326)) {
        ___resumeException($315|0);
        // unreachable;
       }
       $327 = HEAP32[$258>>2]|0;
       __ZdlPv($327);
       ___resumeException($315|0);
       // unreachable;
      }
     } while(0);
     $235 = ___cxa_find_matching_catch_2()|0;
     $236 = tempRet0;
     $237 = HEAP32[$180>>2]|0;
     $238 = ($237|0)==(0|0);
     do {
      if (!($238)) {
       $239 = ((($237)) + 8|0);
       $240 = HEAP32[$239>>2]|0;HEAP32[$239>>2] = (($240-1)|0);
       $241 = ($240|0)==(1);
       if ($241) {
        __THREW__ = 0;
        invoke_viii(3262,($237|0),1,1);
        $242 = __THREW__; __THREW__ = 0;
        $243 = $242&1;
        if (!($243)) {
         break;
        }
        $248 = ___cxa_find_matching_catch_3(0|0)|0;
        $249 = tempRet0;
        $250 = ((($178)) + 11|0);
        $251 = HEAP8[$250>>0]|0;
        $252 = ($251<<24>>24)<(0);
        if (!($252)) {
         ___clang_call_terminate($248);
         // unreachable;
        }
        $253 = HEAP32[$178>>2]|0;
        __ZdlPv($253);
        ___clang_call_terminate($248);
        // unreachable;
       }
      }
     } while(0);
     HEAP32[$180>>2] = 0;
     $244 = ((($178)) + 11|0);
     $245 = HEAP8[$244>>0]|0;
     $246 = ($245<<24>>24)<(0);
     if (!($246)) {
      ___resumeException($235|0);
      // unreachable;
     }
     $247 = HEAP32[$178>>2]|0;
     __ZdlPv($247);
     ___resumeException($235|0);
     // unreachable;
    }
   } while(0);
   $155 = ___cxa_find_matching_catch_2()|0;
   $156 = tempRet0;
   $157 = HEAP32[$100>>2]|0;
   $158 = ($157|0)==(0|0);
   if (!($158)) {
    $159 = ((($157)) + 8|0);
    $160 = HEAP32[$159>>2]|0;HEAP32[$159>>2] = (($160-1)|0);
    $161 = ($160|0)==(1);
    if ($161) {
     __THREW__ = 0;
     invoke_viii(3262,($157|0),1,1);
     $162 = __THREW__; __THREW__ = 0;
     $163 = $162&1;
     if ($163) {
      $168 = ___cxa_find_matching_catch_3(0|0)|0;
      $169 = tempRet0;
      $170 = ((($98)) + 11|0);
      $171 = HEAP8[$170>>0]|0;
      $172 = ($171<<24>>24)<(0);
      if (!($172)) {
       ___clang_call_terminate($168);
       // unreachable;
      }
      $173 = HEAP32[$98>>2]|0;
      __ZdlPv($173);
      ___clang_call_terminate($168);
      // unreachable;
     }
    }
   }
   HEAP32[$100>>2] = 0;
   $164 = ((($98)) + 11|0);
   $165 = HEAP8[$164>>0]|0;
   $166 = ($165<<24>>24)<(0);
   if (!($166)) {
    ___resumeException($155|0);
    // unreachable;
   }
   $167 = HEAP32[$98>>2]|0;
   __ZdlPv($167);
   ___resumeException($155|0);
   // unreachable;
  }
 } while(0);
 $75 = ___cxa_find_matching_catch_2()|0;
 $76 = tempRet0;
 $77 = HEAP32[$16>>2]|0;
 $78 = ($77|0)==(0|0);
 if (!($78)) {
  $79 = ((($77)) + 8|0);
  $80 = HEAP32[$79>>2]|0;HEAP32[$79>>2] = (($80-1)|0);
  $81 = ($80|0)==(1);
  if ($81) {
   __THREW__ = 0;
   invoke_viii(3262,($77|0),1,1);
   $82 = __THREW__; __THREW__ = 0;
   $83 = $82&1;
   if ($83) {
    $88 = ___cxa_find_matching_catch_3(0|0)|0;
    $89 = tempRet0;
    $90 = ((($14)) + 11|0);
    $91 = HEAP8[$90>>0]|0;
    $92 = ($91<<24>>24)<(0);
    if (!($92)) {
     ___clang_call_terminate($88);
     // unreachable;
    }
    $93 = HEAP32[$14>>2]|0;
    __ZdlPv($93);
    ___clang_call_terminate($88);
    // unreachable;
   }
  }
 }
 HEAP32[$16>>2] = 0;
 $84 = ((($14)) + 11|0);
 $85 = HEAP8[$84>>0]|0;
 $86 = ($85<<24>>24)<(0);
 if (!($86)) {
  ___resumeException($75|0);
  // unreachable;
 }
 $87 = HEAP32[$14>>2]|0;
 __ZdlPv($87);
 ___resumeException($75|0);
 // unreachable;
 return (0)|0;
}
function __ZNSt3__218__insertion_sort_3IRNS_6__lessIN5osgDB12ReaderWriter10ReadResultES4_EEPS4_EEvT0_S8_T_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$03350 = 0, $$034 = 0, $$034$lcssa52 = 0, $$051 = 0, $$051$phi = 0, $$1 = 0, $$1$phi = 0, $$pr = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $3 = sp;
 $4 = ((($0)) + 40|0);
 $5 = ((($0)) + 20|0);
 (__ZNSt3__27__sort3IRNS_6__lessIN5osgDB12ReaderWriter10ReadResultES4_EEPS4_EEjT0_S8_S8_T_($0,$5,$4,$2)|0);
 $6 = ((($0)) + 60|0);
 $7 = ($6|0)==($1|0);
 if ($7) {
  STACKTOP = sp;return;
 }
 $8 = ((($3)) + 4|0);
 $9 = ((($3)) + 16|0);
 $10 = ((($8)) + 11|0);
 $$03350 = $6;$$051 = $4;
 L4: while(1) {
  $11 = HEAP32[$$03350>>2]|0;
  $12 = HEAP32[$$051>>2]|0;
  $13 = ($11|0)<($12|0);
  if ($13) {
   HEAP32[$3>>2] = $11;
   $14 = ((($$03350)) + 4|0);
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_($8,$14);
   $15 = ((($$03350)) + 16|0);
   $16 = HEAP32[$15>>2]|0;
   HEAP32[$9>>2] = $16;
   $17 = ($16|0)==(0|0);
   if ($17) {
    $$034 = $$051;$$1 = $$03350;
   } else {
    $18 = ((($16)) + 8|0);
    $19 = HEAP32[$18>>2]|0;HEAP32[$18>>2] = (($19+1)|0);
    $$034 = $$051;$$1 = $$03350;
   }
   while(1) {
    $20 = HEAP32[$$034>>2]|0;
    HEAP32[$$1>>2] = $20;
    $21 = ((($$034)) + 4|0);
    $22 = ((($$1)) + 4|0);
    __THREW__ = 0;
    (invoke_iii(3477,($22|0),($21|0))|0);
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if ($24) {
     label = 34;
     break L4;
    }
    $25 = ((($$1)) + 16|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = ((($$034)) + 16|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = ($26|0)==($28|0);
    if (!($29)) {
     HEAP32[$25>>2] = $28;
     $30 = ($28|0)==(0|0);
     if (!($30)) {
      $31 = ((($28)) + 8|0);
      $32 = HEAP32[$31>>2]|0;HEAP32[$31>>2] = (($32+1)|0);
     }
     $33 = ($26|0)==(0|0);
     if (!($33)) {
      $34 = ((($26)) + 8|0);
      $35 = HEAP32[$34>>2]|0;HEAP32[$34>>2] = (($35-1)|0);
      $36 = ($35|0)==(1);
      if ($36) {
       __THREW__ = 0;
       invoke_viii(3262,($26|0),1,1);
       $37 = __THREW__; __THREW__ = 0;
       $38 = $37&1;
       if ($38) {
        label = 34;
        break L4;
       }
      }
     }
    }
    $39 = ($$034|0)==($0|0);
    if ($39) {
     $$034$lcssa52 = $0;
     break;
    }
    $40 = ((($$034)) + -20|0);
    $41 = HEAP32[$3>>2]|0;
    $42 = HEAP32[$40>>2]|0;
    $43 = ($41|0)<($42|0);
    if ($43) {
     $$1$phi = $$034;$$034 = $40;$$1 = $$1$phi;
    } else {
     $$034$lcssa52 = $$034;
     break;
    }
   }
   $44 = ($$034$lcssa52|0)==($3|0);
   if ($44) {
    label = 24;
   } else {
    $45 = HEAP32[$3>>2]|0;
    HEAP32[$$034$lcssa52>>2] = $45;
    $46 = ((($$034$lcssa52)) + 4|0);
    __THREW__ = 0;
    (invoke_iii(3477,($46|0),($8|0))|0);
    $47 = __THREW__; __THREW__ = 0;
    $48 = $47&1;
    if ($48) {
     label = 34;
     break;
    }
    $49 = ((($$034$lcssa52)) + 16|0);
    $50 = HEAP32[$49>>2]|0;
    $51 = HEAP32[$9>>2]|0;
    $52 = ($50|0)==($51|0);
    if ($52) {
     $62 = $50;
    } else {
     HEAP32[$49>>2] = $51;
     $53 = ($51|0)==(0|0);
     if (!($53)) {
      $54 = ((($51)) + 8|0);
      $55 = HEAP32[$54>>2]|0;HEAP32[$54>>2] = (($55+1)|0);
     }
     $56 = ($50|0)==(0|0);
     if ($56) {
      label = 24;
     } else {
      $57 = ((($50)) + 8|0);
      $58 = HEAP32[$57>>2]|0;HEAP32[$57>>2] = (($58-1)|0);
      $59 = ($58|0)==(1);
      if ($59) {
       __THREW__ = 0;
       invoke_viii(3262,($50|0),1,1);
       $60 = __THREW__; __THREW__ = 0;
       $61 = $60&1;
       if ($61) {
        label = 34;
        break;
       } else {
        label = 24;
       }
      } else {
       label = 24;
      }
     }
    }
   }
   if ((label|0) == 24) {
    label = 0;
    $$pr = HEAP32[$9>>2]|0;
    $62 = $$pr;
   }
   $63 = ($62|0)==(0|0);
   if (!($63)) {
    $64 = ((($62)) + 8|0);
    $65 = HEAP32[$64>>2]|0;HEAP32[$64>>2] = (($65-1)|0);
    $66 = ($65|0)==(1);
    if ($66) {
     __THREW__ = 0;
     invoke_viii(3262,($62|0),1,1);
     $67 = __THREW__; __THREW__ = 0;
     $68 = $67&1;
     if ($68) {
      label = 30;
      break;
     }
    }
   }
   HEAP32[$9>>2] = 0;
   $69 = HEAP8[$10>>0]|0;
   $70 = ($69<<24>>24)<(0);
   if ($70) {
    $71 = HEAP32[$8>>2]|0;
    __ZdlPv($71);
   }
  }
  $94 = ((($$03350)) + 20|0);
  $95 = ($94|0)==($1|0);
  if ($95) {
   label = 3;
   break;
  } else {
   $$051$phi = $$03350;$$03350 = $94;$$051 = $$051$phi;
  }
 }
 if ((label|0) == 3) {
  STACKTOP = sp;return;
 }
 else if ((label|0) == 30) {
  $72 = ___cxa_find_matching_catch_2()|0;
  $73 = tempRet0;
  $74 = HEAP8[$10>>0]|0;
  $75 = ($74<<24>>24)<(0);
  if (!($75)) {
   ___resumeException($72|0);
   // unreachable;
  }
  $76 = HEAP32[$8>>2]|0;
  __ZdlPv($76);
  ___resumeException($72|0);
  // unreachable;
 }
 else if ((label|0) == 34) {
  $77 = ___cxa_find_matching_catch_2()|0;
  $78 = tempRet0;
  $79 = HEAP32[$9>>2]|0;
  $80 = ($79|0)==(0|0);
  if (!($80)) {
   $81 = ((($79)) + 8|0);
   $82 = HEAP32[$81>>2]|0;HEAP32[$81>>2] = (($82-1)|0);
   $83 = ($82|0)==(1);
   if ($83) {
    __THREW__ = 0;
    invoke_viii(3262,($79|0),1,1);
    $84 = __THREW__; __THREW__ = 0;
    $85 = $84&1;
    if ($85) {
     $89 = ___cxa_find_matching_catch_3(0|0)|0;
     $90 = tempRet0;
     $91 = HEAP8[$10>>0]|0;
     $92 = ($91<<24>>24)<(0);
     if (!($92)) {
      ___clang_call_terminate($89);
      // unreachable;
     }
     $93 = HEAP32[$8>>2]|0;
     __ZdlPv($93);
     ___clang_call_terminate($89);
     // unreachable;
    }
   }
  }
  HEAP32[$9>>2] = 0;
  $86 = HEAP8[$10>>0]|0;
  $87 = ($86<<24>>24)<(0);
  if (!($87)) {
   ___resumeException($77|0);
   // unreachable;
  }
  $88 = HEAP32[$8>>2]|0;
  __ZdlPv($88);
  ___resumeException($77|0);
  // unreachable;
 }
}
function __ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIN5osgDB12ReaderWriter10ReadResultES4_EEPS4_EEbT0_S8_T_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$$3 = 0, $$068 = 0, $$068$lcssa100 = 0, $$07195 = 0, $$07494 = 0, $$07693 = 0, $$07693$phi = 0, $$170 = 0, $$175 = 0, $$177 = 0, $$177$phi = 0, $$3 = 0, $$5 = 0, $$pr = 0, $$pr$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0;
 var $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0;
 var $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0;
 var $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0;
 var $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0;
 var $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0;
 var $195 = 0, $196 = 0, $197 = 0, $198 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $3 = sp + 20|0;
 $4 = sp;
 $5 = $1;
 $6 = $0;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 20)&-1;
 switch ($8|0) {
 case 2:  {
  $9 = ((($1)) + -20|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = HEAP32[$0>>2]|0;
  $12 = ($10|0)<($11|0);
  if (!($12)) {
   $$5 = 1;
   STACKTOP = sp;return ($$5|0);
  }
  HEAP32[$3>>2] = $11;
  $13 = ((($3)) + 4|0);
  $14 = ((($0)) + 4|0);
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_($13,$14);
  $15 = ((($3)) + 16|0);
  $16 = ((($0)) + 16|0);
  $17 = HEAP32[$16>>2]|0;
  HEAP32[$15>>2] = $17;
  $18 = ($17|0)==(0|0);
  if (!($18)) {
   $19 = ((($17)) + 8|0);
   $20 = HEAP32[$19>>2]|0;HEAP32[$19>>2] = (($20+1)|0);
  }
  $21 = ($9|0)==($0|0);
  if ($21) {
   label = 13;
  } else {
   $22 = HEAP32[$9>>2]|0;
   HEAP32[$0>>2] = $22;
   $23 = ((($1)) + -16|0);
   __THREW__ = 0;
   (invoke_iii(3477,($14|0),($23|0))|0);
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   if (!($25)) {
    $26 = HEAP32[$16>>2]|0;
    $27 = ((($1)) + -4|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = ($26|0)==($28|0);
    if ($29) {
     label = 13;
    } else {
     HEAP32[$16>>2] = $28;
     $30 = ($28|0)==(0|0);
     if (!($30)) {
      $31 = ((($28)) + 8|0);
      $32 = HEAP32[$31>>2]|0;HEAP32[$31>>2] = (($32+1)|0);
     }
     $33 = ($26|0)==(0|0);
     if ($33) {
      label = 13;
     } else {
      $34 = ((($26)) + 8|0);
      $35 = HEAP32[$34>>2]|0;HEAP32[$34>>2] = (($35-1)|0);
      $36 = ($35|0)==(1);
      if ($36) {
       __THREW__ = 0;
       invoke_viii(3262,($26|0),1,1);
       $37 = __THREW__; __THREW__ = 0;
       $38 = $37&1;
       if (!($38)) {
        label = 13;
       }
      } else {
       label = 13;
      }
     }
    }
   }
  }
  do {
   if ((label|0) == 13) {
    $39 = ($3|0)==($9|0);
    if ($39) {
     label = 21;
    } else {
     $40 = HEAP32[$3>>2]|0;
     HEAP32[$9>>2] = $40;
     $41 = ((($1)) + -16|0);
     __THREW__ = 0;
     (invoke_iii(3477,($41|0),($13|0))|0);
     $42 = __THREW__; __THREW__ = 0;
     $43 = $42&1;
     if ($43) {
      break;
     }
     $44 = ((($1)) + -4|0);
     $45 = HEAP32[$44>>2]|0;
     $46 = HEAP32[$15>>2]|0;
     $47 = ($45|0)==($46|0);
     if ($47) {
      $57 = $45;
     } else {
      HEAP32[$44>>2] = $46;
      $48 = ($46|0)==(0|0);
      if (!($48)) {
       $49 = ((($46)) + 8|0);
       $50 = HEAP32[$49>>2]|0;HEAP32[$49>>2] = (($50+1)|0);
      }
      $51 = ($45|0)==(0|0);
      if ($51) {
       label = 21;
      } else {
       $52 = ((($45)) + 8|0);
       $53 = HEAP32[$52>>2]|0;HEAP32[$52>>2] = (($53-1)|0);
       $54 = ($53|0)==(1);
       if ($54) {
        __THREW__ = 0;
        invoke_viii(3262,($45|0),1,1);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         break;
        } else {
         label = 21;
        }
       } else {
        label = 21;
       }
      }
     }
    }
    if ((label|0) == 21) {
     $$pr$i = HEAP32[$15>>2]|0;
     $57 = $$pr$i;
    }
    $58 = ($57|0)==(0|0);
    if (!($58)) {
     $59 = ((($57)) + 8|0);
     $60 = HEAP32[$59>>2]|0;HEAP32[$59>>2] = (($60-1)|0);
     $61 = ($60|0)==(1);
     if ($61) {
      __THREW__ = 0;
      invoke_viii(3262,($57|0),1,1);
      $62 = __THREW__; __THREW__ = 0;
      $63 = $62&1;
      if ($63) {
       $68 = ___cxa_find_matching_catch_2()|0;
       $69 = tempRet0;
       $70 = ((($13)) + 11|0);
       $71 = HEAP8[$70>>0]|0;
       $72 = ($71<<24>>24)<(0);
       if (!($72)) {
        ___resumeException($68|0);
        // unreachable;
       }
       $73 = HEAP32[$13>>2]|0;
       __ZdlPv($73);
       ___resumeException($68|0);
       // unreachable;
      }
     }
    }
    HEAP32[$15>>2] = 0;
    $64 = ((($13)) + 11|0);
    $65 = HEAP8[$64>>0]|0;
    $66 = ($65<<24>>24)<(0);
    if ($66) {
     $67 = HEAP32[$13>>2]|0;
     __ZdlPv($67);
    }
    $$5 = 1;
    STACKTOP = sp;return ($$5|0);
   }
  } while(0);
  $74 = ___cxa_find_matching_catch_2()|0;
  $75 = tempRet0;
  $76 = HEAP32[$15>>2]|0;
  $77 = ($76|0)==(0|0);
  if (!($77)) {
   $78 = ((($76)) + 8|0);
   $79 = HEAP32[$78>>2]|0;HEAP32[$78>>2] = (($79-1)|0);
   $80 = ($79|0)==(1);
   if ($80) {
    __THREW__ = 0;
    invoke_viii(3262,($76|0),1,1);
    $81 = __THREW__; __THREW__ = 0;
    $82 = $81&1;
    if ($82) {
     $87 = ___cxa_find_matching_catch_3(0|0)|0;
     $88 = tempRet0;
     $89 = ((($13)) + 11|0);
     $90 = HEAP8[$89>>0]|0;
     $91 = ($90<<24>>24)<(0);
     if (!($91)) {
      ___clang_call_terminate($87);
      // unreachable;
     }
     $92 = HEAP32[$13>>2]|0;
     __ZdlPv($92);
     ___clang_call_terminate($87);
     // unreachable;
    }
   }
  }
  HEAP32[$15>>2] = 0;
  $83 = ((($13)) + 11|0);
  $84 = HEAP8[$83>>0]|0;
  $85 = ($84<<24>>24)<(0);
  if (!($85)) {
   ___resumeException($74|0);
   // unreachable;
  }
  $86 = HEAP32[$13>>2]|0;
  __ZdlPv($86);
  ___resumeException($74|0);
  // unreachable;
  break;
 }
 case 3:  {
  $93 = ((($0)) + 20|0);
  $94 = ((($1)) + -20|0);
  (__ZNSt3__27__sort3IRNS_6__lessIN5osgDB12ReaderWriter10ReadResultES4_EEPS4_EEjT0_S8_S8_T_($0,$93,$94,$2)|0);
  $$5 = 1;
  STACKTOP = sp;return ($$5|0);
  break;
 }
 case 4:  {
  $95 = ((($0)) + 20|0);
  $96 = ((($0)) + 40|0);
  $97 = ((($1)) + -20|0);
  (__ZNSt3__27__sort4IRNS_6__lessIN5osgDB12ReaderWriter10ReadResultES4_EEPS4_EEjT0_S8_S8_S8_T_($0,$95,$96,$97,$2)|0);
  $$5 = 1;
  STACKTOP = sp;return ($$5|0);
  break;
 }
 case 5:  {
  $98 = ((($0)) + 20|0);
  $99 = ((($0)) + 40|0);
  $100 = ((($0)) + 60|0);
  $101 = ((($1)) + -20|0);
  (__ZNSt3__27__sort5IRNS_6__lessIN5osgDB12ReaderWriter10ReadResultES4_EEPS4_EEjT0_S8_S8_S8_S8_T_($0,$98,$99,$100,$101,$2)|0);
  $$5 = 1;
  STACKTOP = sp;return ($$5|0);
  break;
 }
 case 1: case 0:  {
  $$5 = 1;
  STACKTOP = sp;return ($$5|0);
  break;
 }
 default: {
  $102 = ((($0)) + 40|0);
  $103 = ((($0)) + 20|0);
  (__ZNSt3__27__sort3IRNS_6__lessIN5osgDB12ReaderWriter10ReadResultES4_EEPS4_EEjT0_S8_S8_T_($0,$103,$102,$2)|0);
  $104 = ((($0)) + 60|0);
  $105 = ($104|0)==($1|0);
  L3: do {
   if ($105) {
    $$170 = 1;$$3 = 0;
   } else {
    $106 = ((($4)) + 4|0);
    $107 = ((($4)) + 16|0);
    $108 = ((($106)) + 11|0);
    $$07195 = $104;$$07494 = 0;$$07693 = $102;
    L5: while(1) {
     $109 = HEAP32[$$07195>>2]|0;
     $110 = HEAP32[$$07693>>2]|0;
     $111 = ($109|0)<($110|0);
     if ($111) {
      HEAP32[$4>>2] = $109;
      $112 = ((($$07195)) + 4|0);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_($106,$112);
      $113 = ((($$07195)) + 16|0);
      $114 = HEAP32[$113>>2]|0;
      HEAP32[$107>>2] = $114;
      $115 = ($114|0)==(0|0);
      if ($115) {
       $$068 = $$07693;$$177 = $$07195;
      } else {
       $116 = ((($114)) + 8|0);
       $117 = HEAP32[$116>>2]|0;HEAP32[$116>>2] = (($117+1)|0);
       $$068 = $$07693;$$177 = $$07195;
      }
      while(1) {
       $118 = ($$177|0)==($$068|0);
       if (!($118)) {
        $119 = HEAP32[$$068>>2]|0;
        HEAP32[$$177>>2] = $119;
        $120 = ((($$068)) + 4|0);
        $121 = ((($$177)) + 4|0);
        __THREW__ = 0;
        (invoke_iii(3477,($121|0),($120|0))|0);
        $122 = __THREW__; __THREW__ = 0;
        $123 = $122&1;
        if ($123) {
         break L5;
        }
        $124 = ((($$177)) + 16|0);
        $125 = HEAP32[$124>>2]|0;
        $126 = ((($$068)) + 16|0);
        $127 = HEAP32[$126>>2]|0;
        $128 = ($125|0)==($127|0);
        if (!($128)) {
         HEAP32[$124>>2] = $127;
         $129 = ($127|0)==(0|0);
         if (!($129)) {
          $130 = ((($127)) + 8|0);
          $131 = HEAP32[$130>>2]|0;HEAP32[$130>>2] = (($131+1)|0);
         }
         $132 = ($125|0)==(0|0);
         if (!($132)) {
          $133 = ((($125)) + 8|0);
          $134 = HEAP32[$133>>2]|0;HEAP32[$133>>2] = (($134-1)|0);
          $135 = ($134|0)==(1);
          if ($135) {
           __THREW__ = 0;
           invoke_viii(3262,($125|0),1,1);
           $136 = __THREW__; __THREW__ = 0;
           $137 = $136&1;
           if ($137) {
            break L5;
           }
          }
         }
        }
       }
       $138 = ($$068|0)==($0|0);
       if ($138) {
        $$068$lcssa100 = $0;
        break;
       }
       $139 = ((($$068)) + -20|0);
       $140 = HEAP32[$4>>2]|0;
       $141 = HEAP32[$139>>2]|0;
       $142 = ($140|0)<($141|0);
       if ($142) {
        $$177$phi = $$068;$$068 = $139;$$177 = $$177$phi;
       } else {
        $$068$lcssa100 = $$068;
        break;
       }
      }
      $143 = ($$068$lcssa100|0)==($4|0);
      if ($143) {
       label = 66;
      } else {
       $144 = HEAP32[$4>>2]|0;
       HEAP32[$$068$lcssa100>>2] = $144;
       $145 = ((($$068$lcssa100)) + 4|0);
       __THREW__ = 0;
       (invoke_iii(3477,($145|0),($106|0))|0);
       $146 = __THREW__; __THREW__ = 0;
       $147 = $146&1;
       if ($147) {
        break;
       }
       $148 = ((($$068$lcssa100)) + 16|0);
       $149 = HEAP32[$148>>2]|0;
       $150 = HEAP32[$107>>2]|0;
       $151 = ($149|0)==($150|0);
       if ($151) {
        $165 = $150;
       } else {
        HEAP32[$148>>2] = $150;
        $152 = ($150|0)==(0|0);
        if (!($152)) {
         $153 = ((($150)) + 8|0);
         $154 = HEAP32[$153>>2]|0;HEAP32[$153>>2] = (($154+1)|0);
        }
        $155 = ($149|0)==(0|0);
        if ($155) {
         label = 66;
        } else {
         $156 = ((($149)) + 8|0);
         $157 = HEAP32[$156>>2]|0;HEAP32[$156>>2] = (($157-1)|0);
         $158 = ($157|0)==(1);
         if ($158) {
          __THREW__ = 0;
          invoke_viii(3262,($149|0),1,1);
          $159 = __THREW__; __THREW__ = 0;
          $160 = $159&1;
          if ($160) {
           break;
          } else {
           label = 66;
          }
         } else {
          label = 66;
         }
        }
       }
      }
      if ((label|0) == 66) {
       label = 0;
       $$pr = HEAP32[$107>>2]|0;
       $165 = $$pr;
      }
      $161 = (($$07494) + 1)|0;
      $162 = ($161|0)==(8);
      $163 = ((($$07195)) + 20|0);
      $164 = ($163|0)==($1|0);
      $166 = ($165|0)==(0|0);
      if (!($166)) {
       $167 = ((($165)) + 8|0);
       $168 = HEAP32[$167>>2]|0;HEAP32[$167>>2] = (($168-1)|0);
       $169 = ($168|0)==(1);
       if ($169) {
        __THREW__ = 0;
        invoke_viii(3262,($165|0),1,1);
        $170 = __THREW__; __THREW__ = 0;
        $171 = $170&1;
        if ($171) {
         label = 72;
         break;
        }
       }
      }
      HEAP32[$107>>2] = 0;
      $172 = HEAP8[$108>>0]|0;
      $173 = ($172<<24>>24)<(0);
      if ($173) {
       $174 = HEAP32[$106>>2]|0;
       __ZdlPv($174);
      }
      if ($162) {
       $$170 = 0;$$3 = $164;
       break L3;
      } else {
       $$175 = $161;
      }
     } else {
      $$175 = $$07494;
     }
     $197 = ((($$07195)) + 20|0);
     $198 = ($197|0)==($1|0);
     if ($198) {
      $$170 = 1;$$3 = 0;
      break L3;
     } else {
      $$07693$phi = $$07195;$$07195 = $197;$$07494 = $$175;$$07693 = $$07693$phi;
     }
    }
    if ((label|0) == 72) {
     $175 = ___cxa_find_matching_catch_2()|0;
     $176 = tempRet0;
     $177 = HEAP8[$108>>0]|0;
     $178 = ($177<<24>>24)<(0);
     if (!($178)) {
      ___resumeException($175|0);
      // unreachable;
     }
     $179 = HEAP32[$106>>2]|0;
     __ZdlPv($179);
     ___resumeException($175|0);
     // unreachable;
    }
    $180 = ___cxa_find_matching_catch_2()|0;
    $181 = tempRet0;
    $182 = HEAP32[$107>>2]|0;
    $183 = ($182|0)==(0|0);
    if (!($183)) {
     $184 = ((($182)) + 8|0);
     $185 = HEAP32[$184>>2]|0;HEAP32[$184>>2] = (($185-1)|0);
     $186 = ($185|0)==(1);
     if ($186) {
      __THREW__ = 0;
      invoke_viii(3262,($182|0),1,1);
      $187 = __THREW__; __THREW__ = 0;
      $188 = $187&1;
      if ($188) {
       $192 = ___cxa_find_matching_catch_3(0|0)|0;
       $193 = tempRet0;
       $194 = HEAP8[$108>>0]|0;
       $195 = ($194<<24>>24)<(0);
       if (!($195)) {
        ___clang_call_terminate($192);
        // unreachable;
       }
       $196 = HEAP32[$106>>2]|0;
       __ZdlPv($196);
       ___clang_call_terminate($192);
       // unreachable;
      }
     }
    }
    HEAP32[$107>>2] = 0;
    $189 = HEAP8[$108>>0]|0;
    $190 = ($189<<24>>24)<(0);
    if (!($190)) {
     ___resumeException($180|0);
     // unreachable;
    }
    $191 = HEAP32[$106>>2]|0;
    __ZdlPv($191);
    ___resumeException($180|0);
    // unreachable;
   }
  } while(0);
  $$$3 = $$170 | $$3;
  $$5 = $$$3;
  STACKTOP = sp;return ($$5|0);
 }
 }
 return (0)|0;
}
function __ZNSt3__214__split_bufferIN5osgDB12ReaderWriter10ReadResultERNS_9allocatorIS3_EEED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==($2|0);
 L1: do {
  if (!($5)) {
   $7 = $4;
   while(1) {
    $6 = ((($7)) + -20|0);
    HEAP32[$3>>2] = $6;
    $8 = ((($7)) + -4|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = ($9|0)==(0|0);
    if (!($10)) {
     $11 = ((($9)) + 8|0);
     $12 = HEAP32[$11>>2]|0;HEAP32[$11>>2] = (($12-1)|0);
     $13 = ($12|0)==(1);
     if ($13) {
      __THREW__ = 0;
      invoke_viii(3262,($9|0),1,1);
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if ($15) {
       break;
      }
     }
    }
    HEAP32[$8>>2] = 0;
    $16 = ((($7)) + -16|0);
    $17 = ((($16)) + 11|0);
    $18 = HEAP8[$17>>0]|0;
    $19 = ($18<<24>>24)<(0);
    if ($19) {
     $22 = HEAP32[$16>>2]|0;
     __ZdlPv($22);
    }
    $20 = HEAP32[$3>>2]|0;
    $21 = ($20|0)==($2|0);
    if ($21) {
     break L1;
    } else {
     $7 = $20;
    }
   }
   $23 = ___cxa_find_matching_catch_2()|0;
   $24 = tempRet0;
   $25 = ((($7)) + -16|0);
   $26 = ((($25)) + 11|0);
   $27 = HEAP8[$26>>0]|0;
   $28 = ($27<<24>>24)<(0);
   if (!($28)) {
    ___cxa_call_unexpected(($23|0));
    // unreachable;
   }
   $29 = HEAP32[$25>>2]|0;
   __ZdlPv($29);
   ___cxa_call_unexpected(($23|0));
   // unreachable;
  }
 } while(0);
 $30 = HEAP32[$0>>2]|0;
 $31 = ($30|0)==(0|0);
 if ($31) {
  return;
 }
 __ZdlPv($30);
 return;
}
function __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7ref_ptrIN5osgDB7ArchiveEEEEENS_19__map_value_compareIS7_SD_NS_4lessIS7_EELb1EEENS5_ISD_EEE4findIS7_EENS_15__tree_iteratorISD_PNS_11__tree_nodeISD_PvEEiEERKT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$ph$lcssa$i = 0, $$0$ph15$i = 0, $$07$ph14$i = 0, $$0711$i = 0, $$sroa$0$0 = 0, $$sroa$speculated$i$i$i$i$i = 0, $$sroa$speculated$i$i$i$i$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 do {
  if (!($4)) {
   $5 = ((($1)) + 11|0);
   $6 = HEAP8[$5>>0]|0;
   $7 = ($6<<24>>24)<(0);
   $8 = ((($1)) + 4|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = $6&255;
   $11 = $7 ? $9 : $10;
   $12 = HEAP32[$1>>2]|0;
   $13 = $7 ? $12 : $1;
   $$0$ph15$i = $2;$$07$ph14$i = $3;
   L3: while(1) {
    $$0711$i = $$07$ph14$i;
    while(1) {
     $14 = ((($$0711$i)) + 16|0);
     $15 = ((($14)) + 11|0);
     $16 = HEAP8[$15>>0]|0;
     $17 = ($16<<24>>24)<(0);
     $18 = ((($$0711$i)) + 20|0);
     $19 = HEAP32[$18>>2]|0;
     $20 = $16&255;
     $21 = $17 ? $19 : $20;
     $22 = ($11>>>0)<($21>>>0);
     $$sroa$speculated$i$i$i$i$i$i = $22 ? $11 : $21;
     $23 = ($$sroa$speculated$i$i$i$i$i$i|0)==(0);
     if ($23) {
      label = 6;
     } else {
      $24 = HEAP32[$14>>2]|0;
      $25 = $17 ? $24 : $14;
      $26 = (_memcmp($25,$13,$$sroa$speculated$i$i$i$i$i$i)|0);
      $27 = ($26|0)==(0);
      if ($27) {
       label = 6;
      } else {
       $29 = ($26|0)<(0);
       if (!($29)) {
        break;
       }
      }
     }
     if ((label|0) == 6) {
      label = 0;
      $28 = ($21>>>0)<($11>>>0);
      if (!($28)) {
       break;
      }
     }
     $32 = ((($$0711$i)) + 4|0);
     $33 = HEAP32[$32>>2]|0;
     $34 = ($33|0)==(0|0);
     if ($34) {
      $$0$ph$lcssa$i = $$0$ph15$i;
      break L3;
     } else {
      $$0711$i = $33;
     }
    }
    $30 = HEAP32[$$0711$i>>2]|0;
    $31 = ($30|0)==(0|0);
    if ($31) {
     $$0$ph$lcssa$i = $$0711$i;
     break;
    } else {
     $$0$ph15$i = $$0711$i;$$07$ph14$i = $30;
    }
   }
   $35 = ($$0$ph$lcssa$i|0)==($2|0);
   if (!($35)) {
    $36 = ((($$0$ph$lcssa$i)) + 16|0);
    $37 = ((($36)) + 11|0);
    $38 = HEAP8[$37>>0]|0;
    $39 = ($38<<24>>24)<(0);
    $40 = ((($$0$ph$lcssa$i)) + 20|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = $38&255;
    $43 = $39 ? $41 : $42;
    $44 = ($43>>>0)<($11>>>0);
    $$sroa$speculated$i$i$i$i$i = $44 ? $43 : $11;
    $45 = ($$sroa$speculated$i$i$i$i$i|0)==(0);
    if (!($45)) {
     $46 = HEAP32[$36>>2]|0;
     $47 = $39 ? $46 : $36;
     $48 = (_memcmp($13,$47,$$sroa$speculated$i$i$i$i$i)|0);
     $49 = ($48|0)==(0);
     if (!($49)) {
      $51 = ($48|0)<(0);
      if ($51) {
       break;
      } else {
       $$sroa$0$0 = $$0$ph$lcssa$i;
      }
      return ($$sroa$0$0|0);
     }
    }
    $50 = ($11>>>0)<($43>>>0);
    if (!($50)) {
     $$sroa$0$0 = $$0$ph$lcssa$i;
     return ($$sroa$0$0|0);
    }
   }
  }
 } while(0);
 $$sroa$0$0 = $2;
 return ($$sroa$0$0|0);
}
function __ZN5osgDB8Registry18readImplementationERKNS0_11ReadFunctorENS_7Options16CacheHintOptionsE($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $$033 = 0, $$1 = 0, $$134 = 0, $$2 = 0, $$235 = 0, $$3 = 0, $$336 = 0, $$4 = 0, $$437 = 0, $$5 = 0, $$538 = 0, $$6 = 0, $$639 = 0, $$7 = 0, $$740 = 0, $$9 = 0, $$942 = 0, $$not46 = 0, $$old1 = 0;
 var $$pr = 0, $$pr92$pre = 0, $$pr94 = 0, $$pre = 0, $$pre$phi101Z2D = 0, $$pre$phi102Z2D = 0, $$pre$phi104Z2D = 0, $$pre$phi97Z2D = 0, $$pre$phi98Z2D = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0;
 var $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0;
 var $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0;
 var $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0;
 var $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0;
 var $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0;
 var $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0;
 var $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0;
 var $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0;
 var $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $brmerge47 = 0, $eh$lpad$body78$indexZ2D = 0, $eh$lpad$body88$index2Z2D = 0, $eh$lpad$body88$indexZ2D = 0, $notlhs = 0, $notrhs = 0, $or$cond$not = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(80|0);
 $4 = sp + 68|0;
 $5 = sp + 56|0;
 $6 = sp + 52|0;
 $7 = sp + 48|0;
 $8 = sp + 36|0;
 $9 = sp + 16|0;
 $10 = sp + 12|0;
 $11 = sp;
 $12 = ((($2)) + 4|0);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_($5,$12);
 $13 = ((($2)) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)!=(0|0);
 if ($15) {
  $16 = ((($14)) + 72|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = ($17|0)==(0|0);
  if ($18) {
   label = 3;
  } else {
   $$old1 = ($3|0)==(8);
   if ($$old1) {
    label = 129;
   } else {
    $27 = $17;$316 = 1;
    label = 5;
   }
  }
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $19 = ((($1)) + 212|0);
  $20 = HEAP32[$19>>2]|0;
  $notlhs = ($20|0)==(0|0);
  $notrhs = ($3|0)==(8);
  $or$cond$not = $notrhs | $notlhs;
  $$not46 = $15 ^ 1;
  $brmerge47 = $or$cond$not | $$not46;
  if ($brmerge47) {
   label = 129;
  } else {
   $27 = 0;$316 = 0;
   label = 5;
  }
 }
 L6: do {
  if ((label|0) == 5) {
   $21 = ((($14)) + 68|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = $22 & $3;
   $24 = ($23|0)==(0);
   if ($24) {
    label = 129;
   } else {
    if ($316) {
     __THREW__ = 0;
     invoke_viiii(4217,($6|0),($27|0),($5|0),($14|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      label = 6;
      break;
     }
     $$pre = HEAP32[$6>>2]|0;
     $30 = ($$pre|0)==(0|0);
     if ($30) {
      $$pre$phi97Z2D = $6;
      label = 11;
     } else {
      $$pre$phi102Z2D = $6;$72 = $$pre;
      label = 31;
     }
    } else {
     HEAP32[$6>>2] = 0;
     $$pre$phi97Z2D = $6;
     label = 11;
    }
    L13: do {
     if ((label|0) == 11) {
      $31 = ((($1)) + 212|0);
      $32 = HEAP32[$31>>2]|0;
      $33 = ($32|0)==(0|0);
      L15: do {
       if (!($33)) {
        __THREW__ = 0;
        invoke_viiii(4217,($7|0),($32|0),($5|0),($14|0));
        $34 = __THREW__; __THREW__ = 0;
        $35 = $34&1;
        do {
         if ($35) {
          label = 24;
         } else {
          $36 = HEAP32[$$pre$phi97Z2D>>2]|0;
          $37 = HEAP32[$7>>2]|0;
          $38 = ($36|0)==($37|0);
          if ($38) {
           $48 = $36;
          } else {
           HEAP32[$$pre$phi97Z2D>>2] = $37;
           $39 = ($37|0)==(0|0);
           if (!($39)) {
            $40 = ((($37)) + 8|0);
            $41 = HEAP32[$40>>2]|0;HEAP32[$40>>2] = (($41+1)|0);
           }
           $42 = ($36|0)==(0|0);
           if (!($42)) {
            $43 = ((($36)) + 8|0);
            $44 = HEAP32[$43>>2]|0;HEAP32[$43>>2] = (($44-1)|0);
            $45 = ($44|0)==(1);
            if ($45) {
             __THREW__ = 0;
             invoke_viii(3262,($36|0),1,1);
             $46 = __THREW__; __THREW__ = 0;
             $47 = $46&1;
             if ($47) {
              $59 = ___cxa_find_matching_catch_2()|0;
              $60 = tempRet0;
              $61 = HEAP32[$7>>2]|0;
              $62 = ($61|0)==(0|0);
              if (!($62)) {
               $63 = ((($61)) + 8|0);
               $64 = HEAP32[$63>>2]|0;HEAP32[$63>>2] = (($64-1)|0);
               $65 = ($64|0)==(1);
               if ($65) {
                __THREW__ = 0;
                invoke_viii(3262,($61|0),1,1);
                $66 = __THREW__; __THREW__ = 0;
                $67 = $66&1;
                if ($67) {
                 break L13;
                }
               }
              }
              HEAP32[$7>>2] = 0;
              $$0 = $60;$$033 = $59;
              break;
             }
            }
           }
           $$pr = HEAP32[$7>>2]|0;
           $48 = $$pr;
          }
          $49 = ($48|0)==(0|0);
          if (!($49)) {
           $50 = ((($48)) + 8|0);
           $51 = HEAP32[$50>>2]|0;HEAP32[$50>>2] = (($51-1)|0);
           $52 = ($51|0)==(1);
           if ($52) {
            __THREW__ = 0;
            invoke_viii(3262,($48|0),1,1);
            $53 = __THREW__; __THREW__ = 0;
            $54 = $53&1;
            if ($54) {
             label = 24;
             break;
            }
           }
          }
          $$pr92$pre = HEAP32[$$pre$phi97Z2D>>2]|0;
          $68 = ($$pr92$pre|0)==(0|0);
          if ($68) {
           break L15;
          } else {
           $$pre$phi102Z2D = $$pre$phi97Z2D;$72 = $$pr92$pre;
           label = 31;
           break L13;
          }
         }
        } while(0);
        if ((label|0) == 24) {
         $57 = ___cxa_find_matching_catch_2()|0;
         $58 = tempRet0;
         $$0 = $58;$$033 = $57;
        }
        $$6 = $$0;$$639 = $$033;$$pre$phi98Z2D = $$pre$phi97Z2D;
        label = 124;
        break L13;
       }
      } while(0);
      __THREW__ = 0;
      invoke_viii(4218,($9|0),($1|0),($2|0));
      $104 = __THREW__; __THREW__ = 0;
      $105 = $104&1;
      if ($105) {
       $$pre$phi101Z2D = $$pre$phi97Z2D;
       label = 23;
      } else {
       $106 = ((($9)) + 16|0);
       $107 = HEAP32[$106>>2]|0;
       $108 = ($107|0)==(0|0);
       L43: do {
        if ($108) {
         __THREW__ = 0;
         $192 = (invoke_ii(3265,4)|0);
         $193 = __THREW__; __THREW__ = 0;
         $194 = $193&1;
         if ($194) {
          label = 62;
         } else {
          if ($192) {
           __THREW__ = 0;
           $195 = (invoke_ii(3266,4)|0);
           $196 = __THREW__; __THREW__ = 0;
           $197 = $196&1;
           if ($197) {
            label = 62;
           } else {
            __THREW__ = 0;
            $198 = (invoke_iiii(3267,($195|0),(167862|0),26)|0);
            $199 = __THREW__; __THREW__ = 0;
            $200 = $199&1;
            if ($200) {
             label = 62;
            } else {
             $201 = ((($5)) + 11|0);
             $202 = HEAP8[$201>>0]|0;
             $203 = ($202<<24>>24)<(0);
             $204 = HEAP32[$5>>2]|0;
             $205 = $203 ? $204 : $5;
             $206 = ((($5)) + 4|0);
             $207 = HEAP32[$206>>2]|0;
             $208 = $202&255;
             $209 = $203 ? $207 : $208;
             __THREW__ = 0;
             $210 = (invoke_iiii(3267,($198|0),($205|0),($209|0))|0);
             $211 = __THREW__; __THREW__ = 0;
             $212 = $211&1;
             if ($212) {
              label = 62;
             } else {
              $213 = HEAP32[$210>>2]|0;
              $214 = ((($213)) + -12|0);
              $215 = HEAP32[$214>>2]|0;
              $216 = (($210) + ($215)|0);
              __THREW__ = 0;
              invoke_vii(3257,($4|0),($216|0));
              $217 = __THREW__; __THREW__ = 0;
              $218 = $217&1;
              if ($218) {
               label = 62;
              } else {
               __THREW__ = 0;
               $219 = (invoke_iii(3255,($4|0),(215188|0))|0);
               $220 = __THREW__; __THREW__ = 0;
               $221 = $220&1;
               if (!($221)) {
                $222 = HEAP32[$219>>2]|0;
                $223 = ((($222)) + 28|0);
                $224 = HEAP32[$223>>2]|0;
                __THREW__ = 0;
                $225 = (invoke_iii($224|0,($219|0),10)|0);
                $226 = __THREW__; __THREW__ = 0;
                $227 = $226&1;
                if (!($227)) {
                 __THREW__ = 0;
                 invoke_vi(3263,($4|0));
                 $234 = __THREW__; __THREW__ = 0;
                 $235 = $234&1;
                 if ($235) {
                  label = 62;
                  break;
                 }
                 __THREW__ = 0;
                 (invoke_iii(3268,($210|0),($225|0))|0);
                 $236 = __THREW__; __THREW__ = 0;
                 $237 = $236&1;
                 if ($237) {
                  label = 62;
                  break;
                 }
                 __THREW__ = 0;
                 (invoke_ii(3269,($210|0))|0);
                 $238 = __THREW__; __THREW__ = 0;
                 $239 = $238&1;
                 if ($239) {
                  label = 62;
                  break;
                 } else {
                  label = 99;
                  break;
                 }
                }
               }
               $228 = ___cxa_find_matching_catch_2()|0;
               $229 = tempRet0;
               __THREW__ = 0;
               invoke_vi(3263,($4|0));
               $230 = __THREW__; __THREW__ = 0;
               $231 = $230&1;
               if ($231) {
                $232 = ___cxa_find_matching_catch_3(0|0)|0;
                $233 = tempRet0;
                ___clang_call_terminate($232);
                // unreachable;
               } else {
                $eh$lpad$body88$index2Z2D = $229;$eh$lpad$body88$indexZ2D = $228;
                label = 63;
                break;
               }
              }
             }
            }
           }
          } else {
           label = 99;
          }
         }
        } else {
         $109 = HEAP32[$31>>2]|0;
         __THREW__ = 0;
         invoke_viiii(4217,($10|0),($109|0),($5|0),($14|0));
         $110 = __THREW__; __THREW__ = 0;
         $111 = $110&1;
         do {
          if ($111) {
           label = 64;
          } else {
           $112 = HEAP32[$$pre$phi97Z2D>>2]|0;
           $113 = HEAP32[$10>>2]|0;
           $114 = ($112|0)==($113|0);
           if ($114) {
            $124 = $112;
           } else {
            HEAP32[$$pre$phi97Z2D>>2] = $113;
            $115 = ($113|0)==(0|0);
            if (!($115)) {
             $116 = ((($113)) + 8|0);
             $117 = HEAP32[$116>>2]|0;HEAP32[$116>>2] = (($117+1)|0);
            }
            $118 = ($112|0)==(0|0);
            if (!($118)) {
             $119 = ((($112)) + 8|0);
             $120 = HEAP32[$119>>2]|0;HEAP32[$119>>2] = (($120-1)|0);
             $121 = ($120|0)==(1);
             if ($121) {
              __THREW__ = 0;
              invoke_viii(3262,($112|0),1,1);
              $122 = __THREW__; __THREW__ = 0;
              $123 = $122&1;
              if ($123) {
               $149 = ___cxa_find_matching_catch_2()|0;
               $150 = tempRet0;
               $151 = HEAP32[$10>>2]|0;
               $152 = ($151|0)==(0|0);
               do {
                if (!($152)) {
                 $153 = ((($151)) + 8|0);
                 $154 = HEAP32[$153>>2]|0;HEAP32[$153>>2] = (($154-1)|0);
                 $155 = ($154|0)==(1);
                 if (!($155)) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_viii(3262,($151|0),1,1);
                 $156 = __THREW__; __THREW__ = 0;
                 $157 = $156&1;
                 if ($157) {
                  break L13;
                 }
                }
               } while(0);
               HEAP32[$10>>2] = 0;
               $$2 = $150;$$235 = $149;
               break;
              }
             }
            }
            $$pr94 = HEAP32[$10>>2]|0;
            $124 = $$pr94;
           }
           $125 = ($124|0)==(0|0);
           if (!($125)) {
            $126 = ((($124)) + 8|0);
            $127 = HEAP32[$126>>2]|0;HEAP32[$126>>2] = (($127-1)|0);
            $128 = ($127|0)==(1);
            if ($128) {
             __THREW__ = 0;
             invoke_viii(3262,($124|0),1,1);
             $129 = __THREW__; __THREW__ = 0;
             $130 = $129&1;
             if ($130) {
              label = 64;
              break;
             }
            }
           }
           $131 = HEAP32[$$pre$phi97Z2D>>2]|0;
           $132 = ($131|0)==(0|0);
           if ($132) {
            if ($316) {
             __THREW__ = 0;
             $180 = (invoke_ii(4176,($9|0))|0);
             $181 = __THREW__; __THREW__ = 0;
             $182 = $181&1;
             if ($182) {
              label = 62;
              break L43;
             }
             __THREW__ = 0;
             invoke_viiidi(4219,($27|0),($5|0),($180|0),0.0,($14|0));
             $183 = __THREW__; __THREW__ = 0;
             $184 = $183&1;
             if ($184) {
              label = 62;
              break L43;
             } else {
              label = 99;
              break L43;
             }
            }
            $185 = HEAP32[$31>>2]|0;
            $186 = ($185|0)==(0|0);
            if ($186) {
             label = 99;
             break L43;
            }
            __THREW__ = 0;
            $187 = (invoke_ii(4176,($9|0))|0);
            $188 = __THREW__; __THREW__ = 0;
            $189 = $188&1;
            if ($189) {
             label = 62;
             break L43;
            }
            __THREW__ = 0;
            invoke_viiidi(4219,($185|0),($5|0),($187|0),0.0,($14|0));
            $190 = __THREW__; __THREW__ = 0;
            $191 = $190&1;
            if ($191) {
             label = 62;
             break L43;
            } else {
             label = 99;
             break L43;
            }
           }
           $133 = HEAP32[$2>>2]|0;
           $134 = ((($133)) + 16|0);
           $135 = HEAP32[$134>>2]|0;
           __THREW__ = 0;
           $136 = (invoke_iii($135|0,($2|0),($131|0))|0);
           $137 = __THREW__; __THREW__ = 0;
           $138 = $137&1;
           if ($138) {
            label = 62;
            break L43;
           }
           if ($136) {
            $139 = HEAP32[$$pre$phi97Z2D>>2]|0;
            HEAP32[$0>>2] = 5;
            $140 = ((($0)) + 4|0);
            ;HEAP32[$140>>2]=0|0;HEAP32[$140+4>>2]=0|0;HEAP32[$140+8>>2]=0|0;
            $141 = ((($0)) + 16|0);
            HEAP32[$141>>2] = $139;
            $142 = ($139|0)==(0|0);
            if ($142) {
             label = 102;
             break L43;
            }
            $143 = ((($139)) + 8|0);
            $144 = HEAP32[$143>>2]|0;HEAP32[$143>>2] = (($144+1)|0);
            label = 102;
            break L43;
           }
           ;HEAP32[$11>>2]=0|0;HEAP32[$11+4>>2]=0|0;HEAP32[$11+8>>2]=0|0;
           __THREW__ = 0;
           $158 = (invoke_ii(3276,48)|0);
           $159 = __THREW__; __THREW__ = 0;
           $160 = $159&1;
           do {
            if ($160) {
             $172 = ___cxa_find_matching_catch_2()|0;
             $173 = tempRet0;
             $$3 = $173;$$336 = $172;
            } else {
             HEAP32[$11>>2] = $158;
             $161 = ((($11)) + 8|0);
             HEAP32[$161>>2] = -2147483600;
             $162 = ((($11)) + 4|0);
             HEAP32[$162>>2] = 42;
             dest=$158; src=167819; stop=dest+42|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
             $163 = ((($158)) + 42|0);
             HEAP8[$163>>0] = 0;
             HEAP32[$0>>2] = 3;
             $164 = ((($0)) + 4|0);
             __THREW__ = 0;
             invoke_vii(3457,($164|0),($11|0));
             $165 = __THREW__; __THREW__ = 0;
             $166 = $165&1;
             if ($166) {
              $174 = ___cxa_find_matching_catch_2()|0;
              $175 = tempRet0;
              $176 = ((($11)) + 11|0);
              $177 = HEAP8[$176>>0]|0;
              $178 = ($177<<24>>24)<(0);
              if (!($178)) {
               $$3 = $175;$$336 = $174;
               break;
              }
              $179 = HEAP32[$11>>2]|0;
              __ZdlPv($179);
              $$3 = $175;$$336 = $174;
              break;
             }
             $167 = ((($0)) + 16|0);
             HEAP32[$167>>2] = 0;
             $168 = ((($11)) + 11|0);
             $169 = HEAP8[$168>>0]|0;
             $170 = ($169<<24>>24)<(0);
             if ($170) {
              $171 = HEAP32[$11>>2]|0;
              __ZdlPv($171);
             }
             label = 102;
             break L43;
            }
           } while(0);
           $$4 = $$3;$$437 = $$336;
           label = 111;
           break L43;
          }
         } while(0);
         if ((label|0) == 64) {
          $147 = ___cxa_find_matching_catch_2()|0;
          $148 = tempRet0;
          $$2 = $148;$$235 = $147;
         }
         $$4 = $$2;$$437 = $$235;
         label = 111;
        }
       } while(0);
       if ((label|0) == 99) {
        $240 = HEAP32[$9>>2]|0;
        HEAP32[$0>>2] = $240;
        $241 = ((($0)) + 4|0);
        $242 = ((($9)) + 4|0);
        __THREW__ = 0;
        invoke_vii(3457,($241|0),($242|0));
        $243 = __THREW__; __THREW__ = 0;
        $244 = $243&1;
        if ($244) {
         label = 62;
        } else {
         $245 = ((($0)) + 16|0);
         $246 = HEAP32[$106>>2]|0;
         HEAP32[$245>>2] = $246;
         $247 = ($246|0)==(0|0);
         if ($247) {
          label = 102;
         } else {
          $248 = ((($246)) + 8|0);
          $249 = HEAP32[$248>>2]|0;HEAP32[$248>>2] = (($249+1)|0);
          label = 102;
         }
        }
       }
       do {
        if ((label|0) == 62) {
         $145 = ___cxa_find_matching_catch_2()|0;
         $146 = tempRet0;
         $eh$lpad$body88$index2Z2D = $146;$eh$lpad$body88$indexZ2D = $145;
         label = 63;
        }
        else if ((label|0) == 102) {
         $250 = HEAP32[$106>>2]|0;
         $251 = ($250|0)==(0|0);
         if (!($251)) {
          $252 = ((($250)) + 8|0);
          $253 = HEAP32[$252>>2]|0;HEAP32[$252>>2] = (($253-1)|0);
          $254 = ($253|0)==(1);
          if ($254) {
           __THREW__ = 0;
           invoke_viii(3262,($250|0),1,1);
           $255 = __THREW__; __THREW__ = 0;
           $256 = $255&1;
           if ($256) {
            $262 = ___cxa_find_matching_catch_2()|0;
            $263 = tempRet0;
            $264 = ((($9)) + 4|0);
            $265 = ((($264)) + 11|0);
            $266 = HEAP8[$265>>0]|0;
            $267 = ($266<<24>>24)<(0);
            if ($267) {
             $268 = HEAP32[$264>>2]|0;
             __ZdlPv($268);
            }
            $$5 = $263;$$538 = $262;
            break;
           }
          }
         }
         HEAP32[$106>>2] = 0;
         $257 = ((($9)) + 4|0);
         $258 = ((($257)) + 11|0);
         $259 = HEAP8[$258>>0]|0;
         $260 = ($259<<24>>24)<(0);
         if ($260) {
          $261 = HEAP32[$257>>2]|0;
          __ZdlPv($261);
         }
         $$pre$phi104Z2D = $$pre$phi97Z2D;
         label = 119;
         break L13;
        }
       } while(0);
       if ((label|0) == 63) {
        $$4 = $eh$lpad$body88$index2Z2D;$$437 = $eh$lpad$body88$indexZ2D;
        label = 111;
       }
       if ((label|0) == 111) {
        $269 = HEAP32[$106>>2]|0;
        $270 = ($269|0)==(0|0);
        if (!($270)) {
         $271 = ((($269)) + 8|0);
         $272 = HEAP32[$271>>2]|0;HEAP32[$271>>2] = (($272-1)|0);
         $273 = ($272|0)==(1);
         if ($273) {
          __THREW__ = 0;
          invoke_viii(3262,($269|0),1,1);
          $274 = __THREW__; __THREW__ = 0;
          $275 = $274&1;
          if ($275) {
           $281 = ___cxa_find_matching_catch_3(0|0)|0;
           $282 = tempRet0;
           $283 = ((($9)) + 4|0);
           $284 = ((($283)) + 11|0);
           $285 = HEAP8[$284>>0]|0;
           $286 = ($285<<24>>24)<(0);
           if (!($286)) {
            $eh$lpad$body78$indexZ2D = $281;
            ___clang_call_terminate($eh$lpad$body78$indexZ2D);
            // unreachable;
           }
           $287 = HEAP32[$283>>2]|0;
           __ZdlPv($287);
           $eh$lpad$body78$indexZ2D = $281;
           ___clang_call_terminate($eh$lpad$body78$indexZ2D);
           // unreachable;
          }
         }
        }
        HEAP32[$106>>2] = 0;
        $276 = ((($9)) + 4|0);
        $277 = ((($276)) + 11|0);
        $278 = HEAP8[$277>>0]|0;
        $279 = ($278<<24>>24)<(0);
        if ($279) {
         $280 = HEAP32[$276>>2]|0;
         __ZdlPv($280);
         $$5 = $$4;$$538 = $$437;
        } else {
         $$5 = $$4;$$538 = $$437;
        }
       }
       $$6 = $$5;$$639 = $$538;$$pre$phi98Z2D = $$pre$phi97Z2D;
       label = 124;
      }
     }
    } while(0);
    L143: do {
     if ((label|0) == 31) {
      $69 = HEAP32[$2>>2]|0;
      $70 = ((($69)) + 16|0);
      $71 = HEAP32[$70>>2]|0;
      __THREW__ = 0;
      $73 = (invoke_iii($71|0,($2|0),($72|0))|0);
      $74 = __THREW__; __THREW__ = 0;
      $75 = $74&1;
      if ($75) {
       $$pre$phi101Z2D = $$pre$phi102Z2D;
       label = 23;
      } else {
       if ($73) {
        $76 = HEAP32[$$pre$phi102Z2D>>2]|0;
        HEAP32[$0>>2] = 5;
        $77 = ((($0)) + 4|0);
        ;HEAP32[$77>>2]=0|0;HEAP32[$77+4>>2]=0|0;HEAP32[$77+8>>2]=0|0;
        $78 = ((($0)) + 16|0);
        HEAP32[$78>>2] = $76;
        $79 = ($76|0)==(0|0);
        if ($79) {
         $$pre$phi104Z2D = $$pre$phi102Z2D;
         label = 119;
         break;
        }
        $80 = ((($76)) + 8|0);
        $81 = HEAP32[$80>>2]|0;HEAP32[$80>>2] = (($81+1)|0);
        $$pre$phi104Z2D = $$pre$phi102Z2D;
        label = 119;
        break;
       }
       ;HEAP32[$8>>2]=0|0;HEAP32[$8+4>>2]=0|0;HEAP32[$8+8>>2]=0|0;
       __THREW__ = 0;
       $82 = (invoke_ii(3276,48)|0);
       $83 = __THREW__; __THREW__ = 0;
       $84 = $83&1;
       do {
        if ($84) {
         $96 = ___cxa_find_matching_catch_2()|0;
         $97 = tempRet0;
         $$1 = $97;$$134 = $96;
        } else {
         HEAP32[$8>>2] = $82;
         $85 = ((($8)) + 8|0);
         HEAP32[$85>>2] = -2147483600;
         $86 = ((($8)) + 4|0);
         HEAP32[$86>>2] = 42;
         dest=$82; src=167819; stop=dest+42|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
         $87 = ((($82)) + 42|0);
         HEAP8[$87>>0] = 0;
         HEAP32[$0>>2] = 3;
         $88 = ((($0)) + 4|0);
         __THREW__ = 0;
         invoke_vii(3457,($88|0),($8|0));
         $89 = __THREW__; __THREW__ = 0;
         $90 = $89&1;
         if ($90) {
          $98 = ___cxa_find_matching_catch_2()|0;
          $99 = tempRet0;
          $100 = ((($8)) + 11|0);
          $101 = HEAP8[$100>>0]|0;
          $102 = ($101<<24>>24)<(0);
          if (!($102)) {
           $$1 = $99;$$134 = $98;
           break;
          }
          $103 = HEAP32[$8>>2]|0;
          __ZdlPv($103);
          $$1 = $99;$$134 = $98;
          break;
         }
         $91 = ((($0)) + 16|0);
         HEAP32[$91>>2] = 0;
         $92 = ((($8)) + 11|0);
         $93 = HEAP8[$92>>0]|0;
         $94 = ($93<<24>>24)<(0);
         if ($94) {
          $95 = HEAP32[$8>>2]|0;
          __ZdlPv($95);
         }
         $$pre$phi104Z2D = $$pre$phi102Z2D;
         label = 119;
         break L143;
        }
       } while(0);
       $$6 = $$1;$$639 = $$134;$$pre$phi98Z2D = $$pre$phi102Z2D;
       label = 124;
      }
     }
    } while(0);
    do {
     if ((label|0) == 23) {
      $55 = ___cxa_find_matching_catch_2()|0;
      $56 = tempRet0;
      $$6 = $56;$$639 = $55;$$pre$phi98Z2D = $$pre$phi101Z2D;
      label = 124;
     }
     else if ((label|0) == 119) {
      $288 = HEAP32[$$pre$phi104Z2D>>2]|0;
      $289 = ($288|0)==(0|0);
      if (!($289)) {
       $290 = ((($288)) + 8|0);
       $291 = HEAP32[$290>>2]|0;HEAP32[$290>>2] = (($291-1)|0);
       $292 = ($291|0)==(1);
       if ($292) {
        __THREW__ = 0;
        invoke_viii(3262,($288|0),1,1);
        $293 = __THREW__; __THREW__ = 0;
        $294 = $293&1;
        if ($294) {
         $295 = ___cxa_find_matching_catch_2()|0;
         $296 = tempRet0;
         $$7 = $296;$$740 = $295;
         label = 128;
         break;
        }
       }
      }
      HEAP32[$$pre$phi104Z2D>>2] = 0;
      label = 130;
      break L6;
     }
    } while(0);
    do {
     if ((label|0) == 124) {
      $297 = HEAP32[$$pre$phi98Z2D>>2]|0;
      $298 = ($297|0)==(0|0);
      if (!($298)) {
       $299 = ((($297)) + 8|0);
       $300 = HEAP32[$299>>2]|0;HEAP32[$299>>2] = (($300-1)|0);
       $301 = ($300|0)==(1);
       if ($301) {
        __THREW__ = 0;
        invoke_viii(3262,($297|0),1,1);
        $302 = __THREW__; __THREW__ = 0;
        $303 = $302&1;
        if ($303) {
         break;
        }
       }
      }
      HEAP32[$$pre$phi98Z2D>>2] = 0;
      $$7 = $$6;$$740 = $$639;
      label = 128;
     }
    } while(0);
    if ((label|0) == 128) {
     $$9 = $$7;$$942 = $$740;
     break;
    }
    $314 = ___cxa_find_matching_catch_3(0|0)|0;
    $315 = tempRet0;
    $eh$lpad$body78$indexZ2D = $314;
    ___clang_call_terminate($eh$lpad$body78$indexZ2D);
    // unreachable;
   }
  }
 } while(0);
 if ((label|0) == 129) {
  __THREW__ = 0;
  invoke_viii(4218,($0|0),($1|0),($2|0));
  $304 = __THREW__; __THREW__ = 0;
  $305 = $304&1;
  if ($305) {
   label = 6;
  } else {
   label = 130;
  }
 }
 if ((label|0) == 6) {
  $25 = ___cxa_find_matching_catch_2()|0;
  $26 = tempRet0;
  $$9 = $26;$$942 = $25;
 }
 else if ((label|0) == 130) {
  $306 = ((($5)) + 11|0);
  $307 = HEAP8[$306>>0]|0;
  $308 = ($307<<24>>24)<(0);
  if (!($308)) {
   STACKTOP = sp;return;
  }
  $309 = HEAP32[$5>>2]|0;
  __ZdlPv($309);
  STACKTOP = sp;return;
 }
 $310 = ((($5)) + 11|0);
 $311 = HEAP8[$310>>0]|0;
 $312 = ($311<<24>>24)<(0);
 if (!($312)) {
  ___resumeException($$942|0);
  // unreachable;
 }
 $313 = HEAP32[$5>>2]|0;
 __ZdlPv($313);
 ___resumeException($$942|0);
 // unreachable;
}
function __ZNSt3__23mapINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7ref_ptrIN5osgDB7ArchiveEEENS_4lessIS6_EENS4_INS_4pairIKS6_SB_EEEEEixERSF_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$014 = 0, $$pre$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = (__ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7ref_ptrIN5osgDB7ArchiveEEEEENS_19__map_value_compareIS7_SD_NS_4lessIS7_EELb1EEENS5_ISD_EEE12__find_equalIS7_EERPNS_16__tree_node_baseIPvEERPNS_15__tree_end_nodeISO_EERKT_($0,$2,$1)|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if (!($5)) {
  $$014 = $4;
  $26 = ((($$014)) + 28|0);
  STACKTOP = sp;return ($26|0);
 }
 $6 = (__Znwj(32)|0);
 $7 = ((($6)) + 16|0);
 __THREW__ = 0;
 invoke_vii(3457,($7|0),($1|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $10 = ___cxa_find_matching_catch_2()|0;
  $11 = tempRet0;
  __ZdlPv($6);
  ___resumeException($10|0);
  // unreachable;
 }
 $12 = ((($6)) + 28|0);
 HEAP32[$12>>2] = 0;
 $13 = HEAP32[$2>>2]|0;
 HEAP32[$6>>2] = 0;
 $14 = ((($6)) + 4|0);
 HEAP32[$14>>2] = 0;
 $15 = ((($6)) + 8|0);
 HEAP32[$15>>2] = $13;
 HEAP32[$3>>2] = $6;
 $16 = HEAP32[$0>>2]|0;
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==(0|0);
 if ($18) {
  $22 = $6;
 } else {
  $19 = $17;
  HEAP32[$0>>2] = $19;
  $$pre$i = HEAP32[$3>>2]|0;
  $22 = $$pre$i;
 }
 $20 = ((($0)) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($21,$22);
 $23 = ((($0)) + 8|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (($24) + 1)|0;
 HEAP32[$23>>2] = $25;
 $$014 = $6;
 $26 = ((($$014)) + 28|0);
 STACKTOP = sp;return ($26|0);
}
function __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7ref_ptrIN5osgDB7ArchiveEEEEENS_19__map_value_compareIS7_SD_NS_4lessIS7_EELb1EEENS5_ISD_EEE12__find_equalIS7_EERPNS_16__tree_node_baseIPvEERPNS_15__tree_end_nodeISO_EERKT_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$0$ph = 0, $$024 = 0, $$025 = 0, $$in = 0, $$sroa$speculated$i$i$i$i$i = 0, $$sroa$speculated$i$i$i$i$i26 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  HEAP32[$1>>2] = $3;
  $$025 = $3;
  return ($$025|0);
 }
 $6 = ((($0)) + 4|0);
 $7 = ((($2)) + 11|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = ($8<<24>>24)<(0);
 $10 = ((($2)) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $8&255;
 $13 = $9 ? $11 : $12;
 $14 = HEAP32[$2>>2]|0;
 $15 = $9 ? $14 : $2;
 $$0 = $6;$$024 = $4;
 while(1) {
  $16 = ((($$024)) + 16|0);
  $17 = ((($16)) + 11|0);
  $18 = HEAP8[$17>>0]|0;
  $19 = ($18<<24>>24)<(0);
  $20 = ((($$024)) + 20|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = $18&255;
  $23 = $19 ? $21 : $22;
  $24 = ($23>>>0)<($13>>>0);
  $$sroa$speculated$i$i$i$i$i26 = $24 ? $23 : $13;
  $25 = ($$sroa$speculated$i$i$i$i$i26|0)==(0);
  if ($25) {
   label = 6;
  } else {
   $26 = HEAP32[$16>>2]|0;
   $27 = $19 ? $26 : $16;
   $28 = (_memcmp($15,$27,$$sroa$speculated$i$i$i$i$i26)|0);
   $29 = ($28|0)==(0);
   if ($29) {
    label = 6;
   } else {
    $31 = ($28|0)<(0);
    if ($31) {
     label = 8;
    } else {
     label = 10;
    }
   }
  }
  if ((label|0) == 6) {
   label = 0;
   $30 = ($13>>>0)<($23>>>0);
   if ($30) {
    label = 8;
   } else {
    label = 10;
   }
  }
  if ((label|0) == 8) {
   label = 0;
   $32 = HEAP32[$$024>>2]|0;
   $33 = ($32|0)==(0|0);
   if ($33) {
    label = 9;
    break;
   } else {
    $$0$ph = $$024;$$in = $32;
   }
  }
  else if ((label|0) == 10) {
   label = 0;
   $34 = ($13>>>0)<($23>>>0);
   $$sroa$speculated$i$i$i$i$i = $34 ? $13 : $23;
   $35 = ($$sroa$speculated$i$i$i$i$i|0)==(0);
   if ($35) {
    label = 12;
   } else {
    $36 = HEAP32[$16>>2]|0;
    $37 = $19 ? $36 : $16;
    $38 = (_memcmp($37,$15,$$sroa$speculated$i$i$i$i$i)|0);
    $39 = ($38|0)==(0);
    if ($39) {
     label = 12;
    } else {
     $40 = ($38|0)<(0);
     if (!($40)) {
      label = 16;
      break;
     }
    }
   }
   if ((label|0) == 12) {
    label = 0;
    if (!($24)) {
     label = 16;
     break;
    }
   }
   $41 = ((($$024)) + 4|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = ($42|0)==(0|0);
   if ($43) {
    label = 15;
    break;
   } else {
    $$0$ph = $41;$$in = $42;
   }
  }
  $$0 = $$0$ph;$$024 = $$in;
 }
 if ((label|0) == 9) {
  HEAP32[$1>>2] = $$024;
  $$025 = $$024;
  return ($$025|0);
 }
 else if ((label|0) == 15) {
  HEAP32[$1>>2] = $$024;
  $$025 = $41;
  return ($$025|0);
 }
 else if ((label|0) == 16) {
  HEAP32[$1>>2] = $$024;
  $$025 = $$0;
  return ($$025|0);
 }
 return (0)|0;
}
function __ZN5osgDB8Registry11ReadFunctorD2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (75072);
 $1 = ((($0)) + 4|0);
 $2 = ((($1)) + 11|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)<(0);
 if (!($4)) {
  return;
 }
 $5 = HEAP32[$1>>2]|0;
 __ZdlPv($5);
 return;
}
function __ZN5osgDB8Registry18ReadArchiveFunctorD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (75072);
 $1 = ((($0)) + 4|0);
 $2 = ((($1)) + 11|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)<(0);
 if (!($4)) {
  __ZdlPv($0);
  return;
 }
 $5 = HEAP32[$1>>2]|0;
 __ZdlPv($5);
 __ZdlPv($0);
 return;
}
function __ZNK5osgDB8Registry18ReadArchiveFunctor6doReadERNS_12ReaderWriterE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + 168|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($1)) + 4|0);
 $7 = ((($1)) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($1)) + 24|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ((($1)) + 16|0);
 $12 = HEAP32[$11>>2]|0;
 FUNCTION_TABLE_viiiiii[$5 & 8191]($0,$2,$6,$8,$10,$12);
 return;
}
function __ZNK5osgDB8Registry18ReadArchiveFunctor7isValidERNS_12ReaderWriter10ReadResultE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__ZN5osgDB12ReaderWriter10ReadResult10getArchiveEv($1)|0);
 $3 = ($2|0)!=(0|0);
 return ($3|0);
}
function __ZNK5osgDB8Registry18ReadArchiveFunctor7isValidEPN3osg6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,32912,0)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK5osgDB8Registry18ReadArchiveFunctor9cloneTypeERKNSt3__212basic_stringIcNS2_11char_traitsIcEENS2_9allocatorIcEEEEPKNS_7OptionsE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (__Znwj(28)|0);
 $4 = ((($0)) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($0)) + 24|0);
 $7 = HEAP32[$6>>2]|0;
 HEAP32[$3>>2] = (75072);
 $8 = ((($3)) + 4|0);
 __THREW__ = 0;
 invoke_vii(3457,($8|0),($1|0));
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if ($10) {
  $14 = ___cxa_find_matching_catch_2()|0;
  $15 = tempRet0;
  __ZdlPv($3);
  ___resumeException($14|0);
  // unreachable;
 } else {
  $11 = ((($3)) + 16|0);
  HEAP32[$11>>2] = $2;
  HEAP32[$3>>2] = (75104);
  $12 = ((($3)) + 20|0);
  HEAP32[$12>>2] = $5;
  $13 = ((($3)) + 24|0);
  HEAP32[$13>>2] = $7;
  return ($3|0);
 }
 return (0)|0;
}
function __ZN5osgDB8Registry11ReadFunctorD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (75072);
 $1 = ((($0)) + 4|0);
 $2 = ((($1)) + 11|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)<(0);
 if (!($4)) {
  __ZdlPv($0);
  return;
 }
 $5 = HEAP32[$1>>2]|0;
 __ZdlPv($5);
 __ZdlPv($0);
 return;
}
function __ZN5osgDB8Registry24readObjectImplementationERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEPKNS_7OptionsE($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $4 = sp;
 HEAP32[$4>>2] = (75072);
 $5 = ((($4)) + 4|0);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_($5,$2);
 $6 = ((($4)) + 16|0);
 HEAP32[$6>>2] = $3;
 HEAP32[$4>>2] = (75136);
 __THREW__ = 0;
 invoke_viiii(4212,($0|0),($1|0),($4|0),16);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $13 = ___cxa_find_matching_catch_2()|0;
  $14 = tempRet0;
  HEAP32[$4>>2] = (75072);
  $15 = ((($5)) + 11|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = ($16<<24>>24)<(0);
  if (!($17)) {
   ___resumeException($13|0);
   // unreachable;
  }
  $18 = HEAP32[$5>>2]|0;
  __ZdlPv($18);
  ___resumeException($13|0);
  // unreachable;
 } else {
  HEAP32[$4>>2] = (75072);
  $9 = ((($5)) + 11|0);
  $10 = HEAP8[$9>>0]|0;
  $11 = ($10<<24>>24)<(0);
  if (!($11)) {
   STACKTOP = sp;return;
  }
  $12 = HEAP32[$5>>2]|0;
  __ZdlPv($12);
  STACKTOP = sp;return;
 }
}
function __ZN5osgDB8Registry17ReadObjectFunctorD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (75072);
 $1 = ((($0)) + 4|0);
 $2 = ((($1)) + 11|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)<(0);
 if (!($4)) {
  __ZdlPv($0);
  return;
 }
 $5 = HEAP32[$1>>2]|0;
 __ZdlPv($5);
 __ZdlPv($0);
 return;
}
function __ZNK5osgDB8Registry17ReadObjectFunctor6doReadERNS_12ReaderWriterE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + 176|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($1)) + 4|0);
 $7 = ((($1)) + 16|0);
 $8 = HEAP32[$7>>2]|0;
 FUNCTION_TABLE_viiii[$5 & 8191]($0,$2,$6,$8);
 return;
}
function __ZNK5osgDB8Registry17ReadObjectFunctor7isValidERNS_12ReaderWriter10ReadResultE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)!=(0|0);
 return ($4|0);
}
function __ZNK5osgDB8Registry17ReadObjectFunctor7isValidEPN3osg6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)!=(0|0);
 return ($2|0);
}
function __ZNK5osgDB8Registry17ReadObjectFunctor9cloneTypeERKNSt3__212basic_stringIcNS2_11char_traitsIcEENS2_9allocatorIcEEEEPKNS_7OptionsE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (__Znwj(20)|0);
 HEAP32[$3>>2] = (75072);
 $4 = ((($3)) + 4|0);
 __THREW__ = 0;
 invoke_vii(3457,($4|0),($1|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $8 = ___cxa_find_matching_catch_2()|0;
  $9 = tempRet0;
  __ZdlPv($3);
  ___resumeException($8|0);
  // unreachable;
 } else {
  $7 = ((($3)) + 16|0);
  HEAP32[$7>>2] = $2;
  HEAP32[$3>>2] = (75136);
  return ($3|0);
 }
 return (0)|0;
}
function __ZN5osgDB8Registry25writeObjectImplementationERKN3osg6ObjectERKNSt3__212basic_stringIcNS5_11char_traitsIcEENS5_9allocatorIcEEEEPKNS_7OptionsE($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0$i$i = 0, $$0$i$i39 = 0, $$0$i$i59 = 0, $$0$i$i76 = 0, $$0$ph$lcssa$i$i$i$i$i = 0, $$0$ph$lcssa$i$i$i$i$i37 = 0, $$0$ph$lcssa$i$i$i$i$i57 = 0, $$0$ph$lcssa$i$i$i$i$i74 = 0, $$0$ph13$i$i$i$i$i = 0, $$0$ph13$i$i$i$i$i32 = 0, $$0$ph13$i$i$i$i$i52 = 0, $$0$ph13$i$i$i$i$i69 = 0, $$017 = 0, $$019 = 0, $$07$ph12$i$i$i$i$i = 0, $$07$ph12$i$i$i$i$i33 = 0, $$07$ph12$i$i$i$i$i53 = 0, $$07$ph12$i$i$i$i$i70 = 0, $$0710$i$i$i$i$i = 0, $$0710$i$i$i$i$i35 = 0;
 var $$0710$i$i$i$i$i55 = 0, $$0710$i$i$i$i$i72 = 0, $$118 = 0, $$120 = 0, $$3 = 0, $$322 = 0, $$4 = 0, $$423 = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i$i$i = 0, $$pre$i$i$i100 = 0, $$pre$i$i28 = 0, $$pre$i$i48 = 0, $$pre$i$i65 = 0, $$pre$i102 = 0, $$sroa$011$025$i$i = 0, $$sroa$011$025$i$i30 = 0, $$sroa$011$025$i$i50 = 0;
 var $$sroa$011$025$i$i67 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0;
 var $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0;
 var $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0;
 var $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0;
 var $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0;
 var $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0;
 var $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0;
 var $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0;
 var $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0;
 var $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0;
 var $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0;
 var $299 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0;
 var $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index5Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(112|0);
 $5 = sp;
 $6 = sp + 92|0;
 $7 = sp + 80|0;
 $8 = sp + 60|0;
 $9 = sp + 48|0;
 $10 = sp + 36|0;
 $11 = sp + 24|0;
 $12 = sp + 8|0;
 HEAP32[$7>>2] = 0;
 $13 = ((($7)) + 4|0);
 HEAP32[$13>>2] = 0;
 $14 = ((($7)) + 8|0);
 HEAP32[$14>>2] = 0;
 $15 = ((($1)) + 72|0);
 $16 = ((($1)) + 60|0);
 HEAP32[$8>>2] = $15;
 $17 = ((($8)) + 4|0);
 HEAP32[$17>>2] = $16;
 $18 = ((($8)) + 12|0);
 HEAP32[$18>>2] = 0;
 $19 = ((($8)) + 16|0);
 HEAP32[$19>>2] = 0;
 $20 = ((($8)) + 12|0);
 $21 = ((($8)) + 8|0);
 HEAP32[$21>>2] = $20;
 $22 = ((($7)) + 8|0);
 $23 = ((($0)) + 4|0);
 $24 = ((($23)) + 11|0);
 $26 = $16;
 while(1) {
  $25 = HEAP32[$26>>2]|0;
  $27 = ((($25)) + 8|0);
  $28 = HEAP32[$27>>2]|0;
  __THREW__ = 0;
  (invoke_ii($28|0,($26|0))|0);
  $29 = __THREW__; __THREW__ = 0;
  $30 = $29&1;
  if ($30) {
   label = 31;
   break;
  }
  $31 = HEAP32[$8>>2]|0;
  $32 = HEAP32[$31>>2]|0;
  $33 = ((($31)) + 4|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = ($32|0)==($34|0);
  L4: do {
   if ($35) {
    $$0$i$i = 0;
   } else {
    $36 = HEAP32[$20>>2]|0;
    $37 = ($36|0)==(0|0);
    if ($37) {
     $$pre$i$i = HEAP32[$32>>2]|0;
     $$0$i$i = $$pre$i$i;
     break;
    } else {
     $$sroa$011$025$i$i = $32;
    }
    while(1) {
     $40 = HEAP32[$$sroa$011$025$i$i>>2]|0;
     $$0$ph13$i$i$i$i$i = $20;$$07$ph12$i$i$i$i$i = $36;
     L10: while(1) {
      $$0710$i$i$i$i$i = $$07$ph12$i$i$i$i$i;
      while(1) {
       $41 = ((($$0710$i$i$i$i$i)) + 16|0);
       $42 = HEAP32[$41>>2]|0;
       $43 = ($42>>>0)<($40>>>0);
       if (!($43)) {
        break;
       }
       $46 = ((($$0710$i$i$i$i$i)) + 4|0);
       $47 = HEAP32[$46>>2]|0;
       $48 = ($47|0)==(0|0);
       if ($48) {
        $$0$ph$lcssa$i$i$i$i$i = $$0$ph13$i$i$i$i$i;
        break L10;
       } else {
        $$0710$i$i$i$i$i = $47;
       }
      }
      $44 = HEAP32[$$0710$i$i$i$i$i>>2]|0;
      $45 = ($44|0)==(0|0);
      if ($45) {
       $$0$ph$lcssa$i$i$i$i$i = $$0710$i$i$i$i$i;
       break;
      } else {
       $$0$ph13$i$i$i$i$i = $$0710$i$i$i$i$i;$$07$ph12$i$i$i$i$i = $44;
      }
     }
     $49 = ($$0$ph$lcssa$i$i$i$i$i|0)==($20|0);
     if ($49) {
      $$0$i$i = $40;
      break L4;
     }
     $50 = ((($$0$ph$lcssa$i$i$i$i$i)) + 16|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = ($40>>>0)<($51>>>0);
     $38 = ((($$sroa$011$025$i$i)) + 4|0);
     if ($52) {
      $$0$i$i = $40;
      break L4;
     }
     $39 = ($38|0)==($34|0);
     if ($39) {
      $$0$i$i = 0;
      break;
     } else {
      $$sroa$011$025$i$i = $38;
     }
    }
   }
  } while(0);
  $53 = HEAP32[$26>>2]|0;
  $54 = ((($53)) + 12|0);
  $55 = HEAP32[$54>>2]|0;
  __THREW__ = 0;
  (invoke_ii($55|0,($26|0))|0);
  $56 = __THREW__; __THREW__ = 0;
  $57 = $56&1;
  if ($57) {
   label = 31;
   break;
  }
  $58 = ($$0$i$i|0)==(0|0);
  if ($58) {
   label = 44;
   break;
  }
  $59 = HEAP32[$17>>2]|0;
  $60 = HEAP32[$59>>2]|0;
  $61 = ((($60)) + 8|0);
  $62 = HEAP32[$61>>2]|0;
  __THREW__ = 0;
  (invoke_ii($62|0,($59|0))|0);
  $63 = __THREW__; __THREW__ = 0;
  $64 = $63&1;
  if ($64) {
   label = 31;
   break;
  }
  $65 = HEAP32[$8>>2]|0;
  $66 = HEAP32[$65>>2]|0;
  $67 = ((($65)) + 4|0);
  $68 = HEAP32[$67>>2]|0;
  $69 = ($66|0)==($68|0);
  L23: do {
   if ($69) {
    $$0$i$i39 = 0;
   } else {
    $70 = HEAP32[$20>>2]|0;
    $71 = ($70|0)==(0|0);
    if ($71) {
     $$pre$i$i28 = HEAP32[$66>>2]|0;
     $$0$i$i39 = $$pre$i$i28;
     break;
    } else {
     $$sroa$011$025$i$i30 = $66;
    }
    while(1) {
     $74 = HEAP32[$$sroa$011$025$i$i30>>2]|0;
     $$0$ph13$i$i$i$i$i32 = $20;$$07$ph12$i$i$i$i$i33 = $70;
     L29: while(1) {
      $$0710$i$i$i$i$i35 = $$07$ph12$i$i$i$i$i33;
      while(1) {
       $75 = ((($$0710$i$i$i$i$i35)) + 16|0);
       $76 = HEAP32[$75>>2]|0;
       $77 = ($76>>>0)<($74>>>0);
       if (!($77)) {
        break;
       }
       $80 = ((($$0710$i$i$i$i$i35)) + 4|0);
       $81 = HEAP32[$80>>2]|0;
       $82 = ($81|0)==(0|0);
       if ($82) {
        $$0$ph$lcssa$i$i$i$i$i37 = $$0$ph13$i$i$i$i$i32;
        break L29;
       } else {
        $$0710$i$i$i$i$i35 = $81;
       }
      }
      $78 = HEAP32[$$0710$i$i$i$i$i35>>2]|0;
      $79 = ($78|0)==(0|0);
      if ($79) {
       $$0$ph$lcssa$i$i$i$i$i37 = $$0710$i$i$i$i$i35;
       break;
      } else {
       $$0$ph13$i$i$i$i$i32 = $$0710$i$i$i$i$i35;$$07$ph12$i$i$i$i$i33 = $78;
      }
     }
     $83 = ($$0$ph$lcssa$i$i$i$i$i37|0)==($20|0);
     if ($83) {
      $$0$i$i39 = $74;
      break L23;
     }
     $84 = ((($$0$ph$lcssa$i$i$i$i$i37)) + 16|0);
     $85 = HEAP32[$84>>2]|0;
     $86 = ($74>>>0)<($85>>>0);
     $72 = ((($$sroa$011$025$i$i30)) + 4|0);
     if ($86) {
      $$0$i$i39 = $74;
      break L23;
     }
     $73 = ($72|0)==($68|0);
     if ($73) {
      $$0$i$i39 = 0;
      break;
     } else {
      $$sroa$011$025$i$i30 = $72;
     }
    }
   }
  } while(0);
  $87 = HEAP32[$59>>2]|0;
  $88 = ((($87)) + 12|0);
  $89 = HEAP32[$88>>2]|0;
  __THREW__ = 0;
  (invoke_ii($89|0,($59|0))|0);
  $90 = __THREW__; __THREW__ = 0;
  $91 = $90&1;
  if ($91) {
   label = 31;
   break;
  }
  $92 = HEAP32[$$0$i$i39>>2]|0;
  $93 = ((($92)) + 200|0);
  $94 = HEAP32[$93>>2]|0;
  __THREW__ = 0;
  invoke_viiiii($94|0,($0|0),($$0$i$i39|0),($2|0),($3|0),($4|0));
  $95 = __THREW__; __THREW__ = 0;
  $96 = $95&1;
  if ($96) {
   label = 31;
   break;
  }
  $97 = HEAP32[$0>>2]|0;
  $98 = ($97|0)==(3);
  if ($98) {
   label = 123;
   break;
  }
  $108 = HEAP32[$13>>2]|0;
  $109 = HEAP32[$22>>2]|0;
  $110 = ($108|0)==($109|0);
  if ($110) {
   __THREW__ = 0;
   invoke_vii(4220,($7|0),($0|0));
   $116 = __THREW__; __THREW__ = 0;
   $117 = $116&1;
   if ($117) {
    label = 34;
    break;
   }
  } else {
   HEAP32[$108>>2] = $97;
   $111 = ((($108)) + 4|0);
   __THREW__ = 0;
   invoke_vii(3457,($111|0),($23|0));
   $112 = __THREW__; __THREW__ = 0;
   $113 = $112&1;
   if ($113) {
    label = 34;
    break;
   }
   $114 = HEAP32[$13>>2]|0;
   $115 = ((($114)) + 16|0);
   HEAP32[$13>>2] = $115;
  }
  $118 = HEAP8[$24>>0]|0;
  $119 = ($118<<24>>24)<(0);
  if ($119) {
   $120 = HEAP32[$23>>2]|0;
   __ZdlPv($120);
  }
  __THREW__ = 0;
  invoke_vi(4203,($8|0));
  $121 = __THREW__; __THREW__ = 0;
  $122 = $121&1;
  if ($122) {
   label = 31;
   break;
  }
  $$pre = HEAP32[$17>>2]|0;
  $26 = $$pre;
 }
 L51: do {
  if ((label|0) == 31) {
   $99 = ___cxa_find_matching_catch_2()|0;
   $100 = tempRet0;
   $eh$lpad$body$index5Z2D = $100;$eh$lpad$body$indexZ2D = $99;
   label = 33;
  }
  else if ((label|0) == 34) {
   $103 = ___cxa_find_matching_catch_2()|0;
   $104 = tempRet0;
   $105 = HEAP8[$24>>0]|0;
   $106 = ($105<<24>>24)<(0);
   if ($106) {
    $107 = HEAP32[$23>>2]|0;
    __ZdlPv($107);
    $$4 = $104;$$423 = $103;
   } else {
    $$4 = $104;$$423 = $103;
   }
  }
  else if ((label|0) == 44) {
   __THREW__ = 0;
   invoke_vii(4205,($6|0),($3|0));
   $123 = __THREW__; __THREW__ = 0;
   $124 = $123&1;
   if ($124) {
    $101 = ___cxa_find_matching_catch_2()|0;
    $102 = tempRet0;
    $eh$lpad$body$index5Z2D = $102;$eh$lpad$body$indexZ2D = $101;
    label = 33;
    break;
   }
   __THREW__ = 0;
   invoke_viii(4192,($9|0),($1|0),($6|0));
   $125 = __THREW__; __THREW__ = 0;
   $126 = $125&1;
   if ($126) {
    $131 = ___cxa_find_matching_catch_2()|0;
    $132 = tempRet0;
    $133 = ((($6)) + 11|0);
    $134 = HEAP8[$133>>0]|0;
    $135 = ($134<<24>>24)<(0);
    if ($135) {
     $136 = HEAP32[$6>>2]|0;
     __ZdlPv($136);
    }
    $eh$lpad$body$index5Z2D = $132;$eh$lpad$body$indexZ2D = $131;
    label = 33;
    break;
   }
   $127 = ((($6)) + 11|0);
   $128 = HEAP8[$127>>0]|0;
   $129 = ($128<<24>>24)<(0);
   if ($129) {
    $130 = HEAP32[$6>>2]|0;
    __ZdlPv($130);
   }
   __THREW__ = 0;
   $137 = (invoke_iii(4194,($1|0),($9|0))|0);
   $138 = __THREW__; __THREW__ = 0;
   $139 = $138&1;
   L68: do {
    if ($139) {
     label = 82;
    } else {
     $140 = ($137|0)==(2);
     L70: do {
      if ($140) {
       while(1) {
        $141 = HEAP32[$17>>2]|0;
        $142 = HEAP32[$141>>2]|0;
        $143 = ((($142)) + 8|0);
        $144 = HEAP32[$143>>2]|0;
        __THREW__ = 0;
        (invoke_ii($144|0,($141|0))|0);
        $145 = __THREW__; __THREW__ = 0;
        $146 = $145&1;
        if ($146) {
         label = 82;
         break L68;
        }
        $147 = HEAP32[$8>>2]|0;
        $148 = HEAP32[$147>>2]|0;
        $149 = ((($147)) + 4|0);
        $150 = HEAP32[$149>>2]|0;
        $151 = ($148|0)==($150|0);
        L74: do {
         if ($151) {
          $$0$i$i59 = 0;
         } else {
          $152 = HEAP32[$20>>2]|0;
          $153 = ($152|0)==(0|0);
          if ($153) {
           $$pre$i$i48 = HEAP32[$148>>2]|0;
           $$0$i$i59 = $$pre$i$i48;
           break;
          } else {
           $$sroa$011$025$i$i50 = $148;
          }
          while(1) {
           $156 = HEAP32[$$sroa$011$025$i$i50>>2]|0;
           $$0$ph13$i$i$i$i$i52 = $20;$$07$ph12$i$i$i$i$i53 = $152;
           L80: while(1) {
            $$0710$i$i$i$i$i55 = $$07$ph12$i$i$i$i$i53;
            while(1) {
             $157 = ((($$0710$i$i$i$i$i55)) + 16|0);
             $158 = HEAP32[$157>>2]|0;
             $159 = ($158>>>0)<($156>>>0);
             if (!($159)) {
              break;
             }
             $162 = ((($$0710$i$i$i$i$i55)) + 4|0);
             $163 = HEAP32[$162>>2]|0;
             $164 = ($163|0)==(0|0);
             if ($164) {
              $$0$ph$lcssa$i$i$i$i$i57 = $$0$ph13$i$i$i$i$i52;
              break L80;
             } else {
              $$0710$i$i$i$i$i55 = $163;
             }
            }
            $160 = HEAP32[$$0710$i$i$i$i$i55>>2]|0;
            $161 = ($160|0)==(0|0);
            if ($161) {
             $$0$ph$lcssa$i$i$i$i$i57 = $$0710$i$i$i$i$i55;
             break;
            } else {
             $$0$ph13$i$i$i$i$i52 = $$0710$i$i$i$i$i55;$$07$ph12$i$i$i$i$i53 = $160;
            }
           }
           $165 = ($$0$ph$lcssa$i$i$i$i$i57|0)==($20|0);
           if ($165) {
            $$0$i$i59 = $156;
            break L74;
           }
           $166 = ((($$0$ph$lcssa$i$i$i$i$i57)) + 16|0);
           $167 = HEAP32[$166>>2]|0;
           $168 = ($156>>>0)<($167>>>0);
           $154 = ((($$sroa$011$025$i$i50)) + 4|0);
           if ($168) {
            $$0$i$i59 = $156;
            break L74;
           }
           $155 = ($154|0)==($150|0);
           if ($155) {
            $$0$i$i59 = 0;
            break;
           } else {
            $$sroa$011$025$i$i50 = $154;
           }
          }
         }
        } while(0);
        $169 = HEAP32[$141>>2]|0;
        $170 = ((($169)) + 12|0);
        $171 = HEAP32[$170>>2]|0;
        __THREW__ = 0;
        (invoke_ii($171|0,($141|0))|0);
        $172 = __THREW__; __THREW__ = 0;
        $173 = $172&1;
        if ($173) {
         label = 82;
         break L68;
        }
        $174 = ($$0$i$i59|0)==(0|0);
        if ($174) {
         label = 92;
         break L70;
        }
        $175 = HEAP32[$17>>2]|0;
        $176 = HEAP32[$175>>2]|0;
        $177 = ((($176)) + 8|0);
        $178 = HEAP32[$177>>2]|0;
        __THREW__ = 0;
        (invoke_ii($178|0,($175|0))|0);
        $179 = __THREW__; __THREW__ = 0;
        $180 = $179&1;
        if ($180) {
         label = 82;
         break L68;
        }
        $181 = HEAP32[$8>>2]|0;
        $182 = HEAP32[$181>>2]|0;
        $183 = ((($181)) + 4|0);
        $184 = HEAP32[$183>>2]|0;
        $185 = ($182|0)==($184|0);
        L93: do {
         if ($185) {
          $$0$i$i76 = 0;
         } else {
          $186 = HEAP32[$20>>2]|0;
          $187 = ($186|0)==(0|0);
          if ($187) {
           $$pre$i$i65 = HEAP32[$182>>2]|0;
           $$0$i$i76 = $$pre$i$i65;
           break;
          } else {
           $$sroa$011$025$i$i67 = $182;
          }
          while(1) {
           $190 = HEAP32[$$sroa$011$025$i$i67>>2]|0;
           $$0$ph13$i$i$i$i$i69 = $20;$$07$ph12$i$i$i$i$i70 = $186;
           L99: while(1) {
            $$0710$i$i$i$i$i72 = $$07$ph12$i$i$i$i$i70;
            while(1) {
             $191 = ((($$0710$i$i$i$i$i72)) + 16|0);
             $192 = HEAP32[$191>>2]|0;
             $193 = ($192>>>0)<($190>>>0);
             if (!($193)) {
              break;
             }
             $196 = ((($$0710$i$i$i$i$i72)) + 4|0);
             $197 = HEAP32[$196>>2]|0;
             $198 = ($197|0)==(0|0);
             if ($198) {
              $$0$ph$lcssa$i$i$i$i$i74 = $$0$ph13$i$i$i$i$i69;
              break L99;
             } else {
              $$0710$i$i$i$i$i72 = $197;
             }
            }
            $194 = HEAP32[$$0710$i$i$i$i$i72>>2]|0;
            $195 = ($194|0)==(0|0);
            if ($195) {
             $$0$ph$lcssa$i$i$i$i$i74 = $$0710$i$i$i$i$i72;
             break;
            } else {
             $$0$ph13$i$i$i$i$i69 = $$0710$i$i$i$i$i72;$$07$ph12$i$i$i$i$i70 = $194;
            }
           }
           $199 = ($$0$ph$lcssa$i$i$i$i$i74|0)==($20|0);
           if ($199) {
            $$0$i$i76 = $190;
            break L93;
           }
           $200 = ((($$0$ph$lcssa$i$i$i$i$i74)) + 16|0);
           $201 = HEAP32[$200>>2]|0;
           $202 = ($190>>>0)<($201>>>0);
           $188 = ((($$sroa$011$025$i$i67)) + 4|0);
           if ($202) {
            $$0$i$i76 = $190;
            break L93;
           }
           $189 = ($188|0)==($184|0);
           if ($189) {
            $$0$i$i76 = 0;
            break;
           } else {
            $$sroa$011$025$i$i67 = $188;
           }
          }
         }
        } while(0);
        $203 = HEAP32[$175>>2]|0;
        $204 = ((($203)) + 12|0);
        $205 = HEAP32[$204>>2]|0;
        __THREW__ = 0;
        (invoke_ii($205|0,($175|0))|0);
        $206 = __THREW__; __THREW__ = 0;
        $207 = $206&1;
        if ($207) {
         label = 82;
         break L68;
        }
        $208 = HEAP32[$$0$i$i76>>2]|0;
        $209 = ((($208)) + 200|0);
        $210 = HEAP32[$209>>2]|0;
        __THREW__ = 0;
        invoke_viiiii($210|0,($0|0),($$0$i$i76|0),($2|0),($3|0),($4|0));
        $211 = __THREW__; __THREW__ = 0;
        $212 = $211&1;
        if ($212) {
         label = 82;
         break L68;
        }
        $213 = HEAP32[$0>>2]|0;
        $214 = ($213|0)==(3);
        if ($214) {
         break L70;
        }
        $222 = HEAP32[$13>>2]|0;
        $223 = HEAP32[$22>>2]|0;
        $224 = ($222|0)==($223|0);
        if ($224) {
         __THREW__ = 0;
         invoke_vii(4220,($7|0),($0|0));
         $230 = __THREW__; __THREW__ = 0;
         $231 = $230&1;
         if ($231) {
          break;
         }
        } else {
         HEAP32[$222>>2] = $213;
         $225 = ((($222)) + 4|0);
         __THREW__ = 0;
         invoke_vii(3457,($225|0),($23|0));
         $226 = __THREW__; __THREW__ = 0;
         $227 = $226&1;
         if ($227) {
          break;
         }
         $228 = HEAP32[$13>>2]|0;
         $229 = ((($228)) + 16|0);
         HEAP32[$13>>2] = $229;
        }
        $232 = HEAP8[$24>>0]|0;
        $233 = ($232<<24>>24)<(0);
        if ($233) {
         $234 = HEAP32[$23>>2]|0;
         __ZdlPv($234);
        }
        __THREW__ = 0;
        invoke_vi(4203,($8|0));
        $235 = __THREW__; __THREW__ = 0;
        $236 = $235&1;
        if ($236) {
         label = 82;
         break L68;
        }
       }
       $217 = ___cxa_find_matching_catch_2()|0;
       $218 = tempRet0;
       $219 = HEAP8[$24>>0]|0;
       $220 = ($219<<24>>24)<(0);
       if (!($220)) {
        $$3 = $218;$$322 = $217;
        break L68;
       }
       $221 = HEAP32[$23>>2]|0;
       __ZdlPv($221);
       $$3 = $218;$$322 = $217;
       break L68;
      } else {
       label = 92;
      }
     } while(0);
     L122: do {
      if ((label|0) == 92) {
       $237 = HEAP32[$7>>2]|0;
       $238 = HEAP32[$13>>2]|0;
       $239 = ($237|0)==($238|0);
       if (!($239)) {
        __THREW__ = 0;
        invoke_viii(4221,($237|0),($238|0),($5|0));
        $268 = __THREW__; __THREW__ = 0;
        $269 = $268&1;
        if ($269) {
         label = 82;
         break L68;
        }
        $270 = HEAP32[$13>>2]|0;
        $271 = ((($270)) + -16|0);
        $272 = HEAP32[$271>>2]|0;
        HEAP32[$12>>2] = $272;
        $273 = ((($12)) + 4|0);
        $274 = ((($270)) + -12|0);
        __THREW__ = 0;
        invoke_vii(3457,($273|0),($274|0));
        $275 = __THREW__; __THREW__ = 0;
        $276 = $275&1;
        if ($276) {
         label = 82;
         break L68;
        }
        $277 = HEAP32[$12>>2]|0;
        HEAP32[$0>>2] = $277;
        __THREW__ = 0;
        invoke_vii(3457,($23|0),($273|0));
        $278 = __THREW__; __THREW__ = 0;
        $279 = $278&1;
        if ($279) {
         $284 = ___cxa_find_matching_catch_2()|0;
         $285 = tempRet0;
         $286 = ((($273)) + 11|0);
         $287 = HEAP8[$286>>0]|0;
         $288 = ($287<<24>>24)<(0);
         if ($288) {
          $289 = HEAP32[$273>>2]|0;
          __ZdlPv($289);
         }
         $$3 = $285;$$322 = $284;
         break L68;
        } else {
         $280 = ((($273)) + 11|0);
         $281 = HEAP8[$280>>0]|0;
         $282 = ($281<<24>>24)<(0);
         if ($282) {
          $283 = HEAP32[$273>>2]|0;
          __ZdlPv($283);
         }
         break;
        }
       }
       __THREW__ = 0;
       invoke_viii(4173,($11|0),(167995|0),($3|0));
       $240 = __THREW__; __THREW__ = 0;
       $241 = $240&1;
       if ($241) {
        $254 = ___cxa_find_matching_catch_2()|0;
        $255 = tempRet0;
        $$118 = $255;$$120 = $254;
       } else {
        __THREW__ = 0;
        invoke_viii(3542,($10|0),($11|0),(167562|0));
        $242 = __THREW__; __THREW__ = 0;
        $243 = $242&1;
        do {
         if ($243) {
          $256 = ___cxa_find_matching_catch_2()|0;
          $257 = tempRet0;
          $$017 = $257;$$019 = $256;
         } else {
          HEAP32[$0>>2] = 2;
          __THREW__ = 0;
          invoke_vii(3457,($23|0),($10|0));
          $244 = __THREW__; __THREW__ = 0;
          $245 = $244&1;
          if ($245) {
           $258 = ___cxa_find_matching_catch_2()|0;
           $259 = tempRet0;
           $260 = ((($10)) + 11|0);
           $261 = HEAP8[$260>>0]|0;
           $262 = ($261<<24>>24)<(0);
           if (!($262)) {
            $$017 = $259;$$019 = $258;
            break;
           }
           $263 = HEAP32[$10>>2]|0;
           __ZdlPv($263);
           $$017 = $259;$$019 = $258;
           break;
          }
          $246 = ((($10)) + 11|0);
          $247 = HEAP8[$246>>0]|0;
          $248 = ($247<<24>>24)<(0);
          if ($248) {
           $249 = HEAP32[$10>>2]|0;
           __ZdlPv($249);
          }
          $250 = ((($11)) + 11|0);
          $251 = HEAP8[$250>>0]|0;
          $252 = ($251<<24>>24)<(0);
          if ($252) {
           $253 = HEAP32[$11>>2]|0;
           __ZdlPv($253);
          }
          break L122;
         }
        } while(0);
        $264 = ((($11)) + 11|0);
        $265 = HEAP8[$264>>0]|0;
        $266 = ($265<<24>>24)<(0);
        if ($266) {
         $267 = HEAP32[$11>>2]|0;
         __ZdlPv($267);
         $$118 = $$017;$$120 = $$019;
        } else {
         $$118 = $$017;$$120 = $$019;
        }
       }
       $$3 = $$118;$$322 = $$120;
       break L68;
      }
     } while(0);
     $290 = ((($9)) + 11|0);
     $291 = HEAP8[$290>>0]|0;
     $292 = ($291<<24>>24)<(0);
     if ($292) {
      $293 = HEAP32[$9>>2]|0;
      __ZdlPv($293);
     }
     label = 123;
     break L51;
    }
   } while(0);
   if ((label|0) == 82) {
    $215 = ___cxa_find_matching_catch_2()|0;
    $216 = tempRet0;
    $$3 = $216;$$322 = $215;
   }
   $294 = ((($9)) + 11|0);
   $295 = HEAP8[$294>>0]|0;
   $296 = ($295<<24>>24)<(0);
   if ($296) {
    $297 = HEAP32[$9>>2]|0;
    __ZdlPv($297);
   }
   $$4 = $$3;$$423 = $$322;
  }
 } while(0);
 if ((label|0) == 33) {
  $$4 = $eh$lpad$body$index5Z2D;$$423 = $eh$lpad$body$indexZ2D;
 }
 else if ((label|0) == 123) {
  $298 = ((($8)) + 8|0);
  $299 = HEAP32[$20>>2]|0;
  __ZNSt3__26__treeIPN5osgDB12ReaderWriterENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($298,$299);
  $300 = HEAP32[$7>>2]|0;
  $301 = ($300|0)==(0|0);
  if ($301) {
   STACKTOP = sp;return;
  }
  $302 = HEAP32[$13>>2]|0;
  $303 = ($302|0)==($300|0);
  if ($303) {
   $313 = $300;
  } else {
   $305 = $302;
   while(1) {
    $304 = ((($305)) + -16|0);
    HEAP32[$13>>2] = $304;
    $306 = ((($305)) + -12|0);
    $307 = ((($306)) + 11|0);
    $308 = HEAP8[$307>>0]|0;
    $309 = ($308<<24>>24)<(0);
    if ($309) {
     $312 = HEAP32[$306>>2]|0;
     __ZdlPv($312);
     $$pre$i$i$i100 = HEAP32[$13>>2]|0;
     $310 = $$pre$i$i$i100;
    } else {
     $310 = $304;
    }
    $311 = ($310|0)==($300|0);
    if ($311) {
     break;
    } else {
     $305 = $310;
    }
   }
   $$pre$i102 = HEAP32[$7>>2]|0;
   $313 = $$pre$i102;
  }
  __ZdlPv($313);
  STACKTOP = sp;return;
 }
 $314 = ((($8)) + 8|0);
 $315 = HEAP32[$20>>2]|0;
 __ZNSt3__26__treeIPN5osgDB12ReaderWriterENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($314,$315);
 $316 = HEAP32[$7>>2]|0;
 $317 = ($316|0)==(0|0);
 if ($317) {
  ___resumeException($$423|0);
  // unreachable;
 }
 $318 = HEAP32[$13>>2]|0;
 $319 = ($318|0)==($316|0);
 if ($319) {
  $329 = $316;
 } else {
  $321 = $318;
  while(1) {
   $320 = ((($321)) + -16|0);
   HEAP32[$13>>2] = $320;
   $322 = ((($321)) + -12|0);
   $323 = ((($322)) + 11|0);
   $324 = HEAP8[$323>>0]|0;
   $325 = ($324<<24>>24)<(0);
   if ($325) {
    $328 = HEAP32[$322>>2]|0;
    __ZdlPv($328);
    $$pre$i$i$i = HEAP32[$13>>2]|0;
    $326 = $$pre$i$i$i;
   } else {
    $326 = $320;
   }
   $327 = ($326|0)==($316|0);
   if ($327) {
    break;
   } else {
    $321 = $326;
   }
  }
  $$pre$i = HEAP32[$7>>2]|0;
  $329 = $$pre$i;
 }
 __ZdlPv($329);
 ___resumeException($$423|0);
 // unreachable;
}
function __ZNSt3__26vectorIN5osgDB12ReaderWriter11WriteResultENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$06$i$i = 0, $$pre = 0, $$pre$i = 0, $$sroa$16$0 = 0, $$sroa$7$0 = 0, $$sroa$7$1 = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 4;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(268435455);
 if ($8) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $9 = ((($0)) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) - ($4))|0;
 $12 = $11 >> 4;
 $13 = ($12>>>0)<(134217727);
 $14 = $11 >> 3;
 $15 = ($14>>>0)<($7>>>0);
 $$sroa$speculated$i = $15 ? $7 : $14;
 $$sroa$speculated$$i = $13 ? $$sroa$speculated$i : 268435455;
 $16 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($16) {
   $26 = 0;$82 = 0;
  } else {
   $17 = ($$sroa$speculated$$i>>>0)>(268435455);
   if (!($17)) {
    $23 = $$sroa$speculated$$i << 4;
    $24 = (__Znwj($23)|0);
    $26 = $24;$82 = $24;
    break;
   }
   $18 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($18|0),(204840|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if ($20) {
    $21 = ___cxa_find_matching_catch_2()|0;
    $22 = tempRet0;
    ___cxa_free_exception(($18|0));
    ___resumeException($21|0);
    // unreachable;
   } else {
    HEAP32[$18>>2] = (99824);
    ___cxa_throw(($18|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $25 = (($26) + ($6<<4)|0);
 $27 = $25;
 $28 = (($26) + ($$sroa$speculated$$i<<4)|0);
 $29 = $28;
 $30 = HEAP32[$1>>2]|0;
 HEAP32[$25>>2] = $30;
 $31 = (((($26) + ($6<<4)|0)) + 4|0);
 $32 = ((($1)) + 4|0);
 __THREW__ = 0;
 invoke_vii(3457,($31|0),($32|0));
 $33 = __THREW__; __THREW__ = 0;
 $34 = $33&1;
 L13: do {
  if ($34) {
   $$sroa$16$0 = $27;$$sroa$7$1 = $27;
  } else {
   $35 = ((($25)) + 16|0);
   $36 = $35;
   $37 = HEAP32[$0>>2]|0;
   $38 = HEAP32[$2>>2]|0;
   $39 = ($38|0)==($37|0);
   if ($39) {
    $40 = $37;
    $53 = $27;$54 = $40;$56 = $37;
   } else {
    $$06$i$i = $38;$$sroa$7$0 = $27;$43 = $25;
    while(1) {
     $41 = ((($$06$i$i)) + -16|0);
     $42 = ((($43)) + -16|0);
     $44 = HEAP32[$41>>2]|0;
     HEAP32[$42>>2] = $44;
     $45 = ((($43)) + -12|0);
     $46 = ((($$06$i$i)) + -12|0);
     __THREW__ = 0;
     invoke_vii(3457,($45|0),($46|0));
     $47 = __THREW__; __THREW__ = 0;
     $48 = $47&1;
     if ($48) {
      $$sroa$16$0 = $36;$$sroa$7$1 = $$sroa$7$0;
      break L13;
     }
     $49 = $$sroa$7$0;
     $50 = ((($49)) + -16|0);
     $51 = $50;
     $52 = ($41|0)==($37|0);
     if ($52) {
      break;
     } else {
      $$06$i$i = $41;$$sroa$7$0 = $51;$43 = $50;
     }
    }
    $$pre$i = HEAP32[$0>>2]|0;
    $$pre = HEAP32[$2>>2]|0;
    $53 = $51;$54 = $$pre$i;$56 = $$pre;
   }
   HEAP32[$0>>2] = $53;
   HEAP32[$2>>2] = $36;
   HEAP32[$9>>2] = $29;
   $55 = $54;
   $57 = ($56|0)==($55|0);
   if (!($57)) {
    $59 = $56;
    while(1) {
     $58 = ((($59)) + -16|0);
     $60 = ((($59)) + -12|0);
     $61 = ((($60)) + 11|0);
     $62 = HEAP8[$61>>0]|0;
     $63 = ($62<<24>>24)<(0);
     if ($63) {
      $65 = HEAP32[$60>>2]|0;
      __ZdlPv($65);
     }
     $64 = ($58|0)==($55|0);
     if ($64) {
      break;
     } else {
      $59 = $58;
     }
    }
   }
   $66 = ($54|0)==(0);
   if ($66) {
    return;
   }
   $67 = $54;
   __ZdlPv($67);
   return;
  }
 } while(0);
 $68 = ___cxa_find_matching_catch_2()|0;
 $69 = tempRet0;
 $70 = $$sroa$7$1;
 $71 = $$sroa$16$0;
 $72 = ($71|0)==($70|0);
 if (!($72)) {
  $74 = $71;
  while(1) {
   $73 = ((($74)) + -16|0);
   $75 = ((($74)) + -12|0);
   $76 = ((($75)) + 11|0);
   $77 = HEAP8[$76>>0]|0;
   $78 = ($77<<24>>24)<(0);
   if ($78) {
    $80 = HEAP32[$75>>2]|0;
    __ZdlPv($80);
   }
   $79 = ($73|0)==($70|0);
   if ($79) {
    break;
   } else {
    $74 = $73;
   }
  }
 }
 $81 = ($26|0)==(0|0);
 if ($81) {
  ___resumeException($68|0);
  // unreachable;
 }
 __ZdlPv($82);
 ___resumeException($68|0);
 // unreachable;
}
function __ZNSt3__26__sortIRNS_6__lessIN5osgDB12ReaderWriter11WriteResultES4_EEPS4_EEvT0_S8_T_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$$0174 = 0, $$0 = 0, $$0$ph = 0, $$0154 = 0, $$0160298 = 0, $$0167 = 0, $$0174 = 0, $$0180$ph = 0, $$1 = 0, $$1155 = 0, $$1161 = 0, $$2156 = 0, $$2162 = 0, $$2176 = 0, $$3157 = 0, $$3163 = 0, $$3170 = 0, $$4158 = 0, $$4164 = 0, $$4171 = 0;
 var $$5159 = 0, $$5165 = 0, $$5172 = 0, $$6166 = 0, $$6173 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0;
 var $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(96|0);
 $3 = sp + 80|0;
 $4 = sp + 64|0;
 $5 = sp + 48|0;
 $6 = sp + 32|0;
 $7 = sp + 16|0;
 $8 = sp;
 $9 = ((($6)) + 4|0);
 $10 = ((($9)) + 11|0);
 $11 = ((($7)) + 4|0);
 $12 = ((($11)) + 11|0);
 $13 = ((($3)) + 4|0);
 $14 = ((($13)) + 11|0);
 $15 = ((($4)) + 4|0);
 $16 = ((($15)) + 11|0);
 $17 = ((($5)) + 4|0);
 $18 = ((($17)) + 11|0);
 $$0$ph = $0;$$0180$ph = $1;
 L1: while(1) {
  $19 = $$0180$ph;
  $20 = ((($$0180$ph)) + -16|0);
  $21 = ((($$0180$ph)) + -12|0);
  $22 = ($7|0)==($20|0);
  $$0 = $$0$ph;
  while(1) {
   $$1 = $$0;
   L5: while(1) {
    $23 = $$1;
    $24 = (($19) - ($23))|0;
    $25 = $24 >> 4;
    switch ($25|0) {
    case 2:  {
     label = 5;
     break L1;
     break;
    }
    case 3:  {
     label = 16;
     break L1;
     break;
    }
    case 4:  {
     label = 17;
     break L1;
     break;
    }
    case 5:  {
     label = 18;
     break L1;
     break;
    }
    case 1: case 0:  {
     label = 96;
     break L1;
     break;
    }
    default: {
    }
    }
    $55 = ($24|0)<(112);
    if ($55) {
     label = 20;
     break L1;
    }
    $56 = ($24|0)>(15984);
    $57 = (($25|0) / 2)&-1;
    $58 = (($$1) + ($57<<4)|0);
    if ($56) {
     $59 = (($25|0) / 4)&-1;
     $60 = (($$1) + ($59<<4)|0);
     $61 = (($58) + ($59<<4)|0);
     $62 = (__ZNSt3__27__sort5IRNS_6__lessIN5osgDB12ReaderWriter11WriteResultES4_EEPS4_EEjT0_S8_S8_S8_S8_T_($$1,$60,$58,$61,$20,$2)|0);
     $$0167 = $62;
    } else {
     $63 = (__ZNSt3__27__sort3IRNS_6__lessIN5osgDB12ReaderWriter11WriteResultES4_EEPS4_EEjT0_S8_S8_T_($$1,$58,$20,$2)|0);
     $$0167 = $63;
    }
    $64 = HEAP32[$$1>>2]|0;
    $65 = HEAP32[$58>>2]|0;
    $66 = ($64|0)<($65|0);
    if ($66) {
     $$3157 = $20;$$3170 = $$0167;
     break;
    } else {
     $$0154 = $20;
    }
    while(1) {
     $67 = ((($$0154)) + -16|0);
     $68 = ($$1|0)==($67|0);
     if ($68) {
      break;
     }
     $119 = HEAP32[$67>>2]|0;
     $120 = ($119|0)<($65|0);
     if ($120) {
      label = 54;
      break L5;
     } else {
      $$0154 = $67;
     }
    }
    $69 = ((($$1)) + 16|0);
    $70 = HEAP32[$20>>2]|0;
    $71 = ($64|0)<($70|0);
    if ($71) {
     $$1161 = $69;
    } else {
     $72 = ($69|0)==($20|0);
     if ($72) {
      label = 96;
      break L1;
     } else {
      $$0160298 = $69;
     }
     while(1) {
      $73 = HEAP32[$$0160298>>2]|0;
      $74 = ($64|0)<($73|0);
      if ($74) {
       break;
      }
      $91 = ((($$0160298)) + 16|0);
      $92 = ($91|0)==($20|0);
      if ($92) {
       label = 96;
       break L1;
      } else {
       $$0160298 = $91;
      }
     }
     HEAP32[$7>>2] = $73;
     $75 = ((($$0160298)) + 4|0);
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_($11,$75);
     $76 = HEAP32[$20>>2]|0;
     HEAP32[$$0160298>>2] = $76;
     __THREW__ = 0;
     (invoke_iii(3477,($75|0),($21|0))|0);
     $77 = __THREW__; __THREW__ = 0;
     $78 = $77&1;
     if ($78) {
      label = 34;
      break L1;
     }
     if (!($22)) {
      $79 = HEAP32[$7>>2]|0;
      HEAP32[$20>>2] = $79;
      __THREW__ = 0;
      (invoke_iii(3477,($21|0),($11|0))|0);
      $80 = __THREW__; __THREW__ = 0;
      $81 = $80&1;
      if ($81) {
       label = 34;
       break L1;
      }
     }
     $82 = HEAP8[$12>>0]|0;
     $83 = ($82<<24>>24)<(0);
     if ($83) {
      $84 = HEAP32[$11>>2]|0;
      __ZdlPv($84);
     }
     $90 = ((($$0160298)) + 16|0);
     $$1161 = $90;
    }
    $93 = ($$1161|0)==($20|0);
    if ($93) {
     label = 96;
     break L1;
    } else {
     $$1155 = $20;$$2162 = $$1161;
    }
    while(1) {
     $94 = HEAP32[$$1>>2]|0;
     $$3163 = $$2162;
     while(1) {
      $95 = HEAP32[$$3163>>2]|0;
      $96 = ($94|0)<($95|0);
      $97 = ((($$3163)) + 16|0);
      if ($96) {
       $$2156 = $$1155;
       break;
      } else {
       $$3163 = $97;
      }
     }
     while(1) {
      $98 = ((($$2156)) + -16|0);
      $99 = HEAP32[$98>>2]|0;
      $100 = ($94|0)<($99|0);
      if ($100) {
       $$2156 = $98;
      } else {
       break;
      }
     }
     $101 = ($$3163>>>0)<($98>>>0);
     if (!($101)) {
      $$1 = $$3163;
      continue L5;
     }
     HEAP32[$6>>2] = $95;
     $102 = ((($$3163)) + 4|0);
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_($9,$102);
     $103 = HEAP32[$98>>2]|0;
     HEAP32[$$3163>>2] = $103;
     $104 = ((($$2156)) + -12|0);
     __THREW__ = 0;
     (invoke_iii(3477,($102|0),($104|0))|0);
     $105 = __THREW__; __THREW__ = 0;
     $106 = $105&1;
     if ($106) {
      label = 49;
      break L1;
     }
     $107 = ($6|0)==($98|0);
     if (!($107)) {
      $108 = HEAP32[$6>>2]|0;
      HEAP32[$98>>2] = $108;
      __THREW__ = 0;
      (invoke_iii(3477,($104|0),($9|0))|0);
      $109 = __THREW__; __THREW__ = 0;
      $110 = $109&1;
      if ($110) {
       label = 49;
       break L1;
      }
     }
     $111 = HEAP8[$10>>0]|0;
     $112 = ($111<<24>>24)<(0);
     if ($112) {
      $113 = HEAP32[$9>>2]|0;
      __ZdlPv($113);
     }
     $$1155 = $98;$$2162 = $97;
    }
   }
   if ((label|0) == 54) {
    label = 0;
    HEAP32[$5>>2] = $64;
    $121 = ((($$1)) + 4|0);
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_($17,$121);
    $122 = HEAP32[$67>>2]|0;
    HEAP32[$$1>>2] = $122;
    $123 = ((($$0154)) + -12|0);
    __THREW__ = 0;
    (invoke_iii(3477,($121|0),($123|0))|0);
    $124 = __THREW__; __THREW__ = 0;
    $125 = $124&1;
    if ($125) {
     label = 59;
     break L1;
    }
    $126 = ($5|0)==($67|0);
    if (!($126)) {
     $127 = HEAP32[$5>>2]|0;
     HEAP32[$67>>2] = $127;
     __THREW__ = 0;
     (invoke_iii(3477,($123|0),($17|0))|0);
     $128 = __THREW__; __THREW__ = 0;
     $129 = $128&1;
     if ($129) {
      label = 59;
      break L1;
     }
    }
    $130 = HEAP8[$18>>0]|0;
    $131 = ($130<<24>>24)<(0);
    if ($131) {
     $132 = HEAP32[$17>>2]|0;
     __ZdlPv($132);
    }
    $138 = (($$0167) + 1)|0;
    $$3157 = $67;$$3170 = $138;
   }
   $139 = ((($$1)) + 16|0);
   $140 = ($139>>>0)<($$3157>>>0);
   L56: do {
    if ($140) {
     $$0174 = $58;$$4158 = $$3157;$$4164 = $139;$$4171 = $$3170;
     while(1) {
      $141 = HEAP32[$$0174>>2]|0;
      $$5165 = $$4164;
      while(1) {
       $142 = HEAP32[$$5165>>2]|0;
       $143 = ($142|0)<($141|0);
       $144 = ((($$5165)) + 16|0);
       if ($143) {
        $$5165 = $144;
       } else {
        $$5159 = $$4158;
        break;
       }
      }
      while(1) {
       $145 = ((($$5159)) + -16|0);
       $146 = HEAP32[$145>>2]|0;
       $147 = ($146|0)<($141|0);
       if ($147) {
        break;
       } else {
        $$5159 = $145;
       }
      }
      $148 = ($$5165>>>0)>($145>>>0);
      if ($148) {
       $$2176 = $$0174;$$5172 = $$4171;$$6166 = $$5165;
       break L56;
      }
      HEAP32[$4>>2] = $142;
      $149 = ((($$5165)) + 4|0);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_($15,$149);
      $150 = ($$5165|0)==($145|0);
      if (!($150)) {
       $151 = HEAP32[$145>>2]|0;
       HEAP32[$$5165>>2] = $151;
       $152 = ((($$5159)) + -12|0);
       __THREW__ = 0;
       (invoke_iii(3477,($149|0),($152|0))|0);
       $153 = __THREW__; __THREW__ = 0;
       $154 = $153&1;
       if ($154) {
        label = 74;
        break L1;
       }
      }
      $155 = ($4|0)==($145|0);
      if (!($155)) {
       $156 = HEAP32[$4>>2]|0;
       HEAP32[$145>>2] = $156;
       $157 = ((($$5159)) + -12|0);
       __THREW__ = 0;
       (invoke_iii(3477,($157|0),($15|0))|0);
       $158 = __THREW__; __THREW__ = 0;
       $159 = $158&1;
       if ($159) {
        label = 74;
        break L1;
       }
      }
      $160 = HEAP8[$16>>0]|0;
      $161 = ($160<<24>>24)<(0);
      if ($161) {
       $162 = HEAP32[$15>>2]|0;
       __ZdlPv($162);
      }
      $168 = (($$4171) + 1)|0;
      $169 = ($$0174|0)==($$5165|0);
      $$$0174 = $169 ? $145 : $$0174;
      $$0174 = $$$0174;$$4158 = $145;$$4164 = $144;$$4171 = $168;
     }
    } else {
     $$2176 = $58;$$5172 = $$3170;$$6166 = $139;
    }
   } while(0);
   $170 = ($$6166|0)==($$2176|0);
   if ($170) {
    $$6173 = $$5172;
   } else {
    $171 = HEAP32[$$2176>>2]|0;
    $172 = HEAP32[$$6166>>2]|0;
    $173 = ($171|0)<($172|0);
    if ($173) {
     HEAP32[$3>>2] = $172;
     $174 = ((($$6166)) + 4|0);
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_($13,$174);
     $175 = HEAP32[$$2176>>2]|0;
     HEAP32[$$6166>>2] = $175;
     $176 = ((($$2176)) + 4|0);
     __THREW__ = 0;
     (invoke_iii(3477,($174|0),($176|0))|0);
     $177 = __THREW__; __THREW__ = 0;
     $178 = $177&1;
     if ($178) {
      label = 85;
      break L1;
     }
     $179 = ($3|0)==($$2176|0);
     if (!($179)) {
      $180 = HEAP32[$3>>2]|0;
      HEAP32[$$2176>>2] = $180;
      __THREW__ = 0;
      (invoke_iii(3477,($176|0),($13|0))|0);
      $181 = __THREW__; __THREW__ = 0;
      $182 = $181&1;
      if ($182) {
       label = 85;
       break L1;
      }
     }
     $183 = HEAP8[$14>>0]|0;
     $184 = ($183<<24>>24)<(0);
     if ($184) {
      $185 = HEAP32[$13>>2]|0;
      __ZdlPv($185);
     }
     $191 = (($$5172) + 1)|0;
     $$6173 = $191;
    } else {
     $$6173 = $$5172;
    }
   }
   $192 = ($$6173|0)==(0);
   if ($192) {
    $193 = (__ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIN5osgDB12ReaderWriter11WriteResultES4_EEPS4_EEbT0_S8_T_($$1,$$6166,$2)|0);
    $194 = ((($$6166)) + 16|0);
    $195 = (__ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIN5osgDB12ReaderWriter11WriteResultES4_EEPS4_EEbT0_S8_T_($194,$$0180$ph,$2)|0);
    if ($195) {
     label = 95;
     break;
    }
    if ($193) {
     $$0 = $194;
     continue;
    }
   }
   $196 = $$6166;
   $197 = (($196) - ($23))|0;
   $198 = (($19) - ($196))|0;
   $199 = ($197|0)<($198|0);
   if (!($199)) {
    label = 94;
    break;
   }
   __ZNSt3__26__sortIRNS_6__lessIN5osgDB12ReaderWriter11WriteResultES4_EEPS4_EEvT0_S8_T_($$1,$$6166,$2);
   $200 = ((($$6166)) + 16|0);
   $$0 = $200;
  }
  if ((label|0) == 94) {
   label = 0;
   $201 = ((($$6166)) + 16|0);
   __ZNSt3__26__sortIRNS_6__lessIN5osgDB12ReaderWriter11WriteResultES4_EEPS4_EEvT0_S8_T_($201,$$0180$ph,$2);
   $$0$ph = $$1;$$0180$ph = $$6166;
   continue;
  }
  else if ((label|0) == 95) {
   label = 0;
   if ($193) {
    label = 96;
    break;
   } else {
    $$0$ph = $$1;$$0180$ph = $$6166;
    continue;
   }
  }
 }
 switch (label|0) {
  case 5: {
   $26 = HEAP32[$20>>2]|0;
   $27 = HEAP32[$$1>>2]|0;
   $28 = ($26|0)<($27|0);
   if (!($28)) {
    STACKTOP = sp;return;
   }
   HEAP32[$8>>2] = $27;
   $29 = ((($8)) + 4|0);
   $30 = ((($$1)) + 4|0);
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_($29,$30);
   $31 = ($$1|0)==($20|0);
   if ($31) {
    label = 8;
   } else {
    $32 = HEAP32[$20>>2]|0;
    HEAP32[$$1>>2] = $32;
    __THREW__ = 0;
    (invoke_iii(3477,($30|0),($21|0))|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     label = 8;
    }
   }
   do {
    if ((label|0) == 8) {
     $35 = ($8|0)==($20|0);
     if (!($35)) {
      $36 = HEAP32[$8>>2]|0;
      HEAP32[$20>>2] = $36;
      __THREW__ = 0;
      (invoke_iii(3477,($21|0),($29|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
     }
     $39 = ((($29)) + 11|0);
     $40 = HEAP8[$39>>0]|0;
     $41 = ($40<<24>>24)<(0);
     if ($41) {
      $42 = HEAP32[$29>>2]|0;
      __ZdlPv($42);
     }
     STACKTOP = sp;return;
    }
   } while(0);
   $43 = ___cxa_find_matching_catch_2()|0;
   $44 = tempRet0;
   $45 = ((($29)) + 11|0);
   $46 = HEAP8[$45>>0]|0;
   $47 = ($46<<24>>24)<(0);
   if (!($47)) {
    ___resumeException($43|0);
    // unreachable;
   }
   $48 = HEAP32[$29>>2]|0;
   __ZdlPv($48);
   ___resumeException($43|0);
   // unreachable;
   break;
  }
  case 16: {
   $49 = ((($$1)) + 16|0);
   (__ZNSt3__27__sort3IRNS_6__lessIN5osgDB12ReaderWriter11WriteResultES4_EEPS4_EEjT0_S8_S8_T_($$1,$49,$20,$2)|0);
   STACKTOP = sp;return;
   break;
  }
  case 17: {
   $50 = ((($$1)) + 16|0);
   $51 = ((($$1)) + 32|0);
   (__ZNSt3__27__sort4IRNS_6__lessIN5osgDB12ReaderWriter11WriteResultES4_EEPS4_EEjT0_S8_S8_S8_T_($$1,$50,$51,$20,$2)|0);
   STACKTOP = sp;return;
   break;
  }
  case 18: {
   $52 = ((($$1)) + 16|0);
   $53 = ((($$1)) + 32|0);
   $54 = ((($$1)) + 48|0);
   (__ZNSt3__27__sort5IRNS_6__lessIN5osgDB12ReaderWriter11WriteResultES4_EEPS4_EEjT0_S8_S8_S8_S8_T_($$1,$52,$53,$54,$20,$2)|0);
   STACKTOP = sp;return;
   break;
  }
  case 20: {
   __ZNSt3__218__insertion_sort_3IRNS_6__lessIN5osgDB12ReaderWriter11WriteResultES4_EEPS4_EEvT0_S8_T_($$1,$$0180$ph,$2);
   STACKTOP = sp;return;
   break;
  }
  case 34: {
   $85 = ___cxa_find_matching_catch_2()|0;
   $86 = tempRet0;
   $87 = HEAP8[$12>>0]|0;
   $88 = ($87<<24>>24)<(0);
   if (!($88)) {
    ___resumeException($85|0);
    // unreachable;
   }
   $89 = HEAP32[$11>>2]|0;
   __ZdlPv($89);
   ___resumeException($85|0);
   // unreachable;
   break;
  }
  case 49: {
   $114 = ___cxa_find_matching_catch_2()|0;
   $115 = tempRet0;
   $116 = HEAP8[$10>>0]|0;
   $117 = ($116<<24>>24)<(0);
   if (!($117)) {
    ___resumeException($114|0);
    // unreachable;
   }
   $118 = HEAP32[$9>>2]|0;
   __ZdlPv($118);
   ___resumeException($114|0);
   // unreachable;
   break;
  }
  case 59: {
   $133 = ___cxa_find_matching_catch_2()|0;
   $134 = tempRet0;
   $135 = HEAP8[$18>>0]|0;
   $136 = ($135<<24>>24)<(0);
   if (!($136)) {
    ___resumeException($133|0);
    // unreachable;
   }
   $137 = HEAP32[$17>>2]|0;
   __ZdlPv($137);
   ___resumeException($133|0);
   // unreachable;
   break;
  }
  case 74: {
   $163 = ___cxa_find_matching_catch_2()|0;
   $164 = tempRet0;
   $165 = HEAP8[$16>>0]|0;
   $166 = ($165<<24>>24)<(0);
   if (!($166)) {
    ___resumeException($163|0);
    // unreachable;
   }
   $167 = HEAP32[$15>>2]|0;
   __ZdlPv($167);
   ___resumeException($163|0);
   // unreachable;
   break;
  }
  case 85: {
   $186 = ___cxa_find_matching_catch_2()|0;
   $187 = tempRet0;
   $188 = HEAP8[$14>>0]|0;
   $189 = ($188<<24>>24)<(0);
   if (!($189)) {
    ___resumeException($186|0);
    // unreachable;
   }
   $190 = HEAP32[$13>>2]|0;
   __ZdlPv($190);
   ___resumeException($186|0);
   // unreachable;
   break;
  }
  case 96: {
   STACKTOP = sp;return;
   break;
  }
 }
}
function __ZNSt3__27__sort3IRNS_6__lessIN5osgDB12ReaderWriter11WriteResultES4_EEPS4_EEjT0_S8_S8_T_($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$026 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0;
 var $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(80|0);
 $4 = sp + 64|0;
 $5 = sp + 48|0;
 $6 = sp + 32|0;
 $7 = sp + 16|0;
 $8 = sp;
 $9 = HEAP32[$1>>2]|0;
 $10 = HEAP32[$0>>2]|0;
 $11 = ($9|0)<($10|0);
 $12 = HEAP32[$2>>2]|0;
 $13 = ($12|0)<($9|0);
 if (!($11)) {
  if (!($13)) {
   $$026 = 0;
   STACKTOP = sp;return ($$026|0);
  }
  HEAP32[$7>>2] = $9;
  $14 = ((($7)) + 4|0);
  $15 = ((($1)) + 4|0);
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_($14,$15);
  $16 = ($1|0)==($2|0);
  if ($16) {
   label = 5;
  } else {
   $17 = HEAP32[$2>>2]|0;
   HEAP32[$1>>2] = $17;
   $18 = ((($2)) + 4|0);
   __THREW__ = 0;
   (invoke_iii(3477,($15|0),($18|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    label = 5;
   }
  }
  do {
   if ((label|0) == 5) {
    $21 = ($7|0)==($2|0);
    if (!($21)) {
     $22 = HEAP32[$7>>2]|0;
     HEAP32[$2>>2] = $22;
     $23 = ((($2)) + 4|0);
     __THREW__ = 0;
     (invoke_iii(3477,($23|0),($14|0))|0);
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if ($25) {
      break;
     }
    }
    $26 = ((($14)) + 11|0);
    $27 = HEAP8[$26>>0]|0;
    $28 = ($27<<24>>24)<(0);
    if ($28) {
     $29 = HEAP32[$14>>2]|0;
     __ZdlPv($29);
    }
    $36 = HEAP32[$1>>2]|0;
    $37 = HEAP32[$0>>2]|0;
    $38 = ($36|0)<($37|0);
    if (!($38)) {
     $$026 = 1;
     STACKTOP = sp;return ($$026|0);
    }
    HEAP32[$6>>2] = $37;
    $39 = ((($6)) + 4|0);
    $40 = ((($0)) + 4|0);
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_($39,$40);
    $41 = ($0|0)==($1|0);
    if ($41) {
     label = 15;
    } else {
     $42 = HEAP32[$1>>2]|0;
     HEAP32[$0>>2] = $42;
     __THREW__ = 0;
     (invoke_iii(3477,($40|0),($15|0))|0);
     $43 = __THREW__; __THREW__ = 0;
     $44 = $43&1;
     if (!($44)) {
      label = 15;
     }
    }
    do {
     if ((label|0) == 15) {
      $45 = ($6|0)==($1|0);
      if (!($45)) {
       $46 = HEAP32[$6>>2]|0;
       HEAP32[$1>>2] = $46;
       __THREW__ = 0;
       (invoke_iii(3477,($15|0),($39|0))|0);
       $47 = __THREW__; __THREW__ = 0;
       $48 = $47&1;
       if ($48) {
        break;
       }
      }
      $49 = ((($39)) + 11|0);
      $50 = HEAP8[$49>>0]|0;
      $51 = ($50<<24>>24)<(0);
      if ($51) {
       $52 = HEAP32[$39>>2]|0;
       __ZdlPv($52);
      }
      $$026 = 2;
      STACKTOP = sp;return ($$026|0);
     }
    } while(0);
    $53 = ___cxa_find_matching_catch_2()|0;
    $54 = tempRet0;
    $55 = ((($39)) + 11|0);
    $56 = HEAP8[$55>>0]|0;
    $57 = ($56<<24>>24)<(0);
    if (!($57)) {
     ___resumeException($53|0);
     // unreachable;
    }
    $58 = HEAP32[$39>>2]|0;
    __ZdlPv($58);
    ___resumeException($53|0);
    // unreachable;
   }
  } while(0);
  $30 = ___cxa_find_matching_catch_2()|0;
  $31 = tempRet0;
  $32 = ((($14)) + 11|0);
  $33 = HEAP8[$32>>0]|0;
  $34 = ($33<<24>>24)<(0);
  if (!($34)) {
   ___resumeException($30|0);
   // unreachable;
  }
  $35 = HEAP32[$14>>2]|0;
  __ZdlPv($35);
  ___resumeException($30|0);
  // unreachable;
 }
 if ($13) {
  HEAP32[$5>>2] = $10;
  $59 = ((($5)) + 4|0);
  $60 = ((($0)) + 4|0);
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_($59,$60);
  $61 = ($0|0)==($2|0);
  if ($61) {
   label = 26;
  } else {
   $62 = HEAP32[$2>>2]|0;
   HEAP32[$0>>2] = $62;
   $63 = ((($2)) + 4|0);
   __THREW__ = 0;
   (invoke_iii(3477,($60|0),($63|0))|0);
   $64 = __THREW__; __THREW__ = 0;
   $65 = $64&1;
   if (!($65)) {
    label = 26;
   }
  }
  do {
   if ((label|0) == 26) {
    $66 = ($5|0)==($2|0);
    if (!($66)) {
     $67 = HEAP32[$5>>2]|0;
     HEAP32[$2>>2] = $67;
     $68 = ((($2)) + 4|0);
     __THREW__ = 0;
     (invoke_iii(3477,($68|0),($59|0))|0);
     $69 = __THREW__; __THREW__ = 0;
     $70 = $69&1;
     if ($70) {
      break;
     }
    }
    $71 = ((($59)) + 11|0);
    $72 = HEAP8[$71>>0]|0;
    $73 = ($72<<24>>24)<(0);
    if ($73) {
     $74 = HEAP32[$59>>2]|0;
     __ZdlPv($74);
    }
    $$026 = 1;
    STACKTOP = sp;return ($$026|0);
   }
  } while(0);
  $75 = ___cxa_find_matching_catch_2()|0;
  $76 = tempRet0;
  $77 = ((($59)) + 11|0);
  $78 = HEAP8[$77>>0]|0;
  $79 = ($78<<24>>24)<(0);
  if (!($79)) {
   ___resumeException($75|0);
   // unreachable;
  }
  $80 = HEAP32[$59>>2]|0;
  __ZdlPv($80);
  ___resumeException($75|0);
  // unreachable;
 }
 HEAP32[$4>>2] = $10;
 $81 = ((($4)) + 4|0);
 $82 = ((($0)) + 4|0);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_($81,$82);
 $83 = ($0|0)==($1|0);
 if ($83) {
  label = 36;
 } else {
  $84 = HEAP32[$1>>2]|0;
  HEAP32[$0>>2] = $84;
  $85 = ((($1)) + 4|0);
  __THREW__ = 0;
  (invoke_iii(3477,($82|0),($85|0))|0);
  $86 = __THREW__; __THREW__ = 0;
  $87 = $86&1;
  if (!($87)) {
   label = 36;
  }
 }
 do {
  if ((label|0) == 36) {
   $88 = ($4|0)==($1|0);
   if (!($88)) {
    $89 = HEAP32[$4>>2]|0;
    HEAP32[$1>>2] = $89;
    $90 = ((($1)) + 4|0);
    __THREW__ = 0;
    (invoke_iii(3477,($90|0),($81|0))|0);
    $91 = __THREW__; __THREW__ = 0;
    $92 = $91&1;
    if ($92) {
     break;
    }
   }
   $93 = ((($81)) + 11|0);
   $94 = HEAP8[$93>>0]|0;
   $95 = ($94<<24>>24)<(0);
   if ($95) {
    $96 = HEAP32[$81>>2]|0;
    __ZdlPv($96);
   }
   $103 = HEAP32[$2>>2]|0;
   $104 = HEAP32[$1>>2]|0;
   $105 = ($103|0)<($104|0);
   if (!($105)) {
    $$026 = 1;
    STACKTOP = sp;return ($$026|0);
   }
   HEAP32[$8>>2] = $104;
   $106 = ((($8)) + 4|0);
   $107 = ((($1)) + 4|0);
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_($106,$107);
   $108 = ($1|0)==($2|0);
   if ($108) {
    label = 46;
   } else {
    $109 = HEAP32[$2>>2]|0;
    HEAP32[$1>>2] = $109;
    $110 = ((($2)) + 4|0);
    __THREW__ = 0;
    (invoke_iii(3477,($107|0),($110|0))|0);
    $111 = __THREW__; __THREW__ = 0;
    $112 = $111&1;
    if (!($112)) {
     label = 46;
    }
   }
   do {
    if ((label|0) == 46) {
     $113 = ($8|0)==($2|0);
     if (!($113)) {
      $114 = HEAP32[$8>>2]|0;
      HEAP32[$2>>2] = $114;
      $115 = ((($2)) + 4|0);
      __THREW__ = 0;
      (invoke_iii(3477,($115|0),($106|0))|0);
      $116 = __THREW__; __THREW__ = 0;
      $117 = $116&1;
      if ($117) {
       break;
      }
     }
     $118 = ((($106)) + 11|0);
     $119 = HEAP8[$118>>0]|0;
     $120 = ($119<<24>>24)<(0);
     if ($120) {
      $121 = HEAP32[$106>>2]|0;
      __ZdlPv($121);
     }
     $$026 = 2;
     STACKTOP = sp;return ($$026|0);
    }
   } while(0);
   $122 = ___cxa_find_matching_catch_2()|0;
   $123 = tempRet0;
   $124 = ((($106)) + 11|0);
   $125 = HEAP8[$124>>0]|0;
   $126 = ($125<<24>>24)<(0);
   if (!($126)) {
    ___resumeException($122|0);
    // unreachable;
   }
   $127 = HEAP32[$106>>2]|0;
   __ZdlPv($127);
   ___resumeException($122|0);
   // unreachable;
  }
 } while(0);
 $97 = ___cxa_find_matching_catch_2()|0;
 $98 = tempRet0;
 $99 = ((($81)) + 11|0);
 $100 = HEAP8[$99>>0]|0;
 $101 = ($100<<24>>24)<(0);
 if (!($101)) {
  ___resumeException($97|0);
  // unreachable;
 }
 $102 = HEAP32[$81>>2]|0;
 __ZdlPv($102);
 ___resumeException($97|0);
 // unreachable;
 return (0)|0;
}
function __ZNSt3__27__sort4IRNS_6__lessIN5osgDB12ReaderWriter11WriteResultES4_EEPS4_EEjT0_S8_S8_S8_T_($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $5 = sp + 32|0;
 $6 = sp + 16|0;
 $7 = sp;
 $8 = (__ZNSt3__27__sort3IRNS_6__lessIN5osgDB12ReaderWriter11WriteResultES4_EEPS4_EEjT0_S8_S8_T_($0,$1,$2,$4)|0);
 $9 = HEAP32[$3>>2]|0;
 $10 = HEAP32[$2>>2]|0;
 $11 = ($9|0)<($10|0);
 if (!($11)) {
  $$0 = $8;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$6>>2] = $10;
 $12 = ((($6)) + 4|0);
 $13 = ((($2)) + 4|0);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_($12,$13);
 $14 = ($2|0)==($3|0);
 if ($14) {
  label = 4;
 } else {
  $15 = HEAP32[$3>>2]|0;
  HEAP32[$2>>2] = $15;
  $16 = ((($3)) + 4|0);
  __THREW__ = 0;
  (invoke_iii(3477,($13|0),($16|0))|0);
  $17 = __THREW__; __THREW__ = 0;
  $18 = $17&1;
  if (!($18)) {
   label = 4;
  }
 }
 do {
  if ((label|0) == 4) {
   $19 = ($6|0)==($3|0);
   if (!($19)) {
    $20 = HEAP32[$6>>2]|0;
    HEAP32[$3>>2] = $20;
    $21 = ((($3)) + 4|0);
    __THREW__ = 0;
    (invoke_iii(3477,($21|0),($12|0))|0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
   }
   $24 = ((($12)) + 11|0);
   $25 = HEAP8[$24>>0]|0;
   $26 = ($25<<24>>24)<(0);
   if ($26) {
    $27 = HEAP32[$12>>2]|0;
    __ZdlPv($27);
   }
   $34 = (($8) + 1)|0;
   $35 = HEAP32[$2>>2]|0;
   $36 = HEAP32[$1>>2]|0;
   $37 = ($35|0)<($36|0);
   if (!($37)) {
    $$0 = $34;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$5>>2] = $36;
   $38 = ((($5)) + 4|0);
   $39 = ((($1)) + 4|0);
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_($38,$39);
   $40 = ($1|0)==($2|0);
   if ($40) {
    label = 14;
   } else {
    $41 = HEAP32[$2>>2]|0;
    HEAP32[$1>>2] = $41;
    __THREW__ = 0;
    (invoke_iii(3477,($39|0),($13|0))|0);
    $42 = __THREW__; __THREW__ = 0;
    $43 = $42&1;
    if (!($43)) {
     label = 14;
    }
   }
   do {
    if ((label|0) == 14) {
     $44 = ($5|0)==($2|0);
     if (!($44)) {
      $45 = HEAP32[$5>>2]|0;
      HEAP32[$2>>2] = $45;
      __THREW__ = 0;
      (invoke_iii(3477,($13|0),($38|0))|0);
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       break;
      }
     }
     $48 = ((($38)) + 11|0);
     $49 = HEAP8[$48>>0]|0;
     $50 = ($49<<24>>24)<(0);
     if ($50) {
      $51 = HEAP32[$38>>2]|0;
      __ZdlPv($51);
     }
     $58 = (($8) + 2)|0;
     $59 = HEAP32[$1>>2]|0;
     $60 = HEAP32[$0>>2]|0;
     $61 = ($59|0)<($60|0);
     if (!($61)) {
      $$0 = $58;
      STACKTOP = sp;return ($$0|0);
     }
     HEAP32[$7>>2] = $60;
     $62 = ((($7)) + 4|0);
     $63 = ((($0)) + 4|0);
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_($62,$63);
     $64 = ($0|0)==($1|0);
     if ($64) {
      label = 24;
     } else {
      $65 = HEAP32[$1>>2]|0;
      HEAP32[$0>>2] = $65;
      __THREW__ = 0;
      (invoke_iii(3477,($63|0),($39|0))|0);
      $66 = __THREW__; __THREW__ = 0;
      $67 = $66&1;
      if (!($67)) {
       label = 24;
      }
     }
     do {
      if ((label|0) == 24) {
       $68 = ($7|0)==($1|0);
       if (!($68)) {
        $69 = HEAP32[$7>>2]|0;
        HEAP32[$1>>2] = $69;
        __THREW__ = 0;
        (invoke_iii(3477,($39|0),($62|0))|0);
        $70 = __THREW__; __THREW__ = 0;
        $71 = $70&1;
        if ($71) {
         break;
        }
       }
       $72 = ((($62)) + 11|0);
       $73 = HEAP8[$72>>0]|0;
       $74 = ($73<<24>>24)<(0);
       if ($74) {
        $75 = HEAP32[$62>>2]|0;
        __ZdlPv($75);
       }
       $82 = (($8) + 3)|0;
       $$0 = $82;
       STACKTOP = sp;return ($$0|0);
      }
     } while(0);
     $76 = ___cxa_find_matching_catch_2()|0;
     $77 = tempRet0;
     $78 = ((($62)) + 11|0);
     $79 = HEAP8[$78>>0]|0;
     $80 = ($79<<24>>24)<(0);
     if (!($80)) {
      ___resumeException($76|0);
      // unreachable;
     }
     $81 = HEAP32[$62>>2]|0;
     __ZdlPv($81);
     ___resumeException($76|0);
     // unreachable;
    }
   } while(0);
   $52 = ___cxa_find_matching_catch_2()|0;
   $53 = tempRet0;
   $54 = ((($38)) + 11|0);
   $55 = HEAP8[$54>>0]|0;
   $56 = ($55<<24>>24)<(0);
   if (!($56)) {
    ___resumeException($52|0);
    // unreachable;
   }
   $57 = HEAP32[$38>>2]|0;
   __ZdlPv($57);
   ___resumeException($52|0);
   // unreachable;
  }
 } while(0);
 $28 = ___cxa_find_matching_catch_2()|0;
 $29 = tempRet0;
 $30 = ((($12)) + 11|0);
 $31 = HEAP8[$30>>0]|0;
 $32 = ($31<<24>>24)<(0);
 if (!($32)) {
  ___resumeException($28|0);
  // unreachable;
 }
 $33 = HEAP32[$12>>2]|0;
 __ZdlPv($33);
 ___resumeException($28|0);
 // unreachable;
 return (0)|0;
}
function __ZNSt3__27__sort5IRNS_6__lessIN5osgDB12ReaderWriter11WriteResultES4_EEPS4_EEjT0_S8_S8_S8_S8_T_($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$0 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(64|0);
 $6 = sp + 48|0;
 $7 = sp + 32|0;
 $8 = sp + 16|0;
 $9 = sp;
 $10 = (__ZNSt3__27__sort4IRNS_6__lessIN5osgDB12ReaderWriter11WriteResultES4_EEPS4_EEjT0_S8_S8_S8_T_($0,$1,$2,$3,$5)|0);
 $11 = HEAP32[$4>>2]|0;
 $12 = HEAP32[$3>>2]|0;
 $13 = ($11|0)<($12|0);
 if (!($13)) {
  $$0 = $10;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$8>>2] = $12;
 $14 = ((($8)) + 4|0);
 $15 = ((($3)) + 4|0);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_($14,$15);
 $16 = ($3|0)==($4|0);
 if ($16) {
  label = 4;
 } else {
  $17 = HEAP32[$4>>2]|0;
  HEAP32[$3>>2] = $17;
  $18 = ((($4)) + 4|0);
  __THREW__ = 0;
  (invoke_iii(3477,($15|0),($18|0))|0);
  $19 = __THREW__; __THREW__ = 0;
  $20 = $19&1;
  if (!($20)) {
   label = 4;
  }
 }
 do {
  if ((label|0) == 4) {
   $21 = ($8|0)==($4|0);
   if (!($21)) {
    $22 = HEAP32[$8>>2]|0;
    HEAP32[$4>>2] = $22;
    $23 = ((($4)) + 4|0);
    __THREW__ = 0;
    (invoke_iii(3477,($23|0),($14|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
   }
   $26 = ((($14)) + 11|0);
   $27 = HEAP8[$26>>0]|0;
   $28 = ($27<<24>>24)<(0);
   if ($28) {
    $29 = HEAP32[$14>>2]|0;
    __ZdlPv($29);
   }
   $36 = (($10) + 1)|0;
   $37 = HEAP32[$3>>2]|0;
   $38 = HEAP32[$2>>2]|0;
   $39 = ($37|0)<($38|0);
   if (!($39)) {
    $$0 = $36;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$7>>2] = $38;
   $40 = ((($7)) + 4|0);
   $41 = ((($2)) + 4|0);
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_($40,$41);
   $42 = ($2|0)==($3|0);
   if ($42) {
    label = 14;
   } else {
    $43 = HEAP32[$3>>2]|0;
    HEAP32[$2>>2] = $43;
    __THREW__ = 0;
    (invoke_iii(3477,($41|0),($15|0))|0);
    $44 = __THREW__; __THREW__ = 0;
    $45 = $44&1;
    if (!($45)) {
     label = 14;
    }
   }
   do {
    if ((label|0) == 14) {
     $46 = ($7|0)==($3|0);
     if (!($46)) {
      $47 = HEAP32[$7>>2]|0;
      HEAP32[$3>>2] = $47;
      __THREW__ = 0;
      (invoke_iii(3477,($15|0),($40|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       break;
      }
     }
     $50 = ((($40)) + 11|0);
     $51 = HEAP8[$50>>0]|0;
     $52 = ($51<<24>>24)<(0);
     if ($52) {
      $53 = HEAP32[$40>>2]|0;
      __ZdlPv($53);
     }
     $60 = (($10) + 2)|0;
     $61 = HEAP32[$2>>2]|0;
     $62 = HEAP32[$1>>2]|0;
     $63 = ($61|0)<($62|0);
     if (!($63)) {
      $$0 = $60;
      STACKTOP = sp;return ($$0|0);
     }
     HEAP32[$6>>2] = $62;
     $64 = ((($6)) + 4|0);
     $65 = ((($1)) + 4|0);
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_($64,$65);
     $66 = ($1|0)==($2|0);
     if ($66) {
      label = 24;
     } else {
      $67 = HEAP32[$2>>2]|0;
      HEAP32[$1>>2] = $67;
      __THREW__ = 0;
      (invoke_iii(3477,($65|0),($41|0))|0);
      $68 = __THREW__; __THREW__ = 0;
      $69 = $68&1;
      if (!($69)) {
       label = 24;
      }
     }
     do {
      if ((label|0) == 24) {
       $70 = ($6|0)==($2|0);
       if (!($70)) {
        $71 = HEAP32[$6>>2]|0;
        HEAP32[$2>>2] = $71;
        __THREW__ = 0;
        (invoke_iii(3477,($41|0),($64|0))|0);
        $72 = __THREW__; __THREW__ = 0;
        $73 = $72&1;
        if ($73) {
         break;
        }
       }
       $74 = ((($64)) + 11|0);
       $75 = HEAP8[$74>>0]|0;
       $76 = ($75<<24>>24)<(0);
       if ($76) {
        $77 = HEAP32[$64>>2]|0;
        __ZdlPv($77);
       }
       $84 = (($10) + 3)|0;
       $85 = HEAP32[$1>>2]|0;
       $86 = HEAP32[$0>>2]|0;
       $87 = ($85|0)<($86|0);
       if (!($87)) {
        $$0 = $84;
        STACKTOP = sp;return ($$0|0);
       }
       HEAP32[$9>>2] = $86;
       $88 = ((($9)) + 4|0);
       $89 = ((($0)) + 4|0);
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_($88,$89);
       $90 = ($0|0)==($1|0);
       if ($90) {
        label = 34;
       } else {
        $91 = HEAP32[$1>>2]|0;
        HEAP32[$0>>2] = $91;
        __THREW__ = 0;
        (invoke_iii(3477,($89|0),($65|0))|0);
        $92 = __THREW__; __THREW__ = 0;
        $93 = $92&1;
        if (!($93)) {
         label = 34;
        }
       }
       do {
        if ((label|0) == 34) {
         $94 = ($9|0)==($1|0);
         if (!($94)) {
          $95 = HEAP32[$9>>2]|0;
          HEAP32[$1>>2] = $95;
          __THREW__ = 0;
          (invoke_iii(3477,($65|0),($88|0))|0);
          $96 = __THREW__; __THREW__ = 0;
          $97 = $96&1;
          if ($97) {
           break;
          }
         }
         $98 = ((($88)) + 11|0);
         $99 = HEAP8[$98>>0]|0;
         $100 = ($99<<24>>24)<(0);
         if ($100) {
          $101 = HEAP32[$88>>2]|0;
          __ZdlPv($101);
         }
         $108 = (($10) + 4)|0;
         $$0 = $108;
         STACKTOP = sp;return ($$0|0);
        }
       } while(0);
       $102 = ___cxa_find_matching_catch_2()|0;
       $103 = tempRet0;
       $104 = ((($88)) + 11|0);
       $105 = HEAP8[$104>>0]|0;
       $106 = ($105<<24>>24)<(0);
       if (!($106)) {
        ___resumeException($102|0);
        // unreachable;
       }
       $107 = HEAP32[$88>>2]|0;
       __ZdlPv($107);
       ___resumeException($102|0);
       // unreachable;
      }
     } while(0);
     $78 = ___cxa_find_matching_catch_2()|0;
     $79 = tempRet0;
     $80 = ((($64)) + 11|0);
     $81 = HEAP8[$80>>0]|0;
     $82 = ($81<<24>>24)<(0);
     if (!($82)) {
      ___resumeException($78|0);
      // unreachable;
     }
     $83 = HEAP32[$64>>2]|0;
     __ZdlPv($83);
     ___resumeException($78|0);
     // unreachable;
    }
   } while(0);
   $54 = ___cxa_find_matching_catch_2()|0;
   $55 = tempRet0;
   $56 = ((($40)) + 11|0);
   $57 = HEAP8[$56>>0]|0;
   $58 = ($57<<24>>24)<(0);
   if (!($58)) {
    ___resumeException($54|0);
    // unreachable;
   }
   $59 = HEAP32[$40>>2]|0;
   __ZdlPv($59);
   ___resumeException($54|0);
   // unreachable;
  }
 } while(0);
 $30 = ___cxa_find_matching_catch_2()|0;
 $31 = tempRet0;
 $32 = ((($14)) + 11|0);
 $33 = HEAP8[$32>>0]|0;
 $34 = ($33<<24>>24)<(0);
 if (!($34)) {
  ___resumeException($30|0);
  // unreachable;
 }
 $35 = HEAP32[$14>>2]|0;
 __ZdlPv($35);
 ___resumeException($30|0);
 // unreachable;
 return (0)|0;
}
function __ZNSt3__218__insertion_sort_3IRNS_6__lessIN5osgDB12ReaderWriter11WriteResultES4_EEPS4_EEvT0_S8_T_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$03342 = 0, $$034 = 0, $$034$lcssa44 = 0, $$043 = 0, $$043$phi = 0, $$1 = 0, $$1$phi = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = ((($0)) + 32|0);
 $5 = ((($0)) + 16|0);
 (__ZNSt3__27__sort3IRNS_6__lessIN5osgDB12ReaderWriter11WriteResultES4_EEPS4_EEjT0_S8_S8_T_($0,$5,$4,$2)|0);
 $6 = ((($0)) + 48|0);
 $7 = ($6|0)==($1|0);
 if ($7) {
  STACKTOP = sp;return;
 }
 $8 = ((($3)) + 4|0);
 $9 = ((($8)) + 11|0);
 $$03342 = $6;$$043 = $4;
 L4: while(1) {
  $10 = HEAP32[$$03342>>2]|0;
  $11 = HEAP32[$$043>>2]|0;
  $12 = ($10|0)<($11|0);
  if ($12) {
   HEAP32[$3>>2] = $10;
   $13 = ((($$03342)) + 4|0);
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_($8,$13);
   $$034 = $$043;$$1 = $$03342;
   while(1) {
    $14 = HEAP32[$$034>>2]|0;
    HEAP32[$$1>>2] = $14;
    $15 = ((($$034)) + 4|0);
    $16 = ((($$1)) + 4|0);
    __THREW__ = 0;
    (invoke_iii(3477,($16|0),($15|0))|0);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     break L4;
    }
    $19 = ($$034|0)==($0|0);
    if ($19) {
     $$034$lcssa44 = $0;
     break;
    }
    $20 = ((($$034)) + -16|0);
    $21 = HEAP32[$3>>2]|0;
    $22 = HEAP32[$20>>2]|0;
    $23 = ($21|0)<($22|0);
    if ($23) {
     $$1$phi = $$034;$$034 = $20;$$1 = $$1$phi;
    } else {
     $$034$lcssa44 = $$034;
     break;
    }
   }
   $24 = ($$034$lcssa44|0)==($3|0);
   if (!($24)) {
    $25 = HEAP32[$3>>2]|0;
    HEAP32[$$034$lcssa44>>2] = $25;
    $26 = ((($$034$lcssa44)) + 4|0);
    __THREW__ = 0;
    (invoke_iii(3477,($26|0),($8|0))|0);
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
   }
   $29 = HEAP8[$9>>0]|0;
   $30 = ($29<<24>>24)<(0);
   if ($30) {
    $31 = HEAP32[$8>>2]|0;
    __ZdlPv($31);
   }
  }
  $37 = ((($$03342)) + 16|0);
  $38 = ($37|0)==($1|0);
  if ($38) {
   label = 3;
   break;
  } else {
   $$043$phi = $$03342;$$03342 = $37;$$043 = $$043$phi;
  }
 }
 if ((label|0) == 3) {
  STACKTOP = sp;return;
 }
 $32 = ___cxa_find_matching_catch_2()|0;
 $33 = tempRet0;
 $34 = HEAP8[$9>>0]|0;
 $35 = ($34<<24>>24)<(0);
 if (!($35)) {
  ___resumeException($32|0);
  // unreachable;
 }
 $36 = HEAP32[$8>>2]|0;
 __ZdlPv($36);
 ___resumeException($32|0);
 // unreachable;
}
function __ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIN5osgDB12ReaderWriter11WriteResultES4_EEPS4_EEbT0_S8_T_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$$3 = 0, $$068 = 0, $$068$lcssa92 = 0, $$07187 = 0, $$07486 = 0, $$07685 = 0, $$07685$phi = 0, $$170 = 0, $$175 = 0, $$177 = 0, $$177$phi = 0, $$3 = 0, $$5 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $3 = sp + 16|0;
 $4 = sp;
 $5 = $1;
 $6 = $0;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 4;
 switch ($8|0) {
 case 2:  {
  $9 = ((($1)) + -16|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = HEAP32[$0>>2]|0;
  $12 = ($10|0)<($11|0);
  if (!($12)) {
   $$5 = 1;
   STACKTOP = sp;return ($$5|0);
  }
  HEAP32[$3>>2] = $11;
  $13 = ((($3)) + 4|0);
  $14 = ((($0)) + 4|0);
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_($13,$14);
  $15 = ($9|0)==($0|0);
  if ($15) {
   label = 5;
  } else {
   $16 = HEAP32[$9>>2]|0;
   HEAP32[$0>>2] = $16;
   $17 = ((($1)) + -12|0);
   __THREW__ = 0;
   (invoke_iii(3477,($14|0),($17|0))|0);
   $18 = __THREW__; __THREW__ = 0;
   $19 = $18&1;
   if (!($19)) {
    label = 5;
   }
  }
  do {
   if ((label|0) == 5) {
    $20 = ($3|0)==($9|0);
    if (!($20)) {
     $21 = HEAP32[$3>>2]|0;
     HEAP32[$9>>2] = $21;
     $22 = ((($1)) + -12|0);
     __THREW__ = 0;
     (invoke_iii(3477,($22|0),($13|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
    }
    $25 = ((($13)) + 11|0);
    $26 = HEAP8[$25>>0]|0;
    $27 = ($26<<24>>24)<(0);
    if ($27) {
     $28 = HEAP32[$13>>2]|0;
     __ZdlPv($28);
    }
    $$5 = 1;
    STACKTOP = sp;return ($$5|0);
   }
  } while(0);
  $29 = ___cxa_find_matching_catch_2()|0;
  $30 = tempRet0;
  $31 = ((($13)) + 11|0);
  $32 = HEAP8[$31>>0]|0;
  $33 = ($32<<24>>24)<(0);
  if (!($33)) {
   ___resumeException($29|0);
   // unreachable;
  }
  $34 = HEAP32[$13>>2]|0;
  __ZdlPv($34);
  ___resumeException($29|0);
  // unreachable;
  break;
 }
 case 3:  {
  $35 = ((($0)) + 16|0);
  $36 = ((($1)) + -16|0);
  (__ZNSt3__27__sort3IRNS_6__lessIN5osgDB12ReaderWriter11WriteResultES4_EEPS4_EEjT0_S8_S8_T_($0,$35,$36,$2)|0);
  $$5 = 1;
  STACKTOP = sp;return ($$5|0);
  break;
 }
 case 4:  {
  $37 = ((($0)) + 16|0);
  $38 = ((($0)) + 32|0);
  $39 = ((($1)) + -16|0);
  (__ZNSt3__27__sort4IRNS_6__lessIN5osgDB12ReaderWriter11WriteResultES4_EEPS4_EEjT0_S8_S8_S8_T_($0,$37,$38,$39,$2)|0);
  $$5 = 1;
  STACKTOP = sp;return ($$5|0);
  break;
 }
 case 5:  {
  $40 = ((($0)) + 16|0);
  $41 = ((($0)) + 32|0);
  $42 = ((($0)) + 48|0);
  $43 = ((($1)) + -16|0);
  (__ZNSt3__27__sort5IRNS_6__lessIN5osgDB12ReaderWriter11WriteResultES4_EEPS4_EEjT0_S8_S8_S8_S8_T_($0,$40,$41,$42,$43,$2)|0);
  $$5 = 1;
  STACKTOP = sp;return ($$5|0);
  break;
 }
 case 1: case 0:  {
  $$5 = 1;
  STACKTOP = sp;return ($$5|0);
  break;
 }
 default: {
  $44 = ((($0)) + 32|0);
  $45 = ((($0)) + 16|0);
  (__ZNSt3__27__sort3IRNS_6__lessIN5osgDB12ReaderWriter11WriteResultES4_EEPS4_EEjT0_S8_S8_T_($0,$45,$44,$2)|0);
  $46 = ((($0)) + 48|0);
  $47 = ($46|0)==($1|0);
  L3: do {
   if ($47) {
    $$170 = 1;$$3 = 0;
   } else {
    $48 = ((($4)) + 4|0);
    $49 = ((($48)) + 11|0);
    $$07187 = $46;$$07486 = 0;$$07685 = $44;
    L5: while(1) {
     $50 = HEAP32[$$07187>>2]|0;
     $51 = HEAP32[$$07685>>2]|0;
     $52 = ($50|0)<($51|0);
     if ($52) {
      HEAP32[$4>>2] = $50;
      $53 = ((($$07187)) + 4|0);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_($48,$53);
      $$068 = $$07685;$$177 = $$07187;
      while(1) {
       $54 = ($$177|0)==($$068|0);
       if (!($54)) {
        $55 = HEAP32[$$068>>2]|0;
        HEAP32[$$177>>2] = $55;
        $56 = ((($$068)) + 4|0);
        $57 = ((($$177)) + 4|0);
        __THREW__ = 0;
        (invoke_iii(3477,($57|0),($56|0))|0);
        $58 = __THREW__; __THREW__ = 0;
        $59 = $58&1;
        if ($59) {
         break L5;
        }
       }
       $60 = ($$068|0)==($0|0);
       if ($60) {
        $$068$lcssa92 = $0;
        break;
       }
       $61 = ((($$068)) + -16|0);
       $62 = HEAP32[$4>>2]|0;
       $63 = HEAP32[$61>>2]|0;
       $64 = ($62|0)<($63|0);
       if ($64) {
        $$177$phi = $$068;$$068 = $61;$$177 = $$177$phi;
       } else {
        $$068$lcssa92 = $$068;
        break;
       }
      }
      $65 = ($$068$lcssa92|0)==($4|0);
      if (!($65)) {
       $66 = HEAP32[$4>>2]|0;
       HEAP32[$$068$lcssa92>>2] = $66;
       $67 = ((($$068$lcssa92)) + 4|0);
       __THREW__ = 0;
       (invoke_iii(3477,($67|0),($48|0))|0);
       $68 = __THREW__; __THREW__ = 0;
       $69 = $68&1;
       if ($69) {
        break;
       }
      }
      $70 = (($$07486) + 1)|0;
      $71 = ($70|0)==(8);
      $72 = ((($$07187)) + 16|0);
      $73 = ($72|0)==($1|0);
      $74 = HEAP8[$49>>0]|0;
      $75 = ($74<<24>>24)<(0);
      if ($75) {
       $76 = HEAP32[$48>>2]|0;
       __ZdlPv($76);
      }
      if ($71) {
       $$170 = 0;$$3 = $73;
       break L3;
      } else {
       $$175 = $70;
      }
     } else {
      $$175 = $$07486;
     }
     $82 = ((($$07187)) + 16|0);
     $83 = ($82|0)==($1|0);
     if ($83) {
      $$170 = 1;$$3 = 0;
      break L3;
     } else {
      $$07685$phi = $$07187;$$07187 = $82;$$07486 = $$175;$$07685 = $$07685$phi;
     }
    }
    $77 = ___cxa_find_matching_catch_2()|0;
    $78 = tempRet0;
    $79 = HEAP8[$49>>0]|0;
    $80 = ($79<<24>>24)<(0);
    if (!($80)) {
     ___resumeException($77|0);
     // unreachable;
    }
    $81 = HEAP32[$48>>2]|0;
    __ZdlPv($81);
    ___resumeException($77|0);
    // unreachable;
   }
  } while(0);
  $$$3 = $$170 | $$3;
  $$5 = $$$3;
  STACKTOP = sp;return ($$5|0);
 }
 }
 return (0)|0;
}
function __ZN5osgDB8Registry23readImageImplementationERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEPKNS_7OptionsE($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $4 = sp;
 HEAP32[$4>>2] = (75072);
 $5 = ((($4)) + 4|0);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_($5,$2);
 $6 = ((($4)) + 16|0);
 HEAP32[$6>>2] = $3;
 HEAP32[$4>>2] = (75168);
 __THREW__ = 0;
 invoke_viiii(4212,($0|0),($1|0),($4|0),2);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $13 = ___cxa_find_matching_catch_2()|0;
  $14 = tempRet0;
  HEAP32[$4>>2] = (75072);
  $15 = ((($5)) + 11|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = ($16<<24>>24)<(0);
  if (!($17)) {
   ___resumeException($13|0);
   // unreachable;
  }
  $18 = HEAP32[$5>>2]|0;
  __ZdlPv($18);
  ___resumeException($13|0);
  // unreachable;
 } else {
  HEAP32[$4>>2] = (75072);
  $9 = ((($5)) + 11|0);
  $10 = HEAP8[$9>>0]|0;
  $11 = ($10<<24>>24)<(0);
  if (!($11)) {
   STACKTOP = sp;return;
  }
  $12 = HEAP32[$5>>2]|0;
  __ZdlPv($12);
  STACKTOP = sp;return;
 }
}
function __ZN5osgDB8Registry16ReadImageFunctorD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (75072);
 $1 = ((($0)) + 4|0);
 $2 = ((($1)) + 11|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)<(0);
 if (!($4)) {
  __ZdlPv($0);
  return;
 }
 $5 = HEAP32[$1>>2]|0;
 __ZdlPv($5);
 __ZdlPv($0);
 return;
}
function __ZNK5osgDB8Registry16ReadImageFunctor6doReadERNS_12ReaderWriterE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + 180|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($1)) + 4|0);
 $7 = ((($1)) + 16|0);
 $8 = HEAP32[$7>>2]|0;
 FUNCTION_TABLE_viiii[$5 & 8191]($0,$2,$6,$8);
 return;
}
function __ZNK5osgDB8Registry16ReadImageFunctor7isValidERNS_12ReaderWriter10ReadResultE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__ZN5osgDB12ReaderWriter10ReadResult8getImageEv($1)|0);
 $3 = ($2|0)!=(0|0);
 return ($3|0);
}
function __ZNK5osgDB8Registry16ReadImageFunctor7isValidEPN3osg6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,25320,0)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK5osgDB8Registry16ReadImageFunctor9cloneTypeERKNSt3__212basic_stringIcNS2_11char_traitsIcEENS2_9allocatorIcEEEEPKNS_7OptionsE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (__Znwj(20)|0);
 HEAP32[$3>>2] = (75072);
 $4 = ((($3)) + 4|0);
 __THREW__ = 0;
 invoke_vii(3457,($4|0),($1|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $8 = ___cxa_find_matching_catch_2()|0;
  $9 = tempRet0;
  __ZdlPv($3);
  ___resumeException($8|0);
  // unreachable;
 } else {
  $7 = ((($3)) + 16|0);
  HEAP32[$7>>2] = $2;
  HEAP32[$3>>2] = (75168);
  return ($3|0);
 }
 return (0)|0;
}
function __ZN5osgDB8Registry24writeImageImplementationERKN3osg5ImageERKNSt3__212basic_stringIcNS5_11char_traitsIcEENS5_9allocatorIcEEEEPKNS_7OptionsE($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0$i$i = 0, $$0$i$i39 = 0, $$0$i$i59 = 0, $$0$i$i76 = 0, $$0$ph$lcssa$i$i$i$i$i = 0, $$0$ph$lcssa$i$i$i$i$i37 = 0, $$0$ph$lcssa$i$i$i$i$i57 = 0, $$0$ph$lcssa$i$i$i$i$i74 = 0, $$0$ph13$i$i$i$i$i = 0, $$0$ph13$i$i$i$i$i32 = 0, $$0$ph13$i$i$i$i$i52 = 0, $$0$ph13$i$i$i$i$i69 = 0, $$017 = 0, $$019 = 0, $$07$ph12$i$i$i$i$i = 0, $$07$ph12$i$i$i$i$i33 = 0, $$07$ph12$i$i$i$i$i53 = 0, $$07$ph12$i$i$i$i$i70 = 0, $$0710$i$i$i$i$i = 0, $$0710$i$i$i$i$i35 = 0;
 var $$0710$i$i$i$i$i55 = 0, $$0710$i$i$i$i$i72 = 0, $$118 = 0, $$120 = 0, $$3 = 0, $$322 = 0, $$4 = 0, $$423 = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i$i$i = 0, $$pre$i$i$i100 = 0, $$pre$i$i28 = 0, $$pre$i$i48 = 0, $$pre$i$i65 = 0, $$pre$i102 = 0, $$sroa$011$025$i$i = 0, $$sroa$011$025$i$i30 = 0, $$sroa$011$025$i$i50 = 0;
 var $$sroa$011$025$i$i67 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0;
 var $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0;
 var $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0;
 var $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0;
 var $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0;
 var $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0;
 var $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0;
 var $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0;
 var $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0;
 var $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0;
 var $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0;
 var $299 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0;
 var $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index5Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(112|0);
 $5 = sp;
 $6 = sp + 92|0;
 $7 = sp + 80|0;
 $8 = sp + 60|0;
 $9 = sp + 48|0;
 $10 = sp + 36|0;
 $11 = sp + 24|0;
 $12 = sp + 8|0;
 HEAP32[$7>>2] = 0;
 $13 = ((($7)) + 4|0);
 HEAP32[$13>>2] = 0;
 $14 = ((($7)) + 8|0);
 HEAP32[$14>>2] = 0;
 $15 = ((($1)) + 72|0);
 $16 = ((($1)) + 60|0);
 HEAP32[$8>>2] = $15;
 $17 = ((($8)) + 4|0);
 HEAP32[$17>>2] = $16;
 $18 = ((($8)) + 12|0);
 HEAP32[$18>>2] = 0;
 $19 = ((($8)) + 16|0);
 HEAP32[$19>>2] = 0;
 $20 = ((($8)) + 12|0);
 $21 = ((($8)) + 8|0);
 HEAP32[$21>>2] = $20;
 $22 = ((($7)) + 8|0);
 $23 = ((($0)) + 4|0);
 $24 = ((($23)) + 11|0);
 $26 = $16;
 while(1) {
  $25 = HEAP32[$26>>2]|0;
  $27 = ((($25)) + 8|0);
  $28 = HEAP32[$27>>2]|0;
  __THREW__ = 0;
  (invoke_ii($28|0,($26|0))|0);
  $29 = __THREW__; __THREW__ = 0;
  $30 = $29&1;
  if ($30) {
   label = 31;
   break;
  }
  $31 = HEAP32[$8>>2]|0;
  $32 = HEAP32[$31>>2]|0;
  $33 = ((($31)) + 4|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = ($32|0)==($34|0);
  L4: do {
   if ($35) {
    $$0$i$i = 0;
   } else {
    $36 = HEAP32[$20>>2]|0;
    $37 = ($36|0)==(0|0);
    if ($37) {
     $$pre$i$i = HEAP32[$32>>2]|0;
     $$0$i$i = $$pre$i$i;
     break;
    } else {
     $$sroa$011$025$i$i = $32;
    }
    while(1) {
     $40 = HEAP32[$$sroa$011$025$i$i>>2]|0;
     $$0$ph13$i$i$i$i$i = $20;$$07$ph12$i$i$i$i$i = $36;
     L10: while(1) {
      $$0710$i$i$i$i$i = $$07$ph12$i$i$i$i$i;
      while(1) {
       $41 = ((($$0710$i$i$i$i$i)) + 16|0);
       $42 = HEAP32[$41>>2]|0;
       $43 = ($42>>>0)<($40>>>0);
       if (!($43)) {
        break;
       }
       $46 = ((($$0710$i$i$i$i$i)) + 4|0);
       $47 = HEAP32[$46>>2]|0;
       $48 = ($47|0)==(0|0);
       if ($48) {
        $$0$ph$lcssa$i$i$i$i$i = $$0$ph13$i$i$i$i$i;
        break L10;
       } else {
        $$0710$i$i$i$i$i = $47;
       }
      }
      $44 = HEAP32[$$0710$i$i$i$i$i>>2]|0;
      $45 = ($44|0)==(0|0);
      if ($45) {
       $$0$ph$lcssa$i$i$i$i$i = $$0710$i$i$i$i$i;
       break;
      } else {
       $$0$ph13$i$i$i$i$i = $$0710$i$i$i$i$i;$$07$ph12$i$i$i$i$i = $44;
      }
     }
     $49 = ($$0$ph$lcssa$i$i$i$i$i|0)==($20|0);
     if ($49) {
      $$0$i$i = $40;
      break L4;
     }
     $50 = ((($$0$ph$lcssa$i$i$i$i$i)) + 16|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = ($40>>>0)<($51>>>0);
     $38 = ((($$sroa$011$025$i$i)) + 4|0);
     if ($52) {
      $$0$i$i = $40;
      break L4;
     }
     $39 = ($38|0)==($34|0);
     if ($39) {
      $$0$i$i = 0;
      break;
     } else {
      $$sroa$011$025$i$i = $38;
     }
    }
   }
  } while(0);
  $53 = HEAP32[$26>>2]|0;
  $54 = ((($53)) + 12|0);
  $55 = HEAP32[$54>>2]|0;
  __THREW__ = 0;
  (invoke_ii($55|0,($26|0))|0);
  $56 = __THREW__; __THREW__ = 0;
  $57 = $56&1;
  if ($57) {
   label = 31;
   break;
  }
  $58 = ($$0$i$i|0)==(0|0);
  if ($58) {
   label = 44;
   break;
  }
  $59 = HEAP32[$17>>2]|0;
  $60 = HEAP32[$59>>2]|0;
  $61 = ((($60)) + 8|0);
  $62 = HEAP32[$61>>2]|0;
  __THREW__ = 0;
  (invoke_ii($62|0,($59|0))|0);
  $63 = __THREW__; __THREW__ = 0;
  $64 = $63&1;
  if ($64) {
   label = 31;
   break;
  }
  $65 = HEAP32[$8>>2]|0;
  $66 = HEAP32[$65>>2]|0;
  $67 = ((($65)) + 4|0);
  $68 = HEAP32[$67>>2]|0;
  $69 = ($66|0)==($68|0);
  L23: do {
   if ($69) {
    $$0$i$i39 = 0;
   } else {
    $70 = HEAP32[$20>>2]|0;
    $71 = ($70|0)==(0|0);
    if ($71) {
     $$pre$i$i28 = HEAP32[$66>>2]|0;
     $$0$i$i39 = $$pre$i$i28;
     break;
    } else {
     $$sroa$011$025$i$i30 = $66;
    }
    while(1) {
     $74 = HEAP32[$$sroa$011$025$i$i30>>2]|0;
     $$0$ph13$i$i$i$i$i32 = $20;$$07$ph12$i$i$i$i$i33 = $70;
     L29: while(1) {
      $$0710$i$i$i$i$i35 = $$07$ph12$i$i$i$i$i33;
      while(1) {
       $75 = ((($$0710$i$i$i$i$i35)) + 16|0);
       $76 = HEAP32[$75>>2]|0;
       $77 = ($76>>>0)<($74>>>0);
       if (!($77)) {
        break;
       }
       $80 = ((($$0710$i$i$i$i$i35)) + 4|0);
       $81 = HEAP32[$80>>2]|0;
       $82 = ($81|0)==(0|0);
       if ($82) {
        $$0$ph$lcssa$i$i$i$i$i37 = $$0$ph13$i$i$i$i$i32;
        break L29;
       } else {
        $$0710$i$i$i$i$i35 = $81;
       }
      }
      $78 = HEAP32[$$0710$i$i$i$i$i35>>2]|0;
      $79 = ($78|0)==(0|0);
      if ($79) {
       $$0$ph$lcssa$i$i$i$i$i37 = $$0710$i$i$i$i$i35;
       break;
      } else {
       $$0$ph13$i$i$i$i$i32 = $$0710$i$i$i$i$i35;$$07$ph12$i$i$i$i$i33 = $78;
      }
     }
     $83 = ($$0$ph$lcssa$i$i$i$i$i37|0)==($20|0);
     if ($83) {
      $$0$i$i39 = $74;
      break L23;
     }
     $84 = ((($$0$ph$lcssa$i$i$i$i$i37)) + 16|0);
     $85 = HEAP32[$84>>2]|0;
     $86 = ($74>>>0)<($85>>>0);
     $72 = ((($$sroa$011$025$i$i30)) + 4|0);
     if ($86) {
      $$0$i$i39 = $74;
      break L23;
     }
     $73 = ($72|0)==($68|0);
     if ($73) {
      $$0$i$i39 = 0;
      break;
     } else {
      $$sroa$011$025$i$i30 = $72;
     }
    }
   }
  } while(0);
  $87 = HEAP32[$59>>2]|0;
  $88 = ((($87)) + 12|0);
  $89 = HEAP32[$88>>2]|0;
  __THREW__ = 0;
  (invoke_ii($89|0,($59|0))|0);
  $90 = __THREW__; __THREW__ = 0;
  $91 = $90&1;
  if ($91) {
   label = 31;
   break;
  }
  $92 = HEAP32[$$0$i$i39>>2]|0;
  $93 = ((($92)) + 204|0);
  $94 = HEAP32[$93>>2]|0;
  __THREW__ = 0;
  invoke_viiiii($94|0,($0|0),($$0$i$i39|0),($2|0),($3|0),($4|0));
  $95 = __THREW__; __THREW__ = 0;
  $96 = $95&1;
  if ($96) {
   label = 31;
   break;
  }
  $97 = HEAP32[$0>>2]|0;
  $98 = ($97|0)==(3);
  if ($98) {
   label = 123;
   break;
  }
  $108 = HEAP32[$13>>2]|0;
  $109 = HEAP32[$22>>2]|0;
  $110 = ($108|0)==($109|0);
  if ($110) {
   __THREW__ = 0;
   invoke_vii(4220,($7|0),($0|0));
   $116 = __THREW__; __THREW__ = 0;
   $117 = $116&1;
   if ($117) {
    label = 34;
    break;
   }
  } else {
   HEAP32[$108>>2] = $97;
   $111 = ((($108)) + 4|0);
   __THREW__ = 0;
   invoke_vii(3457,($111|0),($23|0));
   $112 = __THREW__; __THREW__ = 0;
   $113 = $112&1;
   if ($113) {
    label = 34;
    break;
   }
   $114 = HEAP32[$13>>2]|0;
   $115 = ((($114)) + 16|0);
   HEAP32[$13>>2] = $115;
  }
  $118 = HEAP8[$24>>0]|0;
  $119 = ($118<<24>>24)<(0);
  if ($119) {
   $120 = HEAP32[$23>>2]|0;
   __ZdlPv($120);
  }
  __THREW__ = 0;
  invoke_vi(4203,($8|0));
  $121 = __THREW__; __THREW__ = 0;
  $122 = $121&1;
  if ($122) {
   label = 31;
   break;
  }
  $$pre = HEAP32[$17>>2]|0;
  $26 = $$pre;
 }
 L51: do {
  if ((label|0) == 31) {
   $99 = ___cxa_find_matching_catch_2()|0;
   $100 = tempRet0;
   $eh$lpad$body$index5Z2D = $100;$eh$lpad$body$indexZ2D = $99;
   label = 33;
  }
  else if ((label|0) == 34) {
   $103 = ___cxa_find_matching_catch_2()|0;
   $104 = tempRet0;
   $105 = HEAP8[$24>>0]|0;
   $106 = ($105<<24>>24)<(0);
   if ($106) {
    $107 = HEAP32[$23>>2]|0;
    __ZdlPv($107);
    $$4 = $104;$$423 = $103;
   } else {
    $$4 = $104;$$423 = $103;
   }
  }
  else if ((label|0) == 44) {
   __THREW__ = 0;
   invoke_vii(4205,($6|0),($3|0));
   $123 = __THREW__; __THREW__ = 0;
   $124 = $123&1;
   if ($124) {
    $101 = ___cxa_find_matching_catch_2()|0;
    $102 = tempRet0;
    $eh$lpad$body$index5Z2D = $102;$eh$lpad$body$indexZ2D = $101;
    label = 33;
    break;
   }
   __THREW__ = 0;
   invoke_viii(4192,($9|0),($1|0),($6|0));
   $125 = __THREW__; __THREW__ = 0;
   $126 = $125&1;
   if ($126) {
    $131 = ___cxa_find_matching_catch_2()|0;
    $132 = tempRet0;
    $133 = ((($6)) + 11|0);
    $134 = HEAP8[$133>>0]|0;
    $135 = ($134<<24>>24)<(0);
    if ($135) {
     $136 = HEAP32[$6>>2]|0;
     __ZdlPv($136);
    }
    $eh$lpad$body$index5Z2D = $132;$eh$lpad$body$indexZ2D = $131;
    label = 33;
    break;
   }
   $127 = ((($6)) + 11|0);
   $128 = HEAP8[$127>>0]|0;
   $129 = ($128<<24>>24)<(0);
   if ($129) {
    $130 = HEAP32[$6>>2]|0;
    __ZdlPv($130);
   }
   __THREW__ = 0;
   $137 = (invoke_iii(4194,($1|0),($9|0))|0);
   $138 = __THREW__; __THREW__ = 0;
   $139 = $138&1;
   L68: do {
    if ($139) {
     label = 82;
    } else {
     $140 = ($137|0)==(2);
     L70: do {
      if ($140) {
       while(1) {
        $141 = HEAP32[$17>>2]|0;
        $142 = HEAP32[$141>>2]|0;
        $143 = ((($142)) + 8|0);
        $144 = HEAP32[$143>>2]|0;
        __THREW__ = 0;
        (invoke_ii($144|0,($141|0))|0);
        $145 = __THREW__; __THREW__ = 0;
        $146 = $145&1;
        if ($146) {
         label = 82;
         break L68;
        }
        $147 = HEAP32[$8>>2]|0;
        $148 = HEAP32[$147>>2]|0;
        $149 = ((($147)) + 4|0);
        $150 = HEAP32[$149>>2]|0;
        $151 = ($148|0)==($150|0);
        L74: do {
         if ($151) {
          $$0$i$i59 = 0;
         } else {
          $152 = HEAP32[$20>>2]|0;
          $153 = ($152|0)==(0|0);
          if ($153) {
           $$pre$i$i48 = HEAP32[$148>>2]|0;
           $$0$i$i59 = $$pre$i$i48;
           break;
          } else {
           $$sroa$011$025$i$i50 = $148;
          }
          while(1) {
           $156 = HEAP32[$$sroa$011$025$i$i50>>2]|0;
           $$0$ph13$i$i$i$i$i52 = $20;$$07$ph12$i$i$i$i$i53 = $152;
           L80: while(1) {
            $$0710$i$i$i$i$i55 = $$07$ph12$i$i$i$i$i53;
            while(1) {
             $157 = ((($$0710$i$i$i$i$i55)) + 16|0);
             $158 = HEAP32[$157>>2]|0;
             $159 = ($158>>>0)<($156>>>0);
             if (!($159)) {
              break;
             }
             $162 = ((($$0710$i$i$i$i$i55)) + 4|0);
             $163 = HEAP32[$162>>2]|0;
             $164 = ($163|0)==(0|0);
             if ($164) {
              $$0$ph$lcssa$i$i$i$i$i57 = $$0$ph13$i$i$i$i$i52;
              break L80;
             } else {
              $$0710$i$i$i$i$i55 = $163;
             }
            }
            $160 = HEAP32[$$0710$i$i$i$i$i55>>2]|0;
            $161 = ($160|0)==(0|0);
            if ($161) {
             $$0$ph$lcssa$i$i$i$i$i57 = $$0710$i$i$i$i$i55;
             break;
            } else {
             $$0$ph13$i$i$i$i$i52 = $$0710$i$i$i$i$i55;$$07$ph12$i$i$i$i$i53 = $160;
            }
           }
           $165 = ($$0$ph$lcssa$i$i$i$i$i57|0)==($20|0);
           if ($165) {
            $$0$i$i59 = $156;
            break L74;
           }
           $166 = ((($$0$ph$lcssa$i$i$i$i$i57)) + 16|0);
           $167 = HEAP32[$166>>2]|0;
           $168 = ($156>>>0)<($167>>>0);
           $154 = ((($$sroa$011$025$i$i50)) + 4|0);
           if ($168) {
            $$0$i$i59 = $156;
            break L74;
           }
           $155 = ($154|0)==($150|0);
           if ($155) {
            $$0$i$i59 = 0;
            break;
           } else {
            $$sroa$011$025$i$i50 = $154;
           }
          }
         }
        } while(0);
        $169 = HEAP32[$141>>2]|0;
        $170 = ((($169)) + 12|0);
        $171 = HEAP32[$170>>2]|0;
        __THREW__ = 0;
        (invoke_ii($171|0,($141|0))|0);
        $172 = __THREW__; __THREW__ = 0;
        $173 = $172&1;
        if ($173) {
         label = 82;
         break L68;
        }
        $174 = ($$0$i$i59|0)==(0|0);
        if ($174) {
         label = 92;
         break L70;
        }
        $175 = HEAP32[$17>>2]|0;
        $176 = HEAP32[$175>>2]|0;
        $177 = ((($176)) + 8|0);
        $178 = HEAP32[$177>>2]|0;
        __THREW__ = 0;
        (invoke_ii($178|0,($175|0))|0);
        $179 = __THREW__; __THREW__ = 0;
        $180 = $179&1;
        if ($180) {
         label = 82;
         break L68;
        }
        $181 = HEAP32[$8>>2]|0;
        $182 = HEAP32[$181>>2]|0;
        $183 = ((($181)) + 4|0);
        $184 = HEAP32[$183>>2]|0;
        $185 = ($182|0)==($184|0);
        L93: do {
         if ($185) {
          $$0$i$i76 = 0;
         } else {
          $186 = HEAP32[$20>>2]|0;
          $187 = ($186|0)==(0|0);
          if ($187) {
           $$pre$i$i65 = HEAP32[$182>>2]|0;
           $$0$i$i76 = $$pre$i$i65;
           break;
          } else {
           $$sroa$011$025$i$i67 = $182;
          }
          while(1) {
           $190 = HEAP32[$$sroa$011$025$i$i67>>2]|0;
           $$0$ph13$i$i$i$i$i69 = $20;$$07$ph12$i$i$i$i$i70 = $186;
           L99: while(1) {
            $$0710$i$i$i$i$i72 = $$07$ph12$i$i$i$i$i70;
            while(1) {
             $191 = ((($$0710$i$i$i$i$i72)) + 16|0);
             $192 = HEAP32[$191>>2]|0;
             $193 = ($192>>>0)<($190>>>0);
             if (!($193)) {
              break;
             }
             $196 = ((($$0710$i$i$i$i$i72)) + 4|0);
             $197 = HEAP32[$196>>2]|0;
             $198 = ($197|0)==(0|0);
             if ($198) {
              $$0$ph$lcssa$i$i$i$i$i74 = $$0$ph13$i$i$i$i$i69;
              break L99;
             } else {
              $$0710$i$i$i$i$i72 = $197;
             }
            }
            $194 = HEAP32[$$0710$i$i$i$i$i72>>2]|0;
            $195 = ($194|0)==(0|0);
            if ($195) {
             $$0$ph$lcssa$i$i$i$i$i74 = $$0710$i$i$i$i$i72;
             break;
            } else {
             $$0$ph13$i$i$i$i$i69 = $$0710$i$i$i$i$i72;$$07$ph12$i$i$i$i$i70 = $194;
            }
           }
           $199 = ($$0$ph$lcssa$i$i$i$i$i74|0)==($20|0);
           if ($199) {
            $$0$i$i76 = $190;
            break L93;
           }
           $200 = ((($$0$ph$lcssa$i$i$i$i$i74)) + 16|0);
           $201 = HEAP32[$200>>2]|0;
           $202 = ($190>>>0)<($201>>>0);
           $188 = ((($$sroa$011$025$i$i67)) + 4|0);
           if ($202) {
            $$0$i$i76 = $190;
            break L93;
           }
           $189 = ($188|0)==($184|0);
           if ($189) {
            $$0$i$i76 = 0;
            break;
           } else {
            $$sroa$011$025$i$i67 = $188;
           }
          }
         }
        } while(0);
        $203 = HEAP32[$175>>2]|0;
        $204 = ((($203)) + 12|0);
        $205 = HEAP32[$204>>2]|0;
        __THREW__ = 0;
        (invoke_ii($205|0,($175|0))|0);
        $206 = __THREW__; __THREW__ = 0;
        $207 = $206&1;
        if ($207) {
         label = 82;
         break L68;
        }
        $208 = HEAP32[$$0$i$i76>>2]|0;
        $209 = ((($208)) + 204|0);
        $210 = HEAP32[$209>>2]|0;
        __THREW__ = 0;
        invoke_viiiii($210|0,($0|0),($$0$i$i76|0),($2|0),($3|0),($4|0));
        $211 = __THREW__; __THREW__ = 0;
        $212 = $211&1;
        if ($212) {
         label = 82;
         break L68;
        }
        $213 = HEAP32[$0>>2]|0;
        $214 = ($213|0)==(3);
        if ($214) {
         break L70;
        }
        $222 = HEAP32[$13>>2]|0;
        $223 = HEAP32[$22>>2]|0;
        $224 = ($222|0)==($223|0);
        if ($224) {
         __THREW__ = 0;
         invoke_vii(4220,($7|0),($0|0));
         $230 = __THREW__; __THREW__ = 0;
         $231 = $230&1;
         if ($231) {
          break;
         }
        } else {
         HEAP32[$222>>2] = $213;
         $225 = ((($222)) + 4|0);
         __THREW__ = 0;
         invoke_vii(3457,($225|0),($23|0));
         $226 = __THREW__; __THREW__ = 0;
         $227 = $226&1;
         if ($227) {
          break;
         }
         $228 = HEAP32[$13>>2]|0;
         $229 = ((($228)) + 16|0);
         HEAP32[$13>>2] = $229;
        }
        $232 = HEAP8[$24>>0]|0;
        $233 = ($232<<24>>24)<(0);
        if ($233) {
         $234 = HEAP32[$23>>2]|0;
         __ZdlPv($234);
        }
        __THREW__ = 0;
        invoke_vi(4203,($8|0));
        $235 = __THREW__; __THREW__ = 0;
        $236 = $235&1;
        if ($236) {
         label = 82;
         break L68;
        }
       }
       $217 = ___cxa_find_matching_catch_2()|0;
       $218 = tempRet0;
       $219 = HEAP8[$24>>0]|0;
       $220 = ($219<<24>>24)<(0);
       if (!($220)) {
        $$3 = $218;$$322 = $217;
        break L68;
       }
       $221 = HEAP32[$23>>2]|0;
       __ZdlPv($221);
       $$3 = $218;$$322 = $217;
       break L68;
      } else {
       label = 92;
      }
     } while(0);
     L122: do {
      if ((label|0) == 92) {
       $237 = HEAP32[$7>>2]|0;
       $238 = HEAP32[$13>>2]|0;
       $239 = ($237|0)==($238|0);
       if (!($239)) {
        __THREW__ = 0;
        invoke_viii(4221,($237|0),($238|0),($5|0));
        $268 = __THREW__; __THREW__ = 0;
        $269 = $268&1;
        if ($269) {
         label = 82;
         break L68;
        }
        $270 = HEAP32[$13>>2]|0;
        $271 = ((($270)) + -16|0);
        $272 = HEAP32[$271>>2]|0;
        HEAP32[$12>>2] = $272;
        $273 = ((($12)) + 4|0);
        $274 = ((($270)) + -12|0);
        __THREW__ = 0;
        invoke_vii(3457,($273|0),($274|0));
        $275 = __THREW__; __THREW__ = 0;
        $276 = $275&1;
        if ($276) {
         label = 82;
         break L68;
        }
        $277 = HEAP32[$12>>2]|0;
        HEAP32[$0>>2] = $277;
        __THREW__ = 0;
        invoke_vii(3457,($23|0),($273|0));
        $278 = __THREW__; __THREW__ = 0;
        $279 = $278&1;
        if ($279) {
         $284 = ___cxa_find_matching_catch_2()|0;
         $285 = tempRet0;
         $286 = ((($273)) + 11|0);
         $287 = HEAP8[$286>>0]|0;
         $288 = ($287<<24>>24)<(0);
         if ($288) {
          $289 = HEAP32[$273>>2]|0;
          __ZdlPv($289);
         }
         $$3 = $285;$$322 = $284;
         break L68;
        } else {
         $280 = ((($273)) + 11|0);
         $281 = HEAP8[$280>>0]|0;
         $282 = ($281<<24>>24)<(0);
         if ($282) {
          $283 = HEAP32[$273>>2]|0;
          __ZdlPv($283);
         }
         break;
        }
       }
       __THREW__ = 0;
       invoke_viii(4173,($11|0),(168080|0),($3|0));
       $240 = __THREW__; __THREW__ = 0;
       $241 = $240&1;
       if ($241) {
        $254 = ___cxa_find_matching_catch_2()|0;
        $255 = tempRet0;
        $$118 = $255;$$120 = $254;
       } else {
        __THREW__ = 0;
        invoke_viii(3542,($10|0),($11|0),(167562|0));
        $242 = __THREW__; __THREW__ = 0;
        $243 = $242&1;
        do {
         if ($243) {
          $256 = ___cxa_find_matching_catch_2()|0;
          $257 = tempRet0;
          $$017 = $257;$$019 = $256;
         } else {
          HEAP32[$0>>2] = 2;
          __THREW__ = 0;
          invoke_vii(3457,($23|0),($10|0));
          $244 = __THREW__; __THREW__ = 0;
          $245 = $244&1;
          if ($245) {
           $258 = ___cxa_find_matching_catch_2()|0;
           $259 = tempRet0;
           $260 = ((($10)) + 11|0);
           $261 = HEAP8[$260>>0]|0;
           $262 = ($261<<24>>24)<(0);
           if (!($262)) {
            $$017 = $259;$$019 = $258;
            break;
           }
           $263 = HEAP32[$10>>2]|0;
           __ZdlPv($263);
           $$017 = $259;$$019 = $258;
           break;
          }
          $246 = ((($10)) + 11|0);
          $247 = HEAP8[$246>>0]|0;
          $248 = ($247<<24>>24)<(0);
          if ($248) {
           $249 = HEAP32[$10>>2]|0;
           __ZdlPv($249);
          }
          $250 = ((($11)) + 11|0);
          $251 = HEAP8[$250>>0]|0;
          $252 = ($251<<24>>24)<(0);
          if ($252) {
           $253 = HEAP32[$11>>2]|0;
           __ZdlPv($253);
          }
          break L122;
         }
        } while(0);
        $264 = ((($11)) + 11|0);
        $265 = HEAP8[$264>>0]|0;
        $266 = ($265<<24>>24)<(0);
        if ($266) {
         $267 = HEAP32[$11>>2]|0;
         __ZdlPv($267);
         $$118 = $$017;$$120 = $$019;
        } else {
         $$118 = $$017;$$120 = $$019;
        }
       }
       $$3 = $$118;$$322 = $$120;
       break L68;
      }
     } while(0);
     $290 = ((($9)) + 11|0);
     $291 = HEAP8[$290>>0]|0;
     $292 = ($291<<24>>24)<(0);
     if ($292) {
      $293 = HEAP32[$9>>2]|0;
      __ZdlPv($293);
     }
     label = 123;
     break L51;
    }
   } while(0);
   if ((label|0) == 82) {
    $215 = ___cxa_find_matching_catch_2()|0;
    $216 = tempRet0;
    $$3 = $216;$$322 = $215;
   }
   $294 = ((($9)) + 11|0);
   $295 = HEAP8[$294>>0]|0;
   $296 = ($295<<24>>24)<(0);
   if ($296) {
    $297 = HEAP32[$9>>2]|0;
    __ZdlPv($297);
   }
   $$4 = $$3;$$423 = $$322;
  }
 } while(0);
 if ((label|0) == 33) {
  $$4 = $eh$lpad$body$index5Z2D;$$423 = $eh$lpad$body$indexZ2D;
 }
 else if ((label|0) == 123) {
  $298 = ((($8)) + 8|0);
  $299 = HEAP32[$20>>2]|0;
  __ZNSt3__26__treeIPN5osgDB12ReaderWriterENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($298,$299);
  $300 = HEAP32[$7>>2]|0;
  $301 = ($300|0)==(0|0);
  if ($301) {
   STACKTOP = sp;return;
  }
  $302 = HEAP32[$13>>2]|0;
  $303 = ($302|0)==($300|0);
  if ($303) {
   $313 = $300;
  } else {
   $305 = $302;
   while(1) {
    $304 = ((($305)) + -16|0);
    HEAP32[$13>>2] = $304;
    $306 = ((($305)) + -12|0);
    $307 = ((($306)) + 11|0);
    $308 = HEAP8[$307>>0]|0;
    $309 = ($308<<24>>24)<(0);
    if ($309) {
     $312 = HEAP32[$306>>2]|0;
     __ZdlPv($312);
     $$pre$i$i$i100 = HEAP32[$13>>2]|0;
     $310 = $$pre$i$i$i100;
    } else {
     $310 = $304;
    }
    $311 = ($310|0)==($300|0);
    if ($311) {
     break;
    } else {
     $305 = $310;
    }
   }
   $$pre$i102 = HEAP32[$7>>2]|0;
   $313 = $$pre$i102;
  }
  __ZdlPv($313);
  STACKTOP = sp;return;
 }
 $314 = ((($8)) + 8|0);
 $315 = HEAP32[$20>>2]|0;
 __ZNSt3__26__treeIPN5osgDB12ReaderWriterENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($314,$315);
 $316 = HEAP32[$7>>2]|0;
 $317 = ($316|0)==(0|0);
 if ($317) {
  ___resumeException($$423|0);
  // unreachable;
 }
 $318 = HEAP32[$13>>2]|0;
 $319 = ($318|0)==($316|0);
 if ($319) {
  $329 = $316;
 } else {
  $321 = $318;
  while(1) {
   $320 = ((($321)) + -16|0);
   HEAP32[$13>>2] = $320;
   $322 = ((($321)) + -12|0);
   $323 = ((($322)) + 11|0);
   $324 = HEAP8[$323>>0]|0;
   $325 = ($324<<24>>24)<(0);
   if ($325) {
    $328 = HEAP32[$322>>2]|0;
    __ZdlPv($328);
    $$pre$i$i$i = HEAP32[$13>>2]|0;
    $326 = $$pre$i$i$i;
   } else {
    $326 = $320;
   }
   $327 = ($326|0)==($316|0);
   if ($327) {
    break;
   } else {
    $321 = $326;
   }
  }
  $$pre$i = HEAP32[$7>>2]|0;
  $329 = $$pre$i;
 }
 __ZdlPv($329);
 ___resumeException($$423|0);
 // unreachable;
}
function __ZN5osgDB8Registry29readHeightFieldImplementationERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEPKNS_7OptionsE($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $4 = sp;
 HEAP32[$4>>2] = (75072);
 $5 = ((($4)) + 4|0);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_($5,$2);
 $6 = ((($4)) + 16|0);
 HEAP32[$6>>2] = $3;
 HEAP32[$4>>2] = (75200);
 __THREW__ = 0;
 invoke_viiii(4212,($0|0),($1|0),($4|0),4);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $13 = ___cxa_find_matching_catch_2()|0;
  $14 = tempRet0;
  HEAP32[$4>>2] = (75072);
  $15 = ((($5)) + 11|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = ($16<<24>>24)<(0);
  if (!($17)) {
   ___resumeException($13|0);
   // unreachable;
  }
  $18 = HEAP32[$5>>2]|0;
  __ZdlPv($18);
  ___resumeException($13|0);
  // unreachable;
 } else {
  HEAP32[$4>>2] = (75072);
  $9 = ((($5)) + 11|0);
  $10 = HEAP8[$9>>0]|0;
  $11 = ($10<<24>>24)<(0);
  if (!($11)) {
   STACKTOP = sp;return;
  }
  $12 = HEAP32[$5>>2]|0;
  __ZdlPv($12);
  STACKTOP = sp;return;
 }
}
function __ZN5osgDB8Registry22ReadHeightFieldFunctorD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (75072);
 $1 = ((($0)) + 4|0);
 $2 = ((($1)) + 11|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)<(0);
 if (!($4)) {
  __ZdlPv($0);
  return;
 }
 $5 = HEAP32[$1>>2]|0;
 __ZdlPv($5);
 __ZdlPv($0);
 return;
}
function __ZNK5osgDB8Registry22ReadHeightFieldFunctor6doReadERNS_12ReaderWriterE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + 184|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($1)) + 4|0);
 $7 = ((($1)) + 16|0);
 $8 = HEAP32[$7>>2]|0;
 FUNCTION_TABLE_viiii[$5 & 8191]($0,$2,$6,$8);
 return;
}
function __ZNK5osgDB8Registry22ReadHeightFieldFunctor7isValidERNS_12ReaderWriter10ReadResultE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__ZN5osgDB12ReaderWriter10ReadResult14getHeightFieldEv($1)|0);
 $3 = ($2|0)!=(0|0);
 return ($3|0);
}
function __ZNK5osgDB8Registry22ReadHeightFieldFunctor7isValidEPN3osg6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,26576,0)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK5osgDB8Registry22ReadHeightFieldFunctor9cloneTypeERKNSt3__212basic_stringIcNS2_11char_traitsIcEENS2_9allocatorIcEEEEPKNS_7OptionsE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (__Znwj(20)|0);
 HEAP32[$3>>2] = (75072);
 $4 = ((($3)) + 4|0);
 __THREW__ = 0;
 invoke_vii(3457,($4|0),($1|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $8 = ___cxa_find_matching_catch_2()|0;
  $9 = tempRet0;
  __ZdlPv($3);
  ___resumeException($8|0);
  // unreachable;
 } else {
  $7 = ((($3)) + 16|0);
  HEAP32[$7>>2] = $2;
  HEAP32[$3>>2] = (75200);
  return ($3|0);
 }
 return (0)|0;
}
function __ZN5osgDB8Registry30writeHeightFieldImplementationERKN3osg11HeightFieldERKNSt3__212basic_stringIcNS5_11char_traitsIcEENS5_9allocatorIcEEEEPKNS_7OptionsE($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0$i$i = 0, $$0$i$i39 = 0, $$0$i$i59 = 0, $$0$i$i76 = 0, $$0$ph$lcssa$i$i$i$i$i = 0, $$0$ph$lcssa$i$i$i$i$i37 = 0, $$0$ph$lcssa$i$i$i$i$i57 = 0, $$0$ph$lcssa$i$i$i$i$i74 = 0, $$0$ph13$i$i$i$i$i = 0, $$0$ph13$i$i$i$i$i32 = 0, $$0$ph13$i$i$i$i$i52 = 0, $$0$ph13$i$i$i$i$i69 = 0, $$017 = 0, $$019 = 0, $$07$ph12$i$i$i$i$i = 0, $$07$ph12$i$i$i$i$i33 = 0, $$07$ph12$i$i$i$i$i53 = 0, $$07$ph12$i$i$i$i$i70 = 0, $$0710$i$i$i$i$i = 0, $$0710$i$i$i$i$i35 = 0;
 var $$0710$i$i$i$i$i55 = 0, $$0710$i$i$i$i$i72 = 0, $$118 = 0, $$120 = 0, $$3 = 0, $$322 = 0, $$4 = 0, $$423 = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i$i$i = 0, $$pre$i$i$i100 = 0, $$pre$i$i28 = 0, $$pre$i$i48 = 0, $$pre$i$i65 = 0, $$pre$i102 = 0, $$sroa$011$025$i$i = 0, $$sroa$011$025$i$i30 = 0, $$sroa$011$025$i$i50 = 0;
 var $$sroa$011$025$i$i67 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0;
 var $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0;
 var $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0;
 var $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0;
 var $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0;
 var $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0;
 var $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0;
 var $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0;
 var $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0;
 var $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0;
 var $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0;
 var $299 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0;
 var $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index5Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(112|0);
 $5 = sp;
 $6 = sp + 92|0;
 $7 = sp + 80|0;
 $8 = sp + 60|0;
 $9 = sp + 48|0;
 $10 = sp + 36|0;
 $11 = sp + 24|0;
 $12 = sp + 8|0;
 HEAP32[$7>>2] = 0;
 $13 = ((($7)) + 4|0);
 HEAP32[$13>>2] = 0;
 $14 = ((($7)) + 8|0);
 HEAP32[$14>>2] = 0;
 $15 = ((($1)) + 72|0);
 $16 = ((($1)) + 60|0);
 HEAP32[$8>>2] = $15;
 $17 = ((($8)) + 4|0);
 HEAP32[$17>>2] = $16;
 $18 = ((($8)) + 12|0);
 HEAP32[$18>>2] = 0;
 $19 = ((($8)) + 16|0);
 HEAP32[$19>>2] = 0;
 $20 = ((($8)) + 12|0);
 $21 = ((($8)) + 8|0);
 HEAP32[$21>>2] = $20;
 $22 = ((($7)) + 8|0);
 $23 = ((($0)) + 4|0);
 $24 = ((($23)) + 11|0);
 $26 = $16;
 while(1) {
  $25 = HEAP32[$26>>2]|0;
  $27 = ((($25)) + 8|0);
  $28 = HEAP32[$27>>2]|0;
  __THREW__ = 0;
  (invoke_ii($28|0,($26|0))|0);
  $29 = __THREW__; __THREW__ = 0;
  $30 = $29&1;
  if ($30) {
   label = 31;
   break;
  }
  $31 = HEAP32[$8>>2]|0;
  $32 = HEAP32[$31>>2]|0;
  $33 = ((($31)) + 4|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = ($32|0)==($34|0);
  L4: do {
   if ($35) {
    $$0$i$i = 0;
   } else {
    $36 = HEAP32[$20>>2]|0;
    $37 = ($36|0)==(0|0);
    if ($37) {
     $$pre$i$i = HEAP32[$32>>2]|0;
     $$0$i$i = $$pre$i$i;
     break;
    } else {
     $$sroa$011$025$i$i = $32;
    }
    while(1) {
     $40 = HEAP32[$$sroa$011$025$i$i>>2]|0;
     $$0$ph13$i$i$i$i$i = $20;$$07$ph12$i$i$i$i$i = $36;
     L10: while(1) {
      $$0710$i$i$i$i$i = $$07$ph12$i$i$i$i$i;
      while(1) {
       $41 = ((($$0710$i$i$i$i$i)) + 16|0);
       $42 = HEAP32[$41>>2]|0;
       $43 = ($42>>>0)<($40>>>0);
       if (!($43)) {
        break;
       }
       $46 = ((($$0710$i$i$i$i$i)) + 4|0);
       $47 = HEAP32[$46>>2]|0;
       $48 = ($47|0)==(0|0);
       if ($48) {
        $$0$ph$lcssa$i$i$i$i$i = $$0$ph13$i$i$i$i$i;
        break L10;
       } else {
        $$0710$i$i$i$i$i = $47;
       }
      }
      $44 = HEAP32[$$0710$i$i$i$i$i>>2]|0;
      $45 = ($44|0)==(0|0);
      if ($45) {
       $$0$ph$lcssa$i$i$i$i$i = $$0710$i$i$i$i$i;
       break;
      } else {
       $$0$ph13$i$i$i$i$i = $$0710$i$i$i$i$i;$$07$ph12$i$i$i$i$i = $44;
      }
     }
     $49 = ($$0$ph$lcssa$i$i$i$i$i|0)==($20|0);
     if ($49) {
      $$0$i$i = $40;
      break L4;
     }
     $50 = ((($$0$ph$lcssa$i$i$i$i$i)) + 16|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = ($40>>>0)<($51>>>0);
     $38 = ((($$sroa$011$025$i$i)) + 4|0);
     if ($52) {
      $$0$i$i = $40;
      break L4;
     }
     $39 = ($38|0)==($34|0);
     if ($39) {
      $$0$i$i = 0;
      break;
     } else {
      $$sroa$011$025$i$i = $38;
     }
    }
   }
  } while(0);
  $53 = HEAP32[$26>>2]|0;
  $54 = ((($53)) + 12|0);
  $55 = HEAP32[$54>>2]|0;
  __THREW__ = 0;
  (invoke_ii($55|0,($26|0))|0);
  $56 = __THREW__; __THREW__ = 0;
  $57 = $56&1;
  if ($57) {
   label = 31;
   break;
  }
  $58 = ($$0$i$i|0)==(0|0);
  if ($58) {
   label = 44;
   break;
  }
  $59 = HEAP32[$17>>2]|0;
  $60 = HEAP32[$59>>2]|0;
  $61 = ((($60)) + 8|0);
  $62 = HEAP32[$61>>2]|0;
  __THREW__ = 0;
  (invoke_ii($62|0,($59|0))|0);
  $63 = __THREW__; __THREW__ = 0;
  $64 = $63&1;
  if ($64) {
   label = 31;
   break;
  }
  $65 = HEAP32[$8>>2]|0;
  $66 = HEAP32[$65>>2]|0;
  $67 = ((($65)) + 4|0);
  $68 = HEAP32[$67>>2]|0;
  $69 = ($66|0)==($68|0);
  L23: do {
   if ($69) {
    $$0$i$i39 = 0;
   } else {
    $70 = HEAP32[$20>>2]|0;
    $71 = ($70|0)==(0|0);
    if ($71) {
     $$pre$i$i28 = HEAP32[$66>>2]|0;
     $$0$i$i39 = $$pre$i$i28;
     break;
    } else {
     $$sroa$011$025$i$i30 = $66;
    }
    while(1) {
     $74 = HEAP32[$$sroa$011$025$i$i30>>2]|0;
     $$0$ph13$i$i$i$i$i32 = $20;$$07$ph12$i$i$i$i$i33 = $70;
     L29: while(1) {
      $$0710$i$i$i$i$i35 = $$07$ph12$i$i$i$i$i33;
      while(1) {
       $75 = ((($$0710$i$i$i$i$i35)) + 16|0);
       $76 = HEAP32[$75>>2]|0;
       $77 = ($76>>>0)<($74>>>0);
       if (!($77)) {
        break;
       }
       $80 = ((($$0710$i$i$i$i$i35)) + 4|0);
       $81 = HEAP32[$80>>2]|0;
       $82 = ($81|0)==(0|0);
       if ($82) {
        $$0$ph$lcssa$i$i$i$i$i37 = $$0$ph13$i$i$i$i$i32;
        break L29;
       } else {
        $$0710$i$i$i$i$i35 = $81;
       }
      }
      $78 = HEAP32[$$0710$i$i$i$i$i35>>2]|0;
      $79 = ($78|0)==(0|0);
      if ($79) {
       $$0$ph$lcssa$i$i$i$i$i37 = $$0710$i$i$i$i$i35;
       break;
      } else {
       $$0$ph13$i$i$i$i$i32 = $$0710$i$i$i$i$i35;$$07$ph12$i$i$i$i$i33 = $78;
      }
     }
     $83 = ($$0$ph$lcssa$i$i$i$i$i37|0)==($20|0);
     if ($83) {
      $$0$i$i39 = $74;
      break L23;
     }
     $84 = ((($$0$ph$lcssa$i$i$i$i$i37)) + 16|0);
     $85 = HEAP32[$84>>2]|0;
     $86 = ($74>>>0)<($85>>>0);
     $72 = ((($$sroa$011$025$i$i30)) + 4|0);
     if ($86) {
      $$0$i$i39 = $74;
      break L23;
     }
     $73 = ($72|0)==($68|0);
     if ($73) {
      $$0$i$i39 = 0;
      break;
     } else {
      $$sroa$011$025$i$i30 = $72;
     }
    }
   }
  } while(0);
  $87 = HEAP32[$59>>2]|0;
  $88 = ((($87)) + 12|0);
  $89 = HEAP32[$88>>2]|0;
  __THREW__ = 0;
  (invoke_ii($89|0,($59|0))|0);
  $90 = __THREW__; __THREW__ = 0;
  $91 = $90&1;
  if ($91) {
   label = 31;
   break;
  }
  $92 = HEAP32[$$0$i$i39>>2]|0;
  $93 = ((($92)) + 208|0);
  $94 = HEAP32[$93>>2]|0;
  __THREW__ = 0;
  invoke_viiiii($94|0,($0|0),($$0$i$i39|0),($2|0),($3|0),($4|0));
  $95 = __THREW__; __THREW__ = 0;
  $96 = $95&1;
  if ($96) {
   label = 31;
   break;
  }
  $97 = HEAP32[$0>>2]|0;
  $98 = ($97|0)==(3);
  if ($98) {
   label = 123;
   break;
  }
  $108 = HEAP32[$13>>2]|0;
  $109 = HEAP32[$22>>2]|0;
  $110 = ($108|0)==($109|0);
  if ($110) {
   __THREW__ = 0;
   invoke_vii(4220,($7|0),($0|0));
   $116 = __THREW__; __THREW__ = 0;
   $117 = $116&1;
   if ($117) {
    label = 34;
    break;
   }
  } else {
   HEAP32[$108>>2] = $97;
   $111 = ((($108)) + 4|0);
   __THREW__ = 0;
   invoke_vii(3457,($111|0),($23|0));
   $112 = __THREW__; __THREW__ = 0;
   $113 = $112&1;
   if ($113) {
    label = 34;
    break;
   }
   $114 = HEAP32[$13>>2]|0;
   $115 = ((($114)) + 16|0);
   HEAP32[$13>>2] = $115;
  }
  $118 = HEAP8[$24>>0]|0;
  $119 = ($118<<24>>24)<(0);
  if ($119) {
   $120 = HEAP32[$23>>2]|0;
   __ZdlPv($120);
  }
  __THREW__ = 0;
  invoke_vi(4203,($8|0));
  $121 = __THREW__; __THREW__ = 0;
  $122 = $121&1;
  if ($122) {
   label = 31;
   break;
  }
  $$pre = HEAP32[$17>>2]|0;
  $26 = $$pre;
 }
 L51: do {
  if ((label|0) == 31) {
   $99 = ___cxa_find_matching_catch_2()|0;
   $100 = tempRet0;
   $eh$lpad$body$index5Z2D = $100;$eh$lpad$body$indexZ2D = $99;
   label = 33;
  }
  else if ((label|0) == 34) {
   $103 = ___cxa_find_matching_catch_2()|0;
   $104 = tempRet0;
   $105 = HEAP8[$24>>0]|0;
   $106 = ($105<<24>>24)<(0);
   if ($106) {
    $107 = HEAP32[$23>>2]|0;
    __ZdlPv($107);
    $$4 = $104;$$423 = $103;
   } else {
    $$4 = $104;$$423 = $103;
   }
  }
  else if ((label|0) == 44) {
   __THREW__ = 0;
   invoke_vii(4205,($6|0),($3|0));
   $123 = __THREW__; __THREW__ = 0;
   $124 = $123&1;
   if ($124) {
    $101 = ___cxa_find_matching_catch_2()|0;
    $102 = tempRet0;
    $eh$lpad$body$index5Z2D = $102;$eh$lpad$body$indexZ2D = $101;
    label = 33;
    break;
   }
   __THREW__ = 0;
   invoke_viii(4192,($9|0),($1|0),($6|0));
   $125 = __THREW__; __THREW__ = 0;
   $126 = $125&1;
   if ($126) {
    $131 = ___cxa_find_matching_catch_2()|0;
    $132 = tempRet0;
    $133 = ((($6)) + 11|0);
    $134 = HEAP8[$133>>0]|0;
    $135 = ($134<<24>>24)<(0);
    if ($135) {
     $136 = HEAP32[$6>>2]|0;
     __ZdlPv($136);
    }
    $eh$lpad$body$index5Z2D = $132;$eh$lpad$body$indexZ2D = $131;
    label = 33;
    break;
   }
   $127 = ((($6)) + 11|0);
   $128 = HEAP8[$127>>0]|0;
   $129 = ($128<<24>>24)<(0);
   if ($129) {
    $130 = HEAP32[$6>>2]|0;
    __ZdlPv($130);
   }
   __THREW__ = 0;
   $137 = (invoke_iii(4194,($1|0),($9|0))|0);
   $138 = __THREW__; __THREW__ = 0;
   $139 = $138&1;
   L68: do {
    if ($139) {
     label = 82;
    } else {
     $140 = ($137|0)==(2);
     L70: do {
      if ($140) {
       while(1) {
        $141 = HEAP32[$17>>2]|0;
        $142 = HEAP32[$141>>2]|0;
        $143 = ((($142)) + 8|0);
        $144 = HEAP32[$143>>2]|0;
        __THREW__ = 0;
        (invoke_ii($144|0,($141|0))|0);
        $145 = __THREW__; __THREW__ = 0;
        $146 = $145&1;
        if ($146) {
         label = 82;
         break L68;
        }
        $147 = HEAP32[$8>>2]|0;
        $148 = HEAP32[$147>>2]|0;
        $149 = ((($147)) + 4|0);
        $150 = HEAP32[$149>>2]|0;
        $151 = ($148|0)==($150|0);
        L74: do {
         if ($151) {
          $$0$i$i59 = 0;
         } else {
          $152 = HEAP32[$20>>2]|0;
          $153 = ($152|0)==(0|0);
          if ($153) {
           $$pre$i$i48 = HEAP32[$148>>2]|0;
           $$0$i$i59 = $$pre$i$i48;
           break;
          } else {
           $$sroa$011$025$i$i50 = $148;
          }
          while(1) {
           $156 = HEAP32[$$sroa$011$025$i$i50>>2]|0;
           $$0$ph13$i$i$i$i$i52 = $20;$$07$ph12$i$i$i$i$i53 = $152;
           L80: while(1) {
            $$0710$i$i$i$i$i55 = $$07$ph12$i$i$i$i$i53;
            while(1) {
             $157 = ((($$0710$i$i$i$i$i55)) + 16|0);
             $158 = HEAP32[$157>>2]|0;
             $159 = ($158>>>0)<($156>>>0);
             if (!($159)) {
              break;
             }
             $162 = ((($$0710$i$i$i$i$i55)) + 4|0);
             $163 = HEAP32[$162>>2]|0;
             $164 = ($163|0)==(0|0);
             if ($164) {
              $$0$ph$lcssa$i$i$i$i$i57 = $$0$ph13$i$i$i$i$i52;
              break L80;
             } else {
              $$0710$i$i$i$i$i55 = $163;
             }
            }
            $160 = HEAP32[$$0710$i$i$i$i$i55>>2]|0;
            $161 = ($160|0)==(0|0);
            if ($161) {
             $$0$ph$lcssa$i$i$i$i$i57 = $$0710$i$i$i$i$i55;
             break;
            } else {
             $$0$ph13$i$i$i$i$i52 = $$0710$i$i$i$i$i55;$$07$ph12$i$i$i$i$i53 = $160;
            }
           }
           $165 = ($$0$ph$lcssa$i$i$i$i$i57|0)==($20|0);
           if ($165) {
            $$0$i$i59 = $156;
            break L74;
           }
           $166 = ((($$0$ph$lcssa$i$i$i$i$i57)) + 16|0);
           $167 = HEAP32[$166>>2]|0;
           $168 = ($156>>>0)<($167>>>0);
           $154 = ((($$sroa$011$025$i$i50)) + 4|0);
           if ($168) {
            $$0$i$i59 = $156;
            break L74;
           }
           $155 = ($154|0)==($150|0);
           if ($155) {
            $$0$i$i59 = 0;
            break;
           } else {
            $$sroa$011$025$i$i50 = $154;
           }
          }
         }
        } while(0);
        $169 = HEAP32[$141>>2]|0;
        $170 = ((($169)) + 12|0);
        $171 = HEAP32[$170>>2]|0;
        __THREW__ = 0;
        (invoke_ii($171|0,($141|0))|0);
        $172 = __THREW__; __THREW__ = 0;
        $173 = $172&1;
        if ($173) {
         label = 82;
         break L68;
        }
        $174 = ($$0$i$i59|0)==(0|0);
        if ($174) {
         label = 92;
         break L70;
        }
        $175 = HEAP32[$17>>2]|0;
        $176 = HEAP32[$175>>2]|0;
        $177 = ((($176)) + 8|0);
        $178 = HEAP32[$177>>2]|0;
        __THREW__ = 0;
        (invoke_ii($178|0,($175|0))|0);
        $179 = __THREW__; __THREW__ = 0;
        $180 = $179&1;
        if ($180) {
         label = 82;
         break L68;
        }
        $181 = HEAP32[$8>>2]|0;
        $182 = HEAP32[$181>>2]|0;
        $183 = ((($181)) + 4|0);
        $184 = HEAP32[$183>>2]|0;
        $185 = ($182|0)==($184|0);
        L93: do {
         if ($185) {
          $$0$i$i76 = 0;
         } else {
          $186 = HEAP32[$20>>2]|0;
          $187 = ($186|0)==(0|0);
          if ($187) {
           $$pre$i$i65 = HEAP32[$182>>2]|0;
           $$0$i$i76 = $$pre$i$i65;
           break;
          } else {
           $$sroa$011$025$i$i67 = $182;
          }
          while(1) {
           $190 = HEAP32[$$sroa$011$025$i$i67>>2]|0;
           $$0$ph13$i$i$i$i$i69 = $20;$$07$ph12$i$i$i$i$i70 = $186;
           L99: while(1) {
            $$0710$i$i$i$i$i72 = $$07$ph12$i$i$i$i$i70;
            while(1) {
             $191 = ((($$0710$i$i$i$i$i72)) + 16|0);
             $192 = HEAP32[$191>>2]|0;
             $193 = ($192>>>0)<($190>>>0);
             if (!($193)) {
              break;
             }
             $196 = ((($$0710$i$i$i$i$i72)) + 4|0);
             $197 = HEAP32[$196>>2]|0;
             $198 = ($197|0)==(0|0);
             if ($198) {
              $$0$ph$lcssa$i$i$i$i$i74 = $$0$ph13$i$i$i$i$i69;
              break L99;
             } else {
              $$0710$i$i$i$i$i72 = $197;
             }
            }
            $194 = HEAP32[$$0710$i$i$i$i$i72>>2]|0;
            $195 = ($194|0)==(0|0);
            if ($195) {
             $$0$ph$lcssa$i$i$i$i$i74 = $$0710$i$i$i$i$i72;
             break;
            } else {
             $$0$ph13$i$i$i$i$i69 = $$0710$i$i$i$i$i72;$$07$ph12$i$i$i$i$i70 = $194;
            }
           }
           $199 = ($$0$ph$lcssa$i$i$i$i$i74|0)==($20|0);
           if ($199) {
            $$0$i$i76 = $190;
            break L93;
           }
           $200 = ((($$0$ph$lcssa$i$i$i$i$i74)) + 16|0);
           $201 = HEAP32[$200>>2]|0;
           $202 = ($190>>>0)<($201>>>0);
           $188 = ((($$sroa$011$025$i$i67)) + 4|0);
           if ($202) {
            $$0$i$i76 = $190;
            break L93;
           }
           $189 = ($188|0)==($184|0);
           if ($189) {
            $$0$i$i76 = 0;
            break;
           } else {
            $$sroa$011$025$i$i67 = $188;
           }
          }
         }
        } while(0);
        $203 = HEAP32[$175>>2]|0;
        $204 = ((($203)) + 12|0);
        $205 = HEAP32[$204>>2]|0;
        __THREW__ = 0;
        (invoke_ii($205|0,($175|0))|0);
        $206 = __THREW__; __THREW__ = 0;
        $207 = $206&1;
        if ($207) {
         label = 82;
         break L68;
        }
        $208 = HEAP32[$$0$i$i76>>2]|0;
        $209 = ((($208)) + 208|0);
        $210 = HEAP32[$209>>2]|0;
        __THREW__ = 0;
        invoke_viiiii($210|0,($0|0),($$0$i$i76|0),($2|0),($3|0),($4|0));
        $211 = __THREW__; __THREW__ = 0;
        $212 = $211&1;
        if ($212) {
         label = 82;
         break L68;
        }
        $213 = HEAP32[$0>>2]|0;
        $214 = ($213|0)==(3);
        if ($214) {
         break L70;
        }
        $222 = HEAP32[$13>>2]|0;
        $223 = HEAP32[$22>>2]|0;
        $224 = ($222|0)==($223|0);
        if ($224) {
         __THREW__ = 0;
         invoke_vii(4220,($7|0),($0|0));
         $230 = __THREW__; __THREW__ = 0;
         $231 = $230&1;
         if ($231) {
          break;
         }
        } else {
         HEAP32[$222>>2] = $213;
         $225 = ((($222)) + 4|0);
         __THREW__ = 0;
         invoke_vii(3457,($225|0),($23|0));
         $226 = __THREW__; __THREW__ = 0;
         $227 = $226&1;
         if ($227) {
          break;
         }
         $228 = HEAP32[$13>>2]|0;
         $229 = ((($228)) + 16|0);
         HEAP32[$13>>2] = $229;
        }
        $232 = HEAP8[$24>>0]|0;
        $233 = ($232<<24>>24)<(0);
        if ($233) {
         $234 = HEAP32[$23>>2]|0;
         __ZdlPv($234);
        }
        __THREW__ = 0;
        invoke_vi(4203,($8|0));
        $235 = __THREW__; __THREW__ = 0;
        $236 = $235&1;
        if ($236) {
         label = 82;
         break L68;
        }
       }
       $217 = ___cxa_find_matching_catch_2()|0;
       $218 = tempRet0;
       $219 = HEAP8[$24>>0]|0;
       $220 = ($219<<24>>24)<(0);
       if (!($220)) {
        $$3 = $218;$$322 = $217;
        break L68;
       }
       $221 = HEAP32[$23>>2]|0;
       __ZdlPv($221);
       $$3 = $218;$$322 = $217;
       break L68;
      } else {
       label = 92;
      }
     } while(0);
     L122: do {
      if ((label|0) == 92) {
       $237 = HEAP32[$7>>2]|0;
       $238 = HEAP32[$13>>2]|0;
       $239 = ($237|0)==($238|0);
       if (!($239)) {
        __THREW__ = 0;
        invoke_viii(4221,($237|0),($238|0),($5|0));
        $268 = __THREW__; __THREW__ = 0;
        $269 = $268&1;
        if ($269) {
         label = 82;
         break L68;
        }
        $270 = HEAP32[$13>>2]|0;
        $271 = ((($270)) + -16|0);
        $272 = HEAP32[$271>>2]|0;
        HEAP32[$12>>2] = $272;
        $273 = ((($12)) + 4|0);
        $274 = ((($270)) + -12|0);
        __THREW__ = 0;
        invoke_vii(3457,($273|0),($274|0));
        $275 = __THREW__; __THREW__ = 0;
        $276 = $275&1;
        if ($276) {
         label = 82;
         break L68;
        }
        $277 = HEAP32[$12>>2]|0;
        HEAP32[$0>>2] = $277;
        __THREW__ = 0;
        invoke_vii(3457,($23|0),($273|0));
        $278 = __THREW__; __THREW__ = 0;
        $279 = $278&1;
        if ($279) {
         $284 = ___cxa_find_matching_catch_2()|0;
         $285 = tempRet0;
         $286 = ((($273)) + 11|0);
         $287 = HEAP8[$286>>0]|0;
         $288 = ($287<<24>>24)<(0);
         if ($288) {
          $289 = HEAP32[$273>>2]|0;
          __ZdlPv($289);
         }
         $$3 = $285;$$322 = $284;
         break L68;
        } else {
         $280 = ((($273)) + 11|0);
         $281 = HEAP8[$280>>0]|0;
         $282 = ($281<<24>>24)<(0);
         if ($282) {
          $283 = HEAP32[$273>>2]|0;
          __ZdlPv($283);
         }
         break;
        }
       }
       __THREW__ = 0;
       invoke_viii(4173,($11|0),(168169|0),($3|0));
       $240 = __THREW__; __THREW__ = 0;
       $241 = $240&1;
       if ($241) {
        $254 = ___cxa_find_matching_catch_2()|0;
        $255 = tempRet0;
        $$118 = $255;$$120 = $254;
       } else {
        __THREW__ = 0;
        invoke_viii(3542,($10|0),($11|0),(167562|0));
        $242 = __THREW__; __THREW__ = 0;
        $243 = $242&1;
        do {
         if ($243) {
          $256 = ___cxa_find_matching_catch_2()|0;
          $257 = tempRet0;
          $$017 = $257;$$019 = $256;
         } else {
          HEAP32[$0>>2] = 2;
          __THREW__ = 0;
          invoke_vii(3457,($23|0),($10|0));
          $244 = __THREW__; __THREW__ = 0;
          $245 = $244&1;
          if ($245) {
           $258 = ___cxa_find_matching_catch_2()|0;
           $259 = tempRet0;
           $260 = ((($10)) + 11|0);
           $261 = HEAP8[$260>>0]|0;
           $262 = ($261<<24>>24)<(0);
           if (!($262)) {
            $$017 = $259;$$019 = $258;
            break;
           }
           $263 = HEAP32[$10>>2]|0;
           __ZdlPv($263);
           $$017 = $259;$$019 = $258;
           break;
          }
          $246 = ((($10)) + 11|0);
          $247 = HEAP8[$246>>0]|0;
          $248 = ($247<<24>>24)<(0);
          if ($248) {
           $249 = HEAP32[$10>>2]|0;
           __ZdlPv($249);
          }
          $250 = ((($11)) + 11|0);
          $251 = HEAP8[$250>>0]|0;
          $252 = ($251<<24>>24)<(0);
          if ($252) {
           $253 = HEAP32[$11>>2]|0;
           __ZdlPv($253);
          }
          break L122;
         }
        } while(0);
        $264 = ((($11)) + 11|0);
        $265 = HEAP8[$264>>0]|0;
        $266 = ($265<<24>>24)<(0);
        if ($266) {
         $267 = HEAP32[$11>>2]|0;
         __ZdlPv($267);
         $$118 = $$017;$$120 = $$019;
        } else {
         $$118 = $$017;$$120 = $$019;
        }
       }
       $$3 = $$118;$$322 = $$120;
       break L68;
      }
     } while(0);
     $290 = ((($9)) + 11|0);
     $291 = HEAP8[$290>>0]|0;
     $292 = ($291<<24>>24)<(0);
     if ($292) {
      $293 = HEAP32[$9>>2]|0;
      __ZdlPv($293);
     }
     label = 123;
     break L51;
    }
   } while(0);
   if ((label|0) == 82) {
    $215 = ___cxa_find_matching_catch_2()|0;
    $216 = tempRet0;
    $$3 = $216;$$322 = $215;
   }
   $294 = ((($9)) + 11|0);
   $295 = HEAP8[$294>>0]|0;
   $296 = ($295<<24>>24)<(0);
   if ($296) {
    $297 = HEAP32[$9>>2]|0;
    __ZdlPv($297);
   }
   $$4 = $$3;$$423 = $$322;
  }
 } while(0);
 if ((label|0) == 33) {
  $$4 = $eh$lpad$body$index5Z2D;$$423 = $eh$lpad$body$indexZ2D;
 }
 else if ((label|0) == 123) {
  $298 = ((($8)) + 8|0);
  $299 = HEAP32[$20>>2]|0;
  __ZNSt3__26__treeIPN5osgDB12ReaderWriterENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($298,$299);
  $300 = HEAP32[$7>>2]|0;
  $301 = ($300|0)==(0|0);
  if ($301) {
   STACKTOP = sp;return;
  }
  $302 = HEAP32[$13>>2]|0;
  $303 = ($302|0)==($300|0);
  if ($303) {
   $313 = $300;
  } else {
   $305 = $302;
   while(1) {
    $304 = ((($305)) + -16|0);
    HEAP32[$13>>2] = $304;
    $306 = ((($305)) + -12|0);
    $307 = ((($306)) + 11|0);
    $308 = HEAP8[$307>>0]|0;
    $309 = ($308<<24>>24)<(0);
    if ($309) {
     $312 = HEAP32[$306>>2]|0;
     __ZdlPv($312);
     $$pre$i$i$i100 = HEAP32[$13>>2]|0;
     $310 = $$pre$i$i$i100;
    } else {
     $310 = $304;
    }
    $311 = ($310|0)==($300|0);
    if ($311) {
     break;
    } else {
     $305 = $310;
    }
   }
   $$pre$i102 = HEAP32[$7>>2]|0;
   $313 = $$pre$i102;
  }
  __ZdlPv($313);
  STACKTOP = sp;return;
 }
 $314 = ((($8)) + 8|0);
 $315 = HEAP32[$20>>2]|0;
 __ZNSt3__26__treeIPN5osgDB12ReaderWriterENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($314,$315);
 $316 = HEAP32[$7>>2]|0;
 $317 = ($316|0)==(0|0);
 if ($317) {
  ___resumeException($$423|0);
  // unreachable;
 }
 $318 = HEAP32[$13>>2]|0;
 $319 = ($318|0)==($316|0);
 if ($319) {
  $329 = $316;
 } else {
  $321 = $318;
  while(1) {
   $320 = ((($321)) + -16|0);
   HEAP32[$13>>2] = $320;
   $322 = ((($321)) + -12|0);
   $323 = ((($322)) + 11|0);
   $324 = HEAP8[$323>>0]|0;
   $325 = ($324<<24>>24)<(0);
   if ($325) {
    $328 = HEAP32[$322>>2]|0;
    __ZdlPv($328);
    $$pre$i$i$i = HEAP32[$13>>2]|0;
    $326 = $$pre$i$i$i;
   } else {
    $326 = $320;
   }
   $327 = ($326|0)==($316|0);
   if ($327) {
    break;
   } else {
    $321 = $326;
   }
  }
  $$pre$i = HEAP32[$7>>2]|0;
  $329 = $$pre$i;
 }
 __ZdlPv($329);
 ___resumeException($$423|0);
 // unreachable;
}
function __ZN5osgDB8Registry22readNodeImplementationERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEPKNS_7OptionsE($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $4 = sp;
 HEAP32[$4>>2] = (75072);
 $5 = ((($4)) + 4|0);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_($5,$2);
 $6 = ((($4)) + 16|0);
 HEAP32[$6>>2] = $3;
 HEAP32[$4>>2] = (75232);
 __THREW__ = 0;
 invoke_viiii(4212,($0|0),($1|0),($4|0),1);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $13 = ___cxa_find_matching_catch_2()|0;
  $14 = tempRet0;
  HEAP32[$4>>2] = (75072);
  $15 = ((($5)) + 11|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = ($16<<24>>24)<(0);
  if (!($17)) {
   ___resumeException($13|0);
   // unreachable;
  }
  $18 = HEAP32[$5>>2]|0;
  __ZdlPv($18);
  ___resumeException($13|0);
  // unreachable;
 } else {
  HEAP32[$4>>2] = (75072);
  $9 = ((($5)) + 11|0);
  $10 = HEAP8[$9>>0]|0;
  $11 = ($10<<24>>24)<(0);
  if (!($11)) {
   STACKTOP = sp;return;
  }
  $12 = HEAP32[$5>>2]|0;
  __ZdlPv($12);
  STACKTOP = sp;return;
 }
}
function __ZN5osgDB8Registry15ReadNodeFunctorD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (75072);
 $1 = ((($0)) + 4|0);
 $2 = ((($1)) + 11|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)<(0);
 if (!($4)) {
  __ZdlPv($0);
  return;
 }
 $5 = HEAP32[$1>>2]|0;
 __ZdlPv($5);
 __ZdlPv($0);
 return;
}
function __ZNK5osgDB8Registry15ReadNodeFunctor6doReadERNS_12ReaderWriterE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + 188|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($1)) + 4|0);
 $7 = ((($1)) + 16|0);
 $8 = HEAP32[$7>>2]|0;
 FUNCTION_TABLE_viiii[$5 & 8191]($0,$2,$6,$8);
 return;
}
function __ZNK5osgDB8Registry15ReadNodeFunctor7isValidERNS_12ReaderWriter10ReadResultE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__ZN5osgDB12ReaderWriter10ReadResult7getNodeEv($1)|0);
 $3 = ($2|0)!=(0|0);
 return ($3|0);
}
function __ZNK5osgDB8Registry15ReadNodeFunctor7isValidEPN3osg6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,25952,0)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK5osgDB8Registry15ReadNodeFunctor9cloneTypeERKNSt3__212basic_stringIcNS2_11char_traitsIcEENS2_9allocatorIcEEEEPKNS_7OptionsE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (__Znwj(20)|0);
 HEAP32[$3>>2] = (75072);
 $4 = ((($3)) + 4|0);
 __THREW__ = 0;
 invoke_vii(3457,($4|0),($1|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $8 = ___cxa_find_matching_catch_2()|0;
  $9 = tempRet0;
  __ZdlPv($3);
  ___resumeException($8|0);
  // unreachable;
 } else {
  $7 = ((($3)) + 16|0);
  HEAP32[$7>>2] = $2;
  HEAP32[$3>>2] = (75232);
  return ($3|0);
 }
 return (0)|0;
}
function __ZN5osgDB8Registry23writeNodeImplementationERKN3osg4NodeERKNSt3__212basic_stringIcNS5_11char_traitsIcEENS5_9allocatorIcEEEEPKNS_7OptionsE($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0$i$i = 0, $$0$i$i39 = 0, $$0$i$i59 = 0, $$0$i$i76 = 0, $$0$ph$lcssa$i$i$i$i$i = 0, $$0$ph$lcssa$i$i$i$i$i37 = 0, $$0$ph$lcssa$i$i$i$i$i57 = 0, $$0$ph$lcssa$i$i$i$i$i74 = 0, $$0$ph13$i$i$i$i$i = 0, $$0$ph13$i$i$i$i$i32 = 0, $$0$ph13$i$i$i$i$i52 = 0, $$0$ph13$i$i$i$i$i69 = 0, $$017 = 0, $$019 = 0, $$07$ph12$i$i$i$i$i = 0, $$07$ph12$i$i$i$i$i33 = 0, $$07$ph12$i$i$i$i$i53 = 0, $$07$ph12$i$i$i$i$i70 = 0, $$0710$i$i$i$i$i = 0, $$0710$i$i$i$i$i35 = 0;
 var $$0710$i$i$i$i$i55 = 0, $$0710$i$i$i$i$i72 = 0, $$118 = 0, $$120 = 0, $$3 = 0, $$322 = 0, $$4 = 0, $$423 = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i$i$i = 0, $$pre$i$i$i100 = 0, $$pre$i$i28 = 0, $$pre$i$i48 = 0, $$pre$i$i65 = 0, $$pre$i102 = 0, $$sroa$011$025$i$i = 0, $$sroa$011$025$i$i30 = 0, $$sroa$011$025$i$i50 = 0;
 var $$sroa$011$025$i$i67 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0;
 var $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0;
 var $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0;
 var $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0;
 var $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0;
 var $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0;
 var $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0;
 var $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0;
 var $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0;
 var $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0;
 var $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0;
 var $299 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0;
 var $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index5Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(112|0);
 $5 = sp;
 $6 = sp + 92|0;
 $7 = sp + 80|0;
 $8 = sp + 60|0;
 $9 = sp + 48|0;
 $10 = sp + 36|0;
 $11 = sp + 24|0;
 $12 = sp + 8|0;
 HEAP32[$7>>2] = 0;
 $13 = ((($7)) + 4|0);
 HEAP32[$13>>2] = 0;
 $14 = ((($7)) + 8|0);
 HEAP32[$14>>2] = 0;
 $15 = ((($1)) + 72|0);
 $16 = ((($1)) + 60|0);
 HEAP32[$8>>2] = $15;
 $17 = ((($8)) + 4|0);
 HEAP32[$17>>2] = $16;
 $18 = ((($8)) + 12|0);
 HEAP32[$18>>2] = 0;
 $19 = ((($8)) + 16|0);
 HEAP32[$19>>2] = 0;
 $20 = ((($8)) + 12|0);
 $21 = ((($8)) + 8|0);
 HEAP32[$21>>2] = $20;
 $22 = ((($7)) + 8|0);
 $23 = ((($0)) + 4|0);
 $24 = ((($23)) + 11|0);
 $26 = $16;
 while(1) {
  $25 = HEAP32[$26>>2]|0;
  $27 = ((($25)) + 8|0);
  $28 = HEAP32[$27>>2]|0;
  __THREW__ = 0;
  (invoke_ii($28|0,($26|0))|0);
  $29 = __THREW__; __THREW__ = 0;
  $30 = $29&1;
  if ($30) {
   label = 31;
   break;
  }
  $31 = HEAP32[$8>>2]|0;
  $32 = HEAP32[$31>>2]|0;
  $33 = ((($31)) + 4|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = ($32|0)==($34|0);
  L4: do {
   if ($35) {
    $$0$i$i = 0;
   } else {
    $36 = HEAP32[$20>>2]|0;
    $37 = ($36|0)==(0|0);
    if ($37) {
     $$pre$i$i = HEAP32[$32>>2]|0;
     $$0$i$i = $$pre$i$i;
     break;
    } else {
     $$sroa$011$025$i$i = $32;
    }
    while(1) {
     $40 = HEAP32[$$sroa$011$025$i$i>>2]|0;
     $$0$ph13$i$i$i$i$i = $20;$$07$ph12$i$i$i$i$i = $36;
     L10: while(1) {
      $$0710$i$i$i$i$i = $$07$ph12$i$i$i$i$i;
      while(1) {
       $41 = ((($$0710$i$i$i$i$i)) + 16|0);
       $42 = HEAP32[$41>>2]|0;
       $43 = ($42>>>0)<($40>>>0);
       if (!($43)) {
        break;
       }
       $46 = ((($$0710$i$i$i$i$i)) + 4|0);
       $47 = HEAP32[$46>>2]|0;
       $48 = ($47|0)==(0|0);
       if ($48) {
        $$0$ph$lcssa$i$i$i$i$i = $$0$ph13$i$i$i$i$i;
        break L10;
       } else {
        $$0710$i$i$i$i$i = $47;
       }
      }
      $44 = HEAP32[$$0710$i$i$i$i$i>>2]|0;
      $45 = ($44|0)==(0|0);
      if ($45) {
       $$0$ph$lcssa$i$i$i$i$i = $$0710$i$i$i$i$i;
       break;
      } else {
       $$0$ph13$i$i$i$i$i = $$0710$i$i$i$i$i;$$07$ph12$i$i$i$i$i = $44;
      }
     }
     $49 = ($$0$ph$lcssa$i$i$i$i$i|0)==($20|0);
     if ($49) {
      $$0$i$i = $40;
      break L4;
     }
     $50 = ((($$0$ph$lcssa$i$i$i$i$i)) + 16|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = ($40>>>0)<($51>>>0);
     $38 = ((($$sroa$011$025$i$i)) + 4|0);
     if ($52) {
      $$0$i$i = $40;
      break L4;
     }
     $39 = ($38|0)==($34|0);
     if ($39) {
      $$0$i$i = 0;
      break;
     } else {
      $$sroa$011$025$i$i = $38;
     }
    }
   }
  } while(0);
  $53 = HEAP32[$26>>2]|0;
  $54 = ((($53)) + 12|0);
  $55 = HEAP32[$54>>2]|0;
  __THREW__ = 0;
  (invoke_ii($55|0,($26|0))|0);
  $56 = __THREW__; __THREW__ = 0;
  $57 = $56&1;
  if ($57) {
   label = 31;
   break;
  }
  $58 = ($$0$i$i|0)==(0|0);
  if ($58) {
   label = 44;
   break;
  }
  $59 = HEAP32[$17>>2]|0;
  $60 = HEAP32[$59>>2]|0;
  $61 = ((($60)) + 8|0);
  $62 = HEAP32[$61>>2]|0;
  __THREW__ = 0;
  (invoke_ii($62|0,($59|0))|0);
  $63 = __THREW__; __THREW__ = 0;
  $64 = $63&1;
  if ($64) {
   label = 31;
   break;
  }
  $65 = HEAP32[$8>>2]|0;
  $66 = HEAP32[$65>>2]|0;
  $67 = ((($65)) + 4|0);
  $68 = HEAP32[$67>>2]|0;
  $69 = ($66|0)==($68|0);
  L23: do {
   if ($69) {
    $$0$i$i39 = 0;
   } else {
    $70 = HEAP32[$20>>2]|0;
    $71 = ($70|0)==(0|0);
    if ($71) {
     $$pre$i$i28 = HEAP32[$66>>2]|0;
     $$0$i$i39 = $$pre$i$i28;
     break;
    } else {
     $$sroa$011$025$i$i30 = $66;
    }
    while(1) {
     $74 = HEAP32[$$sroa$011$025$i$i30>>2]|0;
     $$0$ph13$i$i$i$i$i32 = $20;$$07$ph12$i$i$i$i$i33 = $70;
     L29: while(1) {
      $$0710$i$i$i$i$i35 = $$07$ph12$i$i$i$i$i33;
      while(1) {
       $75 = ((($$0710$i$i$i$i$i35)) + 16|0);
       $76 = HEAP32[$75>>2]|0;
       $77 = ($76>>>0)<($74>>>0);
       if (!($77)) {
        break;
       }
       $80 = ((($$0710$i$i$i$i$i35)) + 4|0);
       $81 = HEAP32[$80>>2]|0;
       $82 = ($81|0)==(0|0);
       if ($82) {
        $$0$ph$lcssa$i$i$i$i$i37 = $$0$ph13$i$i$i$i$i32;
        break L29;
       } else {
        $$0710$i$i$i$i$i35 = $81;
       }
      }
      $78 = HEAP32[$$0710$i$i$i$i$i35>>2]|0;
      $79 = ($78|0)==(0|0);
      if ($79) {
       $$0$ph$lcssa$i$i$i$i$i37 = $$0710$i$i$i$i$i35;
       break;
      } else {
       $$0$ph13$i$i$i$i$i32 = $$0710$i$i$i$i$i35;$$07$ph12$i$i$i$i$i33 = $78;
      }
     }
     $83 = ($$0$ph$lcssa$i$i$i$i$i37|0)==($20|0);
     if ($83) {
      $$0$i$i39 = $74;
      break L23;
     }
     $84 = ((($$0$ph$lcssa$i$i$i$i$i37)) + 16|0);
     $85 = HEAP32[$84>>2]|0;
     $86 = ($74>>>0)<($85>>>0);
     $72 = ((($$sroa$011$025$i$i30)) + 4|0);
     if ($86) {
      $$0$i$i39 = $74;
      break L23;
     }
     $73 = ($72|0)==($68|0);
     if ($73) {
      $$0$i$i39 = 0;
      break;
     } else {
      $$sroa$011$025$i$i30 = $72;
     }
    }
   }
  } while(0);
  $87 = HEAP32[$59>>2]|0;
  $88 = ((($87)) + 12|0);
  $89 = HEAP32[$88>>2]|0;
  __THREW__ = 0;
  (invoke_ii($89|0,($59|0))|0);
  $90 = __THREW__; __THREW__ = 0;
  $91 = $90&1;
  if ($91) {
   label = 31;
   break;
  }
  $92 = HEAP32[$$0$i$i39>>2]|0;
  $93 = ((($92)) + 212|0);
  $94 = HEAP32[$93>>2]|0;
  __THREW__ = 0;
  invoke_viiiii($94|0,($0|0),($$0$i$i39|0),($2|0),($3|0),($4|0));
  $95 = __THREW__; __THREW__ = 0;
  $96 = $95&1;
  if ($96) {
   label = 31;
   break;
  }
  $97 = HEAP32[$0>>2]|0;
  $98 = ($97|0)==(3);
  if ($98) {
   label = 123;
   break;
  }
  $108 = HEAP32[$13>>2]|0;
  $109 = HEAP32[$22>>2]|0;
  $110 = ($108|0)==($109|0);
  if ($110) {
   __THREW__ = 0;
   invoke_vii(4220,($7|0),($0|0));
   $116 = __THREW__; __THREW__ = 0;
   $117 = $116&1;
   if ($117) {
    label = 34;
    break;
   }
  } else {
   HEAP32[$108>>2] = $97;
   $111 = ((($108)) + 4|0);
   __THREW__ = 0;
   invoke_vii(3457,($111|0),($23|0));
   $112 = __THREW__; __THREW__ = 0;
   $113 = $112&1;
   if ($113) {
    label = 34;
    break;
   }
   $114 = HEAP32[$13>>2]|0;
   $115 = ((($114)) + 16|0);
   HEAP32[$13>>2] = $115;
  }
  $118 = HEAP8[$24>>0]|0;
  $119 = ($118<<24>>24)<(0);
  if ($119) {
   $120 = HEAP32[$23>>2]|0;
   __ZdlPv($120);
  }
  __THREW__ = 0;
  invoke_vi(4203,($8|0));
  $121 = __THREW__; __THREW__ = 0;
  $122 = $121&1;
  if ($122) {
   label = 31;
   break;
  }
  $$pre = HEAP32[$17>>2]|0;
  $26 = $$pre;
 }
 L51: do {
  if ((label|0) == 31) {
   $99 = ___cxa_find_matching_catch_2()|0;
   $100 = tempRet0;
   $eh$lpad$body$index5Z2D = $100;$eh$lpad$body$indexZ2D = $99;
   label = 33;
  }
  else if ((label|0) == 34) {
   $103 = ___cxa_find_matching_catch_2()|0;
   $104 = tempRet0;
   $105 = HEAP8[$24>>0]|0;
   $106 = ($105<<24>>24)<(0);
   if ($106) {
    $107 = HEAP32[$23>>2]|0;
    __ZdlPv($107);
    $$4 = $104;$$423 = $103;
   } else {
    $$4 = $104;$$423 = $103;
   }
  }
  else if ((label|0) == 44) {
   __THREW__ = 0;
   invoke_vii(4205,($6|0),($3|0));
   $123 = __THREW__; __THREW__ = 0;
   $124 = $123&1;
   if ($124) {
    $101 = ___cxa_find_matching_catch_2()|0;
    $102 = tempRet0;
    $eh$lpad$body$index5Z2D = $102;$eh$lpad$body$indexZ2D = $101;
    label = 33;
    break;
   }
   __THREW__ = 0;
   invoke_viii(4192,($9|0),($1|0),($6|0));
   $125 = __THREW__; __THREW__ = 0;
   $126 = $125&1;
   if ($126) {
    $131 = ___cxa_find_matching_catch_2()|0;
    $132 = tempRet0;
    $133 = ((($6)) + 11|0);
    $134 = HEAP8[$133>>0]|0;
    $135 = ($134<<24>>24)<(0);
    if ($135) {
     $136 = HEAP32[$6>>2]|0;
     __ZdlPv($136);
    }
    $eh$lpad$body$index5Z2D = $132;$eh$lpad$body$indexZ2D = $131;
    label = 33;
    break;
   }
   $127 = ((($6)) + 11|0);
   $128 = HEAP8[$127>>0]|0;
   $129 = ($128<<24>>24)<(0);
   if ($129) {
    $130 = HEAP32[$6>>2]|0;
    __ZdlPv($130);
   }
   __THREW__ = 0;
   $137 = (invoke_iii(4194,($1|0),($9|0))|0);
   $138 = __THREW__; __THREW__ = 0;
   $139 = $138&1;
   L68: do {
    if ($139) {
     label = 82;
    } else {
     $140 = ($137|0)==(2);
     L70: do {
      if ($140) {
       while(1) {
        $141 = HEAP32[$17>>2]|0;
        $142 = HEAP32[$141>>2]|0;
        $143 = ((($142)) + 8|0);
        $144 = HEAP32[$143>>2]|0;
        __THREW__ = 0;
        (invoke_ii($144|0,($141|0))|0);
        $145 = __THREW__; __THREW__ = 0;
        $146 = $145&1;
        if ($146) {
         label = 82;
         break L68;
        }
        $147 = HEAP32[$8>>2]|0;
        $148 = HEAP32[$147>>2]|0;
        $149 = ((($147)) + 4|0);
        $150 = HEAP32[$149>>2]|0;
        $151 = ($148|0)==($150|0);
        L74: do {
         if ($151) {
          $$0$i$i59 = 0;
         } else {
          $152 = HEAP32[$20>>2]|0;
          $153 = ($152|0)==(0|0);
          if ($153) {
           $$pre$i$i48 = HEAP32[$148>>2]|0;
           $$0$i$i59 = $$pre$i$i48;
           break;
          } else {
           $$sroa$011$025$i$i50 = $148;
          }
          while(1) {
           $156 = HEAP32[$$sroa$011$025$i$i50>>2]|0;
           $$0$ph13$i$i$i$i$i52 = $20;$$07$ph12$i$i$i$i$i53 = $152;
           L80: while(1) {
            $$0710$i$i$i$i$i55 = $$07$ph12$i$i$i$i$i53;
            while(1) {
             $157 = ((($$0710$i$i$i$i$i55)) + 16|0);
             $158 = HEAP32[$157>>2]|0;
             $159 = ($158>>>0)<($156>>>0);
             if (!($159)) {
              break;
             }
             $162 = ((($$0710$i$i$i$i$i55)) + 4|0);
             $163 = HEAP32[$162>>2]|0;
             $164 = ($163|0)==(0|0);
             if ($164) {
              $$0$ph$lcssa$i$i$i$i$i57 = $$0$ph13$i$i$i$i$i52;
              break L80;
             } else {
              $$0710$i$i$i$i$i55 = $163;
             }
            }
            $160 = HEAP32[$$0710$i$i$i$i$i55>>2]|0;
            $161 = ($160|0)==(0|0);
            if ($161) {
             $$0$ph$lcssa$i$i$i$i$i57 = $$0710$i$i$i$i$i55;
             break;
            } else {
             $$0$ph13$i$i$i$i$i52 = $$0710$i$i$i$i$i55;$$07$ph12$i$i$i$i$i53 = $160;
            }
           }
           $165 = ($$0$ph$lcssa$i$i$i$i$i57|0)==($20|0);
           if ($165) {
            $$0$i$i59 = $156;
            break L74;
           }
           $166 = ((($$0$ph$lcssa$i$i$i$i$i57)) + 16|0);
           $167 = HEAP32[$166>>2]|0;
           $168 = ($156>>>0)<($167>>>0);
           $154 = ((($$sroa$011$025$i$i50)) + 4|0);
           if ($168) {
            $$0$i$i59 = $156;
            break L74;
           }
           $155 = ($154|0)==($150|0);
           if ($155) {
            $$0$i$i59 = 0;
            break;
           } else {
            $$sroa$011$025$i$i50 = $154;
           }
          }
         }
        } while(0);
        $169 = HEAP32[$141>>2]|0;
        $170 = ((($169)) + 12|0);
        $171 = HEAP32[$170>>2]|0;
        __THREW__ = 0;
        (invoke_ii($171|0,($141|0))|0);
        $172 = __THREW__; __THREW__ = 0;
        $173 = $172&1;
        if ($173) {
         label = 82;
         break L68;
        }
        $174 = ($$0$i$i59|0)==(0|0);
        if ($174) {
         label = 92;
         break L70;
        }
        $175 = HEAP32[$17>>2]|0;
        $176 = HEAP32[$175>>2]|0;
        $177 = ((($176)) + 8|0);
        $178 = HEAP32[$177>>2]|0;
        __THREW__ = 0;
        (invoke_ii($178|0,($175|0))|0);
        $179 = __THREW__; __THREW__ = 0;
        $180 = $179&1;
        if ($180) {
         label = 82;
         break L68;
        }
        $181 = HEAP32[$8>>2]|0;
        $182 = HEAP32[$181>>2]|0;
        $183 = ((($181)) + 4|0);
        $184 = HEAP32[$183>>2]|0;
        $185 = ($182|0)==($184|0);
        L93: do {
         if ($185) {
          $$0$i$i76 = 0;
         } else {
          $186 = HEAP32[$20>>2]|0;
          $187 = ($186|0)==(0|0);
          if ($187) {
           $$pre$i$i65 = HEAP32[$182>>2]|0;
           $$0$i$i76 = $$pre$i$i65;
           break;
          } else {
           $$sroa$011$025$i$i67 = $182;
          }
          while(1) {
           $190 = HEAP32[$$sroa$011$025$i$i67>>2]|0;
           $$0$ph13$i$i$i$i$i69 = $20;$$07$ph12$i$i$i$i$i70 = $186;
           L99: while(1) {
            $$0710$i$i$i$i$i72 = $$07$ph12$i$i$i$i$i70;
            while(1) {
             $191 = ((($$0710$i$i$i$i$i72)) + 16|0);
             $192 = HEAP32[$191>>2]|0;
             $193 = ($192>>>0)<($190>>>0);
             if (!($193)) {
              break;
             }
             $196 = ((($$0710$i$i$i$i$i72)) + 4|0);
             $197 = HEAP32[$196>>2]|0;
             $198 = ($197|0)==(0|0);
             if ($198) {
              $$0$ph$lcssa$i$i$i$i$i74 = $$0$ph13$i$i$i$i$i69;
              break L99;
             } else {
              $$0710$i$i$i$i$i72 = $197;
             }
            }
            $194 = HEAP32[$$0710$i$i$i$i$i72>>2]|0;
            $195 = ($194|0)==(0|0);
            if ($195) {
             $$0$ph$lcssa$i$i$i$i$i74 = $$0710$i$i$i$i$i72;
             break;
            } else {
             $$0$ph13$i$i$i$i$i69 = $$0710$i$i$i$i$i72;$$07$ph12$i$i$i$i$i70 = $194;
            }
           }
           $199 = ($$0$ph$lcssa$i$i$i$i$i74|0)==($20|0);
           if ($199) {
            $$0$i$i76 = $190;
            break L93;
           }
           $200 = ((($$0$ph$lcssa$i$i$i$i$i74)) + 16|0);
           $201 = HEAP32[$200>>2]|0;
           $202 = ($190>>>0)<($201>>>0);
           $188 = ((($$sroa$011$025$i$i67)) + 4|0);
           if ($202) {
            $$0$i$i76 = $190;
            break L93;
           }
           $189 = ($188|0)==($184|0);
           if ($189) {
            $$0$i$i76 = 0;
            break;
           } else {
            $$sroa$011$025$i$i67 = $188;
           }
          }
         }
        } while(0);
        $203 = HEAP32[$175>>2]|0;
        $204 = ((($203)) + 12|0);
        $205 = HEAP32[$204>>2]|0;
        __THREW__ = 0;
        (invoke_ii($205|0,($175|0))|0);
        $206 = __THREW__; __THREW__ = 0;
        $207 = $206&1;
        if ($207) {
         label = 82;
         break L68;
        }
        $208 = HEAP32[$$0$i$i76>>2]|0;
        $209 = ((($208)) + 212|0);
        $210 = HEAP32[$209>>2]|0;
        __THREW__ = 0;
        invoke_viiiii($210|0,($0|0),($$0$i$i76|0),($2|0),($3|0),($4|0));
        $211 = __THREW__; __THREW__ = 0;
        $212 = $211&1;
        if ($212) {
         label = 82;
         break L68;
        }
        $213 = HEAP32[$0>>2]|0;
        $214 = ($213|0)==(3);
        if ($214) {
         break L70;
        }
        $222 = HEAP32[$13>>2]|0;
        $223 = HEAP32[$22>>2]|0;
        $224 = ($222|0)==($223|0);
        if ($224) {
         __THREW__ = 0;
         invoke_vii(4220,($7|0),($0|0));
         $230 = __THREW__; __THREW__ = 0;
         $231 = $230&1;
         if ($231) {
          break;
         }
        } else {
         HEAP32[$222>>2] = $213;
         $225 = ((($222)) + 4|0);
         __THREW__ = 0;
         invoke_vii(3457,($225|0),($23|0));
         $226 = __THREW__; __THREW__ = 0;
         $227 = $226&1;
         if ($227) {
          break;
         }
         $228 = HEAP32[$13>>2]|0;
         $229 = ((($228)) + 16|0);
         HEAP32[$13>>2] = $229;
        }
        $232 = HEAP8[$24>>0]|0;
        $233 = ($232<<24>>24)<(0);
        if ($233) {
         $234 = HEAP32[$23>>2]|0;
         __ZdlPv($234);
        }
        __THREW__ = 0;
        invoke_vi(4203,($8|0));
        $235 = __THREW__; __THREW__ = 0;
        $236 = $235&1;
        if ($236) {
         label = 82;
         break L68;
        }
       }
       $217 = ___cxa_find_matching_catch_2()|0;
       $218 = tempRet0;
       $219 = HEAP8[$24>>0]|0;
       $220 = ($219<<24>>24)<(0);
       if (!($220)) {
        $$3 = $218;$$322 = $217;
        break L68;
       }
       $221 = HEAP32[$23>>2]|0;
       __ZdlPv($221);
       $$3 = $218;$$322 = $217;
       break L68;
      } else {
       label = 92;
      }
     } while(0);
     L122: do {
      if ((label|0) == 92) {
       $237 = HEAP32[$7>>2]|0;
       $238 = HEAP32[$13>>2]|0;
       $239 = ($237|0)==($238|0);
       if (!($239)) {
        __THREW__ = 0;
        invoke_viii(4221,($237|0),($238|0),($5|0));
        $268 = __THREW__; __THREW__ = 0;
        $269 = $268&1;
        if ($269) {
         label = 82;
         break L68;
        }
        $270 = HEAP32[$13>>2]|0;
        $271 = ((($270)) + -16|0);
        $272 = HEAP32[$271>>2]|0;
        HEAP32[$12>>2] = $272;
        $273 = ((($12)) + 4|0);
        $274 = ((($270)) + -12|0);
        __THREW__ = 0;
        invoke_vii(3457,($273|0),($274|0));
        $275 = __THREW__; __THREW__ = 0;
        $276 = $275&1;
        if ($276) {
         label = 82;
         break L68;
        }
        $277 = HEAP32[$12>>2]|0;
        HEAP32[$0>>2] = $277;
        __THREW__ = 0;
        invoke_vii(3457,($23|0),($273|0));
        $278 = __THREW__; __THREW__ = 0;
        $279 = $278&1;
        if ($279) {
         $284 = ___cxa_find_matching_catch_2()|0;
         $285 = tempRet0;
         $286 = ((($273)) + 11|0);
         $287 = HEAP8[$286>>0]|0;
         $288 = ($287<<24>>24)<(0);
         if ($288) {
          $289 = HEAP32[$273>>2]|0;
          __ZdlPv($289);
         }
         $$3 = $285;$$322 = $284;
         break L68;
        } else {
         $280 = ((($273)) + 11|0);
         $281 = HEAP8[$280>>0]|0;
         $282 = ($281<<24>>24)<(0);
         if ($282) {
          $283 = HEAP32[$273>>2]|0;
          __ZdlPv($283);
         }
         break;
        }
       }
       __THREW__ = 0;
       invoke_viii(4173,($11|0),(168257|0),($3|0));
       $240 = __THREW__; __THREW__ = 0;
       $241 = $240&1;
       if ($241) {
        $254 = ___cxa_find_matching_catch_2()|0;
        $255 = tempRet0;
        $$118 = $255;$$120 = $254;
       } else {
        __THREW__ = 0;
        invoke_viii(3542,($10|0),($11|0),(167562|0));
        $242 = __THREW__; __THREW__ = 0;
        $243 = $242&1;
        do {
         if ($243) {
          $256 = ___cxa_find_matching_catch_2()|0;
          $257 = tempRet0;
          $$017 = $257;$$019 = $256;
         } else {
          HEAP32[$0>>2] = 2;
          __THREW__ = 0;
          invoke_vii(3457,($23|0),($10|0));
          $244 = __THREW__; __THREW__ = 0;
          $245 = $244&1;
          if ($245) {
           $258 = ___cxa_find_matching_catch_2()|0;
           $259 = tempRet0;
           $260 = ((($10)) + 11|0);
           $261 = HEAP8[$260>>0]|0;
           $262 = ($261<<24>>24)<(0);
           if (!($262)) {
            $$017 = $259;$$019 = $258;
            break;
           }
           $263 = HEAP32[$10>>2]|0;
           __ZdlPv($263);
           $$017 = $259;$$019 = $258;
           break;
          }
          $246 = ((($10)) + 11|0);
          $247 = HEAP8[$246>>0]|0;
          $248 = ($247<<24>>24)<(0);
          if ($248) {
           $249 = HEAP32[$10>>2]|0;
           __ZdlPv($249);
          }
          $250 = ((($11)) + 11|0);
          $251 = HEAP8[$250>>0]|0;
          $252 = ($251<<24>>24)<(0);
          if ($252) {
           $253 = HEAP32[$11>>2]|0;
           __ZdlPv($253);
          }
          break L122;
         }
        } while(0);
        $264 = ((($11)) + 11|0);
        $265 = HEAP8[$264>>0]|0;
        $266 = ($265<<24>>24)<(0);
        if ($266) {
         $267 = HEAP32[$11>>2]|0;
         __ZdlPv($267);
         $$118 = $$017;$$120 = $$019;
        } else {
         $$118 = $$017;$$120 = $$019;
        }
       }
       $$3 = $$118;$$322 = $$120;
       break L68;
      }
     } while(0);
     $290 = ((($9)) + 11|0);
     $291 = HEAP8[$290>>0]|0;
     $292 = ($291<<24>>24)<(0);
     if ($292) {
      $293 = HEAP32[$9>>2]|0;
      __ZdlPv($293);
     }
     label = 123;
     break L51;
    }
   } while(0);
   if ((label|0) == 82) {
    $215 = ___cxa_find_matching_catch_2()|0;
    $216 = tempRet0;
    $$3 = $216;$$322 = $215;
   }
   $294 = ((($9)) + 11|0);
   $295 = HEAP8[$294>>0]|0;
   $296 = ($295<<24>>24)<(0);
   if ($296) {
    $297 = HEAP32[$9>>2]|0;
    __ZdlPv($297);
   }
   $$4 = $$3;$$423 = $$322;
  }
 } while(0);
 if ((label|0) == 33) {
  $$4 = $eh$lpad$body$index5Z2D;$$423 = $eh$lpad$body$indexZ2D;
 }
 else if ((label|0) == 123) {
  $298 = ((($8)) + 8|0);
  $299 = HEAP32[$20>>2]|0;
  __ZNSt3__26__treeIPN5osgDB12ReaderWriterENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($298,$299);
  $300 = HEAP32[$7>>2]|0;
  $301 = ($300|0)==(0|0);
  if ($301) {
   STACKTOP = sp;return;
  }
  $302 = HEAP32[$13>>2]|0;
  $303 = ($302|0)==($300|0);
  if ($303) {
   $313 = $300;
  } else {
   $305 = $302;
   while(1) {
    $304 = ((($305)) + -16|0);
    HEAP32[$13>>2] = $304;
    $306 = ((($305)) + -12|0);
    $307 = ((($306)) + 11|0);
    $308 = HEAP8[$307>>0]|0;
    $309 = ($308<<24>>24)<(0);
    if ($309) {
     $312 = HEAP32[$306>>2]|0;
     __ZdlPv($312);
     $$pre$i$i$i100 = HEAP32[$13>>2]|0;
     $310 = $$pre$i$i$i100;
    } else {
     $310 = $304;
    }
    $311 = ($310|0)==($300|0);
    if ($311) {
     break;
    } else {
     $305 = $310;
    }
   }
   $$pre$i102 = HEAP32[$7>>2]|0;
   $313 = $$pre$i102;
  }
  __ZdlPv($313);
  STACKTOP = sp;return;
 }
 $314 = ((($8)) + 8|0);
 $315 = HEAP32[$20>>2]|0;
 __ZNSt3__26__treeIPN5osgDB12ReaderWriterENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($314,$315);
 $316 = HEAP32[$7>>2]|0;
 $317 = ($316|0)==(0|0);
 if ($317) {
  ___resumeException($$423|0);
  // unreachable;
 }
 $318 = HEAP32[$13>>2]|0;
 $319 = ($318|0)==($316|0);
 if ($319) {
  $329 = $316;
 } else {
  $321 = $318;
  while(1) {
   $320 = ((($321)) + -16|0);
   HEAP32[$13>>2] = $320;
   $322 = ((($321)) + -12|0);
   $323 = ((($322)) + 11|0);
   $324 = HEAP8[$323>>0]|0;
   $325 = ($324<<24>>24)<(0);
   if ($325) {
    $328 = HEAP32[$322>>2]|0;
    __ZdlPv($328);
    $$pre$i$i$i = HEAP32[$13>>2]|0;
    $326 = $$pre$i$i$i;
   } else {
    $326 = $320;
   }
   $327 = ($326|0)==($316|0);
   if ($327) {
    break;
   } else {
    $321 = $326;
   }
  }
  $$pre$i = HEAP32[$7>>2]|0;
  $329 = $$pre$i;
 }
 __ZdlPv($329);
 ___resumeException($$423|0);
 // unreachable;
}
function __ZN5osgDB8Registry24readShaderImplementationERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEPKNS_7OptionsE($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $4 = sp;
 HEAP32[$4>>2] = (75072);
 $5 = ((($4)) + 4|0);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_($5,$2);
 $6 = ((($4)) + 16|0);
 HEAP32[$6>>2] = $3;
 HEAP32[$4>>2] = (75264);
 __THREW__ = 0;
 invoke_viiii(4212,($0|0),($1|0),($4|0),32);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $13 = ___cxa_find_matching_catch_2()|0;
  $14 = tempRet0;
  HEAP32[$4>>2] = (75072);
  $15 = ((($5)) + 11|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = ($16<<24>>24)<(0);
  if (!($17)) {
   ___resumeException($13|0);
   // unreachable;
  }
  $18 = HEAP32[$5>>2]|0;
  __ZdlPv($18);
  ___resumeException($13|0);
  // unreachable;
 } else {
  HEAP32[$4>>2] = (75072);
  $9 = ((($5)) + 11|0);
  $10 = HEAP8[$9>>0]|0;
  $11 = ($10<<24>>24)<(0);
  if (!($11)) {
   STACKTOP = sp;return;
  }
  $12 = HEAP32[$5>>2]|0;
  __ZdlPv($12);
  STACKTOP = sp;return;
 }
}
function __ZN5osgDB8Registry17ReadShaderFunctorD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (75072);
 $1 = ((($0)) + 4|0);
 $2 = ((($1)) + 11|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)<(0);
 if (!($4)) {
  __ZdlPv($0);
  return;
 }
 $5 = HEAP32[$1>>2]|0;
 __ZdlPv($5);
 __ZdlPv($0);
 return;
}
function __ZNK5osgDB8Registry17ReadShaderFunctor6doReadERNS_12ReaderWriterE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + 192|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($1)) + 4|0);
 $7 = ((($1)) + 16|0);
 $8 = HEAP32[$7>>2]|0;
 FUNCTION_TABLE_viiii[$5 & 8191]($0,$2,$6,$8);
 return;
}
function __ZNK5osgDB8Registry17ReadShaderFunctor7isValidERNS_12ReaderWriter10ReadResultE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__ZN5osgDB12ReaderWriter10ReadResult9getShaderEv($1)|0);
 $3 = ($2|0)!=(0|0);
 return ($3|0);
}
function __ZNK5osgDB8Registry17ReadShaderFunctor7isValidEPN3osg6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,26544,0)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK5osgDB8Registry17ReadShaderFunctor9cloneTypeERKNSt3__212basic_stringIcNS2_11char_traitsIcEENS2_9allocatorIcEEEEPKNS_7OptionsE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (__Znwj(20)|0);
 HEAP32[$3>>2] = (75072);
 $4 = ((($3)) + 4|0);
 __THREW__ = 0;
 invoke_vii(3457,($4|0),($1|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $8 = ___cxa_find_matching_catch_2()|0;
  $9 = tempRet0;
  __ZdlPv($3);
  ___resumeException($8|0);
  // unreachable;
 } else {
  $7 = ((($3)) + 16|0);
  HEAP32[$7>>2] = $2;
  HEAP32[$3>>2] = (75264);
  return ($3|0);
 }
 return (0)|0;
}
function __ZN5osgDB8Registry25writeShaderImplementationERKN3osg6ShaderERKNSt3__212basic_stringIcNS5_11char_traitsIcEENS5_9allocatorIcEEEEPKNS_7OptionsE($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0$i$i = 0, $$0$i$i39 = 0, $$0$i$i63 = 0, $$0$i$i80 = 0, $$0$ph$lcssa$i$i$i$i$i = 0, $$0$ph$lcssa$i$i$i$i$i37 = 0, $$0$ph$lcssa$i$i$i$i$i61 = 0, $$0$ph$lcssa$i$i$i$i$i78 = 0, $$0$ph13$i$i$i$i$i = 0, $$0$ph13$i$i$i$i$i32 = 0, $$0$ph13$i$i$i$i$i56 = 0, $$0$ph13$i$i$i$i$i73 = 0, $$017 = 0, $$019 = 0, $$07$ph12$i$i$i$i$i = 0, $$07$ph12$i$i$i$i$i33 = 0, $$07$ph12$i$i$i$i$i57 = 0, $$07$ph12$i$i$i$i$i74 = 0, $$0710$i$i$i$i$i = 0, $$0710$i$i$i$i$i35 = 0;
 var $$0710$i$i$i$i$i59 = 0, $$0710$i$i$i$i$i76 = 0, $$118 = 0, $$120 = 0, $$3 = 0, $$322 = 0, $$4 = 0, $$423 = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i$i$i = 0, $$pre$i$i$i104 = 0, $$pre$i$i$i48 = 0, $$pre$i$i28 = 0, $$pre$i$i52 = 0, $$pre$i$i69 = 0, $$pre$i106 = 0, $$sroa$011$025$i$i = 0, $$sroa$011$025$i$i30 = 0;
 var $$sroa$011$025$i$i54 = 0, $$sroa$011$025$i$i71 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0;
 var $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0;
 var $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0;
 var $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0;
 var $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0;
 var $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0;
 var $298 = 0, $299 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0;
 var $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0;
 var $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index5Z2D = 0;
 var $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(112|0);
 $5 = sp;
 $6 = sp + 92|0;
 $7 = sp + 80|0;
 $8 = sp + 60|0;
 $9 = sp + 48|0;
 $10 = sp + 36|0;
 $11 = sp + 24|0;
 $12 = sp + 8|0;
 HEAP32[$7>>2] = 0;
 $13 = ((($7)) + 4|0);
 HEAP32[$13>>2] = 0;
 $14 = ((($7)) + 8|0);
 HEAP32[$14>>2] = 0;
 $15 = ((($1)) + 72|0);
 $16 = ((($1)) + 60|0);
 HEAP32[$8>>2] = $15;
 $17 = ((($8)) + 4|0);
 HEAP32[$17>>2] = $16;
 $18 = ((($8)) + 12|0);
 HEAP32[$18>>2] = 0;
 $19 = ((($8)) + 16|0);
 HEAP32[$19>>2] = 0;
 $20 = ((($8)) + 12|0);
 $21 = ((($8)) + 8|0);
 HEAP32[$21>>2] = $20;
 $22 = ((($7)) + 8|0);
 $23 = ((($0)) + 4|0);
 $24 = ((($23)) + 11|0);
 $26 = $16;
 while(1) {
  $25 = HEAP32[$26>>2]|0;
  $27 = ((($25)) + 8|0);
  $28 = HEAP32[$27>>2]|0;
  __THREW__ = 0;
  (invoke_ii($28|0,($26|0))|0);
  $29 = __THREW__; __THREW__ = 0;
  $30 = $29&1;
  if ($30) {
   label = 31;
   break;
  }
  $31 = HEAP32[$8>>2]|0;
  $32 = HEAP32[$31>>2]|0;
  $33 = ((($31)) + 4|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = ($32|0)==($34|0);
  L4: do {
   if ($35) {
    $$0$i$i = 0;
   } else {
    $36 = HEAP32[$20>>2]|0;
    $37 = ($36|0)==(0|0);
    if ($37) {
     $$pre$i$i = HEAP32[$32>>2]|0;
     $$0$i$i = $$pre$i$i;
     break;
    } else {
     $$sroa$011$025$i$i = $32;
    }
    while(1) {
     $40 = HEAP32[$$sroa$011$025$i$i>>2]|0;
     $$0$ph13$i$i$i$i$i = $20;$$07$ph12$i$i$i$i$i = $36;
     L10: while(1) {
      $$0710$i$i$i$i$i = $$07$ph12$i$i$i$i$i;
      while(1) {
       $41 = ((($$0710$i$i$i$i$i)) + 16|0);
       $42 = HEAP32[$41>>2]|0;
       $43 = ($42>>>0)<($40>>>0);
       if (!($43)) {
        break;
       }
       $46 = ((($$0710$i$i$i$i$i)) + 4|0);
       $47 = HEAP32[$46>>2]|0;
       $48 = ($47|0)==(0|0);
       if ($48) {
        $$0$ph$lcssa$i$i$i$i$i = $$0$ph13$i$i$i$i$i;
        break L10;
       } else {
        $$0710$i$i$i$i$i = $47;
       }
      }
      $44 = HEAP32[$$0710$i$i$i$i$i>>2]|0;
      $45 = ($44|0)==(0|0);
      if ($45) {
       $$0$ph$lcssa$i$i$i$i$i = $$0710$i$i$i$i$i;
       break;
      } else {
       $$0$ph13$i$i$i$i$i = $$0710$i$i$i$i$i;$$07$ph12$i$i$i$i$i = $44;
      }
     }
     $49 = ($$0$ph$lcssa$i$i$i$i$i|0)==($20|0);
     if ($49) {
      $$0$i$i = $40;
      break L4;
     }
     $50 = ((($$0$ph$lcssa$i$i$i$i$i)) + 16|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = ($40>>>0)<($51>>>0);
     $38 = ((($$sroa$011$025$i$i)) + 4|0);
     if ($52) {
      $$0$i$i = $40;
      break L4;
     }
     $39 = ($38|0)==($34|0);
     if ($39) {
      $$0$i$i = 0;
      break;
     } else {
      $$sroa$011$025$i$i = $38;
     }
    }
   }
  } while(0);
  $53 = HEAP32[$26>>2]|0;
  $54 = ((($53)) + 12|0);
  $55 = HEAP32[$54>>2]|0;
  __THREW__ = 0;
  (invoke_ii($55|0,($26|0))|0);
  $56 = __THREW__; __THREW__ = 0;
  $57 = $56&1;
  if ($57) {
   label = 31;
   break;
  }
  $58 = ($$0$i$i|0)==(0|0);
  if ($58) {
   label = 44;
   break;
  }
  $59 = HEAP32[$17>>2]|0;
  $60 = HEAP32[$59>>2]|0;
  $61 = ((($60)) + 8|0);
  $62 = HEAP32[$61>>2]|0;
  __THREW__ = 0;
  (invoke_ii($62|0,($59|0))|0);
  $63 = __THREW__; __THREW__ = 0;
  $64 = $63&1;
  if ($64) {
   label = 31;
   break;
  }
  $65 = HEAP32[$8>>2]|0;
  $66 = HEAP32[$65>>2]|0;
  $67 = ((($65)) + 4|0);
  $68 = HEAP32[$67>>2]|0;
  $69 = ($66|0)==($68|0);
  L23: do {
   if ($69) {
    $$0$i$i39 = 0;
   } else {
    $70 = HEAP32[$20>>2]|0;
    $71 = ($70|0)==(0|0);
    if ($71) {
     $$pre$i$i28 = HEAP32[$66>>2]|0;
     $$0$i$i39 = $$pre$i$i28;
     break;
    } else {
     $$sroa$011$025$i$i30 = $66;
    }
    while(1) {
     $74 = HEAP32[$$sroa$011$025$i$i30>>2]|0;
     $$0$ph13$i$i$i$i$i32 = $20;$$07$ph12$i$i$i$i$i33 = $70;
     L29: while(1) {
      $$0710$i$i$i$i$i35 = $$07$ph12$i$i$i$i$i33;
      while(1) {
       $75 = ((($$0710$i$i$i$i$i35)) + 16|0);
       $76 = HEAP32[$75>>2]|0;
       $77 = ($76>>>0)<($74>>>0);
       if (!($77)) {
        break;
       }
       $80 = ((($$0710$i$i$i$i$i35)) + 4|0);
       $81 = HEAP32[$80>>2]|0;
       $82 = ($81|0)==(0|0);
       if ($82) {
        $$0$ph$lcssa$i$i$i$i$i37 = $$0$ph13$i$i$i$i$i32;
        break L29;
       } else {
        $$0710$i$i$i$i$i35 = $81;
       }
      }
      $78 = HEAP32[$$0710$i$i$i$i$i35>>2]|0;
      $79 = ($78|0)==(0|0);
      if ($79) {
       $$0$ph$lcssa$i$i$i$i$i37 = $$0710$i$i$i$i$i35;
       break;
      } else {
       $$0$ph13$i$i$i$i$i32 = $$0710$i$i$i$i$i35;$$07$ph12$i$i$i$i$i33 = $78;
      }
     }
     $83 = ($$0$ph$lcssa$i$i$i$i$i37|0)==($20|0);
     if ($83) {
      $$0$i$i39 = $74;
      break L23;
     }
     $84 = ((($$0$ph$lcssa$i$i$i$i$i37)) + 16|0);
     $85 = HEAP32[$84>>2]|0;
     $86 = ($74>>>0)<($85>>>0);
     $72 = ((($$sroa$011$025$i$i30)) + 4|0);
     if ($86) {
      $$0$i$i39 = $74;
      break L23;
     }
     $73 = ($72|0)==($68|0);
     if ($73) {
      $$0$i$i39 = 0;
      break;
     } else {
      $$sroa$011$025$i$i30 = $72;
     }
    }
   }
  } while(0);
  $87 = HEAP32[$59>>2]|0;
  $88 = ((($87)) + 12|0);
  $89 = HEAP32[$88>>2]|0;
  __THREW__ = 0;
  (invoke_ii($89|0,($59|0))|0);
  $90 = __THREW__; __THREW__ = 0;
  $91 = $90&1;
  if ($91) {
   label = 31;
   break;
  }
  $92 = HEAP32[$$0$i$i39>>2]|0;
  $93 = ((($92)) + 216|0);
  $94 = HEAP32[$93>>2]|0;
  __THREW__ = 0;
  invoke_viiiii($94|0,($0|0),($$0$i$i39|0),($2|0),($3|0),($4|0));
  $95 = __THREW__; __THREW__ = 0;
  $96 = $95&1;
  if ($96) {
   label = 31;
   break;
  }
  $97 = HEAP32[$0>>2]|0;
  $98 = ($97|0)==(3);
  if ($98) {
   label = 127;
   break;
  }
  $108 = HEAP32[$13>>2]|0;
  $109 = HEAP32[$22>>2]|0;
  $110 = ($108|0)==($109|0);
  if ($110) {
   __THREW__ = 0;
   invoke_vii(4220,($7|0),($0|0));
   $116 = __THREW__; __THREW__ = 0;
   $117 = $116&1;
   if ($117) {
    label = 34;
    break;
   }
  } else {
   HEAP32[$108>>2] = $97;
   $111 = ((($108)) + 4|0);
   __THREW__ = 0;
   invoke_vii(3457,($111|0),($23|0));
   $112 = __THREW__; __THREW__ = 0;
   $113 = $112&1;
   if ($113) {
    label = 34;
    break;
   }
   $114 = HEAP32[$13>>2]|0;
   $115 = ((($114)) + 16|0);
   HEAP32[$13>>2] = $115;
  }
  $118 = HEAP8[$24>>0]|0;
  $119 = ($118<<24>>24)<(0);
  if ($119) {
   $120 = HEAP32[$23>>2]|0;
   __ZdlPv($120);
  }
  __THREW__ = 0;
  invoke_vi(4203,($8|0));
  $121 = __THREW__; __THREW__ = 0;
  $122 = $121&1;
  if ($122) {
   label = 31;
   break;
  }
  $$pre = HEAP32[$17>>2]|0;
  $26 = $$pre;
 }
 L51: do {
  if ((label|0) == 31) {
   $99 = ___cxa_find_matching_catch_2()|0;
   $100 = tempRet0;
   $eh$lpad$body$index5Z2D = $100;$eh$lpad$body$indexZ2D = $99;
   label = 33;
  }
  else if ((label|0) == 34) {
   $103 = ___cxa_find_matching_catch_2()|0;
   $104 = tempRet0;
   $105 = HEAP8[$24>>0]|0;
   $106 = ($105<<24>>24)<(0);
   if ($106) {
    $107 = HEAP32[$23>>2]|0;
    __ZdlPv($107);
    $$4 = $104;$$423 = $103;
   } else {
    $$4 = $104;$$423 = $103;
   }
  }
  else if ((label|0) == 44) {
   $123 = HEAP32[$7>>2]|0;
   $124 = HEAP32[$13>>2]|0;
   $125 = ($124|0)==($123|0);
   if (!($125)) {
    $127 = $124;
    while(1) {
     $126 = ((($127)) + -16|0);
     HEAP32[$13>>2] = $126;
     $128 = ((($127)) + -12|0);
     $129 = ((($128)) + 11|0);
     $130 = HEAP8[$129>>0]|0;
     $131 = ($130<<24>>24)<(0);
     if ($131) {
      $134 = HEAP32[$128>>2]|0;
      __ZdlPv($134);
      $$pre$i$i$i48 = HEAP32[$13>>2]|0;
      $132 = $$pre$i$i$i48;
     } else {
      $132 = $126;
     }
     $133 = ($132|0)==($123|0);
     if ($133) {
      break;
     } else {
      $127 = $132;
     }
    }
   }
   __THREW__ = 0;
   invoke_vii(4205,($6|0),($3|0));
   $135 = __THREW__; __THREW__ = 0;
   $136 = $135&1;
   if ($136) {
    $101 = ___cxa_find_matching_catch_2()|0;
    $102 = tempRet0;
    $eh$lpad$body$index5Z2D = $102;$eh$lpad$body$indexZ2D = $101;
    label = 33;
    break;
   }
   __THREW__ = 0;
   invoke_viii(4192,($9|0),($1|0),($6|0));
   $137 = __THREW__; __THREW__ = 0;
   $138 = $137&1;
   if ($138) {
    $143 = ___cxa_find_matching_catch_2()|0;
    $144 = tempRet0;
    $145 = ((($6)) + 11|0);
    $146 = HEAP8[$145>>0]|0;
    $147 = ($146<<24>>24)<(0);
    if ($147) {
     $148 = HEAP32[$6>>2]|0;
     __ZdlPv($148);
    }
    $eh$lpad$body$index5Z2D = $144;$eh$lpad$body$indexZ2D = $143;
    label = 33;
    break;
   }
   $139 = ((($6)) + 11|0);
   $140 = HEAP8[$139>>0]|0;
   $141 = ($140<<24>>24)<(0);
   if ($141) {
    $142 = HEAP32[$6>>2]|0;
    __ZdlPv($142);
   }
   __THREW__ = 0;
   $149 = (invoke_iii(4194,($1|0),($9|0))|0);
   $150 = __THREW__; __THREW__ = 0;
   $151 = $150&1;
   L75: do {
    if ($151) {
     label = 86;
    } else {
     $152 = ($149|0)==(2);
     L77: do {
      if ($152) {
       while(1) {
        $153 = HEAP32[$17>>2]|0;
        $154 = HEAP32[$153>>2]|0;
        $155 = ((($154)) + 8|0);
        $156 = HEAP32[$155>>2]|0;
        __THREW__ = 0;
        (invoke_ii($156|0,($153|0))|0);
        $157 = __THREW__; __THREW__ = 0;
        $158 = $157&1;
        if ($158) {
         label = 86;
         break L75;
        }
        $159 = HEAP32[$8>>2]|0;
        $160 = HEAP32[$159>>2]|0;
        $161 = ((($159)) + 4|0);
        $162 = HEAP32[$161>>2]|0;
        $163 = ($160|0)==($162|0);
        L81: do {
         if ($163) {
          $$0$i$i63 = 0;
         } else {
          $164 = HEAP32[$20>>2]|0;
          $165 = ($164|0)==(0|0);
          if ($165) {
           $$pre$i$i52 = HEAP32[$160>>2]|0;
           $$0$i$i63 = $$pre$i$i52;
           break;
          } else {
           $$sroa$011$025$i$i54 = $160;
          }
          while(1) {
           $168 = HEAP32[$$sroa$011$025$i$i54>>2]|0;
           $$0$ph13$i$i$i$i$i56 = $20;$$07$ph12$i$i$i$i$i57 = $164;
           L87: while(1) {
            $$0710$i$i$i$i$i59 = $$07$ph12$i$i$i$i$i57;
            while(1) {
             $169 = ((($$0710$i$i$i$i$i59)) + 16|0);
             $170 = HEAP32[$169>>2]|0;
             $171 = ($170>>>0)<($168>>>0);
             if (!($171)) {
              break;
             }
             $174 = ((($$0710$i$i$i$i$i59)) + 4|0);
             $175 = HEAP32[$174>>2]|0;
             $176 = ($175|0)==(0|0);
             if ($176) {
              $$0$ph$lcssa$i$i$i$i$i61 = $$0$ph13$i$i$i$i$i56;
              break L87;
             } else {
              $$0710$i$i$i$i$i59 = $175;
             }
            }
            $172 = HEAP32[$$0710$i$i$i$i$i59>>2]|0;
            $173 = ($172|0)==(0|0);
            if ($173) {
             $$0$ph$lcssa$i$i$i$i$i61 = $$0710$i$i$i$i$i59;
             break;
            } else {
             $$0$ph13$i$i$i$i$i56 = $$0710$i$i$i$i$i59;$$07$ph12$i$i$i$i$i57 = $172;
            }
           }
           $177 = ($$0$ph$lcssa$i$i$i$i$i61|0)==($20|0);
           if ($177) {
            $$0$i$i63 = $168;
            break L81;
           }
           $178 = ((($$0$ph$lcssa$i$i$i$i$i61)) + 16|0);
           $179 = HEAP32[$178>>2]|0;
           $180 = ($168>>>0)<($179>>>0);
           $166 = ((($$sroa$011$025$i$i54)) + 4|0);
           if ($180) {
            $$0$i$i63 = $168;
            break L81;
           }
           $167 = ($166|0)==($162|0);
           if ($167) {
            $$0$i$i63 = 0;
            break;
           } else {
            $$sroa$011$025$i$i54 = $166;
           }
          }
         }
        } while(0);
        $181 = HEAP32[$153>>2]|0;
        $182 = ((($181)) + 12|0);
        $183 = HEAP32[$182>>2]|0;
        __THREW__ = 0;
        (invoke_ii($183|0,($153|0))|0);
        $184 = __THREW__; __THREW__ = 0;
        $185 = $184&1;
        if ($185) {
         label = 86;
         break L75;
        }
        $186 = ($$0$i$i63|0)==(0|0);
        if ($186) {
         label = 96;
         break L77;
        }
        $187 = HEAP32[$17>>2]|0;
        $188 = HEAP32[$187>>2]|0;
        $189 = ((($188)) + 8|0);
        $190 = HEAP32[$189>>2]|0;
        __THREW__ = 0;
        (invoke_ii($190|0,($187|0))|0);
        $191 = __THREW__; __THREW__ = 0;
        $192 = $191&1;
        if ($192) {
         label = 86;
         break L75;
        }
        $193 = HEAP32[$8>>2]|0;
        $194 = HEAP32[$193>>2]|0;
        $195 = ((($193)) + 4|0);
        $196 = HEAP32[$195>>2]|0;
        $197 = ($194|0)==($196|0);
        L100: do {
         if ($197) {
          $$0$i$i80 = 0;
         } else {
          $198 = HEAP32[$20>>2]|0;
          $199 = ($198|0)==(0|0);
          if ($199) {
           $$pre$i$i69 = HEAP32[$194>>2]|0;
           $$0$i$i80 = $$pre$i$i69;
           break;
          } else {
           $$sroa$011$025$i$i71 = $194;
          }
          while(1) {
           $202 = HEAP32[$$sroa$011$025$i$i71>>2]|0;
           $$0$ph13$i$i$i$i$i73 = $20;$$07$ph12$i$i$i$i$i74 = $198;
           L106: while(1) {
            $$0710$i$i$i$i$i76 = $$07$ph12$i$i$i$i$i74;
            while(1) {
             $203 = ((($$0710$i$i$i$i$i76)) + 16|0);
             $204 = HEAP32[$203>>2]|0;
             $205 = ($204>>>0)<($202>>>0);
             if (!($205)) {
              break;
             }
             $208 = ((($$0710$i$i$i$i$i76)) + 4|0);
             $209 = HEAP32[$208>>2]|0;
             $210 = ($209|0)==(0|0);
             if ($210) {
              $$0$ph$lcssa$i$i$i$i$i78 = $$0$ph13$i$i$i$i$i73;
              break L106;
             } else {
              $$0710$i$i$i$i$i76 = $209;
             }
            }
            $206 = HEAP32[$$0710$i$i$i$i$i76>>2]|0;
            $207 = ($206|0)==(0|0);
            if ($207) {
             $$0$ph$lcssa$i$i$i$i$i78 = $$0710$i$i$i$i$i76;
             break;
            } else {
             $$0$ph13$i$i$i$i$i73 = $$0710$i$i$i$i$i76;$$07$ph12$i$i$i$i$i74 = $206;
            }
           }
           $211 = ($$0$ph$lcssa$i$i$i$i$i78|0)==($20|0);
           if ($211) {
            $$0$i$i80 = $202;
            break L100;
           }
           $212 = ((($$0$ph$lcssa$i$i$i$i$i78)) + 16|0);
           $213 = HEAP32[$212>>2]|0;
           $214 = ($202>>>0)<($213>>>0);
           $200 = ((($$sroa$011$025$i$i71)) + 4|0);
           if ($214) {
            $$0$i$i80 = $202;
            break L100;
           }
           $201 = ($200|0)==($196|0);
           if ($201) {
            $$0$i$i80 = 0;
            break;
           } else {
            $$sroa$011$025$i$i71 = $200;
           }
          }
         }
        } while(0);
        $215 = HEAP32[$187>>2]|0;
        $216 = ((($215)) + 12|0);
        $217 = HEAP32[$216>>2]|0;
        __THREW__ = 0;
        (invoke_ii($217|0,($187|0))|0);
        $218 = __THREW__; __THREW__ = 0;
        $219 = $218&1;
        if ($219) {
         label = 86;
         break L75;
        }
        $220 = HEAP32[$$0$i$i80>>2]|0;
        $221 = ((($220)) + 216|0);
        $222 = HEAP32[$221>>2]|0;
        __THREW__ = 0;
        invoke_viiiii($222|0,($0|0),($$0$i$i80|0),($2|0),($3|0),($4|0));
        $223 = __THREW__; __THREW__ = 0;
        $224 = $223&1;
        if ($224) {
         label = 86;
         break L75;
        }
        $225 = HEAP32[$0>>2]|0;
        $226 = ($225|0)==(3);
        if ($226) {
         break L77;
        }
        $234 = HEAP32[$13>>2]|0;
        $235 = HEAP32[$22>>2]|0;
        $236 = ($234|0)==($235|0);
        if ($236) {
         __THREW__ = 0;
         invoke_vii(4220,($7|0),($0|0));
         $242 = __THREW__; __THREW__ = 0;
         $243 = $242&1;
         if ($243) {
          break;
         }
        } else {
         HEAP32[$234>>2] = $225;
         $237 = ((($234)) + 4|0);
         __THREW__ = 0;
         invoke_vii(3457,($237|0),($23|0));
         $238 = __THREW__; __THREW__ = 0;
         $239 = $238&1;
         if ($239) {
          break;
         }
         $240 = HEAP32[$13>>2]|0;
         $241 = ((($240)) + 16|0);
         HEAP32[$13>>2] = $241;
        }
        $244 = HEAP8[$24>>0]|0;
        $245 = ($244<<24>>24)<(0);
        if ($245) {
         $246 = HEAP32[$23>>2]|0;
         __ZdlPv($246);
        }
        __THREW__ = 0;
        invoke_vi(4203,($8|0));
        $247 = __THREW__; __THREW__ = 0;
        $248 = $247&1;
        if ($248) {
         label = 86;
         break L75;
        }
       }
       $229 = ___cxa_find_matching_catch_2()|0;
       $230 = tempRet0;
       $231 = HEAP8[$24>>0]|0;
       $232 = ($231<<24>>24)<(0);
       if (!($232)) {
        $$3 = $230;$$322 = $229;
        break L75;
       }
       $233 = HEAP32[$23>>2]|0;
       __ZdlPv($233);
       $$3 = $230;$$322 = $229;
       break L75;
      } else {
       label = 96;
      }
     } while(0);
     L129: do {
      if ((label|0) == 96) {
       $249 = HEAP32[$7>>2]|0;
       $250 = HEAP32[$13>>2]|0;
       $251 = ($249|0)==($250|0);
       if (!($251)) {
        __THREW__ = 0;
        invoke_viii(4221,($249|0),($250|0),($5|0));
        $280 = __THREW__; __THREW__ = 0;
        $281 = $280&1;
        if ($281) {
         label = 86;
         break L75;
        }
        $282 = HEAP32[$13>>2]|0;
        $283 = ((($282)) + -16|0);
        $284 = HEAP32[$283>>2]|0;
        HEAP32[$12>>2] = $284;
        $285 = ((($12)) + 4|0);
        $286 = ((($282)) + -12|0);
        __THREW__ = 0;
        invoke_vii(3457,($285|0),($286|0));
        $287 = __THREW__; __THREW__ = 0;
        $288 = $287&1;
        if ($288) {
         label = 86;
         break L75;
        }
        $289 = HEAP32[$12>>2]|0;
        HEAP32[$0>>2] = $289;
        __THREW__ = 0;
        invoke_vii(3457,($23|0),($285|0));
        $290 = __THREW__; __THREW__ = 0;
        $291 = $290&1;
        if ($291) {
         $296 = ___cxa_find_matching_catch_2()|0;
         $297 = tempRet0;
         $298 = ((($285)) + 11|0);
         $299 = HEAP8[$298>>0]|0;
         $300 = ($299<<24>>24)<(0);
         if ($300) {
          $301 = HEAP32[$285>>2]|0;
          __ZdlPv($301);
         }
         $$3 = $297;$$322 = $296;
         break L75;
        } else {
         $292 = ((($285)) + 11|0);
         $293 = HEAP8[$292>>0]|0;
         $294 = ($293<<24>>24)<(0);
         if ($294) {
          $295 = HEAP32[$285>>2]|0;
          __ZdlPv($295);
         }
         break;
        }
       }
       __THREW__ = 0;
       invoke_viii(4173,($11|0),(168341|0),($3|0));
       $252 = __THREW__; __THREW__ = 0;
       $253 = $252&1;
       if ($253) {
        $266 = ___cxa_find_matching_catch_2()|0;
        $267 = tempRet0;
        $$118 = $267;$$120 = $266;
       } else {
        __THREW__ = 0;
        invoke_viii(3542,($10|0),($11|0),(167562|0));
        $254 = __THREW__; __THREW__ = 0;
        $255 = $254&1;
        do {
         if ($255) {
          $268 = ___cxa_find_matching_catch_2()|0;
          $269 = tempRet0;
          $$017 = $269;$$019 = $268;
         } else {
          HEAP32[$0>>2] = 2;
          __THREW__ = 0;
          invoke_vii(3457,($23|0),($10|0));
          $256 = __THREW__; __THREW__ = 0;
          $257 = $256&1;
          if ($257) {
           $270 = ___cxa_find_matching_catch_2()|0;
           $271 = tempRet0;
           $272 = ((($10)) + 11|0);
           $273 = HEAP8[$272>>0]|0;
           $274 = ($273<<24>>24)<(0);
           if (!($274)) {
            $$017 = $271;$$019 = $270;
            break;
           }
           $275 = HEAP32[$10>>2]|0;
           __ZdlPv($275);
           $$017 = $271;$$019 = $270;
           break;
          }
          $258 = ((($10)) + 11|0);
          $259 = HEAP8[$258>>0]|0;
          $260 = ($259<<24>>24)<(0);
          if ($260) {
           $261 = HEAP32[$10>>2]|0;
           __ZdlPv($261);
          }
          $262 = ((($11)) + 11|0);
          $263 = HEAP8[$262>>0]|0;
          $264 = ($263<<24>>24)<(0);
          if ($264) {
           $265 = HEAP32[$11>>2]|0;
           __ZdlPv($265);
          }
          break L129;
         }
        } while(0);
        $276 = ((($11)) + 11|0);
        $277 = HEAP8[$276>>0]|0;
        $278 = ($277<<24>>24)<(0);
        if ($278) {
         $279 = HEAP32[$11>>2]|0;
         __ZdlPv($279);
         $$118 = $$017;$$120 = $$019;
        } else {
         $$118 = $$017;$$120 = $$019;
        }
       }
       $$3 = $$118;$$322 = $$120;
       break L75;
      }
     } while(0);
     $302 = ((($9)) + 11|0);
     $303 = HEAP8[$302>>0]|0;
     $304 = ($303<<24>>24)<(0);
     if ($304) {
      $305 = HEAP32[$9>>2]|0;
      __ZdlPv($305);
     }
     label = 127;
     break L51;
    }
   } while(0);
   if ((label|0) == 86) {
    $227 = ___cxa_find_matching_catch_2()|0;
    $228 = tempRet0;
    $$3 = $228;$$322 = $227;
   }
   $306 = ((($9)) + 11|0);
   $307 = HEAP8[$306>>0]|0;
   $308 = ($307<<24>>24)<(0);
   if ($308) {
    $309 = HEAP32[$9>>2]|0;
    __ZdlPv($309);
   }
   $$4 = $$3;$$423 = $$322;
  }
 } while(0);
 if ((label|0) == 33) {
  $$4 = $eh$lpad$body$index5Z2D;$$423 = $eh$lpad$body$indexZ2D;
 }
 else if ((label|0) == 127) {
  $310 = ((($8)) + 8|0);
  $311 = HEAP32[$20>>2]|0;
  __ZNSt3__26__treeIPN5osgDB12ReaderWriterENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($310,$311);
  $312 = HEAP32[$7>>2]|0;
  $313 = ($312|0)==(0|0);
  if ($313) {
   STACKTOP = sp;return;
  }
  $314 = HEAP32[$13>>2]|0;
  $315 = ($314|0)==($312|0);
  if ($315) {
   $325 = $312;
  } else {
   $317 = $314;
   while(1) {
    $316 = ((($317)) + -16|0);
    HEAP32[$13>>2] = $316;
    $318 = ((($317)) + -12|0);
    $319 = ((($318)) + 11|0);
    $320 = HEAP8[$319>>0]|0;
    $321 = ($320<<24>>24)<(0);
    if ($321) {
     $324 = HEAP32[$318>>2]|0;
     __ZdlPv($324);
     $$pre$i$i$i104 = HEAP32[$13>>2]|0;
     $322 = $$pre$i$i$i104;
    } else {
     $322 = $316;
    }
    $323 = ($322|0)==($312|0);
    if ($323) {
     break;
    } else {
     $317 = $322;
    }
   }
   $$pre$i106 = HEAP32[$7>>2]|0;
   $325 = $$pre$i106;
  }
  __ZdlPv($325);
  STACKTOP = sp;return;
 }
 $326 = ((($8)) + 8|0);
 $327 = HEAP32[$20>>2]|0;
 __ZNSt3__26__treeIPN5osgDB12ReaderWriterENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($326,$327);
 $328 = HEAP32[$7>>2]|0;
 $329 = ($328|0)==(0|0);
 if ($329) {
  ___resumeException($$423|0);
  // unreachable;
 }
 $330 = HEAP32[$13>>2]|0;
 $331 = ($330|0)==($328|0);
 if ($331) {
  $341 = $328;
 } else {
  $333 = $330;
  while(1) {
   $332 = ((($333)) + -16|0);
   HEAP32[$13>>2] = $332;
   $334 = ((($333)) + -12|0);
   $335 = ((($334)) + 11|0);
   $336 = HEAP8[$335>>0]|0;
   $337 = ($336<<24>>24)<(0);
   if ($337) {
    $340 = HEAP32[$334>>2]|0;
    __ZdlPv($340);
    $$pre$i$i$i = HEAP32[$13>>2]|0;
    $338 = $$pre$i$i$i;
   } else {
    $338 = $332;
   }
   $339 = ($338|0)==($328|0);
   if ($339) {
    break;
   } else {
    $333 = $338;
   }
  }
  $$pre$i = HEAP32[$7>>2]|0;
  $341 = $$pre$i;
 }
 __ZdlPv($341);
 ___resumeException($$423|0);
 // unreachable;
}
function __ZN5osgDB8Registry21getRefFromObjectCacheERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEPNS_7OptionsE($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ((($1)) + 212|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  HEAP32[$0>>2] = 0;
  return;
 } else {
  __ZN5osgDB11ObjectCache21getRefFromObjectCacheERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEPKNS_7OptionsE($0,$5,$2,$3);
  return;
 }
}
function __ZN5osgDB8Registry53updateTimeStampOfObjectsInCacheWithExternalReferencesERKN3osg10FrameStampE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 212|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  return;
 }
 $5 = ((($1)) + 16|0);
 $6 = +HEAPF64[$5>>3];
 __ZN5osgDB11ObjectCache53updateTimeStampOfObjectsInCacheWithExternalReferencesEd($3,$6);
 return;
}
function __ZN5osgDB8Registry27removeExpiredObjectsInCacheERKN3osg10FrameStampE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0.0, $7 = 0, $8 = 0.0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 212|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  return;
 }
 $5 = ((($1)) + 16|0);
 $6 = +HEAPF64[$5>>3];
 $7 = ((($0)) + 216|0);
 $8 = +HEAPF64[$7>>3];
 $9 = $6 - $8;
 __ZN5osgDB11ObjectCache27removeExpiredObjectsInCacheEd($3,$9);
 return;
}
function __ZN5osgDB8Registry20isProtocolRegisteredERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 __ZN5osgDB18convertToLowerCaseERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE($2,$1);
 $3 = ((($0)) + 32|0);
 __THREW__ = 0;
 $4 = (invoke_iii(3785,($3|0),($2|0))|0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $13 = ___cxa_find_matching_catch_2()|0;
  $14 = tempRet0;
  $15 = ((($2)) + 11|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = ($16<<24>>24)<(0);
  if (!($17)) {
   ___resumeException($13|0);
   // unreachable;
  }
  $18 = HEAP32[$2>>2]|0;
  __ZdlPv($18);
  ___resumeException($13|0);
  // unreachable;
 } else {
  $7 = ((($0)) + 36|0);
  $8 = ($4|0)!=($7|0);
  $9 = ((($2)) + 11|0);
  $10 = HEAP8[$9>>0]|0;
  $11 = ($10<<24>>24)<(0);
  if (!($11)) {
   STACKTOP = sp;return ($8|0);
  }
  $12 = HEAP32[$2>>2]|0;
  __ZdlPv($12);
  STACKTOP = sp;return ($8|0);
 }
 return (0)|0;
}
function __ZNSt3__26__treeINS_12__value_typeIPN3osg8StateSetENS_4pairIS4_bEEEENS_19__map_value_compareIS4_S7_NS_4lessIS4_EELb1EEENS_9allocatorIS7_EEE7destroyEPNS_11__tree_nodeIS7_PvEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 } else {
  $3 = HEAP32[$1>>2]|0;
  __ZNSt3__26__treeINS_12__value_typeIPN3osg8StateSetENS_4pairIS4_bEEEENS_19__map_value_compareIS4_S7_NS_4lessIS4_EELb1EEENS_9allocatorIS7_EEE7destroyEPNS_11__tree_nodeIS7_PvEE($0,$3);
  $4 = ((($1)) + 4|0);
  $5 = HEAP32[$4>>2]|0;
  __ZNSt3__26__treeINS_12__value_typeIPN3osg8StateSetENS_4pairIS4_bEEEENS_19__map_value_compareIS4_S7_NS_4lessIS4_EELb1EEENS_9allocatorIS7_EEE7destroyEPNS_11__tree_nodeIS7_PvEE($0,$5);
  __ZdlPv($1);
  return;
 }
}
function __ZNSt3__26__treeINS_12__value_typeIPN3osg14StateAttributeENS_4pairIS4_bEEEENS_19__map_value_compareIS4_S7_NS_4lessIS4_EELb1EEENS_9allocatorIS7_EEE7destroyEPNS_11__tree_nodeIS7_PvEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 } else {
  $3 = HEAP32[$1>>2]|0;
  __ZNSt3__26__treeINS_12__value_typeIPN3osg14StateAttributeENS_4pairIS4_bEEEENS_19__map_value_compareIS4_S7_NS_4lessIS4_EELb1EEENS_9allocatorIS7_EEE7destroyEPNS_11__tree_nodeIS7_PvEE($0,$3);
  $4 = ((($1)) + 4|0);
  $5 = HEAP32[$4>>2]|0;
  __ZNSt3__26__treeINS_12__value_typeIPN3osg14StateAttributeENS_4pairIS4_bEEEENS_19__map_value_compareIS4_S7_NS_4lessIS4_EELb1EEENS_9allocatorIS7_EEE7destroyEPNS_11__tree_nodeIS7_PvEE($0,$5);
  __ZdlPv($1);
  return;
 }
}
function __ZN5osgDB18SharedStateManager5pruneEv($0) {
 $0 = $0|0;
 var $$0$i$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i19 = 0, $$0$i$i$i$i23 = 0, $$0$i$i$i$i29 = 0, $$0$i$i$i$i9 = 0, $$0$i$i$i10 = 0, $$0$i$i$i1075 = 0, $$0$i$i$i1076 = 0, $$0$i$i$i12 = 0, $$0$i$i$i33 = 0, $$0$i$i$i3373 = 0, $$0$i$i$i3374 = 0, $$sroa$037$0$be = 0, $$sroa$037$065 = 0, $$sroa$050$0$be = 0, $$sroa$050$066 = 0, $1 = 0, $10 = 0;
 var $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0;
 var $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0;
 var $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 120|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 (FUNCTION_TABLE_ii[$4 & 8191]($1)|0);
 $5 = ((($0)) + 68|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($0)) + 72|0);
 $8 = ($6|0)==($7|0);
 L1: do {
  if ($8) {
   label = 26;
  } else {
   $9 = ((($0)) + 76|0);
   $10 = ((($0)) + 72|0);
   $$sroa$050$066 = $6;
   while(1) {
    $11 = ((($$sroa$050$066)) + 16|0);
    $12 = HEAP32[$11>>2]|0;
    /* fence */;
    $13 = ((($12)) + 8|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ($14|0)<(2);
    $16 = ((($$sroa$050$066)) + 4|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = ($17|0)==(0|0);
    do {
     if ($15) {
      if ($18) {
       $19 = ((($$sroa$050$066)) + 8|0);
       $20 = HEAP32[$19>>2]|0;
       $21 = HEAP32[$20>>2]|0;
       $22 = ($21|0)==($$sroa$050$066|0);
       if ($22) {
        $$0$i$i$i3374 = $20;
        label = 10;
       } else {
        $26 = $19;
        while(1) {
         $25 = HEAP32[$26>>2]|0;
         $27 = ((($25)) + 8|0);
         $28 = HEAP32[$27>>2]|0;
         $29 = HEAP32[$28>>2]|0;
         $30 = ($29|0)==($25|0);
         if ($30) {
          $$0$i$i$i33 = $28;
          label = 9;
          break;
         } else {
          $26 = $27;
         }
        }
       }
      } else {
       $$0$i$i$i$i29 = $17;
       while(1) {
        $23 = HEAP32[$$0$i$i$i$i29>>2]|0;
        $24 = ($23|0)==(0|0);
        if ($24) {
         break;
        } else {
         $$0$i$i$i$i29 = $23;
        }
       }
       $$0$i$i$i33 = $$0$i$i$i$i29;
       label = 9;
      }
      if ((label|0) == 9) {
       label = 0;
       if ($18) {
        $$0$i$i$i3374 = $$0$i$i$i33;
        label = 10;
       } else {
        $$0$i$i$i$i$i19 = $17;
        while(1) {
         $35 = HEAP32[$$0$i$i$i$i$i19>>2]|0;
         $36 = ($35|0)==(0|0);
         if ($36) {
          break;
         } else {
          $$0$i$i$i$i$i19 = $35;
         }
        }
        $$0$i$i$i$i23 = $$0$i$i$i$i$i19;$$0$i$i$i3373 = $$0$i$i$i33;
       }
      }
      if ((label|0) == 10) {
       label = 0;
       $31 = ((($$sroa$050$066)) + 8|0);
       $32 = HEAP32[$31>>2]|0;
       $33 = HEAP32[$32>>2]|0;
       $34 = ($33|0)==($$sroa$050$066|0);
       if ($34) {
        $$0$i$i$i$i23 = $32;$$0$i$i$i3373 = $$0$i$i$i3374;
       } else {
        $38 = $31;
        while(1) {
         $37 = HEAP32[$38>>2]|0;
         $39 = ((($37)) + 8|0);
         $40 = HEAP32[$39>>2]|0;
         $41 = HEAP32[$40>>2]|0;
         $42 = ($41|0)==($37|0);
         if ($42) {
          $$0$i$i$i$i23 = $40;$$0$i$i$i3373 = $$0$i$i$i3374;
          break;
         } else {
          $38 = $39;
         }
        }
       }
      }
      $43 = HEAP32[$5>>2]|0;
      $44 = ($43|0)==($$sroa$050$066|0);
      if ($44) {
       $45 = $$0$i$i$i$i23;
       HEAP32[$5>>2] = $45;
      }
      $46 = HEAP32[$9>>2]|0;
      $47 = (($46) + -1)|0;
      HEAP32[$9>>2] = $47;
      $48 = HEAP32[$10>>2]|0;
      __ZNSt3__213__tree_removeIPNS_16__tree_node_baseIPvEEEEvT_S5_($48,$$sroa$050$066);
      $49 = HEAP32[$11>>2]|0;
      $50 = ($49|0)==(0|0);
      if (!($50)) {
       $51 = ((($49)) + 8|0);
       $52 = HEAP32[$51>>2]|0;HEAP32[$51>>2] = (($52-1)|0);
       $53 = ($52|0)==(1);
       if ($53) {
        __THREW__ = 0;
        invoke_viii(3262,($49|0),1,1);
        $54 = __THREW__; __THREW__ = 0;
        $55 = $54&1;
        if ($55) {
         break L1;
        }
       }
      }
      __ZdlPv($$sroa$050$066);
      $$sroa$050$0$be = $$0$i$i$i3373;
     } else {
      if ($18) {
       $57 = ((($$sroa$050$066)) + 8|0);
       $58 = HEAP32[$57>>2]|0;
       $59 = HEAP32[$58>>2]|0;
       $60 = ($59|0)==($$sroa$050$066|0);
       if ($60) {
        $$sroa$050$0$be = $58;
        break;
       } else {
        $64 = $57;
       }
       while(1) {
        $63 = HEAP32[$64>>2]|0;
        $65 = ((($63)) + 8|0);
        $66 = HEAP32[$65>>2]|0;
        $67 = HEAP32[$66>>2]|0;
        $68 = ($67|0)==($63|0);
        if ($68) {
         $$sroa$050$0$be = $66;
         break;
        } else {
         $64 = $65;
        }
       }
      } else {
       $$0$i$i$i12 = $17;
       while(1) {
        $61 = HEAP32[$$0$i$i$i12>>2]|0;
        $62 = ($61|0)==(0|0);
        if ($62) {
         break;
        } else {
         $$0$i$i$i12 = $61;
        }
       }
       $$sroa$050$0$be = $$0$i$i$i12;
       break;
      }
     }
    } while(0);
    $56 = ($$sroa$050$0$be|0)==($7|0);
    if ($56) {
     label = 26;
     break;
    } else {
     $$sroa$050$066 = $$sroa$050$0$be;
    }
   }
  }
 } while(0);
 L40: do {
  if ((label|0) == 26) {
   $69 = ((($0)) + 56|0);
   $70 = HEAP32[$69>>2]|0;
   $71 = ((($0)) + 60|0);
   $72 = ($70|0)==($71|0);
   if ($72) {
    $133 = HEAP32[$1>>2]|0;
    $134 = ((($133)) + 12|0);
    $135 = HEAP32[$134>>2]|0;
    (FUNCTION_TABLE_ii[$135 & 8191]($1)|0);
    return;
   }
   $73 = ((($0)) + 64|0);
   $74 = ((($0)) + 60|0);
   $$sroa$037$065 = $70;
   while(1) {
    $75 = ((($$sroa$037$065)) + 16|0);
    $76 = HEAP32[$75>>2]|0;
    /* fence */;
    $77 = ((($76)) + 8|0);
    $78 = HEAP32[$77>>2]|0;
    $79 = ($78|0)<(2);
    $80 = ((($$sroa$037$065)) + 4|0);
    $81 = HEAP32[$80>>2]|0;
    $82 = ($81|0)==(0|0);
    do {
     if ($79) {
      if ($82) {
       $83 = ((($$sroa$037$065)) + 8|0);
       $84 = HEAP32[$83>>2]|0;
       $85 = HEAP32[$84>>2]|0;
       $86 = ($85|0)==($$sroa$037$065|0);
       if ($86) {
        $$0$i$i$i1076 = $84;
        label = 35;
       } else {
        $90 = $83;
        while(1) {
         $89 = HEAP32[$90>>2]|0;
         $91 = ((($89)) + 8|0);
         $92 = HEAP32[$91>>2]|0;
         $93 = HEAP32[$92>>2]|0;
         $94 = ($93|0)==($89|0);
         if ($94) {
          $$0$i$i$i10 = $92;
          label = 34;
          break;
         } else {
          $90 = $91;
         }
        }
       }
      } else {
       $$0$i$i$i$i9 = $81;
       while(1) {
        $87 = HEAP32[$$0$i$i$i$i9>>2]|0;
        $88 = ($87|0)==(0|0);
        if ($88) {
         break;
        } else {
         $$0$i$i$i$i9 = $87;
        }
       }
       $$0$i$i$i10 = $$0$i$i$i$i9;
       label = 34;
      }
      if ((label|0) == 34) {
       label = 0;
       if ($82) {
        $$0$i$i$i1076 = $$0$i$i$i10;
        label = 35;
       } else {
        $$0$i$i$i$i$i = $81;
        while(1) {
         $99 = HEAP32[$$0$i$i$i$i$i>>2]|0;
         $100 = ($99|0)==(0|0);
         if ($100) {
          break;
         } else {
          $$0$i$i$i$i$i = $99;
         }
        }
        $$0$i$i$i$i = $$0$i$i$i$i$i;$$0$i$i$i1075 = $$0$i$i$i10;
       }
      }
      if ((label|0) == 35) {
       label = 0;
       $95 = ((($$sroa$037$065)) + 8|0);
       $96 = HEAP32[$95>>2]|0;
       $97 = HEAP32[$96>>2]|0;
       $98 = ($97|0)==($$sroa$037$065|0);
       if ($98) {
        $$0$i$i$i$i = $96;$$0$i$i$i1075 = $$0$i$i$i1076;
       } else {
        $102 = $95;
        while(1) {
         $101 = HEAP32[$102>>2]|0;
         $103 = ((($101)) + 8|0);
         $104 = HEAP32[$103>>2]|0;
         $105 = HEAP32[$104>>2]|0;
         $106 = ($105|0)==($101|0);
         if ($106) {
          $$0$i$i$i$i = $104;$$0$i$i$i1075 = $$0$i$i$i1076;
          break;
         } else {
          $102 = $103;
         }
        }
       }
      }
      $107 = HEAP32[$69>>2]|0;
      $108 = ($107|0)==($$sroa$037$065|0);
      if ($108) {
       $109 = $$0$i$i$i$i;
       HEAP32[$69>>2] = $109;
      }
      $110 = HEAP32[$73>>2]|0;
      $111 = (($110) + -1)|0;
      HEAP32[$73>>2] = $111;
      $112 = HEAP32[$74>>2]|0;
      __ZNSt3__213__tree_removeIPNS_16__tree_node_baseIPvEEEEvT_S5_($112,$$sroa$037$065);
      $113 = HEAP32[$75>>2]|0;
      $114 = ($113|0)==(0|0);
      if (!($114)) {
       $115 = ((($113)) + 8|0);
       $116 = HEAP32[$115>>2]|0;HEAP32[$115>>2] = (($116-1)|0);
       $117 = ($116|0)==(1);
       if ($117) {
        __THREW__ = 0;
        invoke_viii(3262,($113|0),1,1);
        $118 = __THREW__; __THREW__ = 0;
        $119 = $118&1;
        if ($119) {
         break L40;
        }
       }
      }
      __ZdlPv($$sroa$037$065);
      $$sroa$037$0$be = $$0$i$i$i1075;
     } else {
      if ($82) {
       $121 = ((($$sroa$037$065)) + 8|0);
       $122 = HEAP32[$121>>2]|0;
       $123 = HEAP32[$122>>2]|0;
       $124 = ($123|0)==($$sroa$037$065|0);
       if ($124) {
        $$sroa$037$0$be = $122;
        break;
       } else {
        $128 = $121;
       }
       while(1) {
        $127 = HEAP32[$128>>2]|0;
        $129 = ((($127)) + 8|0);
        $130 = HEAP32[$129>>2]|0;
        $131 = HEAP32[$130>>2]|0;
        $132 = ($131|0)==($127|0);
        if ($132) {
         $$sroa$037$0$be = $130;
         break;
        } else {
         $128 = $129;
        }
       }
      } else {
       $$0$i$i$i = $81;
       while(1) {
        $125 = HEAP32[$$0$i$i$i>>2]|0;
        $126 = ($125|0)==(0|0);
        if ($126) {
         break;
        } else {
         $$0$i$i$i = $125;
        }
       }
       $$sroa$037$0$be = $$0$i$i$i;
       break;
      }
     }
    } while(0);
    $120 = ($$sroa$037$0$be|0)==($71|0);
    if ($120) {
     break;
    } else {
     $$sroa$037$065 = $$sroa$037$0$be;
    }
   }
   $133 = HEAP32[$1>>2]|0;
   $134 = ((($133)) + 12|0);
   $135 = HEAP32[$134>>2]|0;
   (FUNCTION_TABLE_ii[$135 & 8191]($1)|0);
   return;
  }
 } while(0);
 $136 = ___cxa_find_matching_catch_2()|0;
 $137 = tempRet0;
 $138 = HEAP32[$1>>2]|0;
 $139 = ((($138)) + 12|0);
 $140 = HEAP32[$139>>2]|0;
 __THREW__ = 0;
 (invoke_ii($140|0,($1|0))|0);
 $141 = __THREW__; __THREW__ = 0;
 $142 = $141&1;
 if ($142) {
  $143 = ___cxa_find_matching_catch_3(0|0)|0;
  $144 = tempRet0;
  ___clang_call_terminate($143);
  // unreachable;
 } else {
  ___resumeException($136|0);
  // unreachable;
 }
}
function __ZN5osgDB18SharedStateManager5shareEPN3osg4NodeEPN11OpenThreads5MutexE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 116|0);
 HEAP32[$3>>2] = $2;
 $4 = HEAP32[$1>>2]|0;
 $5 = ((($4)) + 188|0);
 $6 = HEAP32[$5>>2]|0;
 FUNCTION_TABLE_vii[$6 & 8191]($1,$0);
 $7 = ((($0)) + 80|0);
 $8 = ((($0)) + 84|0);
 $9 = HEAP32[$8>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIPN3osg14StateAttributeENS_4pairIS4_bEEEENS_19__map_value_compareIS4_S7_NS_4lessIS4_EELb1EEENS_9allocatorIS7_EEE7destroyEPNS_11__tree_nodeIS7_PvEE($7,$9);
 $10 = ((($0)) + 88|0);
 HEAP32[$10>>2] = 0;
 HEAP32[$7>>2] = $8;
 HEAP32[$8>>2] = 0;
 $11 = ((($0)) + 92|0);
 $12 = ((($0)) + 96|0);
 $13 = HEAP32[$12>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIPN3osg8StateSetENS_4pairIS4_bEEEENS_19__map_value_compareIS4_S7_NS_4lessIS4_EELb1EEENS_9allocatorIS7_EEE7destroyEPNS_11__tree_nodeIS7_PvEE($11,$13);
 $14 = ((($0)) + 100|0);
 HEAP32[$14>>2] = 0;
 HEAP32[$11>>2] = $12;
 HEAP32[$12>>2] = 0;
 HEAP32[$3>>2] = 0;
 return;
}
function __ZN5osgDB15writeObjectFileERKN3osg6ObjectERKNSt3__212basic_stringIcNS4_11char_traitsIcEENS4_9allocatorIcEEEEPKNS_7OptionsE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$05 = 0, $$1 = 0, $$16 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $3 = sp + 32|0;
 $4 = sp + 16|0;
 $5 = sp;
 $6 = (__ZN5osgDB8Registry8instanceEb(0)|0);
 $7 = ($2|0)==(0|0);
 if ($7) {
  label = 4;
 } else {
  $8 = ((($2)) + 120|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($9|0)==(0|0);
  if ($10) {
   label = 4;
  } else {
   $11 = HEAP32[$9>>2]|0;
   $12 = HEAP32[$11>>2]|0;
   FUNCTION_TABLE_viiiii[$12 & 8191]($4,$9,$0,$1,$2);
  }
 }
 do {
  if ((label|0) == 4) {
   $13 = ((($6)) + 52|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = ($14|0)==(0|0);
   if ($15) {
    __ZN5osgDB8Registry25writeObjectImplementationERKN3osg6ObjectERKNSt3__212basic_stringIcNS5_11char_traitsIcEENS5_9allocatorIcEEEEPKNS_7OptionsE($4,$6,$0,$1,$2);
    break;
   } else {
    $16 = HEAP32[$14>>2]|0;
    $17 = HEAP32[$16>>2]|0;
    FUNCTION_TABLE_viiiii[$17 & 8191]($4,$14,$0,$1,$2);
    break;
   }
  }
 } while(0);
 $18 = HEAP32[$4>>2]|0;
 $19 = ($18|0)==(3);
 L10: do {
  if (!($19)) {
   __THREW__ = 0;
   $20 = (invoke_ii(3265,2)|0);
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if ($22) {
    label = 28;
   } else {
    if (!($20)) {
     break;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(3266,2)|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     label = 28;
    } else {
     __THREW__ = 0;
     $26 = (invoke_iiii(3267,($23|0),(168389|0),19)|0);
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     if ($28) {
      label = 28;
     } else {
      $29 = ((($1)) + 11|0);
      $30 = HEAP8[$29>>0]|0;
      $31 = ($30<<24>>24)<(0);
      $32 = HEAP32[$1>>2]|0;
      $33 = $31 ? $32 : $1;
      $34 = ((($1)) + 4|0);
      $35 = HEAP32[$34>>2]|0;
      $36 = $30&255;
      $37 = $31 ? $35 : $36;
      __THREW__ = 0;
      $38 = (invoke_iiii(3267,($26|0),($33|0),($37|0))|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if ($40) {
       label = 28;
      } else {
       __THREW__ = 0;
       $41 = (invoke_iiii(3267,($38|0),(205152|0),2)|0);
       $42 = __THREW__; __THREW__ = 0;
       $43 = $42&1;
       if ($43) {
        label = 28;
       } else {
        __THREW__ = 0;
        invoke_vii(4222,($5|0),($4|0));
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if ($45) {
         $90 = ___cxa_find_matching_catch_2()|0;
         $91 = tempRet0;
         $$0 = $91;$$05 = $90;
        } else {
         $46 = ((($5)) + 11|0);
         $47 = HEAP8[$46>>0]|0;
         $48 = ($47<<24>>24)<(0);
         $49 = HEAP32[$5>>2]|0;
         $50 = $48 ? $49 : $5;
         $51 = ((($5)) + 4|0);
         $52 = HEAP32[$51>>2]|0;
         $53 = $47&255;
         $54 = $48 ? $52 : $53;
         __THREW__ = 0;
         $55 = (invoke_iiii(3267,($41|0),($50|0),($54|0))|0);
         $56 = __THREW__; __THREW__ = 0;
         $57 = $56&1;
         do {
          if ($57) {
           label = 30;
          } else {
           $58 = HEAP32[$55>>2]|0;
           $59 = ((($58)) + -12|0);
           $60 = HEAP32[$59>>2]|0;
           $61 = (($55) + ($60)|0);
           __THREW__ = 0;
           invoke_vii(3257,($3|0),($61|0));
           $62 = __THREW__; __THREW__ = 0;
           $63 = $62&1;
           if ($63) {
            label = 30;
           } else {
            __THREW__ = 0;
            $64 = (invoke_iii(3255,($3|0),(215188|0))|0);
            $65 = __THREW__; __THREW__ = 0;
            $66 = $65&1;
            if (!($66)) {
             $67 = HEAP32[$64>>2]|0;
             $68 = ((($67)) + 28|0);
             $69 = HEAP32[$68>>2]|0;
             __THREW__ = 0;
             $70 = (invoke_iii($69|0,($64|0),10)|0);
             $71 = __THREW__; __THREW__ = 0;
             $72 = $71&1;
             if (!($72)) {
              __THREW__ = 0;
              invoke_vi(3263,($3|0));
              $73 = __THREW__; __THREW__ = 0;
              $74 = $73&1;
              if ($74) {
               label = 30;
               break;
              }
              __THREW__ = 0;
              (invoke_iii(3268,($55|0),($70|0))|0);
              $81 = __THREW__; __THREW__ = 0;
              $82 = $81&1;
              if ($82) {
               label = 30;
               break;
              }
              __THREW__ = 0;
              (invoke_ii(3269,($55|0))|0);
              $83 = __THREW__; __THREW__ = 0;
              $84 = $83&1;
              if ($84) {
               label = 30;
               break;
              }
              $85 = HEAP8[$46>>0]|0;
              $86 = ($85<<24>>24)<(0);
              if ($86) {
               $87 = HEAP32[$5>>2]|0;
               __ZdlPv($87);
              }
              break L10;
             }
            }
            $75 = ___cxa_find_matching_catch_2()|0;
            $76 = tempRet0;
            __THREW__ = 0;
            invoke_vi(3263,($3|0));
            $77 = __THREW__; __THREW__ = 0;
            $78 = $77&1;
            if ($78) {
             $79 = ___cxa_find_matching_catch_3(0|0)|0;
             $80 = tempRet0;
             ___clang_call_terminate($79);
             // unreachable;
            } else {
             $eh$lpad$body$index2Z2D = $76;$eh$lpad$body$indexZ2D = $75;
             break;
            }
           }
          }
         } while(0);
         if ((label|0) == 30) {
          $92 = ___cxa_find_matching_catch_2()|0;
          $93 = tempRet0;
          $eh$lpad$body$index2Z2D = $93;$eh$lpad$body$indexZ2D = $92;
         }
         $94 = HEAP8[$46>>0]|0;
         $95 = ($94<<24>>24)<(0);
         if ($95) {
          $96 = HEAP32[$5>>2]|0;
          __ZdlPv($96);
          $$0 = $eh$lpad$body$index2Z2D;$$05 = $eh$lpad$body$indexZ2D;
         } else {
          $$0 = $eh$lpad$body$index2Z2D;$$05 = $eh$lpad$body$indexZ2D;
         }
        }
        $$1 = $$0;$$16 = $$05;
       }
      }
     }
    }
   }
   if ((label|0) == 28) {
    $88 = ___cxa_find_matching_catch_2()|0;
    $89 = tempRet0;
    $$1 = $89;$$16 = $88;
   }
   $104 = ((($4)) + 4|0);
   $105 = ((($104)) + 11|0);
   $106 = HEAP8[$105>>0]|0;
   $107 = ($106<<24>>24)<(0);
   if (!($107)) {
    ___resumeException($$16|0);
    // unreachable;
   }
   $108 = HEAP32[$104>>2]|0;
   __ZdlPv($108);
   ___resumeException($$16|0);
   // unreachable;
  }
 } while(0);
 $97 = HEAP32[$4>>2]|0;
 $98 = ($97|0)==(3);
 $99 = ((($4)) + 4|0);
 $100 = ((($99)) + 11|0);
 $101 = HEAP8[$100>>0]|0;
 $102 = ($101<<24>>24)<(0);
 if (!($102)) {
  STACKTOP = sp;return ($98|0);
 }
 $103 = HEAP32[$99>>2]|0;
 __ZdlPv($103);
 STACKTOP = sp;return ($98|0);
}
function __ZN5osgDB20ObjectWrapperManagerD2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (75296);
 $1 = ((($0)) + 48|0);
 $2 = ((($0)) + 52|0);
 $3 = HEAP32[$2>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN5osgDB9IntLookupEEENS_19__map_value_compareIS7_SA_NS_4lessIS7_EELb1EEENS5_ISA_EEE7destroyEPNS_11__tree_nodeISA_PvEE($1,$3);
 $4 = ((($0)) + 36|0);
 $5 = ((($0)) + 40|0);
 $6 = HEAP32[$5>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7ref_ptrIN5osgDB14BaseCompressorEEEEENS_19__map_value_compareIS7_SD_NS_4lessIS7_EELb1EEENS5_ISD_EEE7destroyEPNS_11__tree_nodeISD_PvEE($4,$6);
 $7 = ((($0)) + 24|0);
 $8 = ((($0)) + 28|0);
 $9 = HEAP32[$8>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7ref_ptrIN5osgDB13ObjectWrapperEEEEENS_19__map_value_compareIS7_SD_NS_4lessIS7_EELb1EEENS5_ISD_EEE7destroyEPNS_11__tree_nodeISD_PvEE($7,$9);
 $10 = ((($0)) + 12|0);
 __THREW__ = 0;
 invoke_vi(707,($10|0));
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if (!($12)) {
  __ZN3osg10ReferencedD2Ev($0);
  return;
 }
 $13 = ___cxa_find_matching_catch_2()|0;
 $14 = tempRet0;
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $15 = __THREW__; __THREW__ = 0;
 $16 = $15&1;
 if ($16) {
  $17 = ___cxa_find_matching_catch_3(0|0)|0;
  $18 = tempRet0;
  ___clang_call_terminate($17);
  // unreachable;
 } else {
  ___resumeException($13|0);
  // unreachable;
 }
}
function __ZN5osgDB20ObjectWrapperManagerD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(2710,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN5osgDB9IntLookupEEENS_19__map_value_compareIS7_SA_NS_4lessIS7_EELb1EEENS5_ISA_EEE7destroyEPNS_11__tree_nodeISA_PvEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 }
 $3 = HEAP32[$1>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN5osgDB9IntLookupEEENS_19__map_value_compareIS7_SA_NS_4lessIS7_EELb1EEENS5_ISA_EEE7destroyEPNS_11__tree_nodeISA_PvEE($0,$3);
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN5osgDB9IntLookupEEENS_19__map_value_compareIS7_SA_NS_4lessIS7_EELb1EEENS5_ISA_EEE7destroyEPNS_11__tree_nodeISA_PvEE($0,$5);
 $6 = ((($1)) + 16|0);
 $7 = ((($1)) + 40|0);
 $8 = ((($1)) + 44|0);
 $9 = HEAP32[$8>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEEENS_19__map_value_compareIiS8_NS_4lessIiEELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($7,$9);
 $10 = ((($1)) + 28|0);
 $11 = ((($1)) + 32|0);
 $12 = HEAP32[$11>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEiEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($10,$12);
 $13 = ((($6)) + 11|0);
 $14 = HEAP8[$13>>0]|0;
 $15 = ($14<<24>>24)<(0);
 if ($15) {
  $16 = HEAP32[$6>>2]|0;
  __ZdlPv($16);
 }
 __ZdlPv($1);
 return;
}
function __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7ref_ptrIN5osgDB14BaseCompressorEEEEENS_19__map_value_compareIS7_SD_NS_4lessIS7_EELb1EEENS5_ISD_EEE7destroyEPNS_11__tree_nodeISD_PvEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 }
 $3 = HEAP32[$1>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7ref_ptrIN5osgDB14BaseCompressorEEEEENS_19__map_value_compareIS7_SD_NS_4lessIS7_EELb1EEENS5_ISD_EEE7destroyEPNS_11__tree_nodeISD_PvEE($0,$3);
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7ref_ptrIN5osgDB14BaseCompressorEEEEENS_19__map_value_compareIS7_SD_NS_4lessIS7_EELb1EEENS5_ISD_EEE7destroyEPNS_11__tree_nodeISD_PvEE($0,$5);
 $6 = ((($1)) + 16|0);
 $7 = ((($1)) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if (!($9)) {
  $10 = ((($8)) + 8|0);
  $11 = HEAP32[$10>>2]|0;HEAP32[$10>>2] = (($11-1)|0);
  $12 = ($11|0)==(1);
  if ($12) {
   __THREW__ = 0;
   invoke_viii(3262,($8|0),1,1);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if ($14) {
    $19 = ___cxa_find_matching_catch_2()|0;
    $20 = tempRet0;
    $21 = ((($6)) + 11|0);
    $22 = HEAP8[$21>>0]|0;
    $23 = ($22<<24>>24)<(0);
    if (!($23)) {
     ___cxa_call_unexpected(($19|0));
     // unreachable;
    }
    $24 = HEAP32[$6>>2]|0;
    __ZdlPv($24);
    ___cxa_call_unexpected(($19|0));
    // unreachable;
   }
  }
 }
 HEAP32[$7>>2] = 0;
 $15 = ((($6)) + 11|0);
 $16 = HEAP8[$15>>0]|0;
 $17 = ($16<<24>>24)<(0);
 if ($17) {
  $18 = HEAP32[$6>>2]|0;
  __ZdlPv($18);
 }
 __ZdlPv($1);
 return;
}
function __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7ref_ptrIN5osgDB13ObjectWrapperEEEEENS_19__map_value_compareIS7_SD_NS_4lessIS7_EELb1EEENS5_ISD_EEE7destroyEPNS_11__tree_nodeISD_PvEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 }
 $3 = HEAP32[$1>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7ref_ptrIN5osgDB13ObjectWrapperEEEEENS_19__map_value_compareIS7_SD_NS_4lessIS7_EELb1EEENS5_ISD_EEE7destroyEPNS_11__tree_nodeISD_PvEE($0,$3);
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7ref_ptrIN5osgDB13ObjectWrapperEEEEENS_19__map_value_compareIS7_SD_NS_4lessIS7_EELb1EEENS5_ISD_EEE7destroyEPNS_11__tree_nodeISD_PvEE($0,$5);
 $6 = ((($1)) + 16|0);
 $7 = ((($1)) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if (!($9)) {
  $10 = ((($8)) + 8|0);
  $11 = HEAP32[$10>>2]|0;HEAP32[$10>>2] = (($11-1)|0);
  $12 = ($11|0)==(1);
  if ($12) {
   __THREW__ = 0;
   invoke_viii(3262,($8|0),1,1);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if ($14) {
    $19 = ___cxa_find_matching_catch_2()|0;
    $20 = tempRet0;
    $21 = ((($6)) + 11|0);
    $22 = HEAP8[$21>>0]|0;
    $23 = ($22<<24>>24)<(0);
    if (!($23)) {
     ___cxa_call_unexpected(($19|0));
     // unreachable;
    }
    $24 = HEAP32[$6>>2]|0;
    __ZdlPv($24);
    ___cxa_call_unexpected(($19|0));
    // unreachable;
   }
  }
 }
 HEAP32[$7>>2] = 0;
 $15 = ((($6)) + 11|0);
 $16 = HEAP8[$15>>0]|0;
 $17 = ($16<<24>>24)<(0);
 if ($17) {
  $18 = HEAP32[$6>>2]|0;
  __ZdlPv($18);
 }
 __ZdlPv($1);
 return;
}
function __ZNSt3__26__treeINS_12__value_typeIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEEENS_19__map_value_compareIiS8_NS_4lessIiEELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 }
 $3 = HEAP32[$1>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEEENS_19__map_value_compareIiS8_NS_4lessIiEELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($0,$3);
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEEENS_19__map_value_compareIiS8_NS_4lessIiEELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($0,$5);
 $6 = ((($1)) + 20|0);
 $7 = ((($6)) + 11|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = ($8<<24>>24)<(0);
 if ($9) {
  $10 = HEAP32[$6>>2]|0;
  __ZdlPv($10);
 }
 __ZdlPv($1);
 return;
}
function __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEiEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 }
 $3 = HEAP32[$1>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEiEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($0,$3);
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEiEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($0,$5);
 $6 = ((($1)) + 16|0);
 $7 = ((($6)) + 11|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = ($8<<24>>24)<(0);
 if ($9) {
  $10 = HEAP32[$6>>2]|0;
  __ZdlPv($10);
 }
 __ZdlPv($1);
 return;
}
function __ZN5osgDB20ObjectWrapperManagerC2Ev($0) {
 $0 = $0|0;
 var $$2 = 0, $$2225 = 0, $$5 = 0, $$5228 = 0, $$9 = 0, $$9232 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0;
 var $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0;
 var $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0;
 var $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0;
 var $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0;
 var $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0;
 var $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0;
 var $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0;
 var $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0;
 var $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0;
 var $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0;
 var $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0;
 var $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0;
 var $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0;
 var $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0;
 var $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0;
 var $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0;
 var $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0;
 var $508 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $1 = sp + 24|0;
 $2 = sp + 12|0;
 $3 = sp;
 __ZN3osg10ReferencedC2Ev($0);
 HEAP32[$0>>2] = (75296);
 $4 = ((($0)) + 12|0);
 __THREW__ = 0;
 invoke_vii(3507,($4|0),1);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $474 = ___cxa_find_matching_catch_2()|0;
  $475 = tempRet0;
  $$9 = $474;$$9232 = $475;
 } else {
  HEAP32[$4>>2] = (41932);
  $7 = ((($0)) + 24|0);
  $8 = ((($0)) + 28|0);
  HEAP32[$8>>2] = 0;
  $9 = ((($0)) + 32|0);
  HEAP32[$9>>2] = 0;
  $10 = ((($0)) + 28|0);
  HEAP32[$7>>2] = $10;
  $11 = ((($0)) + 36|0);
  $12 = ((($0)) + 40|0);
  HEAP32[$12>>2] = 0;
  $13 = ((($0)) + 44|0);
  HEAP32[$13>>2] = 0;
  $14 = ((($0)) + 40|0);
  HEAP32[$11>>2] = $14;
  $15 = ((($0)) + 48|0);
  $16 = ((($0)) + 52|0);
  HEAP32[$16>>2] = 0;
  $17 = ((($0)) + 56|0);
  HEAP32[$17>>2] = 0;
  $18 = ((($0)) + 52|0);
  HEAP32[$15>>2] = $18;
  ;HEAP32[$1>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;
  $19 = ((($1)) + 11|0);
  HEAP8[$19>>0] = 2;
  HEAP16[$1>>1] = 19527;
  $20 = ((($1)) + 2|0);
  HEAP8[$20>>0] = 0;
  __THREW__ = 0;
  $21 = (invoke_iii(4223,($15|0),($1|0))|0);
  $22 = __THREW__; __THREW__ = 0;
  $23 = $22&1;
  L4: do {
   if ($23) {
    $476 = ___cxa_find_matching_catch_2()|0;
    $477 = tempRet0;
    $478 = HEAP8[$19>>0]|0;
    $479 = ($478<<24>>24)<(0);
    if ($479) {
     $480 = HEAP32[$1>>2]|0;
     __ZdlPv($480);
    }
    $$5 = $476;$$5228 = $477;
   } else {
    $24 = HEAP8[$19>>0]|0;
    $25 = ($24<<24>>24)<(0);
    if ($25) {
     $26 = HEAP32[$1>>2]|0;
     __ZdlPv($26);
    }
    __THREW__ = 0;
    invoke_viii(4224,($21|0),(168440|0),3008);
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    do {
     if (!($28)) {
      __THREW__ = 0;
      invoke_viii(4224,($21|0),(168454|0),3042);
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if (!($30)) {
       __THREW__ = 0;
       invoke_viii(4224,($21|0),(168463|0),3058);
       $31 = __THREW__; __THREW__ = 0;
       $32 = $31&1;
       if (!($32)) {
        __THREW__ = 0;
        invoke_viii(4224,($21|0),(168481|0),2903);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if (!($34)) {
         __THREW__ = 0;
         invoke_viii(4224,($21|0),(168499|0),2884);
         $35 = __THREW__; __THREW__ = 0;
         $36 = $35&1;
         if (!($36)) {
          __THREW__ = 0;
          invoke_viii(4224,($21|0),(168512|0),2929);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if (!($38)) {
           __THREW__ = 0;
           invoke_viii(4224,($21|0),(168526|0),2912);
           $39 = __THREW__; __THREW__ = 0;
           $40 = $39&1;
           if (!($40)) {
            __THREW__ = 0;
            invoke_viii(4224,($21|0),(168533|0),34820);
            $41 = __THREW__; __THREW__ = 0;
            $42 = $41&1;
            if (!($42)) {
             __THREW__ = 0;
             invoke_viii(4224,($21|0),(168557|0),2852);
             $43 = __THREW__; __THREW__ = 0;
             $44 = $43&1;
             if (!($44)) {
              __THREW__ = 0;
              invoke_viii(4224,($21|0),(168573|0),2832);
              $45 = __THREW__; __THREW__ = 0;
              $46 = $45&1;
              if (!($46)) {
               __THREW__ = 0;
               invoke_viii(4224,($21|0),(168589|0),34913);
               $47 = __THREW__; __THREW__ = 0;
               $48 = $47&1;
               if (!($48)) {
                __THREW__ = 0;
                invoke_viii(4224,($21|0),(168609|0),32823);
                $49 = __THREW__; __THREW__ = 0;
                $50 = $49&1;
                if (!($50)) {
                 __THREW__ = 0;
                 invoke_viii(4224,($21|0),(168632|0),10754);
                 $51 = __THREW__; __THREW__ = 0;
                 $52 = $51&1;
                 if (!($52)) {
                  __THREW__ = 0;
                  invoke_viii(4224,($21|0),(168655|0),10753);
                  $53 = __THREW__; __THREW__ = 0;
                  $54 = $53&1;
                  if (!($54)) {
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(168679|0),2882);
                   $55 = __THREW__; __THREW__ = 0;
                   $56 = $55&1;
                   if ($56) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(168698|0),3089);
                   $57 = __THREW__; __THREW__ = 0;
                   $58 = $57&1;
                   if ($58) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(168714|0),2960);
                   $59 = __THREW__; __THREW__ = 0;
                   $60 = $59&1;
                   if ($60) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(168730|0),35088);
                   $61 = __THREW__; __THREW__ = 0;
                   $62 = $61&1;
                   if ($62) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(168755|0),34336);
                   $63 = __THREW__; __THREW__ = 0;
                   $64 = $63&1;
                   if ($64) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(168777|0),33880);
                   $65 = __THREW__; __THREW__ = 0;
                   $66 = $65&1;
                   if ($66) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(168790|0),2896);
                   $67 = __THREW__; __THREW__ = 0;
                   $68 = $67&1;
                   if ($68) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(168802|0),2977);
                   $69 = __THREW__; __THREW__ = 0;
                   $70 = $69&1;
                   if ($70) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(168815|0),32826);
                   $71 = __THREW__; __THREW__ = 0;
                   $72 = $71&1;
                   if ($72) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(168833|0),3552);
                   $73 = __THREW__; __THREW__ = 0;
                   $74 = $73&1;
                   if ($74) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(168847|0),3553);
                   $75 = __THREW__; __THREW__ = 0;
                   $76 = $75&1;
                   if ($76) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(168861|0),32879);
                   $77 = __THREW__; __THREW__ = 0;
                   $78 = $77&1;
                   if ($78) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(168875|0),34067);
                   $79 = __THREW__; __THREW__ = 0;
                   $80 = $79&1;
                   if ($80) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(168895|0),34037);
                   $81 = __THREW__; __THREW__ = 0;
                   $82 = $81&1;
                   if ($82) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(168916|0),3171);
                   $83 = __THREW__; __THREW__ = 0;
                   $84 = $83&1;
                   if ($84) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(168933|0),3170);
                   $85 = __THREW__; __THREW__ = 0;
                   $86 = $85&1;
                   if ($86) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(168950|0),3168);
                   $87 = __THREW__; __THREW__ = 0;
                   $88 = $87&1;
                   if ($88) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(168967|0),3169);
                   $89 = __THREW__; __THREW__ = 0;
                   $90 = $89&1;
                   if ($90) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(168984|0),12288);
                   $91 = __THREW__; __THREW__ = 0;
                   $92 = $91&1;
                   if ($92) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(168999|0),12289);
                   $93 = __THREW__; __THREW__ = 0;
                   $94 = $93&1;
                   if ($94) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(169014|0),12290);
                   $95 = __THREW__; __THREW__ = 0;
                   $96 = $95&1;
                   if ($96) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(169029|0),12291);
                   $97 = __THREW__; __THREW__ = 0;
                   $98 = $97&1;
                   if ($98) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(169044|0),12292);
                   $99 = __THREW__; __THREW__ = 0;
                   $100 = $99&1;
                   if ($100) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(169059|0),12293);
                   $101 = __THREW__; __THREW__ = 0;
                   $102 = $101&1;
                   if ($102) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(169074|0),16384);
                   $103 = __THREW__; __THREW__ = 0;
                   $104 = $103&1;
                   if ($104) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(169084|0),16385);
                   $105 = __THREW__; __THREW__ = 0;
                   $106 = $105&1;
                   if ($106) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(169094|0),16386);
                   $107 = __THREW__; __THREW__ = 0;
                   $108 = $107&1;
                   if ($108) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(169104|0),16387);
                   $109 = __THREW__; __THREW__ = 0;
                   $110 = $109&1;
                   if ($110) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(169114|0),16388);
                   $111 = __THREW__; __THREW__ = 0;
                   $112 = $111&1;
                   if ($112) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(169124|0),16389);
                   $113 = __THREW__; __THREW__ = 0;
                   $114 = $113&1;
                   if ($114) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(169134|0),16390);
                   $115 = __THREW__; __THREW__ = 0;
                   $116 = $115&1;
                   if ($116) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(169144|0),16391);
                   $117 = __THREW__; __THREW__ = 0;
                   $118 = $117&1;
                   if ($118) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(169154|0),34370);
                   $119 = __THREW__; __THREW__ = 0;
                   $120 = $119&1;
                   if ($120) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(169183|0),34371);
                   $121 = __THREW__; __THREW__ = 0;
                   $122 = $121&1;
                   if ($122) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(169210|0),512);
                   $123 = __THREW__; __THREW__ = 0;
                   $124 = $123&1;
                   if ($124) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(169216|0),513);
                   $125 = __THREW__; __THREW__ = 0;
                   $126 = $125&1;
                   if ($126) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(169221|0),514);
                   $127 = __THREW__; __THREW__ = 0;
                   $128 = $127&1;
                   if ($128) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(169227|0),515);
                   $129 = __THREW__; __THREW__ = 0;
                   $130 = $129&1;
                   if ($130) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(169234|0),516);
                   $131 = __THREW__; __THREW__ = 0;
                   $132 = $131&1;
                   if ($132) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(169242|0),517);
                   $133 = __THREW__; __THREW__ = 0;
                   $134 = $133&1;
                   if ($134) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(169251|0),518);
                   $135 = __THREW__; __THREW__ = 0;
                   $136 = $135&1;
                   if ($136) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(169258|0),519);
                   $137 = __THREW__; __THREW__ = 0;
                   $138 = $137&1;
                   if ($138) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(169265|0),7681);
                   $139 = __THREW__; __THREW__ = 0;
                   $140 = $139&1;
                   if ($140) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(169273|0),8448);
                   $141 = __THREW__; __THREW__ = 0;
                   $142 = $141&1;
                   if ($142) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(169282|0),260);
                   $143 = __THREW__; __THREW__ = 0;
                   $144 = $143&1;
                   if ($144) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(169286|0),34164);
                   $145 = __THREW__; __THREW__ = 0;
                   $146 = $145&1;
                   if ($146) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(169297|0),34165);
                   $147 = __THREW__; __THREW__ = 0;
                   $148 = $147&1;
                   if ($148) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(169309|0),34023);
                   $149 = __THREW__; __THREW__ = 0;
                   $150 = $149&1;
                   if ($150) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(169318|0),34478);
                   $151 = __THREW__; __THREW__ = 0;
                   $152 = $151&1;
                   if ($152) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(169327|0),34479);
                   $153 = __THREW__; __THREW__ = 0;
                   $154 = $153&1;
                   if ($154) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(169337|0),34166);
                   $155 = __THREW__; __THREW__ = 0;
                   $156 = $155&1;
                   if ($156) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(169346|0),34167);
                   $157 = __THREW__; __THREW__ = 0;
                   $158 = $157&1;
                   if ($158) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(169360|0),34168);
                   $159 = __THREW__; __THREW__ = 0;
                   $160 = $159&1;
                   if ($160) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(169369|0),5890);
                   $161 = __THREW__; __THREW__ = 0;
                   $162 = $161&1;
                   if ($162) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(169377|0),33984);
                   $163 = __THREW__; __THREW__ = 0;
                   $164 = $163&1;
                   if ($164) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(169386|0),33985);
                   $165 = __THREW__; __THREW__ = 0;
                   $166 = $165&1;
                   if ($166) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(169395|0),33986);
                   $167 = __THREW__; __THREW__ = 0;
                   $168 = $167&1;
                   if ($168) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(169404|0),33987);
                   $169 = __THREW__; __THREW__ = 0;
                   $170 = $169&1;
                   if ($170) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(169413|0),33988);
                   $171 = __THREW__; __THREW__ = 0;
                   $172 = $171&1;
                   if ($172) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(169422|0),33989);
                   $173 = __THREW__; __THREW__ = 0;
                   $174 = $173&1;
                   if ($174) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(169431|0),33990);
                   $175 = __THREW__; __THREW__ = 0;
                   $176 = $175&1;
                   if ($176) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(169440|0),33991);
                   $177 = __THREW__; __THREW__ = 0;
                   $178 = $177&1;
                   if ($178) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(169449|0),10496);
                   $179 = __THREW__; __THREW__ = 0;
                   $180 = $179&1;
                   if ($180) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(169455|0),33071);
                   $181 = __THREW__; __THREW__ = 0;
                   $182 = $181&1;
                   if ($182) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(169469|0),33069);
                   $183 = __THREW__; __THREW__ = 0;
                   $184 = $183&1;
                   if ($184) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(169485|0),10497);
                   $185 = __THREW__; __THREW__ = 0;
                   $186 = $185&1;
                   if ($186) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(169492|0),33648);
                   $187 = __THREW__; __THREW__ = 0;
                   $188 = $187&1;
                   if ($188) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(169499|0),9729);
                   $189 = __THREW__; __THREW__ = 0;
                   $190 = $189&1;
                   if ($190) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(169506|0),9987);
                   $191 = __THREW__; __THREW__ = 0;
                   $192 = $191&1;
                   if ($192) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(169527|0),9985);
                   $193 = __THREW__; __THREW__ = 0;
                   $194 = $193&1;
                   if ($194) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(169549|0),9728);
                   $195 = __THREW__; __THREW__ = 0;
                   $196 = $195&1;
                   if ($196) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(169557|0),9986);
                   $197 = __THREW__; __THREW__ = 0;
                   $198 = $197&1;
                   if ($198) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(169579|0),9984);
                   $199 = __THREW__; __THREW__ = 0;
                   $200 = $199&1;
                   if ($200) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(169602|0),32841);
                   $201 = __THREW__; __THREW__ = 0;
                   $202 = $201&1;
                   if ($202) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(169615|0),6409);
                   $203 = __THREW__; __THREW__ = 0;
                   $204 = $203&1;
                   if ($204) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(169628|0),6406);
                   $205 = __THREW__; __THREW__ = 0;
                   $206 = $205&1;
                   if ($206) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(169637|0),6410);
                   $207 = __THREW__; __THREW__ = 0;
                   $208 = $207&1;
                   if ($208) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(169656|0),6407);
                   $209 = __THREW__; __THREW__ = 0;
                   $210 = $209&1;
                   if ($210) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(169663|0),6408);
                   $211 = __THREW__; __THREW__ = 0;
                   $212 = $211&1;
                   if ($212) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(169671|0),34025);
                   $213 = __THREW__; __THREW__ = 0;
                   $214 = $213&1;
                   if ($214) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(169695|0),34026);
                   $215 = __THREW__; __THREW__ = 0;
                   $216 = $215&1;
                   if ($216) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(169723|0),34028);
                   $217 = __THREW__; __THREW__ = 0;
                   $218 = $217&1;
                   if ($218) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(169751|0),34027);
                   $219 = __THREW__; __THREW__ = 0;
                   $220 = $219&1;
                   if ($220) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(169785|0),34029);
                   $221 = __THREW__; __THREW__ = 0;
                   $222 = $221&1;
                   if ($222) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(169807|0),34030);
                   $223 = __THREW__; __THREW__ = 0;
                   $224 = $223&1;
                   if ($224) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(169830|0),33776);
                   $225 = __THREW__; __THREW__ = 0;
                   $226 = $225&1;
                   if ($226) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(169862|0),33777);
                   $227 = __THREW__; __THREW__ = 0;
                   $228 = $227&1;
                   if ($228) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(169895|0),33778);
                   $229 = __THREW__; __THREW__ = 0;
                   $230 = $229&1;
                   if ($230) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(169928|0),33779);
                   $231 = __THREW__; __THREW__ = 0;
                   $232 = $231&1;
                   if ($232) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(169961|0),35840);
                   $233 = __THREW__; __THREW__ = 0;
                   $234 = $233&1;
                   if ($234) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(169996|0),35841);
                   $235 = __THREW__; __THREW__ = 0;
                   $236 = $235&1;
                   if ($236) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(170031|0),35842);
                   $237 = __THREW__; __THREW__ = 0;
                   $238 = $237&1;
                   if ($238) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(170067|0),35843);
                   $239 = __THREW__; __THREW__ = 0;
                   $240 = $239&1;
                   if ($240) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(170103|0),36196);
                   $241 = __THREW__; __THREW__ = 0;
                   $242 = $241&1;
                   if ($242) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(170120|0),37492);
                   $243 = __THREW__; __THREW__ = 0;
                   $244 = $243&1;
                   if ($244) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(170144|0),37493);
                   $245 = __THREW__; __THREW__ = 0;
                   $246 = $245&1;
                   if ($246) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(170169|0),37494);
                   $247 = __THREW__; __THREW__ = 0;
                   $248 = $247&1;
                   if ($248) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(170213|0),37495);
                   $249 = __THREW__; __THREW__ = 0;
                   $250 = $249&1;
                   if ($250) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(170258|0),37496);
                   $251 = __THREW__; __THREW__ = 0;
                   $252 = $251&1;
                   if ($252) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(170287|0),37497);
                   $253 = __THREW__; __THREW__ = 0;
                   $254 = $253&1;
                   if ($254) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(170323|0),37488);
                   $255 = __THREW__; __THREW__ = 0;
                   $256 = $255&1;
                   if ($256) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(170345|0),37489);
                   $257 = __THREW__; __THREW__ = 0;
                   $258 = $257&1;
                   if ($258) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(170374|0),37490);
                   $259 = __THREW__; __THREW__ = 0;
                   $260 = $259&1;
                   if ($260) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(170397|0),37491);
                   $261 = __THREW__; __THREW__ = 0;
                   $262 = $261&1;
                   if ($262) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(170427|0),5120);
                   $263 = __THREW__; __THREW__ = 0;
                   $264 = $263&1;
                   if ($264) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(170435|0),5122);
                   $265 = __THREW__; __THREW__ = 0;
                   $266 = $265&1;
                   if ($266) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(170444|0),5124);
                   $267 = __THREW__; __THREW__ = 0;
                   $268 = $267&1;
                   if ($268) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(170451|0),5126);
                   $269 = __THREW__; __THREW__ = 0;
                   $270 = $269&1;
                   if ($270) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(170460|0),5130);
                   $271 = __THREW__; __THREW__ = 0;
                   $272 = $271&1;
                   if ($272) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(170470|0),5121);
                   $273 = __THREW__; __THREW__ = 0;
                   $274 = $273&1;
                   if ($274) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(170487|0),5123);
                   $275 = __THREW__; __THREW__ = 0;
                   $276 = $275&1;
                   if ($276) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(170505|0),5125);
                   $277 = __THREW__; __THREW__ = 0;
                   $278 = $277&1;
                   if ($278) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(170521|0),772);
                   $279 = __THREW__; __THREW__ = 0;
                   $280 = $279&1;
                   if ($280) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(170531|0),774);
                   $281 = __THREW__; __THREW__ = 0;
                   $282 = $281&1;
                   if ($282) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(170541|0),1);
                   $283 = __THREW__; __THREW__ = 0;
                   $284 = $283&1;
                   if ($284) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(170545|0),773);
                   $285 = __THREW__; __THREW__ = 0;
                   $286 = $285&1;
                   if ($286) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(170565|0),775);
                   $287 = __THREW__; __THREW__ = 0;
                   $288 = $287&1;
                   if ($288) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(170585|0),771);
                   $289 = __THREW__; __THREW__ = 0;
                   $290 = $289&1;
                   if ($290) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(170605|0),769);
                   $291 = __THREW__; __THREW__ = 0;
                   $292 = $291&1;
                   if ($292) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(170625|0),770);
                   $293 = __THREW__; __THREW__ = 0;
                   $294 = $293&1;
                   if ($294) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(170635|0),776);
                   $295 = __THREW__; __THREW__ = 0;
                   $296 = $295&1;
                   if ($296) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(170654|0),768);
                   $297 = __THREW__; __THREW__ = 0;
                   $298 = $297&1;
                   if ($298) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(170664|0),32769);
                   $299 = __THREW__; __THREW__ = 0;
                   $300 = $299&1;
                   if ($300) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(170679|0),32770);
                   $301 = __THREW__; __THREW__ = 0;
                   $302 = $301&1;
                   if ($302) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(170704|0),32771);
                   $303 = __THREW__; __THREW__ = 0;
                   $304 = $303&1;
                   if ($304) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(170719|0),32772);
                   $305 = __THREW__; __THREW__ = 0;
                   $306 = $305&1;
                   if ($306) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(170744|0),0);
                   $307 = __THREW__; __THREW__ = 0;
                   $308 = $307&1;
                   if ($308) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(170749|0),33873);
                   $309 = __THREW__; __THREW__ = 0;
                   $310 = $309&1;
                   if ($310) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(170760|0),33874);
                   $311 = __THREW__; __THREW__ = 0;
                   $312 = $311&1;
                   if ($312) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(170766|0),3156);
                   $313 = __THREW__; __THREW__ = 0;
                   $314 = $313&1;
                   if ($314) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(170775|0),33170);
                   $315 = __THREW__; __THREW__ = 0;
                   $316 = $315&1;
                   if ($316) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(170796|0),3154);
                   $317 = __THREW__; __THREW__ = 0;
                   $318 = $317&1;
                   if ($318) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(170813|0),3152);
                   $319 = __THREW__; __THREW__ = 0;
                   $320 = $319&1;
                   if ($320) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(170841|0),3153);
                   $321 = __THREW__; __THREW__ = 0;
                   $322 = $321&1;
                   if ($322) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(170859|0),3155);
                   $323 = __THREW__; __THREW__ = 0;
                   $324 = $323&1;
                   if ($324) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(170879|0),34031);
                   $325 = __THREW__; __THREW__ = 0;
                   $326 = $325&1;
                   if ($326) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(170904|0),35723);
                   $327 = __THREW__; __THREW__ = 0;
                   $328 = $327&1;
                   if ($328) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(170936|0),6912);
                   $329 = __THREW__; __THREW__ = 0;
                   $330 = $329&1;
                   if ($330) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(170942|0),6913);
                   $331 = __THREW__; __THREW__ = 0;
                   $332 = $331&1;
                   if ($332) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(170947|0),6914);
                   $333 = __THREW__; __THREW__ = 0;
                   $334 = $333&1;
                   if ($334) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(170952|0),1029);
                   $335 = __THREW__; __THREW__ = 0;
                   $336 = $335&1;
                   if ($336) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(170957|0),1028);
                   $337 = __THREW__; __THREW__ = 0;
                   $338 = $337&1;
                   if ($338) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(170963|0),1032);
                   $339 = __THREW__; __THREW__ = 0;
                   $340 = $339&1;
                   if ($340) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(170978|0),35101);
                   $341 = __THREW__; __THREW__ = 0;
                   $342 = $341&1;
                   if ($342) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(170989|0),4353);
                   $343 = __THREW__; __THREW__ = 0;
                   $344 = $343&1;
                   if ($344) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(170997|0),4354);
                   $345 = __THREW__; __THREW__ = 0;
                   $346 = $345&1;
                   if ($346) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($21|0),(171004|0),4352);
                   $347 = __THREW__; __THREW__ = 0;
                   $348 = $347&1;
                   if ($348) {
                    break;
                   }
                   ;HEAP32[$2>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;
                   $349 = ((($2)) + 11|0);
                   HEAP8[$349>>0] = 9;
                   dest=$2; src=171014; stop=dest+9|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                   $350 = ((($2)) + 9|0);
                   HEAP8[$350>>0] = 0;
                   __THREW__ = 0;
                   $351 = (invoke_iii(4223,($15|0),($2|0))|0);
                   $352 = __THREW__; __THREW__ = 0;
                   $353 = $352&1;
                   if ($353) {
                    $483 = ___cxa_find_matching_catch_2()|0;
                    $484 = tempRet0;
                    $485 = HEAP8[$349>>0]|0;
                    $486 = ($485<<24>>24)<(0);
                    if ($486) {
                     $487 = HEAP32[$2>>2]|0;
                     __ZdlPv($487);
                    }
                    $$5 = $483;$$5228 = $484;
                    break L4;
                   }
                   $354 = HEAP8[$349>>0]|0;
                   $355 = ($354<<24>>24)<(0);
                   if ($355) {
                    $356 = HEAP32[$2>>2]|0;
                    __ZdlPv($356);
                   }
                   __THREW__ = 0;
                   invoke_viii(4224,($351|0),(171024|0),0);
                   $357 = __THREW__; __THREW__ = 0;
                   $358 = $357&1;
                   do {
                    if (!($358)) {
                     __THREW__ = 0;
                     invoke_viii(4224,($351|0),(171034|0),1);
                     $359 = __THREW__; __THREW__ = 0;
                     $360 = $359&1;
                     if ($360) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_viii(4224,($351|0),(171045|0),2);
                     $361 = __THREW__; __THREW__ = 0;
                     $362 = $361&1;
                     if ($362) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_viii(4224,($351|0),(171056|0),3);
                     $363 = __THREW__; __THREW__ = 0;
                     $364 = $363&1;
                     if ($364) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_viii(4224,($351|0),(171068|0),4);
                     $365 = __THREW__; __THREW__ = 0;
                     $366 = $365&1;
                     if ($366) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_viii(4224,($351|0),(171077|0),5);
                     $367 = __THREW__; __THREW__ = 0;
                     $368 = $367&1;
                     if ($368) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_viii(4224,($351|0),(171087|0),6);
                     $369 = __THREW__; __THREW__ = 0;
                     $370 = $369&1;
                     if ($370) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_viii(4224,($351|0),(171098|0),7);
                     $371 = __THREW__; __THREW__ = 0;
                     $372 = $371&1;
                     if ($372) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_viii(4224,($351|0),(171110|0),8);
                     $373 = __THREW__; __THREW__ = 0;
                     $374 = $373&1;
                     if ($374) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_viii(4224,($351|0),(171121|0),9);
                     $375 = __THREW__; __THREW__ = 0;
                     $376 = $375&1;
                     if ($376) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_viii(4224,($351|0),(171132|0),10);
                     $377 = __THREW__; __THREW__ = 0;
                     $378 = $377&1;
                     if ($378) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_viii(4224,($351|0),(171143|0),21);
                     $379 = __THREW__; __THREW__ = 0;
                     $380 = $379&1;
                     if ($380) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_viii(4224,($351|0),(171155|0),22);
                     $381 = __THREW__; __THREW__ = 0;
                     $382 = $381&1;
                     if ($382) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_viii(4224,($351|0),(171167|0),11);
                     $383 = __THREW__; __THREW__ = 0;
                     $384 = $383&1;
                     if ($384) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_viii(4224,($351|0),(171179|0),12);
                     $385 = __THREW__; __THREW__ = 0;
                     $386 = $385&1;
                     if ($386) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_viii(4224,($351|0),(171190|0),13);
                     $387 = __THREW__; __THREW__ = 0;
                     $388 = $387&1;
                     if ($388) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_viii(4224,($351|0),(171201|0),14);
                     $389 = __THREW__; __THREW__ = 0;
                     $390 = $389&1;
                     if ($390) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_viii(4224,($351|0),(171212|0),23);
                     $391 = __THREW__; __THREW__ = 0;
                     $392 = $391&1;
                     if ($392) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_viii(4224,($351|0),(171224|0),24);
                     $393 = __THREW__; __THREW__ = 0;
                     $394 = $393&1;
                     if ($394) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_viii(4224,($351|0),(171236|0),25);
                     $395 = __THREW__; __THREW__ = 0;
                     $396 = $395&1;
                     if ($396) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_viii(4224,($351|0),(171248|0),15);
                     $397 = __THREW__; __THREW__ = 0;
                     $398 = $397&1;
                     if ($398) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_viii(4224,($351|0),(171259|0),16);
                     $399 = __THREW__; __THREW__ = 0;
                     $400 = $399&1;
                     if ($400) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_viii(4224,($351|0),(171270|0),17);
                     $401 = __THREW__; __THREW__ = 0;
                     $402 = $401&1;
                     if ($402) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_viii(4224,($351|0),(171281|0),18);
                     $403 = __THREW__; __THREW__ = 0;
                     $404 = $403&1;
                     if ($404) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_viii(4224,($351|0),(171292|0),19);
                     $405 = __THREW__; __THREW__ = 0;
                     $406 = $405&1;
                     if ($406) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_viii(4224,($351|0),(171303|0),20);
                     $407 = __THREW__; __THREW__ = 0;
                     $408 = $407&1;
                     if ($408) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_viii(4224,($351|0),(171314|0),26);
                     $409 = __THREW__; __THREW__ = 0;
                     $410 = $409&1;
                     if ($410) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_viii(4224,($351|0),(171325|0),27);
                     $411 = __THREW__; __THREW__ = 0;
                     $412 = $411&1;
                     if ($412) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_viii(4224,($351|0),(171336|0),28);
                     $413 = __THREW__; __THREW__ = 0;
                     $414 = $413&1;
                     if ($414) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_viii(4224,($351|0),(171347|0),29);
                     $415 = __THREW__; __THREW__ = 0;
                     $416 = $415&1;
                     if ($416) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_viii(4224,($351|0),(171359|0),30);
                     $417 = __THREW__; __THREW__ = 0;
                     $418 = $417&1;
                     if ($418) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_viii(4224,($351|0),(171371|0),31);
                     $419 = __THREW__; __THREW__ = 0;
                     $420 = $419&1;
                     if ($420) {
                      break;
                     }
                     ;HEAP32[$3>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;
                     __THREW__ = 0;
                     $421 = (invoke_ii(3276,16)|0);
                     $422 = __THREW__; __THREW__ = 0;
                     $423 = $422&1;
                     do {
                      if ($423) {
                       $490 = ___cxa_find_matching_catch_2()|0;
                       $491 = tempRet0;
                       $$2 = $490;$$2225 = $491;
                      } else {
                       HEAP32[$3>>2] = $421;
                       $424 = ((($3)) + 8|0);
                       HEAP32[$424>>2] = -2147483632;
                       $425 = ((($3)) + 4|0);
                       HEAP32[$425>>2] = 13;
                       dest=$421; src=171383; stop=dest+13|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                       $426 = ((($421)) + 13|0);
                       HEAP8[$426>>0] = 0;
                       __THREW__ = 0;
                       $427 = (invoke_iii(4223,($15|0),($3|0))|0);
                       $428 = __THREW__; __THREW__ = 0;
                       $429 = $428&1;
                       if ($429) {
                        $492 = ___cxa_find_matching_catch_2()|0;
                        $493 = tempRet0;
                        $494 = ((($3)) + 11|0);
                        $495 = HEAP8[$494>>0]|0;
                        $496 = ($495<<24>>24)<(0);
                        if (!($496)) {
                         $$2 = $492;$$2225 = $493;
                         break;
                        }
                        $497 = HEAP32[$3>>2]|0;
                        __ZdlPv($497);
                        $$2 = $492;$$2225 = $493;
                        break;
                       }
                       $430 = ((($3)) + 11|0);
                       $431 = HEAP8[$430>>0]|0;
                       $432 = ($431<<24>>24)<(0);
                       if ($432) {
                        $433 = HEAP32[$3>>2]|0;
                        __ZdlPv($433);
                       }
                       __THREW__ = 0;
                       invoke_viii(4224,($427|0),(171397|0),50);
                       $434 = __THREW__; __THREW__ = 0;
                       $435 = $434&1;
                       do {
                        if (!($435)) {
                         __THREW__ = 0;
                         invoke_viii(4224,($427|0),(171408|0),51);
                         $436 = __THREW__; __THREW__ = 0;
                         $437 = $436&1;
                         if ($437) {
                          break;
                         }
                         __THREW__ = 0;
                         invoke_viii(4224,($427|0),(171425|0),52);
                         $438 = __THREW__; __THREW__ = 0;
                         $439 = $438&1;
                         if ($439) {
                          break;
                         }
                         __THREW__ = 0;
                         invoke_viii(4224,($427|0),(171443|0),53);
                         $440 = __THREW__; __THREW__ = 0;
                         $441 = $440&1;
                         if ($441) {
                          break;
                         }
                         __THREW__ = 0;
                         invoke_viii(4224,($427|0),(171462|0),54);
                         $442 = __THREW__; __THREW__ = 0;
                         $443 = $442&1;
                         if ($443) {
                          break;
                         }
                         __THREW__ = 0;
                         invoke_viii(4224,($427|0),(171479|0),0);
                         $444 = __THREW__; __THREW__ = 0;
                         $445 = $444&1;
                         if ($445) {
                          break;
                         }
                         __THREW__ = 0;
                         invoke_viii(4224,($427|0),(171489|0),1);
                         $446 = __THREW__; __THREW__ = 0;
                         $447 = $446&1;
                         if ($447) {
                          break;
                         }
                         __THREW__ = 0;
                         invoke_viii(4224,($427|0),(171498|0),3);
                         $448 = __THREW__; __THREW__ = 0;
                         $449 = $448&1;
                         if ($449) {
                          break;
                         }
                         __THREW__ = 0;
                         invoke_viii(4224,($427|0),(171512|0),2);
                         $450 = __THREW__; __THREW__ = 0;
                         $451 = $450&1;
                         if ($451) {
                          break;
                         }
                         __THREW__ = 0;
                         invoke_viii(4224,($427|0),(171525|0),4);
                         $452 = __THREW__; __THREW__ = 0;
                         $453 = $452&1;
                         if ($453) {
                          break;
                         }
                         __THREW__ = 0;
                         invoke_viii(4224,($427|0),(171538|0),5);
                         $454 = __THREW__; __THREW__ = 0;
                         $455 = $454&1;
                         if ($455) {
                          break;
                         }
                         __THREW__ = 0;
                         invoke_viii(4224,($427|0),(171556|0),6);
                         $456 = __THREW__; __THREW__ = 0;
                         $457 = $456&1;
                         if ($457) {
                          break;
                         }
                         __THREW__ = 0;
                         invoke_viii(4224,($427|0),(171572|0),7);
                         $458 = __THREW__; __THREW__ = 0;
                         $459 = $458&1;
                         if ($459) {
                          break;
                         }
                         __THREW__ = 0;
                         invoke_viii(4224,($427|0),(171581|0),8);
                         $460 = __THREW__; __THREW__ = 0;
                         $461 = $460&1;
                         if ($461) {
                          break;
                         }
                         __THREW__ = 0;
                         invoke_viii(4224,($427|0),(171595|0),9);
                         $462 = __THREW__; __THREW__ = 0;
                         $463 = $462&1;
                         if ($463) {
                          break;
                         }
                         __THREW__ = 0;
                         invoke_viiii(4225,($427|0),(171606|0),(171629|0),10);
                         $464 = __THREW__; __THREW__ = 0;
                         $465 = $464&1;
                         if ($465) {
                          break;
                         }
                         __THREW__ = 0;
                         invoke_viiii(4225,($427|0),(171648|0),(171676|0),11);
                         $466 = __THREW__; __THREW__ = 0;
                         $467 = $466&1;
                         if ($467) {
                          break;
                         }
                         __THREW__ = 0;
                         invoke_viiii(4225,($427|0),(171700|0),(171727|0),12);
                         $468 = __THREW__; __THREW__ = 0;
                         $469 = $468&1;
                         if ($469) {
                          break;
                         }
                         __THREW__ = 0;
                         invoke_viiii(4225,($427|0),(171750|0),(171782|0),13);
                         $470 = __THREW__; __THREW__ = 0;
                         $471 = $470&1;
                         if ($471) {
                          break;
                         }
                         __THREW__ = 0;
                         invoke_viii(4224,($427|0),(171810|0),14);
                         $472 = __THREW__; __THREW__ = 0;
                         $473 = $472&1;
                         if ($473) {
                          break;
                         }
                         STACKTOP = sp;return;
                        }
                       } while(0);
                       $498 = ___cxa_find_matching_catch_2()|0;
                       $499 = tempRet0;
                       $$5 = $498;$$5228 = $499;
                       break L4;
                      }
                     } while(0);
                     $$5 = $$2;$$5228 = $$2225;
                     break L4;
                    }
                   } while(0);
                   $488 = ___cxa_find_matching_catch_2()|0;
                   $489 = tempRet0;
                   $$5 = $488;$$5228 = $489;
                   break L4;
                  }
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    } while(0);
    $481 = ___cxa_find_matching_catch_2()|0;
    $482 = tempRet0;
    $$5 = $481;$$5228 = $482;
   }
  } while(0);
  $500 = HEAP32[$18>>2]|0;
  __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN5osgDB9IntLookupEEENS_19__map_value_compareIS7_SA_NS_4lessIS7_EELb1EEENS5_ISA_EEE7destroyEPNS_11__tree_nodeISA_PvEE($15,$500);
  $501 = HEAP32[$14>>2]|0;
  __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7ref_ptrIN5osgDB14BaseCompressorEEEEENS_19__map_value_compareIS7_SD_NS_4lessIS7_EELb1EEENS5_ISD_EEE7destroyEPNS_11__tree_nodeISD_PvEE($11,$501);
  $502 = HEAP32[$10>>2]|0;
  __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7ref_ptrIN5osgDB13ObjectWrapperEEEEENS_19__map_value_compareIS7_SD_NS_4lessIS7_EELb1EEENS5_ISD_EEE7destroyEPNS_11__tree_nodeISD_PvEE($7,$502);
  __THREW__ = 0;
  invoke_vi(707,($4|0));
  $503 = __THREW__; __THREW__ = 0;
  $504 = $503&1;
  if ($504) {
   $507 = ___cxa_find_matching_catch_3(0|0)|0;
   $508 = tempRet0;
   ___clang_call_terminate($507);
   // unreachable;
  } else {
   $$9 = $$5;$$9232 = $$5228;
  }
 }
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $505 = __THREW__; __THREW__ = 0;
 $506 = $505&1;
 if ($506) {
  $507 = ___cxa_find_matching_catch_3(0|0)|0;
  $508 = tempRet0;
  ___clang_call_terminate($507);
  // unreachable;
 } else {
  ___resumeException($$9|0);
  // unreachable;
 }
}
function __ZNSt3__23mapINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN5osgDB9IntLookupENS_4lessIS6_EENS4_INS_4pairIKS6_S8_EEEEEixERSC_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$014 = 0, $$pre$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = (__ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN5osgDB9IntLookupEEENS_19__map_value_compareIS7_SA_NS_4lessIS7_EELb1EEENS5_ISA_EEE12__find_equalIS7_EERPNS_16__tree_node_baseIPvEERPNS_15__tree_end_nodeISL_EERKT_($0,$2,$1)|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if (!($5)) {
  $$014 = $4;
  $31 = ((($$014)) + 28|0);
  STACKTOP = sp;return ($31|0);
 }
 $6 = (__Znwj(52)|0);
 $7 = ((($6)) + 16|0);
 __THREW__ = 0;
 invoke_vii(3457,($7|0),($1|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $10 = ___cxa_find_matching_catch_2()|0;
  $11 = tempRet0;
  __ZdlPv($6);
  ___resumeException($10|0);
  // unreachable;
 }
 $12 = ((($6)) + 28|0);
 $13 = ((($6)) + 32|0);
 HEAP32[$13>>2] = 0;
 $14 = ((($6)) + 36|0);
 HEAP32[$14>>2] = 0;
 HEAP32[$12>>2] = $13;
 $15 = ((($6)) + 44|0);
 HEAP32[$15>>2] = 0;
 $16 = ((($6)) + 48|0);
 HEAP32[$16>>2] = 0;
 $17 = ((($6)) + 40|0);
 HEAP32[$17>>2] = $15;
 $18 = HEAP32[$2>>2]|0;
 HEAP32[$6>>2] = 0;
 $19 = ((($6)) + 4|0);
 HEAP32[$19>>2] = 0;
 $20 = ((($6)) + 8|0);
 HEAP32[$20>>2] = $18;
 HEAP32[$3>>2] = $6;
 $21 = HEAP32[$0>>2]|0;
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0|0);
 if ($23) {
  $27 = $6;
 } else {
  $24 = $22;
  HEAP32[$0>>2] = $24;
  $$pre$i = HEAP32[$3>>2]|0;
  $27 = $$pre$i;
 }
 $25 = ((($0)) + 4|0);
 $26 = HEAP32[$25>>2]|0;
 __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($26,$27);
 $28 = ((($0)) + 8|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (($29) + 1)|0;
 HEAP32[$28>>2] = $30;
 $$014 = $6;
 $31 = ((($$014)) + 28|0);
 STACKTOP = sp;return ($31|0);
}
function __ZN5osgDB9IntLookup3addEPKci($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$i$i = 0, $$0$i$i11 = 0, $$0$ph$i$i = 0, $$0$ph$i$i8 = 0, $$0$ph$lcssa$i$i$i = 0, $$0$ph13$i$i$i = 0, $$014$i = 0, $$014$i20 = 0, $$016$i$i = 0, $$017$i$i = 0, $$024$i$i = 0, $$024$i$i10 = 0, $$025$i$i = 0, $$025$i$i13 = 0, $$025$i53$i = 0, $$025$i53$i15 = 0, $$037$i = 0, $$037$i12 = 0, $$03752$i = 0, $$03752$i16 = 0;
 var $$07$ph12$i$i$i = 0, $$0710$i$i$i = 0, $$in$i$i = 0, $$in$i$i7 = 0, $$pr = 0, $$pr$pre = 0, $$pre$i$i = 0, $$pre$i$i18 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp + 12|0;
 $4 = sp;
 $5 = ((($0)) + 12|0);
 $6 = ((($0)) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 do {
  if ($8) {
   $142 = 0;
   label = 39;
  } else {
   $$0$ph13$i$i$i = $6;$$07$ph12$i$i$i = $7;
   L2: while(1) {
    $$0710$i$i$i = $$07$ph12$i$i$i;
    while(1) {
     $9 = ((($$0710$i$i$i)) + 16|0);
     $10 = HEAP32[$9>>2]|0;
     $11 = ($10|0)<($2|0);
     if (!($11)) {
      break;
     }
     $14 = ((($$0710$i$i$i)) + 4|0);
     $15 = HEAP32[$14>>2]|0;
     $16 = ($15|0)==(0|0);
     if ($16) {
      $$0$ph$lcssa$i$i$i = $$0$ph13$i$i$i;
      break L2;
     } else {
      $$0710$i$i$i = $15;
     }
    }
    $12 = HEAP32[$$0710$i$i$i>>2]|0;
    $13 = ($12|0)==(0|0);
    if ($13) {
     $$0$ph$lcssa$i$i$i = $$0710$i$i$i;
     break;
    } else {
     $$0$ph13$i$i$i = $$0710$i$i$i;$$07$ph12$i$i$i = $12;
    }
   }
   $17 = ($$0$ph$lcssa$i$i$i|0)==($6|0);
   do {
    if ($17) {
     $$pr = $7;
    } else {
     $18 = ((($$0$ph$lcssa$i$i$i)) + 16|0);
     $19 = HEAP32[$18>>2]|0;
     $20 = ($19|0)>($2|0);
     if ($20) {
      $$pr = $7;
     } else {
      $21 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
      $22 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($21,171821,21)|0);
      $23 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi($22,$2)|0);
      $24 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($23,171843,18)|0);
      $25 = HEAP32[$6>>2]|0;
      $26 = ($25|0)==(0|0);
      do {
       if ($26) {
        $$025$i$i = $6;$$037$i = $6;$37 = $25;
        label = 19;
       } else {
        $27 = ((($0)) + 16|0);
        $$0$i$i = $27;$$024$i$i = $25;$143 = $25;
        while(1) {
         $28 = ((($$024$i$i)) + 16|0);
         $29 = HEAP32[$28>>2]|0;
         $30 = ($29|0)>($2|0);
         if ($30) {
          $31 = HEAP32[$$024$i$i>>2]|0;
          $32 = ($31|0)==(0|0);
          if ($32) {
           label = 13;
           break;
          } else {
           $$0$ph$i$i = $$024$i$i;$$in$i$i = $31;
          }
         } else {
          $33 = ($29|0)<($2|0);
          if (!($33)) {
           label = 17;
           break;
          }
          $34 = ((($$024$i$i)) + 4|0);
          $35 = HEAP32[$34>>2]|0;
          $36 = ($35|0)==(0|0);
          if ($36) {
           label = 16;
           break;
          } else {
           $$0$ph$i$i = $34;$$in$i$i = $35;
          }
         }
         $$0$i$i = $$0$ph$i$i;$$024$i$i = $$in$i$i;$143 = $$in$i$i;
        }
        if ((label|0) == 13) {
         $$025$i53$i = $$024$i$i;$$03752$i = $$024$i$i;
         label = 20;
         break;
        }
        else if ((label|0) == 16) {
         $$025$i53$i = $34;$$03752$i = $$024$i$i;
         label = 20;
         break;
        }
        else if ((label|0) == 17) {
         $$025$i$i = $$0$i$i;$$037$i = $$024$i$i;$37 = $143;
         label = 19;
         break;
        }
       }
      } while(0);
      if ((label|0) == 19) {
       $38 = ($37|0)==(0|0);
       if ($38) {
        $$025$i53$i = $$025$i$i;$$03752$i = $$037$i;
        label = 20;
       } else {
        $$014$i = $37;
       }
      }
      if ((label|0) == 20) {
       $39 = (__Znwj(32)|0);
       $40 = ((($39)) + 16|0);
       HEAP32[$40>>2] = $2;
       $41 = ((($39)) + 20|0);
       ;HEAP32[$41>>2]=0|0;HEAP32[$41+4>>2]=0|0;HEAP32[$41+8>>2]=0|0;
       HEAP32[$39>>2] = 0;
       $42 = ((($39)) + 4|0);
       HEAP32[$42>>2] = 0;
       $43 = ((($39)) + 8|0);
       HEAP32[$43>>2] = $$03752$i;
       HEAP32[$$025$i53$i>>2] = $39;
       $44 = HEAP32[$5>>2]|0;
       $45 = HEAP32[$44>>2]|0;
       $46 = ($45|0)==(0|0);
       if ($46) {
        $50 = $39;
       } else {
        $47 = $45;
        HEAP32[$5>>2] = $47;
        $$pre$i$i = HEAP32[$$025$i53$i>>2]|0;
        $50 = $$pre$i$i;
       }
       $48 = ((($0)) + 16|0);
       $49 = HEAP32[$48>>2]|0;
       __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($49,$50);
       $51 = ((($0)) + 20|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 1)|0;
       HEAP32[$51>>2] = $53;
       $$014$i = $39;
      }
      $54 = ((($$014$i)) + 20|0);
      $55 = ((($54)) + 11|0);
      $56 = HEAP8[$55>>0]|0;
      $57 = ($56<<24>>24)<(0);
      $58 = HEAP32[$54>>2]|0;
      $59 = $57 ? $58 : $54;
      $60 = ((($$014$i)) + 24|0);
      $61 = HEAP32[$60>>2]|0;
      $62 = $56&255;
      $63 = $57 ? $61 : $62;
      $64 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($24,$59,$63)|0);
      $65 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($64,171887,17)|0);
      $66 = (_strlen($1)|0);
      $67 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($65,$1,$66)|0);
      $68 = HEAP32[$67>>2]|0;
      $69 = ((($68)) + -12|0);
      $70 = HEAP32[$69>>2]|0;
      $71 = (($67) + ($70)|0);
      __ZNKSt3__28ios_base6getlocEv($3,$71);
      __THREW__ = 0;
      $72 = (invoke_iii(3255,($3|0),(215188|0))|0);
      $73 = __THREW__; __THREW__ = 0;
      $74 = $73&1;
      if (!($74)) {
       $75 = HEAP32[$72>>2]|0;
       $76 = ((($75)) + 28|0);
       $77 = HEAP32[$76>>2]|0;
       __THREW__ = 0;
       $78 = (invoke_iii($77|0,($72|0),10)|0);
       $79 = __THREW__; __THREW__ = 0;
       $80 = $79&1;
       if (!($80)) {
        __ZNSt3__26localeD2Ev($3);
        (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($67,$78)|0);
        (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($67)|0);
        $$pr$pre = HEAP32[$6>>2]|0;
        $$pr = $$pr$pre;
        break;
       }
      }
      $81 = ___cxa_find_matching_catch_2()|0;
      $82 = tempRet0;
      __THREW__ = 0;
      invoke_vi(3263,($3|0));
      $83 = __THREW__; __THREW__ = 0;
      $84 = $83&1;
      if ($84) {
       $85 = ___cxa_find_matching_catch_3(0|0)|0;
       $86 = tempRet0;
       ___clang_call_terminate($85);
       // unreachable;
      } else {
       ___resumeException($81|0);
       // unreachable;
      }
     }
    }
   } while(0);
   $87 = ($$pr|0)==(0|0);
   if ($87) {
    $142 = $$pr;
    label = 39;
   } else {
    $88 = ((($0)) + 16|0);
    $$0$i$i11 = $88;$$024$i$i10 = $$pr;$144 = $$pr;
    while(1) {
     $89 = ((($$024$i$i10)) + 16|0);
     $90 = HEAP32[$89>>2]|0;
     $91 = ($90|0)>($2|0);
     if ($91) {
      $92 = HEAP32[$$024$i$i10>>2]|0;
      $93 = ($92|0)==(0|0);
      if ($93) {
       label = 34;
       break;
      } else {
       $$0$ph$i$i8 = $$024$i$i10;$$in$i$i7 = $92;
      }
     } else {
      $94 = ($90|0)<($2|0);
      if (!($94)) {
       label = 38;
       break;
      }
      $95 = ((($$024$i$i10)) + 4|0);
      $96 = HEAP32[$95>>2]|0;
      $97 = ($96|0)==(0|0);
      if ($97) {
       label = 37;
       break;
      } else {
       $$0$ph$i$i8 = $95;$$in$i$i7 = $96;
      }
     }
     $$0$i$i11 = $$0$ph$i$i8;$$024$i$i10 = $$in$i$i7;$144 = $$in$i$i7;
    }
    if ((label|0) == 34) {
     $$025$i53$i15 = $$024$i$i10;$$03752$i16 = $$024$i$i10;
     label = 41;
     break;
    }
    else if ((label|0) == 37) {
     $$025$i53$i15 = $95;$$03752$i16 = $$024$i$i10;
     label = 41;
     break;
    }
    else if ((label|0) == 38) {
     $$025$i$i13 = $$0$i$i11;$$037$i12 = $$024$i$i10;$98 = $144;
     label = 40;
     break;
    }
   }
  }
 } while(0);
 if ((label|0) == 39) {
  $$025$i$i13 = $6;$$037$i12 = $6;$98 = $142;
  label = 40;
 }
 if ((label|0) == 40) {
  $99 = ($98|0)==(0|0);
  if ($99) {
   $$025$i53$i15 = $$025$i$i13;$$03752$i16 = $$037$i12;
   label = 41;
  } else {
   $$014$i20 = $98;
  }
 }
 if ((label|0) == 41) {
  $100 = (__Znwj(32)|0);
  $101 = ((($100)) + 16|0);
  HEAP32[$101>>2] = $2;
  $102 = ((($100)) + 20|0);
  ;HEAP32[$102>>2]=0|0;HEAP32[$102+4>>2]=0|0;HEAP32[$102+8>>2]=0|0;
  HEAP32[$100>>2] = 0;
  $103 = ((($100)) + 4|0);
  HEAP32[$103>>2] = 0;
  $104 = ((($100)) + 8|0);
  HEAP32[$104>>2] = $$03752$i16;
  HEAP32[$$025$i53$i15>>2] = $100;
  $105 = HEAP32[$5>>2]|0;
  $106 = HEAP32[$105>>2]|0;
  $107 = ($106|0)==(0|0);
  if ($107) {
   $111 = $100;
  } else {
   $108 = $106;
   HEAP32[$5>>2] = $108;
   $$pre$i$i18 = HEAP32[$$025$i53$i15>>2]|0;
   $111 = $$pre$i$i18;
  }
  $109 = ((($0)) + 16|0);
  $110 = HEAP32[$109>>2]|0;
  __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($110,$111);
  $112 = ((($0)) + 20|0);
  $113 = HEAP32[$112>>2]|0;
  $114 = (($113) + 1)|0;
  HEAP32[$112>>2] = $114;
  $$014$i20 = $100;
 }
 $115 = ((($$014$i20)) + 20|0);
 (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($115,$1)|0);
 ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;
 $116 = (_strlen($1)|0);
 $117 = ($116>>>0)>(4294967279);
 if ($117) {
  __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv($4);
  // unreachable;
 }
 $118 = ($116>>>0)<(11);
 if ($118) {
  $125 = $116&255;
  $126 = ((($4)) + 11|0);
  HEAP8[$126>>0] = $125;
  $127 = ($116|0)==(0);
  if ($127) {
   $$017$i$i = $4;
  } else {
   $$016$i$i = $4;
   label = 49;
  }
 } else {
  $119 = (($116) + 16)|0;
  $120 = $119 & -16;
  $121 = (__Znwj($120)|0);
  HEAP32[$4>>2] = $121;
  $122 = $120 | -2147483648;
  $123 = ((($4)) + 8|0);
  HEAP32[$123>>2] = $122;
  $124 = ((($4)) + 4|0);
  HEAP32[$124>>2] = $116;
  $$016$i$i = $121;
  label = 49;
 }
 if ((label|0) == 49) {
  _memcpy(($$016$i$i|0),($1|0),($116|0))|0;
  $$017$i$i = $$016$i$i;
 }
 $128 = (($$017$i$i) + ($116)|0);
 HEAP8[$128>>0] = 0;
 __THREW__ = 0;
 $129 = (invoke_iii(4226,($0|0),($4|0))|0);
 $130 = __THREW__; __THREW__ = 0;
 $131 = $130&1;
 if ($131) {
  $136 = ___cxa_find_matching_catch_2()|0;
  $137 = tempRet0;
  $138 = ((($4)) + 11|0);
  $139 = HEAP8[$138>>0]|0;
  $140 = ($139<<24>>24)<(0);
  if (!($140)) {
   ___resumeException($136|0);
   // unreachable;
  }
  $141 = HEAP32[$4>>2]|0;
  __ZdlPv($141);
  ___resumeException($136|0);
  // unreachable;
 } else {
  HEAP32[$129>>2] = $2;
  $132 = ((($4)) + 11|0);
  $133 = HEAP8[$132>>0]|0;
  $134 = ($133<<24>>24)<(0);
  if (!($134)) {
   STACKTOP = sp;return;
  }
  $135 = HEAP32[$4>>2]|0;
  __ZdlPv($135);
  STACKTOP = sp;return;
 }
}
function __ZN5osgDB9IntLookup4add2EPKcS2_i($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $$0$i$i = 0, $$0$i$i15 = 0, $$0$ph$i$i = 0, $$0$ph$i$i12 = 0, $$0$ph$lcssa$i$i$i = 0, $$0$ph13$i$i$i = 0, $$014$i = 0, $$014$i24 = 0, $$016$i$i = 0, $$016$i$i28 = 0, $$017$i$i = 0, $$017$i$i29 = 0, $$024$i$i = 0, $$024$i$i14 = 0, $$025$i$i = 0, $$025$i$i17 = 0, $$025$i53$i = 0, $$025$i53$i19 = 0, $$037$i = 0;
 var $$037$i16 = 0, $$03752$i = 0, $$03752$i20 = 0, $$07 = 0, $$07$ph12$i$i$i = 0, $$0710$i$i$i = 0, $$in$i$i = 0, $$in$i$i11 = 0, $$pr = 0, $$pr$pre = 0, $$pre$i$i = 0, $$pre$i$i22 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0;
 var $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0;
 var $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $4 = sp + 24|0;
 $5 = sp + 12|0;
 $6 = sp;
 $7 = ((($0)) + 12|0);
 $8 = ((($0)) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 do {
  if ($10) {
   $173 = 0;
   label = 39;
  } else {
   $$0$ph13$i$i$i = $8;$$07$ph12$i$i$i = $9;
   L2: while(1) {
    $$0710$i$i$i = $$07$ph12$i$i$i;
    while(1) {
     $11 = ((($$0710$i$i$i)) + 16|0);
     $12 = HEAP32[$11>>2]|0;
     $13 = ($12|0)<($3|0);
     if (!($13)) {
      break;
     }
     $16 = ((($$0710$i$i$i)) + 4|0);
     $17 = HEAP32[$16>>2]|0;
     $18 = ($17|0)==(0|0);
     if ($18) {
      $$0$ph$lcssa$i$i$i = $$0$ph13$i$i$i;
      break L2;
     } else {
      $$0710$i$i$i = $17;
     }
    }
    $14 = HEAP32[$$0710$i$i$i>>2]|0;
    $15 = ($14|0)==(0|0);
    if ($15) {
     $$0$ph$lcssa$i$i$i = $$0710$i$i$i;
     break;
    } else {
     $$0$ph13$i$i$i = $$0710$i$i$i;$$07$ph12$i$i$i = $14;
    }
   }
   $19 = ($$0$ph$lcssa$i$i$i|0)==($8|0);
   do {
    if ($19) {
     $$pr = $9;
    } else {
     $20 = ((($$0$ph$lcssa$i$i$i)) + 16|0);
     $21 = HEAP32[$20>>2]|0;
     $22 = ($21|0)>($3|0);
     if ($22) {
      $$pr = $9;
     } else {
      $23 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
      $24 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($23,171821,21)|0);
      $25 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi($24,$3)|0);
      $26 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($25,171843,18)|0);
      $27 = HEAP32[$8>>2]|0;
      $28 = ($27|0)==(0|0);
      do {
       if ($28) {
        $$025$i$i = $8;$$037$i = $8;$39 = $27;
        label = 19;
       } else {
        $29 = ((($0)) + 16|0);
        $$0$i$i = $29;$$024$i$i = $27;$174 = $27;
        while(1) {
         $30 = ((($$024$i$i)) + 16|0);
         $31 = HEAP32[$30>>2]|0;
         $32 = ($31|0)>($3|0);
         if ($32) {
          $33 = HEAP32[$$024$i$i>>2]|0;
          $34 = ($33|0)==(0|0);
          if ($34) {
           label = 13;
           break;
          } else {
           $$0$ph$i$i = $$024$i$i;$$in$i$i = $33;
          }
         } else {
          $35 = ($31|0)<($3|0);
          if (!($35)) {
           label = 17;
           break;
          }
          $36 = ((($$024$i$i)) + 4|0);
          $37 = HEAP32[$36>>2]|0;
          $38 = ($37|0)==(0|0);
          if ($38) {
           label = 16;
           break;
          } else {
           $$0$ph$i$i = $36;$$in$i$i = $37;
          }
         }
         $$0$i$i = $$0$ph$i$i;$$024$i$i = $$in$i$i;$174 = $$in$i$i;
        }
        if ((label|0) == 13) {
         $$025$i53$i = $$024$i$i;$$03752$i = $$024$i$i;
         label = 20;
         break;
        }
        else if ((label|0) == 16) {
         $$025$i53$i = $36;$$03752$i = $$024$i$i;
         label = 20;
         break;
        }
        else if ((label|0) == 17) {
         $$025$i$i = $$0$i$i;$$037$i = $$024$i$i;$39 = $174;
         label = 19;
         break;
        }
       }
      } while(0);
      if ((label|0) == 19) {
       $40 = ($39|0)==(0|0);
       if ($40) {
        $$025$i53$i = $$025$i$i;$$03752$i = $$037$i;
        label = 20;
       } else {
        $$014$i = $39;
       }
      }
      if ((label|0) == 20) {
       $41 = (__Znwj(32)|0);
       $42 = ((($41)) + 16|0);
       HEAP32[$42>>2] = $3;
       $43 = ((($41)) + 20|0);
       ;HEAP32[$43>>2]=0|0;HEAP32[$43+4>>2]=0|0;HEAP32[$43+8>>2]=0|0;
       HEAP32[$41>>2] = 0;
       $44 = ((($41)) + 4|0);
       HEAP32[$44>>2] = 0;
       $45 = ((($41)) + 8|0);
       HEAP32[$45>>2] = $$03752$i;
       HEAP32[$$025$i53$i>>2] = $41;
       $46 = HEAP32[$7>>2]|0;
       $47 = HEAP32[$46>>2]|0;
       $48 = ($47|0)==(0|0);
       if ($48) {
        $52 = $41;
       } else {
        $49 = $47;
        HEAP32[$7>>2] = $49;
        $$pre$i$i = HEAP32[$$025$i53$i>>2]|0;
        $52 = $$pre$i$i;
       }
       $50 = ((($0)) + 16|0);
       $51 = HEAP32[$50>>2]|0;
       __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($51,$52);
       $53 = ((($0)) + 20|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = (($54) + 1)|0;
       HEAP32[$53>>2] = $55;
       $$014$i = $41;
      }
      $56 = ((($$014$i)) + 20|0);
      $57 = ((($56)) + 11|0);
      $58 = HEAP8[$57>>0]|0;
      $59 = ($58<<24>>24)<(0);
      $60 = HEAP32[$56>>2]|0;
      $61 = $59 ? $60 : $56;
      $62 = ((($$014$i)) + 24|0);
      $63 = HEAP32[$62>>2]|0;
      $64 = $58&255;
      $65 = $59 ? $63 : $64;
      $66 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($26,$61,$65)|0);
      $67 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($66,171862,18)|0);
      $68 = (_strlen($1)|0);
      $69 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($67,$1,$68)|0);
      $70 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($69,171881,5)|0);
      $71 = (_strlen($2)|0);
      $72 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($70,$2,$71)|0);
      $73 = HEAP32[$72>>2]|0;
      $74 = ((($73)) + -12|0);
      $75 = HEAP32[$74>>2]|0;
      $76 = (($72) + ($75)|0);
      __ZNKSt3__28ios_base6getlocEv($4,$76);
      __THREW__ = 0;
      $77 = (invoke_iii(3255,($4|0),(215188|0))|0);
      $78 = __THREW__; __THREW__ = 0;
      $79 = $78&1;
      if (!($79)) {
       $80 = HEAP32[$77>>2]|0;
       $81 = ((($80)) + 28|0);
       $82 = HEAP32[$81>>2]|0;
       __THREW__ = 0;
       $83 = (invoke_iii($82|0,($77|0),10)|0);
       $84 = __THREW__; __THREW__ = 0;
       $85 = $84&1;
       if (!($85)) {
        __ZNSt3__26localeD2Ev($4);
        (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($72,$83)|0);
        (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($72)|0);
        $$pr$pre = HEAP32[$8>>2]|0;
        $$pr = $$pr$pre;
        break;
       }
      }
      $86 = ___cxa_find_matching_catch_2()|0;
      $87 = tempRet0;
      __THREW__ = 0;
      invoke_vi(3263,($4|0));
      $88 = __THREW__; __THREW__ = 0;
      $89 = $88&1;
      if ($89) {
       $90 = ___cxa_find_matching_catch_3(0|0)|0;
       $91 = tempRet0;
       ___clang_call_terminate($90);
       // unreachable;
      } else {
       ___resumeException($86|0);
       // unreachable;
      }
     }
    }
   } while(0);
   $92 = ($$pr|0)==(0|0);
   if ($92) {
    $173 = $$pr;
    label = 39;
   } else {
    $93 = ((($0)) + 16|0);
    $$0$i$i15 = $93;$$024$i$i14 = $$pr;$175 = $$pr;
    while(1) {
     $94 = ((($$024$i$i14)) + 16|0);
     $95 = HEAP32[$94>>2]|0;
     $96 = ($95|0)>($3|0);
     if ($96) {
      $97 = HEAP32[$$024$i$i14>>2]|0;
      $98 = ($97|0)==(0|0);
      if ($98) {
       label = 34;
       break;
      } else {
       $$0$ph$i$i12 = $$024$i$i14;$$in$i$i11 = $97;
      }
     } else {
      $99 = ($95|0)<($3|0);
      if (!($99)) {
       label = 38;
       break;
      }
      $100 = ((($$024$i$i14)) + 4|0);
      $101 = HEAP32[$100>>2]|0;
      $102 = ($101|0)==(0|0);
      if ($102) {
       label = 37;
       break;
      } else {
       $$0$ph$i$i12 = $100;$$in$i$i11 = $101;
      }
     }
     $$0$i$i15 = $$0$ph$i$i12;$$024$i$i14 = $$in$i$i11;$175 = $$in$i$i11;
    }
    if ((label|0) == 34) {
     $$025$i53$i19 = $$024$i$i14;$$03752$i20 = $$024$i$i14;
     label = 41;
     break;
    }
    else if ((label|0) == 37) {
     $$025$i53$i19 = $100;$$03752$i20 = $$024$i$i14;
     label = 41;
     break;
    }
    else if ((label|0) == 38) {
     $$025$i$i17 = $$0$i$i15;$$037$i16 = $$024$i$i14;$103 = $175;
     label = 40;
     break;
    }
   }
  }
 } while(0);
 if ((label|0) == 39) {
  $$025$i$i17 = $8;$$037$i16 = $8;$103 = $173;
  label = 40;
 }
 if ((label|0) == 40) {
  $104 = ($103|0)==(0|0);
  if ($104) {
   $$025$i53$i19 = $$025$i$i17;$$03752$i20 = $$037$i16;
   label = 41;
  } else {
   $$014$i24 = $103;
  }
 }
 if ((label|0) == 41) {
  $105 = (__Znwj(32)|0);
  $106 = ((($105)) + 16|0);
  HEAP32[$106>>2] = $3;
  $107 = ((($105)) + 20|0);
  ;HEAP32[$107>>2]=0|0;HEAP32[$107+4>>2]=0|0;HEAP32[$107+8>>2]=0|0;
  HEAP32[$105>>2] = 0;
  $108 = ((($105)) + 4|0);
  HEAP32[$108>>2] = 0;
  $109 = ((($105)) + 8|0);
  HEAP32[$109>>2] = $$03752$i20;
  HEAP32[$$025$i53$i19>>2] = $105;
  $110 = HEAP32[$7>>2]|0;
  $111 = HEAP32[$110>>2]|0;
  $112 = ($111|0)==(0|0);
  if ($112) {
   $116 = $105;
  } else {
   $113 = $111;
   HEAP32[$7>>2] = $113;
   $$pre$i$i22 = HEAP32[$$025$i53$i19>>2]|0;
   $116 = $$pre$i$i22;
  }
  $114 = ((($0)) + 16|0);
  $115 = HEAP32[$114>>2]|0;
  __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($115,$116);
  $117 = ((($0)) + 20|0);
  $118 = HEAP32[$117>>2]|0;
  $119 = (($118) + 1)|0;
  HEAP32[$117>>2] = $119;
  $$014$i24 = $105;
 }
 $120 = ((($$014$i24)) + 20|0);
 (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($120,$2)|0);
 ;HEAP32[$5>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;
 $121 = (_strlen($2)|0);
 $122 = ($121>>>0)>(4294967279);
 if ($122) {
  __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv($5);
  // unreachable;
 }
 $123 = ($121>>>0)<(11);
 if ($123) {
  $130 = $121&255;
  $131 = ((($5)) + 11|0);
  HEAP8[$131>>0] = $130;
  $132 = ($121|0)==(0);
  if ($132) {
   $$017$i$i = $5;
  } else {
   $$016$i$i = $5;
   label = 49;
  }
 } else {
  $124 = (($121) + 16)|0;
  $125 = $124 & -16;
  $126 = (__Znwj($125)|0);
  HEAP32[$5>>2] = $126;
  $127 = $125 | -2147483648;
  $128 = ((($5)) + 8|0);
  HEAP32[$128>>2] = $127;
  $129 = ((($5)) + 4|0);
  HEAP32[$129>>2] = $121;
  $$016$i$i = $126;
  label = 49;
 }
 if ((label|0) == 49) {
  _memcpy(($$016$i$i|0),($2|0),($121|0))|0;
  $$017$i$i = $$016$i$i;
 }
 $133 = (($$017$i$i) + ($121)|0);
 HEAP8[$133>>0] = 0;
 __THREW__ = 0;
 $134 = (invoke_iii(4226,($0|0),($5|0))|0);
 $135 = __THREW__; __THREW__ = 0;
 $136 = $135&1;
 if ($136) {
  $161 = ___cxa_find_matching_catch_2()|0;
  $162 = tempRet0;
  $163 = ((($5)) + 11|0);
  $164 = HEAP8[$163>>0]|0;
  $165 = ($164<<24>>24)<(0);
  if ($165) {
   $166 = HEAP32[$5>>2]|0;
   __ZdlPv($166);
  }
  $$0 = $162;$$07 = $161;
  ___resumeException($$07|0);
  // unreachable;
 }
 HEAP32[$134>>2] = $3;
 $137 = ((($5)) + 11|0);
 $138 = HEAP8[$137>>0]|0;
 $139 = ($138<<24>>24)<(0);
 if ($139) {
  $140 = HEAP32[$5>>2]|0;
  __ZdlPv($140);
 }
 ;HEAP32[$6>>2]=0|0;HEAP32[$6+4>>2]=0|0;HEAP32[$6+8>>2]=0|0;
 $141 = (_strlen($1)|0);
 $142 = ($141>>>0)>(4294967279);
 if ($142) {
  __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv($6);
  // unreachable;
 }
 $143 = ($141>>>0)<(11);
 if ($143) {
  $150 = $141&255;
  $151 = ((($6)) + 11|0);
  HEAP8[$151>>0] = $150;
  $152 = ($141|0)==(0);
  if ($152) {
   $$017$i$i29 = $6;
  } else {
   $$016$i$i28 = $6;
   label = 58;
  }
 } else {
  $144 = (($141) + 16)|0;
  $145 = $144 & -16;
  $146 = (__Znwj($145)|0);
  HEAP32[$6>>2] = $146;
  $147 = $145 | -2147483648;
  $148 = ((($6)) + 8|0);
  HEAP32[$148>>2] = $147;
  $149 = ((($6)) + 4|0);
  HEAP32[$149>>2] = $141;
  $$016$i$i28 = $146;
  label = 58;
 }
 if ((label|0) == 58) {
  _memcpy(($$016$i$i28|0),($1|0),($141|0))|0;
  $$017$i$i29 = $$016$i$i28;
 }
 $153 = (($$017$i$i29) + ($141)|0);
 HEAP8[$153>>0] = 0;
 __THREW__ = 0;
 $154 = (invoke_iii(4226,($0|0),($6|0))|0);
 $155 = __THREW__; __THREW__ = 0;
 $156 = $155&1;
 if ($156) {
  $167 = ___cxa_find_matching_catch_2()|0;
  $168 = tempRet0;
  $169 = ((($6)) + 11|0);
  $170 = HEAP8[$169>>0]|0;
  $171 = ($170<<24>>24)<(0);
  if ($171) {
   $172 = HEAP32[$6>>2]|0;
   __ZdlPv($172);
  }
  $$0 = $168;$$07 = $167;
  ___resumeException($$07|0);
  // unreachable;
 } else {
  HEAP32[$154>>2] = $3;
  $157 = ((($6)) + 11|0);
  $158 = HEAP8[$157>>0]|0;
  $159 = ($158<<24>>24)<(0);
  if (!($159)) {
   STACKTOP = sp;return;
  }
  $160 = HEAP32[$6>>2]|0;
  __ZdlPv($160);
  STACKTOP = sp;return;
 }
}
function __ZNSt3__23mapINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEiNS_4lessIS6_EENS4_INS_4pairIKS6_iEEEEEixERSA_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$014 = 0, $$pre$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = (__ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEiEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE12__find_equalIS7_EERPNS_16__tree_node_baseIPvEERPNS_15__tree_end_nodeISJ_EERKT_($0,$2,$1)|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if (!($5)) {
  $$014 = $4;
  $26 = ((($$014)) + 28|0);
  STACKTOP = sp;return ($26|0);
 }
 $6 = (__Znwj(32)|0);
 $7 = ((($6)) + 16|0);
 __THREW__ = 0;
 invoke_vii(3457,($7|0),($1|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $10 = ___cxa_find_matching_catch_2()|0;
  $11 = tempRet0;
  __ZdlPv($6);
  ___resumeException($10|0);
  // unreachable;
 }
 $12 = ((($6)) + 28|0);
 HEAP32[$12>>2] = 0;
 $13 = HEAP32[$2>>2]|0;
 HEAP32[$6>>2] = 0;
 $14 = ((($6)) + 4|0);
 HEAP32[$14>>2] = 0;
 $15 = ((($6)) + 8|0);
 HEAP32[$15>>2] = $13;
 HEAP32[$3>>2] = $6;
 $16 = HEAP32[$0>>2]|0;
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==(0|0);
 if ($18) {
  $22 = $6;
 } else {
  $19 = $17;
  HEAP32[$0>>2] = $19;
  $$pre$i = HEAP32[$3>>2]|0;
  $22 = $$pre$i;
 }
 $20 = ((($0)) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($21,$22);
 $23 = ((($0)) + 8|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (($24) + 1)|0;
 HEAP32[$23>>2] = $25;
 $$014 = $6;
 $26 = ((($$014)) + 28|0);
 STACKTOP = sp;return ($26|0);
}
function __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEiEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE12__find_equalIS7_EERPNS_16__tree_node_baseIPvEERPNS_15__tree_end_nodeISJ_EERKT_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$0$ph = 0, $$024 = 0, $$025 = 0, $$in = 0, $$sroa$speculated$i$i$i$i$i = 0, $$sroa$speculated$i$i$i$i$i26 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  HEAP32[$1>>2] = $3;
  $$025 = $3;
  return ($$025|0);
 }
 $6 = ((($0)) + 4|0);
 $7 = ((($2)) + 11|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = ($8<<24>>24)<(0);
 $10 = ((($2)) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $8&255;
 $13 = $9 ? $11 : $12;
 $14 = HEAP32[$2>>2]|0;
 $15 = $9 ? $14 : $2;
 $$0 = $6;$$024 = $4;
 while(1) {
  $16 = ((($$024)) + 16|0);
  $17 = ((($16)) + 11|0);
  $18 = HEAP8[$17>>0]|0;
  $19 = ($18<<24>>24)<(0);
  $20 = ((($$024)) + 20|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = $18&255;
  $23 = $19 ? $21 : $22;
  $24 = ($23>>>0)<($13>>>0);
  $$sroa$speculated$i$i$i$i$i26 = $24 ? $23 : $13;
  $25 = ($$sroa$speculated$i$i$i$i$i26|0)==(0);
  if ($25) {
   label = 6;
  } else {
   $26 = HEAP32[$16>>2]|0;
   $27 = $19 ? $26 : $16;
   $28 = (_memcmp($15,$27,$$sroa$speculated$i$i$i$i$i26)|0);
   $29 = ($28|0)==(0);
   if ($29) {
    label = 6;
   } else {
    $31 = ($28|0)<(0);
    if ($31) {
     label = 8;
    } else {
     label = 10;
    }
   }
  }
  if ((label|0) == 6) {
   label = 0;
   $30 = ($13>>>0)<($23>>>0);
   if ($30) {
    label = 8;
   } else {
    label = 10;
   }
  }
  if ((label|0) == 8) {
   label = 0;
   $32 = HEAP32[$$024>>2]|0;
   $33 = ($32|0)==(0|0);
   if ($33) {
    label = 9;
    break;
   } else {
    $$0$ph = $$024;$$in = $32;
   }
  }
  else if ((label|0) == 10) {
   label = 0;
   $34 = ($13>>>0)<($23>>>0);
   $$sroa$speculated$i$i$i$i$i = $34 ? $13 : $23;
   $35 = ($$sroa$speculated$i$i$i$i$i|0)==(0);
   if ($35) {
    label = 12;
   } else {
    $36 = HEAP32[$16>>2]|0;
    $37 = $19 ? $36 : $16;
    $38 = (_memcmp($37,$15,$$sroa$speculated$i$i$i$i$i)|0);
    $39 = ($38|0)==(0);
    if ($39) {
     label = 12;
    } else {
     $40 = ($38|0)<(0);
     if (!($40)) {
      label = 16;
      break;
     }
    }
   }
   if ((label|0) == 12) {
    label = 0;
    if (!($24)) {
     label = 16;
     break;
    }
   }
   $41 = ((($$024)) + 4|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = ($42|0)==(0|0);
   if ($43) {
    label = 15;
    break;
   } else {
    $$0$ph = $41;$$in = $42;
   }
  }
  $$0 = $$0$ph;$$024 = $$in;
 }
 if ((label|0) == 9) {
  HEAP32[$1>>2] = $$024;
  $$025 = $$024;
  return ($$025|0);
 }
 else if ((label|0) == 15) {
  HEAP32[$1>>2] = $$024;
  $$025 = $41;
  return ($$025|0);
 }
 else if ((label|0) == 16) {
  HEAP32[$1>>2] = $$024;
  $$025 = $$0;
  return ($$025|0);
 }
 return (0)|0;
}
function __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN5osgDB9IntLookupEEENS_19__map_value_compareIS7_SA_NS_4lessIS7_EELb1EEENS5_ISA_EEE12__find_equalIS7_EERPNS_16__tree_node_baseIPvEERPNS_15__tree_end_nodeISL_EERKT_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$0$ph = 0, $$024 = 0, $$025 = 0, $$in = 0, $$sroa$speculated$i$i$i$i$i = 0, $$sroa$speculated$i$i$i$i$i26 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  HEAP32[$1>>2] = $3;
  $$025 = $3;
  return ($$025|0);
 }
 $6 = ((($0)) + 4|0);
 $7 = ((($2)) + 11|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = ($8<<24>>24)<(0);
 $10 = ((($2)) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $8&255;
 $13 = $9 ? $11 : $12;
 $14 = HEAP32[$2>>2]|0;
 $15 = $9 ? $14 : $2;
 $$0 = $6;$$024 = $4;
 while(1) {
  $16 = ((($$024)) + 16|0);
  $17 = ((($16)) + 11|0);
  $18 = HEAP8[$17>>0]|0;
  $19 = ($18<<24>>24)<(0);
  $20 = ((($$024)) + 20|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = $18&255;
  $23 = $19 ? $21 : $22;
  $24 = ($23>>>0)<($13>>>0);
  $$sroa$speculated$i$i$i$i$i26 = $24 ? $23 : $13;
  $25 = ($$sroa$speculated$i$i$i$i$i26|0)==(0);
  if ($25) {
   label = 6;
  } else {
   $26 = HEAP32[$16>>2]|0;
   $27 = $19 ? $26 : $16;
   $28 = (_memcmp($15,$27,$$sroa$speculated$i$i$i$i$i26)|0);
   $29 = ($28|0)==(0);
   if ($29) {
    label = 6;
   } else {
    $31 = ($28|0)<(0);
    if ($31) {
     label = 8;
    } else {
     label = 10;
    }
   }
  }
  if ((label|0) == 6) {
   label = 0;
   $30 = ($13>>>0)<($23>>>0);
   if ($30) {
    label = 8;
   } else {
    label = 10;
   }
  }
  if ((label|0) == 8) {
   label = 0;
   $32 = HEAP32[$$024>>2]|0;
   $33 = ($32|0)==(0|0);
   if ($33) {
    label = 9;
    break;
   } else {
    $$0$ph = $$024;$$in = $32;
   }
  }
  else if ((label|0) == 10) {
   label = 0;
   $34 = ($13>>>0)<($23>>>0);
   $$sroa$speculated$i$i$i$i$i = $34 ? $13 : $23;
   $35 = ($$sroa$speculated$i$i$i$i$i|0)==(0);
   if ($35) {
    label = 12;
   } else {
    $36 = HEAP32[$16>>2]|0;
    $37 = $19 ? $36 : $16;
    $38 = (_memcmp($37,$15,$$sroa$speculated$i$i$i$i$i)|0);
    $39 = ($38|0)==(0);
    if ($39) {
     label = 12;
    } else {
     $40 = ($38|0)<(0);
     if (!($40)) {
      label = 16;
      break;
     }
    }
   }
   if ((label|0) == 12) {
    label = 0;
    if (!($24)) {
     label = 16;
     break;
    }
   }
   $41 = ((($$024)) + 4|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = ($42|0)==(0|0);
   if ($43) {
    label = 15;
    break;
   } else {
    $$0$ph = $41;$$in = $42;
   }
  }
  $$0 = $$0$ph;$$024 = $$in;
 }
 if ((label|0) == 9) {
  HEAP32[$1>>2] = $$024;
  $$025 = $$024;
  return ($$025|0);
 }
 else if ((label|0) == 15) {
  HEAP32[$1>>2] = $$024;
  $$025 = $41;
  return ($$025|0);
 }
 else if ((label|0) == 16) {
  HEAP32[$1>>2] = $$024;
  $$025 = $$0;
  return ($$025|0);
 }
 return (0)|0;
}
function __GLOBAL__sub_I_InputStream_cpp() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF32[52357] = 1.0;
 HEAPF32[(209432)>>2] = 0.0;
 HEAPF32[(209436)>>2] = 0.0;
 HEAPF32[52360] = 0.0;
 HEAPF32[(209444)>>2] = 1.0;
 HEAPF32[(209448)>>2] = 0.0;
 HEAPF32[52363] = 0.0;
 HEAPF32[(209456)>>2] = 0.0;
 HEAPF32[(209460)>>2] = 1.0;
 ;HEAP32[209464>>2]=0|0;HEAP32[209464+4>>2]=0|0;HEAP32[209464+8>>2]=0|0;
 (___cxa_atexit((3252|0),(209464|0),(___dso_handle|0))|0);
 return;
}
function __ZN5osgDB14DynamicLibraryD2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 HEAP32[$0>>2] = (75316);
 $2 = ((($0)) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 L1: do {
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_ii(3265,4)|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   L3: do {
    if ($7) {
     label = 16;
    } else {
     do {
      if ($5) {
       __THREW__ = 0;
       $8 = (invoke_ii(3266,4)|0);
       $9 = __THREW__; __THREW__ = 0;
       $10 = $9&1;
       if ($10) {
        label = 16;
        break L3;
       }
       __THREW__ = 0;
       $11 = (invoke_iiii(3267,($8|0),(171922|0),23)|0);
       $12 = __THREW__; __THREW__ = 0;
       $13 = $12&1;
       if ($13) {
        label = 16;
        break L3;
       }
       $14 = ((($0)) + 16|0);
       $15 = ((($14)) + 11|0);
       $16 = HEAP8[$15>>0]|0;
       $17 = ($16<<24>>24)<(0);
       $18 = HEAP32[$14>>2]|0;
       $19 = $17 ? $18 : $14;
       $20 = ((($0)) + 20|0);
       $21 = HEAP32[$20>>2]|0;
       $22 = $16&255;
       $23 = $17 ? $21 : $22;
       __THREW__ = 0;
       $24 = (invoke_iiii(3267,($11|0),($19|0),($23|0))|0);
       $25 = __THREW__; __THREW__ = 0;
       $26 = $25&1;
       if ($26) {
        label = 16;
        break L3;
       }
       $27 = HEAP32[$24>>2]|0;
       $28 = ((($27)) + -12|0);
       $29 = HEAP32[$28>>2]|0;
       $30 = (($24) + ($29)|0);
       __THREW__ = 0;
       invoke_vii(3257,($1|0),($30|0));
       $31 = __THREW__; __THREW__ = 0;
       $32 = $31&1;
       if ($32) {
        label = 16;
        break L3;
       }
       __THREW__ = 0;
       $33 = (invoke_iii(3255,($1|0),(215188|0))|0);
       $34 = __THREW__; __THREW__ = 0;
       $35 = $34&1;
       if (!($35)) {
        $36 = HEAP32[$33>>2]|0;
        $37 = ((($36)) + 28|0);
        $38 = HEAP32[$37>>2]|0;
        __THREW__ = 0;
        $39 = (invoke_iii($38|0,($33|0),10)|0);
        $40 = __THREW__; __THREW__ = 0;
        $41 = $40&1;
        if (!($41)) {
         __THREW__ = 0;
         invoke_vi(3263,($1|0));
         $48 = __THREW__; __THREW__ = 0;
         $49 = $48&1;
         if ($49) {
          label = 16;
          break L3;
         }
         __THREW__ = 0;
         (invoke_iii(3268,($24|0),($39|0))|0);
         $50 = __THREW__; __THREW__ = 0;
         $51 = $50&1;
         if ($51) {
          label = 16;
          break L3;
         }
         __THREW__ = 0;
         (invoke_ii(3269,($24|0))|0);
         $52 = __THREW__; __THREW__ = 0;
         $53 = $52&1;
         if ($53) {
          label = 16;
          break L3;
         } else {
          break;
         }
        }
       }
       $42 = ___cxa_find_matching_catch_2()|0;
       $43 = tempRet0;
       __THREW__ = 0;
       invoke_vi(3263,($1|0));
       $44 = __THREW__; __THREW__ = 0;
       $45 = $44&1;
       if ($45) {
        $46 = ___cxa_find_matching_catch_3(0|0)|0;
        $47 = tempRet0;
        ___clang_call_terminate($46);
        // unreachable;
       } else {
        $eh$lpad$body$index2Z2D = $43;$eh$lpad$body$indexZ2D = $42;
        break L3;
       }
      }
     } while(0);
     $68 = HEAP32[$2>>2]|0;
     __THREW__ = 0;
     (invoke_ii(4227,($68|0))|0);
     $69 = __THREW__; __THREW__ = 0;
     $70 = $69&1;
     if ($70) {
      label = 16;
     } else {
      break L1;
     }
    }
   } while(0);
   if ((label|0) == 16) {
    $54 = ___cxa_find_matching_catch_2()|0;
    $55 = tempRet0;
    $eh$lpad$body$index2Z2D = $55;$eh$lpad$body$indexZ2D = $54;
   }
   $56 = ((($0)) + 28|0);
   $57 = ((($56)) + 11|0);
   $58 = HEAP8[$57>>0]|0;
   $59 = ($58<<24>>24)<(0);
   if ($59) {
    $60 = HEAP32[$56>>2]|0;
    __ZdlPv($60);
   }
   $61 = ((($0)) + 16|0);
   $62 = ((($61)) + 11|0);
   $63 = HEAP8[$62>>0]|0;
   $64 = ($63<<24>>24)<(0);
   if ($64) {
    $65 = HEAP32[$61>>2]|0;
    __ZdlPv($65);
   }
   __THREW__ = 0;
   invoke_vi(712,($0|0));
   $66 = __THREW__; __THREW__ = 0;
   $67 = $66&1;
   if ($67) {
    $81 = ___cxa_find_matching_catch_3(0|0)|0;
    $82 = tempRet0;
    ___clang_call_terminate($81);
    // unreachable;
   } else {
    ___resumeException($eh$lpad$body$indexZ2D|0);
    // unreachable;
   }
  }
 } while(0);
 $71 = ((($0)) + 28|0);
 $72 = ((($71)) + 11|0);
 $73 = HEAP8[$72>>0]|0;
 $74 = ($73<<24>>24)<(0);
 if ($74) {
  $75 = HEAP32[$71>>2]|0;
  __ZdlPv($75);
 }
 $76 = ((($0)) + 16|0);
 $77 = ((($76)) + 11|0);
 $78 = HEAP8[$77>>0]|0;
 $79 = ($78<<24>>24)<(0);
 if (!($79)) {
  __ZN3osg10ReferencedD2Ev($0);
  STACKTOP = sp;return;
 }
 $80 = HEAP32[$76>>2]|0;
 __ZdlPv($80);
 __ZN3osg10ReferencedD2Ev($0);
 STACKTOP = sp;return;
}
function __ZN5osgDB14DynamicLibraryD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(2712,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZN5osgDB14DynamicLibraryC2ERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEPv($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 __ZN3osg10ReferencedC2Ev($0);
 HEAP32[$0>>2] = (75316);
 $4 = ((($0)) + 16|0);
 $5 = ((($0)) + 28|0);
 ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;HEAP32[$4+12>>2]=0|0;HEAP32[$4+16>>2]=0|0;HEAP32[$4+20>>2]=0|0;
 __THREW__ = 0;
 (invoke_iii(3477,($4|0),($1|0))|0);
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 do {
  if ($7) {
   label = 16;
  } else {
   $8 = ((($0)) + 12|0);
   HEAP32[$8>>2] = $2;
   __THREW__ = 0;
   $9 = (invoke_ii(3265,4)|0);
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if ($11) {
    label = 16;
   } else {
    if (!($9)) {
     STACKTOP = sp;return;
    }
    __THREW__ = 0;
    $12 = (invoke_ii(3266,4)|0);
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     label = 16;
    } else {
     __THREW__ = 0;
     $15 = (invoke_iiii(3267,($12|0),(171971|0),22)|0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      label = 16;
     } else {
      $18 = ((($4)) + 11|0);
      $19 = HEAP8[$18>>0]|0;
      $20 = ($19<<24>>24)<(0);
      $21 = HEAP32[$4>>2]|0;
      $22 = $20 ? $21 : $4;
      $23 = ((($0)) + 20|0);
      $24 = HEAP32[$23>>2]|0;
      $25 = $19&255;
      $26 = $20 ? $24 : $25;
      __THREW__ = 0;
      $27 = (invoke_iiii(3267,($15|0),($22|0),($26|0))|0);
      $28 = __THREW__; __THREW__ = 0;
      $29 = $28&1;
      if ($29) {
       label = 16;
      } else {
       $30 = HEAP32[$27>>2]|0;
       $31 = ((($30)) + -12|0);
       $32 = HEAP32[$31>>2]|0;
       $33 = (($27) + ($32)|0);
       __THREW__ = 0;
       invoke_vii(3257,($3|0),($33|0));
       $34 = __THREW__; __THREW__ = 0;
       $35 = $34&1;
       if ($35) {
        label = 16;
       } else {
        __THREW__ = 0;
        $36 = (invoke_iii(3255,($3|0),(215188|0))|0);
        $37 = __THREW__; __THREW__ = 0;
        $38 = $37&1;
        if (!($38)) {
         $39 = HEAP32[$36>>2]|0;
         $40 = ((($39)) + 28|0);
         $41 = HEAP32[$40>>2]|0;
         __THREW__ = 0;
         $42 = (invoke_iii($41|0,($36|0),10)|0);
         $43 = __THREW__; __THREW__ = 0;
         $44 = $43&1;
         if (!($44)) {
          __THREW__ = 0;
          invoke_vi(3263,($3|0));
          $45 = __THREW__; __THREW__ = 0;
          $46 = $45&1;
          if ($46) {
           label = 16;
           break;
          }
          __THREW__ = 0;
          (invoke_iii(3268,($27|0),($42|0))|0);
          $53 = __THREW__; __THREW__ = 0;
          $54 = $53&1;
          if ($54) {
           label = 16;
           break;
          }
          __THREW__ = 0;
          (invoke_ii(3269,($27|0))|0);
          $55 = __THREW__; __THREW__ = 0;
          $56 = $55&1;
          if ($56) {
           label = 16;
           break;
          }
          STACKTOP = sp;return;
         }
        }
        $47 = ___cxa_find_matching_catch_2()|0;
        $48 = tempRet0;
        __THREW__ = 0;
        invoke_vi(3263,($3|0));
        $49 = __THREW__; __THREW__ = 0;
        $50 = $49&1;
        if ($50) {
         $51 = ___cxa_find_matching_catch_3(0|0)|0;
         $52 = tempRet0;
         ___clang_call_terminate($51);
         // unreachable;
        } else {
         $eh$lpad$body$index2Z2D = $48;$eh$lpad$body$indexZ2D = $47;
         break;
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 16) {
  $57 = ___cxa_find_matching_catch_2()|0;
  $58 = tempRet0;
  $eh$lpad$body$index2Z2D = $58;$eh$lpad$body$indexZ2D = $57;
 }
 $59 = ((($5)) + 11|0);
 $60 = HEAP8[$59>>0]|0;
 $61 = ($60<<24>>24)<(0);
 if ($61) {
  $62 = HEAP32[$5>>2]|0;
  __ZdlPv($62);
 }
 $63 = ((($4)) + 11|0);
 $64 = HEAP8[$63>>0]|0;
 $65 = ($64<<24>>24)<(0);
 if ($65) {
  $66 = HEAP32[$4>>2]|0;
  __ZdlPv($66);
 }
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $67 = __THREW__; __THREW__ = 0;
 $68 = $67&1;
 if ($68) {
  $69 = ___cxa_find_matching_catch_3(0|0)|0;
  $70 = tempRet0;
  ___clang_call_terminate($69);
  // unreachable;
 } else {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
}
function __ZN5osgDB14DynamicLibrary11loadLibraryERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE($0) {
 $0 = $0|0;
 var $$0 = 0, $$010 = 0, $$011 = 0, $$012 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp + 12|0;
 $2 = sp;
 __ZN5osgDB15findLibraryFileERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEENS_15CaseSensitivityE($2,$0,0);
 $3 = ((($2)) + 11|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)<(0);
 $6 = ((($2)) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $4&255;
 $9 = $5 ? $7 : $8;
 $10 = ($9|0)==(0);
 if ($10) {
  __THREW__ = 0;
  $16 = (invoke_ii(4228,($0|0))|0);
  $17 = __THREW__; __THREW__ = 0;
  $18 = $17&1;
  if ($18) {
   label = 3;
  } else {
   $$011 = $16;
   label = 6;
  }
 } else {
  __THREW__ = 0;
  $11 = (invoke_ii(4228,($2|0))|0);
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if ($13) {
   label = 3;
  } else {
   $$011 = $11;
   label = 6;
  }
 }
 L4: do {
  if ((label|0) == 6) {
   $19 = ($$011|0)==(0|0);
   do {
    if ($19) {
     __THREW__ = 0;
     $27 = (invoke_ii(3265,4)|0);
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      label = 3;
      break L4;
     }
     if ($27) {
      __THREW__ = 0;
      $30 = (invoke_ii(3266,4)|0);
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if ($32) {
       label = 3;
       break L4;
      }
      __THREW__ = 0;
      $33 = (invoke_iiii(3267,($30|0),(171994|0),32)|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       label = 3;
       break L4;
      }
      $36 = ((($0)) + 11|0);
      $37 = HEAP8[$36>>0]|0;
      $38 = ($37<<24>>24)<(0);
      $39 = HEAP32[$0>>2]|0;
      $40 = $38 ? $39 : $0;
      $41 = ((($0)) + 4|0);
      $42 = HEAP32[$41>>2]|0;
      $43 = $37&255;
      $44 = $38 ? $42 : $43;
      __THREW__ = 0;
      $45 = (invoke_iiii(3267,($33|0),($40|0),($44|0))|0);
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       label = 3;
       break L4;
      }
      __THREW__ = 0;
      $48 = (invoke_iiii(3267,($45|0),(172027|0),1)|0);
      $49 = __THREW__; __THREW__ = 0;
      $50 = $49&1;
      if ($50) {
       label = 3;
       break L4;
      }
      $51 = HEAP32[$48>>2]|0;
      $52 = ((($51)) + -12|0);
      $53 = HEAP32[$52>>2]|0;
      $54 = (($48) + ($53)|0);
      __THREW__ = 0;
      invoke_vii(3257,($1|0),($54|0));
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 3;
       break L4;
      }
      __THREW__ = 0;
      $57 = (invoke_iii(3255,($1|0),(215188|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if (!($59)) {
       $60 = HEAP32[$57>>2]|0;
       $61 = ((($60)) + 28|0);
       $62 = HEAP32[$61>>2]|0;
       __THREW__ = 0;
       $63 = (invoke_iii($62|0,($57|0),10)|0);
       $64 = __THREW__; __THREW__ = 0;
       $65 = $64&1;
       if (!($65)) {
        __THREW__ = 0;
        invoke_vi(3263,($1|0));
        $72 = __THREW__; __THREW__ = 0;
        $73 = $72&1;
        if ($73) {
         label = 3;
         break L4;
        }
        __THREW__ = 0;
        (invoke_iii(3268,($48|0),($63|0))|0);
        $74 = __THREW__; __THREW__ = 0;
        $75 = $74&1;
        if ($75) {
         label = 3;
         break L4;
        }
        __THREW__ = 0;
        (invoke_ii(3269,($48|0))|0);
        $76 = __THREW__; __THREW__ = 0;
        $77 = $76&1;
        if ($77) {
         label = 3;
         break L4;
        } else {
         $$012 = 0;
         break;
        }
       }
      }
      $66 = ___cxa_find_matching_catch_2()|0;
      $67 = tempRet0;
      __THREW__ = 0;
      invoke_vi(3263,($1|0));
      $68 = __THREW__; __THREW__ = 0;
      $69 = $68&1;
      if ($69) {
       $70 = ___cxa_find_matching_catch_3(0|0)|0;
       $71 = tempRet0;
       ___clang_call_terminate($70);
       // unreachable;
      } else {
       $eh$lpad$body$index2Z2D = $67;$eh$lpad$body$indexZ2D = $66;
       label = 4;
       break L4;
      }
     } else {
      $$012 = 0;
     }
    } else {
     __THREW__ = 0;
     $20 = (invoke_ii(3276,40)|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      label = 3;
      break L4;
     }
     __THREW__ = 0;
     invoke_viii(4229,($20|0),($0|0),($$011|0));
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      $25 = ___cxa_find_matching_catch_2()|0;
      $26 = tempRet0;
      __ZdlPv($20);
      $$0 = $26;$$010 = $25;
      break L4;
     } else {
      $$012 = $20;
     }
    }
   } while(0);
   $78 = HEAP8[$3>>0]|0;
   $79 = ($78<<24>>24)<(0);
   if (!($79)) {
    STACKTOP = sp;return ($$012|0);
   }
   $80 = HEAP32[$2>>2]|0;
   __ZdlPv($80);
   STACKTOP = sp;return ($$012|0);
  }
 } while(0);
 if ((label|0) == 3) {
  $14 = ___cxa_find_matching_catch_2()|0;
  $15 = tempRet0;
  $eh$lpad$body$index2Z2D = $15;$eh$lpad$body$indexZ2D = $14;
  label = 4;
 }
 if ((label|0) == 4) {
  $$0 = $eh$lpad$body$index2Z2D;$$010 = $eh$lpad$body$indexZ2D;
 }
 $81 = HEAP8[$3>>0]|0;
 $82 = ($81<<24>>24)<(0);
 if (!($82)) {
  ___resumeException($$010|0);
  // unreachable;
 }
 $83 = HEAP32[$2>>2]|0;
 __ZdlPv($83);
 ___resumeException($$010|0);
 // unreachable;
 return (0)|0;
}
function __ZN5osgDB14DynamicLibrary16getLibraryHandleERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE($0) {
 $0 = $0|0;
 var $$0 = 0, $$011 = 0, $$02026$i62 = 0, $$02125$i63 = 0, $$027$i61 = 0, $$1 = 0, $$1$i = 0, $$112 = 0, $$pre = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0;
 var $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0;
 var $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0;
 var $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0;
 var $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0;
 var $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0;
 var $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index5Z2D = 0, $eh$lpad$body$indexZ2D = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(64|0);
 $1 = sp + 48|0;
 $2 = sp + 44|0;
 $3 = sp + 40|0;
 $4 = sp + 36|0;
 $5 = sp + 24|0;
 $6 = sp + 12|0;
 $7 = sp;
 ;HEAP32[$5>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;
 __THREW__ = 0;
 invoke_vii(4196,($6|0),($0|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 L1: do {
  if ($9) {
   $50 = ___cxa_find_matching_catch_2()|0;
   $51 = tempRet0;
   $$1 = $51;$$112 = $50;
  } else {
   $10 = ((($0)) + 11|0);
   $11 = HEAP8[$10>>0]|0;
   $12 = ($11<<24>>24)<(0);
   $13 = ((($0)) + 4|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = $11&255;
   $16 = $12 ? $14 : $15;
   $17 = ((($6)) + 11|0);
   $18 = HEAP8[$17>>0]|0;
   $19 = ($18<<24>>24)<(0);
   $20 = ((($6)) + 4|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = $18&255;
   $23 = $19 ? $21 : $22;
   $24 = ($16|0)==($23|0);
   L4: do {
    if ($24) {
     $25 = HEAP32[$0>>2]|0;
     $26 = $12 ? $25 : $0;
     $27 = HEAP32[$6>>2]|0;
     $28 = $19 ? $27 : $6;
     $29 = ($16|0)==(0);
     if ($12) {
      if ($29) {
       $$1$i = 1;
       break;
      }
      $34 = (_memcmp($26,$28,$16)|0);
      $phitmp$i = ($34|0)==(0);
      $$1$i = $phitmp$i;
      break;
     }
     if ($29) {
      $$1$i = 1;
     } else {
      $30 = $25;
      $31 = $30&255;
      $32 = HEAP8[$28>>0]|0;
      $33 = ($31<<24>>24)==($32<<24>>24);
      if ($33) {
       $$02026$i62 = $0;$$02125$i63 = $15;$$027$i61 = $28;
       while(1) {
        $35 = (($$02125$i63) + -1)|0;
        $36 = ((($$02026$i62)) + 1|0);
        $37 = ($35|0)==(0);
        if ($37) {
         $$1$i = 1;
         break L4;
        }
        $38 = ((($$027$i61)) + 1|0);
        $$pre = HEAP8[$36>>0]|0;
        $39 = HEAP8[$38>>0]|0;
        $40 = ($$pre<<24>>24)==($39<<24>>24);
        if ($40) {
         $$02026$i62 = $36;$$02125$i63 = $35;$$027$i61 = $38;
        } else {
         $$1$i = 0;
         break;
        }
       }
      } else {
       $$1$i = 0;
      }
     }
    } else {
     $$1$i = 0;
    }
   } while(0);
   if ($19) {
    $41 = HEAP32[$6>>2]|0;
    __ZdlPv($41);
   }
   L18: do {
    if ($$1$i) {
     __THREW__ = 0;
     invoke_viii(4173,($7|0),(172811|0),($0|0));
     $42 = __THREW__; __THREW__ = 0;
     $43 = $42&1;
     do {
      if ($43) {
       $52 = ___cxa_find_matching_catch_2()|0;
       $53 = tempRet0;
       $$0 = $53;$$011 = $52;
      } else {
       __THREW__ = 0;
       (invoke_iii(3477,($5|0),($7|0))|0);
       $44 = __THREW__; __THREW__ = 0;
       $45 = $44&1;
       if ($45) {
        $54 = ___cxa_find_matching_catch_2()|0;
        $55 = tempRet0;
        $56 = ((($7)) + 11|0);
        $57 = HEAP8[$56>>0]|0;
        $58 = ($57<<24>>24)<(0);
        if (!($58)) {
         $$0 = $55;$$011 = $54;
         break;
        }
        $59 = HEAP32[$7>>2]|0;
        __ZdlPv($59);
        $$0 = $55;$$011 = $54;
        break;
       }
       $46 = ((($7)) + 11|0);
       $47 = HEAP8[$46>>0]|0;
       $48 = ($47<<24>>24)<(0);
       if ($48) {
        $49 = HEAP32[$7>>2]|0;
        __ZdlPv($49);
       }
       label = 26;
       break L18;
      }
     } while(0);
     $$1 = $$0;$$112 = $$011;
     break L1;
    } else {
     __THREW__ = 0;
     (invoke_iii(3477,($5|0),($0|0))|0);
     $60 = __THREW__; __THREW__ = 0;
     $61 = $60&1;
     if ($61) {
      label = 24;
     } else {
      label = 26;
     }
    }
   } while(0);
   L32: do {
    if ((label|0) == 26) {
     $64 = ((($5)) + 11|0);
     $65 = HEAP8[$64>>0]|0;
     $66 = ($65<<24>>24)<(0);
     $67 = HEAP32[$5>>2]|0;
     $68 = $66 ? $67 : $5;
     __THREW__ = 0;
     $69 = (invoke_iii(4230,($68|0),257)|0);
     $70 = __THREW__; __THREW__ = 0;
     $71 = $70&1;
     if ($71) {
      label = 24;
     } else {
      $72 = ($69|0)==(0|0);
      L35: do {
       if ($72) {
        __THREW__ = 0;
        $73 = (invoke_ii(4195,($5|0))|0);
        $74 = __THREW__; __THREW__ = 0;
        $75 = $74&1;
        if ($75) {
         label = 24;
         break L32;
        }
        if ($73) {
         __THREW__ = 0;
         $76 = (invoke_ii(3265,2)|0);
         $77 = __THREW__; __THREW__ = 0;
         $78 = $77&1;
         if ($78) {
          label = 24;
          break L32;
         }
         L41: do {
          if ($76) {
           __THREW__ = 0;
           $79 = (invoke_ii(3266,2)|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if ($81) {
            label = 24;
            break L32;
           }
           __THREW__ = 0;
           $82 = (invoke_iiii(3267,($79|0),(172029|0),26)|0);
           $83 = __THREW__; __THREW__ = 0;
           $84 = $83&1;
           if ($84) {
            label = 24;
            break L32;
           }
           $85 = HEAP8[$10>>0]|0;
           $86 = ($85<<24>>24)<(0);
           $87 = HEAP32[$0>>2]|0;
           $88 = $86 ? $87 : $0;
           $89 = HEAP32[$13>>2]|0;
           $90 = $85&255;
           $91 = $86 ? $89 : $90;
           __THREW__ = 0;
           $92 = (invoke_iiii(3267,($82|0),($88|0),($91|0))|0);
           $93 = __THREW__; __THREW__ = 0;
           $94 = $93&1;
           if ($94) {
            label = 24;
            break L32;
           }
           __THREW__ = 0;
           $95 = (invoke_iiii(3267,($92|0),(172056|0),56)|0);
           $96 = __THREW__; __THREW__ = 0;
           $97 = $96&1;
           if ($97) {
            label = 24;
            break L32;
           }
           $98 = HEAP32[$95>>2]|0;
           $99 = ((($98)) + -12|0);
           $100 = HEAP32[$99>>2]|0;
           $101 = (($95) + ($100)|0);
           __THREW__ = 0;
           invoke_vii(3257,($4|0),($101|0));
           $102 = __THREW__; __THREW__ = 0;
           $103 = $102&1;
           if ($103) {
            label = 24;
            break L32;
           }
           __THREW__ = 0;
           $104 = (invoke_iii(3255,($4|0),(215188|0))|0);
           $105 = __THREW__; __THREW__ = 0;
           $106 = $105&1;
           do {
            if (!($106)) {
             $107 = HEAP32[$104>>2]|0;
             $108 = ((($107)) + 28|0);
             $109 = HEAP32[$108>>2]|0;
             __THREW__ = 0;
             $110 = (invoke_iii($109|0,($104|0),10)|0);
             $111 = __THREW__; __THREW__ = 0;
             $112 = $111&1;
             if ($112) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3263,($4|0));
             $119 = __THREW__; __THREW__ = 0;
             $120 = $119&1;
             if ($120) {
              label = 24;
              break L32;
             }
             __THREW__ = 0;
             (invoke_iii(3268,($95|0),($110|0))|0);
             $121 = __THREW__; __THREW__ = 0;
             $122 = $121&1;
             if ($122) {
              label = 24;
              break L32;
             }
             __THREW__ = 0;
             (invoke_ii(3269,($95|0))|0);
             $123 = __THREW__; __THREW__ = 0;
             $124 = $123&1;
             if ($124) {
              label = 24;
              break L32;
             } else {
              break L41;
             }
            }
           } while(0);
           $113 = ___cxa_find_matching_catch_2()|0;
           $114 = tempRet0;
           __THREW__ = 0;
           invoke_vi(3263,($4|0));
           $115 = __THREW__; __THREW__ = 0;
           $116 = $115&1;
           if ($116) {
            $117 = ___cxa_find_matching_catch_3(0|0)|0;
            $118 = tempRet0;
            ___clang_call_terminate($117);
            // unreachable;
           } else {
            $eh$lpad$body$index5Z2D = $114;$eh$lpad$body$indexZ2D = $113;
            break L32;
           }
          }
         } while(0);
         __THREW__ = 0;
         $125 = (invoke_ii(3265,2)|0);
         $126 = __THREW__; __THREW__ = 0;
         $127 = $126&1;
         if ($127) {
          label = 24;
          break L32;
         }
         if (!($125)) {
          break;
         }
         __THREW__ = 0;
         $128 = (invoke_ii(3266,2)|0);
         $129 = __THREW__; __THREW__ = 0;
         $130 = $129&1;
         if ($130) {
          label = 24;
          break L32;
         }
         __THREW__ = 0;
         $131 = (invoke_i(4231)|0);
         $132 = __THREW__; __THREW__ = 0;
         $133 = $132&1;
         if ($133) {
          label = 24;
          break L32;
         }
         $134 = (_strlen($131)|0);
         __THREW__ = 0;
         $135 = (invoke_iiii(3267,($128|0),($131|0),($134|0))|0);
         $136 = __THREW__; __THREW__ = 0;
         $137 = $136&1;
         if ($137) {
          label = 24;
          break L32;
         }
         $138 = HEAP32[$135>>2]|0;
         $139 = ((($138)) + -12|0);
         $140 = HEAP32[$139>>2]|0;
         $141 = (($135) + ($140)|0);
         __THREW__ = 0;
         invoke_vii(3257,($3|0),($141|0));
         $142 = __THREW__; __THREW__ = 0;
         $143 = $142&1;
         if ($143) {
          label = 24;
          break L32;
         }
         __THREW__ = 0;
         $144 = (invoke_iii(3255,($3|0),(215188|0))|0);
         $145 = __THREW__; __THREW__ = 0;
         $146 = $145&1;
         do {
          if (!($146)) {
           $147 = HEAP32[$144>>2]|0;
           $148 = ((($147)) + 28|0);
           $149 = HEAP32[$148>>2]|0;
           __THREW__ = 0;
           $150 = (invoke_iii($149|0,($144|0),10)|0);
           $151 = __THREW__; __THREW__ = 0;
           $152 = $151&1;
           if ($152) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3263,($3|0));
           $159 = __THREW__; __THREW__ = 0;
           $160 = $159&1;
           if ($160) {
            label = 24;
            break L32;
           }
           __THREW__ = 0;
           (invoke_iii(3268,($135|0),($150|0))|0);
           $161 = __THREW__; __THREW__ = 0;
           $162 = $161&1;
           if ($162) {
            label = 24;
            break L32;
           }
           __THREW__ = 0;
           (invoke_ii(3269,($135|0))|0);
           $163 = __THREW__; __THREW__ = 0;
           $164 = $163&1;
           if ($164) {
            label = 24;
            break L32;
           } else {
            break L35;
           }
          }
         } while(0);
         $153 = ___cxa_find_matching_catch_2()|0;
         $154 = tempRet0;
         __THREW__ = 0;
         invoke_vi(3263,($3|0));
         $155 = __THREW__; __THREW__ = 0;
         $156 = $155&1;
         if ($156) {
          $157 = ___cxa_find_matching_catch_3(0|0)|0;
          $158 = tempRet0;
          ___clang_call_terminate($157);
          // unreachable;
         } else {
          $eh$lpad$body$index5Z2D = $154;$eh$lpad$body$indexZ2D = $153;
          break L32;
         }
        } else {
         __THREW__ = 0;
         $165 = (invoke_ii(3265,4)|0);
         $166 = __THREW__; __THREW__ = 0;
         $167 = $166&1;
         if ($167) {
          label = 24;
          break L32;
         }
         L75: do {
          if ($165) {
           __THREW__ = 0;
           $168 = (invoke_ii(3266,4)|0);
           $169 = __THREW__; __THREW__ = 0;
           $170 = $169&1;
           if ($170) {
            label = 24;
            break L32;
           }
           __THREW__ = 0;
           $171 = (invoke_iiii(3267,($168|0),(172029|0),26)|0);
           $172 = __THREW__; __THREW__ = 0;
           $173 = $172&1;
           if ($173) {
            label = 24;
            break L32;
           }
           $174 = HEAP8[$10>>0]|0;
           $175 = ($174<<24>>24)<(0);
           $176 = HEAP32[$0>>2]|0;
           $177 = $175 ? $176 : $0;
           $178 = HEAP32[$13>>2]|0;
           $179 = $174&255;
           $180 = $175 ? $178 : $179;
           __THREW__ = 0;
           $181 = (invoke_iiii(3267,($171|0),($177|0),($180|0))|0);
           $182 = __THREW__; __THREW__ = 0;
           $183 = $182&1;
           if ($183) {
            label = 24;
            break L32;
           }
           __THREW__ = 0;
           $184 = (invoke_iiii(3267,($181|0),(172113|0),37)|0);
           $185 = __THREW__; __THREW__ = 0;
           $186 = $185&1;
           if ($186) {
            label = 24;
            break L32;
           }
           $187 = HEAP32[$184>>2]|0;
           $188 = ((($187)) + -12|0);
           $189 = HEAP32[$188>>2]|0;
           $190 = (($184) + ($189)|0);
           __THREW__ = 0;
           invoke_vii(3257,($2|0),($190|0));
           $191 = __THREW__; __THREW__ = 0;
           $192 = $191&1;
           if ($192) {
            label = 24;
            break L32;
           }
           __THREW__ = 0;
           $193 = (invoke_iii(3255,($2|0),(215188|0))|0);
           $194 = __THREW__; __THREW__ = 0;
           $195 = $194&1;
           do {
            if (!($195)) {
             $196 = HEAP32[$193>>2]|0;
             $197 = ((($196)) + 28|0);
             $198 = HEAP32[$197>>2]|0;
             __THREW__ = 0;
             $199 = (invoke_iii($198|0,($193|0),10)|0);
             $200 = __THREW__; __THREW__ = 0;
             $201 = $200&1;
             if ($201) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3263,($2|0));
             $208 = __THREW__; __THREW__ = 0;
             $209 = $208&1;
             if ($209) {
              label = 24;
              break L32;
             }
             __THREW__ = 0;
             (invoke_iii(3268,($184|0),($199|0))|0);
             $210 = __THREW__; __THREW__ = 0;
             $211 = $210&1;
             if ($211) {
              label = 24;
              break L32;
             }
             __THREW__ = 0;
             (invoke_ii(3269,($184|0))|0);
             $212 = __THREW__; __THREW__ = 0;
             $213 = $212&1;
             if ($213) {
              label = 24;
              break L32;
             } else {
              break L75;
             }
            }
           } while(0);
           $202 = ___cxa_find_matching_catch_2()|0;
           $203 = tempRet0;
           __THREW__ = 0;
           invoke_vi(3263,($2|0));
           $204 = __THREW__; __THREW__ = 0;
           $205 = $204&1;
           if ($205) {
            $206 = ___cxa_find_matching_catch_3(0|0)|0;
            $207 = tempRet0;
            ___clang_call_terminate($206);
            // unreachable;
           } else {
            $eh$lpad$body$index5Z2D = $203;$eh$lpad$body$indexZ2D = $202;
            break L32;
           }
          }
         } while(0);
         __THREW__ = 0;
         $214 = (invoke_ii(3265,4)|0);
         $215 = __THREW__; __THREW__ = 0;
         $216 = $215&1;
         if ($216) {
          label = 24;
          break L32;
         }
         if (!($214)) {
          break;
         }
         __THREW__ = 0;
         $217 = (invoke_ii(3266,4)|0);
         $218 = __THREW__; __THREW__ = 0;
         $219 = $218&1;
         if ($219) {
          label = 24;
          break L32;
         }
         __THREW__ = 0;
         $220 = (invoke_i(4231)|0);
         $221 = __THREW__; __THREW__ = 0;
         $222 = $221&1;
         if ($222) {
          label = 24;
          break L32;
         }
         $223 = (_strlen($220)|0);
         __THREW__ = 0;
         $224 = (invoke_iiii(3267,($217|0),($220|0),($223|0))|0);
         $225 = __THREW__; __THREW__ = 0;
         $226 = $225&1;
         if ($226) {
          label = 24;
          break L32;
         }
         $227 = HEAP32[$224>>2]|0;
         $228 = ((($227)) + -12|0);
         $229 = HEAP32[$228>>2]|0;
         $230 = (($224) + ($229)|0);
         __THREW__ = 0;
         invoke_vii(3257,($1|0),($230|0));
         $231 = __THREW__; __THREW__ = 0;
         $232 = $231&1;
         if ($232) {
          label = 24;
          break L32;
         }
         __THREW__ = 0;
         $233 = (invoke_iii(3255,($1|0),(215188|0))|0);
         $234 = __THREW__; __THREW__ = 0;
         $235 = $234&1;
         do {
          if (!($235)) {
           $236 = HEAP32[$233>>2]|0;
           $237 = ((($236)) + 28|0);
           $238 = HEAP32[$237>>2]|0;
           __THREW__ = 0;
           $239 = (invoke_iii($238|0,($233|0),10)|0);
           $240 = __THREW__; __THREW__ = 0;
           $241 = $240&1;
           if ($241) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3263,($1|0));
           $248 = __THREW__; __THREW__ = 0;
           $249 = $248&1;
           if ($249) {
            label = 24;
            break L32;
           }
           __THREW__ = 0;
           (invoke_iii(3268,($224|0),($239|0))|0);
           $250 = __THREW__; __THREW__ = 0;
           $251 = $250&1;
           if ($251) {
            label = 24;
            break L32;
           }
           __THREW__ = 0;
           (invoke_ii(3269,($224|0))|0);
           $252 = __THREW__; __THREW__ = 0;
           $253 = $252&1;
           if ($253) {
            label = 24;
            break L32;
           } else {
            break L35;
           }
          }
         } while(0);
         $242 = ___cxa_find_matching_catch_2()|0;
         $243 = tempRet0;
         __THREW__ = 0;
         invoke_vi(3263,($1|0));
         $244 = __THREW__; __THREW__ = 0;
         $245 = $244&1;
         if ($245) {
          $246 = ___cxa_find_matching_catch_3(0|0)|0;
          $247 = tempRet0;
          ___clang_call_terminate($246);
          // unreachable;
         } else {
          $eh$lpad$body$index5Z2D = $243;$eh$lpad$body$indexZ2D = $242;
          break L32;
         }
        }
       }
      } while(0);
      $254 = HEAP8[$64>>0]|0;
      $255 = ($254<<24>>24)<(0);
      if (!($255)) {
       STACKTOP = sp;return ($69|0);
      }
      $256 = HEAP32[$5>>2]|0;
      __ZdlPv($256);
      STACKTOP = sp;return ($69|0);
     }
    }
   } while(0);
   if ((label|0) == 24) {
    $62 = ___cxa_find_matching_catch_2()|0;
    $63 = tempRet0;
    $eh$lpad$body$index5Z2D = $63;$eh$lpad$body$indexZ2D = $62;
   }
   $$1 = $eh$lpad$body$index5Z2D;$$112 = $eh$lpad$body$indexZ2D;
  }
 } while(0);
 $257 = ((($5)) + 11|0);
 $258 = HEAP8[$257>>0]|0;
 $259 = ($258<<24>>24)<(0);
 if (!($259)) {
  ___resumeException($$112|0);
  // unreachable;
 }
 $260 = HEAP32[$5>>2]|0;
 __ZdlPv($260);
 ___resumeException($$112|0);
 // unreachable;
 return (0)|0;
}
function __ZN5osgDB9FileCacheD2Ev($0) {
 $0 = $0|0;
 var $$023$i$i = 0, $$023$i$i6 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 HEAP32[$0>>2] = (75336);
 __THREW__ = 0;
 $2 = (invoke_ii(3265,4)|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 L1: do {
  if ($4) {
   label = 14;
  } else {
   do {
    if ($2) {
     __THREW__ = 0;
     $5 = (invoke_ii(3266,4)|0);
     $6 = __THREW__; __THREW__ = 0;
     $7 = $6&1;
     if ($7) {
      label = 14;
      break L1;
     }
     __THREW__ = 0;
     $8 = (invoke_iiii(3267,($5|0),(172548|0),21)|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      label = 14;
      break L1;
     }
     $11 = HEAP32[$8>>2]|0;
     $12 = ((($11)) + -12|0);
     $13 = HEAP32[$12>>2]|0;
     $14 = (($8) + ($13)|0);
     __THREW__ = 0;
     invoke_vii(3257,($1|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      label = 14;
      break L1;
     }
     __THREW__ = 0;
     $17 = (invoke_iii(3255,($1|0),(215188|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if (!($19)) {
      $20 = HEAP32[$17>>2]|0;
      $21 = ((($20)) + 28|0);
      $22 = HEAP32[$21>>2]|0;
      __THREW__ = 0;
      $23 = (invoke_iii($22|0,($17|0),10)|0);
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if (!($25)) {
       __THREW__ = 0;
       invoke_vi(3263,($1|0));
       $32 = __THREW__; __THREW__ = 0;
       $33 = $32&1;
       if ($33) {
        label = 14;
        break L1;
       }
       __THREW__ = 0;
       (invoke_iii(3268,($8|0),($23|0))|0);
       $34 = __THREW__; __THREW__ = 0;
       $35 = $34&1;
       if ($35) {
        label = 14;
        break L1;
       }
       __THREW__ = 0;
       (invoke_ii(3269,($8|0))|0);
       $36 = __THREW__; __THREW__ = 0;
       $37 = $36&1;
       if ($37) {
        label = 14;
        break L1;
       } else {
        break;
       }
      }
     }
     $26 = ___cxa_find_matching_catch_2()|0;
     $27 = tempRet0;
     __THREW__ = 0;
     invoke_vi(3263,($1|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      $30 = ___cxa_find_matching_catch_3(0|0)|0;
      $31 = tempRet0;
      ___clang_call_terminate($30);
      // unreachable;
     } else {
      $eh$lpad$body$index2Z2D = $27;$eh$lpad$body$indexZ2D = $26;
      break L1;
     }
    }
   } while(0);
   $73 = ((($0)) + 24|0);
   $74 = ((($0)) + 32|0);
   $75 = HEAP32[$74>>2]|0;
   $76 = ($75|0)==(0);
   L18: do {
    if (!($76)) {
     $77 = ((($0)) + 28|0);
     $78 = HEAP32[$77>>2]|0;
     $79 = HEAP32[$73>>2]|0;
     $80 = ((($79)) + 4|0);
     $81 = HEAP32[$80>>2]|0;
     $82 = HEAP32[$78>>2]|0;
     $83 = ((($82)) + 4|0);
     HEAP32[$83>>2] = $81;
     $84 = HEAP32[$80>>2]|0;
     HEAP32[$84>>2] = $82;
     HEAP32[$74>>2] = 0;
     $85 = ($78|0)==($73|0);
     if (!($85)) {
      $$023$i$i6 = $78;
      while(1) {
       $86 = ((($$023$i$i6)) + 4|0);
       $87 = HEAP32[$86>>2]|0;
       $88 = ((($$023$i$i6)) + 8|0);
       $89 = HEAP32[$88>>2]|0;
       $90 = ($89|0)==(0|0);
       if (!($90)) {
        $91 = ((($89)) + 8|0);
        $92 = HEAP32[$91>>2]|0;HEAP32[$91>>2] = (($92-1)|0);
        $93 = ($92|0)==(1);
        if ($93) {
         __THREW__ = 0;
         invoke_viii(3262,($89|0),1,1);
         $94 = __THREW__; __THREW__ = 0;
         $95 = $94&1;
         if ($95) {
          break;
         }
        }
       }
       __ZdlPv($$023$i$i6);
       $96 = ($87|0)==($73|0);
       if ($96) {
        break L18;
       } else {
        $$023$i$i6 = $87;
       }
      }
      $97 = ___cxa_find_matching_catch_2()|0;
      $98 = tempRet0;
      ___cxa_call_unexpected(($97|0));
      // unreachable;
     }
    }
   } while(0);
   $99 = ((($0)) + 12|0);
   $100 = ((($99)) + 11|0);
   $101 = HEAP8[$100>>0]|0;
   $102 = ($101<<24>>24)<(0);
   if (!($102)) {
    __ZN3osg10ReferencedD2Ev($0);
    STACKTOP = sp;return;
   }
   $103 = HEAP32[$99>>2]|0;
   __ZdlPv($103);
   __ZN3osg10ReferencedD2Ev($0);
   STACKTOP = sp;return;
  }
 } while(0);
 if ((label|0) == 14) {
  $38 = ___cxa_find_matching_catch_2()|0;
  $39 = tempRet0;
  $eh$lpad$body$index2Z2D = $39;$eh$lpad$body$indexZ2D = $38;
 }
 $40 = ((($0)) + 24|0);
 $41 = ((($0)) + 32|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ($42|0)==(0);
 L35: do {
  if (!($43)) {
   $44 = ((($0)) + 28|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = HEAP32[$40>>2]|0;
   $47 = ((($46)) + 4|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = HEAP32[$45>>2]|0;
   $50 = ((($49)) + 4|0);
   HEAP32[$50>>2] = $48;
   $51 = HEAP32[$47>>2]|0;
   HEAP32[$51>>2] = $49;
   HEAP32[$41>>2] = 0;
   $52 = ($45|0)==($40|0);
   if (!($52)) {
    $$023$i$i = $45;
    while(1) {
     $53 = ((($$023$i$i)) + 4|0);
     $54 = HEAP32[$53>>2]|0;
     $55 = ((($$023$i$i)) + 8|0);
     $56 = HEAP32[$55>>2]|0;
     $57 = ($56|0)==(0|0);
     if (!($57)) {
      $58 = ((($56)) + 8|0);
      $59 = HEAP32[$58>>2]|0;HEAP32[$58>>2] = (($59-1)|0);
      $60 = ($59|0)==(1);
      if ($60) {
       __THREW__ = 0;
       invoke_viii(3262,($56|0),1,1);
       $61 = __THREW__; __THREW__ = 0;
       $62 = $61&1;
       if ($62) {
        break;
       }
      }
     }
     __ZdlPv($$023$i$i);
     $63 = ($54|0)==($40|0);
     if ($63) {
      break L35;
     } else {
      $$023$i$i = $54;
     }
    }
    $64 = ___cxa_find_matching_catch_2()|0;
    $65 = tempRet0;
    ___cxa_call_unexpected(($64|0));
    // unreachable;
   }
  }
 } while(0);
 $66 = ((($0)) + 12|0);
 $67 = ((($66)) + 11|0);
 $68 = HEAP8[$67>>0]|0;
 $69 = ($68<<24>>24)<(0);
 if ($69) {
  $70 = HEAP32[$66>>2]|0;
  __ZdlPv($70);
 }
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $71 = __THREW__; __THREW__ = 0;
 $72 = $71&1;
 if ($72) {
  $104 = ___cxa_find_matching_catch_3(0|0)|0;
  $105 = tempRet0;
  ___clang_call_terminate($104);
  // unreachable;
 } else {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
}
function __ZN5osgDB9FileCacheD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(2714,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  return;
 }
}
function __ZNK5osgDB9FileCache29isFileAppropriateForFileCacheERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__ZN5osgDB21containsServerAddressERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE($1)|0);
 return ($2|0);
}
function __ZNK5osgDB9FileCache19createCacheFileNameERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$06 = 0, $$1 = 0, $$17 = 0, $$2 = 0, $$28 = 0, $$3 = 0, $$39 = 0, $$4 = 0, $$410 = 0, $$pre$phi27Z2D = 0, $$pre$phi31Z2D = 0, $$pre26 = 0, $$pre30 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0;
 var $141 = 0, $142 = 0, $143 = 0, $144 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(64|0);
 $3 = sp + 60|0;
 $4 = sp + 48|0;
 $5 = sp + 36|0;
 $6 = sp + 24|0;
 $7 = sp + 12|0;
 $8 = sp;
 __ZN5osgDB16getServerAddressERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE($4,$2);
 $9 = ((($1)) + 12|0);
 __THREW__ = 0;
 invoke_viii(3542,($7|0),($9|0),(172817|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 L1: do {
  if ($11) {
   $108 = ___cxa_find_matching_catch_2()|0;
   $109 = tempRet0;
   $$3 = $109;$$39 = $108;
   label = 42;
  } else {
   __THREW__ = 0;
   invoke_viii(3550,($6|0),($7|0),($4|0));
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if ($13) {
    $110 = ___cxa_find_matching_catch_2()|0;
    $111 = tempRet0;
    $$2 = $111;$$28 = $110;
   } else {
    $14 = ((($4)) + 11|0);
    $15 = HEAP8[$14>>0]|0;
    $16 = ($15<<24>>24)<(0);
    $17 = ((($4)) + 4|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = $15&255;
    $20 = $16 ? $18 : $19;
    $21 = ($20|0)==(0);
    $22 = $21 ? 221531 : 172817;
    __THREW__ = 0;
    invoke_viii(3542,($5|0),($6|0),($22|0));
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if ($24) {
     $112 = ___cxa_find_matching_catch_2()|0;
     $113 = tempRet0;
     $$1 = $113;$$17 = $112;
    } else {
     __THREW__ = 0;
     invoke_vii(4232,($8|0),($2|0));
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     do {
      if ($26) {
       $114 = ___cxa_find_matching_catch_2()|0;
       $115 = tempRet0;
       $$0 = $115;$$06 = $114;
      } else {
       __THREW__ = 0;
       invoke_viii(3550,($0|0),($5|0),($8|0));
       $27 = __THREW__; __THREW__ = 0;
       $28 = $27&1;
       if ($28) {
        $116 = ___cxa_find_matching_catch_2()|0;
        $117 = tempRet0;
        $118 = ((($8)) + 11|0);
        $119 = HEAP8[$118>>0]|0;
        $120 = ($119<<24>>24)<(0);
        if (!($120)) {
         $$0 = $117;$$06 = $116;
         break;
        }
        $121 = HEAP32[$8>>2]|0;
        __ZdlPv($121);
        $$0 = $117;$$06 = $116;
        break;
       }
       $29 = ((($8)) + 11|0);
       $30 = HEAP8[$29>>0]|0;
       $31 = ($30<<24>>24)<(0);
       if ($31) {
        $32 = HEAP32[$8>>2]|0;
        __ZdlPv($32);
       }
       $33 = ((($5)) + 11|0);
       $34 = HEAP8[$33>>0]|0;
       $35 = ($34<<24>>24)<(0);
       if ($35) {
        $36 = HEAP32[$5>>2]|0;
        __ZdlPv($36);
       }
       $37 = ((($6)) + 11|0);
       $38 = HEAP8[$37>>0]|0;
       $39 = ($38<<24>>24)<(0);
       if ($39) {
        $40 = HEAP32[$6>>2]|0;
        __ZdlPv($40);
       }
       $41 = ((($7)) + 11|0);
       $42 = HEAP8[$41>>0]|0;
       $43 = ($42<<24>>24)<(0);
       if ($43) {
        $44 = HEAP32[$7>>2]|0;
        __ZdlPv($44);
       }
       __THREW__ = 0;
       $45 = (invoke_ii(3265,5)|0);
       $46 = __THREW__; __THREW__ = 0;
       $47 = $46&1;
       L29: do {
        if ($47) {
         label = 43;
        } else {
         L31: do {
          if ($45) {
           __THREW__ = 0;
           $48 = (invoke_ii(3266,5)|0);
           $49 = __THREW__; __THREW__ = 0;
           $50 = $49&1;
           if ($50) {
            label = 43;
            break L29;
           }
           __THREW__ = 0;
           $51 = (invoke_iiii(3267,($48|0),(172511|0),31)|0);
           $52 = __THREW__; __THREW__ = 0;
           $53 = $52&1;
           if ($53) {
            label = 43;
            break L29;
           }
           $54 = ((($2)) + 11|0);
           $55 = HEAP8[$54>>0]|0;
           $56 = ($55<<24>>24)<(0);
           $57 = HEAP32[$2>>2]|0;
           $58 = $56 ? $57 : $2;
           $59 = ((($2)) + 4|0);
           $60 = HEAP32[$59>>2]|0;
           $61 = $55&255;
           $62 = $56 ? $60 : $61;
           __THREW__ = 0;
           $63 = (invoke_iiii(3267,($51|0),($58|0),($62|0))|0);
           $64 = __THREW__; __THREW__ = 0;
           $65 = $64&1;
           if ($65) {
            label = 43;
            break L29;
           }
           __THREW__ = 0;
           $66 = (invoke_iiii(3267,($63|0),(172543|0),4)|0);
           $67 = __THREW__; __THREW__ = 0;
           $68 = $67&1;
           if ($68) {
            label = 43;
            break L29;
           }
           $69 = ((($0)) + 11|0);
           $70 = HEAP8[$69>>0]|0;
           $71 = ($70<<24>>24)<(0);
           $72 = HEAP32[$0>>2]|0;
           $73 = $71 ? $72 : $0;
           $74 = ((($0)) + 4|0);
           $75 = HEAP32[$74>>2]|0;
           $76 = $70&255;
           $77 = $71 ? $75 : $76;
           __THREW__ = 0;
           $78 = (invoke_iiii(3267,($66|0),($73|0),($77|0))|0);
           $79 = __THREW__; __THREW__ = 0;
           $80 = $79&1;
           if ($80) {
            label = 43;
            break L29;
           }
           $81 = HEAP32[$78>>2]|0;
           $82 = ((($81)) + -12|0);
           $83 = HEAP32[$82>>2]|0;
           $84 = (($78) + ($83)|0);
           __THREW__ = 0;
           invoke_vii(3257,($3|0),($84|0));
           $85 = __THREW__; __THREW__ = 0;
           $86 = $85&1;
           if ($86) {
            label = 43;
            break L29;
           }
           __THREW__ = 0;
           $87 = (invoke_iii(3255,($3|0),(215188|0))|0);
           $88 = __THREW__; __THREW__ = 0;
           $89 = $88&1;
           do {
            if (!($89)) {
             $90 = HEAP32[$87>>2]|0;
             $91 = ((($90)) + 28|0);
             $92 = HEAP32[$91>>2]|0;
             __THREW__ = 0;
             $93 = (invoke_iii($92|0,($87|0),10)|0);
             $94 = __THREW__; __THREW__ = 0;
             $95 = $94&1;
             if ($95) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3263,($3|0));
             $102 = __THREW__; __THREW__ = 0;
             $103 = $102&1;
             if ($103) {
              label = 43;
              break L29;
             }
             __THREW__ = 0;
             (invoke_iii(3268,($78|0),($93|0))|0);
             $104 = __THREW__; __THREW__ = 0;
             $105 = $104&1;
             if ($105) {
              label = 43;
              break L29;
             }
             __THREW__ = 0;
             (invoke_ii(3269,($78|0))|0);
             $106 = __THREW__; __THREW__ = 0;
             $107 = $106&1;
             if ($107) {
              label = 43;
              break L29;
             } else {
              break L31;
             }
            }
           } while(0);
           $96 = ___cxa_find_matching_catch_2()|0;
           $97 = tempRet0;
           __THREW__ = 0;
           invoke_vi(3263,($3|0));
           $98 = __THREW__; __THREW__ = 0;
           $99 = $98&1;
           if ($99) {
            $100 = ___cxa_find_matching_catch_3(0|0)|0;
            $101 = tempRet0;
            ___clang_call_terminate($100);
            // unreachable;
           } else {
            $$pre$phi27Z2D = $69;$eh$lpad$body$index2Z2D = $97;$eh$lpad$body$indexZ2D = $96;
            break L29;
           }
          }
         } while(0);
         $139 = HEAP8[$14>>0]|0;
         $140 = ($139<<24>>24)<(0);
         if (!($140)) {
          STACKTOP = sp;return;
         }
         $141 = HEAP32[$4>>2]|0;
         __ZdlPv($141);
         STACKTOP = sp;return;
        }
       } while(0);
       if ((label|0) == 43) {
        $134 = ___cxa_find_matching_catch_2()|0;
        $135 = tempRet0;
        $$pre26 = ((($0)) + 11|0);
        $$pre$phi27Z2D = $$pre26;$eh$lpad$body$index2Z2D = $135;$eh$lpad$body$indexZ2D = $134;
       }
       $136 = HEAP8[$$pre$phi27Z2D>>0]|0;
       $137 = ($136<<24>>24)<(0);
       if (!($137)) {
        $$4 = $eh$lpad$body$index2Z2D;$$410 = $eh$lpad$body$indexZ2D;$$pre$phi31Z2D = $14;
        break L1;
       }
       $138 = HEAP32[$0>>2]|0;
       __ZdlPv($138);
       $$4 = $eh$lpad$body$index2Z2D;$$410 = $eh$lpad$body$indexZ2D;$$pre$phi31Z2D = $14;
       break L1;
      }
     } while(0);
     $122 = ((($5)) + 11|0);
     $123 = HEAP8[$122>>0]|0;
     $124 = ($123<<24>>24)<(0);
     if ($124) {
      $125 = HEAP32[$5>>2]|0;
      __ZdlPv($125);
      $$1 = $$0;$$17 = $$06;
     } else {
      $$1 = $$0;$$17 = $$06;
     }
    }
    $126 = ((($6)) + 11|0);
    $127 = HEAP8[$126>>0]|0;
    $128 = ($127<<24>>24)<(0);
    if ($128) {
     $129 = HEAP32[$6>>2]|0;
     __ZdlPv($129);
     $$2 = $$1;$$28 = $$17;
    } else {
     $$2 = $$1;$$28 = $$17;
    }
   }
   $130 = ((($7)) + 11|0);
   $131 = HEAP8[$130>>0]|0;
   $132 = ($131<<24>>24)<(0);
   if ($132) {
    $133 = HEAP32[$7>>2]|0;
    __ZdlPv($133);
    $$3 = $$2;$$39 = $$28;
    label = 42;
   } else {
    $$3 = $$2;$$39 = $$28;
    label = 42;
   }
  }
 } while(0);
 if ((label|0) == 42) {
  $$pre30 = ((($4)) + 11|0);
  $$4 = $$3;$$410 = $$39;$$pre$phi31Z2D = $$pre30;
 }
 $142 = HEAP8[$$pre$phi31Z2D>>0]|0;
 $143 = ($142<<24>>24)<(0);
 if (!($143)) {
  ___resumeException($$410|0);
  // unreachable;
 }
 $144 = HEAP32[$4>>2]|0;
 __ZdlPv($144);
 ___resumeException($$410|0);
 // unreachable;
}
function __ZNK5osgDB9FileCache13existsInCacheERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$sroa$05$0$i = 0, $$sroa$05$010$i = 0, $$sroa$05$011$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = HEAP32[$0>>2]|0;
 $4 = ((($3)) + 16|0);
 $5 = HEAP32[$4>>2]|0;
 FUNCTION_TABLE_viii[$5 & 8191]($2,$0,$1);
 __THREW__ = 0;
 $6 = (invoke_ii(4195,($2|0))|0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $25 = ___cxa_find_matching_catch_2()|0;
  $26 = tempRet0;
  $27 = ((($2)) + 11|0);
  $28 = HEAP8[$27>>0]|0;
  $29 = ($28<<24>>24)<(0);
  if (!($29)) {
   ___resumeException($25|0);
   // unreachable;
  }
  $30 = HEAP32[$2>>2]|0;
  __ZdlPv($30);
  ___resumeException($25|0);
  // unreachable;
 }
 $9 = ((($2)) + 11|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = ($10<<24>>24)<(0);
 if ($11) {
  $12 = HEAP32[$2>>2]|0;
  __ZdlPv($12);
 }
 if (!($6)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $13 = ((($0)) + 28|0);
 $$sroa$05$010$i = HEAP32[$13>>2]|0;
 $14 = ((($0)) + 24|0);
 $15 = $$sroa$05$010$i;
 $16 = ($15|0)==($14|0);
 if ($16) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 } else {
  $$sroa$05$011$i = $$sroa$05$010$i;$18 = $15;
 }
 while(1) {
  $21 = $$sroa$05$011$i;
  $22 = ((($21)) + 8|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (__ZNK5osgDB17DatabaseRevisions17isFileBlackListedERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE($23,$1)|0);
  if ($24) {
   $$0 = 0;
   label = 11;
   break;
  }
  $17 = ((($18)) + 4|0);
  $$sroa$05$0$i = HEAP32[$17>>2]|0;
  $19 = $$sroa$05$0$i;
  $20 = ($19|0)==($14|0);
  if ($20) {
   $$0 = 1;
   label = 11;
   break;
  } else {
   $$sroa$05$011$i = $$sroa$05$0$i;$18 = $19;
  }
 }
 if ((label|0) == 11) {
  STACKTOP = sp;return ($$0|0);
 }
 return (0)|0;
}
function __ZNK5osgDB9FileCache9readImageERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEPKNS_7OptionsE($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $4 = sp + 12|0;
 $5 = sp;
 $6 = HEAP32[$1>>2]|0;
 $7 = ((($6)) + 16|0);
 $8 = HEAP32[$7>>2]|0;
 FUNCTION_TABLE_viii[$8 & 8191]($5,$1,$2);
 $9 = ((($5)) + 11|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = ($10<<24>>24)<(0);
 $12 = ((($5)) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $10&255;
 $15 = $11 ? $13 : $14;
 $16 = ($15|0)==(0);
 L1: do {
  if ($16) {
   label = 31;
  } else {
   __THREW__ = 0;
   $17 = (invoke_ii(4195,($5|0))|0);
   $18 = __THREW__; __THREW__ = 0;
   $19 = $18&1;
   L3: do {
    if ($19) {
     label = 20;
    } else {
     if (!($17)) {
      label = 31;
      break L1;
     }
     __THREW__ = 0;
     $20 = (invoke_ii(3265,4)|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      label = 20;
     } else {
      do {
       if ($20) {
        __THREW__ = 0;
        $23 = (invoke_ii(3266,4)|0);
        $24 = __THREW__; __THREW__ = 0;
        $25 = $24&1;
        if ($25) {
         label = 20;
         break L3;
        }
        __THREW__ = 0;
        $26 = (invoke_iiii(3267,($23|0),(172480|0),30)|0);
        $27 = __THREW__; __THREW__ = 0;
        $28 = $27&1;
        if ($28) {
         label = 20;
         break L3;
        }
        $29 = ((($2)) + 11|0);
        $30 = HEAP8[$29>>0]|0;
        $31 = ($30<<24>>24)<(0);
        $32 = HEAP32[$2>>2]|0;
        $33 = $31 ? $32 : $2;
        $34 = ((($2)) + 4|0);
        $35 = HEAP32[$34>>2]|0;
        $36 = $30&255;
        $37 = $31 ? $35 : $36;
        __THREW__ = 0;
        $38 = (invoke_iiii(3267,($26|0),($33|0),($37|0))|0);
        $39 = __THREW__; __THREW__ = 0;
        $40 = $39&1;
        if ($40) {
         label = 20;
         break L3;
        }
        __THREW__ = 0;
        $41 = (invoke_iiii(3267,($38|0),(172217|0),5)|0);
        $42 = __THREW__; __THREW__ = 0;
        $43 = $42&1;
        if ($43) {
         label = 20;
         break L3;
        }
        $44 = HEAP8[$9>>0]|0;
        $45 = ($44<<24>>24)<(0);
        $46 = HEAP32[$5>>2]|0;
        $47 = $45 ? $46 : $5;
        $48 = HEAP32[$12>>2]|0;
        $49 = $44&255;
        $50 = $45 ? $48 : $49;
        __THREW__ = 0;
        $51 = (invoke_iiii(3267,($41|0),($47|0),($50|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 20;
         break L3;
        }
        $54 = HEAP32[$51>>2]|0;
        $55 = ((($54)) + -12|0);
        $56 = HEAP32[$55>>2]|0;
        $57 = (($51) + ($56)|0);
        __THREW__ = 0;
        invoke_vii(3257,($4|0),($57|0));
        $58 = __THREW__; __THREW__ = 0;
        $59 = $58&1;
        if ($59) {
         label = 20;
         break L3;
        }
        __THREW__ = 0;
        $60 = (invoke_iii(3255,($4|0),(215188|0))|0);
        $61 = __THREW__; __THREW__ = 0;
        $62 = $61&1;
        if (!($62)) {
         $63 = HEAP32[$60>>2]|0;
         $64 = ((($63)) + 28|0);
         $65 = HEAP32[$64>>2]|0;
         __THREW__ = 0;
         $66 = (invoke_iii($65|0,($60|0),10)|0);
         $67 = __THREW__; __THREW__ = 0;
         $68 = $67&1;
         if (!($68)) {
          __THREW__ = 0;
          invoke_vi(3263,($4|0));
          $75 = __THREW__; __THREW__ = 0;
          $76 = $75&1;
          if ($76) {
           label = 20;
           break L3;
          }
          __THREW__ = 0;
          (invoke_iii(3268,($51|0),($66|0))|0);
          $77 = __THREW__; __THREW__ = 0;
          $78 = $77&1;
          if ($78) {
           label = 20;
           break L3;
          }
          __THREW__ = 0;
          (invoke_ii(3269,($51|0))|0);
          $79 = __THREW__; __THREW__ = 0;
          $80 = $79&1;
          if ($80) {
           label = 20;
           break L3;
          } else {
           break;
          }
         }
        }
        $69 = ___cxa_find_matching_catch_2()|0;
        $70 = tempRet0;
        __THREW__ = 0;
        invoke_vi(3263,($4|0));
        $71 = __THREW__; __THREW__ = 0;
        $72 = $71&1;
        if ($72) {
         $73 = ___cxa_find_matching_catch_3(0|0)|0;
         $74 = tempRet0;
         ___clang_call_terminate($73);
         // unreachable;
        } else {
         $eh$lpad$body$index2Z2D = $70;$eh$lpad$body$indexZ2D = $69;
         break L3;
        }
       }
      } while(0);
      __THREW__ = 0;
      $86 = (invoke_ii(3482,0)|0);
      $87 = __THREW__; __THREW__ = 0;
      $88 = $87&1;
      if ($88) {
       label = 20;
      } else {
       $89 = ($3|0)==(0|0);
       if (!($89)) {
        $90 = ((($3)) + 116|0);
        $91 = HEAP32[$90>>2]|0;
        $92 = ($91|0)==(0|0);
        if (!($92)) {
         $93 = HEAP32[$91>>2]|0;
         $94 = ((($93)) + 8|0);
         $95 = HEAP32[$94>>2]|0;
         __THREW__ = 0;
         invoke_viiii($95|0,($0|0),($91|0),($5|0),($3|0));
         $96 = __THREW__; __THREW__ = 0;
         $97 = $96&1;
         if ($97) {
          label = 20;
          break;
         } else {
          break L1;
         }
        }
       }
       $98 = ((($86)) + 48|0);
       $99 = HEAP32[$98>>2]|0;
       $100 = ($99|0)==(0|0);
       if ($100) {
        __THREW__ = 0;
        invoke_viiii(4233,($0|0),($86|0),($5|0),($3|0));
        $106 = __THREW__; __THREW__ = 0;
        $107 = $106&1;
        if ($107) {
         label = 20;
         break;
        } else {
         break L1;
        }
       } else {
        $101 = HEAP32[$99>>2]|0;
        $102 = ((($101)) + 8|0);
        $103 = HEAP32[$102>>2]|0;
        __THREW__ = 0;
        invoke_viiii($103|0,($0|0),($99|0),($5|0),($3|0));
        $104 = __THREW__; __THREW__ = 0;
        $105 = $104&1;
        if ($105) {
         label = 20;
         break;
        } else {
         break L1;
        }
       }
      }
     }
    }
   } while(0);
   if ((label|0) == 20) {
    $81 = ___cxa_find_matching_catch_2()|0;
    $82 = tempRet0;
    $eh$lpad$body$index2Z2D = $82;$eh$lpad$body$indexZ2D = $81;
   }
   $83 = HEAP8[$9>>0]|0;
   $84 = ($83<<24>>24)<(0);
   if (!($84)) {
    ___resumeException($eh$lpad$body$indexZ2D|0);
    // unreachable;
   }
   $85 = HEAP32[$5>>2]|0;
   __ZdlPv($85);
   ___resumeException($eh$lpad$body$indexZ2D|0);
   // unreachable;
  }
 } while(0);
 if ((label|0) == 31) {
  HEAP32[$0>>2] = 4;
  $108 = ((($0)) + 4|0);
  ;HEAP32[$108>>2]=0|0;HEAP32[$108+4>>2]=0|0;HEAP32[$108+8>>2]=0|0;HEAP32[$108+12>>2]=0|0;
 }
 $109 = HEAP8[$9>>0]|0;
 $110 = ($109<<24>>24)<(0);
 if (!($110)) {
  STACKTOP = sp;return;
 }
 $111 = HEAP32[$5>>2]|0;
 __ZdlPv($111);
 STACKTOP = sp;return;
}
function __ZNK5osgDB9FileCache10writeImageERKN3osg5ImageERKNSt3__212basic_stringIcNS5_11char_traitsIcEENS5_9allocatorIcEEEEPKNS_7OptionsE($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$1 = 0, $$18 = 0, $$2 = 0, $$29 = 0, $$pre = 0, $$pre39 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $eh$lpad$body$index3Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $5 = sp + 44|0;
 $6 = sp + 40|0;
 $7 = sp + 28|0;
 $8 = sp + 16|0;
 $9 = sp;
 $10 = HEAP32[$1>>2]|0;
 $11 = ((($10)) + 16|0);
 $12 = HEAP32[$11>>2]|0;
 FUNCTION_TABLE_viii[$12 & 8191]($7,$1,$3);
 $13 = ((($7)) + 11|0);
 $14 = HEAP8[$13>>0]|0;
 $15 = ($14<<24>>24)<(0);
 $16 = ((($7)) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = $14&255;
 $19 = $15 ? $17 : $18;
 $20 = ($19|0)==(0);
 L1: do {
  if ($20) {
   HEAP32[$0>>2] = 1;
   $193 = ((($0)) + 4|0);
   ;HEAP32[$193>>2]=0|0;HEAP32[$193+4>>2]=0|0;HEAP32[$193+8>>2]=0|0;
   $194 = $14;
  } else {
   __THREW__ = 0;
   invoke_vii(4234,($8|0),($7|0));
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if ($22) {
    $77 = ___cxa_find_matching_catch_2()|0;
    $78 = tempRet0;
    $$2 = $78;$$29 = $77;
   } else {
    __THREW__ = 0;
    $23 = (invoke_ii(4195,($8|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    L7: do {
     if ($25) {
      label = 22;
     } else {
      if ($23) {
       label = 25;
      } else {
       __THREW__ = 0;
       $26 = (invoke_ii(4235,($8|0))|0);
       $27 = __THREW__; __THREW__ = 0;
       $28 = $27&1;
       if ($28) {
        label = 22;
        break;
       }
       if ($26) {
        label = 25;
       } else {
        __THREW__ = 0;
        $29 = (invoke_ii(3265,3)|0);
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if ($31) {
         label = 22;
         break;
        }
        do {
         if ($29) {
          __THREW__ = 0;
          $32 = (invoke_ii(3266,3)|0);
          $33 = __THREW__; __THREW__ = 0;
          $34 = $33&1;
          if ($34) {
           label = 22;
           break L7;
          }
          __THREW__ = 0;
          $35 = (invoke_iiii(3267,($32|0),(172151|0),34)|0);
          $36 = __THREW__; __THREW__ = 0;
          $37 = $36&1;
          if ($37) {
           label = 22;
           break L7;
          }
          $38 = ((($8)) + 11|0);
          $39 = HEAP8[$38>>0]|0;
          $40 = ($39<<24>>24)<(0);
          $41 = HEAP32[$8>>2]|0;
          $42 = $40 ? $41 : $8;
          $43 = ((($8)) + 4|0);
          $44 = HEAP32[$43>>2]|0;
          $45 = $39&255;
          $46 = $40 ? $44 : $45;
          __THREW__ = 0;
          $47 = (invoke_iiii(3267,($35|0),($42|0),($46|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           label = 22;
           break L7;
          }
          $50 = HEAP32[$47>>2]|0;
          $51 = ((($50)) + -12|0);
          $52 = HEAP32[$51>>2]|0;
          $53 = (($47) + ($52)|0);
          __THREW__ = 0;
          invoke_vii(3257,($6|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           label = 22;
           break L7;
          }
          __THREW__ = 0;
          $56 = (invoke_iii(3255,($6|0),(215188|0))|0);
          $57 = __THREW__; __THREW__ = 0;
          $58 = $57&1;
          if (!($58)) {
           $59 = HEAP32[$56>>2]|0;
           $60 = ((($59)) + 28|0);
           $61 = HEAP32[$60>>2]|0;
           __THREW__ = 0;
           $62 = (invoke_iii($61|0,($56|0),10)|0);
           $63 = __THREW__; __THREW__ = 0;
           $64 = $63&1;
           if (!($64)) {
            __THREW__ = 0;
            invoke_vi(3263,($6|0));
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             label = 22;
             break L7;
            }
            __THREW__ = 0;
            (invoke_iii(3268,($47|0),($62|0))|0);
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             label = 22;
             break L7;
            }
            __THREW__ = 0;
            (invoke_ii(3269,($47|0))|0);
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             label = 22;
             break L7;
            } else {
             break;
            }
           }
          }
          $65 = ___cxa_find_matching_catch_2()|0;
          $66 = tempRet0;
          __THREW__ = 0;
          invoke_vi(3263,($6|0));
          $67 = __THREW__; __THREW__ = 0;
          $68 = $67&1;
          if ($68) {
           $69 = ___cxa_find_matching_catch_3(0|0)|0;
           $70 = tempRet0;
           ___clang_call_terminate($69);
           // unreachable;
          } else {
           $eh$lpad$body$index3Z2D = $66;$eh$lpad$body$indexZ2D = $65;
           label = 23;
           break L7;
          }
         }
        } while(0);
        HEAP32[$0>>2] = 2;
        $81 = ((($0)) + 4|0);
        ;HEAP32[$81>>2]=0|0;HEAP32[$81+4>>2]=0|0;HEAP32[$81+8>>2]=0|0;
       }
      }
      do {
       if ((label|0) == 25) {
        __THREW__ = 0;
        $82 = (invoke_ii(3265,4)|0);
        $83 = __THREW__; __THREW__ = 0;
        $84 = $83&1;
        if ($84) {
         label = 22;
         break L7;
        }
        do {
         if ($82) {
          __THREW__ = 0;
          $85 = (invoke_ii(3266,4)|0);
          $86 = __THREW__; __THREW__ = 0;
          $87 = $86&1;
          if ($87) {
           label = 22;
           break L7;
          }
          __THREW__ = 0;
          $88 = (invoke_iiii(3267,($85|0),(172450|0),29)|0);
          $89 = __THREW__; __THREW__ = 0;
          $90 = $89&1;
          if ($90) {
           label = 22;
           break L7;
          }
          $91 = ((($3)) + 11|0);
          $92 = HEAP8[$91>>0]|0;
          $93 = ($92<<24>>24)<(0);
          $94 = HEAP32[$3>>2]|0;
          $95 = $93 ? $94 : $3;
          $96 = ((($3)) + 4|0);
          $97 = HEAP32[$96>>2]|0;
          $98 = $92&255;
          $99 = $93 ? $97 : $98;
          __THREW__ = 0;
          $100 = (invoke_iiii(3267,($88|0),($95|0),($99|0))|0);
          $101 = __THREW__; __THREW__ = 0;
          $102 = $101&1;
          if ($102) {
           label = 22;
           break L7;
          }
          __THREW__ = 0;
          $103 = (invoke_iiii(3267,($100|0),(172217|0),5)|0);
          $104 = __THREW__; __THREW__ = 0;
          $105 = $104&1;
          if ($105) {
           label = 22;
           break L7;
          }
          $106 = HEAP8[$13>>0]|0;
          $107 = ($106<<24>>24)<(0);
          $108 = HEAP32[$7>>2]|0;
          $109 = $107 ? $108 : $7;
          $110 = HEAP32[$16>>2]|0;
          $111 = $106&255;
          $112 = $107 ? $110 : $111;
          __THREW__ = 0;
          $113 = (invoke_iiii(3267,($103|0),($109|0),($112|0))|0);
          $114 = __THREW__; __THREW__ = 0;
          $115 = $114&1;
          if ($115) {
           label = 22;
           break L7;
          }
          $116 = HEAP32[$113>>2]|0;
          $117 = ((($116)) + -12|0);
          $118 = HEAP32[$117>>2]|0;
          $119 = (($113) + ($118)|0);
          __THREW__ = 0;
          invoke_vii(3257,($5|0),($119|0));
          $120 = __THREW__; __THREW__ = 0;
          $121 = $120&1;
          if ($121) {
           label = 22;
           break L7;
          }
          __THREW__ = 0;
          $122 = (invoke_iii(3255,($5|0),(215188|0))|0);
          $123 = __THREW__; __THREW__ = 0;
          $124 = $123&1;
          if (!($124)) {
           $125 = HEAP32[$122>>2]|0;
           $126 = ((($125)) + 28|0);
           $127 = HEAP32[$126>>2]|0;
           __THREW__ = 0;
           $128 = (invoke_iii($127|0,($122|0),10)|0);
           $129 = __THREW__; __THREW__ = 0;
           $130 = $129&1;
           if (!($130)) {
            __THREW__ = 0;
            invoke_vi(3263,($5|0));
            $137 = __THREW__; __THREW__ = 0;
            $138 = $137&1;
            if ($138) {
             label = 22;
             break L7;
            }
            __THREW__ = 0;
            (invoke_iii(3268,($113|0),($128|0))|0);
            $139 = __THREW__; __THREW__ = 0;
            $140 = $139&1;
            if ($140) {
             label = 22;
             break L7;
            }
            __THREW__ = 0;
            (invoke_ii(3269,($113|0))|0);
            $141 = __THREW__; __THREW__ = 0;
            $142 = $141&1;
            if ($142) {
             label = 22;
             break L7;
            } else {
             break;
            }
           }
          }
          $131 = ___cxa_find_matching_catch_2()|0;
          $132 = tempRet0;
          __THREW__ = 0;
          invoke_vi(3263,($5|0));
          $133 = __THREW__; __THREW__ = 0;
          $134 = $133&1;
          if ($134) {
           $135 = ___cxa_find_matching_catch_3(0|0)|0;
           $136 = tempRet0;
           ___clang_call_terminate($135);
           // unreachable;
          } else {
           $eh$lpad$body$index3Z2D = $132;$eh$lpad$body$indexZ2D = $131;
           label = 23;
           break L7;
          }
         }
        } while(0);
        __THREW__ = 0;
        $143 = (invoke_ii(3482,0)|0);
        $144 = __THREW__; __THREW__ = 0;
        $145 = $144&1;
        if ($145) {
         label = 22;
         break L7;
        }
        $146 = ($4|0)==(0|0);
        if ($146) {
         label = 45;
        } else {
         $147 = ((($4)) + 120|0);
         $148 = HEAP32[$147>>2]|0;
         $149 = ($148|0)==(0|0);
         if ($149) {
          label = 45;
         } else {
          $150 = HEAP32[$148>>2]|0;
          $151 = ((($150)) + 4|0);
          $152 = HEAP32[$151>>2]|0;
          __THREW__ = 0;
          invoke_viiiii($152|0,($9|0),($148|0),($2|0),($7|0),($4|0));
          $153 = __THREW__; __THREW__ = 0;
          $154 = $153&1;
          if ($154) {
           label = 22;
           break L7;
          }
         }
        }
        do {
         if ((label|0) == 45) {
          $155 = ((($143)) + 52|0);
          $156 = HEAP32[$155>>2]|0;
          $157 = ($156|0)==(0|0);
          if ($157) {
           __THREW__ = 0;
           invoke_viiiii(4236,($9|0),($143|0),($2|0),($7|0),($4|0));
           $163 = __THREW__; __THREW__ = 0;
           $164 = $163&1;
           if ($164) {
            label = 22;
            break L7;
           } else {
            break;
           }
          } else {
           $158 = HEAP32[$156>>2]|0;
           $159 = ((($158)) + 4|0);
           $160 = HEAP32[$159>>2]|0;
           __THREW__ = 0;
           invoke_viiiii($160|0,($9|0),($156|0),($2|0),($7|0),($4|0));
           $161 = __THREW__; __THREW__ = 0;
           $162 = $161&1;
           if ($162) {
            label = 22;
            break L7;
           } else {
            break;
           }
          }
         }
        } while(0);
        $165 = HEAP32[$9>>2]|0;
        $166 = ($165|0)==(3);
        if ($166) {
         __THREW__ = 0;
         (invoke_iii(4237,($1|0),($3|0))|0);
         $167 = __THREW__; __THREW__ = 0;
         $168 = $167&1;
         if (!($168)) {
          $$pre = HEAP32[$9>>2]|0;
          $176 = $$pre;
          label = 53;
         }
        } else {
         $176 = $165;
         label = 53;
        }
        if ((label|0) == 53) {
         HEAP32[$0>>2] = $176;
         $177 = ((($0)) + 4|0);
         $178 = ((($9)) + 4|0);
         __THREW__ = 0;
         invoke_vii(3457,($177|0),($178|0));
         $179 = __THREW__; __THREW__ = 0;
         $180 = $179&1;
         if (!($180)) {
          $181 = ((($178)) + 11|0);
          $182 = HEAP8[$181>>0]|0;
          $183 = ($182<<24>>24)<(0);
          if ($183) {
           $184 = HEAP32[$178>>2]|0;
           __ZdlPv($184);
          }
          break;
         }
        }
        $169 = ___cxa_find_matching_catch_2()|0;
        $170 = tempRet0;
        $171 = ((($9)) + 4|0);
        $172 = ((($171)) + 11|0);
        $173 = HEAP8[$172>>0]|0;
        $174 = ($173<<24>>24)<(0);
        if ($174) {
         $175 = HEAP32[$171>>2]|0;
         __ZdlPv($175);
        }
        $$1 = $170;$$18 = $169;
        break L7;
       }
      } while(0);
      $185 = ((($8)) + 11|0);
      $186 = HEAP8[$185>>0]|0;
      $187 = ($186<<24>>24)<(0);
      if ($187) {
       $188 = HEAP32[$8>>2]|0;
       __ZdlPv($188);
      }
      $$pre39 = HEAP8[$13>>0]|0;
      $194 = $$pre39;
      break L1;
     }
    } while(0);
    if ((label|0) == 22) {
     $79 = ___cxa_find_matching_catch_2()|0;
     $80 = tempRet0;
     $eh$lpad$body$index3Z2D = $80;$eh$lpad$body$indexZ2D = $79;
     label = 23;
    }
    if ((label|0) == 23) {
     $$1 = $eh$lpad$body$index3Z2D;$$18 = $eh$lpad$body$indexZ2D;
    }
    $189 = ((($8)) + 11|0);
    $190 = HEAP8[$189>>0]|0;
    $191 = ($190<<24>>24)<(0);
    if ($191) {
     $192 = HEAP32[$8>>2]|0;
     __ZdlPv($192);
    }
    $$2 = $$1;$$29 = $$18;
   }
   $197 = HEAP8[$13>>0]|0;
   $198 = ($197<<24>>24)<(0);
   if (!($198)) {
    ___resumeException($$29|0);
    // unreachable;
   }
   $199 = HEAP32[$7>>2]|0;
   __ZdlPv($199);
   ___resumeException($$29|0);
   // unreachable;
  }
 } while(0);
 $195 = ($194<<24>>24)<(0);
 if (!($195)) {
  STACKTOP = sp;return;
 }
 $196 = HEAP32[$7>>2]|0;
 __ZdlPv($196);
 STACKTOP = sp;return;
}
function __ZNK5osgDB9FileCache10readObjectERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEPKNS_7OptionsE($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $4 = sp + 12|0;
 $5 = sp;
 $6 = HEAP32[$1>>2]|0;
 $7 = ((($6)) + 16|0);
 $8 = HEAP32[$7>>2]|0;
 FUNCTION_TABLE_viii[$8 & 8191]($5,$1,$2);
 $9 = ((($5)) + 11|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = ($10<<24>>24)<(0);
 $12 = ((($5)) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $10&255;
 $15 = $11 ? $13 : $14;
 $16 = ($15|0)==(0);
 L1: do {
  if ($16) {
   label = 26;
  } else {
   __THREW__ = 0;
   $17 = (invoke_ii(4195,($5|0))|0);
   $18 = __THREW__; __THREW__ = 0;
   $19 = $18&1;
   L3: do {
    if ($19) {
     label = 20;
    } else {
     if (!($17)) {
      label = 26;
      break L1;
     }
     __THREW__ = 0;
     $20 = (invoke_ii(3265,4)|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      label = 20;
     } else {
      do {
       if ($20) {
        __THREW__ = 0;
        $23 = (invoke_ii(3266,4)|0);
        $24 = __THREW__; __THREW__ = 0;
        $25 = $24&1;
        if ($25) {
         label = 20;
         break L3;
        }
        __THREW__ = 0;
        $26 = (invoke_iiii(3267,($23|0),(172418|0),31)|0);
        $27 = __THREW__; __THREW__ = 0;
        $28 = $27&1;
        if ($28) {
         label = 20;
         break L3;
        }
        $29 = ((($2)) + 11|0);
        $30 = HEAP8[$29>>0]|0;
        $31 = ($30<<24>>24)<(0);
        $32 = HEAP32[$2>>2]|0;
        $33 = $31 ? $32 : $2;
        $34 = ((($2)) + 4|0);
        $35 = HEAP32[$34>>2]|0;
        $36 = $30&255;
        $37 = $31 ? $35 : $36;
        __THREW__ = 0;
        $38 = (invoke_iiii(3267,($26|0),($33|0),($37|0))|0);
        $39 = __THREW__; __THREW__ = 0;
        $40 = $39&1;
        if ($40) {
         label = 20;
         break L3;
        }
        __THREW__ = 0;
        $41 = (invoke_iiii(3267,($38|0),(172217|0),5)|0);
        $42 = __THREW__; __THREW__ = 0;
        $43 = $42&1;
        if ($43) {
         label = 20;
         break L3;
        }
        $44 = HEAP8[$9>>0]|0;
        $45 = ($44<<24>>24)<(0);
        $46 = HEAP32[$5>>2]|0;
        $47 = $45 ? $46 : $5;
        $48 = HEAP32[$12>>2]|0;
        $49 = $44&255;
        $50 = $45 ? $48 : $49;
        __THREW__ = 0;
        $51 = (invoke_iiii(3267,($41|0),($47|0),($50|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 20;
         break L3;
        }
        $54 = HEAP32[$51>>2]|0;
        $55 = ((($54)) + -12|0);
        $56 = HEAP32[$55>>2]|0;
        $57 = (($51) + ($56)|0);
        __THREW__ = 0;
        invoke_vii(3257,($4|0),($57|0));
        $58 = __THREW__; __THREW__ = 0;
        $59 = $58&1;
        if ($59) {
         label = 20;
         break L3;
        }
        __THREW__ = 0;
        $60 = (invoke_iii(3255,($4|0),(215188|0))|0);
        $61 = __THREW__; __THREW__ = 0;
        $62 = $61&1;
        if (!($62)) {
         $63 = HEAP32[$60>>2]|0;
         $64 = ((($63)) + 28|0);
         $65 = HEAP32[$64>>2]|0;
         __THREW__ = 0;
         $66 = (invoke_iii($65|0,($60|0),10)|0);
         $67 = __THREW__; __THREW__ = 0;
         $68 = $67&1;
         if (!($68)) {
          __THREW__ = 0;
          invoke_vi(3263,($4|0));
          $75 = __THREW__; __THREW__ = 0;
          $76 = $75&1;
          if ($76) {
           label = 20;
           break L3;
          }
          __THREW__ = 0;
          (invoke_iii(3268,($51|0),($66|0))|0);
          $77 = __THREW__; __THREW__ = 0;
          $78 = $77&1;
          if ($78) {
           label = 20;
           break L3;
          }
          __THREW__ = 0;
          (invoke_ii(3269,($51|0))|0);
          $79 = __THREW__; __THREW__ = 0;
          $80 = $79&1;
          if ($80) {
           label = 20;
           break L3;
          } else {
           break;
          }
         }
        }
        $69 = ___cxa_find_matching_catch_2()|0;
        $70 = tempRet0;
        __THREW__ = 0;
        invoke_vi(3263,($4|0));
        $71 = __THREW__; __THREW__ = 0;
        $72 = $71&1;
        if ($72) {
         $73 = ___cxa_find_matching_catch_3(0|0)|0;
         $74 = tempRet0;
         ___clang_call_terminate($73);
         // unreachable;
        } else {
         $eh$lpad$body$index2Z2D = $70;$eh$lpad$body$indexZ2D = $69;
         break L3;
        }
       }
      } while(0);
      __THREW__ = 0;
      $86 = (invoke_ii(3482,0)|0);
      $87 = __THREW__; __THREW__ = 0;
      $88 = $87&1;
      if ($88) {
       label = 20;
      } else {
       __THREW__ = 0;
       invoke_viiiii(4238,($0|0),($86|0),($5|0),($3|0),1);
       $89 = __THREW__; __THREW__ = 0;
       $90 = $89&1;
       if ($90) {
        label = 20;
       } else {
        break L1;
       }
      }
     }
    }
   } while(0);
   if ((label|0) == 20) {
    $81 = ___cxa_find_matching_catch_2()|0;
    $82 = tempRet0;
    $eh$lpad$body$index2Z2D = $82;$eh$lpad$body$indexZ2D = $81;
   }
   $83 = HEAP8[$9>>0]|0;
   $84 = ($83<<24>>24)<(0);
   if (!($84)) {
    ___resumeException($eh$lpad$body$indexZ2D|0);
    // unreachable;
   }
   $85 = HEAP32[$5>>2]|0;
   __ZdlPv($85);
   ___resumeException($eh$lpad$body$indexZ2D|0);
   // unreachable;
  }
 } while(0);
 if ((label|0) == 26) {
  HEAP32[$0>>2] = 4;
  $91 = ((($0)) + 4|0);
  ;HEAP32[$91>>2]=0|0;HEAP32[$91+4>>2]=0|0;HEAP32[$91+8>>2]=0|0;HEAP32[$91+12>>2]=0|0;
 }
 $92 = HEAP8[$9>>0]|0;
 $93 = ($92<<24>>24)<(0);
 if (!($93)) {
  STACKTOP = sp;return;
 }
 $94 = HEAP32[$5>>2]|0;
 __ZdlPv($94);
 STACKTOP = sp;return;
}
function __ZNK5osgDB9FileCache11writeObjectERKN3osg6ObjectERKNSt3__212basic_stringIcNS5_11char_traitsIcEENS5_9allocatorIcEEEEPKNS_7OptionsE($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$1 = 0, $$18 = 0, $$2 = 0, $$29 = 0, $$pre = 0, $$pre39 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index3Z2D = 0;
 var $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $5 = sp + 44|0;
 $6 = sp + 40|0;
 $7 = sp + 28|0;
 $8 = sp + 16|0;
 $9 = sp;
 $10 = HEAP32[$1>>2]|0;
 $11 = ((($10)) + 16|0);
 $12 = HEAP32[$11>>2]|0;
 FUNCTION_TABLE_viii[$12 & 8191]($7,$1,$3);
 $13 = ((($7)) + 11|0);
 $14 = HEAP8[$13>>0]|0;
 $15 = ($14<<24>>24)<(0);
 $16 = ((($7)) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = $14&255;
 $19 = $15 ? $17 : $18;
 $20 = ($19|0)==(0);
 L1: do {
  if ($20) {
   HEAP32[$0>>2] = 1;
   $191 = ((($0)) + 4|0);
   ;HEAP32[$191>>2]=0|0;HEAP32[$191+4>>2]=0|0;HEAP32[$191+8>>2]=0|0;
   $192 = $14;
  } else {
   __THREW__ = 0;
   invoke_vii(4234,($8|0),($7|0));
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if ($22) {
    $77 = ___cxa_find_matching_catch_2()|0;
    $78 = tempRet0;
    $$2 = $78;$$29 = $77;
   } else {
    __THREW__ = 0;
    $23 = (invoke_ii(4195,($8|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    L7: do {
     if ($25) {
      label = 22;
     } else {
      if ($23) {
       label = 25;
      } else {
       __THREW__ = 0;
       $26 = (invoke_ii(4235,($8|0))|0);
       $27 = __THREW__; __THREW__ = 0;
       $28 = $27&1;
       if ($28) {
        label = 22;
        break;
       }
       if ($26) {
        label = 25;
       } else {
        __THREW__ = 0;
        $29 = (invoke_ii(3265,3)|0);
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if ($31) {
         label = 22;
         break;
        }
        do {
         if ($29) {
          __THREW__ = 0;
          $32 = (invoke_ii(3266,3)|0);
          $33 = __THREW__; __THREW__ = 0;
          $34 = $33&1;
          if ($34) {
           label = 22;
           break L7;
          }
          __THREW__ = 0;
          $35 = (invoke_iiii(3267,($32|0),(172151|0),34)|0);
          $36 = __THREW__; __THREW__ = 0;
          $37 = $36&1;
          if ($37) {
           label = 22;
           break L7;
          }
          $38 = ((($8)) + 11|0);
          $39 = HEAP8[$38>>0]|0;
          $40 = ($39<<24>>24)<(0);
          $41 = HEAP32[$8>>2]|0;
          $42 = $40 ? $41 : $8;
          $43 = ((($8)) + 4|0);
          $44 = HEAP32[$43>>2]|0;
          $45 = $39&255;
          $46 = $40 ? $44 : $45;
          __THREW__ = 0;
          $47 = (invoke_iiii(3267,($35|0),($42|0),($46|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           label = 22;
           break L7;
          }
          $50 = HEAP32[$47>>2]|0;
          $51 = ((($50)) + -12|0);
          $52 = HEAP32[$51>>2]|0;
          $53 = (($47) + ($52)|0);
          __THREW__ = 0;
          invoke_vii(3257,($6|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           label = 22;
           break L7;
          }
          __THREW__ = 0;
          $56 = (invoke_iii(3255,($6|0),(215188|0))|0);
          $57 = __THREW__; __THREW__ = 0;
          $58 = $57&1;
          if (!($58)) {
           $59 = HEAP32[$56>>2]|0;
           $60 = ((($59)) + 28|0);
           $61 = HEAP32[$60>>2]|0;
           __THREW__ = 0;
           $62 = (invoke_iii($61|0,($56|0),10)|0);
           $63 = __THREW__; __THREW__ = 0;
           $64 = $63&1;
           if (!($64)) {
            __THREW__ = 0;
            invoke_vi(3263,($6|0));
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             label = 22;
             break L7;
            }
            __THREW__ = 0;
            (invoke_iii(3268,($47|0),($62|0))|0);
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             label = 22;
             break L7;
            }
            __THREW__ = 0;
            (invoke_ii(3269,($47|0))|0);
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             label = 22;
             break L7;
            } else {
             break;
            }
           }
          }
          $65 = ___cxa_find_matching_catch_2()|0;
          $66 = tempRet0;
          __THREW__ = 0;
          invoke_vi(3263,($6|0));
          $67 = __THREW__; __THREW__ = 0;
          $68 = $67&1;
          if ($68) {
           $69 = ___cxa_find_matching_catch_3(0|0)|0;
           $70 = tempRet0;
           ___clang_call_terminate($69);
           // unreachable;
          } else {
           $eh$lpad$body$index3Z2D = $66;$eh$lpad$body$indexZ2D = $65;
           label = 23;
           break L7;
          }
         }
        } while(0);
        HEAP32[$0>>2] = 2;
        $81 = ((($0)) + 4|0);
        ;HEAP32[$81>>2]=0|0;HEAP32[$81+4>>2]=0|0;HEAP32[$81+8>>2]=0|0;
       }
      }
      do {
       if ((label|0) == 25) {
        __THREW__ = 0;
        $82 = (invoke_ii(3265,4)|0);
        $83 = __THREW__; __THREW__ = 0;
        $84 = $83&1;
        if ($84) {
         label = 22;
         break L7;
        }
        do {
         if ($82) {
          __THREW__ = 0;
          $85 = (invoke_ii(3266,4)|0);
          $86 = __THREW__; __THREW__ = 0;
          $87 = $86&1;
          if ($87) {
           label = 22;
           break L7;
          }
          __THREW__ = 0;
          $88 = (invoke_iiii(3267,($85|0),(172387|0),30)|0);
          $89 = __THREW__; __THREW__ = 0;
          $90 = $89&1;
          if ($90) {
           label = 22;
           break L7;
          }
          $91 = ((($3)) + 11|0);
          $92 = HEAP8[$91>>0]|0;
          $93 = ($92<<24>>24)<(0);
          $94 = HEAP32[$3>>2]|0;
          $95 = $93 ? $94 : $3;
          $96 = ((($3)) + 4|0);
          $97 = HEAP32[$96>>2]|0;
          $98 = $92&255;
          $99 = $93 ? $97 : $98;
          __THREW__ = 0;
          $100 = (invoke_iiii(3267,($88|0),($95|0),($99|0))|0);
          $101 = __THREW__; __THREW__ = 0;
          $102 = $101&1;
          if ($102) {
           label = 22;
           break L7;
          }
          __THREW__ = 0;
          $103 = (invoke_iiii(3267,($100|0),(172217|0),5)|0);
          $104 = __THREW__; __THREW__ = 0;
          $105 = $104&1;
          if ($105) {
           label = 22;
           break L7;
          }
          $106 = HEAP8[$13>>0]|0;
          $107 = ($106<<24>>24)<(0);
          $108 = HEAP32[$7>>2]|0;
          $109 = $107 ? $108 : $7;
          $110 = HEAP32[$16>>2]|0;
          $111 = $106&255;
          $112 = $107 ? $110 : $111;
          __THREW__ = 0;
          $113 = (invoke_iiii(3267,($103|0),($109|0),($112|0))|0);
          $114 = __THREW__; __THREW__ = 0;
          $115 = $114&1;
          if ($115) {
           label = 22;
           break L7;
          }
          $116 = HEAP32[$113>>2]|0;
          $117 = ((($116)) + -12|0);
          $118 = HEAP32[$117>>2]|0;
          $119 = (($113) + ($118)|0);
          __THREW__ = 0;
          invoke_vii(3257,($5|0),($119|0));
          $120 = __THREW__; __THREW__ = 0;
          $121 = $120&1;
          if ($121) {
           label = 22;
           break L7;
          }
          __THREW__ = 0;
          $122 = (invoke_iii(3255,($5|0),(215188|0))|0);
          $123 = __THREW__; __THREW__ = 0;
          $124 = $123&1;
          if (!($124)) {
           $125 = HEAP32[$122>>2]|0;
           $126 = ((($125)) + 28|0);
           $127 = HEAP32[$126>>2]|0;
           __THREW__ = 0;
           $128 = (invoke_iii($127|0,($122|0),10)|0);
           $129 = __THREW__; __THREW__ = 0;
           $130 = $129&1;
           if (!($130)) {
            __THREW__ = 0;
            invoke_vi(3263,($5|0));
            $137 = __THREW__; __THREW__ = 0;
            $138 = $137&1;
            if ($138) {
             label = 22;
             break L7;
            }
            __THREW__ = 0;
            (invoke_iii(3268,($113|0),($128|0))|0);
            $139 = __THREW__; __THREW__ = 0;
            $140 = $139&1;
            if ($140) {
             label = 22;
             break L7;
            }
            __THREW__ = 0;
            (invoke_ii(3269,($113|0))|0);
            $141 = __THREW__; __THREW__ = 0;
            $142 = $141&1;
            if ($142) {
             label = 22;
             break L7;
            } else {
             break;
            }
           }
          }
          $131 = ___cxa_find_matching_catch_2()|0;
          $132 = tempRet0;
          __THREW__ = 0;
          invoke_vi(3263,($5|0));
          $133 = __THREW__; __THREW__ = 0;
          $134 = $133&1;
          if ($134) {
           $135 = ___cxa_find_matching_catch_3(0|0)|0;
           $136 = tempRet0;
           ___clang_call_terminate($135);
           // unreachable;
          } else {
           $eh$lpad$body$index3Z2D = $132;$eh$lpad$body$indexZ2D = $131;
           label = 23;
           break L7;
          }
         }
        } while(0);
        __THREW__ = 0;
        $143 = (invoke_ii(3482,0)|0);
        $144 = __THREW__; __THREW__ = 0;
        $145 = $144&1;
        if ($145) {
         label = 22;
         break L7;
        }
        $146 = ($4|0)==(0|0);
        if ($146) {
         label = 45;
        } else {
         $147 = ((($4)) + 120|0);
         $148 = HEAP32[$147>>2]|0;
         $149 = ($148|0)==(0|0);
         if ($149) {
          label = 45;
         } else {
          $150 = HEAP32[$148>>2]|0;
          $151 = HEAP32[$150>>2]|0;
          __THREW__ = 0;
          invoke_viiiii($151|0,($9|0),($148|0),($2|0),($7|0),($4|0));
          $152 = __THREW__; __THREW__ = 0;
          $153 = $152&1;
          if ($153) {
           label = 22;
           break L7;
          }
         }
        }
        do {
         if ((label|0) == 45) {
          $154 = ((($143)) + 52|0);
          $155 = HEAP32[$154>>2]|0;
          $156 = ($155|0)==(0|0);
          if ($156) {
           __THREW__ = 0;
           invoke_viiiii(4239,($9|0),($143|0),($2|0),($7|0),($4|0));
           $161 = __THREW__; __THREW__ = 0;
           $162 = $161&1;
           if ($162) {
            label = 22;
            break L7;
           } else {
            break;
           }
          } else {
           $157 = HEAP32[$155>>2]|0;
           $158 = HEAP32[$157>>2]|0;
           __THREW__ = 0;
           invoke_viiiii($158|0,($9|0),($155|0),($2|0),($7|0),($4|0));
           $159 = __THREW__; __THREW__ = 0;
           $160 = $159&1;
           if ($160) {
            label = 22;
            break L7;
           } else {
            break;
           }
          }
         }
        } while(0);
        $163 = HEAP32[$9>>2]|0;
        $164 = ($163|0)==(3);
        if ($164) {
         __THREW__ = 0;
         (invoke_iii(4237,($1|0),($3|0))|0);
         $165 = __THREW__; __THREW__ = 0;
         $166 = $165&1;
         if (!($166)) {
          $$pre = HEAP32[$9>>2]|0;
          $174 = $$pre;
          label = 53;
         }
        } else {
         $174 = $163;
         label = 53;
        }
        if ((label|0) == 53) {
         HEAP32[$0>>2] = $174;
         $175 = ((($0)) + 4|0);
         $176 = ((($9)) + 4|0);
         __THREW__ = 0;
         invoke_vii(3457,($175|0),($176|0));
         $177 = __THREW__; __THREW__ = 0;
         $178 = $177&1;
         if (!($178)) {
          $179 = ((($176)) + 11|0);
          $180 = HEAP8[$179>>0]|0;
          $181 = ($180<<24>>24)<(0);
          if ($181) {
           $182 = HEAP32[$176>>2]|0;
           __ZdlPv($182);
          }
          break;
         }
        }
        $167 = ___cxa_find_matching_catch_2()|0;
        $168 = tempRet0;
        $169 = ((($9)) + 4|0);
        $170 = ((($169)) + 11|0);
        $171 = HEAP8[$170>>0]|0;
        $172 = ($171<<24>>24)<(0);
        if ($172) {
         $173 = HEAP32[$169>>2]|0;
         __ZdlPv($173);
        }
        $$1 = $168;$$18 = $167;
        break L7;
       }
      } while(0);
      $183 = ((($8)) + 11|0);
      $184 = HEAP8[$183>>0]|0;
      $185 = ($184<<24>>24)<(0);
      if ($185) {
       $186 = HEAP32[$8>>2]|0;
       __ZdlPv($186);
      }
      $$pre39 = HEAP8[$13>>0]|0;
      $192 = $$pre39;
      break L1;
     }
    } while(0);
    if ((label|0) == 22) {
     $79 = ___cxa_find_matching_catch_2()|0;
     $80 = tempRet0;
     $eh$lpad$body$index3Z2D = $80;$eh$lpad$body$indexZ2D = $79;
     label = 23;
    }
    if ((label|0) == 23) {
     $$1 = $eh$lpad$body$index3Z2D;$$18 = $eh$lpad$body$indexZ2D;
    }
    $187 = ((($8)) + 11|0);
    $188 = HEAP8[$187>>0]|0;
    $189 = ($188<<24>>24)<(0);
    if ($189) {
     $190 = HEAP32[$8>>2]|0;
     __ZdlPv($190);
    }
    $$2 = $$1;$$29 = $$18;
   }
   $195 = HEAP8[$13>>0]|0;
   $196 = ($195<<24>>24)<(0);
   if (!($196)) {
    ___resumeException($$29|0);
    // unreachable;
   }
   $197 = HEAP32[$7>>2]|0;
   __ZdlPv($197);
   ___resumeException($$29|0);
   // unreachable;
  }
 } while(0);
 $193 = ($192<<24>>24)<(0);
 if (!($193)) {
  STACKTOP = sp;return;
 }
 $194 = HEAP32[$7>>2]|0;
 __ZdlPv($194);
 STACKTOP = sp;return;
}
function __ZNK5osgDB9FileCache15readHeightFieldERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEPKNS_7OptionsE($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $4 = sp + 12|0;
 $5 = sp;
 $6 = HEAP32[$1>>2]|0;
 $7 = ((($6)) + 16|0);
 $8 = HEAP32[$7>>2]|0;
 FUNCTION_TABLE_viii[$8 & 8191]($5,$1,$2);
 $9 = ((($5)) + 11|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = ($10<<24>>24)<(0);
 $12 = ((($5)) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $10&255;
 $15 = $11 ? $13 : $14;
 $16 = ($15|0)==(0);
 L1: do {
  if ($16) {
   label = 31;
  } else {
   __THREW__ = 0;
   $17 = (invoke_ii(4195,($5|0))|0);
   $18 = __THREW__; __THREW__ = 0;
   $19 = $18&1;
   L3: do {
    if ($19) {
     label = 20;
    } else {
     if (!($17)) {
      label = 31;
      break L1;
     }
     __THREW__ = 0;
     $20 = (invoke_ii(3265,4)|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      label = 20;
     } else {
      do {
       if ($20) {
        __THREW__ = 0;
        $23 = (invoke_ii(3266,4)|0);
        $24 = __THREW__; __THREW__ = 0;
        $25 = $24&1;
        if ($25) {
         label = 20;
         break L3;
        }
        __THREW__ = 0;
        $26 = (invoke_iiii(3267,($23|0),(172350|0),36)|0);
        $27 = __THREW__; __THREW__ = 0;
        $28 = $27&1;
        if ($28) {
         label = 20;
         break L3;
        }
        $29 = ((($2)) + 11|0);
        $30 = HEAP8[$29>>0]|0;
        $31 = ($30<<24>>24)<(0);
        $32 = HEAP32[$2>>2]|0;
        $33 = $31 ? $32 : $2;
        $34 = ((($2)) + 4|0);
        $35 = HEAP32[$34>>2]|0;
        $36 = $30&255;
        $37 = $31 ? $35 : $36;
        __THREW__ = 0;
        $38 = (invoke_iiii(3267,($26|0),($33|0),($37|0))|0);
        $39 = __THREW__; __THREW__ = 0;
        $40 = $39&1;
        if ($40) {
         label = 20;
         break L3;
        }
        __THREW__ = 0;
        $41 = (invoke_iiii(3267,($38|0),(172217|0),5)|0);
        $42 = __THREW__; __THREW__ = 0;
        $43 = $42&1;
        if ($43) {
         label = 20;
         break L3;
        }
        $44 = HEAP8[$9>>0]|0;
        $45 = ($44<<24>>24)<(0);
        $46 = HEAP32[$5>>2]|0;
        $47 = $45 ? $46 : $5;
        $48 = HEAP32[$12>>2]|0;
        $49 = $44&255;
        $50 = $45 ? $48 : $49;
        __THREW__ = 0;
        $51 = (invoke_iiii(3267,($41|0),($47|0),($50|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 20;
         break L3;
        }
        $54 = HEAP32[$51>>2]|0;
        $55 = ((($54)) + -12|0);
        $56 = HEAP32[$55>>2]|0;
        $57 = (($51) + ($56)|0);
        __THREW__ = 0;
        invoke_vii(3257,($4|0),($57|0));
        $58 = __THREW__; __THREW__ = 0;
        $59 = $58&1;
        if ($59) {
         label = 20;
         break L3;
        }
        __THREW__ = 0;
        $60 = (invoke_iii(3255,($4|0),(215188|0))|0);
        $61 = __THREW__; __THREW__ = 0;
        $62 = $61&1;
        if (!($62)) {
         $63 = HEAP32[$60>>2]|0;
         $64 = ((($63)) + 28|0);
         $65 = HEAP32[$64>>2]|0;
         __THREW__ = 0;
         $66 = (invoke_iii($65|0,($60|0),10)|0);
         $67 = __THREW__; __THREW__ = 0;
         $68 = $67&1;
         if (!($68)) {
          __THREW__ = 0;
          invoke_vi(3263,($4|0));
          $75 = __THREW__; __THREW__ = 0;
          $76 = $75&1;
          if ($76) {
           label = 20;
           break L3;
          }
          __THREW__ = 0;
          (invoke_iii(3268,($51|0),($66|0))|0);
          $77 = __THREW__; __THREW__ = 0;
          $78 = $77&1;
          if ($78) {
           label = 20;
           break L3;
          }
          __THREW__ = 0;
          (invoke_ii(3269,($51|0))|0);
          $79 = __THREW__; __THREW__ = 0;
          $80 = $79&1;
          if ($80) {
           label = 20;
           break L3;
          } else {
           break;
          }
         }
        }
        $69 = ___cxa_find_matching_catch_2()|0;
        $70 = tempRet0;
        __THREW__ = 0;
        invoke_vi(3263,($4|0));
        $71 = __THREW__; __THREW__ = 0;
        $72 = $71&1;
        if ($72) {
         $73 = ___cxa_find_matching_catch_3(0|0)|0;
         $74 = tempRet0;
         ___clang_call_terminate($73);
         // unreachable;
        } else {
         $eh$lpad$body$index2Z2D = $70;$eh$lpad$body$indexZ2D = $69;
         break L3;
        }
       }
      } while(0);
      __THREW__ = 0;
      $86 = (invoke_ii(3482,0)|0);
      $87 = __THREW__; __THREW__ = 0;
      $88 = $87&1;
      if ($88) {
       label = 20;
      } else {
       $89 = ($3|0)==(0|0);
       if (!($89)) {
        $90 = ((($3)) + 116|0);
        $91 = HEAP32[$90>>2]|0;
        $92 = ($91|0)==(0|0);
        if (!($92)) {
         $93 = HEAP32[$91>>2]|0;
         $94 = ((($93)) + 12|0);
         $95 = HEAP32[$94>>2]|0;
         __THREW__ = 0;
         invoke_viiii($95|0,($0|0),($91|0),($5|0),($3|0));
         $96 = __THREW__; __THREW__ = 0;
         $97 = $96&1;
         if ($97) {
          label = 20;
          break;
         } else {
          break L1;
         }
        }
       }
       $98 = ((($86)) + 48|0);
       $99 = HEAP32[$98>>2]|0;
       $100 = ($99|0)==(0|0);
       if ($100) {
        __THREW__ = 0;
        invoke_viiii(4240,($0|0),($86|0),($5|0),($3|0));
        $106 = __THREW__; __THREW__ = 0;
        $107 = $106&1;
        if ($107) {
         label = 20;
         break;
        } else {
         break L1;
        }
       } else {
        $101 = HEAP32[$99>>2]|0;
        $102 = ((($101)) + 12|0);
        $103 = HEAP32[$102>>2]|0;
        __THREW__ = 0;
        invoke_viiii($103|0,($0|0),($99|0),($5|0),($3|0));
        $104 = __THREW__; __THREW__ = 0;
        $105 = $104&1;
        if ($105) {
         label = 20;
         break;
        } else {
         break L1;
        }
       }
      }
     }
    }
   } while(0);
   if ((label|0) == 20) {
    $81 = ___cxa_find_matching_catch_2()|0;
    $82 = tempRet0;
    $eh$lpad$body$index2Z2D = $82;$eh$lpad$body$indexZ2D = $81;
   }
   $83 = HEAP8[$9>>0]|0;
   $84 = ($83<<24>>24)<(0);
   if (!($84)) {
    ___resumeException($eh$lpad$body$indexZ2D|0);
    // unreachable;
   }
   $85 = HEAP32[$5>>2]|0;
   __ZdlPv($85);
   ___resumeException($eh$lpad$body$indexZ2D|0);
   // unreachable;
  }
 } while(0);
 if ((label|0) == 31) {
  HEAP32[$0>>2] = 4;
  $108 = ((($0)) + 4|0);
  ;HEAP32[$108>>2]=0|0;HEAP32[$108+4>>2]=0|0;HEAP32[$108+8>>2]=0|0;HEAP32[$108+12>>2]=0|0;
 }
 $109 = HEAP8[$9>>0]|0;
 $110 = ($109<<24>>24)<(0);
 if (!($110)) {
  STACKTOP = sp;return;
 }
 $111 = HEAP32[$5>>2]|0;
 __ZdlPv($111);
 STACKTOP = sp;return;
}
function __ZNK5osgDB9FileCache16writeHeightFieldERKN3osg11HeightFieldERKNSt3__212basic_stringIcNS5_11char_traitsIcEENS5_9allocatorIcEEEEPKNS_7OptionsE($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$1 = 0, $$18 = 0, $$2 = 0, $$29 = 0, $$pre = 0, $$pre39 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $eh$lpad$body$index3Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $5 = sp + 44|0;
 $6 = sp + 40|0;
 $7 = sp + 28|0;
 $8 = sp + 16|0;
 $9 = sp;
 $10 = HEAP32[$1>>2]|0;
 $11 = ((($10)) + 16|0);
 $12 = HEAP32[$11>>2]|0;
 FUNCTION_TABLE_viii[$12 & 8191]($7,$1,$3);
 $13 = ((($7)) + 11|0);
 $14 = HEAP8[$13>>0]|0;
 $15 = ($14<<24>>24)<(0);
 $16 = ((($7)) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = $14&255;
 $19 = $15 ? $17 : $18;
 $20 = ($19|0)==(0);
 L1: do {
  if ($20) {
   HEAP32[$0>>2] = 1;
   $193 = ((($0)) + 4|0);
   ;HEAP32[$193>>2]=0|0;HEAP32[$193+4>>2]=0|0;HEAP32[$193+8>>2]=0|0;
   $194 = $14;
  } else {
   __THREW__ = 0;
   invoke_vii(4234,($8|0),($7|0));
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if ($22) {
    $77 = ___cxa_find_matching_catch_2()|0;
    $78 = tempRet0;
    $$2 = $78;$$29 = $77;
   } else {
    __THREW__ = 0;
    $23 = (invoke_ii(4195,($8|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    L7: do {
     if ($25) {
      label = 22;
     } else {
      if ($23) {
       label = 25;
      } else {
       __THREW__ = 0;
       $26 = (invoke_ii(4235,($8|0))|0);
       $27 = __THREW__; __THREW__ = 0;
       $28 = $27&1;
       if ($28) {
        label = 22;
        break;
       }
       if ($26) {
        label = 25;
       } else {
        __THREW__ = 0;
        $29 = (invoke_ii(3265,3)|0);
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if ($31) {
         label = 22;
         break;
        }
        do {
         if ($29) {
          __THREW__ = 0;
          $32 = (invoke_ii(3266,3)|0);
          $33 = __THREW__; __THREW__ = 0;
          $34 = $33&1;
          if ($34) {
           label = 22;
           break L7;
          }
          __THREW__ = 0;
          $35 = (invoke_iiii(3267,($32|0),(172151|0),34)|0);
          $36 = __THREW__; __THREW__ = 0;
          $37 = $36&1;
          if ($37) {
           label = 22;
           break L7;
          }
          $38 = ((($8)) + 11|0);
          $39 = HEAP8[$38>>0]|0;
          $40 = ($39<<24>>24)<(0);
          $41 = HEAP32[$8>>2]|0;
          $42 = $40 ? $41 : $8;
          $43 = ((($8)) + 4|0);
          $44 = HEAP32[$43>>2]|0;
          $45 = $39&255;
          $46 = $40 ? $44 : $45;
          __THREW__ = 0;
          $47 = (invoke_iiii(3267,($35|0),($42|0),($46|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           label = 22;
           break L7;
          }
          $50 = HEAP32[$47>>2]|0;
          $51 = ((($50)) + -12|0);
          $52 = HEAP32[$51>>2]|0;
          $53 = (($47) + ($52)|0);
          __THREW__ = 0;
          invoke_vii(3257,($6|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           label = 22;
           break L7;
          }
          __THREW__ = 0;
          $56 = (invoke_iii(3255,($6|0),(215188|0))|0);
          $57 = __THREW__; __THREW__ = 0;
          $58 = $57&1;
          if (!($58)) {
           $59 = HEAP32[$56>>2]|0;
           $60 = ((($59)) + 28|0);
           $61 = HEAP32[$60>>2]|0;
           __THREW__ = 0;
           $62 = (invoke_iii($61|0,($56|0),10)|0);
           $63 = __THREW__; __THREW__ = 0;
           $64 = $63&1;
           if (!($64)) {
            __THREW__ = 0;
            invoke_vi(3263,($6|0));
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             label = 22;
             break L7;
            }
            __THREW__ = 0;
            (invoke_iii(3268,($47|0),($62|0))|0);
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             label = 22;
             break L7;
            }
            __THREW__ = 0;
            (invoke_ii(3269,($47|0))|0);
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             label = 22;
             break L7;
            } else {
             break;
            }
           }
          }
          $65 = ___cxa_find_matching_catch_2()|0;
          $66 = tempRet0;
          __THREW__ = 0;
          invoke_vi(3263,($6|0));
          $67 = __THREW__; __THREW__ = 0;
          $68 = $67&1;
          if ($68) {
           $69 = ___cxa_find_matching_catch_3(0|0)|0;
           $70 = tempRet0;
           ___clang_call_terminate($69);
           // unreachable;
          } else {
           $eh$lpad$body$index3Z2D = $66;$eh$lpad$body$indexZ2D = $65;
           label = 23;
           break L7;
          }
         }
        } while(0);
        HEAP32[$0>>2] = 2;
        $81 = ((($0)) + 4|0);
        ;HEAP32[$81>>2]=0|0;HEAP32[$81+4>>2]=0|0;HEAP32[$81+8>>2]=0|0;
       }
      }
      do {
       if ((label|0) == 25) {
        __THREW__ = 0;
        $82 = (invoke_ii(3265,4)|0);
        $83 = __THREW__; __THREW__ = 0;
        $84 = $83&1;
        if ($84) {
         label = 22;
         break L7;
        }
        do {
         if ($82) {
          __THREW__ = 0;
          $85 = (invoke_ii(3266,4)|0);
          $86 = __THREW__; __THREW__ = 0;
          $87 = $86&1;
          if ($87) {
           label = 22;
           break L7;
          }
          __THREW__ = 0;
          $88 = (invoke_iiii(3267,($85|0),(172314|0),35)|0);
          $89 = __THREW__; __THREW__ = 0;
          $90 = $89&1;
          if ($90) {
           label = 22;
           break L7;
          }
          $91 = ((($3)) + 11|0);
          $92 = HEAP8[$91>>0]|0;
          $93 = ($92<<24>>24)<(0);
          $94 = HEAP32[$3>>2]|0;
          $95 = $93 ? $94 : $3;
          $96 = ((($3)) + 4|0);
          $97 = HEAP32[$96>>2]|0;
          $98 = $92&255;
          $99 = $93 ? $97 : $98;
          __THREW__ = 0;
          $100 = (invoke_iiii(3267,($88|0),($95|0),($99|0))|0);
          $101 = __THREW__; __THREW__ = 0;
          $102 = $101&1;
          if ($102) {
           label = 22;
           break L7;
          }
          __THREW__ = 0;
          $103 = (invoke_iiii(3267,($100|0),(172217|0),5)|0);
          $104 = __THREW__; __THREW__ = 0;
          $105 = $104&1;
          if ($105) {
           label = 22;
           break L7;
          }
          $106 = HEAP8[$13>>0]|0;
          $107 = ($106<<24>>24)<(0);
          $108 = HEAP32[$7>>2]|0;
          $109 = $107 ? $108 : $7;
          $110 = HEAP32[$16>>2]|0;
          $111 = $106&255;
          $112 = $107 ? $110 : $111;
          __THREW__ = 0;
          $113 = (invoke_iiii(3267,($103|0),($109|0),($112|0))|0);
          $114 = __THREW__; __THREW__ = 0;
          $115 = $114&1;
          if ($115) {
           label = 22;
           break L7;
          }
          $116 = HEAP32[$113>>2]|0;
          $117 = ((($116)) + -12|0);
          $118 = HEAP32[$117>>2]|0;
          $119 = (($113) + ($118)|0);
          __THREW__ = 0;
          invoke_vii(3257,($5|0),($119|0));
          $120 = __THREW__; __THREW__ = 0;
          $121 = $120&1;
          if ($121) {
           label = 22;
           break L7;
          }
          __THREW__ = 0;
          $122 = (invoke_iii(3255,($5|0),(215188|0))|0);
          $123 = __THREW__; __THREW__ = 0;
          $124 = $123&1;
          if (!($124)) {
           $125 = HEAP32[$122>>2]|0;
           $126 = ((($125)) + 28|0);
           $127 = HEAP32[$126>>2]|0;
           __THREW__ = 0;
           $128 = (invoke_iii($127|0,($122|0),10)|0);
           $129 = __THREW__; __THREW__ = 0;
           $130 = $129&1;
           if (!($130)) {
            __THREW__ = 0;
            invoke_vi(3263,($5|0));
            $137 = __THREW__; __THREW__ = 0;
            $138 = $137&1;
            if ($138) {
             label = 22;
             break L7;
            }
            __THREW__ = 0;
            (invoke_iii(3268,($113|0),($128|0))|0);
            $139 = __THREW__; __THREW__ = 0;
            $140 = $139&1;
            if ($140) {
             label = 22;
             break L7;
            }
            __THREW__ = 0;
            (invoke_ii(3269,($113|0))|0);
            $141 = __THREW__; __THREW__ = 0;
            $142 = $141&1;
            if ($142) {
             label = 22;
             break L7;
            } else {
             break;
            }
           }
          }
          $131 = ___cxa_find_matching_catch_2()|0;
          $132 = tempRet0;
          __THREW__ = 0;
          invoke_vi(3263,($5|0));
          $133 = __THREW__; __THREW__ = 0;
          $134 = $133&1;
          if ($134) {
           $135 = ___cxa_find_matching_catch_3(0|0)|0;
           $136 = tempRet0;
           ___clang_call_terminate($135);
           // unreachable;
          } else {
           $eh$lpad$body$index3Z2D = $132;$eh$lpad$body$indexZ2D = $131;
           label = 23;
           break L7;
          }
         }
        } while(0);
        __THREW__ = 0;
        $143 = (invoke_ii(3482,0)|0);
        $144 = __THREW__; __THREW__ = 0;
        $145 = $144&1;
        if ($145) {
         label = 22;
         break L7;
        }
        $146 = ($4|0)==(0|0);
        if ($146) {
         label = 45;
        } else {
         $147 = ((($4)) + 120|0);
         $148 = HEAP32[$147>>2]|0;
         $149 = ($148|0)==(0|0);
         if ($149) {
          label = 45;
         } else {
          $150 = HEAP32[$148>>2]|0;
          $151 = ((($150)) + 8|0);
          $152 = HEAP32[$151>>2]|0;
          __THREW__ = 0;
          invoke_viiiii($152|0,($9|0),($148|0),($2|0),($7|0),($4|0));
          $153 = __THREW__; __THREW__ = 0;
          $154 = $153&1;
          if ($154) {
           label = 22;
           break L7;
          }
         }
        }
        do {
         if ((label|0) == 45) {
          $155 = ((($143)) + 52|0);
          $156 = HEAP32[$155>>2]|0;
          $157 = ($156|0)==(0|0);
          if ($157) {
           __THREW__ = 0;
           invoke_viiiii(4241,($9|0),($143|0),($2|0),($7|0),($4|0));
           $163 = __THREW__; __THREW__ = 0;
           $164 = $163&1;
           if ($164) {
            label = 22;
            break L7;
           } else {
            break;
           }
          } else {
           $158 = HEAP32[$156>>2]|0;
           $159 = ((($158)) + 8|0);
           $160 = HEAP32[$159>>2]|0;
           __THREW__ = 0;
           invoke_viiiii($160|0,($9|0),($156|0),($2|0),($7|0),($4|0));
           $161 = __THREW__; __THREW__ = 0;
           $162 = $161&1;
           if ($162) {
            label = 22;
            break L7;
           } else {
            break;
           }
          }
         }
        } while(0);
        $165 = HEAP32[$9>>2]|0;
        $166 = ($165|0)==(3);
        if ($166) {
         __THREW__ = 0;
         (invoke_iii(4237,($1|0),($3|0))|0);
         $167 = __THREW__; __THREW__ = 0;
         $168 = $167&1;
         if (!($168)) {
          $$pre = HEAP32[$9>>2]|0;
          $176 = $$pre;
          label = 53;
         }
        } else {
         $176 = $165;
         label = 53;
        }
        if ((label|0) == 53) {
         HEAP32[$0>>2] = $176;
         $177 = ((($0)) + 4|0);
         $178 = ((($9)) + 4|0);
         __THREW__ = 0;
         invoke_vii(3457,($177|0),($178|0));
         $179 = __THREW__; __THREW__ = 0;
         $180 = $179&1;
         if (!($180)) {
          $181 = ((($178)) + 11|0);
          $182 = HEAP8[$181>>0]|0;
          $183 = ($182<<24>>24)<(0);
          if ($183) {
           $184 = HEAP32[$178>>2]|0;
           __ZdlPv($184);
          }
          break;
         }
        }
        $169 = ___cxa_find_matching_catch_2()|0;
        $170 = tempRet0;
        $171 = ((($9)) + 4|0);
        $172 = ((($171)) + 11|0);
        $173 = HEAP8[$172>>0]|0;
        $174 = ($173<<24>>24)<(0);
        if ($174) {
         $175 = HEAP32[$171>>2]|0;
         __ZdlPv($175);
        }
        $$1 = $170;$$18 = $169;
        break L7;
       }
      } while(0);
      $185 = ((($8)) + 11|0);
      $186 = HEAP8[$185>>0]|0;
      $187 = ($186<<24>>24)<(0);
      if ($187) {
       $188 = HEAP32[$8>>2]|0;
       __ZdlPv($188);
      }
      $$pre39 = HEAP8[$13>>0]|0;
      $194 = $$pre39;
      break L1;
     }
    } while(0);
    if ((label|0) == 22) {
     $79 = ___cxa_find_matching_catch_2()|0;
     $80 = tempRet0;
     $eh$lpad$body$index3Z2D = $80;$eh$lpad$body$indexZ2D = $79;
     label = 23;
    }
    if ((label|0) == 23) {
     $$1 = $eh$lpad$body$index3Z2D;$$18 = $eh$lpad$body$indexZ2D;
    }
    $189 = ((($8)) + 11|0);
    $190 = HEAP8[$189>>0]|0;
    $191 = ($190<<24>>24)<(0);
    if ($191) {
     $192 = HEAP32[$8>>2]|0;
     __ZdlPv($192);
    }
    $$2 = $$1;$$29 = $$18;
   }
   $197 = HEAP8[$13>>0]|0;
   $198 = ($197<<24>>24)<(0);
   if (!($198)) {
    ___resumeException($$29|0);
    // unreachable;
   }
   $199 = HEAP32[$7>>2]|0;
   __ZdlPv($199);
   ___resumeException($$29|0);
   // unreachable;
  }
 } while(0);
 $195 = ($194<<24>>24)<(0);
 if (!($195)) {
  STACKTOP = sp;return;
 }
 $196 = HEAP32[$7>>2]|0;
 __ZdlPv($196);
 STACKTOP = sp;return;
}
function __ZNK5osgDB9FileCache8readNodeERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEPKNS_7OptionsEb($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $5 = sp + 12|0;
 $6 = sp;
 $7 = HEAP32[$1>>2]|0;
 $8 = ((($7)) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 FUNCTION_TABLE_viii[$9 & 8191]($6,$1,$2);
 $10 = ((($6)) + 11|0);
 $11 = HEAP8[$10>>0]|0;
 $12 = ($11<<24>>24)<(0);
 $13 = ((($6)) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $11&255;
 $16 = $12 ? $14 : $15;
 $17 = ($16|0)==(0);
 L1: do {
  if ($17) {
   label = 26;
  } else {
   __THREW__ = 0;
   $18 = (invoke_ii(4195,($6|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   L3: do {
    if ($20) {
     label = 20;
    } else {
     if (!($18)) {
      label = 26;
      break L1;
     }
     __THREW__ = 0;
     $21 = (invoke_ii(3265,4)|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      label = 20;
     } else {
      do {
       if ($21) {
        __THREW__ = 0;
        $24 = (invoke_ii(3266,4)|0);
        $25 = __THREW__; __THREW__ = 0;
        $26 = $25&1;
        if ($26) {
         label = 20;
         break L3;
        }
        __THREW__ = 0;
        $27 = (invoke_iiii(3267,($24|0),(172284|0),29)|0);
        $28 = __THREW__; __THREW__ = 0;
        $29 = $28&1;
        if ($29) {
         label = 20;
         break L3;
        }
        $30 = ((($2)) + 11|0);
        $31 = HEAP8[$30>>0]|0;
        $32 = ($31<<24>>24)<(0);
        $33 = HEAP32[$2>>2]|0;
        $34 = $32 ? $33 : $2;
        $35 = ((($2)) + 4|0);
        $36 = HEAP32[$35>>2]|0;
        $37 = $31&255;
        $38 = $32 ? $36 : $37;
        __THREW__ = 0;
        $39 = (invoke_iiii(3267,($27|0),($34|0),($38|0))|0);
        $40 = __THREW__; __THREW__ = 0;
        $41 = $40&1;
        if ($41) {
         label = 20;
         break L3;
        }
        __THREW__ = 0;
        $42 = (invoke_iiii(3267,($39|0),(172217|0),5)|0);
        $43 = __THREW__; __THREW__ = 0;
        $44 = $43&1;
        if ($44) {
         label = 20;
         break L3;
        }
        $45 = HEAP8[$10>>0]|0;
        $46 = ($45<<24>>24)<(0);
        $47 = HEAP32[$6>>2]|0;
        $48 = $46 ? $47 : $6;
        $49 = HEAP32[$13>>2]|0;
        $50 = $45&255;
        $51 = $46 ? $49 : $50;
        __THREW__ = 0;
        $52 = (invoke_iiii(3267,($42|0),($48|0),($51|0))|0);
        $53 = __THREW__; __THREW__ = 0;
        $54 = $53&1;
        if ($54) {
         label = 20;
         break L3;
        }
        $55 = HEAP32[$52>>2]|0;
        $56 = ((($55)) + -12|0);
        $57 = HEAP32[$56>>2]|0;
        $58 = (($52) + ($57)|0);
        __THREW__ = 0;
        invoke_vii(3257,($5|0),($58|0));
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 20;
         break L3;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(3255,($5|0),(215188|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if (!($63)) {
         $64 = HEAP32[$61>>2]|0;
         $65 = ((($64)) + 28|0);
         $66 = HEAP32[$65>>2]|0;
         __THREW__ = 0;
         $67 = (invoke_iii($66|0,($61|0),10)|0);
         $68 = __THREW__; __THREW__ = 0;
         $69 = $68&1;
         if (!($69)) {
          __THREW__ = 0;
          invoke_vi(3263,($5|0));
          $76 = __THREW__; __THREW__ = 0;
          $77 = $76&1;
          if ($77) {
           label = 20;
           break L3;
          }
          __THREW__ = 0;
          (invoke_iii(3268,($52|0),($67|0))|0);
          $78 = __THREW__; __THREW__ = 0;
          $79 = $78&1;
          if ($79) {
           label = 20;
           break L3;
          }
          __THREW__ = 0;
          (invoke_ii(3269,($52|0))|0);
          $80 = __THREW__; __THREW__ = 0;
          $81 = $80&1;
          if ($81) {
           label = 20;
           break L3;
          } else {
           break;
          }
         }
        }
        $70 = ___cxa_find_matching_catch_2()|0;
        $71 = tempRet0;
        __THREW__ = 0;
        invoke_vi(3263,($5|0));
        $72 = __THREW__; __THREW__ = 0;
        $73 = $72&1;
        if ($73) {
         $74 = ___cxa_find_matching_catch_3(0|0)|0;
         $75 = tempRet0;
         ___clang_call_terminate($74);
         // unreachable;
        } else {
         $eh$lpad$body$index2Z2D = $71;$eh$lpad$body$indexZ2D = $70;
         break L3;
        }
       }
      } while(0);
      __THREW__ = 0;
      $87 = (invoke_ii(3482,0)|0);
      $88 = __THREW__; __THREW__ = 0;
      $89 = $88&1;
      if ($89) {
       label = 20;
      } else {
       __THREW__ = 0;
       invoke_viiiii(4125,($0|0),($87|0),($6|0),($3|0),($4|0));
       $90 = __THREW__; __THREW__ = 0;
       $91 = $90&1;
       if ($91) {
        label = 20;
       } else {
        break L1;
       }
      }
     }
    }
   } while(0);
   if ((label|0) == 20) {
    $82 = ___cxa_find_matching_catch_2()|0;
    $83 = tempRet0;
    $eh$lpad$body$index2Z2D = $83;$eh$lpad$body$indexZ2D = $82;
   }
   $84 = HEAP8[$10>>0]|0;
   $85 = ($84<<24>>24)<(0);
   if (!($85)) {
    ___resumeException($eh$lpad$body$indexZ2D|0);
    // unreachable;
   }
   $86 = HEAP32[$6>>2]|0;
   __ZdlPv($86);
   ___resumeException($eh$lpad$body$indexZ2D|0);
   // unreachable;
  }
 } while(0);
 if ((label|0) == 26) {
  HEAP32[$0>>2] = 4;
  $92 = ((($0)) + 4|0);
  ;HEAP32[$92>>2]=0|0;HEAP32[$92+4>>2]=0|0;HEAP32[$92+8>>2]=0|0;HEAP32[$92+12>>2]=0|0;
 }
 $93 = HEAP8[$10>>0]|0;
 $94 = ($93<<24>>24)<(0);
 if (!($94)) {
  STACKTOP = sp;return;
 }
 $95 = HEAP32[$6>>2]|0;
 __ZdlPv($95);
 STACKTOP = sp;return;
}
function __ZNK5osgDB9FileCache9writeNodeERKN3osg4NodeERKNSt3__212basic_stringIcNS5_11char_traitsIcEENS5_9allocatorIcEEEEPKNS_7OptionsE($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$1 = 0, $$18 = 0, $$2 = 0, $$29 = 0, $$pre = 0, $$pre39 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $eh$lpad$body$index3Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $5 = sp + 44|0;
 $6 = sp + 40|0;
 $7 = sp + 28|0;
 $8 = sp + 16|0;
 $9 = sp;
 $10 = HEAP32[$1>>2]|0;
 $11 = ((($10)) + 16|0);
 $12 = HEAP32[$11>>2]|0;
 FUNCTION_TABLE_viii[$12 & 8191]($7,$1,$3);
 $13 = ((($7)) + 11|0);
 $14 = HEAP8[$13>>0]|0;
 $15 = ($14<<24>>24)<(0);
 $16 = ((($7)) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = $14&255;
 $19 = $15 ? $17 : $18;
 $20 = ($19|0)==(0);
 L1: do {
  if ($20) {
   HEAP32[$0>>2] = 1;
   $193 = ((($0)) + 4|0);
   ;HEAP32[$193>>2]=0|0;HEAP32[$193+4>>2]=0|0;HEAP32[$193+8>>2]=0|0;
   $194 = $14;
  } else {
   __THREW__ = 0;
   invoke_vii(4234,($8|0),($7|0));
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if ($22) {
    $77 = ___cxa_find_matching_catch_2()|0;
    $78 = tempRet0;
    $$2 = $78;$$29 = $77;
   } else {
    __THREW__ = 0;
    $23 = (invoke_ii(4195,($8|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    L7: do {
     if ($25) {
      label = 22;
     } else {
      if ($23) {
       label = 25;
      } else {
       __THREW__ = 0;
       $26 = (invoke_ii(4235,($8|0))|0);
       $27 = __THREW__; __THREW__ = 0;
       $28 = $27&1;
       if ($28) {
        label = 22;
        break;
       }
       if ($26) {
        label = 25;
       } else {
        __THREW__ = 0;
        $29 = (invoke_ii(3265,3)|0);
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if ($31) {
         label = 22;
         break;
        }
        do {
         if ($29) {
          __THREW__ = 0;
          $32 = (invoke_ii(3266,3)|0);
          $33 = __THREW__; __THREW__ = 0;
          $34 = $33&1;
          if ($34) {
           label = 22;
           break L7;
          }
          __THREW__ = 0;
          $35 = (invoke_iiii(3267,($32|0),(172151|0),34)|0);
          $36 = __THREW__; __THREW__ = 0;
          $37 = $36&1;
          if ($37) {
           label = 22;
           break L7;
          }
          $38 = ((($8)) + 11|0);
          $39 = HEAP8[$38>>0]|0;
          $40 = ($39<<24>>24)<(0);
          $41 = HEAP32[$8>>2]|0;
          $42 = $40 ? $41 : $8;
          $43 = ((($8)) + 4|0);
          $44 = HEAP32[$43>>2]|0;
          $45 = $39&255;
          $46 = $40 ? $44 : $45;
          __THREW__ = 0;
          $47 = (invoke_iiii(3267,($35|0),($42|0),($46|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           label = 22;
           break L7;
          }
          $50 = HEAP32[$47>>2]|0;
          $51 = ((($50)) + -12|0);
          $52 = HEAP32[$51>>2]|0;
          $53 = (($47) + ($52)|0);
          __THREW__ = 0;
          invoke_vii(3257,($6|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           label = 22;
           break L7;
          }
          __THREW__ = 0;
          $56 = (invoke_iii(3255,($6|0),(215188|0))|0);
          $57 = __THREW__; __THREW__ = 0;
          $58 = $57&1;
          if (!($58)) {
           $59 = HEAP32[$56>>2]|0;
           $60 = ((($59)) + 28|0);
           $61 = HEAP32[$60>>2]|0;
           __THREW__ = 0;
           $62 = (invoke_iii($61|0,($56|0),10)|0);
           $63 = __THREW__; __THREW__ = 0;
           $64 = $63&1;
           if (!($64)) {
            __THREW__ = 0;
            invoke_vi(3263,($6|0));
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             label = 22;
             break L7;
            }
            __THREW__ = 0;
            (invoke_iii(3268,($47|0),($62|0))|0);
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             label = 22;
             break L7;
            }
            __THREW__ = 0;
            (invoke_ii(3269,($47|0))|0);
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             label = 22;
             break L7;
            } else {
             break;
            }
           }
          }
          $65 = ___cxa_find_matching_catch_2()|0;
          $66 = tempRet0;
          __THREW__ = 0;
          invoke_vi(3263,($6|0));
          $67 = __THREW__; __THREW__ = 0;
          $68 = $67&1;
          if ($68) {
           $69 = ___cxa_find_matching_catch_3(0|0)|0;
           $70 = tempRet0;
           ___clang_call_terminate($69);
           // unreachable;
          } else {
           $eh$lpad$body$index3Z2D = $66;$eh$lpad$body$indexZ2D = $65;
           label = 23;
           break L7;
          }
         }
        } while(0);
        HEAP32[$0>>2] = 2;
        $81 = ((($0)) + 4|0);
        ;HEAP32[$81>>2]=0|0;HEAP32[$81+4>>2]=0|0;HEAP32[$81+8>>2]=0|0;
       }
      }
      do {
       if ((label|0) == 25) {
        __THREW__ = 0;
        $82 = (invoke_ii(3265,4)|0);
        $83 = __THREW__; __THREW__ = 0;
        $84 = $83&1;
        if ($84) {
         label = 22;
         break L7;
        }
        do {
         if ($82) {
          __THREW__ = 0;
          $85 = (invoke_ii(3266,4)|0);
          $86 = __THREW__; __THREW__ = 0;
          $87 = $86&1;
          if ($87) {
           label = 22;
           break L7;
          }
          __THREW__ = 0;
          $88 = (invoke_iiii(3267,($85|0),(172255|0),28)|0);
          $89 = __THREW__; __THREW__ = 0;
          $90 = $89&1;
          if ($90) {
           label = 22;
           break L7;
          }
          $91 = ((($3)) + 11|0);
          $92 = HEAP8[$91>>0]|0;
          $93 = ($92<<24>>24)<(0);
          $94 = HEAP32[$3>>2]|0;
          $95 = $93 ? $94 : $3;
          $96 = ((($3)) + 4|0);
          $97 = HEAP32[$96>>2]|0;
          $98 = $92&255;
          $99 = $93 ? $97 : $98;
          __THREW__ = 0;
          $100 = (invoke_iiii(3267,($88|0),($95|0),($99|0))|0);
          $101 = __THREW__; __THREW__ = 0;
          $102 = $101&1;
          if ($102) {
           label = 22;
           break L7;
          }
          __THREW__ = 0;
          $103 = (invoke_iiii(3267,($100|0),(172217|0),5)|0);
          $104 = __THREW__; __THREW__ = 0;
          $105 = $104&1;
          if ($105) {
           label = 22;
           break L7;
          }
          $106 = HEAP8[$13>>0]|0;
          $107 = ($106<<24>>24)<(0);
          $108 = HEAP32[$7>>2]|0;
          $109 = $107 ? $108 : $7;
          $110 = HEAP32[$16>>2]|0;
          $111 = $106&255;
          $112 = $107 ? $110 : $111;
          __THREW__ = 0;
          $113 = (invoke_iiii(3267,($103|0),($109|0),($112|0))|0);
          $114 = __THREW__; __THREW__ = 0;
          $115 = $114&1;
          if ($115) {
           label = 22;
           break L7;
          }
          $116 = HEAP32[$113>>2]|0;
          $117 = ((($116)) + -12|0);
          $118 = HEAP32[$117>>2]|0;
          $119 = (($113) + ($118)|0);
          __THREW__ = 0;
          invoke_vii(3257,($5|0),($119|0));
          $120 = __THREW__; __THREW__ = 0;
          $121 = $120&1;
          if ($121) {
           label = 22;
           break L7;
          }
          __THREW__ = 0;
          $122 = (invoke_iii(3255,($5|0),(215188|0))|0);
          $123 = __THREW__; __THREW__ = 0;
          $124 = $123&1;
          if (!($124)) {
           $125 = HEAP32[$122>>2]|0;
           $126 = ((($125)) + 28|0);
           $127 = HEAP32[$126>>2]|0;
           __THREW__ = 0;
           $128 = (invoke_iii($127|0,($122|0),10)|0);
           $129 = __THREW__; __THREW__ = 0;
           $130 = $129&1;
           if (!($130)) {
            __THREW__ = 0;
            invoke_vi(3263,($5|0));
            $137 = __THREW__; __THREW__ = 0;
            $138 = $137&1;
            if ($138) {
             label = 22;
             break L7;
            }
            __THREW__ = 0;
            (invoke_iii(3268,($113|0),($128|0))|0);
            $139 = __THREW__; __THREW__ = 0;
            $140 = $139&1;
            if ($140) {
             label = 22;
             break L7;
            }
            __THREW__ = 0;
            (invoke_ii(3269,($113|0))|0);
            $141 = __THREW__; __THREW__ = 0;
            $142 = $141&1;
            if ($142) {
             label = 22;
             break L7;
            } else {
             break;
            }
           }
          }
          $131 = ___cxa_find_matching_catch_2()|0;
          $132 = tempRet0;
          __THREW__ = 0;
          invoke_vi(3263,($5|0));
          $133 = __THREW__; __THREW__ = 0;
          $134 = $133&1;
          if ($134) {
           $135 = ___cxa_find_matching_catch_3(0|0)|0;
           $136 = tempRet0;
           ___clang_call_terminate($135);
           // unreachable;
          } else {
           $eh$lpad$body$index3Z2D = $132;$eh$lpad$body$indexZ2D = $131;
           label = 23;
           break L7;
          }
         }
        } while(0);
        __THREW__ = 0;
        $143 = (invoke_ii(3482,0)|0);
        $144 = __THREW__; __THREW__ = 0;
        $145 = $144&1;
        if ($145) {
         label = 22;
         break L7;
        }
        $146 = ($4|0)==(0|0);
        if ($146) {
         label = 45;
        } else {
         $147 = ((($4)) + 120|0);
         $148 = HEAP32[$147>>2]|0;
         $149 = ($148|0)==(0|0);
         if ($149) {
          label = 45;
         } else {
          $150 = HEAP32[$148>>2]|0;
          $151 = ((($150)) + 12|0);
          $152 = HEAP32[$151>>2]|0;
          __THREW__ = 0;
          invoke_viiiii($152|0,($9|0),($148|0),($2|0),($7|0),($4|0));
          $153 = __THREW__; __THREW__ = 0;
          $154 = $153&1;
          if ($154) {
           label = 22;
           break L7;
          }
         }
        }
        do {
         if ((label|0) == 45) {
          $155 = ((($143)) + 52|0);
          $156 = HEAP32[$155>>2]|0;
          $157 = ($156|0)==(0|0);
          if ($157) {
           __THREW__ = 0;
           invoke_viiiii(4242,($9|0),($143|0),($2|0),($7|0),($4|0));
           $163 = __THREW__; __THREW__ = 0;
           $164 = $163&1;
           if ($164) {
            label = 22;
            break L7;
           } else {
            break;
           }
          } else {
           $158 = HEAP32[$156>>2]|0;
           $159 = ((($158)) + 12|0);
           $160 = HEAP32[$159>>2]|0;
           __THREW__ = 0;
           invoke_viiiii($160|0,($9|0),($156|0),($2|0),($7|0),($4|0));
           $161 = __THREW__; __THREW__ = 0;
           $162 = $161&1;
           if ($162) {
            label = 22;
            break L7;
           } else {
            break;
           }
          }
         }
        } while(0);
        $165 = HEAP32[$9>>2]|0;
        $166 = ($165|0)==(3);
        if ($166) {
         __THREW__ = 0;
         (invoke_iii(4237,($1|0),($3|0))|0);
         $167 = __THREW__; __THREW__ = 0;
         $168 = $167&1;
         if (!($168)) {
          $$pre = HEAP32[$9>>2]|0;
          $176 = $$pre;
          label = 53;
         }
        } else {
         $176 = $165;
         label = 53;
        }
        if ((label|0) == 53) {
         HEAP32[$0>>2] = $176;
         $177 = ((($0)) + 4|0);
         $178 = ((($9)) + 4|0);
         __THREW__ = 0;
         invoke_vii(3457,($177|0),($178|0));
         $179 = __THREW__; __THREW__ = 0;
         $180 = $179&1;
         if (!($180)) {
          $181 = ((($178)) + 11|0);
          $182 = HEAP8[$181>>0]|0;
          $183 = ($182<<24>>24)<(0);
          if ($183) {
           $184 = HEAP32[$178>>2]|0;
           __ZdlPv($184);
          }
          break;
         }
        }
        $169 = ___cxa_find_matching_catch_2()|0;
        $170 = tempRet0;
        $171 = ((($9)) + 4|0);
        $172 = ((($171)) + 11|0);
        $173 = HEAP8[$172>>0]|0;
        $174 = ($173<<24>>24)<(0);
        if ($174) {
         $175 = HEAP32[$171>>2]|0;
         __ZdlPv($175);
        }
        $$1 = $170;$$18 = $169;
        break L7;
       }
      } while(0);
      $185 = ((($8)) + 11|0);
      $186 = HEAP8[$185>>0]|0;
      $187 = ($186<<24>>24)<(0);
      if ($187) {
       $188 = HEAP32[$8>>2]|0;
       __ZdlPv($188);
      }
      $$pre39 = HEAP8[$13>>0]|0;
      $194 = $$pre39;
      break L1;
     }
    } while(0);
    if ((label|0) == 22) {
     $79 = ___cxa_find_matching_catch_2()|0;
     $80 = tempRet0;
     $eh$lpad$body$index3Z2D = $80;$eh$lpad$body$indexZ2D = $79;
     label = 23;
    }
    if ((label|0) == 23) {
     $$1 = $eh$lpad$body$index3Z2D;$$18 = $eh$lpad$body$indexZ2D;
    }
    $189 = ((($8)) + 11|0);
    $190 = HEAP8[$189>>0]|0;
    $191 = ($190<<24>>24)<(0);
    if ($191) {
     $192 = HEAP32[$8>>2]|0;
     __ZdlPv($192);
    }
    $$2 = $$1;$$29 = $$18;
   }
   $197 = HEAP8[$13>>0]|0;
   $198 = ($197<<24>>24)<(0);
   if (!($198)) {
    ___resumeException($$29|0);
    // unreachable;
   }
   $199 = HEAP32[$7>>2]|0;
   __ZdlPv($199);
   ___resumeException($$29|0);
   // unreachable;
  }
 } while(0);
 $195 = ($194<<24>>24)<(0);
 if (!($195)) {
  STACKTOP = sp;return;
 }
 $196 = HEAP32[$7>>2]|0;
 __ZdlPv($196);
 STACKTOP = sp;return;
}
function __ZNK5osgDB9FileCache10readShaderERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEPKNS_7OptionsE($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $4 = sp + 12|0;
 $5 = sp;
 $6 = HEAP32[$1>>2]|0;
 $7 = ((($6)) + 16|0);
 $8 = HEAP32[$7>>2]|0;
 FUNCTION_TABLE_viii[$8 & 8191]($5,$1,$2);
 $9 = ((($5)) + 11|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = ($10<<24>>24)<(0);
 $12 = ((($5)) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $10&255;
 $15 = $11 ? $13 : $14;
 $16 = ($15|0)==(0);
 L1: do {
  if ($16) {
   label = 31;
  } else {
   __THREW__ = 0;
   $17 = (invoke_ii(4195,($5|0))|0);
   $18 = __THREW__; __THREW__ = 0;
   $19 = $18&1;
   L3: do {
    if ($19) {
     label = 20;
    } else {
     if (!($17)) {
      label = 31;
      break L1;
     }
     __THREW__ = 0;
     $20 = (invoke_ii(3265,4)|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      label = 20;
     } else {
      do {
       if ($20) {
        __THREW__ = 0;
        $23 = (invoke_ii(3266,4)|0);
        $24 = __THREW__; __THREW__ = 0;
        $25 = $24&1;
        if ($25) {
         label = 20;
         break L3;
        }
        __THREW__ = 0;
        $26 = (invoke_iiii(3267,($23|0),(172223|0),31)|0);
        $27 = __THREW__; __THREW__ = 0;
        $28 = $27&1;
        if ($28) {
         label = 20;
         break L3;
        }
        $29 = ((($2)) + 11|0);
        $30 = HEAP8[$29>>0]|0;
        $31 = ($30<<24>>24)<(0);
        $32 = HEAP32[$2>>2]|0;
        $33 = $31 ? $32 : $2;
        $34 = ((($2)) + 4|0);
        $35 = HEAP32[$34>>2]|0;
        $36 = $30&255;
        $37 = $31 ? $35 : $36;
        __THREW__ = 0;
        $38 = (invoke_iiii(3267,($26|0),($33|0),($37|0))|0);
        $39 = __THREW__; __THREW__ = 0;
        $40 = $39&1;
        if ($40) {
         label = 20;
         break L3;
        }
        __THREW__ = 0;
        $41 = (invoke_iiii(3267,($38|0),(172217|0),5)|0);
        $42 = __THREW__; __THREW__ = 0;
        $43 = $42&1;
        if ($43) {
         label = 20;
         break L3;
        }
        $44 = HEAP8[$9>>0]|0;
        $45 = ($44<<24>>24)<(0);
        $46 = HEAP32[$5>>2]|0;
        $47 = $45 ? $46 : $5;
        $48 = HEAP32[$12>>2]|0;
        $49 = $44&255;
        $50 = $45 ? $48 : $49;
        __THREW__ = 0;
        $51 = (invoke_iiii(3267,($41|0),($47|0),($50|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 20;
         break L3;
        }
        $54 = HEAP32[$51>>2]|0;
        $55 = ((($54)) + -12|0);
        $56 = HEAP32[$55>>2]|0;
        $57 = (($51) + ($56)|0);
        __THREW__ = 0;
        invoke_vii(3257,($4|0),($57|0));
        $58 = __THREW__; __THREW__ = 0;
        $59 = $58&1;
        if ($59) {
         label = 20;
         break L3;
        }
        __THREW__ = 0;
        $60 = (invoke_iii(3255,($4|0),(215188|0))|0);
        $61 = __THREW__; __THREW__ = 0;
        $62 = $61&1;
        if (!($62)) {
         $63 = HEAP32[$60>>2]|0;
         $64 = ((($63)) + 28|0);
         $65 = HEAP32[$64>>2]|0;
         __THREW__ = 0;
         $66 = (invoke_iii($65|0,($60|0),10)|0);
         $67 = __THREW__; __THREW__ = 0;
         $68 = $67&1;
         if (!($68)) {
          __THREW__ = 0;
          invoke_vi(3263,($4|0));
          $75 = __THREW__; __THREW__ = 0;
          $76 = $75&1;
          if ($76) {
           label = 20;
           break L3;
          }
          __THREW__ = 0;
          (invoke_iii(3268,($51|0),($66|0))|0);
          $77 = __THREW__; __THREW__ = 0;
          $78 = $77&1;
          if ($78) {
           label = 20;
           break L3;
          }
          __THREW__ = 0;
          (invoke_ii(3269,($51|0))|0);
          $79 = __THREW__; __THREW__ = 0;
          $80 = $79&1;
          if ($80) {
           label = 20;
           break L3;
          } else {
           break;
          }
         }
        }
        $69 = ___cxa_find_matching_catch_2()|0;
        $70 = tempRet0;
        __THREW__ = 0;
        invoke_vi(3263,($4|0));
        $71 = __THREW__; __THREW__ = 0;
        $72 = $71&1;
        if ($72) {
         $73 = ___cxa_find_matching_catch_3(0|0)|0;
         $74 = tempRet0;
         ___clang_call_terminate($73);
         // unreachable;
        } else {
         $eh$lpad$body$index2Z2D = $70;$eh$lpad$body$indexZ2D = $69;
         break L3;
        }
       }
      } while(0);
      __THREW__ = 0;
      $86 = (invoke_ii(3482,0)|0);
      $87 = __THREW__; __THREW__ = 0;
      $88 = $87&1;
      if ($88) {
       label = 20;
      } else {
       $89 = ($3|0)==(0|0);
       if (!($89)) {
        $90 = ((($3)) + 116|0);
        $91 = HEAP32[$90>>2]|0;
        $92 = ($91|0)==(0|0);
        if (!($92)) {
         $93 = HEAP32[$91>>2]|0;
         $94 = ((($93)) + 20|0);
         $95 = HEAP32[$94>>2]|0;
         __THREW__ = 0;
         invoke_viiii($95|0,($0|0),($91|0),($5|0),($3|0));
         $96 = __THREW__; __THREW__ = 0;
         $97 = $96&1;
         if ($97) {
          label = 20;
          break;
         } else {
          break L1;
         }
        }
       }
       $98 = ((($86)) + 48|0);
       $99 = HEAP32[$98>>2]|0;
       $100 = ($99|0)==(0|0);
       if ($100) {
        __THREW__ = 0;
        invoke_viiii(4243,($0|0),($86|0),($5|0),($3|0));
        $106 = __THREW__; __THREW__ = 0;
        $107 = $106&1;
        if ($107) {
         label = 20;
         break;
        } else {
         break L1;
        }
       } else {
        $101 = HEAP32[$99>>2]|0;
        $102 = ((($101)) + 20|0);
        $103 = HEAP32[$102>>2]|0;
        __THREW__ = 0;
        invoke_viiii($103|0,($0|0),($99|0),($5|0),($3|0));
        $104 = __THREW__; __THREW__ = 0;
        $105 = $104&1;
        if ($105) {
         label = 20;
         break;
        } else {
         break L1;
        }
       }
      }
     }
    }
   } while(0);
   if ((label|0) == 20) {
    $81 = ___cxa_find_matching_catch_2()|0;
    $82 = tempRet0;
    $eh$lpad$body$index2Z2D = $82;$eh$lpad$body$indexZ2D = $81;
   }
   $83 = HEAP8[$9>>0]|0;
   $84 = ($83<<24>>24)<(0);
   if (!($84)) {
    ___resumeException($eh$lpad$body$indexZ2D|0);
    // unreachable;
   }
   $85 = HEAP32[$5>>2]|0;
   __ZdlPv($85);
   ___resumeException($eh$lpad$body$indexZ2D|0);
   // unreachable;
  }
 } while(0);
 if ((label|0) == 31) {
  HEAP32[$0>>2] = 4;
  $108 = ((($0)) + 4|0);
  ;HEAP32[$108>>2]=0|0;HEAP32[$108+4>>2]=0|0;HEAP32[$108+8>>2]=0|0;HEAP32[$108+12>>2]=0|0;
 }
 $109 = HEAP8[$9>>0]|0;
 $110 = ($109<<24>>24)<(0);
 if (!($110)) {
  STACKTOP = sp;return;
 }
 $111 = HEAP32[$5>>2]|0;
 __ZdlPv($111);
 STACKTOP = sp;return;
}
function __ZNK5osgDB9FileCache11writeShaderERKN3osg6ShaderERKNSt3__212basic_stringIcNS5_11char_traitsIcEENS5_9allocatorIcEEEEPKNS_7OptionsE($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$1 = 0, $$18 = 0, $$2 = 0, $$29 = 0, $$pre = 0, $$pre39 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $eh$lpad$body$index3Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $5 = sp + 44|0;
 $6 = sp + 40|0;
 $7 = sp + 28|0;
 $8 = sp + 16|0;
 $9 = sp;
 $10 = HEAP32[$1>>2]|0;
 $11 = ((($10)) + 16|0);
 $12 = HEAP32[$11>>2]|0;
 FUNCTION_TABLE_viii[$12 & 8191]($7,$1,$3);
 $13 = ((($7)) + 11|0);
 $14 = HEAP8[$13>>0]|0;
 $15 = ($14<<24>>24)<(0);
 $16 = ((($7)) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = $14&255;
 $19 = $15 ? $17 : $18;
 $20 = ($19|0)==(0);
 L1: do {
  if ($20) {
   HEAP32[$0>>2] = 1;
   $193 = ((($0)) + 4|0);
   ;HEAP32[$193>>2]=0|0;HEAP32[$193+4>>2]=0|0;HEAP32[$193+8>>2]=0|0;
   $194 = $14;
  } else {
   __THREW__ = 0;
   invoke_vii(4234,($8|0),($7|0));
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if ($22) {
    $77 = ___cxa_find_matching_catch_2()|0;
    $78 = tempRet0;
    $$2 = $78;$$29 = $77;
   } else {
    __THREW__ = 0;
    $23 = (invoke_ii(4195,($8|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    L7: do {
     if ($25) {
      label = 22;
     } else {
      if ($23) {
       label = 25;
      } else {
       __THREW__ = 0;
       $26 = (invoke_ii(4235,($8|0))|0);
       $27 = __THREW__; __THREW__ = 0;
       $28 = $27&1;
       if ($28) {
        label = 22;
        break;
       }
       if ($26) {
        label = 25;
       } else {
        __THREW__ = 0;
        $29 = (invoke_ii(3265,3)|0);
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if ($31) {
         label = 22;
         break;
        }
        do {
         if ($29) {
          __THREW__ = 0;
          $32 = (invoke_ii(3266,3)|0);
          $33 = __THREW__; __THREW__ = 0;
          $34 = $33&1;
          if ($34) {
           label = 22;
           break L7;
          }
          __THREW__ = 0;
          $35 = (invoke_iiii(3267,($32|0),(172151|0),34)|0);
          $36 = __THREW__; __THREW__ = 0;
          $37 = $36&1;
          if ($37) {
           label = 22;
           break L7;
          }
          $38 = ((($8)) + 11|0);
          $39 = HEAP8[$38>>0]|0;
          $40 = ($39<<24>>24)<(0);
          $41 = HEAP32[$8>>2]|0;
          $42 = $40 ? $41 : $8;
          $43 = ((($8)) + 4|0);
          $44 = HEAP32[$43>>2]|0;
          $45 = $39&255;
          $46 = $40 ? $44 : $45;
          __THREW__ = 0;
          $47 = (invoke_iiii(3267,($35|0),($42|0),($46|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           label = 22;
           break L7;
          }
          $50 = HEAP32[$47>>2]|0;
          $51 = ((($50)) + -12|0);
          $52 = HEAP32[$51>>2]|0;
          $53 = (($47) + ($52)|0);
          __THREW__ = 0;
          invoke_vii(3257,($6|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           label = 22;
           break L7;
          }
          __THREW__ = 0;
          $56 = (invoke_iii(3255,($6|0),(215188|0))|0);
          $57 = __THREW__; __THREW__ = 0;
          $58 = $57&1;
          if (!($58)) {
           $59 = HEAP32[$56>>2]|0;
           $60 = ((($59)) + 28|0);
           $61 = HEAP32[$60>>2]|0;
           __THREW__ = 0;
           $62 = (invoke_iii($61|0,($56|0),10)|0);
           $63 = __THREW__; __THREW__ = 0;
           $64 = $63&1;
           if (!($64)) {
            __THREW__ = 0;
            invoke_vi(3263,($6|0));
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             label = 22;
             break L7;
            }
            __THREW__ = 0;
            (invoke_iii(3268,($47|0),($62|0))|0);
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             label = 22;
             break L7;
            }
            __THREW__ = 0;
            (invoke_ii(3269,($47|0))|0);
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             label = 22;
             break L7;
            } else {
             break;
            }
           }
          }
          $65 = ___cxa_find_matching_catch_2()|0;
          $66 = tempRet0;
          __THREW__ = 0;
          invoke_vi(3263,($6|0));
          $67 = __THREW__; __THREW__ = 0;
          $68 = $67&1;
          if ($68) {
           $69 = ___cxa_find_matching_catch_3(0|0)|0;
           $70 = tempRet0;
           ___clang_call_terminate($69);
           // unreachable;
          } else {
           $eh$lpad$body$index3Z2D = $66;$eh$lpad$body$indexZ2D = $65;
           label = 23;
           break L7;
          }
         }
        } while(0);
        HEAP32[$0>>2] = 2;
        $81 = ((($0)) + 4|0);
        ;HEAP32[$81>>2]=0|0;HEAP32[$81+4>>2]=0|0;HEAP32[$81+8>>2]=0|0;
       }
      }
      do {
       if ((label|0) == 25) {
        __THREW__ = 0;
        $82 = (invoke_ii(3265,4)|0);
        $83 = __THREW__; __THREW__ = 0;
        $84 = $83&1;
        if ($84) {
         label = 22;
         break L7;
        }
        do {
         if ($82) {
          __THREW__ = 0;
          $85 = (invoke_ii(3266,4)|0);
          $86 = __THREW__; __THREW__ = 0;
          $87 = $86&1;
          if ($87) {
           label = 22;
           break L7;
          }
          __THREW__ = 0;
          $88 = (invoke_iiii(3267,($85|0),(172186|0),30)|0);
          $89 = __THREW__; __THREW__ = 0;
          $90 = $89&1;
          if ($90) {
           label = 22;
           break L7;
          }
          $91 = ((($3)) + 11|0);
          $92 = HEAP8[$91>>0]|0;
          $93 = ($92<<24>>24)<(0);
          $94 = HEAP32[$3>>2]|0;
          $95 = $93 ? $94 : $3;
          $96 = ((($3)) + 4|0);
          $97 = HEAP32[$96>>2]|0;
          $98 = $92&255;
          $99 = $93 ? $97 : $98;
          __THREW__ = 0;
          $100 = (invoke_iiii(3267,($88|0),($95|0),($99|0))|0);
          $101 = __THREW__; __THREW__ = 0;
          $102 = $101&1;
          if ($102) {
           label = 22;
           break L7;
          }
          __THREW__ = 0;
          $103 = (invoke_iiii(3267,($100|0),(172217|0),5)|0);
          $104 = __THREW__; __THREW__ = 0;
          $105 = $104&1;
          if ($105) {
           label = 22;
           break L7;
          }
          $106 = HEAP8[$13>>0]|0;
          $107 = ($106<<24>>24)<(0);
          $108 = HEAP32[$7>>2]|0;
          $109 = $107 ? $108 : $7;
          $110 = HEAP32[$16>>2]|0;
          $111 = $106&255;
          $112 = $107 ? $110 : $111;
          __THREW__ = 0;
          $113 = (invoke_iiii(3267,($103|0),($109|0),($112|0))|0);
          $114 = __THREW__; __THREW__ = 0;
          $115 = $114&1;
          if ($115) {
           label = 22;
           break L7;
          }
          $116 = HEAP32[$113>>2]|0;
          $117 = ((($116)) + -12|0);
          $118 = HEAP32[$117>>2]|0;
          $119 = (($113) + ($118)|0);
          __THREW__ = 0;
          invoke_vii(3257,($5|0),($119|0));
          $120 = __THREW__; __THREW__ = 0;
          $121 = $120&1;
          if ($121) {
           label = 22;
           break L7;
          }
          __THREW__ = 0;
          $122 = (invoke_iii(3255,($5|0),(215188|0))|0);
          $123 = __THREW__; __THREW__ = 0;
          $124 = $123&1;
          if (!($124)) {
           $125 = HEAP32[$122>>2]|0;
           $126 = ((($125)) + 28|0);
           $127 = HEAP32[$126>>2]|0;
           __THREW__ = 0;
           $128 = (invoke_iii($127|0,($122|0),10)|0);
           $129 = __THREW__; __THREW__ = 0;
           $130 = $129&1;
           if (!($130)) {
            __THREW__ = 0;
            invoke_vi(3263,($5|0));
            $137 = __THREW__; __THREW__ = 0;
            $138 = $137&1;
            if ($138) {
             label = 22;
             break L7;
            }
            __THREW__ = 0;
            (invoke_iii(3268,($113|0),($128|0))|0);
            $139 = __THREW__; __THREW__ = 0;
            $140 = $139&1;
            if ($140) {
             label = 22;
             break L7;
            }
            __THREW__ = 0;
            (invoke_ii(3269,($113|0))|0);
            $141 = __THREW__; __THREW__ = 0;
            $142 = $141&1;
            if ($142) {
             label = 22;
             break L7;
            } else {
             break;
            }
           }
          }
          $131 = ___cxa_find_matching_catch_2()|0;
          $132 = tempRet0;
          __THREW__ = 0;
          invoke_vi(3263,($5|0));
          $133 = __THREW__; __THREW__ = 0;
          $134 = $133&1;
          if ($134) {
           $135 = ___cxa_find_matching_catch_3(0|0)|0;
           $136 = tempRet0;
           ___clang_call_terminate($135);
           // unreachable;
          } else {
           $eh$lpad$body$index3Z2D = $132;$eh$lpad$body$indexZ2D = $131;
           label = 23;
           break L7;
          }
         }
        } while(0);
        __THREW__ = 0;
        $143 = (invoke_ii(3482,0)|0);
        $144 = __THREW__; __THREW__ = 0;
        $145 = $144&1;
        if ($145) {
         label = 22;
         break L7;
        }
        $146 = ($4|0)==(0|0);
        if ($146) {
         label = 45;
        } else {
         $147 = ((($4)) + 120|0);
         $148 = HEAP32[$147>>2]|0;
         $149 = ($148|0)==(0|0);
         if ($149) {
          label = 45;
         } else {
          $150 = HEAP32[$148>>2]|0;
          $151 = ((($150)) + 16|0);
          $152 = HEAP32[$151>>2]|0;
          __THREW__ = 0;
          invoke_viiiii($152|0,($9|0),($148|0),($2|0),($7|0),($4|0));
          $153 = __THREW__; __THREW__ = 0;
          $154 = $153&1;
          if ($154) {
           label = 22;
           break L7;
          }
         }
        }
        do {
         if ((label|0) == 45) {
          $155 = ((($143)) + 52|0);
          $156 = HEAP32[$155>>2]|0;
          $157 = ($156|0)==(0|0);
          if ($157) {
           __THREW__ = 0;
           invoke_viiiii(4244,($9|0),($143|0),($2|0),($7|0),($4|0));
           $163 = __THREW__; __THREW__ = 0;
           $164 = $163&1;
           if ($164) {
            label = 22;
            break L7;
           } else {
            break;
           }
          } else {
           $158 = HEAP32[$156>>2]|0;
           $159 = ((($158)) + 16|0);
           $160 = HEAP32[$159>>2]|0;
           __THREW__ = 0;
           invoke_viiiii($160|0,($9|0),($156|0),($2|0),($7|0),($4|0));
           $161 = __THREW__; __THREW__ = 0;
           $162 = $161&1;
           if ($162) {
            label = 22;
            break L7;
           } else {
            break;
           }
          }
         }
        } while(0);
        $165 = HEAP32[$9>>2]|0;
        $166 = ($165|0)==(3);
        if ($166) {
         __THREW__ = 0;
         (invoke_iii(4237,($1|0),($3|0))|0);
         $167 = __THREW__; __THREW__ = 0;
         $168 = $167&1;
         if (!($168)) {
          $$pre = HEAP32[$9>>2]|0;
          $176 = $$pre;
          label = 53;
         }
        } else {
         $176 = $165;
         label = 53;
        }
        if ((label|0) == 53) {
         HEAP32[$0>>2] = $176;
         $177 = ((($0)) + 4|0);
         $178 = ((($9)) + 4|0);
         __THREW__ = 0;
         invoke_vii(3457,($177|0),($178|0));
         $179 = __THREW__; __THREW__ = 0;
         $180 = $179&1;
         if (!($180)) {
          $181 = ((($178)) + 11|0);
          $182 = HEAP8[$181>>0]|0;
          $183 = ($182<<24>>24)<(0);
          if ($183) {
           $184 = HEAP32[$178>>2]|0;
           __ZdlPv($184);
          }
          break;
         }
        }
        $169 = ___cxa_find_matching_catch_2()|0;
        $170 = tempRet0;
        $171 = ((($9)) + 4|0);
        $172 = ((($171)) + 11|0);
        $173 = HEAP8[$172>>0]|0;
        $174 = ($173<<24>>24)<(0);
        if ($174) {
         $175 = HEAP32[$171>>2]|0;
         __ZdlPv($175);
        }
        $$1 = $170;$$18 = $169;
        break L7;
       }
      } while(0);
      $185 = ((($8)) + 11|0);
      $186 = HEAP8[$185>>0]|0;
      $187 = ($186<<24>>24)<(0);
      if ($187) {
       $188 = HEAP32[$8>>2]|0;
       __ZdlPv($188);
      }
      $$pre39 = HEAP8[$13>>0]|0;
      $194 = $$pre39;
      break L1;
     }
    } while(0);
    if ((label|0) == 22) {
     $79 = ___cxa_find_matching_catch_2()|0;
     $80 = tempRet0;
     $eh$lpad$body$index3Z2D = $80;$eh$lpad$body$indexZ2D = $79;
     label = 23;
    }
    if ((label|0) == 23) {
     $$1 = $eh$lpad$body$index3Z2D;$$18 = $eh$lpad$body$indexZ2D;
    }
    $189 = ((($8)) + 11|0);
    $190 = HEAP8[$189>>0]|0;
    $191 = ($190<<24>>24)<(0);
    if ($191) {
     $192 = HEAP32[$8>>2]|0;
     __ZdlPv($192);
    }
    $$2 = $$1;$$29 = $$18;
   }
   $197 = HEAP8[$13>>0]|0;
   $198 = ($197<<24>>24)<(0);
   if (!($198)) {
    ___resumeException($$29|0);
    // unreachable;
   }
   $199 = HEAP32[$7>>2]|0;
   __ZdlPv($199);
   ___resumeException($$29|0);
   // unreachable;
  }
 } while(0);
 $195 = ($194<<24>>24)<(0);
 if (!($195)) {
  STACKTOP = sp;return;
 }
 $196 = HEAP32[$7>>2]|0;
 __ZdlPv($196);
 STACKTOP = sp;return;
}
function __ZNK5osgDB9FileCache25removeFileFromBlackListedERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$030 = 0, $$031 = 0, $$1 = 0, $$132 = 0, $$2 = 0, $$233 = 0, $$3 = 0, $$334 = 0, $$4 = 0, $$435 = 0, $$5 = 0, $$536 = 0, $$6 = 0, $$637 = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre$phi114Z2D = 0, $$pre$phiZ2D = 0, $$pre110 = 0, $$pre111 = 0;
 var $$pre112 = 0, $$pre113 = 0, $$sink103 = 0, $$sroa$074$0 = 0, $$sroa$074$0105 = 0, $$sroa$074$0106 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0;
 var $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0;
 var $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0;
 var $239 = 0, $24 = 0, $240 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(96|0);
 $2 = sp + 72|0;
 $3 = sp + 84|0;
 $4 = sp + 60|0;
 $5 = sp + 48|0;
 $6 = sp + 36|0;
 $7 = sp + 24|0;
 $8 = sp + 12|0;
 $9 = sp;
 $10 = ((($0)) + 28|0);
 $$sroa$074$0105 = HEAP32[$10>>2]|0;
 $11 = ((($0)) + 24|0);
 $12 = $$sroa$074$0105;
 $13 = ($12|0)==($11|0);
 if ($13) {
  STACKTOP = sp;return 0;
 }
 $14 = ((($1)) + 11|0);
 $15 = ((($1)) + 4|0);
 $16 = ((($2)) + 11|0);
 $17 = ((($9)) + 11|0);
 $18 = ((($8)) + 11|0);
 $19 = ((($8)) + 4|0);
 $20 = ((($7)) + 11|0);
 $21 = ((($6)) + 11|0);
 $22 = ((($6)) + 4|0);
 $23 = ((($5)) + 11|0);
 $24 = ((($4)) + 11|0);
 $25 = ((($4)) + 4|0);
 $$sroa$074$0106 = $$sroa$074$0105;$238 = $12;
 L4: while(1) {
  $26 = $$sroa$074$0106;
  $27 = ((($26)) + 8|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = ((($28)) + 32|0);
  $30 = ((($29)) + 11|0);
  $31 = HEAP8[$30>>0]|0;
  $32 = ($31<<24>>24)<(0);
  if ($32) {
   $33 = ((($28)) + 36|0);
   $34 = HEAP32[$33>>2]|0;
   $41 = $34;
  } else {
   $35 = $31&255;
   $41 = $35;
  }
  $36 = HEAP8[$14>>0]|0;
  $37 = ($36<<24>>24)<(0);
  $38 = HEAP32[$15>>2]|0;
  $39 = $36&255;
  $40 = $37 ? $38 : $39;
  $42 = ($41>>>0)<($40>>>0);
  if ($42) {
   if ($32) {
    $43 = ((($28)) + 36|0);
    $44 = HEAP32[$43>>2]|0;
    $$pre113 = $31&255;
    $$pre$phi114Z2D = $$pre113;$$pre$phiZ2D = $43;$48 = $44;$50 = $44;
   } else {
    $45 = $31&255;
    $$phi$trans$insert = ((($28)) + 36|0);
    $$pre = HEAP32[$$phi$trans$insert>>2]|0;
    $$pre$phi114Z2D = $45;$$pre$phiZ2D = $$phi$trans$insert;$48 = $$pre;$50 = $45;
   }
   $46 = HEAP32[$29>>2]|0;
   $47 = $32 ? $46 : $29;
   $49 = $32 ? $48 : $$pre$phi114Z2D;
   $51 = (__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7compareEjjPKcj($1,0,$50,$47,$49)|0);
   $52 = ($51|0)==(0);
   if ($52) {
    $53 = HEAP8[$30>>0]|0;
    $54 = ($53<<24>>24)<(0);
    if ($54) {
     $55 = HEAP32[$$pre$phiZ2D>>2]|0;
     $57 = $55;
    } else {
     $56 = $53&255;
     $57 = $56;
    }
    $58 = ($57|0)==(0);
    if ($58) {
     $63 = 0;
    } else {
     if ($54) {
      $59 = HEAP32[$$pre$phiZ2D>>2]|0;
      $62 = $59;
     } else {
      $60 = $53&255;
      $62 = $60;
     }
     $61 = (($62) + 1)|0;
     $63 = $61;
    }
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_jjRKS4_($2,$1,$63,-1,$3);
    $64 = ((($28)) + 44|0);
    $65 = HEAP32[$64>>2]|0;
    $66 = ((($28)) + 48|0);
    $67 = HEAP32[$66>>2]|0;
    $68 = ($65|0)==($67|0);
    if (!($68)) {
     $$sink103 = $65;
     while(1) {
      $72 = HEAP32[$$sink103>>2]|0;
      $73 = ((($72)) + 44|0);
      $74 = HEAP32[$73>>2]|0;
      $75 = ($74|0)==(0|0);
      if (!($75)) {
       __THREW__ = 0;
       $76 = (invoke_iii(4245,($74|0),($2|0))|0);
       $77 = __THREW__; __THREW__ = 0;
       $78 = $77&1;
       if ($78) {
        label = 35;
        break L4;
       }
       if ($76) {
        $79 = HEAP32[$73>>2]|0;
        $80 = ((($79)) + 12|0);
        __THREW__ = 0;
        invoke_vii(3457,($4|0),($80|0));
        $81 = __THREW__; __THREW__ = 0;
        $82 = $81&1;
        if ($82) {
         label = 35;
         break L4;
        }
        __THREW__ = 0;
        $83 = (invoke_ii(4206,($4|0))|0);
        $84 = __THREW__; __THREW__ = 0;
        $85 = $84&1;
        if ($85) {
         label = 36;
         break L4;
        }
        if ($83) {
         $86 = HEAP32[$0>>2]|0;
         $87 = ((($86)) + 16|0);
         $88 = HEAP32[$87>>2]|0;
         __THREW__ = 0;
         invoke_viii($88|0,($5|0),($0|0),($4|0));
         $89 = __THREW__; __THREW__ = 0;
         $90 = $89&1;
         if ($90) {
          label = 37;
          break L4;
         }
         __THREW__ = 0;
         (invoke_iii(3477,($4|0),($5|0))|0);
         $91 = __THREW__; __THREW__ = 0;
         $92 = $91&1;
         if ($92) {
          label = 38;
          break L4;
         }
         $93 = HEAP8[$23>>0]|0;
         $94 = ($93<<24>>24)<(0);
         if ($94) {
          $95 = HEAP32[$5>>2]|0;
          __ZdlPv($95);
         }
        }
        $107 = HEAP8[$24>>0]|0;
        $108 = ($107<<24>>24)<(0);
        $109 = HEAP32[$25>>2]|0;
        $110 = $107&255;
        $111 = $108 ? $109 : $110;
        $112 = ($111|0)==(0);
        if ($112) {
         $121 = $107;
        } else {
         $113 = HEAP32[$73>>2]|0;
         __THREW__ = 0;
         $114 = (invoke_ii(3482,0)|0);
         $115 = __THREW__; __THREW__ = 0;
         $116 = $115&1;
         if ($116) {
          label = 36;
          break L4;
         }
         $117 = ((($114)) + 160|0);
         $118 = HEAP32[$117>>2]|0;
         __THREW__ = 0;
         (invoke_iiii(3483,($113|0),($4|0),($118|0))|0);
         $119 = __THREW__; __THREW__ = 0;
         $120 = $119&1;
         if ($120) {
          label = 36;
          break L4;
         }
         $$pre110 = HEAP8[$24>>0]|0;
         $121 = $$pre110;
        }
        $122 = ($121<<24>>24)<(0);
        if ($122) {
         $123 = HEAP32[$4>>2]|0;
         __ZdlPv($123);
        }
       }
      }
      $127 = ((($72)) + 48|0);
      $128 = HEAP32[$127>>2]|0;
      $129 = ($128|0)==(0|0);
      if (!($129)) {
       __THREW__ = 0;
       $130 = (invoke_iii(4245,($128|0),($2|0))|0);
       $131 = __THREW__; __THREW__ = 0;
       $132 = $131&1;
       if ($132) {
        label = 35;
        break L4;
       }
       if ($130) {
        $133 = HEAP32[$127>>2]|0;
        $134 = ((($133)) + 12|0);
        __THREW__ = 0;
        invoke_vii(3457,($6|0),($134|0));
        $135 = __THREW__; __THREW__ = 0;
        $136 = $135&1;
        if ($136) {
         label = 35;
         break L4;
        }
        __THREW__ = 0;
        $137 = (invoke_ii(4206,($6|0))|0);
        $138 = __THREW__; __THREW__ = 0;
        $139 = $138&1;
        if ($139) {
         label = 62;
         break L4;
        }
        if ($137) {
         $140 = HEAP32[$0>>2]|0;
         $141 = ((($140)) + 16|0);
         $142 = HEAP32[$141>>2]|0;
         __THREW__ = 0;
         invoke_viii($142|0,($7|0),($0|0),($6|0));
         $143 = __THREW__; __THREW__ = 0;
         $144 = $143&1;
         if ($144) {
          label = 63;
          break L4;
         }
         __THREW__ = 0;
         (invoke_iii(3477,($6|0),($7|0))|0);
         $145 = __THREW__; __THREW__ = 0;
         $146 = $145&1;
         if ($146) {
          label = 64;
          break L4;
         }
         $147 = HEAP8[$20>>0]|0;
         $148 = ($147<<24>>24)<(0);
         if ($148) {
          $149 = HEAP32[$7>>2]|0;
          __ZdlPv($149);
         }
        }
        $159 = HEAP8[$21>>0]|0;
        $160 = ($159<<24>>24)<(0);
        $161 = HEAP32[$22>>2]|0;
        $162 = $159&255;
        $163 = $160 ? $161 : $162;
        $164 = ($163|0)==(0);
        if ($164) {
         $173 = $159;
        } else {
         $165 = HEAP32[$127>>2]|0;
         __THREW__ = 0;
         $166 = (invoke_ii(3482,0)|0);
         $167 = __THREW__; __THREW__ = 0;
         $168 = $167&1;
         if ($168) {
          label = 62;
          break L4;
         }
         $169 = ((($166)) + 160|0);
         $170 = HEAP32[$169>>2]|0;
         __THREW__ = 0;
         (invoke_iiii(3483,($165|0),($6|0),($170|0))|0);
         $171 = __THREW__; __THREW__ = 0;
         $172 = $171&1;
         if ($172) {
          label = 62;
          break L4;
         }
         $$pre111 = HEAP8[$21>>0]|0;
         $173 = $$pre111;
        }
        $174 = ($173<<24>>24)<(0);
        if ($174) {
         $175 = HEAP32[$6>>2]|0;
         __ZdlPv($175);
        }
       }
      }
      $179 = ((($72)) + 52|0);
      $180 = HEAP32[$179>>2]|0;
      $181 = ($180|0)==(0|0);
      if (!($181)) {
       __THREW__ = 0;
       $182 = (invoke_iii(4245,($180|0),($2|0))|0);
       $183 = __THREW__; __THREW__ = 0;
       $184 = $183&1;
       if ($184) {
        label = 35;
        break L4;
       }
       if ($182) {
        $185 = HEAP32[$179>>2]|0;
        $186 = ((($185)) + 12|0);
        __THREW__ = 0;
        invoke_vii(3457,($8|0),($186|0));
        $187 = __THREW__; __THREW__ = 0;
        $188 = $187&1;
        if ($188) {
         label = 35;
         break L4;
        }
        __THREW__ = 0;
        $189 = (invoke_ii(4206,($8|0))|0);
        $190 = __THREW__; __THREW__ = 0;
        $191 = $190&1;
        if ($191) {
         label = 88;
         break L4;
        }
        if ($189) {
         $192 = HEAP32[$0>>2]|0;
         $193 = ((($192)) + 16|0);
         $194 = HEAP32[$193>>2]|0;
         __THREW__ = 0;
         invoke_viii($194|0,($9|0),($0|0),($8|0));
         $195 = __THREW__; __THREW__ = 0;
         $196 = $195&1;
         if ($196) {
          label = 89;
          break L4;
         }
         __THREW__ = 0;
         (invoke_iii(3477,($8|0),($9|0))|0);
         $197 = __THREW__; __THREW__ = 0;
         $198 = $197&1;
         if ($198) {
          label = 90;
          break L4;
         }
         $199 = HEAP8[$17>>0]|0;
         $200 = ($199<<24>>24)<(0);
         if ($200) {
          $201 = HEAP32[$9>>2]|0;
          __ZdlPv($201);
         }
        }
        $211 = HEAP8[$18>>0]|0;
        $212 = ($211<<24>>24)<(0);
        $213 = HEAP32[$19>>2]|0;
        $214 = $211&255;
        $215 = $212 ? $213 : $214;
        $216 = ($215|0)==(0);
        if ($216) {
         $225 = $211;
        } else {
         $217 = HEAP32[$179>>2]|0;
         __THREW__ = 0;
         $218 = (invoke_ii(3482,0)|0);
         $219 = __THREW__; __THREW__ = 0;
         $220 = $219&1;
         if ($220) {
          label = 88;
          break L4;
         }
         $221 = ((($218)) + 160|0);
         $222 = HEAP32[$221>>2]|0;
         __THREW__ = 0;
         (invoke_iiii(3483,($217|0),($8|0),($222|0))|0);
         $223 = __THREW__; __THREW__ = 0;
         $224 = $223&1;
         if ($224) {
          label = 88;
          break L4;
         }
         $$pre112 = HEAP8[$18>>0]|0;
         $225 = $$pre112;
        }
        $226 = ($225<<24>>24)<(0);
        if ($226) {
         $227 = HEAP32[$8>>2]|0;
         __ZdlPv($227);
        }
       }
      }
      $231 = ((($$sink103)) + 4|0);
      $232 = HEAP32[$66>>2]|0;
      $233 = ($231|0)==($232|0);
      if ($233) {
       break;
      } else {
       $$sink103 = $231;
      }
     }
    }
    $69 = HEAP8[$16>>0]|0;
    $70 = ($69<<24>>24)<(0);
    if ($70) {
     $71 = HEAP32[$2>>2]|0;
     __ZdlPv($71);
    }
   }
  }
  $237 = ((($238)) + 4|0);
  $$sroa$074$0 = HEAP32[$237>>2]|0;
  $239 = $$sroa$074$0;
  $240 = ($239|0)==($11|0);
  if ($240) {
   label = 3;
   break;
  } else {
   $$sroa$074$0106 = $$sroa$074$0;$238 = $239;
  }
 }
 switch (label|0) {
  case 3: {
   STACKTOP = sp;return 0;
   break;
  }
  case 35: {
   $96 = ___cxa_find_matching_catch_2()|0;
   $97 = tempRet0;
   $$6 = $97;$$637 = $96;
   break;
  }
  case 36: {
   $98 = ___cxa_find_matching_catch_2()|0;
   $99 = tempRet0;
   $$1 = $99;$$132 = $98;
   label = 48;
   break;
  }
  case 37: {
   $100 = ___cxa_find_matching_catch_2()|0;
   $101 = tempRet0;
   $$030 = $101;$$031 = $100;
   label = 40;
   break;
  }
  case 38: {
   $102 = ___cxa_find_matching_catch_2()|0;
   $103 = tempRet0;
   $104 = HEAP8[$23>>0]|0;
   $105 = ($104<<24>>24)<(0);
   if ($105) {
    $106 = HEAP32[$5>>2]|0;
    __ZdlPv($106);
    $$030 = $103;$$031 = $102;
    label = 40;
   } else {
    $$030 = $103;$$031 = $102;
    label = 40;
   }
   break;
  }
  case 62: {
   $150 = ___cxa_find_matching_catch_2()|0;
   $151 = tempRet0;
   $$3 = $151;$$334 = $150;
   label = 74;
   break;
  }
  case 63: {
   $152 = ___cxa_find_matching_catch_2()|0;
   $153 = tempRet0;
   $$2 = $153;$$233 = $152;
   label = 66;
   break;
  }
  case 64: {
   $154 = ___cxa_find_matching_catch_2()|0;
   $155 = tempRet0;
   $156 = HEAP8[$20>>0]|0;
   $157 = ($156<<24>>24)<(0);
   if ($157) {
    $158 = HEAP32[$7>>2]|0;
    __ZdlPv($158);
    $$2 = $155;$$233 = $154;
    label = 66;
   } else {
    $$2 = $155;$$233 = $154;
    label = 66;
   }
   break;
  }
  case 88: {
   $202 = ___cxa_find_matching_catch_2()|0;
   $203 = tempRet0;
   $$5 = $203;$$536 = $202;
   label = 100;
   break;
  }
  case 89: {
   $204 = ___cxa_find_matching_catch_2()|0;
   $205 = tempRet0;
   $$4 = $205;$$435 = $204;
   label = 92;
   break;
  }
  case 90: {
   $206 = ___cxa_find_matching_catch_2()|0;
   $207 = tempRet0;
   $208 = HEAP8[$17>>0]|0;
   $209 = ($208<<24>>24)<(0);
   if ($209) {
    $210 = HEAP32[$9>>2]|0;
    __ZdlPv($210);
    $$4 = $207;$$435 = $206;
    label = 92;
   } else {
    $$4 = $207;$$435 = $206;
    label = 92;
   }
   break;
  }
 }
 if ((label|0) == 40) {
  $$1 = $$030;$$132 = $$031;
  label = 48;
 }
 else if ((label|0) == 66) {
  $$3 = $$2;$$334 = $$233;
  label = 74;
 }
 else if ((label|0) == 92) {
  $$5 = $$4;$$536 = $$435;
  label = 100;
 }
 if ((label|0) == 48) {
  $124 = HEAP8[$24>>0]|0;
  $125 = ($124<<24>>24)<(0);
  if ($125) {
   $126 = HEAP32[$4>>2]|0;
   __ZdlPv($126);
  }
  $$6 = $$1;$$637 = $$132;
 }
 else if ((label|0) == 74) {
  $176 = HEAP8[$21>>0]|0;
  $177 = ($176<<24>>24)<(0);
  if ($177) {
   $178 = HEAP32[$6>>2]|0;
   __ZdlPv($178);
  }
  $$6 = $$3;$$637 = $$334;
 }
 else if ((label|0) == 100) {
  $228 = HEAP8[$18>>0]|0;
  $229 = ($228<<24>>24)<(0);
  if ($229) {
   $230 = HEAP32[$8>>2]|0;
   __ZdlPv($230);
  }
  $$6 = $$5;$$637 = $$536;
 }
 $234 = HEAP8[$16>>0]|0;
 $235 = ($234<<24>>24)<(0);
 if (!($235)) {
  ___resumeException($$637|0);
  // unreachable;
 }
 $236 = HEAP32[$2>>2]|0;
 __ZdlPv($236);
 ___resumeException($$637|0);
 // unreachable;
 return (0)|0;
}
function __ZN5osgDB9FileCacheC2ERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$023$i$i = 0, $$1 = 0, $$15 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 __ZN3osg10ReferencedC2Eb($0,1);
 HEAP32[$0>>2] = (75336);
 $3 = ((($0)) + 12|0);
 __THREW__ = 0;
 invoke_vii(3457,($3|0),($1|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $57 = ___cxa_find_matching_catch_2()|0;
  $58 = tempRet0;
  $$1 = $58;$$15 = $57;
 } else {
  $6 = ((($0)) + 24|0);
  HEAP32[$6>>2] = $6;
  $7 = ((($0)) + 28|0);
  HEAP32[$7>>2] = $6;
  $8 = ((($0)) + 32|0);
  HEAP32[$8>>2] = 0;
  __THREW__ = 0;
  $9 = (invoke_ii(3265,4)|0);
  $10 = __THREW__; __THREW__ = 0;
  $11 = $10&1;
  do {
   if ($11) {
    label = 17;
   } else {
    if (!($9)) {
     STACKTOP = sp;return;
    }
    __THREW__ = 0;
    $12 = (invoke_ii(3266,4)|0);
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     label = 17;
    } else {
     __THREW__ = 0;
     $15 = (invoke_iiii(3267,($12|0),(172589|0),24)|0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      label = 17;
     } else {
      $18 = ((($1)) + 11|0);
      $19 = HEAP8[$18>>0]|0;
      $20 = ($19<<24>>24)<(0);
      $21 = HEAP32[$1>>2]|0;
      $22 = $20 ? $21 : $1;
      $23 = ((($1)) + 4|0);
      $24 = HEAP32[$23>>2]|0;
      $25 = $19&255;
      $26 = $20 ? $24 : $25;
      __THREW__ = 0;
      $27 = (invoke_iiii(3267,($15|0),($22|0),($26|0))|0);
      $28 = __THREW__; __THREW__ = 0;
      $29 = $28&1;
      if ($29) {
       label = 17;
      } else {
       $30 = HEAP32[$27>>2]|0;
       $31 = ((($30)) + -12|0);
       $32 = HEAP32[$31>>2]|0;
       $33 = (($27) + ($32)|0);
       __THREW__ = 0;
       invoke_vii(3257,($2|0),($33|0));
       $34 = __THREW__; __THREW__ = 0;
       $35 = $34&1;
       if ($35) {
        label = 17;
       } else {
        __THREW__ = 0;
        $36 = (invoke_iii(3255,($2|0),(215188|0))|0);
        $37 = __THREW__; __THREW__ = 0;
        $38 = $37&1;
        if (!($38)) {
         $39 = HEAP32[$36>>2]|0;
         $40 = ((($39)) + 28|0);
         $41 = HEAP32[$40>>2]|0;
         __THREW__ = 0;
         $42 = (invoke_iii($41|0,($36|0),10)|0);
         $43 = __THREW__; __THREW__ = 0;
         $44 = $43&1;
         if (!($44)) {
          __THREW__ = 0;
          invoke_vi(3263,($2|0));
          $45 = __THREW__; __THREW__ = 0;
          $46 = $45&1;
          if ($46) {
           label = 17;
           break;
          }
          __THREW__ = 0;
          (invoke_iii(3268,($27|0),($42|0))|0);
          $53 = __THREW__; __THREW__ = 0;
          $54 = $53&1;
          if ($54) {
           label = 17;
           break;
          }
          __THREW__ = 0;
          (invoke_ii(3269,($27|0))|0);
          $55 = __THREW__; __THREW__ = 0;
          $56 = $55&1;
          if ($56) {
           label = 17;
           break;
          }
          STACKTOP = sp;return;
         }
        }
        $47 = ___cxa_find_matching_catch_2()|0;
        $48 = tempRet0;
        __THREW__ = 0;
        invoke_vi(3263,($2|0));
        $49 = __THREW__; __THREW__ = 0;
        $50 = $49&1;
        if ($50) {
         $51 = ___cxa_find_matching_catch_3(0|0)|0;
         $52 = tempRet0;
         ___clang_call_terminate($51);
         // unreachable;
        } else {
         $eh$lpad$body$index2Z2D = $48;$eh$lpad$body$indexZ2D = $47;
         break;
        }
       }
      }
     }
    }
   }
  } while(0);
  if ((label|0) == 17) {
   $59 = ___cxa_find_matching_catch_2()|0;
   $60 = tempRet0;
   $eh$lpad$body$index2Z2D = $60;$eh$lpad$body$indexZ2D = $59;
  }
  $61 = HEAP32[$8>>2]|0;
  $62 = ($61|0)==(0);
  L26: do {
   if (!($62)) {
    $63 = HEAP32[$7>>2]|0;
    $64 = HEAP32[$6>>2]|0;
    $65 = ((($64)) + 4|0);
    $66 = HEAP32[$65>>2]|0;
    $67 = HEAP32[$63>>2]|0;
    $68 = ((($67)) + 4|0);
    HEAP32[$68>>2] = $66;
    $69 = HEAP32[$65>>2]|0;
    HEAP32[$69>>2] = $67;
    HEAP32[$8>>2] = 0;
    $70 = ($63|0)==($6|0);
    if (!($70)) {
     $$023$i$i = $63;
     while(1) {
      $71 = ((($$023$i$i)) + 4|0);
      $72 = HEAP32[$71>>2]|0;
      $73 = ((($$023$i$i)) + 8|0);
      $74 = HEAP32[$73>>2]|0;
      $75 = ($74|0)==(0|0);
      if (!($75)) {
       $76 = ((($74)) + 8|0);
       $77 = HEAP32[$76>>2]|0;HEAP32[$76>>2] = (($77-1)|0);
       $78 = ($77|0)==(1);
       if ($78) {
        __THREW__ = 0;
        invoke_viii(3262,($74|0),1,1);
        $79 = __THREW__; __THREW__ = 0;
        $80 = $79&1;
        if ($80) {
         break;
        }
       }
      }
      __ZdlPv($$023$i$i);
      $81 = ($72|0)==($6|0);
      if ($81) {
       break L26;
      } else {
       $$023$i$i = $72;
      }
     }
     $82 = ___cxa_find_matching_catch_2()|0;
     $83 = tempRet0;
     ___cxa_call_unexpected(($82|0));
     // unreachable;
    }
   }
  } while(0);
  $84 = ((($3)) + 11|0);
  $85 = HEAP8[$84>>0]|0;
  $86 = ($85<<24>>24)<(0);
  if ($86) {
   $87 = HEAP32[$3>>2]|0;
   __ZdlPv($87);
   $$1 = $eh$lpad$body$index2Z2D;$$15 = $eh$lpad$body$indexZ2D;
  } else {
   $$1 = $eh$lpad$body$index2Z2D;$$15 = $eh$lpad$body$indexZ2D;
  }
 }
 __THREW__ = 0;
 invoke_vi(712,($0|0));
 $88 = __THREW__; __THREW__ = 0;
 $89 = $88&1;
 if ($89) {
  $90 = ___cxa_find_matching_catch_3(0|0)|0;
  $91 = tempRet0;
  ___clang_call_terminate($90);
  // unreachable;
 } else {
  ___resumeException($$15|0);
  // unreachable;
 }
}
function __ZN5osgDB11getFilePathERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$022$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = ((($1)) + 11|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)<(0);
 $6 = HEAP32[$1>>2]|0;
 $7 = $5 ? $6 : $1;
 $8 = ((($1)) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $4&255;
 $11 = $5 ? $9 : $10;
 $12 = (($7) + ($11)|0);
 $13 = $7;
 $$022$i$i = $12;
 while(1) {
  $14 = ($$022$i$i|0)==($7|0);
  if ($14) {
   break;
  }
  $15 = ((($$022$i$i)) + -1|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = $16&255;
  $18 = (_memchr(172614,$17,2)|0);
  $19 = ($18|0)==(0|0);
  if ($19) {
   $$022$i$i = $15;
  } else {
   label = 4;
   break;
  }
 }
 if ((label|0) == 4) {
  $20 = $15;
  $21 = (($20) - ($13))|0;
  $22 = ($21|0)==(-1);
  if (!($22)) {
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_jjRKS4_($0,$1,0,$21,$2);
   STACKTOP = sp;return;
  }
 }
 ;HEAP32[$0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;
 STACKTOP = sp;return;
}
function __ZN5osgDB17getSimpleFileNameERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$lcssa$i$i = 0, $$0$ph$i$i = 0, $$020$i$i = 0, $$022$i$i = 0, $$sroa$02$0$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 11|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)<(0);
 $5 = HEAP32[$1>>2]|0;
 $6 = $4 ? $5 : $1;
 $7 = ((($1)) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $3&255;
 $10 = $4 ? $8 : $9;
 $11 = (($6) + ($10)|0);
 $12 = $6;
 $$022$i$i = $11;
 while(1) {
  $13 = ($$022$i$i|0)==($6|0);
  if ($13) {
   break;
  }
  $14 = ((($$022$i$i)) + -1|0);
  $15 = HEAP8[$14>>0]|0;
  $16 = $15&255;
  $17 = (_memchr(172614,$16,2)|0);
  $18 = ($17|0)==(0|0);
  if ($18) {
   $$022$i$i = $14;
  } else {
   label = 4;
   break;
  }
 }
 if ((label|0) == 4) {
  $19 = $14;
  $20 = (($19) - ($12))|0;
  $21 = ($20|0)==(-1);
  if (!($21)) {
   $22 = $11;
   $23 = $$022$i$i;
   ;HEAP32[$0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;
   $24 = (($22) - ($23))|0;
   $25 = ($24>>>0)>(4294967279);
   if ($25) {
    __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv($0);
    // unreachable;
   }
   $26 = ($24>>>0)<(11);
   if ($26) {
    $27 = $24&255;
    $28 = ((($0)) + 11|0);
    HEAP8[$28>>0] = $27;
    $$0$ph$i$i = $0;
   } else {
    $29 = (($24) + 16)|0;
    $30 = $29 & -16;
    $31 = (__Znwj($30)|0);
    HEAP32[$0>>2] = $31;
    $32 = $30 | -2147483648;
    $33 = ((($0)) + 8|0);
    HEAP32[$33>>2] = $32;
    $34 = ((($0)) + 4|0);
    HEAP32[$34>>2] = $24;
    $$0$ph$i$i = $31;
   }
   $35 = ($$022$i$i|0)==($11|0);
   if ($35) {
    $$0$lcssa$i$i = $$0$ph$i$i;
   } else {
    $$020$i$i = $$0$ph$i$i;$$sroa$02$0$i = $23;$37 = $$022$i$i;
    while(1) {
     $36 = HEAP8[$37>>0]|0;
     HEAP8[$$020$i$i>>0] = $36;
     $38 = $$sroa$02$0$i;
     $39 = ((($38)) + 1|0);
     $40 = $39;
     $41 = ((($$020$i$i)) + 1|0);
     $42 = ($39|0)==($11|0);
     if ($42) {
      $$0$lcssa$i$i = $41;
      break;
     } else {
      $$020$i$i = $41;$$sroa$02$0$i = $40;$37 = $39;
     }
    }
   }
   HEAP8[$$0$lcssa$i$i>>0] = 0;
   return;
  }
 }
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_($0,$1);
 return;
}
function __ZN5osgDB16getFileExtensionERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$lcssa$i$i$sink = 0, $$0$ph$i$i = 0, $$020$i$i = 0, $$022$i$i = 0, $$3$i$i = 0, $$sroa$02$0$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5rfindEcj($1,46,-1)|0);
 $3 = ((($1)) + 11|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)<(0);
 $6 = HEAP32[$1>>2]|0;
 $7 = $5 ? $6 : $1;
 $8 = ((($1)) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $4&255;
 $11 = $5 ? $9 : $10;
 $12 = (($7) + ($11)|0);
 $13 = $7;
 $$022$i$i = $12;
 while(1) {
  $14 = ($$022$i$i|0)==($7|0);
  if ($14) {
   $$3$i$i = -1;
   break;
  }
  $15 = ((($$022$i$i)) + -1|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = $16&255;
  $18 = (_memchr(172614,$17,2)|0);
  $19 = ($18|0)==(0|0);
  $20 = $15;
  $21 = (($20) - ($13))|0;
  if ($19) {
   $$022$i$i = $15;
  } else {
   $$3$i$i = $21;
   break;
  }
 }
 $22 = ($2|0)==(-1);
 if (!($22)) {
  $23 = ($$3$i$i|0)!=(-1);
  $24 = ($2>>>0)<($$3$i$i>>>0);
  $or$cond = $23 & $24;
  if (!($or$cond)) {
   $25 = (($7) + ($2)|0);
   $26 = ((($25)) + 1|0);
   $27 = $12;
   $28 = $26;
   ;HEAP32[$0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;
   $29 = (($27) - ($28))|0;
   $30 = ($29>>>0)>(4294967279);
   if ($30) {
    __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv($0);
    // unreachable;
   }
   $31 = ($29>>>0)<(11);
   if ($31) {
    $32 = $29&255;
    $33 = ((($0)) + 11|0);
    HEAP8[$33>>0] = $32;
    $$0$ph$i$i = $0;
   } else {
    $34 = (($29) + 16)|0;
    $35 = $34 & -16;
    $36 = (__Znwj($35)|0);
    HEAP32[$0>>2] = $36;
    $37 = $35 | -2147483648;
    $38 = ((($0)) + 8|0);
    HEAP32[$38>>2] = $37;
    $39 = ((($0)) + 4|0);
    HEAP32[$39>>2] = $29;
    $$0$ph$i$i = $36;
   }
   $40 = ($26|0)==($12|0);
   if ($40) {
    $$0$lcssa$i$i$sink = $$0$ph$i$i;
    HEAP8[$$0$lcssa$i$i$sink>>0] = 0;
    return;
   } else {
    $$020$i$i = $$0$ph$i$i;$$sroa$02$0$i = $28;$42 = $26;
   }
   while(1) {
    $41 = HEAP8[$42>>0]|0;
    HEAP8[$$020$i$i>>0] = $41;
    $43 = $$sroa$02$0$i;
    $44 = ((($43)) + 1|0);
    $45 = $44;
    $46 = ((($$020$i$i)) + 1|0);
    $47 = ($44|0)==($12|0);
    if ($47) {
     $$0$lcssa$i$i$sink = $46;
     break;
    } else {
     $$020$i$i = $46;$$sroa$02$0$i = $45;$42 = $44;
    }
   }
   HEAP8[$$0$lcssa$i$i$sink>>0] = 0;
   return;
  }
 }
 ;HEAP32[$0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;
 $$0$lcssa$i$i$sink = $0;
 HEAP8[$$0$lcssa$i$i$sink>>0] = 0;
 return;
}
function __ZN5osgDB21isFileNameNativeStyleERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE4findEcj($0,92,0)|0);
 $2 = ($1|0)==(-1);
 return ($2|0);
}
function __ZN5osgDB28convertFileNameToNativeStyleERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_($0,$1);
 $2 = (__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE4findEcj($0,92,0)|0);
 $3 = ($2|0)==(-1);
 if ($3) {
  return;
 }
 $4 = ((($0)) + 11|0);
 $10 = $2;
 while(1) {
  $5 = HEAP8[$4>>0]|0;
  $6 = ($5<<24>>24)<(0);
  if ($6) {
   $7 = HEAP32[$0>>2]|0;
   $9 = $7;
  } else {
   $9 = $0;
  }
  $8 = (($9) + ($10)|0);
  HEAP8[$8>>0] = 47;
  $11 = (__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE4findEcj($0,92,$10)|0);
  $12 = ($11|0)==(-1);
  if ($12) {
   break;
  } else {
   $10 = $11;
  }
 }
 return;
}
function __ZN5osgDB18convertToLowerCaseERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$pre = 0, $$pre$phi10Z2D = 0, $$pre$phiZ2D = 0, $$sroa$03$0 = 0, $$sroa$03$0$ph = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_($0,$1);
 $2 = ((($0)) + 11|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)<(0);
 if ($4) {
  $5 = HEAP32[$0>>2]|0;
  $$pre$phi10Z2D = $0;$$pre$phiZ2D = $0;$$sroa$03$0$ph = $5;
 } else {
  $$pre$phi10Z2D = $0;$$pre$phiZ2D = $0;$$sroa$03$0$ph = $0;
 }
 $6 = ((($0)) + 4|0);
 $$sroa$03$0 = $$sroa$03$0$ph;$7 = $3;
 while(1) {
  $8 = ($7<<24>>24)<(0);
  if ($8) {
   $9 = HEAP32[$$pre$phiZ2D>>2]|0;
   $10 = HEAP32[$6>>2]|0;
   $13 = $9;$14 = $10;
  } else {
   $11 = $7&255;
   $13 = $$pre$phi10Z2D;$14 = $11;
  }
  $12 = (($13) + ($14)|0);
  $15 = ($$sroa$03$0|0)==($12|0);
  if ($15) {
   break;
  }
  $16 = HEAP8[$$sroa$03$0>>0]|0;
  $17 = $16 << 24 >> 24;
  $18 = (_tolower($17)|0);
  $19 = $18&255;
  HEAP8[$$sroa$03$0>>0] = $19;
  $20 = ((($$sroa$03$0)) + 1|0);
  $$pre = HEAP8[$2>>0]|0;
  $$sroa$03$0 = $20;$7 = $$pre;
 }
 return;
}
function __ZN5osgDB20equalCaseInsensitiveERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEES8_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$1 = 0, $$sroa$012$017 = 0, $$sroa$09$0$ph = 0, $$sroa$09$016 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 11|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)<(0);
 $5 = ((($0)) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $3&255;
 $8 = $4 ? $6 : $7;
 $9 = ((($1)) + 11|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = ($10<<24>>24)<(0);
 $12 = ((($1)) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $10&255;
 $15 = $11 ? $13 : $14;
 $16 = ($8|0)==($15|0);
 if (!($16)) {
  $$1 = 0;
  return ($$1|0);
 }
 $17 = HEAP32[$0>>2]|0;
 $18 = $4 ? $17 : $0;
 $19 = (($18) + ($8)|0);
 $20 = ($8|0)==(0);
 if ($20) {
  $$1 = 1;
  return ($$1|0);
 }
 $21 = HEAP32[$1>>2]|0;
 $$sroa$09$0$ph = $11 ? $21 : $1;
 $$sroa$012$017 = $18;$$sroa$09$016 = $$sroa$09$0$ph;
 while(1) {
  $22 = HEAP8[$$sroa$012$017>>0]|0;
  $23 = $22 << 24 >> 24;
  $24 = (_tolower($23)|0);
  $25 = HEAP8[$$sroa$09$016>>0]|0;
  $26 = $25 << 24 >> 24;
  $27 = (_tolower($26)|0);
  $28 = ($24|0)==($27|0);
  if (!($28)) {
   $$1 = 0;
   label = 6;
   break;
  }
  $29 = ((($$sroa$012$017)) + 1|0);
  $30 = ((($$sroa$09$016)) + 1|0);
  $31 = ($29|0)==($19|0);
  if ($31) {
   $$1 = 1;
   label = 6;
   break;
  } else {
   $$sroa$012$017 = $29;$$sroa$09$016 = $30;
  }
 }
 if ((label|0) == 6) {
  return ($$1|0);
 }
 return (0)|0;
}
function __ZN5osgDB21containsServerAddressERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE($0) {
 $0 = $0|0;
 var $$0 = 0, $$02729$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $2 = ((($0)) + 11|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)<(0);
 $5 = HEAP32[$0>>2]|0;
 $6 = $4 ? $5 : $0;
 $7 = ((($0)) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $3&255;
 $10 = $4 ? $8 : $9;
 $11 = (($6) + ($10)|0);
 $12 = $11;
 $13 = $6;
 $14 = ($10|0)<(3);
 if ($14) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  $$02729$i$i$i = $6;$16 = $10;
 }
 while(1) {
  $15 = (($16) + -2)|0;
  $17 = ($15|0)==(0);
  if ($17) {
   $$0 = 0;
   label = 15;
   break;
  }
  $18 = (_memchr($$02729$i$i$i,58,$15)|0);
  $19 = ($18|0)==(0|0);
  if ($19) {
   $$0 = 0;
   label = 15;
   break;
  }
  $20 = (_memcmp($18,172617,3)|0);
  $21 = ($20|0)==(0);
  if ($21) {
   label = 6;
   break;
  }
  $22 = ((($18)) + 1|0);
  $23 = $22;
  $24 = (($12) - ($23))|0;
  $25 = ($24|0)<(3);
  if ($25) {
   $$0 = 0;
   label = 15;
   break;
  } else {
   $$02729$i$i$i = $22;$16 = $24;
  }
 }
 if ((label|0) == 6) {
  $26 = ($18|0)==($11|0);
  $27 = $18;
  $28 = (($27) - ($13))|0;
  $29 = ($28|0)==(-1);
  $or$cond = $26 | $29;
  if ($or$cond) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_jjRKS4_($1,$0,0,$28,$0);
  __THREW__ = 0;
  $30 = (invoke_ii(3482,0)|0);
  $31 = __THREW__; __THREW__ = 0;
  $32 = $31&1;
  if (!($32)) {
   __THREW__ = 0;
   $33 = (invoke_iii(4246,($30|0),($1|0))|0);
   $34 = __THREW__; __THREW__ = 0;
   $35 = $34&1;
   if (!($35)) {
    $36 = ((($1)) + 11|0);
    $37 = HEAP8[$36>>0]|0;
    $38 = ($37<<24>>24)<(0);
    if ($38) {
     $39 = HEAP32[$1>>2]|0;
     __ZdlPv($39);
    }
    $$0 = $33;
    STACKTOP = sp;return ($$0|0);
   }
  }
  $40 = ___cxa_find_matching_catch_2()|0;
  $41 = tempRet0;
  $42 = ((($1)) + 11|0);
  $43 = HEAP8[$42>>0]|0;
  $44 = ($43<<24>>24)<(0);
  if (!($44)) {
   ___resumeException($40|0);
   // unreachable;
  }
  $45 = HEAP32[$1>>2]|0;
  __ZdlPv($45);
  ___resumeException($40|0);
  // unreachable;
 }
 else if ((label|0) == 15) {
  STACKTOP = sp;return ($$0|0);
 }
 return (0)|0;
}
function __ZN5osgDB17getServerProtocolERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$02729$i$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 11|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)<(0);
 $5 = HEAP32[$1>>2]|0;
 $6 = $4 ? $5 : $1;
 $7 = ((($1)) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $3&255;
 $10 = $4 ? $8 : $9;
 $11 = (($6) + ($10)|0);
 $12 = $11;
 $13 = $6;
 $14 = ($10|0)<(3);
 L1: do {
  if (!($14)) {
   $$02729$i$i$i = $6;$16 = $10;
   while(1) {
    $15 = (($16) + -2)|0;
    $17 = ($15|0)==(0);
    if ($17) {
     break L1;
    }
    $18 = (_memchr($$02729$i$i$i,58,$15)|0);
    $19 = ($18|0)==(0|0);
    if ($19) {
     break L1;
    }
    $20 = (_memcmp($18,172617,3)|0);
    $21 = ($20|0)==(0);
    if ($21) {
     break;
    }
    $22 = ((($18)) + 1|0);
    $23 = $22;
    $24 = (($12) - ($23))|0;
    $25 = ($24|0)<(3);
    if ($25) {
     break L1;
    } else {
     $$02729$i$i$i = $22;$16 = $24;
    }
   }
   $26 = ($18|0)==($11|0);
   $27 = $18;
   $28 = (($27) - ($13))|0;
   $29 = ($28|0)==(-1);
   $or$cond = $26 | $29;
   if (!($or$cond)) {
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_jjRKS4_($0,$1,0,$28,$1);
    return;
   }
  }
 } while(0);
 ;HEAP32[$0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;
 return;
}
function __ZN5osgDB16getServerAddressERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$02729$i$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 11|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)<(0);
 $5 = HEAP32[$1>>2]|0;
 $6 = $4 ? $5 : $1;
 $7 = ((($1)) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $3&255;
 $10 = $4 ? $8 : $9;
 $11 = (($6) + ($10)|0);
 $12 = $11;
 $13 = $6;
 $14 = ($10|0)<(3);
 L1: do {
  if (!($14)) {
   $$02729$i$i$i = $6;$16 = $10;
   while(1) {
    $15 = (($16) + -2)|0;
    $17 = ($15|0)==(0);
    if ($17) {
     break L1;
    }
    $18 = (_memchr($$02729$i$i$i,58,$15)|0);
    $19 = ($18|0)==(0|0);
    if ($19) {
     break L1;
    }
    $20 = (_memcmp($18,172617,3)|0);
    $21 = ($20|0)==(0);
    if ($21) {
     break;
    }
    $22 = ((($18)) + 1|0);
    $23 = $22;
    $24 = (($12) - ($23))|0;
    $25 = ($24|0)<(3);
    if ($25) {
     break L1;
    } else {
     $$02729$i$i$i = $22;$16 = $24;
    }
   }
   $26 = ($18|0)==($11|0);
   $27 = $18;
   $28 = (($27) - ($13))|0;
   $29 = ($28|0)==(-1);
   $or$cond = $26 | $29;
   if (!($or$cond)) {
    $30 = (($28) + 3)|0;
    $31 = (__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE4findEcj($1,47,$30)|0);
    $32 = ($31|0)==(-1);
    if ($32) {
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_jjRKS4_($0,$1,$30,-1,$1);
     return;
    } else {
     $33 = (-3 - ($28))|0;
     $34 = (($33) + ($31))|0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_jjRKS4_($0,$1,$30,$34,$1);
     return;
    }
   }
  }
 } while(0);
 ;HEAP32[$0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;
 return;
}
function __ZN5osgDB17getServerFileNameERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$02729$i$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 11|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)<(0);
 $5 = HEAP32[$1>>2]|0;
 $6 = $4 ? $5 : $1;
 $7 = ((($1)) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $3&255;
 $10 = $4 ? $8 : $9;
 $11 = (($6) + ($10)|0);
 $12 = $11;
 $13 = $6;
 $14 = ($10|0)<(3);
 L1: do {
  if (!($14)) {
   $$02729$i$i$i = $6;$16 = $10;
   while(1) {
    $15 = (($16) + -2)|0;
    $17 = ($15|0)==(0);
    if ($17) {
     break L1;
    }
    $18 = (_memchr($$02729$i$i$i,58,$15)|0);
    $19 = ($18|0)==(0|0);
    if ($19) {
     break L1;
    }
    $20 = (_memcmp($18,172617,3)|0);
    $21 = ($20|0)==(0);
    if ($21) {
     break;
    }
    $22 = ((($18)) + 1|0);
    $23 = $22;
    $24 = (($12) - ($23))|0;
    $25 = ($24|0)<(3);
    if ($25) {
     break L1;
    } else {
     $$02729$i$i$i = $22;$16 = $24;
    }
   }
   $26 = ($18|0)==($11|0);
   $27 = $18;
   $28 = (($27) - ($13))|0;
   $29 = ($28|0)==(-1);
   $or$cond = $26 | $29;
   if (!($or$cond)) {
    $30 = (($28) + 3)|0;
    $31 = (__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE4findEcj($1,47,$30)|0);
    $32 = ($31|0)==(-1);
    if ($32) {
     ;HEAP32[$0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;
     return;
    } else {
     $33 = (($31) + 1)|0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_jjRKS4_($0,$1,$33,-1,$1);
     return;
    }
   }
  }
 } while(0);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_($0,$1);
 return;
}
function __ZN5osgDB11concatPathsERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEES8_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$014 = 0, $$1 = 0, $$115 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $3 = sp + 24|0;
 $4 = sp + 12|0;
 $5 = sp;
 $6 = ((($1)) + 11|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = ($7<<24>>24)<(0);
 $9 = ((($1)) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $7&255;
 $12 = $8 ? $10 : $11;
 $13 = ($12|0)==(0);
 if ($13) {
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_($0,$2);
  STACKTOP = sp;return;
 }
 $14 = (($12) + -1)|0;
 $15 = HEAP32[$1>>2]|0;
 $16 = $8 ? $15 : $1;
 $17 = (($16) + ($14)|0);
 $18 = HEAP8[$17>>0]|0;
 switch ($18<<24>>24) {
 case 47:  {
  __ZNSt3__2plIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_12basic_stringIT_T0_T1_EERKS9_SB_($0,$1,$2);
  STACKTOP = sp;return;
  break;
 }
 case 92:  {
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_jjRKS4_($4,$1,0,$14,$1);
  __THREW__ = 0;
  invoke_viii(4198,($3|0),($4|0),47);
  $19 = __THREW__; __THREW__ = 0;
  $20 = $19&1;
  do {
   if ($20) {
    $31 = ___cxa_find_matching_catch_2()|0;
    $32 = tempRet0;
    $$0 = $32;$$014 = $31;
   } else {
    __THREW__ = 0;
    invoke_viii(3550,($0|0),($3|0),($2|0));
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if ($22) {
     $33 = ___cxa_find_matching_catch_2()|0;
     $34 = tempRet0;
     $35 = ((($3)) + 11|0);
     $36 = HEAP8[$35>>0]|0;
     $37 = ($36<<24>>24)<(0);
     if (!($37)) {
      $$0 = $34;$$014 = $33;
      break;
     }
     $38 = HEAP32[$3>>2]|0;
     __ZdlPv($38);
     $$0 = $34;$$014 = $33;
     break;
    }
    $23 = ((($3)) + 11|0);
    $24 = HEAP8[$23>>0]|0;
    $25 = ($24<<24>>24)<(0);
    if ($25) {
     $26 = HEAP32[$3>>2]|0;
     __ZdlPv($26);
    }
    $27 = ((($4)) + 11|0);
    $28 = HEAP8[$27>>0]|0;
    $29 = ($28<<24>>24)<(0);
    if ($29) {
     $30 = HEAP32[$4>>2]|0;
     __ZdlPv($30);
    }
    STACKTOP = sp;return;
   }
  } while(0);
  $39 = ((($4)) + 11|0);
  $40 = HEAP8[$39>>0]|0;
  $41 = ($40<<24>>24)<(0);
  if ($41) {
   $42 = HEAP32[$4>>2]|0;
   __ZdlPv($42);
  }
  $$1 = $$0;$$115 = $$014;
  ___resumeException($$115|0);
  // unreachable;
  break;
 }
 default: {
  __ZNSt3__2plIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_12basic_stringIT_T0_T1_EERKS9_S6_($5,$1,47);
  __THREW__ = 0;
  invoke_viii(3550,($0|0),($5|0),($2|0));
  $43 = __THREW__; __THREW__ = 0;
  $44 = $43&1;
  if ($44) {
   $49 = ___cxa_find_matching_catch_2()|0;
   $50 = tempRet0;
   $51 = ((($5)) + 11|0);
   $52 = HEAP8[$51>>0]|0;
   $53 = ($52<<24>>24)<(0);
   if ($53) {
    $54 = HEAP32[$5>>2]|0;
    __ZdlPv($54);
   }
   $$1 = $50;$$115 = $49;
   ___resumeException($$115|0);
   // unreachable;
  } else {
   $45 = ((($5)) + 11|0);
   $46 = HEAP8[$45>>0]|0;
   $47 = ($46<<24>>24)<(0);
   if ($47) {
    $48 = HEAP32[$5>>2]|0;
    __ZdlPv($48);
   }
   STACKTOP = sp;return;
  }
 }
 }
}
function __ZN5osgDB11getRealPathERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$016$i$i = 0, $$017$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 4096|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(4096|0);
 $2 = sp;
 $3 = ((($1)) + 11|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)<(0);
 $6 = HEAP32[$1>>2]|0;
 $7 = $5 ? $6 : $1;
 $8 = (_realpath($7,$2)|0);
 $9 = ($8|0)==(0|0);
 if ($9) {
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_($0,$1);
  STACKTOP = sp;return;
 }
 ;HEAP32[$0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;
 $10 = (_strlen($2)|0);
 $11 = ($10>>>0)>(4294967279);
 if ($11) {
  __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $12 = ($10>>>0)<(11);
 if ($12) {
  $19 = $10&255;
  $20 = ((($0)) + 11|0);
  HEAP8[$20>>0] = $19;
  $21 = ($10|0)==(0);
  if ($21) {
   $$017$i$i = $0;
  } else {
   $$016$i$i = $0;
   label = 7;
  }
 } else {
  $13 = (($10) + 16)|0;
  $14 = $13 & -16;
  $15 = (__Znwj($14)|0);
  HEAP32[$0>>2] = $15;
  $16 = $14 | -2147483648;
  $17 = ((($0)) + 8|0);
  HEAP32[$17>>2] = $16;
  $18 = ((($0)) + 4|0);
  HEAP32[$18>>2] = $10;
  $$016$i$i = $15;
  label = 7;
 }
 if ((label|0) == 7) {
  _memcpy(($$016$i$i|0),($2|0),($10|0))|0;
  $$017$i$i = $$016$i$i;
 }
 $22 = (($$017$i$i) + ($10)|0);
 HEAP8[$22>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5osgDB13makeDirectoryERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE($0) {
 $0 = $0|0;
 var $$$i$i$i$i = 0, $$$i$i$i$i49 = 0, $$0 = 0, $$08$i$i = 0, $$08$i$i55 = 0, $$09 = 0, $$1 = 0, $$110 = 0, $$2 = 0, $$211 = 0, $$3 = 0, $$4 = 0, $$5 = 0, $$cast$i = 0, $$cast$i83 = 0, $$in = 0, $$in$i = 0, $$in$i82 = 0, $$in128 = 0, $$lcssa$i = 0;
 var $$lcssa$i85 = 0, $$lcssa104 = 0, $$neg1$i = 0, $$pre = 0, $$pre$i$i = 0, $$pre$i$i48 = 0, $$pre$i$i53 = 0, $$pre$i$i57 = 0, $$pre$phi117Z2D = 0, $$pre$phi119Z2D = 0, $$pre$phi123Z2D = 0, $$pre$phi125Z2D = 0, $$pre$phi127Z2D = 0, $$pre$phiZ2D = 0, $$pre$pre$phiZZ2D = 0, $$pre116$pre$phiZZ2D = 0, $$pre118$pre$phiZZ2D = 0, $$pre120 = 0, $$pre121 = 0, $$pre122 = 0;
 var $$pre124 = 0, $$pre126 = 0, $$pre4$i$i = 0, $$pre5$i$i = 0, $$pre6$i$i = 0, $$pre8$i$i = 0, $$pre9$i$i = 0, $$pre9$i$i54 = 0, $$pre9$i$i58 = 0, $$sink$i = 0, $$sink$i87 = 0, $$sroa$011$0$ph$i = 0, $$sroa$011$0$ph$i76 = 0, $$sroa$6$0$i = 0, $$sroa$6$0$i79 = 0, $$sroa$6$0$ph$i = 0, $$sroa$6$0$ph$i77 = 0, $1 = 0, $10 = 0, $100 = 0;
 var $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0;
 var $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0;
 var $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0;
 var $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0;
 var $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0;
 var $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0;
 var $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0;
 var $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0;
 var $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0;
 var $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0;
 var $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0;
 var $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0;
 var $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0;
 var $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0;
 var $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0;
 var $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0;
 var $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0;
 var $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0;
 var $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0;
 var $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0;
 var $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index8Z2D = 0, $eh$lpad$body$indexZ2D = 0, $eh$lpad$body71$index14Z2D = 0, $eh$lpad$body71$indexZ2D = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $phitmp$i = 0, $phitmp$i74 = 0, $scevgep$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i60 = 0, $scevgep5$i$i$i$i$i$i = 0, $scevgep5$i$i$i$i$i$i61 = 0, $sum$i$i$i = 0, $sum$i$neg$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(160|0);
 $1 = sp + 152|0;
 $2 = sp + 148|0;
 $3 = sp + 144|0;
 $4 = sp + 140|0;
 $5 = sp + 64|0;
 $6 = sp + 40|0;
 $7 = sp + 24|0;
 $8 = sp + 12|0;
 $9 = sp;
 $10 = ((($0)) + 11|0);
 $11 = HEAP8[$10>>0]|0;
 $12 = ($11<<24>>24)<(0);
 $13 = ((($0)) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $11&255;
 $16 = $12 ? $14 : $15;
 $17 = ($16|0)==(0);
 if ($17) {
  $18 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(5)|0);
  if (!($18)) {
   $$5 = 0;
   STACKTOP = sp;return ($$5|0);
  }
  $19 = (__ZN3osg6notifyENS_14NotifySeverityE(5)|0);
  $20 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($19,172621,56)|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = ((($21)) + -12|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (($20) + ($23)|0);
  __ZNKSt3__28ios_base6getlocEv($2,$24);
  __THREW__ = 0;
  $25 = (invoke_iii(3255,($2|0),(215188|0))|0);
  $26 = __THREW__; __THREW__ = 0;
  $27 = $26&1;
  if (!($27)) {
   $28 = HEAP32[$25>>2]|0;
   $29 = ((($28)) + 28|0);
   $30 = HEAP32[$29>>2]|0;
   __THREW__ = 0;
   $31 = (invoke_iii($30|0,($25|0),10)|0);
   $32 = __THREW__; __THREW__ = 0;
   $33 = $32&1;
   if (!($33)) {
    __ZNSt3__26localeD2Ev($2);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($20,$31)|0);
    (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($20)|0);
    $$5 = 0;
    STACKTOP = sp;return ($$5|0);
   }
  }
  $34 = ___cxa_find_matching_catch_2()|0;
  $35 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3263,($2|0));
  $36 = __THREW__; __THREW__ = 0;
  $37 = $36&1;
  if ($37) {
   $38 = ___cxa_find_matching_catch_3(0|0)|0;
   $39 = tempRet0;
   ___clang_call_terminate($38);
   // unreachable;
  } else {
   ___resumeException($34|0);
   // unreachable;
  }
 }
 $40 = HEAP32[$0>>2]|0;
 $41 = $12 ? $40 : $0;
 $42 = (_stat($41,$5)|0);
 $43 = ($42|0)==(0);
 L15: do {
  if ($43) {
   $44 = ((($5)) + 12|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = $45 & 61440;
   $47 = ($46|0)==(16384);
   if ($47) {
    $$4 = 1;
   } else {
    $48 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(5)|0);
    if ($48) {
     $49 = (__ZN3osg6notifyENS_14NotifySeverityE(5)|0);
     $50 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($49,172678,24)|0);
     $51 = HEAP8[$10>>0]|0;
     $52 = ($51<<24>>24)<(0);
     $53 = HEAP32[$0>>2]|0;
     $54 = $52 ? $53 : $0;
     $55 = HEAP32[$13>>2]|0;
     $56 = $51&255;
     $57 = $52 ? $55 : $56;
     $58 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($50,$54,$57)|0);
     $59 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($58,172703,39)|0);
     $60 = HEAP32[$59>>2]|0;
     $61 = ((($60)) + -12|0);
     $62 = HEAP32[$61>>2]|0;
     $63 = (($59) + ($62)|0);
     __ZNKSt3__28ios_base6getlocEv($4,$63);
     __THREW__ = 0;
     $64 = (invoke_iii(3255,($4|0),(215188|0))|0);
     $65 = __THREW__; __THREW__ = 0;
     $66 = $65&1;
     if (!($66)) {
      $67 = HEAP32[$64>>2]|0;
      $68 = ((($67)) + 28|0);
      $69 = HEAP32[$68>>2]|0;
      __THREW__ = 0;
      $70 = (invoke_iii($69|0,($64|0),10)|0);
      $71 = __THREW__; __THREW__ = 0;
      $72 = $71&1;
      if (!($72)) {
       __ZNSt3__26localeD2Ev($4);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($59,$70)|0);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($59)|0);
       $$4 = 0;
       break;
      }
     }
     $73 = ___cxa_find_matching_catch_2()|0;
     $74 = tempRet0;
     __THREW__ = 0;
     invoke_vi(3263,($4|0));
     $75 = __THREW__; __THREW__ = 0;
     $76 = $75&1;
     if ($76) {
      $77 = ___cxa_find_matching_catch_3(0|0)|0;
      $78 = tempRet0;
      ___clang_call_terminate($77);
      // unreachable;
     } else {
      ___resumeException($73|0);
      // unreachable;
     }
    } else {
     $$4 = 0;
    }
   }
  } else {
   ;HEAP32[$6>>2]=0|0;HEAP32[$6+4>>2]=0|0;HEAP32[$6+8>>2]=0|0;HEAP32[$6+12>>2]=0|0;HEAP32[$6+16>>2]=0|0;HEAP32[$6+20>>2]=0|0;
   __THREW__ = 0;
   invoke_vii(3457,($7|0),($0|0));
   $79 = __THREW__; __THREW__ = 0;
   $80 = $79&1;
   L27: do {
    if ($80) {
     $96 = ___cxa_find_matching_catch_2()|0;
     $97 = tempRet0;
     $$pre120 = ((($6)) + 4|0);
     $$pre = ((($6)) + 16|0);
     $$pre121 = ((($6)) + 8|0);
     $$pre$pre$phiZZ2D = $$pre120;$$pre116$pre$phiZZ2D = $$pre;$$pre118$pre$phiZZ2D = $$pre121;$lpad$phi$index = $96;$lpad$phi$index2 = $97;
     label = 23;
    } else {
     $81 = ((($7)) + 11|0);
     $82 = HEAP8[$81>>0]|0;
     $83 = ($82<<24>>24)<(0);
     $84 = ((($7)) + 4|0);
     $85 = HEAP32[$84>>2]|0;
     $86 = $82&255;
     $87 = $83 ? $85 : $86;
     $88 = ($87|0)==(0);
     L30: do {
      if ($88) {
       $$lcssa104 = $83;
       label = 68;
      } else {
       $89 = ((($6)) + 8|0);
       $90 = ((($6)) + 4|0);
       $91 = ((($6)) + 16|0);
       $92 = ((($6)) + 20|0);
       $93 = ((($8)) + 11|0);
       $99 = $83;
       L32: while(1) {
        $98 = HEAP32[$7>>2]|0;
        $100 = $99 ? $98 : $7;
        $101 = (_stat($100,$5)|0);
        $102 = ($101|0)<(0);
        if ($102) {
         __THREW__ = 0;
         $103 = (invoke_i(4247)|0);
         $104 = __THREW__; __THREW__ = 0;
         $105 = $104&1;
         if ($105) {
          label = 27;
          break;
         }
         $106 = HEAP32[$103>>2]|0;
         switch ($106|0) {
         case 20: case 2:  {
          break;
         }
         default: {
          label = 37;
          break L32;
         }
         }
         $111 = HEAP32[$89>>2]|0;
         $112 = HEAP32[$90>>2]|0;
         $113 = (($111) - ($112))|0;
         $114 = $113 >> 2;
         $115 = ($114|0)==(0);
         $116 = ($114*341)|0;
         $117 = (($116) + -1)|0;
         $$$i$i$i$i = $115 ? 0 : $117;
         $118 = HEAP32[$91>>2]|0;
         $119 = HEAP32[$92>>2]|0;
         $sum$i$i$i = (($119) + ($118))|0;
         $120 = ($$$i$i$i$i|0)==($sum$i$i$i|0);
         $121 = $112;
         $122 = $111;
         if ($120) {
          __THREW__ = 0;
          invoke_vi(4201,($6|0));
          $123 = __THREW__; __THREW__ = 0;
          $124 = $123&1;
          if ($124) {
           label = 27;
           break;
          }
          $$pre$i$i = HEAP32[$92>>2]|0;
          $$pre4$i$i = HEAP32[$91>>2]|0;
          $$pre5$i$i = HEAP32[$90>>2]|0;
          $$pre6$i$i = HEAP32[$89>>2]|0;
          $126 = $$pre4$i$i;$127 = $$pre$i$i;$128 = $$pre6$i$i;$130 = $$pre5$i$i;
         } else {
          $126 = $118;$127 = $119;$128 = $122;$130 = $121;
         }
         $125 = (($127) + ($126))|0;
         $129 = ($128|0)==($130|0);
         if ($129) {
          $136 = 0;
         } else {
          $131 = (($125>>>0) / 341)&-1;
          $132 = (($130) + ($131<<2)|0);
          $133 = HEAP32[$132>>2]|0;
          $134 = (($125>>>0) % 341)&-1;
          $135 = (($133) + (($134*12)|0)|0);
          $136 = $135;
         }
         __THREW__ = 0;
         invoke_vii(3457,($136|0),($7|0));
         $137 = __THREW__; __THREW__ = 0;
         $138 = $137&1;
         if ($138) {
          label = 27;
          break;
         }
         $139 = HEAP32[$92>>2]|0;
         $140 = (($139) + 1)|0;
         HEAP32[$92>>2] = $140;
        }
        __THREW__ = 0;
        invoke_vii(4234,($8|0),($7|0));
        $188 = __THREW__; __THREW__ = 0;
        $189 = $188&1;
        if ($189) {
         label = 58;
         break;
        }
        __THREW__ = 0;
        (invoke_iii(3477,($7|0),($8|0))|0);
        $190 = __THREW__; __THREW__ = 0;
        $191 = $190&1;
        if ($191) {
         label = 59;
         break;
        }
        $192 = HEAP8[$93>>0]|0;
        $193 = ($192<<24>>24)<(0);
        if ($193) {
         $194 = HEAP32[$8>>2]|0;
         __ZdlPv($194);
        }
        $195 = HEAP8[$81>>0]|0;
        $196 = ($195<<24>>24)<(0);
        $197 = HEAP32[$84>>2]|0;
        $198 = $195&255;
        $199 = $196 ? $197 : $198;
        $200 = ($199|0)==(0);
        if ($200) {
         $$lcssa104 = $196;
         label = 68;
         break L30;
        } else {
         $99 = $196;
        }
       }
       L52: do {
        if ((label|0) == 27) {
         $107 = ___cxa_find_matching_catch_2()|0;
         $108 = tempRet0;
         $eh$lpad$body$index8Z2D = $108;$eh$lpad$body$indexZ2D = $107;
         label = 29;
        }
        else if ((label|0) == 37) {
         __THREW__ = 0;
         $141 = (invoke_ii(3265,5)|0);
         $142 = __THREW__; __THREW__ = 0;
         $143 = $142&1;
         L58: do {
          if (!($143)) {
           L60: do {
            if ($141) {
             __THREW__ = 0;
             $144 = (invoke_ii(3266,5)|0);
             $145 = __THREW__; __THREW__ = 0;
             $146 = $145&1;
             if ($146) {
              break L58;
             }
             __THREW__ = 0;
             $147 = (invoke_iiii(3267,($144|0),(172678|0),24)|0);
             $148 = __THREW__; __THREW__ = 0;
             $149 = $148&1;
             if ($149) {
              break L58;
             }
             __THREW__ = 0;
             $150 = (invoke_i(4247)|0);
             $151 = __THREW__; __THREW__ = 0;
             $152 = $151&1;
             if ($152) {
              break L58;
             }
             $153 = HEAP32[$150>>2]|0;
             __THREW__ = 0;
             $154 = (invoke_ii(4248,($153|0))|0);
             $155 = __THREW__; __THREW__ = 0;
             $156 = $155&1;
             if ($156) {
              break L58;
             }
             $157 = (_strlen($154)|0);
             __THREW__ = 0;
             $158 = (invoke_iiii(3267,($147|0),($154|0),($157|0))|0);
             $159 = __THREW__; __THREW__ = 0;
             $160 = $159&1;
             if ($160) {
              break L58;
             }
             $161 = HEAP32[$158>>2]|0;
             $162 = ((($161)) + -12|0);
             $163 = HEAP32[$162>>2]|0;
             $164 = (($158) + ($163)|0);
             __THREW__ = 0;
             invoke_vii(3257,($3|0),($164|0));
             $165 = __THREW__; __THREW__ = 0;
             $166 = $165&1;
             if ($166) {
              break L58;
             }
             __THREW__ = 0;
             $167 = (invoke_iii(3255,($3|0),(215188|0))|0);
             $168 = __THREW__; __THREW__ = 0;
             $169 = $168&1;
             do {
              if (!($169)) {
               $170 = HEAP32[$167>>2]|0;
               $171 = ((($170)) + 28|0);
               $172 = HEAP32[$171>>2]|0;
               __THREW__ = 0;
               $173 = (invoke_iii($172|0,($167|0),10)|0);
               $174 = __THREW__; __THREW__ = 0;
               $175 = $174&1;
               if ($175) {
                break;
               }
               __THREW__ = 0;
               invoke_vi(3263,($3|0));
               $176 = __THREW__; __THREW__ = 0;
               $177 = $176&1;
               if ($177) {
                break L58;
               }
               __THREW__ = 0;
               (invoke_iii(3268,($158|0),($173|0))|0);
               $184 = __THREW__; __THREW__ = 0;
               $185 = $184&1;
               if ($185) {
                break L58;
               }
               __THREW__ = 0;
               (invoke_ii(3269,($158|0))|0);
               $186 = __THREW__; __THREW__ = 0;
               $187 = $186&1;
               if ($187) {
                break L58;
               } else {
                break L60;
               }
              }
             } while(0);
             $178 = ___cxa_find_matching_catch_2()|0;
             $179 = tempRet0;
             __THREW__ = 0;
             invoke_vi(3263,($3|0));
             $180 = __THREW__; __THREW__ = 0;
             $181 = $180&1;
             if ($181) {
              $182 = ___cxa_find_matching_catch_3(0|0)|0;
              $183 = tempRet0;
              ___clang_call_terminate($182);
              // unreachable;
             } else {
              $eh$lpad$body$index8Z2D = $179;$eh$lpad$body$indexZ2D = $178;
              label = 29;
              break L52;
             }
            }
           } while(0);
           $208 = HEAP8[$81>>0]|0;
           $209 = ($208<<24>>24)<(0);
           if ($209) {
            $210 = HEAP32[$7>>2]|0;
            __ZdlPv($210);
           }
           $$3 = 0;$$pre$phi123Z2D = $90;$$pre$phi125Z2D = $91;$$pre$phi127Z2D = $89;
           break L30;
          }
         } while(0);
         $109 = ___cxa_find_matching_catch_2()|0;
         $110 = tempRet0;
         $eh$lpad$body$index8Z2D = $110;$eh$lpad$body$indexZ2D = $109;
         label = 29;
        }
        else if ((label|0) == 58) {
         $201 = ___cxa_find_matching_catch_2()|0;
         $202 = tempRet0;
         $$0 = $202;$$09 = $201;
         label = 61;
        }
        else if ((label|0) == 59) {
         $203 = ___cxa_find_matching_catch_2()|0;
         $204 = tempRet0;
         $205 = HEAP8[$93>>0]|0;
         $206 = ($205<<24>>24)<(0);
         if ($206) {
          $207 = HEAP32[$8>>2]|0;
          __ZdlPv($207);
          $$0 = $204;$$09 = $203;
          label = 61;
         } else {
          $$0 = $204;$$09 = $203;
          label = 61;
         }
        }
       } while(0);
       if ((label|0) == 29) {
        $$1 = $eh$lpad$body$index8Z2D;$$110 = $eh$lpad$body$indexZ2D;
       }
       else if ((label|0) == 61) {
        $$1 = $$0;$$110 = $$09;
       }
       $211 = HEAP8[$81>>0]|0;
       $212 = ($211<<24>>24)<(0);
       if ($212) {
        $213 = HEAP32[$7>>2]|0;
        __ZdlPv($213);
       }
       $$2 = $$1;$$211 = $$110;$$pre$phi117Z2D = $91;$$pre$phi119Z2D = $89;$$pre$phiZ2D = $90;
       break L27;
      }
     } while(0);
     L89: do {
      if ((label|0) == 68) {
       if ($$lcssa104) {
        $214 = HEAP32[$7>>2]|0;
        __ZdlPv($214);
       }
       $215 = ((($6)) + 20|0);
       $216 = HEAP32[$215>>2]|0;
       $217 = ($216|0)==(0);
       if ($217) {
        $$pre122 = ((($6)) + 4|0);
        $$pre124 = ((($6)) + 16|0);
        $$pre126 = ((($6)) + 8|0);
        $$3 = 1;$$pre$phi123Z2D = $$pre122;$$pre$phi125Z2D = $$pre124;$$pre$phi127Z2D = $$pre126;
        break;
       }
       $218 = ((($6)) + 16|0);
       $219 = ((($6)) + 4|0);
       $220 = ((($9)) + 11|0);
       $221 = ((($6)) + 8|0);
       $224 = $216;
       while(1) {
        $222 = HEAP32[$218>>2]|0;
        $223 = (($224) + -1)|0;
        $225 = (($223) + ($222))|0;
        $226 = HEAP32[$219>>2]|0;
        $227 = (($225>>>0) / 341)&-1;
        $228 = (($226) + ($227<<2)|0);
        $229 = HEAP32[$228>>2]|0;
        $230 = (($225>>>0) % 341)&-1;
        $231 = (($229) + (($230*12)|0)|0);
        __THREW__ = 0;
        invoke_vii(3457,($9|0),($231|0));
        $232 = __THREW__; __THREW__ = 0;
        $233 = $232&1;
        if ($233) {
         label = 21;
         break;
        }
        $234 = HEAP8[$220>>0]|0;
        $235 = ($234<<24>>24)<(0);
        $236 = HEAP32[$9>>2]|0;
        $237 = $235 ? $236 : $9;
        $238 = (_mkdir($237,493)|0);
        $239 = ($238|0)<(0);
        if ($239) {
         $240 = HEAP8[$220>>0]|0;
         $241 = ($240<<24>>24)<(0);
         $242 = HEAP32[$9>>2]|0;
         $243 = $241 ? $242 : $9;
         $244 = (_access($243,0)|0);
         $245 = ($244|0)==(0);
         if (!($245)) {
          break;
         }
        }
        $298 = HEAP32[$215>>2]|0;
        $299 = HEAP32[$218>>2]|0;
        $300 = (($298) + -1)|0;
        $301 = (($300) + ($299))|0;
        $302 = HEAP32[$219>>2]|0;
        $303 = (($301>>>0) / 341)&-1;
        $304 = (($302) + ($303<<2)|0);
        $305 = HEAP32[$304>>2]|0;
        $306 = (($301>>>0) % 341)&-1;
        $307 = (($305) + (($306*12)|0)|0);
        $308 = ((($307)) + 11|0);
        $309 = HEAP8[$308>>0]|0;
        $310 = ($309<<24>>24)<(0);
        if ($310) {
         $312 = HEAP32[$307>>2]|0;
         __ZdlPv($312);
         $$pre$i$i48 = HEAP32[$215>>2]|0;
         $$pre8$i$i = HEAP32[$219>>2]|0;
         $$pre9$i$i = HEAP32[$218>>2]|0;
         $314 = $$pre$i$i48;$317 = $$pre8$i$i;$322 = $$pre9$i$i;
        } else {
         $311 = $302;
         $314 = $298;$317 = $311;$322 = $299;
        }
        $313 = (($314) + -1)|0;
        HEAP32[$215>>2] = $313;
        $315 = HEAP32[$221>>2]|0;
        $316 = (($315) - ($317))|0;
        $318 = $316 >> 2;
        $319 = ($318|0)==(0);
        $320 = ($318*341)|0;
        $321 = (($320) + -1)|0;
        $$$i$i$i$i49 = $319 ? 0 : $321;
        $$neg1$i = (1 - ($322))|0;
        $sum$i$neg$i = (($$neg1$i) - ($314))|0;
        $323 = (($sum$i$neg$i) + ($$$i$i$i$i49))|0;
        $324 = ($323>>>0)>(681);
        if ($324) {
         $325 = $315;
         $326 = ((($325)) + -4|0);
         $327 = HEAP32[$326>>2]|0;
         __ZdlPv($327);
         $328 = HEAP32[$221>>2]|0;
         $329 = ((($328)) + -4|0);
         HEAP32[$221>>2] = $329;
        }
        $330 = HEAP8[$220>>0]|0;
        $331 = ($330<<24>>24)<(0);
        if ($331) {
         $332 = HEAP32[$9>>2]|0;
         __ZdlPv($332);
        }
        $333 = HEAP32[$215>>2]|0;
        $334 = ($333|0)==(0);
        if ($334) {
         $$3 = 1;$$pre$phi123Z2D = $219;$$pre$phi125Z2D = $218;$$pre$phi127Z2D = $221;
         break L89;
        } else {
         $224 = $333;
        }
       }
       if ((label|0) == 21) {
        $94 = ___cxa_find_matching_catch_2()|0;
        $95 = tempRet0;
        $$pre$pre$phiZZ2D = $219;$$pre116$pre$phiZZ2D = $218;$$pre118$pre$phiZZ2D = $221;$lpad$phi$index = $94;$lpad$phi$index2 = $95;
        label = 23;
        break L27;
       }
       __THREW__ = 0;
       $246 = (invoke_ii(3265,5)|0);
       $247 = __THREW__; __THREW__ = 0;
       $248 = $247&1;
       L116: do {
        if ($248) {
         label = 92;
        } else {
         if (!($246)) {
          $338 = HEAP8[$220>>0]|0;
          $339 = ($338<<24>>24)<(0);
          if ($339) {
           $340 = HEAP32[$9>>2]|0;
           __ZdlPv($340);
          }
          $$3 = 0;$$pre$phi123Z2D = $219;$$pre$phi125Z2D = $218;$$pre$phi127Z2D = $221;
          break L89;
         }
         __THREW__ = 0;
         $249 = (invoke_ii(3266,5)|0);
         $250 = __THREW__; __THREW__ = 0;
         $251 = $250&1;
         if ($251) {
          label = 92;
         } else {
          __THREW__ = 0;
          $252 = (invoke_iiii(3267,($249|0),(172678|0),24)|0);
          $253 = __THREW__; __THREW__ = 0;
          $254 = $253&1;
          if ($254) {
           label = 92;
          } else {
           __THREW__ = 0;
           $255 = (invoke_i(4247)|0);
           $256 = __THREW__; __THREW__ = 0;
           $257 = $256&1;
           if ($257) {
            label = 92;
           } else {
            $258 = HEAP32[$255>>2]|0;
            __THREW__ = 0;
            $259 = (invoke_ii(4248,($258|0))|0);
            $260 = __THREW__; __THREW__ = 0;
            $261 = $260&1;
            if ($261) {
             label = 92;
            } else {
             $262 = (_strlen($259)|0);
             __THREW__ = 0;
             $263 = (invoke_iiii(3267,($252|0),($259|0),($262|0))|0);
             $264 = __THREW__; __THREW__ = 0;
             $265 = $264&1;
             if ($265) {
              label = 92;
             } else {
              $266 = HEAP32[$263>>2]|0;
              $267 = ((($266)) + -12|0);
              $268 = HEAP32[$267>>2]|0;
              $269 = (($263) + ($268)|0);
              __THREW__ = 0;
              invoke_vii(3257,($1|0),($269|0));
              $270 = __THREW__; __THREW__ = 0;
              $271 = $270&1;
              if ($271) {
               label = 92;
              } else {
               __THREW__ = 0;
               $272 = (invoke_iii(3255,($1|0),(215188|0))|0);
               $273 = __THREW__; __THREW__ = 0;
               $274 = $273&1;
               do {
                if (!($274)) {
                 $275 = HEAP32[$272>>2]|0;
                 $276 = ((($275)) + 28|0);
                 $277 = HEAP32[$276>>2]|0;
                 __THREW__ = 0;
                 $278 = (invoke_iii($277|0,($272|0),10)|0);
                 $279 = __THREW__; __THREW__ = 0;
                 $280 = $279&1;
                 if ($280) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3263,($1|0));
                 $281 = __THREW__; __THREW__ = 0;
                 $282 = $281&1;
                 if ($282) {
                  label = 92;
                  break L116;
                 }
                 __THREW__ = 0;
                 (invoke_iii(3268,($263|0),($278|0))|0);
                 $289 = __THREW__; __THREW__ = 0;
                 $290 = $289&1;
                 if ($290) {
                  label = 92;
                  break L116;
                 }
                 __THREW__ = 0;
                 (invoke_ii(3269,($263|0))|0);
                 $291 = __THREW__; __THREW__ = 0;
                 $292 = $291&1;
                 if ($292) {
                  label = 92;
                  break L116;
                 }
                 $335 = HEAP8[$220>>0]|0;
                 $336 = ($335<<24>>24)<(0);
                 if ($336) {
                  $337 = HEAP32[$9>>2]|0;
                  __ZdlPv($337);
                 }
                 $$3 = 0;$$pre$phi123Z2D = $219;$$pre$phi125Z2D = $218;$$pre$phi127Z2D = $221;
                 break L89;
                }
               } while(0);
               $283 = ___cxa_find_matching_catch_2()|0;
               $284 = tempRet0;
               __THREW__ = 0;
               invoke_vi(3263,($1|0));
               $285 = __THREW__; __THREW__ = 0;
               $286 = $285&1;
               if ($286) {
                $287 = ___cxa_find_matching_catch_3(0|0)|0;
                $288 = tempRet0;
                ___clang_call_terminate($287);
                // unreachable;
               } else {
                $eh$lpad$body71$index14Z2D = $284;$eh$lpad$body71$indexZ2D = $283;
                break;
               }
              }
             }
            }
           }
          }
         }
        }
       } while(0);
       if ((label|0) == 92) {
        $293 = ___cxa_find_matching_catch_2()|0;
        $294 = tempRet0;
        $eh$lpad$body71$index14Z2D = $294;$eh$lpad$body71$indexZ2D = $293;
       }
       $295 = HEAP8[$220>>0]|0;
       $296 = ($295<<24>>24)<(0);
       if ($296) {
        $297 = HEAP32[$9>>2]|0;
        __ZdlPv($297);
       }
       $$2 = $eh$lpad$body71$index14Z2D;$$211 = $eh$lpad$body71$indexZ2D;$$pre$phi117Z2D = $218;$$pre$phi119Z2D = $221;$$pre$phiZ2D = $219;
       break L27;
      }
     } while(0);
     $341 = HEAP32[$$pre$phi123Z2D>>2]|0;
     $342 = HEAP32[$$pre$phi125Z2D>>2]|0;
     $343 = (($342>>>0) / 341)&-1;
     $344 = (($341) + ($343<<2)|0);
     $345 = HEAP32[$$pre$phi127Z2D>>2]|0;
     $346 = ($345|0)==($341|0);
     if ($346) {
      $347 = ((($6)) + 20|0);
      $361 = 0;$362 = $347;$465 = 0;
     } else {
      $348 = HEAP32[$344>>2]|0;
      $349 = (($342>>>0) % 341)&-1;
      $350 = (($348) + (($349*12)|0)|0);
      $phitmp$i = $350;
      $351 = ((($6)) + 20|0);
      $352 = HEAP32[$351>>2]|0;
      $353 = (($352) + ($342))|0;
      $354 = (($353>>>0) / 341)&-1;
      $355 = (($341) + ($354<<2)|0);
      $356 = HEAP32[$355>>2]|0;
      $357 = (($353>>>0) % 341)&-1;
      $358 = (($356) + (($357*12)|0)|0);
      $361 = $358;$362 = $351;$465 = $phitmp$i;
     }
     $$sroa$011$0$ph$i = $344;$$sroa$6$0$ph$i = $465;
     L154: while(1) {
      $$sroa$6$0$i = $$sroa$6$0$ph$i;
      while(1) {
       $359 = $$sroa$6$0$i;
       $360 = ($359|0)==($361|0);
       if ($360) {
        break L154;
       }
       $369 = $$sroa$6$0$i;
       $370 = ((($369)) + 11|0);
       $371 = HEAP8[$370>>0]|0;
       $372 = ($371<<24>>24)<(0);
       if ($372) {
        $373 = HEAP32[$359>>2]|0;
        __ZdlPv($373);
       }
       $374 = ((($359)) + 12|0);
       $375 = $374;
       $376 = HEAP32[$$sroa$011$0$ph$i>>2]|0;
       $377 = (($375) - ($376))|0;
       $378 = ($377|0)==(4092);
       if ($378) {
        break;
       } else {
        $$sroa$6$0$i = $375;
       }
      }
      $379 = ((($$sroa$011$0$ph$i)) + 4|0);
      $380 = HEAP32[$379>>2]|0;
      $$sroa$011$0$ph$i = $379;$$sroa$6$0$ph$i = $380;
     }
     HEAP32[$362>>2] = 0;
     $363 = HEAP32[$$pre$phi127Z2D>>2]|0;
     $364 = HEAP32[$$pre$phi123Z2D>>2]|0;
     $365 = (($363) - ($364))|0;
     $366 = $365 >> 2;
     $367 = ($366>>>0)>(2);
     $368 = $364;
     if ($367) {
      $$in$i = $364;
      while(1) {
       $381 = $$in$i;
       $382 = HEAP32[$381>>2]|0;
       __ZdlPv($382);
       $383 = HEAP32[$$pre$phi123Z2D>>2]|0;
       $384 = ((($383)) + 4|0);
       HEAP32[$$pre$phi123Z2D>>2] = $384;
       $385 = HEAP32[$$pre$phi127Z2D>>2]|0;
       $$cast$i = $384;
       $386 = (($385) - ($$cast$i))|0;
       $387 = $386 >> 2;
       $388 = ($387>>>0)>(2);
       if ($388) {
        $$in$i = $$cast$i;
       } else {
        $$in128 = $385;$$lcssa$i = $387;$390 = $384;
        break;
       }
      }
     } else {
      $$in128 = $363;$$lcssa$i = $366;$390 = $368;
     }
     $389 = $$in128;
     switch ($$lcssa$i|0) {
     case 1:  {
      $$sink$i = 170;
      label = 124;
      break;
     }
     case 2:  {
      $$sink$i = 341;
      label = 124;
      break;
     }
     default: {
     }
     }
     if ((label|0) == 124) {
      HEAP32[$$pre$phi125Z2D>>2] = $$sink$i;
     }
     $391 = ($390|0)==($389|0);
     if (!($391)) {
      $$08$i$i = $390;
      while(1) {
       $392 = HEAP32[$$08$i$i>>2]|0;
       __ZdlPv($392);
       $393 = ((($$08$i$i)) + 4|0);
       $394 = ($393|0)==($389|0);
       if ($394) {
        break;
       } else {
        $$08$i$i = $393;
       }
      }
      $$pre$i$i53 = HEAP32[$$pre$phi123Z2D>>2]|0;
      $$pre9$i$i54 = HEAP32[$$pre$phi127Z2D>>2]|0;
      $395 = ($$pre9$i$i54|0)==($$pre$i$i53|0);
      if (!($395)) {
       $scevgep$i$i$i$i$i$i = ((($$pre9$i$i54)) + -4|0);
       $396 = $scevgep$i$i$i$i$i$i;
       $397 = $$pre$i$i53;
       $398 = (($396) - ($397))|0;
       $399 = $398 >>> 2;
       $400 = $399 ^ -1;
       $scevgep5$i$i$i$i$i$i = (($$pre9$i$i54) + ($400<<2)|0);
       HEAP32[$$pre$phi127Z2D>>2] = $scevgep5$i$i$i$i$i$i;
      }
     }
     $401 = HEAP32[$6>>2]|0;
     $402 = ($401|0)==(0|0);
     if (!($402)) {
      __ZdlPv($401);
     }
     $$4 = $$3;
     break L15;
    }
   } while(0);
   if ((label|0) == 23) {
    $$2 = $lpad$phi$index2;$$211 = $lpad$phi$index;$$pre$phi117Z2D = $$pre116$pre$phiZZ2D;$$pre$phi119Z2D = $$pre118$pre$phiZZ2D;$$pre$phiZ2D = $$pre$pre$phiZZ2D;
   }
   $403 = HEAP32[$$pre$phiZ2D>>2]|0;
   $404 = HEAP32[$$pre$phi117Z2D>>2]|0;
   $405 = (($404>>>0) / 341)&-1;
   $406 = (($403) + ($405<<2)|0);
   $407 = HEAP32[$$pre$phi119Z2D>>2]|0;
   $408 = ($407|0)==($403|0);
   if ($408) {
    $409 = ((($6)) + 20|0);
    $423 = 0;$424 = $409;$466 = 0;
   } else {
    $410 = HEAP32[$406>>2]|0;
    $411 = (($404>>>0) % 341)&-1;
    $412 = (($410) + (($411*12)|0)|0);
    $phitmp$i74 = $412;
    $413 = ((($6)) + 20|0);
    $414 = HEAP32[$413>>2]|0;
    $415 = (($414) + ($404))|0;
    $416 = (($415>>>0) / 341)&-1;
    $417 = (($403) + ($416<<2)|0);
    $418 = HEAP32[$417>>2]|0;
    $419 = (($415>>>0) % 341)&-1;
    $420 = (($418) + (($419*12)|0)|0);
    $423 = $420;$424 = $413;$466 = $phitmp$i74;
   }
   $$sroa$011$0$ph$i76 = $406;$$sroa$6$0$ph$i77 = $466;
   L189: while(1) {
    $$sroa$6$0$i79 = $$sroa$6$0$ph$i77;
    while(1) {
     $421 = $$sroa$6$0$i79;
     $422 = ($421|0)==($423|0);
     if ($422) {
      break L189;
     }
     $431 = $$sroa$6$0$i79;
     $432 = ((($431)) + 11|0);
     $433 = HEAP8[$432>>0]|0;
     $434 = ($433<<24>>24)<(0);
     if ($434) {
      $435 = HEAP32[$421>>2]|0;
      __ZdlPv($435);
     }
     $436 = ((($421)) + 12|0);
     $437 = $436;
     $438 = HEAP32[$$sroa$011$0$ph$i76>>2]|0;
     $439 = (($437) - ($438))|0;
     $440 = ($439|0)==(4092);
     if ($440) {
      break;
     } else {
      $$sroa$6$0$i79 = $437;
     }
    }
    $441 = ((($$sroa$011$0$ph$i76)) + 4|0);
    $442 = HEAP32[$441>>2]|0;
    $$sroa$011$0$ph$i76 = $441;$$sroa$6$0$ph$i77 = $442;
   }
   HEAP32[$424>>2] = 0;
   $425 = HEAP32[$$pre$phi119Z2D>>2]|0;
   $426 = HEAP32[$$pre$phiZ2D>>2]|0;
   $427 = (($425) - ($426))|0;
   $428 = $427 >> 2;
   $429 = ($428>>>0)>(2);
   $430 = $426;
   if ($429) {
    $$in$i82 = $426;
    while(1) {
     $443 = $$in$i82;
     $444 = HEAP32[$443>>2]|0;
     __ZdlPv($444);
     $445 = HEAP32[$$pre$phiZ2D>>2]|0;
     $446 = ((($445)) + 4|0);
     HEAP32[$$pre$phiZ2D>>2] = $446;
     $447 = HEAP32[$$pre$phi119Z2D>>2]|0;
     $$cast$i83 = $446;
     $448 = (($447) - ($$cast$i83))|0;
     $449 = $448 >> 2;
     $450 = ($449>>>0)>(2);
     if ($450) {
      $$in$i82 = $$cast$i83;
     } else {
      $$in = $447;$$lcssa$i85 = $449;$452 = $446;
      break;
     }
    }
   } else {
    $$in = $425;$$lcssa$i85 = $428;$452 = $430;
   }
   $451 = $$in;
   switch ($$lcssa$i85|0) {
   case 1:  {
    $$sink$i87 = 170;
    label = 146;
    break;
   }
   case 2:  {
    $$sink$i87 = 341;
    label = 146;
    break;
   }
   default: {
   }
   }
   if ((label|0) == 146) {
    HEAP32[$$pre$phi117Z2D>>2] = $$sink$i87;
   }
   $453 = ($452|0)==($451|0);
   if (!($453)) {
    $$08$i$i55 = $452;
    while(1) {
     $454 = HEAP32[$$08$i$i55>>2]|0;
     __ZdlPv($454);
     $455 = ((($$08$i$i55)) + 4|0);
     $456 = ($455|0)==($451|0);
     if ($456) {
      break;
     } else {
      $$08$i$i55 = $455;
     }
    }
    $$pre$i$i57 = HEAP32[$$pre$phiZ2D>>2]|0;
    $$pre9$i$i58 = HEAP32[$$pre$phi119Z2D>>2]|0;
    $457 = ($$pre9$i$i58|0)==($$pre$i$i57|0);
    if (!($457)) {
     $scevgep$i$i$i$i$i$i60 = ((($$pre9$i$i58)) + -4|0);
     $458 = $scevgep$i$i$i$i$i$i60;
     $459 = $$pre$i$i57;
     $460 = (($458) - ($459))|0;
     $461 = $460 >>> 2;
     $462 = $461 ^ -1;
     $scevgep5$i$i$i$i$i$i61 = (($$pre9$i$i58) + ($462<<2)|0);
     HEAP32[$$pre$phi119Z2D>>2] = $scevgep5$i$i$i$i$i$i61;
    }
   }
   $463 = HEAP32[$6>>2]|0;
   $464 = ($463|0)==(0|0);
   if ($464) {
    ___resumeException($$211|0);
    // unreachable;
   }
   __ZdlPv($463);
   ___resumeException($$211|0);
   // unreachable;
  }
 } while(0);
 $$5 = $$4;
 STACKTOP = sp;return ($$5|0);
}
function __ZN5osgDB10fileExistsERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 11|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)<(0);
 $4 = HEAP32[$0>>2]|0;
 $5 = $3 ? $4 : $0;
 $6 = (_access($5,0)|0);
 $7 = ($6|0)==(0);
 return ($7|0);
}
function __ZN5osgDB33convertStringPathIntoFilePathListERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEERNS0_5dequeIS6_NS4_IS6_EEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$$i$i$i = 0, $$$i$i$i26 = 0, $$0 = 0, $$019 = 0, $$020$lcssa = 0, $$02038 = 0, $$pre = 0, $$pre$i = 0, $$pre$i28 = 0, $$pre4$i = 0, $$pre4$i29 = 0, $$pre5$i = 0, $$pre5$i30 = 0, $$pre6$i = 0, $$pre6$i31 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0;
 var $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $sum$i$i = 0, $sum$i$i27 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $2 = sp + 12|0;
 $3 = sp + 25|0;
 $4 = sp;
 $5 = sp + 24|0;
 $6 = ((($0)) + 11|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = ($7<<24>>24)<(0);
 $9 = ((($0)) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $7&255;
 $12 = $8 ? $10 : $11;
 $13 = ($12|0)==(0);
 if ($13) {
  STACKTOP = sp;return;
 }
 $14 = (__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE4findEcj($0,58,0)|0);
 $15 = ($14|0)==(-1);
 L4: do {
  if ($15) {
   $$020$lcssa = 0;
  } else {
   $16 = ((($1)) + 8|0);
   $17 = ((($1)) + 4|0);
   $18 = ((($1)) + 16|0);
   $19 = ((($1)) + 20|0);
   $20 = ((($2)) + 11|0);
   $$02038 = 0;$22 = $14;
   while(1) {
    $21 = (($22) - ($$02038))|0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_jjRKS4_($2,$0,$$02038,$21,$3);
    $23 = HEAP32[$16>>2]|0;
    $24 = HEAP32[$17>>2]|0;
    $25 = (($23) - ($24))|0;
    $26 = $25 >> 2;
    $27 = ($26|0)==(0);
    $28 = ($26*341)|0;
    $29 = (($28) + -1)|0;
    $$$i$i$i = $27 ? 0 : $29;
    $30 = HEAP32[$18>>2]|0;
    $31 = HEAP32[$19>>2]|0;
    $sum$i$i = (($31) + ($30))|0;
    $32 = ($$$i$i$i|0)==($sum$i$i|0);
    $33 = $24;
    $34 = $23;
    if ($32) {
     __THREW__ = 0;
     invoke_vi(4201,($1|0));
     $35 = __THREW__; __THREW__ = 0;
     $36 = $35&1;
     if ($36) {
      break;
     }
     $$pre$i = HEAP32[$19>>2]|0;
     $$pre4$i = HEAP32[$18>>2]|0;
     $$pre5$i = HEAP32[$17>>2]|0;
     $$pre6$i = HEAP32[$16>>2]|0;
     $38 = $$pre4$i;$39 = $$pre$i;$40 = $$pre6$i;$42 = $$pre5$i;
    } else {
     $38 = $30;$39 = $31;$40 = $34;$42 = $33;
    }
    $37 = (($39) + ($38))|0;
    $41 = ($40|0)==($42|0);
    if ($41) {
     $48 = 0;
    } else {
     $43 = (($37>>>0) / 341)&-1;
     $44 = (($42) + ($43<<2)|0);
     $45 = HEAP32[$44>>2]|0;
     $46 = (($37>>>0) % 341)&-1;
     $47 = (($45) + (($46*12)|0)|0);
     $48 = $47;
    }
    __THREW__ = 0;
    invoke_vii(3457,($48|0),($2|0));
    $49 = __THREW__; __THREW__ = 0;
    $50 = $49&1;
    if ($50) {
     break;
    }
    $51 = HEAP32[$19>>2]|0;
    $52 = (($51) + 1)|0;
    HEAP32[$19>>2] = $52;
    $53 = HEAP8[$20>>0]|0;
    $54 = ($53<<24>>24)<(0);
    if ($54) {
     $55 = HEAP32[$2>>2]|0;
     __ZdlPv($55);
    }
    $56 = (($22) + 1)|0;
    $57 = (__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE4findEcj($0,58,$56)|0);
    $58 = ($57|0)==(-1);
    if ($58) {
     $$020$lcssa = $56;
     break L4;
    } else {
     $$02038 = $56;$22 = $57;
    }
   }
   $59 = ___cxa_find_matching_catch_2()|0;
   $60 = tempRet0;
   $61 = HEAP8[$20>>0]|0;
   $62 = ($61<<24>>24)<(0);
   if ($62) {
    $63 = HEAP32[$2>>2]|0;
    __ZdlPv($63);
   }
   $$0 = $60;$$019 = $59;
   ___resumeException($$019|0);
   // unreachable;
  }
 } while(0);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_jjRKS4_($4,$0,$$020$lcssa,-1,$5);
 $64 = ((($4)) + 11|0);
 $65 = HEAP8[$64>>0]|0;
 $66 = ($65<<24>>24)<(0);
 $67 = ((($4)) + 4|0);
 $68 = HEAP32[$67>>2]|0;
 $69 = $65&255;
 $70 = $66 ? $68 : $69;
 $71 = ($70|0)==(0);
 do {
  if ($71) {
   $111 = $65;
  } else {
   $72 = ((($1)) + 8|0);
   $73 = HEAP32[$72>>2]|0;
   $74 = ((($1)) + 4|0);
   $75 = HEAP32[$74>>2]|0;
   $76 = (($73) - ($75))|0;
   $77 = $76 >> 2;
   $78 = ($77|0)==(0);
   $79 = ($77*341)|0;
   $80 = (($79) + -1)|0;
   $$$i$i$i26 = $78 ? 0 : $80;
   $81 = ((($1)) + 16|0);
   $82 = HEAP32[$81>>2]|0;
   $83 = ((($1)) + 20|0);
   $84 = HEAP32[$83>>2]|0;
   $sum$i$i27 = (($84) + ($82))|0;
   $85 = ($$$i$i$i26|0)==($sum$i$i27|0);
   $86 = $75;
   $87 = $73;
   if ($85) {
    __THREW__ = 0;
    invoke_vi(4201,($1|0));
    $88 = __THREW__; __THREW__ = 0;
    $89 = $88&1;
    if (!($89)) {
     $$pre$i28 = HEAP32[$83>>2]|0;
     $$pre4$i29 = HEAP32[$81>>2]|0;
     $$pre5$i30 = HEAP32[$74>>2]|0;
     $$pre6$i31 = HEAP32[$72>>2]|0;
     $91 = $$pre4$i29;$92 = $$pre$i28;$93 = $$pre6$i31;$95 = $$pre5$i30;
     label = 20;
    }
   } else {
    $91 = $82;$92 = $84;$93 = $87;$95 = $86;
    label = 20;
   }
   if ((label|0) == 20) {
    $90 = (($92) + ($91))|0;
    $94 = ($93|0)==($95|0);
    if ($94) {
     $101 = 0;
    } else {
     $96 = (($90>>>0) / 341)&-1;
     $97 = (($95) + ($96<<2)|0);
     $98 = HEAP32[$97>>2]|0;
     $99 = (($90>>>0) % 341)&-1;
     $100 = (($98) + (($99*12)|0)|0);
     $101 = $100;
    }
    __THREW__ = 0;
    invoke_vii(3457,($101|0),($4|0));
    $102 = __THREW__; __THREW__ = 0;
    $103 = $102&1;
    if (!($103)) {
     $104 = HEAP32[$83>>2]|0;
     $105 = (($104) + 1)|0;
     HEAP32[$83>>2] = $105;
     $$pre = HEAP8[$64>>0]|0;
     $111 = $$pre;
     break;
    }
   }
   $106 = ___cxa_find_matching_catch_2()|0;
   $107 = tempRet0;
   $108 = HEAP8[$64>>0]|0;
   $109 = ($108<<24>>24)<(0);
   if ($109) {
    $110 = HEAP32[$4>>2]|0;
    __ZdlPv($110);
   }
   $$0 = $107;$$019 = $106;
   ___resumeException($$019|0);
   // unreachable;
  }
 } while(0);
 $112 = ($111<<24>>24)<(0);
 if ($112) {
  $113 = HEAP32[$4>>2]|0;
  __ZdlPv($113);
 }
 STACKTOP = sp;return;
}
function __ZN5osgDB14findFileInPathERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEERKNS0_5dequeIS6_NS4_IS6_EEEENS_15CaseSensitivityE($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$018 = 0, $$021 = 0, $$1 = 0, $$119 = 0, $$122 = 0, $$220 = 0, $$223 = 0, $$mux = 0, $$not = 0, $$not61 = 0, $$pre = 0, $$pre$phi60Z2D = 0, $$pre59 = 0, $$sroa$039$0$ph = 0, $$sroa$6$0 = 0, $$sroa$6$0$ph = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0;
 var $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0;
 var $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $brmerge = 0, $cond = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $4 = sp + 24|0;
 $5 = sp + 12|0;
 $6 = sp;
 $7 = ((($1)) + 11|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = ($8<<24>>24)<(0);
 $10 = ((($1)) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $8&255;
 $13 = $9 ? $11 : $12;
 $14 = ($13|0)==(0);
 if ($14) {
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_($0,$1);
  STACKTOP = sp;return;
 }
 $15 = (__ZN5osgDB21isFileNameNativeStyleERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE($1)|0);
 if (!($15)) {
  __ZN5osgDB28convertFileNameToNativeStyleERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE($4,$1);
  __THREW__ = 0;
  invoke_viiii(4197,($0|0),($4|0),($2|0),($3|0));
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if ($17) {
   $22 = ___cxa_find_matching_catch_2()|0;
   $23 = tempRet0;
   $24 = ((($4)) + 11|0);
   $25 = HEAP8[$24>>0]|0;
   $26 = ($25<<24>>24)<(0);
   if ($26) {
    $27 = HEAP32[$4>>2]|0;
    __ZdlPv($27);
   }
   $$220 = $23;$$223 = $22;
   ___resumeException($$223|0);
   // unreachable;
  } else {
   $18 = ((($4)) + 11|0);
   $19 = HEAP8[$18>>0]|0;
   $20 = ($19<<24>>24)<(0);
   if ($20) {
    $21 = HEAP32[$4>>2]|0;
    __ZdlPv($21);
   }
   STACKTOP = sp;return;
  }
 }
 $28 = ((($2)) + 4|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ((($2)) + 16|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (($31>>>0) / 341)&-1;
 $33 = (($29) + ($32<<2)|0);
 $34 = ((($2)) + 8|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = ($35|0)==($29|0);
 if ($36) {
  $170 = 0;
 } else {
  $37 = HEAP32[$33>>2]|0;
  $38 = (($31>>>0) % 341)&-1;
  $39 = (($37) + (($38*12)|0)|0);
  $phitmp = $39;
  $170 = $phitmp;
 }
 $40 = ((($2)) + 20|0);
 $41 = ((($6)) + 11|0);
 $42 = ((($5)) + 11|0);
 $43 = ((($5)) + 4|0);
 $44 = ($3|0)==(1);
 $45 = ((($0)) + 11|0);
 $46 = ((($0)) + 4|0);
 $$sroa$039$0$ph = $33;$$sroa$6$0$ph = $170;
 L22: while(1) {
  $$sroa$6$0 = $$sroa$6$0$ph;
  while(1) {
   $47 = HEAP32[$40>>2]|0;
   $48 = HEAP32[$30>>2]|0;
   $49 = (($48) + ($47))|0;
   $50 = HEAP32[$28>>2]|0;
   $51 = HEAP32[$34>>2]|0;
   $52 = ($51|0)==($50|0);
   if ($52) {
    $60 = 0;
   } else {
    $53 = (($49>>>0) / 341)&-1;
    $54 = (($50) + ($53<<2)|0);
    $55 = HEAP32[$54>>2]|0;
    $56 = (($49>>>0) % 341)&-1;
    $57 = (($55) + (($56*12)|0)|0);
    $60 = $57;
   }
   $58 = $$sroa$6$0;
   $59 = ($58|0)==($60|0);
   if ($59) {
    label = 65;
    break L22;
   }
   $61 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(5)|0);
   if ($61) {
    $62 = (__ZN3osg6notifyENS_14NotifySeverityE(5)|0);
    $63 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($62,172743,5)|0);
    $64 = $$sroa$6$0;
    $65 = ((($64)) + 11|0);
    $66 = HEAP8[$65>>0]|0;
    $67 = ($66<<24>>24)<(0);
    $68 = HEAP32[$58>>2]|0;
    $69 = $$sroa$6$0;
    $70 = $67 ? $68 : $69;
    $71 = ((($58)) + 4|0);
    $72 = HEAP32[$71>>2]|0;
    $73 = $66&255;
    $74 = $67 ? $72 : $73;
    $75 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($63,$70,$74)|0);
    (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($75,172749,2)|0);
    $$pre$phi60Z2D = $65;
   } else {
    $$pre = $$sroa$6$0;
    $$pre59 = ((($$pre)) + 11|0);
    $$pre$phi60Z2D = $$pre59;
   }
   $76 = HEAP8[$$pre$phi60Z2D>>0]|0;
   $77 = ($76<<24>>24)<(0);
   if ($77) {
    $78 = ((($58)) + 4|0);
    $79 = HEAP32[$78>>2]|0;
    $81 = $79;
   } else {
    $80 = $76&255;
    $81 = $80;
   }
   $82 = ($81|0)==(0);
   if ($82) {
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_($5,$1);
   } else {
    __ZN5osgDB11concatPathsERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEES8_($5,$58,$1);
   }
   __THREW__ = 0;
   invoke_vii(4249,($6|0),($5|0));
   $83 = __THREW__; __THREW__ = 0;
   $84 = $83&1;
   if ($84) {
    label = 37;
    break L22;
   }
   __THREW__ = 0;
   (invoke_iii(3477,($5|0),($6|0))|0);
   $85 = __THREW__; __THREW__ = 0;
   $86 = $85&1;
   if ($86) {
    label = 38;
    break L22;
   }
   $87 = HEAP8[$41>>0]|0;
   $88 = ($87<<24>>24)<(0);
   if ($88) {
    $89 = HEAP32[$6>>2]|0;
    __ZdlPv($89);
   }
   __THREW__ = 0;
   $90 = (invoke_ii(3265,5)|0);
   $91 = __THREW__; __THREW__ = 0;
   $92 = $91&1;
   if ($92) {
    label = 41;
    break L22;
   }
   if ($90) {
    __THREW__ = 0;
    $93 = (invoke_ii(3266,5)|0);
    $94 = __THREW__; __THREW__ = 0;
    $95 = $94&1;
    if ($95) {
     label = 41;
     break L22;
    }
    __THREW__ = 0;
    $96 = (invoke_iiii(3267,($93|0),(172752|0),26)|0);
    $97 = __THREW__; __THREW__ = 0;
    $98 = $97&1;
    if ($98) {
     label = 41;
     break L22;
    }
    $99 = HEAP8[$42>>0]|0;
    $100 = ($99<<24>>24)<(0);
    $101 = HEAP32[$5>>2]|0;
    $102 = $100 ? $101 : $5;
    $103 = HEAP32[$43>>2]|0;
    $104 = $99&255;
    $105 = $100 ? $103 : $104;
    __THREW__ = 0;
    $106 = (invoke_iiii(3267,($96|0),($102|0),($105|0))|0);
    $107 = __THREW__; __THREW__ = 0;
    $108 = $107&1;
    if ($108) {
     label = 41;
     break L22;
    }
    __THREW__ = 0;
    (invoke_iiii(3267,($106|0),(172779|0),5)|0);
    $109 = __THREW__; __THREW__ = 0;
    $110 = $109&1;
    if ($110) {
     label = 41;
     break L22;
    }
   }
   $120 = HEAP8[$42>>0]|0;
   $121 = ($120<<24>>24)<(0);
   $122 = HEAP32[$5>>2]|0;
   $123 = $121 ? $122 : $5;
   $124 = (_access($123,0)|0);
   $125 = ($124|0)==(0);
   do {
    if ($125) {
     __THREW__ = 0;
     $126 = (invoke_ii(3265,5)|0);
     $127 = __THREW__; __THREW__ = 0;
     $128 = $127&1;
     if ($128) {
      label = 41;
      break L22;
     }
     if ($126) {
      __THREW__ = 0;
      $129 = (invoke_ii(3266,5)|0);
      $130 = __THREW__; __THREW__ = 0;
      $131 = $130&1;
      if ($131) {
       label = 41;
       break L22;
      }
      __THREW__ = 0;
      $132 = (invoke_iiii(3267,($129|0),(172785|0),25)|0);
      $133 = __THREW__; __THREW__ = 0;
      $134 = $133&1;
      if ($134) {
       label = 41;
       break L22;
      }
      $135 = HEAP8[$42>>0]|0;
      $136 = ($135<<24>>24)<(0);
      $137 = HEAP32[$5>>2]|0;
      $138 = $136 ? $137 : $5;
      $139 = HEAP32[$43>>2]|0;
      $140 = $135&255;
      $141 = $136 ? $139 : $140;
      __THREW__ = 0;
      $142 = (invoke_iiii(3267,($132|0),($138|0),($141|0))|0);
      $143 = __THREW__; __THREW__ = 0;
      $144 = $143&1;
      if ($144) {
       label = 41;
       break L22;
      }
      __THREW__ = 0;
      (invoke_iiii(3267,($142|0),(195712|0),1)|0);
      $145 = __THREW__; __THREW__ = 0;
      $146 = $145&1;
      if ($146) {
       label = 41;
       break L22;
      }
     }
     __THREW__ = 0;
     invoke_vii(3457,($0|0),($5|0));
     $147 = __THREW__; __THREW__ = 0;
     $148 = $147&1;
     if ($148) {
      label = 41;
      break L22;
     } else {
      $$1 = 1;
     }
    } else {
     if ($44) {
      __THREW__ = 0;
      invoke_viiii(4250,($0|0),($1|0),($58|0),1);
      $149 = __THREW__; __THREW__ = 0;
      $150 = $149&1;
      if ($150) {
       label = 41;
       break L22;
      }
      $151 = HEAP8[$45>>0]|0;
      $152 = ($151<<24>>24)<(0);
      if ($152) {
       $153 = HEAP32[$46>>2]|0;
       $155 = $153;
      } else {
       $154 = $151&255;
       $155 = $154;
      }
      $$not = ($155|0)!=(0);
      $$not61 = $152 ^ 1;
      $brmerge = $$not | $$not61;
      $$mux = $$not&1;
      if ($brmerge) {
       $$1 = $$mux;
       break;
      }
      $156 = HEAP32[$0>>2]|0;
      __ZdlPv($156);
      $$1 = 0;
     } else {
      $$1 = 0;
     }
    }
   } while(0);
   $157 = HEAP8[$42>>0]|0;
   $158 = ($157<<24>>24)<(0);
   if ($158) {
    $159 = HEAP32[$5>>2]|0;
    __ZdlPv($159);
   }
   $cond = ($$1|0)==(0);
   if (!($cond)) {
    label = 66;
    break L22;
   }
   $160 = ((($58)) + 12|0);
   $161 = $160;
   $162 = HEAP32[$$sroa$039$0$ph>>2]|0;
   $163 = (($161) - ($162))|0;
   $164 = ($163|0)==(4092);
   if ($164) {
    break;
   } else {
    $$sroa$6$0 = $161;
   }
  }
  $165 = ((($$sroa$039$0$ph)) + 4|0);
  $166 = HEAP32[$165>>2]|0;
  $$sroa$039$0$ph = $165;$$sroa$6$0$ph = $166;
 }
 if ((label|0) == 37) {
  $111 = ___cxa_find_matching_catch_2()|0;
  $112 = tempRet0;
  $$018 = $112;$$021 = $111;
  label = 40;
 }
 else if ((label|0) == 38) {
  $113 = ___cxa_find_matching_catch_2()|0;
  $114 = tempRet0;
  $115 = HEAP8[$41>>0]|0;
  $116 = ($115<<24>>24)<(0);
  if ($116) {
   $117 = HEAP32[$6>>2]|0;
   __ZdlPv($117);
   $$018 = $114;$$021 = $113;
   label = 40;
  } else {
   $$018 = $114;$$021 = $113;
   label = 40;
  }
 }
 else if ((label|0) == 41) {
  $118 = ___cxa_find_matching_catch_2()|0;
  $119 = tempRet0;
  $$119 = $119;$$122 = $118;
 }
 else if ((label|0) == 65) {
  ;HEAP32[$0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 66) {
  STACKTOP = sp;return;
 }
 if ((label|0) == 40) {
  $$119 = $$018;$$122 = $$021;
 }
 $167 = HEAP8[$42>>0]|0;
 $168 = ($167<<24>>24)<(0);
 if ($168) {
  $169 = HEAP32[$5>>2]|0;
  __ZdlPv($169);
 }
 $$220 = $$119;$$223 = $$122;
 ___resumeException($$223|0);
 // unreachable;
}
function __ZN5osgDB19findFileInDirectoryERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEES8_NS_15CaseSensitivityE($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$02026$i$i300 = 0, $$02026$i$us363 = 0, $$02026$i367 = 0, $$02125$i$i301 = 0, $$02125$i$us364 = 0, $$02125$i368 = 0, $$027$i$i299 = 0, $$027$i$us362 = 0, $$027$i366 = 0, $$029 = 0, $$033 = 0, $$1 = 0, $$1$i$i = 0, $$10 = 0, $$1043 = 0, $$12 = 0, $$1245 = 0, $$128$off0 = 0, $$130 = 0, $$134 = 0;
 var $$14 = 0, $$1447 = 0, $$16 = 0, $$1649 = 0, $$17 = 0, $$1750 = 0, $$18 = 0, $$1851 = 0, $$19 = 0, $$1952 = 0, $$20 = 0, $$2053 = 0, $$21 = 0, $$2154 = 0, $$22 = 0, $$2255 = 0, $$23 = 0, $$231 = 0, $$235 = 0, $$2356 = 0;
 var $$24 = 0, $$2457 = 0, $$26 = 0, $$2659 = 0, $$27 = 0, $$2760 = 0, $$28343 = 0, $$2861342 = 0, $$3$off0 = 0, $$332 = 0, $$336 = 0, $$4 = 0, $$437 = 0, $$5 = 0, $$538 = 0, $$6 = 0, $$639 = 0, $$7 = 0, $$740 = 0, $$9 = 0;
 var $$942 = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i$i = 0, $$pre$i$i$i119 = 0, $$pre$i$i$i128 = 0, $$pre$i$i$i147 = 0, $$pre$i$i$i156 = 0, $$pre$i$i$i183 = 0, $$pre$i$i$i193 = 0, $$pre$i$i$i202 = 0, $$pre$i$i$i213 = 0, $$pre$i$i$i224 = 0, $$pre$i$i$i238 = 0, $$pre$i$i$i248 = 0, $$pre$i$i$i267 = 0, $$pre$i$i$i96 = 0, $$pre$i121 = 0, $$pre$i130 = 0, $$pre$i149 = 0;
 var $$pre$i158 = 0, $$pre$i185 = 0, $$pre$i195 = 0, $$pre$i204 = 0, $$pre$i215 = 0, $$pre$i226 = 0, $$pre$i240 = 0, $$pre$i250 = 0, $$pre$i269 = 0, $$pre$i92 = 0, $$pre$i98 = 0, $$pre$phi329Z2D = 0, $$pre$phi333Z2D = 0, $$pre$phi337Z2D = 0, $$pre$phi339Z2D = 0, $$pre313 = 0, $$pre314 = 0, $$pre315 = 0, $$pre316 = 0, $$pre317 = 0;
 var $$pre318 = 0, $$pre319 = 0, $$pre320 = 0, $$pre321 = 0, $$pre322 = 0, $$pre323 = 0, $$pre324 = 0, $$pre325 = 0, $$pre326 = 0, $$pre328$pre$phiZZ2D = 0, $$pre332 = 0, $$pre336 = 0, $$pre338 = 0, $$pre341 = 0, $$sink = 0, $$sink289 = 0, $$sroa$0276$0296 = 0, $$sroa$0276$0297 = 0, $$sroa$0276$0297$us = 0, $10 = 0;
 var $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0;
 var $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0;
 var $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0;
 var $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0;
 var $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0;
 var $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0;
 var $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0;
 var $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0;
 var $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0;
 var $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0;
 var $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $30 = 0;
 var $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0;
 var $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0;
 var $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0;
 var $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0;
 var $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0;
 var $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0;
 var $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0;
 var $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0;
 var $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0;
 var $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0;
 var $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0;
 var $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0;
 var $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0;
 var $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0;
 var $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0;
 var $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0;
 var $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0;
 var $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0;
 var $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0;
 var $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0;
 var $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0;
 var $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0;
 var $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0;
 var $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0;
 var $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0;
 var $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0;
 var $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0;
 var $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $extract$t62 = 0, $phitmp$i = 0, $phitmp$i254 = 0;
 var $phitmp$i254$us = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 336|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(336|0);
 $4 = sp + 324|0;
 $5 = sp + 312|0;
 $6 = sp + 300|0;
 $7 = sp + 288|0;
 $8 = sp + 276|0;
 $9 = sp + 264|0;
 $10 = sp + 252|0;
 $11 = sp + 240|0;
 $12 = sp + 228|0;
 $13 = sp + 216|0;
 $14 = sp + 204|0;
 $15 = sp + 192|0;
 $16 = sp + 180|0;
 $17 = sp + 168|0;
 $18 = sp + 156|0;
 $19 = sp + 144|0;
 $20 = sp + 132|0;
 $21 = sp + 120|0;
 $22 = sp + 108|0;
 $23 = sp + 96|0;
 $24 = sp + 84|0;
 $25 = sp + 72|0;
 $26 = sp + 60|0;
 $27 = sp + 48|0;
 $28 = sp + 36|0;
 $29 = sp + 24|0;
 $30 = sp + 12|0;
 $31 = sp;
 HEAP32[$4>>2] = 0;
 $32 = ((($4)) + 4|0);
 HEAP32[$32>>2] = 0;
 $33 = ((($4)) + 8|0);
 HEAP32[$33>>2] = 0;
 __THREW__ = 0;
 invoke_vii(3457,($5|0),($2|0));
 $34 = __THREW__; __THREW__ = 0;
 $35 = $34&1;
 if ($35) {
  $87 = ___cxa_find_matching_catch_2()|0;
  $88 = tempRet0;
  $$28343 = $87;$$2861342 = $88;
  ___resumeException($$28343|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_vii(3457,($6|0),($1|0));
 $36 = __THREW__; __THREW__ = 0;
 $37 = $36&1;
 if ($37) {
  $89 = ___cxa_find_matching_catch_2()|0;
  $90 = tempRet0;
  $$27 = $89;$$2760 = $90;
 } else {
  __THREW__ = 0;
  invoke_vii(4196,($7|0),($1|0));
  $38 = __THREW__; __THREW__ = 0;
  $39 = $38&1;
  L8: do {
   if ($39) {
    $91 = ___cxa_find_matching_catch_2()|0;
    $92 = tempRet0;
    $$26 = $91;$$2659 = $92;
   } else {
    $40 = ((($1)) + 11|0);
    $41 = HEAP8[$40>>0]|0;
    $42 = ($41<<24>>24)<(0);
    $43 = ((($1)) + 4|0);
    $44 = HEAP32[$43>>2]|0;
    $45 = $41&255;
    $46 = $42 ? $44 : $45;
    $47 = ((($7)) + 11|0);
    $48 = HEAP8[$47>>0]|0;
    $49 = ($48<<24>>24)<(0);
    $50 = ((($7)) + 4|0);
    $51 = HEAP32[$50>>2]|0;
    $52 = $48&255;
    $53 = $49 ? $51 : $52;
    $54 = ($46|0)==($53|0);
    L11: do {
     if ($54) {
      $55 = HEAP32[$1>>2]|0;
      $56 = $42 ? $55 : $1;
      $57 = HEAP32[$7>>2]|0;
      $58 = $49 ? $57 : $7;
      $59 = ($46|0)==(0);
      if ($42) {
       if ($59) {
        $$1$i$i = 0;
        break;
       }
       $64 = (_memcmp($56,$58,$46)|0);
       $phitmp$i = ($64|0)!=(0);
       $$1$i$i = $phitmp$i;
       break;
      }
      if ($59) {
       $$1$i$i = 0;
      } else {
       $60 = $55;
       $61 = $60&255;
       $62 = HEAP8[$58>>0]|0;
       $63 = ($61<<24>>24)==($62<<24>>24);
       if ($63) {
        $$02026$i$i300 = $1;$$02125$i$i301 = $45;$$027$i$i299 = $58;
        while(1) {
         $65 = (($$02125$i$i301) + -1)|0;
         $66 = ((($$02026$i$i300)) + 1|0);
         $67 = ($65|0)==(0);
         if ($67) {
          $$1$i$i = 0;
          break L11;
         }
         $68 = ((($$027$i$i299)) + 1|0);
         $$pre$i = HEAP8[$66>>0]|0;
         $69 = HEAP8[$68>>0]|0;
         $70 = ($$pre$i<<24>>24)==($69<<24>>24);
         if ($70) {
          $$02026$i$i300 = $66;$$02125$i$i301 = $65;$$027$i$i299 = $68;
         } else {
          $$1$i$i = 1;
          break;
         }
        }
       } else {
        $$1$i$i = 1;
       }
      }
     } else {
      $$1$i$i = 1;
     }
    } while(0);
    if ($49) {
     $71 = HEAP32[$7>>2]|0;
     __ZdlPv($71);
    }
    L25: do {
     if ($$1$i$i) {
      $72 = ((($5)) + 11|0);
      $73 = HEAP8[$72>>0]|0;
      $74 = ($73<<24>>24)<(0);
      $75 = ((($5)) + 4|0);
      $76 = HEAP32[$75>>2]|0;
      $77 = $73&255;
      $78 = $74 ? $76 : $77;
      L27: do {
       switch ($78|0) {
       case 0:  {
        __THREW__ = 0;
        invoke_vii(4234,($8|0),($1|0));
        $79 = __THREW__; __THREW__ = 0;
        $80 = $79&1;
        do {
         if ($80) {
          $93 = ___cxa_find_matching_catch_2()|0;
          $94 = tempRet0;
          $$029 = $93;$$033 = $94;
         } else {
          __THREW__ = 0;
          (invoke_iii(3477,($5|0),($8|0))|0);
          $81 = __THREW__; __THREW__ = 0;
          $82 = $81&1;
          if ($82) {
           $95 = ___cxa_find_matching_catch_2()|0;
           $96 = tempRet0;
           $97 = ((($8)) + 11|0);
           $98 = HEAP8[$97>>0]|0;
           $99 = ($98<<24>>24)<(0);
           if (!($99)) {
            $$029 = $95;$$033 = $96;
            break;
           }
           $100 = HEAP32[$8>>2]|0;
           __ZdlPv($100);
           $$029 = $95;$$033 = $96;
           break;
          }
          $83 = ((($8)) + 11|0);
          $84 = HEAP8[$83>>0]|0;
          $85 = ($84<<24>>24)<(0);
          if ($85) {
           $86 = HEAP32[$8>>2]|0;
           __ZdlPv($86);
          }
          break L27;
         }
        } while(0);
        $$26 = $$029;$$2659 = $$033;
        break L8;
        break;
       }
       case 1:  {
        __THREW__ = 0;
        $101 = (invoke_iiiiii(3253,($5|0),0,-1,(199839|0),1)|0);
        $102 = __THREW__; __THREW__ = 0;
        $103 = $102&1;
        if ($103) {
         $104 = ___cxa_find_matching_catch_2()|0;
         $105 = tempRet0;
         ___cxa_call_unexpected(($104|0));
         // unreachable;
        }
        $106 = ($101|0)==(0);
        if ($106) {
         label = 41;
        } else {
         $$pre = HEAP8[$72>>0]|0;
         $$pre313 = HEAP32[$75>>2]|0;
         $107 = $$pre;$110 = $$pre313;
         label = 32;
        }
        break;
       }
       default: {
        $107 = $73;$110 = $76;
        label = 32;
       }
       }
      } while(0);
      L45: do {
       if ((label|0) == 32) {
        $108 = ($107<<24>>24)<(0);
        $109 = $107&255;
        $111 = $108 ? $110 : $109;
        $112 = ($111|0)==(2);
        if ($112) {
         __THREW__ = 0;
         $113 = (invoke_iiiiii(3253,($5|0),0,-1,(172811|0),2)|0);
         $114 = __THREW__; __THREW__ = 0;
         $115 = $114&1;
         if ($115) {
          $116 = ___cxa_find_matching_catch_2()|0;
          $117 = tempRet0;
          ___cxa_call_unexpected(($116|0));
          // unreachable;
         }
         $118 = ($113|0)==(0);
         if ($118) {
          label = 41;
          break;
         }
         $$pre314 = HEAP8[$72>>0]|0;
         $$pre315 = HEAP32[$75>>2]|0;
         $119 = $$pre314;$122 = $$pre315;
        } else {
         $119 = $107;$122 = $110;
        }
        $120 = ($119<<24>>24)<(0);
        $121 = $119&255;
        $123 = $120 ? $122 : $121;
        $124 = ($123|0)==(2);
        do {
         if ($124) {
          __THREW__ = 0;
          $125 = (invoke_iiiiii(3253,($5|0),0,-1,(172814|0),2)|0);
          $126 = __THREW__; __THREW__ = 0;
          $127 = $126&1;
          if ($127) {
           $128 = ___cxa_find_matching_catch_2()|0;
           $129 = tempRet0;
           ___cxa_call_unexpected(($128|0));
           // unreachable;
          } else {
           $130 = ($125|0)==(0);
           if ($130) {
            label = 41;
            break L45;
           } else {
            break;
           }
          }
         }
        } while(0);
        $159 = ((($2)) + 11|0);
        $160 = HEAP8[$159>>0]|0;
        $161 = ($160<<24>>24)<(0);
        $162 = ((($2)) + 4|0);
        $163 = HEAP32[$162>>2]|0;
        $164 = $160&255;
        $165 = $161 ? $163 : $164;
        $166 = (($165) + -1)|0;
        $167 = HEAP32[$2>>2]|0;
        $168 = $161 ? $167 : $2;
        $169 = (($168) + ($166)|0);
        $170 = HEAP8[$169>>0]|0;
        switch ($170<<24>>24) {
        case 92: case 47:  {
         __THREW__ = 0;
         invoke_vii(4234,($12|0),($1|0));
         $171 = __THREW__; __THREW__ = 0;
         $172 = $171&1;
         if ($172) {
          $185 = ___cxa_find_matching_catch_2()|0;
          $186 = tempRet0;
          $$4 = $185;$$437 = $186;
         } else {
          __THREW__ = 0;
          invoke_viii(3550,($11|0),($2|0),($12|0));
          $173 = __THREW__; __THREW__ = 0;
          $174 = $173&1;
          do {
           if ($174) {
            $187 = ___cxa_find_matching_catch_2()|0;
            $188 = tempRet0;
            $$332 = $187;$$336 = $188;
           } else {
            __THREW__ = 0;
            (invoke_iii(3477,($5|0),($11|0))|0);
            $175 = __THREW__; __THREW__ = 0;
            $176 = $175&1;
            if ($176) {
             $189 = ___cxa_find_matching_catch_2()|0;
             $190 = tempRet0;
             $191 = ((($11)) + 11|0);
             $192 = HEAP8[$191>>0]|0;
             $193 = ($192<<24>>24)<(0);
             if (!($193)) {
              $$332 = $189;$$336 = $190;
              break;
             }
             $194 = HEAP32[$11>>2]|0;
             __ZdlPv($194);
             $$332 = $189;$$336 = $190;
             break;
            }
            $177 = ((($11)) + 11|0);
            $178 = HEAP8[$177>>0]|0;
            $179 = ($178<<24>>24)<(0);
            if ($179) {
             $180 = HEAP32[$11>>2]|0;
             __ZdlPv($180);
            }
            $181 = ((($12)) + 11|0);
            $182 = HEAP8[$181>>0]|0;
            $183 = ($182<<24>>24)<(0);
            if ($183) {
             $184 = HEAP32[$12>>2]|0;
             __ZdlPv($184);
            }
            break L45;
           }
          } while(0);
          $195 = ((($12)) + 11|0);
          $196 = HEAP8[$195>>0]|0;
          $197 = ($196<<24>>24)<(0);
          if ($197) {
           $198 = HEAP32[$12>>2]|0;
           __ZdlPv($198);
           $$4 = $$332;$$437 = $$336;
          } else {
           $$4 = $$332;$$437 = $$336;
          }
         }
         $$26 = $$4;$$2659 = $$437;
         break L8;
         break;
        }
        default: {
        }
        }
        __THREW__ = 0;
        invoke_viii(3542,($14|0),($2|0),(172817|0));
        $199 = __THREW__; __THREW__ = 0;
        $200 = $199&1;
        if ($200) {
         $219 = ___cxa_find_matching_catch_2()|0;
         $220 = tempRet0;
         $$7 = $219;$$740 = $220;
        } else {
         __THREW__ = 0;
         invoke_vii(4234,($15|0),($1|0));
         $201 = __THREW__; __THREW__ = 0;
         $202 = $201&1;
         if ($202) {
          $221 = ___cxa_find_matching_catch_2()|0;
          $222 = tempRet0;
          $$6 = $221;$$639 = $222;
         } else {
          __THREW__ = 0;
          invoke_viii(3550,($13|0),($14|0),($15|0));
          $203 = __THREW__; __THREW__ = 0;
          $204 = $203&1;
          do {
           if ($204) {
            $223 = ___cxa_find_matching_catch_2()|0;
            $224 = tempRet0;
            $$5 = $223;$$538 = $224;
           } else {
            __THREW__ = 0;
            (invoke_iii(3477,($5|0),($13|0))|0);
            $205 = __THREW__; __THREW__ = 0;
            $206 = $205&1;
            if ($206) {
             $225 = ___cxa_find_matching_catch_2()|0;
             $226 = tempRet0;
             $227 = ((($13)) + 11|0);
             $228 = HEAP8[$227>>0]|0;
             $229 = ($228<<24>>24)<(0);
             if (!($229)) {
              $$5 = $225;$$538 = $226;
              break;
             }
             $230 = HEAP32[$13>>2]|0;
             __ZdlPv($230);
             $$5 = $225;$$538 = $226;
             break;
            }
            $207 = ((($13)) + 11|0);
            $208 = HEAP8[$207>>0]|0;
            $209 = ($208<<24>>24)<(0);
            if ($209) {
             $210 = HEAP32[$13>>2]|0;
             __ZdlPv($210);
            }
            $211 = ((($15)) + 11|0);
            $212 = HEAP8[$211>>0]|0;
            $213 = ($212<<24>>24)<(0);
            if ($213) {
             $214 = HEAP32[$15>>2]|0;
             __ZdlPv($214);
            }
            $215 = ((($14)) + 11|0);
            $216 = HEAP8[$215>>0]|0;
            $217 = ($216<<24>>24)<(0);
            if ($217) {
             $218 = HEAP32[$14>>2]|0;
             __ZdlPv($218);
            }
            break L45;
           }
          } while(0);
          $231 = ((($15)) + 11|0);
          $232 = HEAP8[$231>>0]|0;
          $233 = ($232<<24>>24)<(0);
          if ($233) {
           $234 = HEAP32[$15>>2]|0;
           __ZdlPv($234);
           $$6 = $$5;$$639 = $$538;
          } else {
           $$6 = $$5;$$639 = $$538;
          }
         }
         $235 = ((($14)) + 11|0);
         $236 = HEAP8[$235>>0]|0;
         $237 = ($236<<24>>24)<(0);
         if ($237) {
          $238 = HEAP32[$14>>2]|0;
          __ZdlPv($238);
          $$7 = $$6;$$740 = $$639;
         } else {
          $$7 = $$6;$$740 = $$639;
         }
        }
        $$26 = $$7;$$2659 = $$740;
        break L8;
       }
      } while(0);
      L109: do {
       if ((label|0) == 41) {
        __THREW__ = 0;
        invoke_vii(4234,($10|0),($1|0));
        $131 = __THREW__; __THREW__ = 0;
        $132 = $131&1;
        if ($132) {
         $145 = ___cxa_find_matching_catch_2()|0;
         $146 = tempRet0;
         $$231 = $145;$$235 = $146;
        } else {
         __THREW__ = 0;
         invoke_viii(4173,($9|0),(172811|0),($10|0));
         $133 = __THREW__; __THREW__ = 0;
         $134 = $133&1;
         do {
          if ($134) {
           $147 = ___cxa_find_matching_catch_2()|0;
           $148 = tempRet0;
           $$130 = $147;$$134 = $148;
          } else {
           __THREW__ = 0;
           (invoke_iii(3477,($5|0),($9|0))|0);
           $135 = __THREW__; __THREW__ = 0;
           $136 = $135&1;
           if ($136) {
            $149 = ___cxa_find_matching_catch_2()|0;
            $150 = tempRet0;
            $151 = ((($9)) + 11|0);
            $152 = HEAP8[$151>>0]|0;
            $153 = ($152<<24>>24)<(0);
            if (!($153)) {
             $$130 = $149;$$134 = $150;
             break;
            }
            $154 = HEAP32[$9>>2]|0;
            __ZdlPv($154);
            $$130 = $149;$$134 = $150;
            break;
           }
           $137 = ((($9)) + 11|0);
           $138 = HEAP8[$137>>0]|0;
           $139 = ($138<<24>>24)<(0);
           if ($139) {
            $140 = HEAP32[$9>>2]|0;
            __ZdlPv($140);
           }
           $141 = ((($10)) + 11|0);
           $142 = HEAP8[$141>>0]|0;
           $143 = ($142<<24>>24)<(0);
           if ($143) {
            $144 = HEAP32[$10>>2]|0;
            __ZdlPv($144);
           }
           break L109;
          }
         } while(0);
         $155 = ((($10)) + 11|0);
         $156 = HEAP8[$155>>0]|0;
         $157 = ($156<<24>>24)<(0);
         if ($157) {
          $158 = HEAP32[$10>>2]|0;
          __ZdlPv($158);
          $$231 = $$130;$$235 = $$134;
         } else {
          $$231 = $$130;$$235 = $$134;
         }
        }
        $$26 = $$231;$$2659 = $$235;
        break L8;
       }
      } while(0);
      __THREW__ = 0;
      invoke_vii(4196,($16|0),($1|0));
      $239 = __THREW__; __THREW__ = 0;
      $240 = $239&1;
      do {
       if ($240) {
        $247 = ___cxa_find_matching_catch_2()|0;
        $248 = tempRet0;
        $$9 = $247;$$942 = $248;
       } else {
        __THREW__ = 0;
        (invoke_iii(3477,($6|0),($16|0))|0);
        $241 = __THREW__; __THREW__ = 0;
        $242 = $241&1;
        if ($242) {
         $249 = ___cxa_find_matching_catch_2()|0;
         $250 = tempRet0;
         $251 = ((($16)) + 11|0);
         $252 = HEAP8[$251>>0]|0;
         $253 = ($252<<24>>24)<(0);
         if (!($253)) {
          $$9 = $249;$$942 = $250;
          break;
         }
         $254 = HEAP32[$16>>2]|0;
         __ZdlPv($254);
         $$9 = $249;$$942 = $250;
         break;
        }
        $243 = ((($16)) + 11|0);
        $244 = HEAP8[$243>>0]|0;
        $245 = ($244<<24>>24)<(0);
        if ($245) {
         $246 = HEAP32[$16>>2]|0;
         __ZdlPv($246);
        }
        break L25;
       }
      } while(0);
      $$26 = $$9;$$2659 = $$942;
      break L8;
     }
    } while(0);
    __THREW__ = 0;
    $255 = (invoke_ii(3265,5)|0);
    $256 = __THREW__; __THREW__ = 0;
    $257 = $256&1;
    L143: do {
     if (!($257)) {
      if ($255) {
       __THREW__ = 0;
       $258 = (invoke_ii(3266,5)|0);
       $259 = __THREW__; __THREW__ = 0;
       $260 = $259&1;
       if ($260) {
        break;
       }
       __THREW__ = 0;
       $261 = (invoke_iiii(3267,($258|0),(172819|0),36)|0);
       $262 = __THREW__; __THREW__ = 0;
       $263 = $262&1;
       if ($263) {
        break;
       }
       $264 = ((($6)) + 11|0);
       $265 = HEAP8[$264>>0]|0;
       $266 = ($265<<24>>24)<(0);
       $267 = HEAP32[$6>>2]|0;
       $268 = $266 ? $267 : $6;
       $269 = ((($6)) + 4|0);
       $270 = HEAP32[$269>>2]|0;
       $271 = $265&255;
       $272 = $266 ? $270 : $271;
       __THREW__ = 0;
       $273 = (invoke_iiii(3267,($261|0),($268|0),($272|0))|0);
       $274 = __THREW__; __THREW__ = 0;
       $275 = $274&1;
       if ($275) {
        break;
       }
       __THREW__ = 0;
       $276 = (invoke_iiii(3267,($273|0),(172856|0),4)|0);
       $277 = __THREW__; __THREW__ = 0;
       $278 = $277&1;
       if ($278) {
        break;
       }
       $279 = ((($5)) + 11|0);
       $280 = HEAP8[$279>>0]|0;
       $281 = ($280<<24>>24)<(0);
       $282 = HEAP32[$5>>2]|0;
       $283 = $281 ? $282 : $5;
       $284 = ((($5)) + 4|0);
       $285 = HEAP32[$284>>2]|0;
       $286 = $280&255;
       $287 = $281 ? $285 : $286;
       __THREW__ = 0;
       $288 = (invoke_iiii(3267,($276|0),($283|0),($287|0))|0);
       $289 = __THREW__; __THREW__ = 0;
       $290 = $289&1;
       if ($290) {
        break;
       }
       __THREW__ = 0;
       (invoke_iiii(3267,($288|0),(172861|0),4)|0);
       $291 = __THREW__; __THREW__ = 0;
       $292 = $291&1;
       if ($292) {
        break;
       } else {
        $$pre$phi337Z2D = $279;$$pre$phi339Z2D = $284;
       }
      } else {
       $$pre336 = ((($5)) + 11|0);
       $$pre338 = ((($5)) + 4|0);
       $$pre$phi337Z2D = $$pre336;$$pre$phi339Z2D = $$pre338;
      }
      $295 = HEAP8[$$pre$phi337Z2D>>0]|0;
      $296 = ($295<<24>>24)<(0);
      $297 = HEAP32[$$pre$phi339Z2D>>2]|0;
      $298 = $295&255;
      $299 = $296 ? $297 : $298;
      L154: do {
       switch ($299|0) {
       case 0:  {
        ;HEAP32[$18>>2]=0|0;HEAP32[$18+4>>2]=0|0;HEAP32[$18+8>>2]=0|0;
        $300 = ((($18)) + 11|0);
        HEAP8[$300>>0] = 1;
        HEAP8[$18>>0] = 46;
        $301 = ((($18)) + 1|0);
        HEAP8[$301>>0] = 0;
        __THREW__ = 0;
        invoke_vii(4251,($17|0),($18|0));
        $302 = __THREW__; __THREW__ = 0;
        $303 = $302&1;
        do {
         if ($303) {
          $322 = ___cxa_find_matching_catch_2()|0;
          $323 = tempRet0;
          $$10 = $322;$$1043 = $323;
         } else {
          $304 = HEAP32[$17>>2]|0;
          $305 = ((($17)) + 4|0);
          $306 = HEAP32[$305>>2]|0;
          __THREW__ = 0;
          invoke_viii(3872,($4|0),($304|0),($306|0));
          $307 = __THREW__; __THREW__ = 0;
          $308 = $307&1;
          if ($308) {
           $324 = ___cxa_find_matching_catch_2()|0;
           $325 = tempRet0;
           $326 = HEAP32[$17>>2]|0;
           $327 = ($326|0)==(0|0);
           if ($327) {
            $$10 = $324;$$1043 = $325;
            break;
           }
           $328 = HEAP32[$305>>2]|0;
           $329 = ($328|0)==($326|0);
           if ($329) {
            $338 = $326;
           } else {
            $331 = $328;
            while(1) {
             $330 = ((($331)) + -12|0);
             HEAP32[$305>>2] = $330;
             $332 = ((($330)) + 11|0);
             $333 = HEAP8[$332>>0]|0;
             $334 = ($333<<24>>24)<(0);
             if ($334) {
              $337 = HEAP32[$330>>2]|0;
              __ZdlPv($337);
              $$pre$i$i$i96 = HEAP32[$305>>2]|0;
              $335 = $$pre$i$i$i96;
             } else {
              $335 = $330;
             }
             $336 = ($335|0)==($326|0);
             if ($336) {
              break;
             } else {
              $331 = $335;
             }
            }
            $$pre$i98 = HEAP32[$17>>2]|0;
            $338 = $$pre$i98;
           }
           __ZdlPv($338);
           $$10 = $324;$$1043 = $325;
           break;
          }
          $309 = HEAP32[$17>>2]|0;
          $310 = ($309|0)==(0|0);
          if (!($310)) {
           $311 = HEAP32[$305>>2]|0;
           $312 = ($311|0)==($309|0);
           if ($312) {
            $321 = $309;
           } else {
            $314 = $311;
            while(1) {
             $313 = ((($314)) + -12|0);
             HEAP32[$305>>2] = $313;
             $315 = ((($313)) + 11|0);
             $316 = HEAP8[$315>>0]|0;
             $317 = ($316<<24>>24)<(0);
             if ($317) {
              $320 = HEAP32[$313>>2]|0;
              __ZdlPv($320);
              $$pre$i$i$i = HEAP32[$305>>2]|0;
              $318 = $$pre$i$i$i;
             } else {
              $318 = $313;
             }
             $319 = ($318|0)==($309|0);
             if ($319) {
              break;
             } else {
              $314 = $318;
             }
            }
            $$pre$i92 = HEAP32[$17>>2]|0;
            $321 = $$pre$i92;
           }
           __ZdlPv($321);
          }
          $$128$off0 = 0;$$3$off0 = 0;
          break L154;
         }
        } while(0);
        $$26 = $$10;$$2659 = $$1043;
        break L8;
        break;
       }
       case 1:  {
        __THREW__ = 0;
        $339 = (invoke_iiiiii(3253,($5|0),0,-1,(199839|0),1)|0);
        $340 = __THREW__; __THREW__ = 0;
        $341 = $340&1;
        if ($341) {
         $342 = ___cxa_find_matching_catch_2()|0;
         $343 = tempRet0;
         ___cxa_call_unexpected(($342|0));
         // unreachable;
        }
        $344 = ($339|0)==(0);
        if ($344) {
         label = 146;
        } else {
         $$pre316 = HEAP8[$$pre$phi337Z2D>>0]|0;
         $$pre317 = HEAP32[$$pre$phi339Z2D>>2]|0;
         $345 = $$pre316;$348 = $$pre317;
         label = 136;
        }
        break;
       }
       default: {
        $345 = $295;$348 = $297;
        label = 136;
       }
       }
      } while(0);
      L188: do {
       if ((label|0) == 136) {
        $346 = ($345<<24>>24)<(0);
        $347 = $345&255;
        $349 = $346 ? $348 : $347;
        $350 = ($349|0)==(2);
        if ($350) {
         __THREW__ = 0;
         $351 = (invoke_iiiiii(3253,($5|0),0,-1,(172811|0),2)|0);
         $352 = __THREW__; __THREW__ = 0;
         $353 = $352&1;
         if ($353) {
          $354 = ___cxa_find_matching_catch_2()|0;
          $355 = tempRet0;
          ___cxa_call_unexpected(($354|0));
          // unreachable;
         }
         $356 = ($351|0)==(0);
         if ($356) {
          label = 146;
          break;
         }
         $$pre318 = HEAP8[$$pre$phi337Z2D>>0]|0;
         $$pre319 = HEAP32[$$pre$phi339Z2D>>2]|0;
         $357 = $$pre318;$360 = $$pre319;
        } else {
         $357 = $345;$360 = $348;
        }
        $358 = ($357<<24>>24)<(0);
        $359 = $357&255;
        $361 = $358 ? $360 : $359;
        $362 = ($361|0)==(2);
        if ($362) {
         __THREW__ = 0;
         $363 = (invoke_iiiiii(3253,($5|0),0,-1,(172814|0),2)|0);
         $364 = __THREW__; __THREW__ = 0;
         $365 = $364&1;
         if ($365) {
          $366 = ___cxa_find_matching_catch_2()|0;
          $367 = tempRet0;
          ___cxa_call_unexpected(($366|0));
          // unreachable;
         }
         $368 = ($363|0)==(0);
         if ($368) {
          label = 146;
          break;
         }
         $$pre320 = HEAP8[$$pre$phi337Z2D>>0]|0;
         $$pre321 = HEAP32[$$pre$phi339Z2D>>2]|0;
         $408 = $$pre320;$411 = $$pre321;
        } else {
         $408 = $357;$411 = $360;
        }
        $409 = ($408<<24>>24)<(0);
        $410 = $408&255;
        $412 = $409 ? $411 : $410;
        $413 = ($412|0)==(1);
        if ($413) {
         __THREW__ = 0;
         $414 = (invoke_iiiiii(3253,($5|0),0,-1,(172817|0),1)|0);
         $415 = __THREW__; __THREW__ = 0;
         $416 = $415&1;
         if ($416) {
          $417 = ___cxa_find_matching_catch_2()|0;
          $418 = tempRet0;
          ___cxa_call_unexpected(($417|0));
          // unreachable;
         }
         $419 = ($414|0)==(0);
         if ($419) {
          ;HEAP32[$22>>2]=0|0;HEAP32[$22+4>>2]=0|0;HEAP32[$22+8>>2]=0|0;
          $420 = ((($22)) + 11|0);
          HEAP8[$420>>0] = 1;
          HEAP8[$22>>0] = 47;
          $421 = ((($22)) + 1|0);
          HEAP8[$421>>0] = 0;
          __THREW__ = 0;
          invoke_vii(4251,($21|0),($22|0));
          $422 = __THREW__; __THREW__ = 0;
          $423 = $422&1;
          do {
           if ($423) {
            $442 = ___cxa_find_matching_catch_2()|0;
            $443 = tempRet0;
            $$14 = $442;$$1447 = $443;
           } else {
            $424 = HEAP32[$21>>2]|0;
            $425 = ((($21)) + 4|0);
            $426 = HEAP32[$425>>2]|0;
            __THREW__ = 0;
            invoke_viii(3872,($4|0),($424|0),($426|0));
            $427 = __THREW__; __THREW__ = 0;
            $428 = $427&1;
            if ($428) {
             $444 = ___cxa_find_matching_catch_2()|0;
             $445 = tempRet0;
             $446 = HEAP32[$21>>2]|0;
             $447 = ($446|0)==(0|0);
             if ($447) {
              $$14 = $444;$$1447 = $445;
              break;
             }
             $448 = HEAP32[$425>>2]|0;
             $449 = ($448|0)==($446|0);
             if ($449) {
              $458 = $446;
             } else {
              $451 = $448;
              while(1) {
               $450 = ((($451)) + -12|0);
               HEAP32[$425>>2] = $450;
               $452 = ((($450)) + 11|0);
               $453 = HEAP8[$452>>0]|0;
               $454 = ($453<<24>>24)<(0);
               if ($454) {
                $457 = HEAP32[$450>>2]|0;
                __ZdlPv($457);
                $$pre$i$i$i156 = HEAP32[$425>>2]|0;
                $455 = $$pre$i$i$i156;
               } else {
                $455 = $450;
               }
               $456 = ($455|0)==($446|0);
               if ($456) {
                break;
               } else {
                $451 = $455;
               }
              }
              $$pre$i158 = HEAP32[$21>>2]|0;
              $458 = $$pre$i158;
             }
             __ZdlPv($458);
             $$14 = $444;$$1447 = $445;
             break;
            }
            $429 = HEAP32[$21>>2]|0;
            $430 = ($429|0)==(0|0);
            if (!($430)) {
             $431 = HEAP32[$425>>2]|0;
             $432 = ($431|0)==($429|0);
             if ($432) {
              $441 = $429;
             } else {
              $434 = $431;
              while(1) {
               $433 = ((($434)) + -12|0);
               HEAP32[$425>>2] = $433;
               $435 = ((($433)) + 11|0);
               $436 = HEAP8[$435>>0]|0;
               $437 = ($436<<24>>24)<(0);
               if ($437) {
                $440 = HEAP32[$433>>2]|0;
                __ZdlPv($440);
                $$pre$i$i$i147 = HEAP32[$425>>2]|0;
                $438 = $$pre$i$i$i147;
               } else {
                $438 = $433;
               }
               $439 = ($438|0)==($429|0);
               if ($439) {
                break;
               } else {
                $434 = $438;
               }
              }
              $$pre$i149 = HEAP32[$21>>2]|0;
              $441 = $$pre$i149;
             }
             __ZdlPv($441);
            }
            $$128$off0 = 1;$$3$off0 = 0;
            break L188;
           }
          } while(0);
          $$26 = $$14;$$2659 = $$1447;
          break L8;
         }
        }
        $459 = ($3|0)==(1);
        if (!($459)) {
         __THREW__ = 0;
         invoke_vii(4251,($30|0),($5|0));
         $624 = __THREW__; __THREW__ = 0;
         $625 = $624&1;
         do {
          if ($625) {
           $654 = ___cxa_find_matching_catch_2()|0;
           $655 = tempRet0;
           $$23 = $654;$$2356 = $655;
          } else {
           $626 = HEAP32[$30>>2]|0;
           $627 = ((($30)) + 4|0);
           $628 = HEAP32[$627>>2]|0;
           __THREW__ = 0;
           invoke_viii(3872,($4|0),($626|0),($628|0));
           $629 = __THREW__; __THREW__ = 0;
           $630 = $629&1;
           if ($630) {
            $656 = ___cxa_find_matching_catch_2()|0;
            $657 = tempRet0;
            $658 = HEAP32[$30>>2]|0;
            $659 = ($658|0)==(0|0);
            if ($659) {
             $$23 = $656;$$2356 = $657;
             break;
            }
            $660 = HEAP32[$627>>2]|0;
            $661 = ($660|0)==($658|0);
            if ($661) {
             $670 = $658;
            } else {
             $663 = $660;
             while(1) {
              $662 = ((($663)) + -12|0);
              HEAP32[$627>>2] = $662;
              $664 = ((($662)) + 11|0);
              $665 = HEAP8[$664>>0]|0;
              $666 = ($665<<24>>24)<(0);
              if ($666) {
               $669 = HEAP32[$662>>2]|0;
               __ZdlPv($669);
               $$pre$i$i$i248 = HEAP32[$627>>2]|0;
               $667 = $$pre$i$i$i248;
              } else {
               $667 = $662;
              }
              $668 = ($667|0)==($658|0);
              if ($668) {
               break;
              } else {
               $663 = $667;
              }
             }
             $$pre$i250 = HEAP32[$30>>2]|0;
             $670 = $$pre$i250;
            }
            __ZdlPv($670);
            $$23 = $656;$$2356 = $657;
            break;
           }
           $631 = HEAP32[$30>>2]|0;
           $632 = ($631|0)==(0|0);
           if (!($632)) {
            $633 = HEAP32[$627>>2]|0;
            $634 = ($633|0)==($631|0);
            if ($634) {
             $643 = $631;
            } else {
             $636 = $633;
             while(1) {
              $635 = ((($636)) + -12|0);
              HEAP32[$627>>2] = $635;
              $637 = ((($635)) + 11|0);
              $638 = HEAP8[$637>>0]|0;
              $639 = ($638<<24>>24)<(0);
              if ($639) {
               $642 = HEAP32[$635>>2]|0;
               __ZdlPv($642);
               $$pre$i$i$i238 = HEAP32[$627>>2]|0;
               $640 = $$pre$i$i$i238;
              } else {
               $640 = $635;
              }
              $641 = ($640|0)==($631|0);
              if ($641) {
               break;
              } else {
               $636 = $640;
              }
             }
             $$pre$i240 = HEAP32[$30>>2]|0;
             $643 = $$pre$i240;
            }
            __ZdlPv($643);
           }
           $644 = HEAP8[$$pre$phi337Z2D>>0]|0;
           $645 = ($644<<24>>24)<(0);
           $646 = HEAP32[$$pre$phi339Z2D>>2]|0;
           $647 = $644&255;
           $648 = $645 ? $646 : $647;
           $649 = (($648) + -1)|0;
           $650 = HEAP32[$5>>2]|0;
           $651 = $645 ? $650 : $5;
           $652 = (($651) + ($649)|0);
           $653 = HEAP8[$652>>0]|0;
           switch ($653<<24>>24) {
           case 92: case 47:  {
            $$128$off0 = 1;$$3$off0 = 0;
            break L188;
            break;
           }
           default: {
           }
           }
           $$128$off0 = 1;$$3$off0 = 1;
           break L188;
          }
         } while(0);
         $$26 = $$23;$$2659 = $$2356;
         break L8;
        }
        __THREW__ = 0;
        invoke_vii(4234,($23|0),($5|0));
        $460 = __THREW__; __THREW__ = 0;
        $461 = $460&1;
        if ($461) {
         break L143;
        }
        __THREW__ = 0;
        invoke_vii(4196,($24|0),($5|0));
        $462 = __THREW__; __THREW__ = 0;
        $463 = $462&1;
        do {
         if ($463) {
          $517 = ___cxa_find_matching_catch_2()|0;
          $518 = tempRet0;
          $$pre332 = ((($23)) + 11|0);
          $$22 = $517;$$2255 = $518;$$pre$phi333Z2D = $$pre332;
         } else {
          $464 = ((($23)) + 11|0);
          $465 = HEAP8[$464>>0]|0;
          $466 = ($465<<24>>24)<(0);
          $467 = ((($23)) + 4|0);
          $468 = HEAP32[$467>>2]|0;
          $469 = $465&255;
          $470 = $466 ? $468 : $469;
          $471 = ($470|0)==(0);
          L273: do {
           if ($471) {
            $472 = ((($24)) + 11|0);
            $473 = HEAP8[$472>>0]|0;
            $474 = ($473<<24>>24)<(0);
            $475 = ((($24)) + 4|0);
            $476 = HEAP32[$475>>2]|0;
            $477 = $473&255;
            $478 = $474 ? $476 : $477;
            $479 = ($478|0)==(0);
            if ($479) {
             label = 229;
             break;
            }
            $480 = HEAP8[$$pre$phi337Z2D>>0]|0;
            $481 = ($480<<24>>24)<(0);
            $482 = HEAP32[$5>>2]|0;
            $483 = $481 ? $482 : $5;
            $484 = HEAP8[$483>>0]|0;
            switch ($484<<24>>24) {
            case 92: case 47:  {
             ;HEAP32[$25>>2]=0|0;HEAP32[$25+4>>2]=0|0;HEAP32[$25+8>>2]=0|0;
             $$sink289 = 47;
             break;
            }
            default: {
             ;HEAP32[$25>>2]=0|0;HEAP32[$25+4>>2]=0|0;HEAP32[$25+8>>2]=0|0;
             $$sink289 = 46;
            }
            }
            $485 = ((($25)) + 11|0);
            HEAP8[$485>>0] = 1;
            HEAP8[$25>>0] = $$sink289;
            $$sink = ((($25)) + 1|0);
            HEAP8[$$sink>>0] = 0;
            __THREW__ = 0;
            invoke_viiii(4250,($26|0),($24|0),($25|0),1);
            $486 = __THREW__; __THREW__ = 0;
            $487 = $486&1;
            do {
             if ($487) {
              $519 = ___cxa_find_matching_catch_2()|0;
              $520 = tempRet0;
              $$16 = $519;$$1649 = $520;
              label = 216;
             } else {
              __THREW__ = 0;
              (invoke_iii(3477,($5|0),($26|0))|0);
              $488 = __THREW__; __THREW__ = 0;
              $489 = $488&1;
              if ($489) {
               $521 = ___cxa_find_matching_catch_2()|0;
               $522 = tempRet0;
               $523 = ((($26)) + 11|0);
               $524 = HEAP8[$523>>0]|0;
               $525 = ($524<<24>>24)<(0);
               if (!($525)) {
                $$16 = $521;$$1649 = $522;
                label = 216;
                break;
               }
               $526 = HEAP32[$26>>2]|0;
               __ZdlPv($526);
               $$16 = $521;$$1649 = $522;
               label = 216;
               break;
              }
              $490 = ((($26)) + 11|0);
              $491 = HEAP8[$490>>0]|0;
              $492 = ($491<<24>>24)<(0);
              if ($492) {
               $493 = HEAP32[$26>>2]|0;
               __ZdlPv($493);
              }
              __THREW__ = 0;
              invoke_vii(4251,($27|0),($5|0));
              $494 = __THREW__; __THREW__ = 0;
              $495 = $494&1;
              do {
               if ($495) {
                $527 = ___cxa_find_matching_catch_2()|0;
                $528 = tempRet0;
                $$17 = $527;$$1750 = $528;
               } else {
                $496 = HEAP32[$27>>2]|0;
                $497 = ((($27)) + 4|0);
                $498 = HEAP32[$497>>2]|0;
                __THREW__ = 0;
                invoke_viii(3872,($4|0),($496|0),($498|0));
                $499 = __THREW__; __THREW__ = 0;
                $500 = $499&1;
                if ($500) {
                 $529 = ___cxa_find_matching_catch_2()|0;
                 $530 = tempRet0;
                 $531 = HEAP32[$27>>2]|0;
                 $532 = ($531|0)==(0|0);
                 if ($532) {
                  $$17 = $529;$$1750 = $530;
                  break;
                 }
                 $533 = HEAP32[$497>>2]|0;
                 $534 = ($533|0)==($531|0);
                 if ($534) {
                  $543 = $531;
                 } else {
                  $536 = $533;
                  while(1) {
                   $535 = ((($536)) + -12|0);
                   HEAP32[$497>>2] = $535;
                   $537 = ((($535)) + 11|0);
                   $538 = HEAP8[$537>>0]|0;
                   $539 = ($538<<24>>24)<(0);
                   if ($539) {
                    $542 = HEAP32[$535>>2]|0;
                    __ZdlPv($542);
                    $$pre$i$i$i193 = HEAP32[$497>>2]|0;
                    $540 = $$pre$i$i$i193;
                   } else {
                    $540 = $535;
                   }
                   $541 = ($540|0)==($531|0);
                   if ($541) {
                    break;
                   } else {
                    $536 = $540;
                   }
                  }
                  $$pre$i195 = HEAP32[$27>>2]|0;
                  $543 = $$pre$i195;
                 }
                 __ZdlPv($543);
                 $$17 = $529;$$1750 = $530;
                 break;
                }
                $501 = HEAP32[$27>>2]|0;
                $502 = ($501|0)==(0|0);
                if (!($502)) {
                 $503 = HEAP32[$497>>2]|0;
                 $504 = ($503|0)==($501|0);
                 if ($504) {
                  $513 = $501;
                 } else {
                  $506 = $503;
                  while(1) {
                   $505 = ((($506)) + -12|0);
                   HEAP32[$497>>2] = $505;
                   $507 = ((($505)) + 11|0);
                   $508 = HEAP8[$507>>0]|0;
                   $509 = ($508<<24>>24)<(0);
                   if ($509) {
                    $512 = HEAP32[$505>>2]|0;
                    __ZdlPv($512);
                    $$pre$i$i$i183 = HEAP32[$497>>2]|0;
                    $510 = $$pre$i$i$i183;
                   } else {
                    $510 = $505;
                   }
                   $511 = ($510|0)==($501|0);
                   if ($511) {
                    break;
                   } else {
                    $506 = $510;
                   }
                  }
                  $$pre$i185 = HEAP32[$27>>2]|0;
                  $513 = $$pre$i185;
                 }
                 __ZdlPv($513);
                }
                $514 = HEAP8[$485>>0]|0;
                $515 = ($514<<24>>24)<(0);
                if ($515) {
                 $516 = HEAP32[$25>>2]|0;
                 __ZdlPv($516);
                }
                $$1 = 1;
                break L273;
               }
              } while(0);
              $$18 = $$17;$$1851 = $$1750;
             }
            } while(0);
            if ((label|0) == 216) {
             $$18 = $$16;$$1851 = $$1649;
            }
            $544 = HEAP8[$485>>0]|0;
            $545 = ($544<<24>>24)<(0);
            if ($545) {
             $546 = HEAP32[$25>>2]|0;
             __ZdlPv($546);
            }
            $$21 = $$18;$$2154 = $$1851;
            label = 262;
           } else {
            label = 229;
           }
          } while(0);
          L326: do {
           if ((label|0) == 229) {
            __THREW__ = 0;
            invoke_viiii(4250,($28|0),($24|0),($23|0),1);
            $547 = __THREW__; __THREW__ = 0;
            $548 = $547&1;
            do {
             if ($548) {
              $585 = ___cxa_find_matching_catch_2()|0;
              $586 = tempRet0;
              $$19 = $585;$$1952 = $586;
             } else {
              __THREW__ = 0;
              (invoke_iii(3477,($5|0),($28|0))|0);
              $549 = __THREW__; __THREW__ = 0;
              $550 = $549&1;
              if ($550) {
               $587 = ___cxa_find_matching_catch_2()|0;
               $588 = tempRet0;
               $589 = ((($28)) + 11|0);
               $590 = HEAP8[$589>>0]|0;
               $591 = ($590<<24>>24)<(0);
               if (!($591)) {
                $$19 = $587;$$1952 = $588;
                break;
               }
               $592 = HEAP32[$28>>2]|0;
               __ZdlPv($592);
               $$19 = $587;$$1952 = $588;
               break;
              }
              $551 = ((($28)) + 11|0);
              $552 = HEAP8[$551>>0]|0;
              $553 = ($552<<24>>24)<(0);
              if ($553) {
               $554 = HEAP32[$28>>2]|0;
               __ZdlPv($554);
              }
              __THREW__ = 0;
              invoke_vii(4251,($29|0),($5|0));
              $555 = __THREW__; __THREW__ = 0;
              $556 = $555&1;
              do {
               if ($556) {
                $593 = ___cxa_find_matching_catch_2()|0;
                $594 = tempRet0;
                $$20 = $593;$$2053 = $594;
               } else {
                $557 = HEAP32[$29>>2]|0;
                $558 = ((($29)) + 4|0);
                $559 = HEAP32[$558>>2]|0;
                __THREW__ = 0;
                invoke_viii(3872,($4|0),($557|0),($559|0));
                $560 = __THREW__; __THREW__ = 0;
                $561 = $560&1;
                if ($561) {
                 $595 = ___cxa_find_matching_catch_2()|0;
                 $596 = tempRet0;
                 $597 = HEAP32[$29>>2]|0;
                 $598 = ($597|0)==(0|0);
                 if ($598) {
                  $$20 = $595;$$2053 = $596;
                  break;
                 }
                 $599 = HEAP32[$558>>2]|0;
                 $600 = ($599|0)==($597|0);
                 if ($600) {
                  $609 = $597;
                 } else {
                  $602 = $599;
                  while(1) {
                   $601 = ((($602)) + -12|0);
                   HEAP32[$558>>2] = $601;
                   $603 = ((($601)) + 11|0);
                   $604 = HEAP8[$603>>0]|0;
                   $605 = ($604<<24>>24)<(0);
                   if ($605) {
                    $608 = HEAP32[$601>>2]|0;
                    __ZdlPv($608);
                    $$pre$i$i$i224 = HEAP32[$558>>2]|0;
                    $606 = $$pre$i$i$i224;
                   } else {
                    $606 = $601;
                   }
                   $607 = ($606|0)==($597|0);
                   if ($607) {
                    break;
                   } else {
                    $602 = $606;
                   }
                  }
                  $$pre$i226 = HEAP32[$29>>2]|0;
                  $609 = $$pre$i226;
                 }
                 __ZdlPv($609);
                 $$20 = $595;$$2053 = $596;
                 break;
                }
                $562 = HEAP32[$29>>2]|0;
                $563 = ($562|0)==(0|0);
                if (!($563)) {
                 $564 = HEAP32[$558>>2]|0;
                 $565 = ($564|0)==($562|0);
                 if ($565) {
                  $574 = $562;
                 } else {
                  $567 = $564;
                  while(1) {
                   $566 = ((($567)) + -12|0);
                   HEAP32[$558>>2] = $566;
                   $568 = ((($566)) + 11|0);
                   $569 = HEAP8[$568>>0]|0;
                   $570 = ($569<<24>>24)<(0);
                   if ($570) {
                    $573 = HEAP32[$566>>2]|0;
                    __ZdlPv($573);
                    $$pre$i$i$i213 = HEAP32[$558>>2]|0;
                    $571 = $$pre$i$i$i213;
                   } else {
                    $571 = $566;
                   }
                   $572 = ($571|0)==($562|0);
                   if ($572) {
                    break;
                   } else {
                    $567 = $571;
                   }
                  }
                  $$pre$i215 = HEAP32[$29>>2]|0;
                  $574 = $$pre$i215;
                 }
                 __ZdlPv($574);
                }
                $575 = HEAP8[$$pre$phi337Z2D>>0]|0;
                $576 = ($575<<24>>24)<(0);
                $577 = HEAP32[$$pre$phi339Z2D>>2]|0;
                $578 = $575&255;
                $579 = $576 ? $577 : $578;
                $580 = (($579) + -1)|0;
                $581 = HEAP32[$5>>2]|0;
                $582 = $576 ? $581 : $5;
                $583 = (($582) + ($580)|0);
                $584 = HEAP8[$583>>0]|0;
                switch ($584<<24>>24) {
                case 92: case 47:  {
                 $$1 = 0;
                 break L326;
                 break;
                }
                default: {
                }
                }
                $$1 = 1;
                break L326;
               }
              } while(0);
              $$21 = $$20;$$2154 = $$2053;
              label = 262;
              break L326;
             }
            } while(0);
            $$21 = $$19;$$2154 = $$1952;
            label = 262;
           }
          } while(0);
          if ((label|0) == 262) {
           $617 = ((($24)) + 11|0);
           $618 = HEAP8[$617>>0]|0;
           $619 = ($618<<24>>24)<(0);
           if ($619) {
            $620 = HEAP32[$24>>2]|0;
            __ZdlPv($620);
           }
           $$22 = $$21;$$2255 = $$2154;$$pre$phi333Z2D = $464;
           break;
          }
          $610 = ((($24)) + 11|0);
          $611 = HEAP8[$610>>0]|0;
          $612 = ($611<<24>>24)<(0);
          if ($612) {
           $613 = HEAP32[$24>>2]|0;
           __ZdlPv($613);
          }
          $614 = HEAP8[$464>>0]|0;
          $615 = ($614<<24>>24)<(0);
          if ($615) {
           $616 = HEAP32[$23>>2]|0;
           __ZdlPv($616);
          }
          $extract$t62 = ($$1<<24>>24)!=(0);
          $$128$off0 = 1;$$3$off0 = $extract$t62;
          break L188;
         }
        } while(0);
        $621 = HEAP8[$$pre$phi333Z2D>>0]|0;
        $622 = ($621<<24>>24)<(0);
        if ($622) {
         $623 = HEAP32[$23>>2]|0;
         __ZdlPv($623);
        }
        $$26 = $$22;$$2659 = $$2255;
        break L8;
       }
      } while(0);
      L383: do {
       if ((label|0) == 146) {
        ;HEAP32[$20>>2]=0|0;HEAP32[$20+4>>2]=0|0;HEAP32[$20+8>>2]=0|0;
        $369 = ((($20)) + 11|0);
        HEAP8[$369>>0] = 1;
        HEAP8[$20>>0] = 46;
        $370 = ((($20)) + 1|0);
        HEAP8[$370>>0] = 0;
        __THREW__ = 0;
        invoke_vii(4251,($19|0),($20|0));
        $371 = __THREW__; __THREW__ = 0;
        $372 = $371&1;
        do {
         if ($372) {
          $391 = ___cxa_find_matching_catch_2()|0;
          $392 = tempRet0;
          $$12 = $391;$$1245 = $392;
         } else {
          $373 = HEAP32[$19>>2]|0;
          $374 = ((($19)) + 4|0);
          $375 = HEAP32[$374>>2]|0;
          __THREW__ = 0;
          invoke_viii(3872,($4|0),($373|0),($375|0));
          $376 = __THREW__; __THREW__ = 0;
          $377 = $376&1;
          if ($377) {
           $393 = ___cxa_find_matching_catch_2()|0;
           $394 = tempRet0;
           $395 = HEAP32[$19>>2]|0;
           $396 = ($395|0)==(0|0);
           if ($396) {
            $$12 = $393;$$1245 = $394;
            break;
           }
           $397 = HEAP32[$374>>2]|0;
           $398 = ($397|0)==($395|0);
           if ($398) {
            $407 = $395;
           } else {
            $400 = $397;
            while(1) {
             $399 = ((($400)) + -12|0);
             HEAP32[$374>>2] = $399;
             $401 = ((($399)) + 11|0);
             $402 = HEAP8[$401>>0]|0;
             $403 = ($402<<24>>24)<(0);
             if ($403) {
              $406 = HEAP32[$399>>2]|0;
              __ZdlPv($406);
              $$pre$i$i$i128 = HEAP32[$374>>2]|0;
              $404 = $$pre$i$i$i128;
             } else {
              $404 = $399;
             }
             $405 = ($404|0)==($395|0);
             if ($405) {
              break;
             } else {
              $400 = $404;
             }
            }
            $$pre$i130 = HEAP32[$19>>2]|0;
            $407 = $$pre$i130;
           }
           __ZdlPv($407);
           $$12 = $393;$$1245 = $394;
           break;
          }
          $378 = HEAP32[$19>>2]|0;
          $379 = ($378|0)==(0|0);
          if (!($379)) {
           $380 = HEAP32[$374>>2]|0;
           $381 = ($380|0)==($378|0);
           if ($381) {
            $390 = $378;
           } else {
            $383 = $380;
            while(1) {
             $382 = ((($383)) + -12|0);
             HEAP32[$374>>2] = $382;
             $384 = ((($382)) + 11|0);
             $385 = HEAP8[$384>>0]|0;
             $386 = ($385<<24>>24)<(0);
             if ($386) {
              $389 = HEAP32[$382>>2]|0;
              __ZdlPv($389);
              $$pre$i$i$i119 = HEAP32[$374>>2]|0;
              $387 = $$pre$i$i$i119;
             } else {
              $387 = $382;
             }
             $388 = ($387|0)==($378|0);
             if ($388) {
              break;
             } else {
              $383 = $387;
             }
            }
            $$pre$i121 = HEAP32[$19>>2]|0;
            $390 = $$pre$i121;
           }
           __ZdlPv($390);
          }
          $$128$off0 = 0;$$3$off0 = 0;
          break L383;
         }
        } while(0);
        $$26 = $$12;$$2659 = $$1245;
        break L8;
       }
      } while(0);
      $671 = HEAP32[$4>>2]|0;
      $672 = HEAP32[$32>>2]|0;
      $673 = ($671|0)==($672|0);
      L413: do {
       if ($673) {
        $$pre341 = ((($6)) + 11|0);
        $$pre328$pre$phiZZ2D = $$pre341;
        label = 326;
       } else {
        $674 = ($3|0)==(1);
        $675 = ((($6)) + 11|0);
        $676 = ((($6)) + 4|0);
        L416: do {
         if ($674) {
          $$sroa$0276$0297$us = $671;
          while(1) {
           __THREW__ = 0;
           $685 = (invoke_iii(4252,($6|0),($$sroa$0276$0297$us|0))|0);
           $686 = __THREW__; __THREW__ = 0;
           $687 = $686&1;
           if ($687) {
            break L416;
           }
           if ($685) {
            $$sroa$0276$0296 = $$sroa$0276$0297$us;
            label = 311;
            break L416;
           }
           $688 = HEAP8[$675>>0]|0;
           $689 = ($688<<24>>24)<(0);
           $690 = HEAP32[$676>>2]|0;
           $691 = $688&255;
           $692 = $689 ? $690 : $691;
           $693 = ((($$sroa$0276$0297$us)) + 11|0);
           $694 = HEAP8[$693>>0]|0;
           $695 = ($694<<24>>24)<(0);
           $696 = ((($$sroa$0276$0297$us)) + 4|0);
           $697 = HEAP32[$696>>2]|0;
           $698 = $694&255;
           $699 = $695 ? $697 : $698;
           $700 = ($692|0)==($699|0);
           do {
            if ($700) {
             $701 = HEAP32[$6>>2]|0;
             $702 = $689 ? $701 : $6;
             $703 = HEAP32[$$sroa$0276$0297$us>>2]|0;
             $704 = $695 ? $703 : $$sroa$0276$0297$us;
             $705 = ($692|0)==(0);
             if ($689) {
              if ($705) {
               $$sroa$0276$0296 = $$sroa$0276$0297$us;
               label = 311;
               break L416;
              }
              $716 = (_memcmp($702,$704,$692)|0);
              $phitmp$i254$us = ($716|0)==(0);
              if ($phitmp$i254$us) {
               $$sroa$0276$0296 = $$sroa$0276$0297$us;
               label = 311;
               break L416;
              } else {
               break;
              }
             }
             if ($705) {
              $$sroa$0276$0296 = $$sroa$0276$0297$us;
              label = 311;
              break L416;
             }
             $706 = $701;
             $707 = $706&255;
             $708 = HEAP8[$704>>0]|0;
             $709 = ($707<<24>>24)==($708<<24>>24);
             if ($709) {
              $$02026$i$us363 = $6;$$02125$i$us364 = $691;$$027$i$us362 = $704;
             } else {
              break;
             }
             while(1) {
              $710 = (($$02125$i$us364) + -1)|0;
              $711 = ((($$02026$i$us363)) + 1|0);
              $712 = ($710|0)==(0);
              if ($712) {
               $$sroa$0276$0296 = $$sroa$0276$0297$us;
               label = 311;
               break L416;
              }
              $713 = ((($$027$i$us362)) + 1|0);
              $$pre325 = HEAP8[$711>>0]|0;
              $714 = HEAP8[$713>>0]|0;
              $715 = ($$pre325<<24>>24)==($714<<24>>24);
              if ($715) {
               $$02026$i$us363 = $711;$$02125$i$us364 = $710;$$027$i$us362 = $713;
              } else {
               break;
              }
             }
            }
           } while(0);
           $717 = ((($$sroa$0276$0297$us)) + 12|0);
           $718 = HEAP32[$32>>2]|0;
           $719 = ($717|0)==($718|0);
           if ($719) {
            $$pre328$pre$phiZZ2D = $675;
            label = 326;
            break L413;
           } else {
            $$sroa$0276$0297$us = $717;
           }
          }
         } else {
          $$pre322 = HEAP8[$675>>0]|0;
          $$pre323 = HEAP32[$676>>2]|0;
          $677 = ($$pre322<<24>>24)<(0);
          $678 = $$pre322&255;
          $679 = $677 ? $$pre323 : $678;
          $680 = HEAP32[$6>>2]|0;
          $681 = $677 ? $680 : $6;
          $682 = ($679|0)==(0);
          $683 = $680;
          $684 = $683&255;
          $$sroa$0276$0297 = $671;
          while(1) {
           $720 = ((($$sroa$0276$0297)) + 11|0);
           $721 = HEAP8[$720>>0]|0;
           $722 = ($721<<24>>24)<(0);
           $723 = ((($$sroa$0276$0297)) + 4|0);
           $724 = HEAP32[$723>>2]|0;
           $725 = $721&255;
           $726 = $722 ? $724 : $725;
           $727 = ($679|0)==($726|0);
           do {
            if ($727) {
             $728 = HEAP32[$$sroa$0276$0297>>2]|0;
             $729 = $722 ? $728 : $$sroa$0276$0297;
             if ($677) {
              if ($682) {
               $$sroa$0276$0296 = $$sroa$0276$0297;
               label = 311;
               break L416;
              }
              $738 = (_memcmp($681,$729,$679)|0);
              $phitmp$i254 = ($738|0)==(0);
              if ($phitmp$i254) {
               $$sroa$0276$0296 = $$sroa$0276$0297;
               label = 311;
               break L416;
              } else {
               break;
              }
             }
             if ($682) {
              $$sroa$0276$0296 = $$sroa$0276$0297;
              label = 311;
              break L416;
             }
             $730 = HEAP8[$729>>0]|0;
             $731 = ($684<<24>>24)==($730<<24>>24);
             if ($731) {
              $$02026$i367 = $6;$$02125$i368 = $678;$$027$i366 = $729;
             } else {
              break;
             }
             while(1) {
              $732 = (($$02125$i368) + -1)|0;
              $733 = ((($$02026$i367)) + 1|0);
              $734 = ($732|0)==(0);
              if ($734) {
               $$sroa$0276$0296 = $$sroa$0276$0297;
               label = 311;
               break L416;
              }
              $735 = ((($$027$i366)) + 1|0);
              $$pre324 = HEAP8[$733>>0]|0;
              $736 = HEAP8[$735>>0]|0;
              $737 = ($$pre324<<24>>24)==($736<<24>>24);
              if ($737) {
               $$02026$i367 = $733;$$02125$i368 = $732;$$027$i366 = $735;
              } else {
               break;
              }
             }
            }
           } while(0);
           $761 = ((($$sroa$0276$0297)) + 12|0);
           $762 = ($761|0)==($672|0);
           if ($762) {
            $$pre328$pre$phiZZ2D = $675;
            label = 326;
            break L413;
           } else {
            $$sroa$0276$0297 = $761;
           }
          }
         }
        } while(0);
        do {
         if ((label|0) == 311) {
          if (!($$128$off0)) {
           __THREW__ = 0;
           invoke_vii(3457,($0|0),($$sroa$0276$0296|0));
           $739 = __THREW__; __THREW__ = 0;
           $740 = $739&1;
           if ($740) {
            break;
           } else {
            $$pre$phi329Z2D = $675;
            break L413;
           }
          }
          if (!($$3$off0)) {
           __THREW__ = 0;
           invoke_viii(3550,($0|0),($5|0),($$sroa$0276$0296|0));
           $759 = __THREW__; __THREW__ = 0;
           $760 = $759&1;
           if ($760) {
            break;
           } else {
            $$pre$phi329Z2D = $675;
            break L413;
           }
          }
          __THREW__ = 0;
          invoke_viii(4198,($31|0),($5|0),47);
          $743 = __THREW__; __THREW__ = 0;
          $744 = $743&1;
          do {
           if ($744) {
            $751 = ___cxa_find_matching_catch_2()|0;
            $752 = tempRet0;
            $$24 = $751;$$2457 = $752;
           } else {
            __THREW__ = 0;
            invoke_viii(3550,($0|0),($31|0),($$sroa$0276$0296|0));
            $745 = __THREW__; __THREW__ = 0;
            $746 = $745&1;
            if ($746) {
             $753 = ___cxa_find_matching_catch_2()|0;
             $754 = tempRet0;
             $755 = ((($31)) + 11|0);
             $756 = HEAP8[$755>>0]|0;
             $757 = ($756<<24>>24)<(0);
             if (!($757)) {
              $$24 = $753;$$2457 = $754;
              break;
             }
             $758 = HEAP32[$31>>2]|0;
             __ZdlPv($758);
             $$24 = $753;$$2457 = $754;
             break;
            }
            $747 = ((($31)) + 11|0);
            $748 = HEAP8[$747>>0]|0;
            $749 = ($748<<24>>24)<(0);
            if ($749) {
             $750 = HEAP32[$31>>2]|0;
             __ZdlPv($750);
            }
            $$pre$phi329Z2D = $675;
            break L413;
           }
          } while(0);
          $$26 = $$24;$$2659 = $$2457;
          break L8;
         }
        } while(0);
        $741 = ___cxa_find_matching_catch_2()|0;
        $742 = tempRet0;
        $$26 = $741;$$2659 = $742;
        break L8;
       }
      } while(0);
      if ((label|0) == 326) {
       ;HEAP32[$0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;
       $$pre$phi329Z2D = $$pre328$pre$phiZZ2D;
      }
      $763 = HEAP8[$$pre$phi329Z2D>>0]|0;
      $764 = ($763<<24>>24)<(0);
      if ($764) {
       $765 = HEAP32[$6>>2]|0;
       __ZdlPv($765);
      }
      $766 = HEAP8[$$pre$phi337Z2D>>0]|0;
      $767 = ($766<<24>>24)<(0);
      if ($767) {
       $768 = HEAP32[$5>>2]|0;
       __ZdlPv($768);
      }
      $769 = HEAP32[$4>>2]|0;
      $770 = ($769|0)==(0|0);
      if ($770) {
       STACKTOP = sp;return;
      }
      $771 = HEAP32[$32>>2]|0;
      $772 = ($771|0)==($769|0);
      if ($772) {
       $781 = $769;
      } else {
       $774 = $771;
       while(1) {
        $773 = ((($774)) + -12|0);
        HEAP32[$32>>2] = $773;
        $775 = ((($773)) + 11|0);
        $776 = HEAP8[$775>>0]|0;
        $777 = ($776<<24>>24)<(0);
        if ($777) {
         $780 = HEAP32[$773>>2]|0;
         __ZdlPv($780);
         $$pre$i$i$i267 = HEAP32[$32>>2]|0;
         $778 = $$pre$i$i$i267;
        } else {
         $778 = $773;
        }
        $779 = ($778|0)==($769|0);
        if ($779) {
         break;
        } else {
         $774 = $778;
        }
       }
       $$pre$i269 = HEAP32[$4>>2]|0;
       $781 = $$pre$i269;
      }
      __ZdlPv($781);
      STACKTOP = sp;return;
     }
    } while(0);
    $293 = ___cxa_find_matching_catch_2()|0;
    $294 = tempRet0;
    $$26 = $293;$$2659 = $294;
   }
  } while(0);
  $782 = ((($6)) + 11|0);
  $783 = HEAP8[$782>>0]|0;
  $784 = ($783<<24>>24)<(0);
  if ($784) {
   $785 = HEAP32[$6>>2]|0;
   __ZdlPv($785);
  }
  $$27 = $$26;$$2760 = $$2659;
 }
 $786 = ((($5)) + 11|0);
 $787 = HEAP8[$786>>0]|0;
 $788 = ($787<<24>>24)<(0);
 if ($788) {
  $789 = HEAP32[$5>>2]|0;
  __ZdlPv($789);
 }
 $$pre326 = HEAP32[$4>>2]|0;
 $790 = ($$pre326|0)==(0|0);
 if ($790) {
  $$28343 = $$27;$$2861342 = $$2760;
  ___resumeException($$28343|0);
  // unreachable;
 }
 $791 = HEAP32[$32>>2]|0;
 $792 = ($791|0)==($$pre326|0);
 if ($792) {
  $801 = $$pre326;
 } else {
  $794 = $791;
  while(1) {
   $793 = ((($794)) + -12|0);
   HEAP32[$32>>2] = $793;
   $795 = ((($793)) + 11|0);
   $796 = HEAP8[$795>>0]|0;
   $797 = ($796<<24>>24)<(0);
   if ($797) {
    $800 = HEAP32[$793>>2]|0;
    __ZdlPv($800);
    $$pre$i$i$i202 = HEAP32[$32>>2]|0;
    $798 = $$pre$i$i$i202;
   } else {
    $798 = $793;
   }
   $799 = ($798|0)==($$pre326|0);
   if ($799) {
    break;
   } else {
    $794 = $798;
   }
  }
  $$pre$i204 = HEAP32[$4>>2]|0;
  $801 = $$pre$i204;
 }
 __ZdlPv($801);
 $$28343 = $$27;$$2861342 = $$2760;
 ___resumeException($$28343|0);
 // unreachable;
}
function __ZN5osgDB20getDirectoryContentsERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$012 = 0, $$016$i$i = 0, $$017$i$i = 0, $$1 = 0, $$113 = 0, $$pre$i = 0, $$pre$i$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 HEAP32[$0>>2] = 0;
 $3 = ((($0)) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = ((($0)) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = ((($1)) + 11|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = ($6<<24>>24)<(0);
 $8 = HEAP32[$1>>2]|0;
 $9 = $7 ? $8 : $1;
 $10 = (_opendir($9)|0);
 $11 = ($10|0)==(0|0);
 if ($11) {
  STACKTOP = sp;return;
 }
 $12 = ((($2)) + 11|0);
 $13 = ((($0)) + 8|0);
 $14 = ((($2)) + 8|0);
 $15 = ((($2)) + 4|0);
 while(1) {
  __THREW__ = 0;
  $16 = (invoke_ii(4253,($10|0))|0);
  $17 = __THREW__; __THREW__ = 0;
  $18 = $17&1;
  if ($18) {
   label = 19;
   break;
  }
  $19 = ($16|0)==(0|0);
  if ($19) {
   label = 24;
   break;
  }
  $20 = ((($16)) + 11|0);
  ;HEAP32[$2>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;
  $21 = (_strlen($20)|0);
  $22 = ($21>>>0)>(4294967279);
  if ($22) {
   label = 6;
   break;
  }
  $24 = ($21>>>0)<(11);
  if ($24) {
   $31 = $21&255;
   HEAP8[$12>>0] = $31;
   $32 = ($21|0)==(0);
   if ($32) {
    $$017$i$i = $2;
   } else {
    $$016$i$i = $2;
    label = 11;
   }
  } else {
   $25 = (($21) + 16)|0;
   $26 = $25 & -16;
   __THREW__ = 0;
   $27 = (invoke_ii(3276,($26|0))|0);
   $28 = __THREW__; __THREW__ = 0;
   $29 = $28&1;
   if ($29) {
    label = 20;
    break;
   }
   HEAP32[$2>>2] = $27;
   $30 = $26 | -2147483648;
   HEAP32[$14>>2] = $30;
   HEAP32[$15>>2] = $21;
   $$016$i$i = $27;
   label = 11;
  }
  if ((label|0) == 11) {
   label = 0;
   _memcpy(($$016$i$i|0),($20|0),($21|0))|0;
   $$017$i$i = $$016$i$i;
  }
  $33 = (($$017$i$i) + ($21)|0);
  HEAP8[$33>>0] = 0;
  $34 = HEAP32[$3>>2]|0;
  $35 = HEAP32[$13>>2]|0;
  $36 = ($34|0)==($35|0);
  if ($36) {
   __THREW__ = 0;
   invoke_vii(3747,($0|0),($2|0));
   $41 = __THREW__; __THREW__ = 0;
   $42 = $41&1;
   if ($42) {
    label = 21;
    break;
   }
  } else {
   __THREW__ = 0;
   invoke_vii(3457,($34|0),($2|0));
   $37 = __THREW__; __THREW__ = 0;
   $38 = $37&1;
   if ($38) {
    label = 21;
    break;
   }
   $39 = HEAP32[$3>>2]|0;
   $40 = ((($39)) + 12|0);
   HEAP32[$3>>2] = $40;
  }
  $43 = HEAP8[$12>>0]|0;
  $44 = ($43<<24>>24)<(0);
  if ($44) {
   $45 = HEAP32[$2>>2]|0;
   __ZdlPv($45);
  }
 }
 if ((label|0) == 6) {
  __THREW__ = 0;
  invoke_vi(3367,($2|0));
  $23 = __THREW__; __THREW__ = 0;
  label = 20;
 }
 else if ((label|0) == 19) {
  $46 = ___cxa_find_matching_catch_2()|0;
  $47 = tempRet0;
  $$1 = $47;$$113 = $46;
 }
 else if ((label|0) == 21) {
  $50 = ___cxa_find_matching_catch_2()|0;
  $51 = tempRet0;
  $52 = HEAP8[$12>>0]|0;
  $53 = ($52<<24>>24)<(0);
  if ($53) {
   $54 = HEAP32[$2>>2]|0;
   __ZdlPv($54);
   $$0 = $51;$$012 = $50;
   label = 23;
  } else {
   $$0 = $51;$$012 = $50;
   label = 23;
  }
 }
 else if ((label|0) == 24) {
  (_closedir($10)|0);
  STACKTOP = sp;return;
 }
 if ((label|0) == 20) {
  $48 = ___cxa_find_matching_catch_2()|0;
  $49 = tempRet0;
  $$0 = $49;$$012 = $48;
  label = 23;
 }
 if ((label|0) == 23) {
  $$1 = $$0;$$113 = $$012;
 }
 $55 = HEAP32[$0>>2]|0;
 $56 = ($55|0)==(0|0);
 if ($56) {
  ___resumeException($$113|0);
  // unreachable;
 }
 $57 = HEAP32[$3>>2]|0;
 $58 = ($57|0)==($55|0);
 if ($58) {
  $67 = $55;
 } else {
  $60 = $57;
  while(1) {
   $59 = ((($60)) + -12|0);
   HEAP32[$3>>2] = $59;
   $61 = ((($59)) + 11|0);
   $62 = HEAP8[$61>>0]|0;
   $63 = ($62<<24>>24)<(0);
   if ($63) {
    $66 = HEAP32[$59>>2]|0;
    __ZdlPv($66);
    $$pre$i$i$i = HEAP32[$3>>2]|0;
    $64 = $$pre$i$i$i;
   } else {
    $64 = $59;
   }
   $65 = ($64|0)==($55|0);
   if ($65) {
    break;
   } else {
    $60 = $64;
   }
  }
  $$pre$i = HEAP32[$0>>2]|0;
  $67 = $$pre$i;
 }
 __ZdlPv($67);
 ___resumeException($$113|0);
 // unreachable;
}
function __ZN5osgDB15findLibraryFileERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEENS_15CaseSensitivityE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (__ZN5osgDB8Registry8instanceEb(0)|0);
 $4 = (__ZN5osgDB8Registry8instanceEb(0)|0);
 $5 = ((($4)) + 160|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if (!($7)) {
  $8 = ((($6)) + 112|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($9|0)==(0|0);
  if (!($10)) {
   $11 = HEAP32[$9>>2]|0;
   $12 = ((($11)) + 4|0);
   $13 = HEAP32[$12>>2]|0;
   FUNCTION_TABLE_viiiii[$13 & 8191]($0,$9,$1,$6,$2);
   return;
  }
 }
 $14 = ((($3)) + 44|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0|0);
 if ($16) {
  __ZN5osgDB8Registry29findLibraryFileImplementationERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEPKNS_7OptionsENS_15CaseSensitivityE($0,$3,$1,$6,$2);
  return;
 } else {
  $17 = HEAP32[$15>>2]|0;
  $18 = ((($17)) + 4|0);
  $19 = HEAP32[$18>>2]|0;
  FUNCTION_TABLE_viiiii[$19 & 8191]($0,$15,$1,$6,$2);
  return;
 }
}
function __ZN5osgDB38appendPlatformSpecificLibraryFilePathsERNSt3__25dequeINS0_12basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEENS5_IS7_EEEE($0) {
 $0 = $0|0;
 var $$0 = 0, $$016$i$i = 0, $$017$i$i = 0, $$07 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $1 = sp + 12|0;
 $2 = sp;
 $3 = (_getenv((172866|0))|0);
 $4 = ($3|0)==(0|0);
 do {
  if (!($4)) {
   ;HEAP32[$1>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;
   $5 = (_strlen($3)|0);
   $6 = ($5>>>0)>(4294967279);
   if ($6) {
    __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv($1);
    // unreachable;
   }
   $7 = ($5>>>0)<(11);
   if ($7) {
    $14 = $5&255;
    $15 = ((($1)) + 11|0);
    HEAP8[$15>>0] = $14;
    $16 = ($5|0)==(0);
    if ($16) {
     $$017$i$i = $1;
    } else {
     $$016$i$i = $1;
     label = 7;
    }
   } else {
    $8 = (($5) + 16)|0;
    $9 = $8 & -16;
    $10 = (__Znwj($9)|0);
    HEAP32[$1>>2] = $10;
    $11 = $9 | -2147483648;
    $12 = ((($1)) + 8|0);
    HEAP32[$12>>2] = $11;
    $13 = ((($1)) + 4|0);
    HEAP32[$13>>2] = $5;
    $$016$i$i = $10;
    label = 7;
   }
   if ((label|0) == 7) {
    _memcpy(($$016$i$i|0),($3|0),($5|0))|0;
    $$017$i$i = $$016$i$i;
   }
   $17 = (($$017$i$i) + ($5)|0);
   HEAP8[$17>>0] = 0;
   __THREW__ = 0;
   invoke_vii(4187,($1|0),($0|0));
   $18 = __THREW__; __THREW__ = 0;
   $19 = $18&1;
   if (!($19)) {
    $20 = ((($1)) + 11|0);
    $21 = HEAP8[$20>>0]|0;
    $22 = ($21<<24>>24)<(0);
    if ($22) {
     $23 = HEAP32[$1>>2]|0;
     __ZdlPv($23);
    }
    break;
   }
   $24 = ___cxa_find_matching_catch_2()|0;
   $25 = tempRet0;
   $26 = ((($1)) + 11|0);
   $27 = HEAP8[$26>>0]|0;
   $28 = ($27<<24>>24)<(0);
   if ($28) {
    $29 = HEAP32[$1>>2]|0;
    __ZdlPv($29);
   }
   $$0 = $25;$$07 = $24;
   ___resumeException($$07|0);
   // unreachable;
  }
 } while(0);
 $30 = (__Znwj(32)|0);
 HEAP32[$2>>2] = $30;
 $31 = ((($2)) + 8|0);
 HEAP32[$31>>2] = -2147483616;
 $32 = ((($2)) + 4|0);
 HEAP32[$32>>2] = 25;
 dest=$30; src=172882; stop=dest+25|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $33 = ((($30)) + 25|0);
 HEAP8[$33>>0] = 0;
 __THREW__ = 0;
 invoke_vii(4187,($2|0),($0|0));
 $34 = __THREW__; __THREW__ = 0;
 $35 = $34&1;
 if ($35) {
  $40 = ___cxa_find_matching_catch_2()|0;
  $41 = tempRet0;
  $42 = ((($2)) + 11|0);
  $43 = HEAP8[$42>>0]|0;
  $44 = ($43<<24>>24)<(0);
  if ($44) {
   $45 = HEAP32[$2>>2]|0;
   __ZdlPv($45);
  }
  $$0 = $41;$$07 = $40;
  ___resumeException($$07|0);
  // unreachable;
 } else {
  $36 = ((($2)) + 11|0);
  $37 = HEAP8[$36>>0]|0;
  $38 = ($37<<24>>24)<(0);
  if (!($38)) {
   STACKTOP = sp;return;
  }
  $39 = HEAP32[$2>>2]|0;
  __ZdlPv($39);
  STACKTOP = sp;return;
 }
}
function __ZN5osgDB39appendPlatformSpecificResourceFilePathsERNSt3__25dequeINS0_12basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEENS5_IS7_EEEE($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN5osgDB8FileList10removeFileERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 32|0);
 $3 = (__ZNSt3__26__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EENS4_IS6_EEE4findIS6_EENS_15__tree_iteratorIS6_PNS_11__tree_nodeIS6_PvEEiEERKT_($2,$1)|0);
 $4 = ((($0)) + 36|0);
 $5 = ($3|0)==($4|0);
 if ($5) {
  $$0 = 0;
  return ($$0|0);
 }
 $6 = ((($3)) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if ($8) {
  $9 = ((($3)) + 8|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = HEAP32[$10>>2]|0;
  $12 = ($11|0)==($3|0);
  if ($12) {
   $$0$i$i$i$i = $10;
  } else {
   $16 = $9;
   while(1) {
    $15 = HEAP32[$16>>2]|0;
    $17 = ((($15)) + 8|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = HEAP32[$18>>2]|0;
    $20 = ($19|0)==($15|0);
    if ($20) {
     $$0$i$i$i$i = $18;
     break;
    } else {
     $16 = $17;
    }
   }
  }
 } else {
  $$0$i$i$i$i$i = $7;
  while(1) {
   $13 = HEAP32[$$0$i$i$i$i$i>>2]|0;
   $14 = ($13|0)==(0|0);
   if ($14) {
    break;
   } else {
    $$0$i$i$i$i$i = $13;
   }
  }
  $$0$i$i$i$i = $$0$i$i$i$i$i;
 }
 $21 = HEAP32[$2>>2]|0;
 $22 = ($21|0)==($3|0);
 if ($22) {
  $23 = $$0$i$i$i$i;
  HEAP32[$2>>2] = $23;
 }
 $24 = ((($0)) + 40|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($25) + -1)|0;
 HEAP32[$24>>2] = $26;
 $27 = ((($0)) + 36|0);
 $28 = HEAP32[$27>>2]|0;
 __ZNSt3__213__tree_removeIPNS_16__tree_node_baseIPvEEEEvT_S5_($28,$3);
 $29 = ((($3)) + 16|0);
 $30 = ((($29)) + 11|0);
 $31 = HEAP8[$30>>0]|0;
 $32 = ($31<<24>>24)<(0);
 if ($32) {
  $33 = HEAP32[$29>>2]|0;
  __ZdlPv($33);
 }
 __ZdlPv($3);
 $$0 = 1;
 return ($$0|0);
}
function __ZNK5osgDB16DatabaseRevision17isFileBlackListedERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre$phi13Z2D = 0, $$pre$phiZ2D = 0, $$pre12 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $2 = sp + 12|0;
 $3 = sp;
 $4 = sp + 16|0;
 $5 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
 do {
  if ($5) {
   $6 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
   $7 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($6,174956,17)|0);
   $8 = ((($0)) + 12|0);
   $9 = ((($8)) + 11|0);
   $10 = HEAP8[$9>>0]|0;
   $11 = ($10<<24>>24)<(0);
   $12 = HEAP32[$8>>2]|0;
   $13 = $11 ? $12 : $8;
   $14 = ((($0)) + 16|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = $10&255;
   $17 = $11 ? $15 : $16;
   $18 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($7,$13,$17)|0);
   $19 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($18,174974,21)|0);
   $20 = ((($1)) + 11|0);
   $21 = HEAP8[$20>>0]|0;
   $22 = ($21<<24>>24)<(0);
   $23 = HEAP32[$1>>2]|0;
   $24 = $22 ? $23 : $1;
   $25 = ((($1)) + 4|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = $21&255;
   $28 = $22 ? $26 : $27;
   $29 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($19,$24,$28)|0);
   $30 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($29,174996,1)|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = ((($31)) + -12|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = (($30) + ($33)|0);
   __ZNKSt3__28ios_base6getlocEv($2,$34);
   __THREW__ = 0;
   $35 = (invoke_iii(3255,($2|0),(215188|0))|0);
   $36 = __THREW__; __THREW__ = 0;
   $37 = $36&1;
   if (!($37)) {
    $38 = HEAP32[$35>>2]|0;
    $39 = ((($38)) + 28|0);
    $40 = HEAP32[$39>>2]|0;
    __THREW__ = 0;
    $41 = (invoke_iii($40|0,($35|0),10)|0);
    $42 = __THREW__; __THREW__ = 0;
    $43 = $42&1;
    if (!($43)) {
     __ZNSt3__26localeD2Ev($2);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($30,$41)|0);
     (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($30)|0);
     break;
    }
   }
   $44 = ___cxa_find_matching_catch_2()|0;
   $45 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3263,($2|0));
   $46 = __THREW__; __THREW__ = 0;
   $47 = $46&1;
   if ($47) {
    $48 = ___cxa_find_matching_catch_3(0|0)|0;
    $49 = tempRet0;
    ___clang_call_terminate($48);
    // unreachable;
   } else {
    ___resumeException($44|0);
    // unreachable;
   }
  }
 } while(0);
 $50 = ((($0)) + 32|0);
 $51 = ((($50)) + 11|0);
 $52 = HEAP8[$51>>0]|0;
 $53 = ($52<<24>>24)<(0);
 if ($53) {
  $54 = ((($0)) + 36|0);
  $55 = HEAP32[$54>>2]|0;
  $64 = $55;
 } else {
  $56 = $52&255;
  $64 = $56;
 }
 $57 = ((($1)) + 11|0);
 $58 = HEAP8[$57>>0]|0;
 $59 = ($58<<24>>24)<(0);
 $60 = ((($1)) + 4|0);
 $61 = HEAP32[$60>>2]|0;
 $62 = $58&255;
 $63 = $59 ? $61 : $62;
 $65 = ($64>>>0)<($63>>>0);
 if (!($65)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 if ($53) {
  $66 = ((($0)) + 36|0);
  $67 = HEAP32[$66>>2]|0;
  $$pre12 = $52&255;
  $$pre$phi13Z2D = $$pre12;$$pre$phiZ2D = $66;$71 = $67;$73 = $67;
 } else {
  $68 = $52&255;
  $$phi$trans$insert = ((($0)) + 36|0);
  $$pre = HEAP32[$$phi$trans$insert>>2]|0;
  $$pre$phi13Z2D = $68;$$pre$phiZ2D = $$phi$trans$insert;$71 = $$pre;$73 = $68;
 }
 $69 = HEAP32[$50>>2]|0;
 $70 = $53 ? $69 : $50;
 $72 = $53 ? $71 : $$pre$phi13Z2D;
 $74 = (__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7compareEjjPKcj($1,0,$73,$70,$72)|0);
 $75 = ($74|0)==(0);
 if (!($75)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $76 = HEAP8[$51>>0]|0;
 $77 = ($76<<24>>24)<(0);
 if ($77) {
  $78 = HEAP32[$$pre$phiZ2D>>2]|0;
  $80 = $78;
 } else {
  $79 = $76&255;
  $80 = $79;
 }
 $81 = ($80|0)==(0);
 if ($81) {
  $86 = 0;
 } else {
  if ($77) {
   $82 = HEAP32[$$pre$phiZ2D>>2]|0;
   $85 = $82;
  } else {
   $83 = $76&255;
   $85 = $83;
  }
  $84 = (($85) + 1)|0;
  $86 = $84;
 }
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_jjRKS4_($3,$1,$86,-1,$4);
 $87 = ((($0)) + 48|0);
 $88 = HEAP32[$87>>2]|0;
 $89 = ($88|0)==(0|0);
 if ($89) {
  label = 27;
 } else {
  $90 = ((($88)) + 32|0);
  __THREW__ = 0;
  $91 = (invoke_iii(4254,($90|0),($3|0))|0);
  $92 = __THREW__; __THREW__ = 0;
  $93 = $92&1;
  if ($93) {
   label = 33;
  } else {
   $94 = ($91|0)==(0);
   if ($94) {
    label = 27;
   } else {
    $113 = 1;
    label = 30;
   }
  }
 }
 if ((label|0) == 27) {
  $95 = ((($0)) + 52|0);
  $96 = HEAP32[$95>>2]|0;
  $97 = ($96|0)==(0|0);
  if ($97) {
   $113 = 0;
   label = 30;
  } else {
   $98 = ((($96)) + 32|0);
   __THREW__ = 0;
   $99 = (invoke_iii(4254,($98|0),($3|0))|0);
   $100 = __THREW__; __THREW__ = 0;
   $101 = $100&1;
   if ($101) {
    label = 33;
   } else {
    $102 = ($99|0)!=(0);
    $113 = $102;
    label = 30;
   }
  }
 }
 if ((label|0) == 30) {
  $103 = ((($3)) + 11|0);
  $104 = HEAP8[$103>>0]|0;
  $105 = ($104<<24>>24)<(0);
  if ($105) {
   $106 = HEAP32[$3>>2]|0;
   __ZdlPv($106);
  }
  $$0 = $113;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 33) {
  $107 = ___cxa_find_matching_catch_2()|0;
  $108 = tempRet0;
  $109 = ((($3)) + 11|0);
  $110 = HEAP8[$109>>0]|0;
  $111 = ($110<<24>>24)<(0);
  if (!($111)) {
   ___resumeException($107|0);
   // unreachable;
  }
  $112 = HEAP32[$3>>2]|0;
  __ZdlPv($112);
  ___resumeException($107|0);
  // unreachable;
 }
 return (0)|0;
}
function __ZNKSt3__26__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EENS4_IS6_EEE14__count_uniqueIS6_EEjRKT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$09 = 0, $$sink$be = 0, $$sroa$speculated$i$i$i$i = 0, $$sroa$speculated$i$i$i$i10 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $$09 = 0;
  return ($$09|0);
 }
 $5 = ((($1)) + 11|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = ($6<<24>>24)<(0);
 $8 = ((($1)) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $6&255;
 $11 = $7 ? $9 : $10;
 $12 = HEAP32[$1>>2]|0;
 $13 = $7 ? $12 : $1;
 $15 = $3;
 while(1) {
  $14 = ((($15)) + 16|0);
  $16 = ((($14)) + 11|0);
  $17 = HEAP8[$16>>0]|0;
  $18 = ($17<<24>>24)<(0);
  $19 = ((($15)) + 20|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = $17&255;
  $22 = $18 ? $20 : $21;
  $23 = ($22>>>0)<($11>>>0);
  $$sroa$speculated$i$i$i$i10 = $23 ? $22 : $11;
  $24 = ($$sroa$speculated$i$i$i$i10|0)==(0);
  if ($24) {
   label = 5;
  } else {
   $25 = HEAP32[$14>>2]|0;
   $26 = $18 ? $25 : $14;
   $27 = (_memcmp($13,$26,$$sroa$speculated$i$i$i$i10)|0);
   $28 = ($27|0)==(0);
   if ($28) {
    label = 5;
   } else {
    $30 = ($27|0)<(0);
    if ($30) {
     label = 7;
    } else {
     label = 8;
    }
   }
  }
  if ((label|0) == 5) {
   label = 0;
   $29 = ($11>>>0)<($22>>>0);
   if ($29) {
    label = 7;
   } else {
    label = 8;
   }
  }
  if ((label|0) == 7) {
   label = 0;
   $$sink$be = $15;
  }
  else if ((label|0) == 8) {
   label = 0;
   $31 = ($11>>>0)<($22>>>0);
   $$sroa$speculated$i$i$i$i = $31 ? $11 : $22;
   $32 = ($$sroa$speculated$i$i$i$i|0)==(0);
   if ($32) {
    label = 10;
   } else {
    $33 = HEAP32[$14>>2]|0;
    $34 = $18 ? $33 : $14;
    $35 = (_memcmp($34,$13,$$sroa$speculated$i$i$i$i)|0);
    $36 = ($35|0)==(0);
    if ($36) {
     label = 10;
    } else {
     $37 = ($35|0)<(0);
     if (!($37)) {
      $$09 = 1;
      label = 14;
      break;
     }
    }
   }
   if ((label|0) == 10) {
    label = 0;
    if (!($23)) {
     $$09 = 1;
     label = 14;
     break;
    }
   }
   $38 = ((($15)) + 4|0);
   $$sink$be = $38;
  }
  $39 = HEAP32[$$sink$be>>2]|0;
  $40 = ($39|0)==(0|0);
  if ($40) {
   $$09 = 0;
   label = 14;
   break;
  } else {
   $15 = $39;
  }
 }
 if ((label|0) == 14) {
  return ($$09|0);
 }
 return (0)|0;
}
function __ZNK5osgDB17DatabaseRevisions17isFileBlackListedERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$sroa$06$010 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = ((($0)) + 44|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 48|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4|0)==($6|0);
 if ($7) {
  $45 = 0;
  STACKTOP = sp;return ($45|0);
 } else {
  $$sroa$06$010 = $4;
 }
 while(1) {
  $11 = HEAP32[$$sroa$06$010>>2]|0;
  $12 = (__ZNK5osgDB16DatabaseRevision17isFileBlackListedERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE($11,$1)|0);
  $9 = ((($$sroa$06$010)) + 4|0);
  if ($12) {
   break;
  }
  $8 = HEAP32[$5>>2]|0;
  $10 = ($9|0)==($8|0);
  if ($10) {
   $45 = 0;
   label = 11;
   break;
  } else {
   $$sroa$06$010 = $9;
  }
 }
 if ((label|0) == 11) {
  STACKTOP = sp;return ($45|0);
 }
 $13 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
 if (!($13)) {
  $45 = 1;
  STACKTOP = sp;return ($45|0);
 }
 $14 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
 $15 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($14,174998,21)|0);
 $16 = ((($1)) + 11|0);
 $17 = HEAP8[$16>>0]|0;
 $18 = ($17<<24>>24)<(0);
 $19 = HEAP32[$1>>2]|0;
 $20 = $18 ? $19 : $1;
 $21 = ((($1)) + 4|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = $17&255;
 $24 = $18 ? $22 : $23;
 $25 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($15,$20,$24)|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ((($26)) + -12|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($25) + ($28)|0);
 __ZNKSt3__28ios_base6getlocEv($2,$29);
 __THREW__ = 0;
 $30 = (invoke_iii(3255,($2|0),(215188|0))|0);
 $31 = __THREW__; __THREW__ = 0;
 $32 = $31&1;
 if (!($32)) {
  $33 = HEAP32[$30>>2]|0;
  $34 = ((($33)) + 28|0);
  $35 = HEAP32[$34>>2]|0;
  __THREW__ = 0;
  $36 = (invoke_iii($35|0,($30|0),10)|0);
  $37 = __THREW__; __THREW__ = 0;
  $38 = $37&1;
  if (!($38)) {
   __ZNSt3__26localeD2Ev($2);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($25,$36)|0);
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($25)|0);
   $45 = 1;
   STACKTOP = sp;return ($45|0);
  }
 }
 $39 = ___cxa_find_matching_catch_2()|0;
 $40 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3263,($2|0));
 $41 = __THREW__; __THREW__ = 0;
 $42 = $41&1;
 if ($42) {
  $43 = ___cxa_find_matching_catch_3(0|0)|0;
  $44 = tempRet0;
  ___clang_call_terminate($43);
  // unreachable;
 } else {
  ___resumeException($39|0);
  // unreachable;
 }
 return (0)|0;
}
function __ZN3osg13ImageSequence15setImageToChildEi($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$pre = 0, $$pre$phiZ2D = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp + 12|0;
 $3 = sp + 8|0;
 $4 = sp + 4|0;
 $5 = sp;
 $6 = ($1|0)>(-1);
 if (!($6)) {
  STACKTOP = sp;return;
 }
 $7 = ((($0)) + 212|0);
 $8 = ((($0)) + 216|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$7>>2]|0;
 $11 = (($9) - ($10))|0;
 $12 = (($11|0) / 20)&-1;
 $13 = ($12|0)>($1|0);
 if (!($13)) {
  STACKTOP = sp;return;
 }
 $14 = $10;
 $15 = (((($14) + (($1*20)|0)|0)) + 12|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==(0|0);
 if ($17) {
  STACKTOP = sp;return;
 }
 $18 = ((($16)) + 112|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ((($0)) + 112|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($19|0)==($21|0);
 if ($22) {
  STACKTOP = sp;return;
 }
 $23 = ((($0)) + 176|0);
 $24 = HEAP32[$23>>2]|0;
 L13: do {
  switch ($24|0) {
  case 2: case 4:  {
   $25 = ((($0)) + 224|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = ($26|0)>(-1);
   if ($27) {
    $28 = ($26|0)<($1|0);
    if ($28) {
     $29 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
     do {
      if ($29) {
       $30 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
       $31 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($30,175020,20)|0);
       $32 = HEAP32[$25>>2]|0;
       $33 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi($31,$32)|0);
       $34 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($33,175041,4)|0);
       $35 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi($34,$1)|0);
       $36 = HEAP32[$35>>2]|0;
       $37 = ((($36)) + -12|0);
       $38 = HEAP32[$37>>2]|0;
       $39 = (($35) + ($38)|0);
       __ZNKSt3__28ios_base6getlocEv($4,$39);
       __THREW__ = 0;
       $40 = (invoke_iii(3255,($4|0),(215188|0))|0);
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        $43 = HEAP32[$40>>2]|0;
        $44 = ((($43)) + 28|0);
        $45 = HEAP32[$44>>2]|0;
        __THREW__ = 0;
        $46 = (invoke_iii($45|0,($40|0),10)|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if (!($48)) {
         __ZNSt3__26localeD2Ev($4);
         (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($35,$46)|0);
         (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($35)|0);
         break;
        }
       }
       $49 = ___cxa_find_matching_catch_2()|0;
       $50 = tempRet0;
       __THREW__ = 0;
       invoke_vi(3263,($4|0));
       $51 = __THREW__; __THREW__ = 0;
       $52 = $51&1;
       if ($52) {
        $53 = ___cxa_find_matching_catch_3(0|0)|0;
        $54 = tempRet0;
        ___clang_call_terminate($53);
        // unreachable;
       } else {
        ___resumeException($49|0);
        // unreachable;
       }
      }
     } while(0);
     $55 = HEAP32[$25>>2]|0;
     $56 = ($55|0)<($1|0);
     if (!($56)) {
      $$pre$phiZ2D = $25;
      break L13;
     }
     $57 = ((($0)) + 212|0);
     $60 = $55;
     while(1) {
      $58 = HEAP32[$57>>2]|0;
      $59 = (((($58) + (($60*20)|0)|0)) + 12|0);
      $61 = HEAP32[$59>>2]|0;
      $62 = ($61|0)==(0|0);
      if (!($62)) {
       HEAP32[$59>>2] = 0;
       $63 = ((($61)) + 8|0);
       $64 = HEAP32[$63>>2]|0;HEAP32[$63>>2] = (($64-1)|0);
       $65 = ($64|0)==(1);
       if ($65) {
        __ZNK3osg10Referenced24signalObserversAndDeleteEbb($61,1,1);
       }
      }
      $66 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
      if ($66) {
       $67 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
       $68 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($67,175046,12)|0);
       $69 = HEAP32[$25>>2]|0;
       $70 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi($68,$69)|0);
       $71 = HEAP32[$70>>2]|0;
       $72 = ((($71)) + -12|0);
       $73 = HEAP32[$72>>2]|0;
       $74 = (($70) + ($73)|0);
       __ZNKSt3__28ios_base6getlocEv($3,$74);
       __THREW__ = 0;
       $75 = (invoke_iii(3255,($3|0),(215188|0))|0);
       $76 = __THREW__; __THREW__ = 0;
       $77 = $76&1;
       if ($77) {
        break;
       }
       $78 = HEAP32[$75>>2]|0;
       $79 = ((($78)) + 28|0);
       $80 = HEAP32[$79>>2]|0;
       __THREW__ = 0;
       $81 = (invoke_iii($80|0,($75|0),10)|0);
       $82 = __THREW__; __THREW__ = 0;
       $83 = $82&1;
       if ($83) {
        break;
       }
       __ZNSt3__26localeD2Ev($3);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($70,$81)|0);
       (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($70)|0);
      }
      $90 = HEAP32[$25>>2]|0;
      $91 = (($90) + 1)|0;
      HEAP32[$25>>2] = $91;
      $92 = ($91|0)<($1|0);
      if ($92) {
       $60 = $91;
      } else {
       $$pre$phiZ2D = $25;
       break L13;
      }
     }
     $84 = ___cxa_find_matching_catch_2()|0;
     $85 = tempRet0;
     __THREW__ = 0;
     invoke_vi(3263,($3|0));
     $86 = __THREW__; __THREW__ = 0;
     $87 = $86&1;
     if ($87) {
      $88 = ___cxa_find_matching_catch_3(0|0)|0;
      $89 = tempRet0;
      ___clang_call_terminate($88);
      // unreachable;
     } else {
      ___resumeException($84|0);
      // unreachable;
     }
    }
    $93 = ($26|0)>($1|0);
    if ($93) {
     $94 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
     do {
      if ($94) {
       $95 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
       $96 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($95,175059,17)|0);
       $97 = HEAP32[$25>>2]|0;
       $98 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi($96,$97)|0);
       $99 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($98,175041,4)|0);
       $100 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi($99,$1)|0);
       $101 = HEAP32[$100>>2]|0;
       $102 = ((($101)) + -12|0);
       $103 = HEAP32[$102>>2]|0;
       $104 = (($100) + ($103)|0);
       __ZNKSt3__28ios_base6getlocEv($2,$104);
       __THREW__ = 0;
       $105 = (invoke_iii(3255,($2|0),(215188|0))|0);
       $106 = __THREW__; __THREW__ = 0;
       $107 = $106&1;
       if (!($107)) {
        $108 = HEAP32[$105>>2]|0;
        $109 = ((($108)) + 28|0);
        $110 = HEAP32[$109>>2]|0;
        __THREW__ = 0;
        $111 = (invoke_iii($110|0,($105|0),10)|0);
        $112 = __THREW__; __THREW__ = 0;
        $113 = $112&1;
        if (!($113)) {
         __ZNSt3__26localeD2Ev($2);
         (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($100,$111)|0);
         (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($100)|0);
         break;
        }
       }
       $114 = ___cxa_find_matching_catch_2()|0;
       $115 = tempRet0;
       __THREW__ = 0;
       invoke_vi(3263,($2|0));
       $116 = __THREW__; __THREW__ = 0;
       $117 = $116&1;
       if ($117) {
        $118 = ___cxa_find_matching_catch_3(0|0)|0;
        $119 = tempRet0;
        ___clang_call_terminate($118);
        // unreachable;
       } else {
        ___resumeException($114|0);
        // unreachable;
       }
      }
     } while(0);
     $120 = HEAP32[$25>>2]|0;
     $121 = ($120|0)>($1|0);
     if ($121) {
      $122 = ((($0)) + 212|0);
      $125 = $120;
      while(1) {
       $123 = HEAP32[$122>>2]|0;
       $124 = (((($123) + (($125*20)|0)|0)) + 12|0);
       $126 = HEAP32[$124>>2]|0;
       $127 = ($126|0)==(0|0);
       if (!($127)) {
        HEAP32[$124>>2] = 0;
        $128 = ((($126)) + 8|0);
        $129 = HEAP32[$128>>2]|0;HEAP32[$128>>2] = (($129-1)|0);
        $130 = ($129|0)==(1);
        if ($130) {
         __ZNK3osg10Referenced24signalObserversAndDeleteEbb($126,1,1);
        }
       }
       $131 = (__ZN3osg15isNotifyEnabledENS_14NotifySeverityE(4)|0);
       if ($131) {
        $132 = (__ZN3osg6notifyENS_14NotifySeverityE(4)|0);
        $133 = (__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j($132,175046,12)|0);
        $134 = HEAP32[$25>>2]|0;
        $135 = (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi($133,$134)|0);
        $136 = HEAP32[$135>>2]|0;
        $137 = ((($136)) + -12|0);
        $138 = HEAP32[$137>>2]|0;
        $139 = (($135) + ($138)|0);
        __ZNKSt3__28ios_base6getlocEv($5,$139);
        __THREW__ = 0;
        $140 = (invoke_iii(3255,($5|0),(215188|0))|0);
        $141 = __THREW__; __THREW__ = 0;
        $142 = $141&1;
        if ($142) {
         break;
        }
        $143 = HEAP32[$140>>2]|0;
        $144 = ((($143)) + 28|0);
        $145 = HEAP32[$144>>2]|0;
        __THREW__ = 0;
        $146 = (invoke_iii($145|0,($140|0),10)|0);
        $147 = __THREW__; __THREW__ = 0;
        $148 = $147&1;
        if ($148) {
         break;
        }
        __ZNSt3__26localeD2Ev($5);
        (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($135,$146)|0);
        (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($135)|0);
       }
       $155 = HEAP32[$25>>2]|0;
       $156 = (($155) + -1)|0;
       HEAP32[$25>>2] = $156;
       $157 = ($156|0)>($1|0);
       if ($157) {
        $125 = $156;
       } else {
        $$pre$phiZ2D = $25;
        break L13;
       }
      }
      $149 = ___cxa_find_matching_catch_2()|0;
      $150 = tempRet0;
      __THREW__ = 0;
      invoke_vi(3263,($5|0));
      $151 = __THREW__; __THREW__ = 0;
      $152 = $151&1;
      if ($152) {
       $153 = ___cxa_find_matching_catch_3(0|0)|0;
       $154 = tempRet0;
       ___clang_call_terminate($153);
       // unreachable;
      } else {
       ___resumeException($149|0);
       // unreachable;
      }
     } else {
      $$pre$phiZ2D = $25;
     }
    } else {
     $$pre$phiZ2D = $25;
    }
   } else {
    $$pre$phiZ2D = $25;
   }
   break;
  }
  default: {
   $$pre = ((($0)) + 224|0);
   $$pre$phiZ2D = $$pre;
  }
  }
 } while(0);
 HEAP32[$$pre$phiZ2D>>2] = $1;
 $158 = ((($16)) + 72|0);
 $159 = HEAP32[$158>>2]|0;
 $160 = ((($16)) + 76|0);
 $161 = HEAP32[$160>>2]|0;
 $162 = ((($16)) + 80|0);
 $163 = HEAP32[$162>>2]|0;
 $164 = ((($16)) + 88|0);
 $165 = HEAP32[$164>>2]|0;
 $166 = ((($16)) + 92|0);
 $167 = HEAP32[$166>>2]|0;
 $168 = ((($16)) + 96|0);
 $169 = HEAP32[$168>>2]|0;
 $170 = HEAP32[$18>>2]|0;
 $171 = ((($16)) + 100|0);
 $172 = HEAP32[$171>>2]|0;
 __ZN3osg5Image8setImageEiiiijjPhNS0_14AllocationModeEii($0,$159,$161,$163,$165,$167,$169,$170,0,$172,0);
 $173 = ((($16)) + 116|0);
 $174 = ((($0)) + 116|0);
 $175 = ($174|0)==($173|0);
 if ($175) {
  STACKTOP = sp;return;
 }
 $176 = HEAP32[$173>>2]|0;
 $177 = ((($16)) + 120|0);
 $178 = HEAP32[$177>>2]|0;
 __ZNSt3__26vectorIjNS_9allocatorIjEEE6assignIPjEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIjNS_15iterator_traitsIS7_E9referenceEEE5valueEvE4typeES7_S7_($174,$176,$178);
 STACKTOP = sp;return;
}
function __ZN3osg13ImageSequence9_setImageEjPNS_5ImageE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$pre$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 212|0);
 $4 = ((($0)) + 216|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$3>>2]|0;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 20)&-1;
 $9 = ($8>>>0)>($1>>>0);
 L1: do {
  if (!($9)) {
   $10 = (($1) + 1)|0;
   $11 = ($10>>>0)>($8>>>0);
   $12 = $6;
   $13 = $5;
   if ($11) {
    $14 = (($10) - ($8))|0;
    __ZNSt3__26vectorIN3osg13ImageSequence9ImageDataENS_9allocatorIS3_EEE8__appendEj($3,$14);
    break;
   }
   $15 = ($10>>>0)<($8>>>0);
   if ($15) {
    $16 = (($12) + (($10*20)|0)|0);
    $17 = ($13|0)==($16|0);
    if (!($17)) {
     $19 = $13;
     while(1) {
      $18 = ((($19)) + -20|0);
      HEAP32[$4>>2] = $18;
      __THREW__ = 0;
      invoke_vi(4255,($18|0));
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if ($21) {
       break;
      }
      $$pre$i = HEAP32[$4>>2]|0;
      $22 = ($$pre$i|0)==($16|0);
      if ($22) {
       break L1;
      } else {
       $19 = $$pre$i;
      }
     }
     $23 = ___cxa_find_matching_catch_2()|0;
     $24 = tempRet0;
     ___cxa_call_unexpected(($23|0));
     // unreachable;
    }
   }
  }
 } while(0);
 $25 = HEAP32[$3>>2]|0;
 $26 = (((($25) + (($1*20)|0)|0)) + 12|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ($27|0)==($2|0);
 if (!($28)) {
  HEAP32[$26>>2] = $2;
  $29 = ($2|0)==(0|0);
  if (!($29)) {
   $30 = ((($2)) + 8|0);
   $31 = HEAP32[$30>>2]|0;HEAP32[$30>>2] = (($31+1)|0);
  }
  $32 = ($27|0)==(0|0);
  if (!($32)) {
   $33 = ((($27)) + 8|0);
   $34 = HEAP32[$33>>2]|0;HEAP32[$33>>2] = (($34-1)|0);
   $35 = ($34|0)==(1);
   if ($35) {
    __ZNK3osg10Referenced24signalObserversAndDeleteEbb($27,1,1);
   }
  }
 }
 $36 = ((($2)) + 52|0);
 $37 = HEAP32[$3>>2]|0;
 $38 = (($37) + (($1*20)|0)|0);
 (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEaSERKS5_($38,$36)|0);
 return;
}
function __ZNSt3__26vectorIN3osg13ImageSequence9ImageDataENS_9allocatorIS3_EEE8__appendEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i = 0, $$0$i13 = 0, $$06$i$i = 0, $$in = 0, $$pre = 0, $$pre$i14 = 0, $$sroa$16$0 = 0, $$sroa$16$1 = 0, $$sroa$16$2 = 0, $$sroa$7$0 = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) - ($5))|0;
 $7 = (($6|0) / 20)&-1;
 $8 = ($7>>>0)<($1>>>0);
 if (!($8)) {
  $9 = $5;
  $$0$i = $1;$10 = $9;
  while(1) {
   ;HEAP32[$10>>2]=0|0;HEAP32[$10+4>>2]=0|0;HEAP32[$10+8>>2]=0|0;HEAP32[$10+12>>2]=0|0;HEAP32[$10+16>>2]=0|0;
   $11 = HEAP32[$4>>2]|0;
   $12 = ((($11)) + 20|0);
   HEAP32[$4>>2] = $12;
   $13 = (($$0$i) + -1)|0;
   $14 = ($13|0)==(0);
   if ($14) {
    break;
   } else {
    $$0$i = $13;$10 = $12;
   }
  }
  return;
 }
 $15 = HEAP32[$0>>2]|0;
 $16 = (($5) - ($15))|0;
 $17 = (($16|0) / 20)&-1;
 $18 = (($17) + ($1))|0;
 $19 = ($18>>>0)>(214748364);
 if ($19) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $20 = (($3) - ($15))|0;
 $21 = (($20|0) / 20)&-1;
 $22 = ($21>>>0)<(107374182);
 $23 = $21 << 1;
 $24 = ($23>>>0)<($18>>>0);
 $$sroa$speculated$i = $24 ? $18 : $23;
 $$sroa$speculated$$i = $22 ? $$sroa$speculated$i : 214748364;
 $25 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($25) {
   $35 = 0;$95 = 0;
  } else {
   $26 = ($$sroa$speculated$$i>>>0)>(214748364);
   if (!($26)) {
    $32 = ($$sroa$speculated$$i*20)|0;
    $33 = (__Znwj($32)|0);
    $35 = $33;$95 = $33;
    break;
   }
   $27 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($27|0),(204840|0));
   $28 = __THREW__; __THREW__ = 0;
   $29 = $28&1;
   if ($29) {
    $30 = ___cxa_find_matching_catch_2()|0;
    $31 = tempRet0;
    ___cxa_free_exception(($27|0));
    ___resumeException($30|0);
    // unreachable;
   } else {
    HEAP32[$27>>2] = (99824);
    ___cxa_throw(($27|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $34 = (($35) + (($17*20)|0)|0);
 $36 = $34;
 $37 = (($35) + (($$sroa$speculated$$i*20)|0)|0);
 $$0$i13 = $1;$$in = $34;$$sroa$16$0 = $36;
 while(1) {
  ;HEAP32[$$in>>2]=0|0;HEAP32[$$in+4>>2]=0|0;HEAP32[$$in+8>>2]=0|0;HEAP32[$$in+12>>2]=0|0;HEAP32[$$in+16>>2]=0|0;
  $38 = $$sroa$16$0;
  $39 = ((($38)) + 20|0);
  $40 = $39;
  $41 = (($$0$i13) + -1)|0;
  $42 = ($41|0)==(0);
  if ($42) {
   break;
  } else {
   $$0$i13 = $41;$$in = $39;$$sroa$16$0 = $40;
  }
 }
 $43 = $37;
 $44 = HEAP32[$0>>2]|0;
 $45 = HEAP32[$4>>2]|0;
 $46 = ($45|0)==($44|0);
 do {
  if ($46) {
   $47 = $45;
   $48 = $44;
   $70 = $36;$71 = $48;$96 = $47;
  } else {
   $$06$i$i = $45;$$sroa$7$0 = $36;$51 = $34;
   while(1) {
    $49 = ((($$06$i$i)) + -20|0);
    $50 = ((($51)) + -20|0);
    __THREW__ = 0;
    invoke_vii(3457,($50|0),($49|0));
    $52 = __THREW__; __THREW__ = 0;
    $53 = $52&1;
    if ($53) {
     break;
    }
    $54 = ((($51)) + -8|0);
    $55 = ((($$06$i$i)) + -8|0);
    $56 = HEAP32[$55>>2]|0;
    HEAP32[$54>>2] = $56;
    $57 = ($56|0)==(0|0);
    if (!($57)) {
     $58 = ((($56)) + 8|0);
     $59 = HEAP32[$58>>2]|0;HEAP32[$58>>2] = (($59+1)|0);
    }
    $60 = ((($51)) + -4|0);
    $61 = ((($$06$i$i)) + -4|0);
    $62 = HEAP32[$61>>2]|0;
    HEAP32[$60>>2] = $62;
    $63 = ($62|0)==(0|0);
    if (!($63)) {
     $64 = ((($62)) + 8|0);
     $65 = HEAP32[$64>>2]|0;HEAP32[$64>>2] = (($65+1)|0);
    }
    $66 = $$sroa$7$0;
    $67 = ((($66)) + -20|0);
    $68 = $67;
    $69 = ($49|0)==($44|0);
    if ($69) {
     label = 22;
     break;
    } else {
     $$06$i$i = $49;$$sroa$7$0 = $68;$51 = $67;
    }
   }
   if ((label|0) == 22) {
    $$pre$i14 = HEAP32[$0>>2]|0;
    $$pre = HEAP32[$4>>2]|0;
    $70 = $68;$71 = $$pre$i14;$96 = $$pre;
    break;
   }
   $83 = ___cxa_find_matching_catch_2()|0;
   $84 = tempRet0;
   $85 = $$sroa$7$0;
   $$sroa$16$2 = $40;
   while(1) {
    $86 = $$sroa$16$2;
    $87 = ($86|0)==($85|0);
    if ($87) {
     break;
    }
    $88 = ((($86)) + -20|0);
    $89 = $88;
    __THREW__ = 0;
    invoke_vi(4255,($88|0));
    $90 = __THREW__; __THREW__ = 0;
    $91 = $90&1;
    if ($91) {
     label = 32;
     break;
    } else {
     $$sroa$16$2 = $89;
    }
   }
   if ((label|0) == 32) {
    $92 = ___cxa_find_matching_catch_2()|0;
    $93 = tempRet0;
    ___cxa_call_unexpected(($92|0));
    // unreachable;
   }
   $94 = ($35|0)==(0|0);
   if ($94) {
    ___resumeException($83|0);
    // unreachable;
   }
   __ZdlPv($95);
   ___resumeException($83|0);
   // unreachable;
  }
 } while(0);
 HEAP32[$0>>2] = $70;
 HEAP32[$4>>2] = $40;
 HEAP32[$2>>2] = $43;
 $72 = $71;
 $$sroa$16$1 = $96;
 while(1) {
  $73 = $$sroa$16$1;
  $74 = ($73|0)==($72|0);
  if ($74) {
   break;
  }
  $75 = ((($73)) + -20|0);
  $76 = $75;
  __THREW__ = 0;
  invoke_vi(4255,($75|0));
  $77 = __THREW__; __THREW__ = 0;
  $78 = $77&1;
  if ($78) {
   label = 26;
   break;
  } else {
   $$sroa$16$1 = $76;
  }
 }
 if ((label|0) == 26) {
  $79 = ___cxa_find_matching_catch_2()|0;
  $80 = tempRet0;
  ___cxa_call_unexpected(($79|0));
  // unreachable;
 }
 $81 = ($71|0)==(0);
 if ($81) {
  return;
 }
 $82 = $71;
 __ZdlPv($82);
 return;
}
function __ZN3osg13ImageSequence9ImageDataD2Ev($0) {
 $0 = $0|0;
 var $$0 = 0, $$02 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  label = 4;
 } else {
  $4 = ((($2)) + 8|0);
  $5 = HEAP32[$4>>2]|0;HEAP32[$4>>2] = (($5-1)|0);
  $6 = ($5|0)==(1);
  if ($6) {
   __THREW__ = 0;
   invoke_viii(3262,($2|0),1,1);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $21 = ___cxa_find_matching_catch_2()|0;
    $22 = tempRet0;
    $23 = ((($0)) + 12|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = ($24|0)==(0|0);
    if (!($25)) {
     $26 = ((($24)) + 8|0);
     $27 = HEAP32[$26>>2]|0;HEAP32[$26>>2] = (($27-1)|0);
     $28 = ($27|0)==(1);
     if ($28) {
      __THREW__ = 0;
      invoke_viii(3262,($24|0),1,1);
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if ($30) {
       $37 = ___cxa_find_matching_catch_3(0|0)|0;
       $38 = tempRet0;
       ___clang_call_terminate($37);
       // unreachable;
      }
     }
    }
    HEAP32[$23>>2] = 0;
    $$0 = $22;$$02 = $21;
   } else {
    label = 4;
   }
  } else {
   label = 4;
  }
 }
 do {
  if ((label|0) == 4) {
   HEAP32[$1>>2] = 0;
   $9 = ((($0)) + 12|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($10|0)==(0|0);
   if (!($11)) {
    $12 = ((($10)) + 8|0);
    $13 = HEAP32[$12>>2]|0;HEAP32[$12>>2] = (($13-1)|0);
    $14 = ($13|0)==(1);
    if ($14) {
     __THREW__ = 0;
     invoke_viii(3262,($10|0),1,1);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      $31 = ___cxa_find_matching_catch_2()|0;
      $32 = tempRet0;
      $$0 = $32;$$02 = $31;
      break;
     }
    }
   }
   HEAP32[$9>>2] = 0;
   $17 = ((($0)) + 11|0);
   $18 = HEAP8[$17>>0]|0;
   $19 = ($18<<24>>24)<(0);
   if (!($19)) {
    return;
   }
   $20 = HEAP32[$0>>2]|0;
   __ZdlPv($20);
   return;
  }
 } while(0);
 $33 = ((($0)) + 11|0);
 $34 = HEAP8[$33>>0]|0;
 $35 = ($34<<24>>24)<(0);
 if (!($35)) {
  ___resumeException($$02|0);
  // unreachable;
 }
 $36 = HEAP32[$0>>2]|0;
 __ZdlPv($36);
 ___resumeException($$02|0);
 // unreachable;
}
function __ZNSt3__26vectorIN3osg13ImageSequence9ImageDataENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$06$i$i = 0, $$pre = 0, $$pre$i = 0, $$sroa$16$0 = 0, $$sroa$16$1 = 0, $$sroa$16$2 = 0, $$sroa$7$0 = 0, $$sroa$7$1 = 0, $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = (($5|0) / 20)&-1;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(214748364);
 if ($8) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $9 = ((($0)) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) - ($4))|0;
 $12 = (($11|0) / 20)&-1;
 $13 = ($12>>>0)<(107374182);
 $14 = $12 << 1;
 $15 = ($14>>>0)<($7>>>0);
 $$sroa$speculated$i = $15 ? $7 : $14;
 $$sroa$speculated$$i = $13 ? $$sroa$speculated$i : 214748364;
 $16 = ($$sroa$speculated$$i|0)==(0);
 do {
  if ($16) {
   $26 = 0;$97 = 0;
  } else {
   $17 = ($$sroa$speculated$$i>>>0)>(214748364);
   if (!($17)) {
    $23 = ($$sroa$speculated$$i*20)|0;
    $24 = (__Znwj($23)|0);
    $26 = $24;$97 = $24;
    break;
   }
   $18 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($18|0),(204840|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if ($20) {
    $21 = ___cxa_find_matching_catch_2()|0;
    $22 = tempRet0;
    ___cxa_free_exception(($18|0));
    ___resumeException($21|0);
    // unreachable;
   } else {
    HEAP32[$18>>2] = (99824);
    ___cxa_throw(($18|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 $25 = (($26) + (($6*20)|0)|0);
 $27 = $25;
 $28 = (($26) + (($$sroa$speculated$$i*20)|0)|0);
 $29 = $28;
 __THREW__ = 0;
 invoke_vii(3457,($25|0),($1|0));
 $30 = __THREW__; __THREW__ = 0;
 $31 = $30&1;
 L13: do {
  if ($31) {
   $$sroa$16$1 = $27;$$sroa$7$1 = $27;
  } else {
   $32 = (((($26) + (($6*20)|0)|0)) + 12|0);
   $33 = ((($1)) + 12|0);
   $34 = HEAP32[$33>>2]|0;
   HEAP32[$32>>2] = $34;
   $35 = ($34|0)==(0|0);
   if (!($35)) {
    $36 = ((($34)) + 8|0);
    $37 = HEAP32[$36>>2]|0;HEAP32[$36>>2] = (($37+1)|0);
   }
   $38 = (((($26) + (($6*20)|0)|0)) + 16|0);
   $39 = ((($1)) + 16|0);
   $40 = HEAP32[$39>>2]|0;
   HEAP32[$38>>2] = $40;
   $41 = ($40|0)==(0|0);
   if (!($41)) {
    $42 = ((($40)) + 8|0);
    $43 = HEAP32[$42>>2]|0;HEAP32[$42>>2] = (($43+1)|0);
   }
   $44 = ((($25)) + 20|0);
   $45 = $44;
   $46 = HEAP32[$0>>2]|0;
   $47 = HEAP32[$2>>2]|0;
   $48 = ($47|0)==($46|0);
   if ($48) {
    $49 = $47;
    $50 = $46;
    $72 = $27;$73 = $50;$98 = $49;
   } else {
    $$06$i$i = $47;$$sroa$7$0 = $27;$53 = $25;
    while(1) {
     $51 = ((($$06$i$i)) + -20|0);
     $52 = ((($53)) + -20|0);
     __THREW__ = 0;
     invoke_vii(3457,($52|0),($51|0));
     $54 = __THREW__; __THREW__ = 0;
     $55 = $54&1;
     if ($55) {
      $$sroa$16$1 = $45;$$sroa$7$1 = $$sroa$7$0;
      break L13;
     }
     $56 = ((($53)) + -8|0);
     $57 = ((($$06$i$i)) + -8|0);
     $58 = HEAP32[$57>>2]|0;
     HEAP32[$56>>2] = $58;
     $59 = ($58|0)==(0|0);
     if (!($59)) {
      $60 = ((($58)) + 8|0);
      $61 = HEAP32[$60>>2]|0;HEAP32[$60>>2] = (($61+1)|0);
     }
     $62 = ((($53)) + -4|0);
     $63 = ((($$06$i$i)) + -4|0);
     $64 = HEAP32[$63>>2]|0;
     HEAP32[$62>>2] = $64;
     $65 = ($64|0)==(0|0);
     if (!($65)) {
      $66 = ((($64)) + 8|0);
      $67 = HEAP32[$66>>2]|0;HEAP32[$66>>2] = (($67+1)|0);
     }
     $68 = $$sroa$7$0;
     $69 = ((($68)) + -20|0);
     $70 = $69;
     $71 = ($51|0)==($46|0);
     if ($71) {
      break;
     } else {
      $$06$i$i = $51;$$sroa$7$0 = $70;$53 = $69;
     }
    }
    $$pre$i = HEAP32[$0>>2]|0;
    $$pre = HEAP32[$2>>2]|0;
    $72 = $70;$73 = $$pre$i;$98 = $$pre;
   }
   HEAP32[$0>>2] = $72;
   HEAP32[$2>>2] = $45;
   HEAP32[$9>>2] = $29;
   $74 = $73;
   $$sroa$16$0 = $98;
   while(1) {
    $75 = $$sroa$16$0;
    $76 = ($75|0)==($74|0);
    if ($76) {
     break;
    }
    $77 = ((($75)) + -20|0);
    $78 = $77;
    __THREW__ = 0;
    invoke_vi(4255,($77|0));
    $79 = __THREW__; __THREW__ = 0;
    $80 = $79&1;
    if ($80) {
     label = 26;
     break;
    } else {
     $$sroa$16$0 = $78;
    }
   }
   if ((label|0) == 26) {
    $81 = ___cxa_find_matching_catch_2()|0;
    $82 = tempRet0;
    ___cxa_call_unexpected(($81|0));
    // unreachable;
   }
   $83 = ($73|0)==(0);
   if ($83) {
    return;
   }
   $84 = $73;
   __ZdlPv($84);
   return;
  }
 } while(0);
 $85 = ___cxa_find_matching_catch_2()|0;
 $86 = tempRet0;
 $87 = $$sroa$7$1;
 $$sroa$16$2 = $$sroa$16$1;
 while(1) {
  $88 = $$sroa$16$2;
  $89 = ($88|0)==($87|0);
  if ($89) {
   break;
  }
  $90 = ((($88)) + -20|0);
  $91 = $90;
  __THREW__ = 0;
  invoke_vi(4255,($90|0));
  $92 = __THREW__; __THREW__ = 0;
  $93 = $92&1;
  if ($93) {
   label = 33;
   break;
  } else {
   $$sroa$16$2 = $91;
  }
 }
 if ((label|0) == 33) {
  $94 = ___cxa_find_matching_catch_2()|0;
  $95 = tempRet0;
  ___cxa_call_unexpected(($94|0));
  // unreachable;
 }
 $96 = ($26|0)==(0|0);
 if ($96) {
  ___resumeException($85|0);
  // unreachable;
 }
 __ZdlPv($97);
 ___resumeException($85|0);
 // unreachable;
}
function __ZN3osg13ImageSequence8setImageEjPNS_5ImageE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 200|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($4)) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 (FUNCTION_TABLE_ii[$6 & 8191]($3)|0);
 __THREW__ = 0;
 invoke_viii(4256,($0|0),($1|0),($2|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if (!($8)) {
  $9 = HEAP32[$3>>2]|0;
  $10 = ((($9)) + 12|0);
  $11 = HEAP32[$10>>2]|0;
  (FUNCTION_TABLE_ii[$11 & 8191]($3)|0);
  return;
 }
 $12 = ___cxa_find_matching_catch_2()|0;
 $13 = tempRet0;
 $14 = HEAP32[$3>>2]|0;
 $15 = ((($14)) + 12|0);
 $16 = HEAP32[$15>>2]|0;
 __THREW__ = 0;
 (invoke_ii($16|0,($3|0))|0);
 $17 = __THREW__; __THREW__ = 0;
 $18 = $17&1;
 if ($18) {
  $19 = ___cxa_find_matching_catch_3(0|0)|0;
  $20 = tempRet0;
  ___clang_call_terminate($19);
  // unreachable;
 } else {
  ___resumeException($12|0);
  // unreachable;
 }
}
function __ZN3osg13ImageSequence8addImageEPNS_5ImageE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$04 = 0, $$1 = 0, $$15 = 0, $$sink$i = 0.0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0.0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0.0, $57 = 0.0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $2 = sp;
 $3 = ($1|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = ((($0)) + 200|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($5)) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 (FUNCTION_TABLE_ii[$7 & 8191]($4)|0);
 ;HEAP32[$2>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;HEAP32[$2+12>>2]=0|0;HEAP32[$2+16>>2]=0|0;
 $8 = ((($0)) + 216|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($0)) + 220|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($9|0)==($11|0);
 if ($12) {
  $29 = ((($0)) + 212|0);
  __THREW__ = 0;
  invoke_vii(4257,($29|0),($2|0));
  $30 = __THREW__; __THREW__ = 0;
  $31 = $30&1;
  if ($31) {
   label = 20;
  } else {
   label = 10;
  }
 } else {
  __THREW__ = 0;
  invoke_vii(3457,($9|0),($2|0));
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if ($14) {
   label = 20;
  } else {
   $15 = ((($9)) + 12|0);
   $16 = ((($2)) + 12|0);
   $17 = HEAP32[$16>>2]|0;
   HEAP32[$15>>2] = $17;
   $18 = ($17|0)==(0|0);
   if (!($18)) {
    $19 = ((($17)) + 8|0);
    $20 = HEAP32[$19>>2]|0;HEAP32[$19>>2] = (($20+1)|0);
   }
   $21 = ((($9)) + 16|0);
   $22 = ((($2)) + 16|0);
   $23 = HEAP32[$22>>2]|0;
   HEAP32[$21>>2] = $23;
   $24 = ($23|0)==(0|0);
   if (!($24)) {
    $25 = ((($23)) + 8|0);
    $26 = HEAP32[$25>>2]|0;HEAP32[$25>>2] = (($26+1)|0);
   }
   $27 = HEAP32[$8>>2]|0;
   $28 = ((($27)) + 20|0);
   HEAP32[$8>>2] = $28;
   label = 10;
  }
 }
 do {
  if ((label|0) == 10) {
   __THREW__ = 0;
   invoke_vi(4255,($2|0));
   $32 = __THREW__; __THREW__ = 0;
   $33 = $32&1;
   if ($33) {
    $67 = ___cxa_find_matching_catch_2()|0;
    $68 = tempRet0;
    $$0 = $68;$$04 = $67;
    label = 21;
    break;
   }
   $34 = HEAP32[$8>>2]|0;
   $35 = ((($34)) + -8|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = ($36|0)==($1|0);
   if ($37) {
    label = 15;
   } else {
    HEAP32[$35>>2] = $1;
    $38 = ((($1)) + 8|0);
    $39 = HEAP32[$38>>2]|0;HEAP32[$38>>2] = (($39+1)|0);
    $40 = ($36|0)==(0|0);
    if ($40) {
     label = 15;
    } else {
     $41 = ((($36)) + 8|0);
     $42 = HEAP32[$41>>2]|0;HEAP32[$41>>2] = (($42-1)|0);
     $43 = ($42|0)==(1);
     if ($43) {
      __THREW__ = 0;
      invoke_viii(3262,($36|0),1,1);
      $44 = __THREW__; __THREW__ = 0;
      $45 = $44&1;
      if (!($45)) {
       label = 15;
      }
     } else {
      label = 15;
     }
    }
   }
   do {
    if ((label|0) == 15) {
     $46 = ((($0)) + 212|0);
     $47 = HEAP32[$46>>2]|0;
     $48 = HEAP32[$8>>2]|0;
     $49 = ($47|0)==($48|0);
     $50 = ((($0)) + 184|0);
     $51 = +HEAPF64[$50>>3];
     $52 = $48;
     $53 = $47;
     if ($49) {
      $$sink$i = $51;
     } else {
      $54 = (($52) - ($53))|0;
      $55 = (($54|0) / 20)&-1;
      $56 = (+($55>>>0));
      $57 = $51 / $56;
      $$sink$i = $57;
     }
     $58 = ((($0)) + 192|0);
     HEAPF64[$58>>3] = $$sink$i;
     $59 = ((($0)) + 112|0);
     $60 = HEAP32[$59>>2]|0;
     $61 = ($60|0)==(0|0);
     if ($61) {
      $62 = (($52) - ($53))|0;
      $63 = (($62|0) / 20)&-1;
      $64 = (($63) + -1)|0;
      __THREW__ = 0;
      invoke_vii(4258,($0|0),($64|0));
      $65 = __THREW__; __THREW__ = 0;
      $66 = $65&1;
      if ($66) {
       break;
      }
     }
     $75 = HEAP32[$4>>2]|0;
     $76 = ((($75)) + 12|0);
     $77 = HEAP32[$76>>2]|0;
     (FUNCTION_TABLE_ii[$77 & 8191]($4)|0);
     STACKTOP = sp;return;
    }
   } while(0);
   $73 = ___cxa_find_matching_catch_2()|0;
   $74 = tempRet0;
   $$1 = $74;$$15 = $73;
  }
  else if ((label|0) == 20) {
   $69 = ___cxa_find_matching_catch_2()|0;
   $70 = tempRet0;
   __THREW__ = 0;
   invoke_vi(4255,($2|0));
   $71 = __THREW__; __THREW__ = 0;
   $72 = $71&1;
   if ($72) {
    $83 = ___cxa_find_matching_catch_3(0|0)|0;
    $84 = tempRet0;
    ___clang_call_terminate($83);
    // unreachable;
   } else {
    $$0 = $70;$$04 = $69;
    label = 21;
   }
  }
 } while(0);
 if ((label|0) == 21) {
  $$1 = $$0;$$15 = $$04;
 }
 $78 = HEAP32[$4>>2]|0;
 $79 = ((($78)) + 12|0);
 $80 = HEAP32[$79>>2]|0;
 __THREW__ = 0;
 (invoke_ii($80|0,($4|0))|0);
 $81 = __THREW__; __THREW__ = 0;
 $82 = $81&1;
 if ($82) {
  $83 = ___cxa_find_matching_catch_3(0|0)|0;
  $84 = tempRet0;
  ___clang_call_terminate($83);
  // unreachable;
 } else {
  ___resumeException($$15|0);
  // unreachable;
 }
}
function __ZN3osg13ShapeDrawableD2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (76300);
 $1 = ((($0)) + 292|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  HEAP32[$1>>2] = 0;
  __ZN3osg8GeometryD2Ev($0);
  return;
 }
 $4 = ((($2)) + 8|0);
 $5 = HEAP32[$4>>2]|0;HEAP32[$4>>2] = (($5-1)|0);
 $6 = ($5|0)==(1);
 if (!($6)) {
  HEAP32[$1>>2] = 0;
  __ZN3osg8GeometryD2Ev($0);
  return;
 }
 __THREW__ = 0;
 invoke_viii(3262,($2|0),1,1);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if (!($8)) {
  HEAP32[$1>>2] = 0;
  __ZN3osg8GeometryD2Ev($0);
  return;
 }
 $9 = ___cxa_find_matching_catch_2()|0;
 $10 = tempRet0;
 __THREW__ = 0;
 invoke_vi(1754,($0|0));
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if ($12) {
  $13 = ___cxa_find_matching_catch_3(0|0)|0;
  $14 = tempRet0;
  ___clang_call_terminate($13);
  // unreachable;
 } else {
  ___resumeException($9|0);
  // unreachable;
 }
}
function __ZN3osg13ShapeDrawableD0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (76300);
 $1 = ((($0)) + 292|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = ((($2)) + 8|0);
  $5 = HEAP32[$4>>2]|0;HEAP32[$4>>2] = (($5-1)|0);
  $6 = ($5|0)==(1);
  if ($6) {
   __THREW__ = 0;
   invoke_viii(3262,($2|0),1,1);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch_2()|0;
    $12 = tempRet0;
    __THREW__ = 0;
    invoke_vi(1754,($0|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     $15 = ___cxa_find_matching_catch_3(0|0)|0;
     $16 = tempRet0;
     ___clang_call_terminate($15);
     // unreachable;
    } else {
     $eh$lpad$body$index2Z2D = $12;$eh$lpad$body$indexZ2D = $11;
     __ZdlPv($0);
     ___resumeException($eh$lpad$body$indexZ2D|0);
     // unreachable;
    }
   }
  }
 }
 HEAP32[$1>>2] = 0;
 __THREW__ = 0;
 invoke_vi(1754,($0|0));
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if (!($10)) {
  __ZdlPv($0);
  return;
 }
 $17 = ___cxa_find_matching_catch_2()|0;
 $18 = tempRet0;
 $eh$lpad$body$index2Z2D = $18;$eh$lpad$body$indexZ2D = $17;
 __ZdlPv($0);
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
}
function __ZNK3osg13ShapeDrawable9cloneTypeEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj(296)|0);
 __THREW__ = 0;
 invoke_vi(3485,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $9 = ___cxa_find_matching_catch_2()|0;
  $10 = tempRet0;
  __ZdlPv($1);
  ___resumeException($9|0);
  // unreachable;
 } else {
  HEAP32[$1>>2] = (76300);
  $4 = ((($1)) + 276|0);
  HEAPF32[$4>>2] = 1.0;
  $5 = ((($1)) + 280|0);
  HEAPF32[$5>>2] = 1.0;
  $6 = ((($1)) + 284|0);
  HEAPF32[$6>>2] = 1.0;
  $7 = ((($1)) + 288|0);
  HEAPF32[$7>>2] = 1.0;
  $8 = ((($1)) + 292|0);
  HEAP32[$8>>2] = 0;
  return ($1|0);
 }
 return (0)|0;
}
function __ZNK3osg13ShapeDrawable5cloneERKNS_6CopyOpE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__Znwj(296)|0);
 __THREW__ = 0;
 invoke_viii(3765,($2|0),($0|0),($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $13 = ___cxa_find_matching_catch_2()|0;
  $14 = tempRet0;
  __ZdlPv($2);
  ___resumeException($13|0);
  // unreachable;
 }
 HEAP32[$2>>2] = (76300);
 $5 = ((($2)) + 276|0);
 $6 = ((($0)) + 276|0);
 ;HEAP32[$5>>2]=HEAP32[$6>>2]|0;HEAP32[$5+4>>2]=HEAP32[$6+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$6+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$6+12>>2]|0;
 $7 = ((($2)) + 292|0);
 $8 = ((($0)) + 292|0);
 $9 = HEAP32[$8>>2]|0;
 HEAP32[$7>>2] = $9;
 $10 = ($9|0)==(0|0);
 if ($10) {
  return ($2|0);
 }
 $11 = ((($9)) + 8|0);
 $12 = HEAP32[$11>>2]|0;HEAP32[$11>>2] = (($12+1)|0);
 return ($2|0);
}
function __ZNK3osg13ShapeDrawable12isSameKindAsEPKNS_6ObjectE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  return ($4|0);
 }
 $3 = (___dynamic_cast($1,26112,32976,0)|0);
 $phitmp = ($3|0)!=(0|0);
 $4 = $phitmp;
 return ($4|0);
}
function __ZNK3osg13ShapeDrawable11libraryNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175113|0);
}
function __ZNK3osg13ShapeDrawable9classNameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (175099|0);
}
function __ZN3osg13ShapeDrawable8setShapeEPNS_5ShapeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 176|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==($1|0);
 if ($4) {
  return;
 }
 HEAP32[$2>>2] = $1;
 $5 = ($1|0)==(0|0);
 if (!($5)) {
  $6 = ((($1)) + 8|0);
  $7 = HEAP32[$6>>2]|0;HEAP32[$6>>2] = (($7+1)|0);
 }
 $8 = ($3|0)==(0|0);
 if (!($8)) {
  $9 = ((($3)) + 8|0);
  $10 = HEAP32[$9>>2]|0;HEAP32[$9>>2] = (($10-1)|0);
  $11 = ($10|0)==(1);
  if ($11) {
   __ZNK3osg10Referenced24signalObserversAndDeleteEbb($3,1,1);
  }
 }
 __ZN3osg13ShapeDrawable5buildEv($0);
 return;
}
function __ZN3osg13ShapeDrawable5buildEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 288|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(288|0);
 $1 = sp;
 __ZN3osg8Geometry14setVertexArrayEPNS_5ArrayE($0,0);
 __ZN3osg8Geometry14setNormalArrayEPNS_5ArrayENS1_7BindingE($0,0,-1);
 __ZN3osg8Geometry13setColorArrayEPNS_5ArrayENS1_7BindingE($0,0,-1);
 __ZN3osg8Geometry22setSecondaryColorArrayEPNS_5ArrayENS1_7BindingE($0,0,-1);
 __ZN3osg8Geometry16setFogCoordArrayEPNS_5ArrayENS1_7BindingE($0,0,-1);
 $2 = ((($0)) + 248|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 252|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==($3|0);
 L1: do {
  if (!($6)) {
   $8 = $5;
   while(1) {
    $7 = ((($8)) + -4|0);
    HEAP32[$4>>2] = $7;
    $9 = HEAP32[$7>>2]|0;
    $10 = ($9|0)==(0|0);
    if (!($10)) {
     $11 = ((($9)) + 8|0);
     $12 = HEAP32[$11>>2]|0;HEAP32[$11>>2] = (($12-1)|0);
     $13 = ($12|0)==(1);
     if ($13) {
      __THREW__ = 0;
      invoke_viii(3262,($9|0),1,1);
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if ($15) {
       break;
      }
     }
    }
    HEAP32[$7>>2] = 0;
    $16 = HEAP32[$4>>2]|0;
    $17 = ($16|0)==($3|0);
    if ($17) {
     break L1;
    } else {
     $8 = $16;
    }
   }
   $18 = ___cxa_find_matching_catch_2()|0;
   $19 = tempRet0;
   ___cxa_call_unexpected(($18|0));
   // unreachable;
  }
 } while(0);
 $20 = ((($0)) + 260|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ((($0)) + 264|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)==($21|0);
 L10: do {
  if (!($24)) {
   $26 = $23;
   while(1) {
    $25 = ((($26)) + -4|0);
    HEAP32[$22>>2] = $25;
    $27 = HEAP32[$25>>2]|0;
    $28 = ($27|0)==(0|0);
    if (!($28)) {
     $29 = ((($27)) + 8|0);
     $30 = HEAP32[$29>>2]|0;HEAP32[$29>>2] = (($30-1)|0);
     $31 = ($30|0)==(1);
     if ($31) {
      __THREW__ = 0;
      invoke_viii(3262,($27|0),1,1);
      $32 = __THREW__; __THREW__ = 0;
      $33 = $32&1;
      if ($33) {
       break;
      }
     }
    }
    HEAP32[$25>>2] = 0;
    $34 = HEAP32[$22>>2]|0;
    $35 = ($34|0)==($21|0);
    if ($35) {
     break L10;
    } else {
     $26 = $34;
    }
   }
   $36 = ___cxa_find_matching_catch_2()|0;
   $37 = tempRet0;
   ___cxa_call_unexpected(($36|0));
   // unreachable;
  }
 } while(0);
 $38 = ((($0)) + 216|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = ((($0)) + 220|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = ($41|0)==($39|0);
 L19: do {
  if (!($42)) {
   $44 = $41;
   while(1) {
    $43 = ((($44)) + -4|0);
    HEAP32[$40>>2] = $43;
    $45 = HEAP32[$43>>2]|0;
    $46 = ($45|0)==(0|0);
    if (!($46)) {
     $47 = ((($45)) + 8|0);
     $48 = HEAP32[$47>>2]|0;HEAP32[$47>>2] = (($48-1)|0);
     $49 = ($48|0)==(1);
     if ($49) {
      __THREW__ = 0;
      invoke_viii(3262,($45|0),1,1);
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       break;
      }
     }
    }
    HEAP32[$43>>2] = 0;
    $52 = HEAP32[$40>>2]|0;
    $53 = ($52|0)==($39|0);
    if ($53) {
     break L19;
    } else {
     $44 = $52;
    }
   }
   $54 = ___cxa_find_matching_catch_2()|0;
   $55 = tempRet0;
   ___cxa_call_unexpected(($54|0));
   // unreachable;
  }
 } while(0);
 $56 = ((($0)) + 176|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = ($57|0)==(0|0);
 if ($58) {
  $71 = ((($0)) + 276|0);
  __ZN3osg13ShapeDrawable8setColorERKNS_5Vec4fE($0,$71);
  STACKTOP = sp;return;
 }
 $59 = ((($0)) + 292|0);
 $60 = HEAP32[$59>>2]|0;
 __ZN3osg25BuildShapeGeometryVisitorC2EPNS_8GeometryEPKNS_17TessellationHintsE($1,$0,$60);
 $61 = HEAP32[$56>>2]|0;
 $62 = HEAP32[$61>>2]|0;
 $63 = ((($62)) + 144|0);
 $64 = HEAP32[$63>>2]|0;
 __THREW__ = 0;
 invoke_vii($64|0,($61|0),($1|0));
 $65 = __THREW__; __THREW__ = 0;
 $66 = $65&1;
 if (!($66)) {
  __ZN3osg25BuildShapeGeometryVisitorD2Ev($1);
  $71 = ((($0)) + 276|0);
  __ZN3osg13ShapeDrawable8setColorERKNS_5Vec4fE($0,$71);
  STACKTOP = sp;return;
 }
 $67 = ___cxa_find_matching_catch_2()|0;
 $68 = tempRet0;
 __THREW__ = 0;
 invoke_vi(2226,($1|0));
 $69 = __THREW__; __THREW__ = 0;
 $70 = $69&1;
 if ($70) {
  $72 = ___cxa_find_matching_catch_3(0|0)|0;
  $73 = tempRet0;
  ___clang_call_terminate($72);
  // unreachable;
 } else {
  ___resumeException($67|0);
  // unreachable;
 }
}
function __ZN3osg13ShapeDrawable8setColorERKNS_5Vec4fE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$sroa$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$sroa$0 = sp;
 $2 = ((($0)) + 276|0);
 ;HEAP32[$2>>2]=HEAP32[$1>>2]|0;HEAP32[$2+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$1+12>>2]|0;
 $3 = ((($0)) + 236|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  label = 5;
 } else {
  $6 = (___dynamic_cast($4,23016,5416,0)|0);
  $7 = ($6|0)==(0|0);
  if ($7) {
   label = 5;
  } else {
   $8 = ((($6)) + 76|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = ((($6)) + 80|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = ($9|0)==($11|0);
   if ($12) {
    label = 5;
   } else {
    $13 = ((($6)) + 64|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ($14|0)==(1);
    if ($15) {
     $$0 = $6;$54 = $6;
    } else {
     label = 5;
    }
   }
  }
 }
 if ((label|0) == 5) {
  $16 = (__Znwj(88)|0);
  __THREW__ = 0;
  invoke_vii(3435,($16|0),1);
  $17 = __THREW__; __THREW__ = 0;
  $18 = $17&1;
  if ($18) {
   $51 = ___cxa_find_matching_catch_2()|0;
   $52 = tempRet0;
   $eh$lpad$body$index2Z2D = $52;$eh$lpad$body$indexZ2D = $51;
   __ZdlPv($16);
   ___resumeException($eh$lpad$body$indexZ2D|0);
   // unreachable;
  }
  $19 = ((($16)) + 12|0);
  ;HEAP32[$19>>2]=0|0;HEAP32[$19+4>>2]=0|0;HEAP32[$19+8>>2]=0|0;
  $20 = ((($16)) + 24|0);
  HEAP32[$20>>2] = 2;
  $21 = ((($16)) + 28|0);
  ;HEAP32[$21>>2]=0|0;HEAP32[$21+4>>2]=0|0;HEAP32[$21+8>>2]=0|0;HEAP32[$21+12>>2]=0|0;HEAP32[$21+16>>2]=0|0;HEAP32[$21+20>>2]=0|0;
  HEAP32[$16>>2] = (54500);
  $22 = ((($16)) + 52|0);
  HEAP32[$22>>2] = 29;
  $23 = ((($16)) + 56|0);
  HEAP32[$23>>2] = 4;
  $24 = ((($16)) + 60|0);
  HEAP32[$24>>2] = 5126;
  $25 = ((($16)) + 64|0);
  HEAP32[$25>>2] = 1;
  $26 = ((($16)) + 68|0);
  HEAP8[$26>>0] = 0;
  $27 = ((($16)) + 69|0);
  HEAP8[$27>>0] = 0;
  $28 = ((($16)) + 72|0);
  ;HEAP32[$$sroa$0>>2]=0|0;HEAP32[$$sroa$0+4>>2]=0|0;HEAP32[$$sroa$0+8>>2]=0|0;HEAP32[$$sroa$0+12>>2]=0|0;
  HEAP32[$28>>2] = (38520);
  $29 = ((($16)) + 76|0);
  HEAP32[$29>>2] = 0;
  $30 = ((($16)) + 80|0);
  HEAP32[$30>>2] = 0;
  $31 = ((($16)) + 84|0);
  HEAP32[$31>>2] = 0;
  __THREW__ = 0;
  $32 = (invoke_ii(3276,16)|0);
  $33 = __THREW__; __THREW__ = 0;
  $34 = $33&1;
  if ($34) {
   $39 = ___cxa_find_matching_catch_2()|0;
   $40 = tempRet0;
   __THREW__ = 0;
   invoke_vi(1265,($16|0));
   $41 = __THREW__; __THREW__ = 0;
   $42 = $41&1;
   if ($42) {
    $43 = ___cxa_find_matching_catch_3(0|0)|0;
    $44 = tempRet0;
    ___clang_call_terminate($43);
    // unreachable;
   } else {
    $eh$lpad$body$index2Z2D = $40;$eh$lpad$body$indexZ2D = $39;
    __ZdlPv($16);
    ___resumeException($eh$lpad$body$indexZ2D|0);
    // unreachable;
   }
  }
  HEAP32[$29>>2] = $32;
  $35 = ((($32)) + 16|0);
  HEAP32[$31>>2] = $35;
  ;HEAP32[$32>>2]=HEAP32[$$sroa$0>>2]|0;HEAP32[$32+4>>2]=HEAP32[$$sroa$0+4>>2]|0;HEAP32[$32+8>>2]=HEAP32[$$sroa$0+8>>2]|0;HEAP32[$32+12>>2]=HEAP32[$$sroa$0+12>>2]|0;
  $36 = ((($32)) + 16|0);
  HEAP32[$30>>2] = $36;
  HEAP32[$16>>2] = (38280);
  HEAP32[$28>>2] = (38504);
  $37 = HEAP32[$3>>2]|0;
  $38 = ($37|0)==($16|0);
  if ($38) {
   $$0 = $16;$54 = $16;
  } else {
   HEAP32[$3>>2] = $16;
   $45 = ((($16)) + 8|0);
   $46 = HEAP32[$45>>2]|0;HEAP32[$45>>2] = (($46+1)|0);
   $47 = ($37|0)==(0|0);
   if ($47) {
    $$0 = $16;$54 = $16;
   } else {
    $48 = ((($37)) + 8|0);
    $49 = HEAP32[$48>>2]|0;HEAP32[$48>>2] = (($49-1)|0);
    $50 = ($49|0)==(1);
    if ($50) {
     __ZNK3osg10Referenced24signalObserversAndDeleteEbb($37,1,1);
     $$0 = $16;$54 = $16;
    } else {
     $$0 = $16;$54 = $16;
    }
   }
  }
 }
 $53 = ((($54)) + 76|0);
 $55 = HEAP32[$53>>2]|0;
 ;HEAP32[$55>>2]=HEAP32[$1>>2]|0;HEAP32[$55+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$55+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$55+12>>2]=HEAP32[$1+12>>2]|0;
 $56 = ((($$0)) + 32|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = (($57) + 1)|0;
 HEAP32[$56>>2] = $58;
 $59 = ((($$0)) + 44|0);
 $60 = HEAP32[$59>>2]|0;
 $61 = ($60|0)==(0|0);
 if (!($61)) {
  $62 = HEAP32[$60>>2]|0;
  $63 = ((($62)) + 20|0);
  $64 = HEAP32[$63>>2]|0;
  FUNCTION_TABLE_vii[$64 & 8191]($60,$$0);
 }
 $65 = ((($$0)) + 40|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = ($66|0)==(0|0);
 if ($67) {
  $68 = HEAP32[$0>>2]|0;
  $69 = ((($68)) + 220|0);
  $70 = HEAP32[$69>>2]|0;
  FUNCTION_TABLE_vi[$70 & 8191]($0);
  STACKTOP = sp;return;
 }
 __ZN3osg12BufferObject5dirtyEv($66);
 $68 = HEAP32[$0>>2]|0;
 $69 = ((($68)) + 220|0);
 $70 = HEAP32[$69>>2]|0;
 FUNCTION_TABLE_vi[$70 & 8191]($0);
 STACKTOP = sp;return;
}
function __ZN3osg13ShapeDrawableC2EPNS_5ShapeEPNS_17TessellationHintsE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$pre = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN3osg8GeometryC2Ev($0);
 HEAP32[$0>>2] = (76300);
 $3 = ((($0)) + 276|0);
 HEAPF32[$3>>2] = 1.0;
 $4 = ((($0)) + 280|0);
 HEAPF32[$4>>2] = 1.0;
 $5 = ((($0)) + 284|0);
 HEAPF32[$5>>2] = 1.0;
 $6 = ((($0)) + 288|0);
 HEAPF32[$6>>2] = 1.0;
 $7 = ((($0)) + 292|0);
 HEAP32[$7>>2] = $2;
 $8 = ($2|0)==(0|0);
 if ($8) {
  $12 = (76300);
 } else {
  $9 = ((($2)) + 8|0);
  $10 = HEAP32[$9>>2]|0;HEAP32[$9>>2] = (($10+1)|0);
  $$pre = HEAP32[$0>>2]|0;
  $12 = $$pre;
 }
 $11 = ((($12)) + 208|0);
 $13 = HEAP32[$11>>2]|0;
 __THREW__ = 0;
 invoke_vii($13|0,($0|0),($1|0));
 $14 = __THREW__; __THREW__ = 0;
 $15 = $14&1;
 if (!($15)) {
  return;
 }
 $16 = ___cxa_find_matching_catch_2()|0;
 $17 = tempRet0;
 $18 = HEAP32[$7>>2]|0;
 $19 = ($18|0)==(0|0);
 if (!($19)) {
  $20 = ((($18)) + 8|0);
  $21 = HEAP32[$20>>2]|0;HEAP32[$20>>2] = (($21-1)|0);
  $22 = ($21|0)==(1);
  if ($22) {
   __THREW__ = 0;
   invoke_viii(3262,($18|0),1,1);
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if ($24) {
    $27 = ___cxa_find_matching_catch_3(0|0)|0;
    $28 = tempRet0;
    ___clang_call_terminate($27);
    // unreachable;
   }
  }
 }
 HEAP32[$7>>2] = 0;
 __THREW__ = 0;
 invoke_vi(1754,($0|0));
 $25 = __THREW__; __THREW__ = 0;
 $26 = $25&1;
 if ($26) {
  $27 = ___cxa_find_matching_catch_3(0|0)|0;
  $28 = tempRet0;
  ___clang_call_terminate($27);
  // unreachable;
 } else {
  ___resumeException($16|0);
  // unreachable;
 }
}
function _osgGetVersion() {
 var $0 = 0, $1 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $0 = HEAP32[19144]|0;
 $1 = ($0|0)==(0);
 if ($1) {
  STACKTOP = sp;return (217120|0);
 }
 HEAP32[$vararg_buffer>>2] = 3;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 5;
 $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
 HEAP32[$vararg_ptr2>>2] = 7;
 (_sprintf(217120,175139,$vararg_buffer)|0);
 HEAP32[19144] = 0;
 STACKTOP = sp;return (217120|0);
}
function _GLES2_CreateRenderer($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$0$i$i$i = 0, $$0211$i$i = 0, $$088 = 0, $$122$i$i = 0, $$pre = 0, $$pre$i$i = 0, $$sink$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0;
 var $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0;
 var $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0;
 var $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0;
 var $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0;
 var $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0;
 var $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0;
 var $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0;
 var $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0;
 var $309 = 0.0, $31 = 0, $310 = 0.0, $311 = 0, $312 = 0, $313 = 0.0, $314 = 0.0, $315 = 0, $316 = 0, $317 = 0.0, $318 = 0.0, $319 = 0, $32 = 0, $320 = 0, $321 = 0.0, $322 = 0.0, $323 = 0, $324 = 0, $325 = 0, $326 = 0;
 var $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0;
 var $345 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $or$cond3 = 0, $or$cond5 = 0, $vararg_buffer = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, $vararg_ptr6 = 0;
 var $vararg_ptr7 = 0, $vararg_ptr8 = 0, $vararg_ptr9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(64|0);
 $vararg_buffer2 = sp + 8|0;
 $vararg_buffer = sp;
 $2 = sp + 52|0;
 $3 = sp + 56|0;
 $4 = sp + 48|0;
 $5 = sp + 44|0;
 $6 = sp + 40|0;
 $7 = sp + 36|0;
 $8 = sp + 32|0;
 HEAP32[$6>>2] = 0;
 HEAP32[$7>>2] = 0;
 HEAP32[$8>>2] = 0;
 $9 = (_SDL_GL_GetAttribute(21,$6)|0);
 $10 = ($9|0)<(0);
 if ($10) {
  $$088 = 0;
  STACKTOP = sp;return ($$088|0);
 }
 $11 = (_SDL_GL_GetAttribute(17,$7)|0);
 $12 = ($11|0)<(0);
 if ($12) {
  $$088 = 0;
  STACKTOP = sp;return ($$088|0);
 }
 $13 = (_SDL_GL_GetAttribute(18,$8)|0);
 $14 = ($13|0)<(0);
 if ($14) {
  $$088 = 0;
  STACKTOP = sp;return ($$088|0);
 }
 $15 = (_SDL_GetWindowFlags($0)|0);
 $16 = $15 & 2;
 $17 = ($16|0)==(0);
 $18 = HEAP32[$6>>2]|0;
 $19 = ($18|0)!=(4);
 $or$cond = $17 | $19;
 $20 = HEAP32[$7>>2]|0;
 $21 = ($20|0)!=(2);
 $or$cond3 = $or$cond | $21;
 $22 = HEAP32[$8>>2]|0;
 $23 = ($22|0)!=(0);
 $or$cond5 = $or$cond3 | $23;
 if ($or$cond5) {
  (_SDL_GL_SetAttribute(21,4)|0);
  (_SDL_GL_SetAttribute(17,2)|0);
  (_SDL_GL_SetAttribute(18,0)|0);
  $24 = $15 | 2;
  $25 = (_SDL_RecreateWindow($0,$24)|0);
  $26 = ($25|0)<(0);
  if (!($26)) {
   $$0 = 1;
   label = 6;
  }
 } else {
  $$0 = 0;
  label = 6;
 }
 if ((label|0) == 6) {
  $27 = (_SDL_calloc(1,324)|0);
  $28 = ($27|0)==(0|0);
  do {
   if ($28) {
    (_SDL_Error(0)|0);
   } else {
    $29 = (_SDL_calloc(1,308)|0);
    $30 = ($29|0)==(0|0);
    if ($30) {
     _GLES2_DestroyRenderer($27);
     (_SDL_Error(0)|0);
     break;
    }
    $31 = ((($27)) + 104|0);
    dest=$31; src=(76584); stop=dest+84|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
    $32 = ((($27)) + 108|0);
    HEAP32[$32>>2] = 10;
    $33 = ((($27)) + 320|0);
    HEAP32[$33>>2] = $29;
    $34 = ((($27)) + 188|0);
    HEAP32[$34>>2] = $0;
    $35 = (_SDL_GL_CreateContext($0)|0);
    HEAP32[$29>>2] = $35;
    $36 = ($35|0)==(0|0);
    if ($36) {
     _GLES2_DestroyRenderer($27);
     break;
    }
    $37 = (_SDL_GL_MakeCurrent($0,$35)|0);
    $38 = ($37|0)<(0);
    if ($38) {
     _GLES2_DestroyRenderer($27);
     break;
    }
    $39 = (_SDL_GL_GetProcAddress(198446)|0);
    $40 = ((($29)) + 16|0);
    HEAP32[$40>>2] = $39;
    $41 = ($39|0)==(0|0);
    do {
     if ($41) {
      $$sink$i = 198446;
      label = 68;
     } else {
      $42 = (_SDL_GL_GetProcAddress(196220)|0);
      $43 = ((($29)) + 20|0);
      HEAP32[$43>>2] = $42;
      $44 = ($42|0)==(0|0);
      if ($44) {
       $$sink$i = 196220;
       label = 68;
      } else {
       $45 = (_SDL_GL_GetProcAddress(197518)|0);
       $46 = ((($29)) + 24|0);
       HEAP32[$46>>2] = $45;
       $47 = ($45|0)==(0|0);
       if ($47) {
        $$sink$i = 197518;
        label = 68;
       } else {
        $48 = (_SDL_GL_GetProcAddress(196453)|0);
        $49 = ((($29)) + 28|0);
        HEAP32[$49>>2] = $48;
        $50 = ($48|0)==(0|0);
        if ($50) {
         $$sink$i = 196453;
         label = 68;
        } else {
         $51 = (_SDL_GL_GetProcAddress(198792)|0);
         $52 = ((($29)) + 32|0);
         HEAP32[$52>>2] = $51;
         $53 = ($51|0)==(0|0);
         if ($53) {
          $$sink$i = 198792;
          label = 68;
         } else {
          $54 = (_SDL_GL_GetProcAddress(198343)|0);
          $55 = ((($29)) + 36|0);
          HEAP32[$55>>2] = $54;
          $56 = ($54|0)==(0|0);
          if ($56) {
           $$sink$i = 198343;
           label = 68;
          } else {
           $57 = (_SDL_GL_GetProcAddress(198718)|0);
           $58 = ((($29)) + 40|0);
           HEAP32[$58>>2] = $57;
           $59 = ($57|0)==(0|0);
           if ($59) {
            $$sink$i = 198718;
            label = 68;
           } else {
            $60 = (_SDL_GL_GetProcAddress(197336)|0);
            $61 = ((($29)) + 44|0);
            HEAP32[$61>>2] = $60;
            $62 = ($60|0)==(0|0);
            if ($62) {
             $$sink$i = 197336;
             label = 68;
            } else {
             $63 = (_SDL_GL_GetProcAddress(196121)|0);
             $64 = ((($29)) + 48|0);
             HEAP32[$64>>2] = $63;
             $65 = ($63|0)==(0|0);
             if ($65) {
              $$sink$i = 196121;
              label = 68;
             } else {
              $66 = (_SDL_GL_GetProcAddress(196190)|0);
              $67 = ((($29)) + 52|0);
              HEAP32[$67>>2] = $66;
              $68 = ($66|0)==(0|0);
              if ($68) {
               $$sink$i = 196190;
               label = 68;
               break;
              }
              $69 = (_SDL_GL_GetProcAddress(197411)|0);
              $70 = ((($29)) + 56|0);
              HEAP32[$70>>2] = $69;
              $71 = ($69|0)==(0|0);
              if ($71) {
               $$sink$i = 197411;
               label = 68;
               break;
              }
              $72 = (_SDL_GL_GetProcAddress(197267)|0);
              $73 = ((($29)) + 60|0);
              HEAP32[$73>>2] = $72;
              $74 = ($72|0)==(0|0);
              if ($74) {
               $$sink$i = 197267;
               label = 68;
               break;
              }
              $75 = (_SDL_GL_GetProcAddress(196345)|0);
              $76 = ((($29)) + 64|0);
              HEAP32[$76>>2] = $75;
              $77 = ($75|0)==(0|0);
              if ($77) {
               $$sink$i = 196345;
               label = 68;
               break;
              }
              $78 = (_SDL_GL_GetProcAddress(198310)|0);
              $79 = ((($29)) + 68|0);
              HEAP32[$79>>2] = $78;
              $80 = ($78|0)==(0|0);
              if ($80) {
               $$sink$i = 198310;
               label = 68;
               break;
              }
              $81 = (_SDL_GL_GetProcAddress(198072)|0);
              $82 = ((($29)) + 72|0);
              HEAP32[$82>>2] = $81;
              $83 = ($81|0)==(0|0);
              if ($83) {
               $$sink$i = 198072;
               label = 68;
               break;
              }
              $84 = (_SDL_GL_GetProcAddress(198099)|0);
              $85 = ((($29)) + 76|0);
              HEAP32[$85>>2] = $84;
              $86 = ($84|0)==(0|0);
              if ($86) {
               $$sink$i = 198099;
               label = 68;
               break;
              }
              $87 = (_SDL_GL_GetProcAddress(198301)|0);
              $88 = ((($29)) + 80|0);
              HEAP32[$88>>2] = $87;
              $89 = ($87|0)==(0|0);
              if ($89) {
               $$sink$i = 198301;
               label = 68;
               break;
              }
              $90 = (_SDL_GL_GetProcAddress(198046)|0);
              $91 = ((($29)) + 84|0);
              HEAP32[$91>>2] = $90;
              $92 = ($90|0)==(0|0);
              if ($92) {
               $$sink$i = 198046;
               label = 68;
               break;
              }
              $93 = (_SDL_GL_GetProcAddress(198245)|0);
              $94 = ((($29)) + 88|0);
              HEAP32[$94>>2] = $93;
              $95 = ($93|0)==(0|0);
              if ($95) {
               $$sink$i = 198245;
               label = 68;
               break;
              }
              $96 = (_SDL_GL_GetProcAddress(197557)|0);
              $97 = ((($29)) + 92|0);
              HEAP32[$97>>2] = $96;
              $98 = ($96|0)==(0|0);
              if ($98) {
               $$sink$i = 197557;
               label = 68;
               break;
              }
              $99 = (_SDL_GL_GetProcAddress(196331)|0);
              $100 = ((($29)) + 96|0);
              HEAP32[$100>>2] = $99;
              $101 = ($99|0)==(0|0);
              if ($101) {
               $$sink$i = 196331;
               label = 68;
               break;
              }
              $102 = (_SDL_GL_GetProcAddress(196317)|0);
              $103 = ((($29)) + 100|0);
              HEAP32[$103>>2] = $102;
              $104 = ($102|0)==(0|0);
              if ($104) {
               $$sink$i = 196317;
               label = 68;
               break;
              }
              $105 = (_SDL_GL_GetProcAddress(196279)|0);
              $106 = ((($29)) + 104|0);
              HEAP32[$106>>2] = $105;
              $107 = ($105|0)==(0|0);
              if ($107) {
               $$sink$i = 196279;
               label = 68;
               break;
              }
              $108 = (_SDL_GL_GetProcAddress(198166)|0);
              $109 = ((($29)) + 108|0);
              HEAP32[$109>>2] = $108;
              $110 = ($108|0)==(0|0);
              if ($110) {
               $$sink$i = 198166;
               label = 68;
               break;
              }
              $111 = (_SDL_GL_GetProcAddress(196291)|0);
              $112 = ((($29)) + 112|0);
              HEAP32[$112>>2] = $111;
              $113 = ($111|0)==(0|0);
              if ($113) {
               $$sink$i = 196291;
               label = 68;
               break;
              }
              $114 = (_SDL_GL_GetProcAddress(197385)|0);
              $115 = ((($29)) + 116|0);
              HEAP32[$115>>2] = $114;
              $116 = ($114|0)==(0|0);
              if ($116) {
               $$sink$i = 197385;
               label = 68;
               break;
              }
              $117 = (_SDL_GL_GetProcAddress(197352)|0);
              $118 = ((($29)) + 120|0);
              HEAP32[$118>>2] = $117;
              $119 = ($117|0)==(0|0);
              if ($119) {
               $$sink$i = 197352;
               label = 68;
               break;
              }
              $120 = (_SDL_GL_GetProcAddress(197371)|0);
              $121 = ((($29)) + 124|0);
              HEAP32[$121>>2] = $120;
              $122 = ($120|0)==(0|0);
              if ($122) {
               $$sink$i = 197371;
               label = 68;
               break;
              }
              $123 = (_SDL_GL_GetProcAddress(196781)|0);
              $124 = ((($29)) + 128|0);
              HEAP32[$124>>2] = $123;
              $125 = ($123|0)==(0|0);
              if ($125) {
               $$sink$i = 196781;
               label = 68;
               break;
              }
              $126 = (_SDL_GL_GetProcAddress(197454)|0);
              $127 = ((($29)) + 132|0);
              HEAP32[$127>>2] = $126;
              $128 = ($126|0)==(0|0);
              if ($128) {
               $$sink$i = 197454;
               label = 68;
               break;
              }
              $129 = (_SDL_GL_GetProcAddress(196265)|0);
              $130 = ((($29)) + 136|0);
              HEAP32[$130>>2] = $129;
              $131 = ($129|0)==(0|0);
              if ($131) {
               $$sink$i = 196265;
               label = 68;
               break;
              }
              $132 = (_SDL_GL_GetProcAddress(196440)|0);
              $133 = ((($29)) + 140|0);
              HEAP32[$133>>2] = $132;
              $134 = ($132|0)==(0|0);
              if ($134) {
               $$sink$i = 196440;
               label = 68;
               break;
              }
              $135 = (_SDL_GL_GetProcAddress(198731)|0);
              $136 = ((($29)) + 144|0);
              HEAP32[$136>>2] = $135;
              $137 = ($135|0)==(0|0);
              if ($137) {
               $$sink$i = 198731;
               label = 68;
               break;
              }
              $138 = (_SDL_GL_GetProcAddress(198127)|0);
              $139 = ((($29)) + 148|0);
              HEAP32[$139>>2] = $138;
              $140 = ($138|0)==(0|0);
              if ($140) {
               $$sink$i = 198127;
               label = 68;
               break;
              }
              $141 = (_SDL_GL_GetProcAddress(197303)|0);
              $142 = ((($29)) + 152|0);
              HEAP32[$142>>2] = $141;
              $143 = ($141|0)==(0|0);
              if ($143) {
               $$sink$i = 197303;
               label = 68;
               break;
              }
              $144 = (_SDL_GL_GetProcAddress(196411)|0);
              $145 = ((($29)) + 156|0);
              HEAP32[$145>>2] = $144;
              $146 = ($144|0)==(0|0);
              if ($146) {
               $$sink$i = 196411;
               label = 68;
               break;
              }
              $147 = (_SDL_GL_GetProcAddress(198632)|0);
              $148 = ((($29)) + 160|0);
              HEAP32[$148>>2] = $147;
              $149 = ($147|0)==(0|0);
              if ($149) {
               $$sink$i = 198632;
               label = 68;
               break;
              }
              $150 = (_SDL_GL_GetProcAddress(196424)|0);
              $151 = ((($29)) + 164|0);
              HEAP32[$151>>2] = $150;
              $152 = ($150|0)==(0|0);
              if ($152) {
               $$sink$i = 196424;
               label = 68;
               break;
              }
              $153 = (_SDL_GL_GetProcAddress(196935)|0);
              $154 = ((($29)) + 168|0);
              HEAP32[$154>>2] = $153;
              $155 = ($153|0)==(0|0);
              if ($155) {
               $$sink$i = 196935;
               label = 68;
               break;
              }
              $156 = (_SDL_GL_GetProcAddress(196923)|0);
              $157 = ((($29)) + 172|0);
              HEAP32[$157>>2] = $156;
              $158 = ($156|0)==(0|0);
              if ($158) {
               $$sink$i = 196923;
               label = 68;
               break;
              }
              $159 = (_SDL_GL_GetProcAddress(197125)|0);
              $160 = ((($29)) + 176|0);
              HEAP32[$160>>2] = $159;
              $161 = ($159|0)==(0|0);
              if ($161) {
               $$sink$i = 197125;
               label = 68;
               break;
              }
              $162 = (_SDL_GL_GetProcAddress(196156)|0);
              $163 = ((($29)) + 180|0);
              HEAP32[$163>>2] = $162;
              $164 = ($162|0)==(0|0);
              if ($164) {
               $$sink$i = 196156;
               label = 68;
               break;
              }
              $165 = (_SDL_GL_GetProcAddress(198024)|0);
              $166 = ((($29)) + 184|0);
              HEAP32[$166>>2] = $165;
              $167 = ($165|0)==(0|0);
              if ($167) {
               $$sink$i = 198024;
               label = 68;
               break;
              }
              $168 = (_SDL_GL_GetProcAddress(198707)|0);
              $169 = ((($29)) + 188|0);
              HEAP32[$169>>2] = $168;
              $170 = ($168|0)==(0|0);
              if ($170) {
               $$sink$i = 198707;
               label = 68;
               break;
              }
              $171 = (_SDL_GL_GetProcAddress(197539)|0);
              $172 = ((($29)) + 192|0);
              HEAP32[$172>>2] = $171;
              $173 = ($171|0)==(0|0);
              if ($173) {
               $$sink$i = 197539;
               label = 68;
               break;
              }
              $174 = (_SDL_GL_GetProcAddress(197622)|0);
              $175 = ((($29)) + 196|0);
              HEAP32[$175>>2] = $174;
              $176 = ($174|0)==(0|0);
              if ($176) {
               $$sink$i = 197622;
               label = 68;
               break;
              }
              $177 = (_SDL_GL_GetProcAddress(198404)|0);
              $178 = ((($29)) + 200|0);
              HEAP32[$178>>2] = $177;
              $179 = ($177|0)==(0|0);
              if ($179) {
               $$sink$i = 198404;
               label = 68;
               break;
              }
              $180 = (_SDL_GL_GetProcAddress(197575)|0);
              $181 = ((($29)) + 204|0);
              HEAP32[$181>>2] = $180;
              $182 = ($180|0)==(0|0);
              if ($182) {
               $$sink$i = 197575;
               label = 68;
               break;
              }
              $183 = (_SDL_GL_GetProcAddress(197229)|0);
              $184 = ((($29)) + 208|0);
              HEAP32[$184>>2] = $183;
              $185 = ($183|0)==(0|0);
              if ($185) {
               $$sink$i = 197229;
               label = 68;
               break;
              }
              $186 = (_SDL_GL_GetProcAddress(197468)|0);
              $187 = ((($29)) + 212|0);
              HEAP32[$187>>2] = $186;
              $188 = ($186|0)==(0|0);
              if ($188) {
               $$sink$i = 197468;
               label = 68;
               break;
              }
              $189 = (_SDL_GL_GetProcAddress(196553)|0);
              $190 = ((($29)) + 216|0);
              HEAP32[$190>>2] = $189;
              $191 = ($189|0)==(0|0);
              if ($191) {
               $$sink$i = 196553;
               label = 68;
               break;
              }
              $192 = (_SDL_GL_GetProcAddress(197144)|0);
              $193 = ((($29)) + 220|0);
              HEAP32[$193>>2] = $192;
              $194 = ($192|0)==(0|0);
              if ($194) {
               $$sink$i = 197144;
               label = 68;
               break;
              }
              $195 = (_SDL_GL_GetProcAddress(196605)|0);
              $196 = ((($29)) + 224|0);
              HEAP32[$196>>2] = $195;
              $197 = ($195|0)==(0|0);
              if ($197) {
               $$sink$i = 196605;
               label = 68;
               break;
              }
              $198 = (_SDL_GL_GetProcAddress(196618)|0);
              $199 = ((($29)) + 228|0);
              HEAP32[$199>>2] = $198;
              $200 = ($198|0)==(0|0);
              if ($200) {
               $$sink$i = 196618;
               label = 68;
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    } while(0);
    if ((label|0) == 68) {
     $201 = (_SDL_GetError()|0);
     HEAP32[$vararg_buffer>>2] = $$sink$i;
     $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
     HEAP32[$vararg_ptr1>>2] = $201;
     $202 = (_SDL_SetError(175158,$vararg_buffer)|0);
     $203 = ($202|0)<(0);
     if ($203) {
      _GLES2_DestroyRenderer($27);
      break;
     }
    }
    $204 = $1 & 4;
    $205 = ($204|0)==(0);
    if ($205) {
     (_SDL_GL_SetSwapInterval(0)|0);
    } else {
     (_SDL_GL_SetSwapInterval(1)|0);
    }
    $206 = (_SDL_GL_GetSwapInterval()|0);
    $207 = ($206|0)>(0);
    if ($207) {
     $208 = HEAP32[$32>>2]|0;
     $209 = $208 | 4;
     HEAP32[$32>>2] = $209;
    }
    $210 = (_SDL_GL_GetAttribute(20,$5)|0);
    $211 = ($210|0)==(0);
    if ($211) {
     $212 = HEAP32[$5>>2]|0;
     $213 = $212 & 1;
     $214 = ($213|0)==(0);
     if (!($214)) {
      $215 = ((($29)) + 4|0);
      HEAP32[$215>>2] = 1;
     }
    }
    HEAP32[$5>>2] = 0;
    $216 = ((($29)) + 112|0);
    $217 = HEAP32[$216>>2]|0;
    FUNCTION_TABLE_vii[$217 & 8191](3379,$5);
    $218 = HEAP32[$5>>2]|0;
    $219 = ((($27)) + 180|0);
    HEAP32[$219>>2] = $218;
    HEAP32[$5>>2] = 0;
    $220 = HEAP32[$216>>2]|0;
    FUNCTION_TABLE_vii[$220 & 8191](3379,$5);
    $221 = HEAP32[$5>>2]|0;
    $222 = ((($27)) + 184|0);
    HEAP32[$222>>2] = $221;
    $223 = HEAP32[$216>>2]|0;
    FUNCTION_TABLE_vii[$223 & 8191](36345,$2);
    $224 = ((($29)) + 100|0);
    $225 = HEAP32[$224>>2]|0;
    FUNCTION_TABLE_vii[$225 & 8191](36346,$3);
    $226 = HEAP8[$3>>0]|0;
    $227 = ($226<<24>>24)==(0);
    $$pre = HEAP32[$2>>2]|0;
    if ($227) {
     $229 = $$pre;
    } else {
     $228 = (($$pre) + 1)|0;
     HEAP32[$2>>2] = $228;
     $229 = $228;
    }
    $230 = (_SDL_calloc($229,4)|0);
    $231 = ((($29)) + 244|0);
    HEAP32[$231>>2] = $230;
    $232 = ($230|0)==(0|0);
    if ($232) {
     _GLES2_DestroyRenderer($27);
     (_SDL_Error(0)|0);
     break;
    }
    $233 = HEAP32[$2>>2]|0;
    $234 = ((($29)) + 240|0);
    HEAP32[$234>>2] = $233;
    $235 = HEAP32[$216>>2]|0;
    FUNCTION_TABLE_vii[$235 & 8191](36344,$230);
    $236 = HEAP8[$3>>0]|0;
    $237 = ($236<<24>>24)==(0);
    if (!($237)) {
     $238 = HEAP32[$231>>2]|0;
     $239 = HEAP32[$2>>2]|0;
     $240 = (($239) + -1)|0;
     $241 = (($238) + ($240<<2)|0);
     HEAP32[$241>>2] = -1;
    }
    $242 = ((($29)) + 232|0);
    HEAP32[$242>>2] = 0;
    $243 = HEAP32[$216>>2]|0;
    FUNCTION_TABLE_vii[$243 & 8191](36006,$4);
    $244 = HEAP32[$4>>2]|0;
    $245 = ((($29)) + 236|0);
    HEAP32[$245>>2] = $244;
    $246 = ((($27)) + 4|0);
    HEAP32[$246>>2] = 4259;
    $247 = ((($27)) + 8|0);
    HEAP32[$247>>2] = 4260;
    $248 = ((($27)) + 12|0);
    HEAP32[$248>>2] = 4261;
    $249 = ((($27)) + 28|0);
    HEAP32[$249>>2] = 4262;
    $250 = ((($27)) + 32|0);
    HEAP32[$250>>2] = 4263;
    $251 = ((($27)) + 36|0);
    HEAP32[$251>>2] = 4264;
    $252 = ((($27)) + 40|0);
    HEAP32[$252>>2] = 4265;
    $253 = ((($27)) + 44|0);
    HEAP32[$253>>2] = 4266;
    $254 = ((($27)) + 48|0);
    HEAP32[$254>>2] = 4267;
    $255 = ((($27)) + 52|0);
    HEAP32[$255>>2] = 4268;
    $256 = ((($27)) + 56|0);
    HEAP32[$256>>2] = 4269;
    $257 = ((($27)) + 60|0);
    HEAP32[$257>>2] = 4270;
    $258 = ((($27)) + 64|0);
    HEAP32[$258>>2] = 4271;
    $259 = ((($27)) + 68|0);
    HEAP32[$259>>2] = 4272;
    $260 = ((($27)) + 72|0);
    HEAP32[$260>>2] = 4273;
    $261 = ((($27)) + 76|0);
    HEAP32[$261>>2] = 4274;
    $262 = ((($27)) + 80|0);
    HEAP32[$262>>2] = 4275;
    $263 = ((($27)) + 84|0);
    HEAP32[$263>>2] = 4276;
    $264 = ((($27)) + 88|0);
    HEAP32[$264>>2] = 4277;
    $265 = ((($27)) + 92|0);
    HEAP32[$265>>2] = 4278;
    $266 = ((($27)) + 96|0);
    HEAP32[$266>>2] = 4279;
    $267 = ((($27)) + 100|0);
    HEAP32[$267>>2] = 4280;
    $268 = ((($27)) + 116|0);
    $269 = ((($27)) + 112|0);
    $270 = HEAP32[$269>>2]|0;
    $271 = (($270) + 1)|0;
    HEAP32[$269>>2] = $271;
    $272 = (($268) + ($270<<2)|0);
    HEAP32[$272>>2] = 842094169;
    $273 = HEAP32[$269>>2]|0;
    $274 = (($273) + 1)|0;
    HEAP32[$269>>2] = $274;
    $275 = (($268) + ($273<<2)|0);
    HEAP32[$275>>2] = 1448433993;
    $276 = HEAP32[$269>>2]|0;
    $277 = (($276) + 1)|0;
    HEAP32[$269>>2] = $277;
    $278 = (($268) + ($276<<2)|0);
    HEAP32[$278>>2] = 842094158;
    $279 = HEAP32[$269>>2]|0;
    $280 = (($279) + 1)|0;
    HEAP32[$269>>2] = $280;
    $281 = (($268) + ($279<<2)|0);
    HEAP32[$281>>2] = 825382478;
    $282 = HEAP32[$33>>2]|0;
    $283 = HEAP32[52374]|0;
    $284 = HEAP32[$282>>2]|0;
    $285 = ($283|0)==($284|0);
    do {
     if ($285) {
      (_GLES2_UpdateViewport($27)|0);
     } else {
      $286 = ((($282)) + 268|0);
      HEAP32[$286>>2] = 0;
      $287 = HEAP32[$34>>2]|0;
      $288 = (_SDL_GL_MakeCurrent($287,$284)|0);
      $289 = ($288|0)<(0);
      if (!($289)) {
       $290 = HEAP32[$282>>2]|0;
       HEAP32[52374] = $290;
       (_GLES2_UpdateViewport($27)|0);
       $$pre$i$i = HEAP32[$33>>2]|0;
       $291 = ((($$pre$i$i)) + 4|0);
       $292 = HEAP32[$291>>2]|0;
       $293 = ($292|0)==(0);
       if ($293) {
        break;
       }
       $294 = ((($$pre$i$i)) + 108|0);
       while(1) {
        $295 = HEAP32[$294>>2]|0;
        $296 = (FUNCTION_TABLE_i[$295 & 8191]()|0);
        $297 = ($296|0)==(0);
        if ($297) {
         break;
        }
       }
      }
     }
    } while(0);
    $298 = ((($282)) + 8|0);
    HEAP32[$298>>2] = -1;
    $299 = ((($282)) + 12|0);
    HEAP32[$299>>2] = 0;
    $300 = ((($282)) + 16|0);
    $301 = HEAP32[$300>>2]|0;
    FUNCTION_TABLE_vi[$301 & 8191](33984);
    $302 = ((($282)) + 136|0);
    $303 = HEAP32[$302>>2]|0;
    FUNCTION_TABLE_vii[$303 & 8191](3333,1);
    $304 = HEAP32[$302>>2]|0;
    FUNCTION_TABLE_vii[$304 & 8191](3317,1);
    $305 = ((($282)) + 40|0);
    $306 = HEAP32[$305>>2]|0;
    $307 = ((($282)) + 272|0);
    $308 = HEAP8[$307>>0]|0;
    $309 = (+($308&255));
    $310 = $309 * 0.0039215688593685627;
    $311 = ((($282)) + 273|0);
    $312 = HEAP8[$311>>0]|0;
    $313 = (+($312&255));
    $314 = $313 * 0.0039215688593685627;
    $315 = ((($282)) + 274|0);
    $316 = HEAP8[$315>>0]|0;
    $317 = (+($316&255));
    $318 = $317 * 0.0039215688593685627;
    $319 = ((($282)) + 275|0);
    $320 = HEAP8[$319>>0]|0;
    $321 = (+($320&255));
    $322 = $321 * 0.0039215688593685627;
    FUNCTION_TABLE_vdddd[$306 & 8191]($310,$314,$318,$322);
    $323 = ((($282)) + 84|0);
    $324 = HEAP32[$323>>2]|0;
    FUNCTION_TABLE_vi[$324 & 8191](0);
    $325 = ((($282)) + 72|0);
    $326 = HEAP32[$325>>2]|0;
    FUNCTION_TABLE_vi[$326 & 8191](1);
    $327 = HEAP32[$33>>2]|0;
    $328 = ((($327)) + 4|0);
    $329 = HEAP32[$328>>2]|0;
    $330 = ($329|0)==(0);
    if ($330) {
     $$088 = $27;
     STACKTOP = sp;return ($$088|0);
    }
    $331 = ((($327)) + 108|0);
    $332 = HEAP32[$331>>2]|0;
    $333 = (FUNCTION_TABLE_i[$332 & 8191]()|0);
    $334 = ($333|0)==(0);
    if ($334) {
     $$088 = $27;
     STACKTOP = sp;return ($$088|0);
    } else {
     $$0211$i$i = 221531;$338 = $333;
    }
    while(1) {
     $335 = ($$0211$i$i|0)==(0|0);
     if ($335) {
      label = 94;
     } else {
      $336 = HEAP8[$$0211$i$i>>0]|0;
      $337 = ($336<<24>>24)==(0);
      if ($337) {
       label = 94;
      } else {
       $$122$i$i = $$0211$i$i;
      }
     }
     if ((label|0) == 94) {
      label = 0;
      $$122$i$i = 175195;
     }
     switch ($338|0) {
     case 1280:  {
      $$0$i$i$i = 175266;
      break;
     }
     case 1281:  {
      $$0$i$i$i = 175249;
      break;
     }
     case 1282:  {
      $$0$i$i$i = 175228;
      break;
     }
     case 1285:  {
      $$0$i$i$i = 175211;
      break;
     }
     default: {
      $$0$i$i$i = 175203;
     }
     }
     HEAP32[$vararg_buffer2>>2] = $$122$i$i;
     $vararg_ptr5 = ((($vararg_buffer2)) + 4|0);
     HEAP32[$vararg_ptr5>>2] = 175308;
     $vararg_ptr6 = ((($vararg_buffer2)) + 8|0);
     HEAP32[$vararg_ptr6>>2] = 1954;
     $vararg_ptr7 = ((($vararg_buffer2)) + 12|0);
     HEAP32[$vararg_ptr7>>2] = 175401;
     $vararg_ptr8 = ((($vararg_buffer2)) + 16|0);
     HEAP32[$vararg_ptr8>>2] = $$0$i$i$i;
     $vararg_ptr9 = ((($vararg_buffer2)) + 20|0);
     HEAP32[$vararg_ptr9>>2] = $338;
     (_SDL_SetError(175282,$vararg_buffer2)|0);
     $339 = HEAP32[$331>>2]|0;
     $340 = (FUNCTION_TABLE_i[$339 & 8191]()|0);
     $341 = ($340|0)==(0);
     if ($341) {
      $$088 = $27;
      break;
     } else {
      $$0211$i$i = $$122$i$i;$338 = $340;
     }
    }
    STACKTOP = sp;return ($$088|0);
   }
  } while(0);
  $342 = ($$0|0)==(0);
  if ($342) {
   $$088 = 0;
   STACKTOP = sp;return ($$088|0);
  }
 }
 $343 = HEAP32[$6>>2]|0;
 (_SDL_GL_SetAttribute(21,$343)|0);
 $344 = HEAP32[$7>>2]|0;
 (_SDL_GL_SetAttribute(17,$344)|0);
 $345 = HEAP32[$8>>2]|0;
 (_SDL_GL_SetAttribute(18,$345)|0);
 (_SDL_RecreateWindow($0,$15)|0);
 $$088 = 0;
 STACKTOP = sp;return ($$088|0);
}
function _SDL_GL_GetAttribute($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$033 = 0, $$2 = 0, $$sink = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer11 = 0, $vararg_buffer13 = 0, $vararg_buffer15 = 0, $vararg_buffer17 = 0, $vararg_buffer19 = 0, $vararg_buffer21 = 0, $vararg_buffer3 = 0, $vararg_buffer5 = 0, $vararg_buffer7 = 0, $vararg_buffer9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(112|0);
 $vararg_buffer21 = sp + 88|0;
 $vararg_buffer19 = sp + 80|0;
 $vararg_buffer17 = sp + 72|0;
 $vararg_buffer15 = sp + 64|0;
 $vararg_buffer13 = sp + 56|0;
 $vararg_buffer11 = sp + 48|0;
 $vararg_buffer9 = sp + 40|0;
 $vararg_buffer7 = sp + 32|0;
 $vararg_buffer5 = sp + 24|0;
 $vararg_buffer3 = sp + 16|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $2 = sp + 104|0;
 $3 = sp + 100|0;
 $4 = sp + 96|0;
 $5 = sp + 92|0;
 HEAP32[$1>>2] = 0;
 do {
  switch ($0|0) {
  case 0:  {
   $$033 = 3410;
   break;
  }
  case 2:  {
   $$033 = 3412;
   break;
  }
  case 1:  {
   $$033 = 3411;
   break;
  }
  case 3:  {
   $$033 = 3413;
   break;
  }
  case 5:  {
   $6 = HEAP32[52375]|0;
   $7 = ((($6)) + 320|0);
   $8 = HEAP32[$7>>2]|0;
   HEAP32[$1>>2] = $8;
   $$2 = 0;
   STACKTOP = sp;return ($$2|0);
   break;
  }
  case 6:  {
   $$033 = 3414;
   break;
  }
  case 7:  {
   $$033 = 3415;
   break;
  }
  case 13:  {
   $$033 = 32936;
   break;
  }
  case 14:  {
   $$033 = 32937;
   break;
  }
  case 24:  {
   $$033 = 33531;
   break;
  }
  case 4:  {
   HEAP32[$2>>2] = 0;
   HEAP32[$3>>2] = 0;
   HEAP32[$4>>2] = 0;
   HEAP32[$5>>2] = 0;
   $9 = (_SDL_GL_GetAttribute(0,$2)|0);
   $10 = ($9|0)<(0);
   if ($10) {
    $$0 = -1;
   } else {
    $11 = (_SDL_GL_GetAttribute(1,$3)|0);
    $12 = ($11|0)<(0);
    if ($12) {
     $$0 = -1;
    } else {
     $13 = (_SDL_GL_GetAttribute(2,$4)|0);
     $14 = ($13|0)<(0);
     if ($14) {
      $$0 = -1;
     } else {
      $15 = (_SDL_GL_GetAttribute(3,$5)|0);
      $16 = ($15|0)<(0);
      if ($16) {
       $$0 = -1;
      } else {
       $17 = HEAP32[$2>>2]|0;
       $18 = HEAP32[$3>>2]|0;
       $19 = (($18) + ($17))|0;
       $20 = HEAP32[$4>>2]|0;
       $21 = (($19) + ($20))|0;
       $22 = HEAP32[$5>>2]|0;
       $23 = (($21) + ($22))|0;
       HEAP32[$1>>2] = $23;
       $$0 = 0;
      }
     }
    }
   }
   $$2 = $$0;
   STACKTOP = sp;return ($$2|0);
   break;
  }
  case 15:  {
   $24 = HEAP32[52375]|0;
   $25 = ((($24)) + 352|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = ($26|0)!=(0);
   $28 = $27&1;
   HEAP32[$1>>2] = $28;
   $$2 = 0;
   STACKTOP = sp;return ($$2|0);
   break;
  }
  case 16:  {
   $29 = HEAP32[52375]|0;
   $30 = ((($29)) + 384|0);
   $31 = HEAP32[$30>>2]|0;
   HEAP32[$1>>2] = $31;
   $$2 = 0;
   STACKTOP = sp;return ($$2|0);
   break;
  }
  case 17:  {
   $32 = HEAP32[52375]|0;
   $33 = ((($32)) + 356|0);
   $34 = HEAP32[$33>>2]|0;
   HEAP32[$1>>2] = $34;
   $$2 = 0;
   STACKTOP = sp;return ($$2|0);
   break;
  }
  case 18:  {
   $35 = HEAP32[52375]|0;
   $36 = ((($35)) + 360|0);
   $37 = HEAP32[$36>>2]|0;
   HEAP32[$1>>2] = $37;
   $$2 = 0;
   STACKTOP = sp;return ($$2|0);
   break;
  }
  case 19:  {
   $38 = HEAP32[52375]|0;
   $39 = ((($38)) + 368|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = ($40|0)==(4);
   $$sink = $41&1;
   HEAP32[$1>>2] = $$sink;
   $$2 = 0;
   STACKTOP = sp;return ($$2|0);
   break;
  }
  case 20:  {
   $42 = HEAP32[52375]|0;
   $43 = ((($42)) + 364|0);
   $44 = HEAP32[$43>>2]|0;
   HEAP32[$1>>2] = $44;
   $$2 = 0;
   STACKTOP = sp;return ($$2|0);
   break;
  }
  case 21:  {
   $45 = HEAP32[52375]|0;
   $46 = ((($45)) + 368|0);
   $47 = HEAP32[$46>>2]|0;
   HEAP32[$1>>2] = $47;
   $$2 = 0;
   STACKTOP = sp;return ($$2|0);
   break;
  }
  case 22:  {
   $48 = HEAP32[52375]|0;
   $49 = ((($48)) + 372|0);
   $50 = HEAP32[$49>>2]|0;
   HEAP32[$1>>2] = $50;
   $$2 = 0;
   STACKTOP = sp;return ($$2|0);
   break;
  }
  case 23:  {
   $51 = HEAP32[52375]|0;
   $52 = ((($51)) + 380|0);
   $53 = HEAP32[$52>>2]|0;
   HEAP32[$1>>2] = $53;
   $$2 = 0;
   STACKTOP = sp;return ($$2|0);
   break;
  }
  case 12: case 11: case 10: case 9: case 8:  {
   $$2 = 0;
   STACKTOP = sp;return ($$2|0);
   break;
  }
  default: {
   $54 = (_SDL_SetError(182459,$vararg_buffer)|0);
   $$2 = $54;
   STACKTOP = sp;return ($$2|0);
  }
  }
 } while(0);
 $55 = HEAP32[52375]|0;
 $56 = ($55|0)==(0|0);
 do {
  if ($56) {
   (_SDL_SetError(175439,$vararg_buffer1)|0);
  } else {
   $57 = ((($55)) + 168|0);
   $58 = HEAP32[$57>>2]|0;
   $59 = ($58|0)==(0|0);
   if ($59) {
    (_SDL_SetError(181719,$vararg_buffer5)|0);
    break;
   }
   $60 = ((($55)) + 388|0);
   $61 = HEAP32[$60>>2]|0;
   $62 = ($61|0)==(0);
   if ($62) {
    (_SDL_SetError(181690,$vararg_buffer3)|0);
    break;
   }
   $63 = (FUNCTION_TABLE_iii[$58 & 8191]($55,196291)|0);
   $64 = ($63|0)==(0|0);
   if (!($64)) {
    FUNCTION_TABLE_vii[$63 & 8191]($$033,$1);
    $66 = HEAP32[52375]|0;
    $67 = ($66|0)==(0|0);
    do {
     if ($67) {
      (_SDL_SetError(175439,$vararg_buffer9)|0);
     } else {
      $68 = ((($66)) + 168|0);
      $69 = HEAP32[$68>>2]|0;
      $70 = ($69|0)==(0|0);
      if ($70) {
       (_SDL_SetError(181719,$vararg_buffer13)|0);
       break;
      }
      $71 = ((($66)) + 388|0);
      $72 = HEAP32[$71>>2]|0;
      $73 = ($72|0)==(0);
      if ($73) {
       (_SDL_SetError(181690,$vararg_buffer11)|0);
       break;
      }
      $74 = (FUNCTION_TABLE_iii[$69 & 8191]($66,198166)|0);
      $75 = ($74|0)==(0|0);
      if (!($75)) {
       $77 = (FUNCTION_TABLE_i[$74 & 8191]()|0);
       switch ($77|0) {
       case 1280:  {
        $78 = (_SDL_SetError(182577,$vararg_buffer17)|0);
        $$2 = $78;
        STACKTOP = sp;return ($$2|0);
        break;
       }
       case 1281:  {
        $79 = (_SDL_SetError(182607,$vararg_buffer19)|0);
        $$2 = $79;
        STACKTOP = sp;return ($$2|0);
        break;
       }
       case 0:  {
        $$2 = 0;
        STACKTOP = sp;return ($$2|0);
        break;
       }
       default: {
        HEAP32[$vararg_buffer21>>2] = $77;
        $80 = (_SDL_SetError(182638,$vararg_buffer21)|0);
        $$2 = $80;
        STACKTOP = sp;return ($$2|0);
       }
       }
      }
     }
    } while(0);
    $76 = (_SDL_SetError(182532,$vararg_buffer15)|0);
    $$2 = $76;
    STACKTOP = sp;return ($$2|0);
   }
  }
 } while(0);
 $65 = (_SDL_SetError(182484,$vararg_buffer7)|0);
 $$2 = $65;
 STACKTOP = sp;return ($$2|0);
}
function _SDL_GetWindowFlags($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $1 = HEAP32[52375]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  (_SDL_SetError(175439,$vararg_buffer)|0);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = ($0|0)==(0|0);
 if (!($3)) {
  $4 = HEAP32[$0>>2]|0;
  $5 = ((($1)) + 280|0);
  $6 = ($4|0)==($5|0);
  if ($6) {
   $7 = ((($0)) + 48|0);
   $8 = HEAP32[$7>>2]|0;
   $$0 = $8;
   STACKTOP = sp;return ($$0|0);
  }
 }
 (_SDL_SetError(195204,$vararg_buffer1)|0);
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _SDL_GL_SetAttribute($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$039 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer3 = 0, $vararg_buffer6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $vararg_buffer6 = sp + 24|0;
 $vararg_buffer3 = sp + 16|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $2 = HEAP32[52375]|0;
 $3 = ($2|0)==(0|0);
 L1: do {
  if ($3) {
   $4 = (_SDL_SetError(175439,$vararg_buffer)|0);
   $$039 = $4;
  } else {
   do {
    switch ($0|0) {
    case 0:  {
     $5 = ((($2)) + 292|0);
     HEAP32[$5>>2] = $1;
     $$039 = 0;
     break L1;
     break;
    }
    case 1:  {
     $6 = ((($2)) + 296|0);
     HEAP32[$6>>2] = $1;
     $$039 = 0;
     break L1;
     break;
    }
    case 2:  {
     $7 = ((($2)) + 300|0);
     HEAP32[$7>>2] = $1;
     $$039 = 0;
     break L1;
     break;
    }
    case 3:  {
     $8 = ((($2)) + 304|0);
     HEAP32[$8>>2] = $1;
     $$039 = 0;
     break L1;
     break;
    }
    case 5:  {
     $9 = ((($2)) + 320|0);
     HEAP32[$9>>2] = $1;
     $$039 = 0;
     break L1;
     break;
    }
    case 4:  {
     $10 = ((($2)) + 312|0);
     HEAP32[$10>>2] = $1;
     $$039 = 0;
     break L1;
     break;
    }
    case 6:  {
     $11 = ((($2)) + 308|0);
     HEAP32[$11>>2] = $1;
     $$039 = 0;
     break L1;
     break;
    }
    case 7:  {
     $12 = ((($2)) + 316|0);
     HEAP32[$12>>2] = $1;
     $$039 = 0;
     break L1;
     break;
    }
    case 8:  {
     $13 = ((($2)) + 324|0);
     HEAP32[$13>>2] = $1;
     $$039 = 0;
     break L1;
     break;
    }
    case 9:  {
     $14 = ((($2)) + 328|0);
     HEAP32[$14>>2] = $1;
     $$039 = 0;
     break L1;
     break;
    }
    case 10:  {
     $15 = ((($2)) + 332|0);
     HEAP32[$15>>2] = $1;
     $$039 = 0;
     break L1;
     break;
    }
    case 11:  {
     $16 = ((($2)) + 336|0);
     HEAP32[$16>>2] = $1;
     $$039 = 0;
     break L1;
     break;
    }
    case 12:  {
     $17 = ((($2)) + 340|0);
     HEAP32[$17>>2] = $1;
     $$039 = 0;
     break L1;
     break;
    }
    case 13:  {
     $18 = ((($2)) + 344|0);
     HEAP32[$18>>2] = $1;
     $$039 = 0;
     break L1;
     break;
    }
    case 14:  {
     $19 = ((($2)) + 348|0);
     HEAP32[$19>>2] = $1;
     $$039 = 0;
     break L1;
     break;
    }
    case 15:  {
     $20 = ((($2)) + 352|0);
     HEAP32[$20>>2] = $1;
     $$039 = 0;
     break L1;
     break;
    }
    case 16:  {
     $21 = ((($2)) + 384|0);
     HEAP32[$21>>2] = $1;
     $$039 = 0;
     break L1;
     break;
    }
    case 17:  {
     $22 = ((($2)) + 356|0);
     HEAP32[$22>>2] = $1;
     $$039 = 0;
     break L1;
     break;
    }
    case 18:  {
     $23 = ((($2)) + 360|0);
     HEAP32[$23>>2] = $1;
     $$039 = 0;
     break L1;
     break;
    }
    case 19:  {
     $24 = ($1|0)==(0);
     $25 = ((($2)) + 368|0);
     if ($24) {
      HEAP32[$25>>2] = 0;
      $$039 = 0;
      break L1;
     } else {
      HEAP32[$25>>2] = 4;
      $$039 = 0;
      break L1;
     }
     break;
    }
    case 20:  {
     $26 = ($1>>>0)>(15);
     if ($26) {
      HEAP32[$vararg_buffer1>>2] = $1;
      $27 = (_SDL_SetError(182394,$vararg_buffer1)|0);
      $$039 = $27;
      break L1;
     } else {
      $28 = ((($2)) + 364|0);
      HEAP32[$28>>2] = $1;
      $$039 = 0;
      break L1;
     }
     break;
    }
    case 21:  {
     switch ($1|0) {
     case 0: case 1: case 2: case 4:  {
      $30 = ((($2)) + 368|0);
      HEAP32[$30>>2] = $1;
      $$039 = 0;
      break L1;
      break;
     }
     default: {
      HEAP32[$vararg_buffer3>>2] = $1;
      $29 = (_SDL_SetError(182425,$vararg_buffer3)|0);
      $$039 = $29;
      break L1;
     }
     }
     break;
    }
    case 22:  {
     $31 = ((($2)) + 372|0);
     HEAP32[$31>>2] = $1;
     $$039 = 0;
     break L1;
     break;
    }
    case 23:  {
     $32 = ((($2)) + 380|0);
     HEAP32[$32>>2] = $1;
     $$039 = 0;
     break L1;
     break;
    }
    case 24:  {
     $33 = ((($2)) + 376|0);
     HEAP32[$33>>2] = $1;
     $$039 = 0;
     break L1;
     break;
    }
    default: {
     $34 = (_SDL_SetError(182459,$vararg_buffer6)|0);
     $$039 = $34;
     break L1;
    }
    }
   } while(0);
  }
 } while(0);
 STACKTOP = sp;return ($$039|0);
}
function _SDL_RecreateWindow($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$035 = 0, $$036 = 0, $$06$i = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre39 = 0, $$pre40 = 0, $$pre41 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0;
 var $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0;
 var $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $brmerge = 0, $or$cond = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer11 = 0, $vararg_buffer13 = 0;
 var $vararg_buffer15 = 0, $vararg_buffer17 = 0, $vararg_buffer19 = 0, $vararg_buffer21 = 0, $vararg_buffer23 = 0, $vararg_buffer25 = 0, $vararg_buffer27 = 0, $vararg_buffer3 = 0, $vararg_buffer5 = 0, $vararg_buffer7 = 0, $vararg_buffer9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(128|0);
 $vararg_buffer27 = sp + 112|0;
 $vararg_buffer25 = sp + 104|0;
 $vararg_buffer23 = sp + 96|0;
 $vararg_buffer21 = sp + 88|0;
 $vararg_buffer19 = sp + 80|0;
 $vararg_buffer17 = sp + 72|0;
 $vararg_buffer15 = sp + 64|0;
 $vararg_buffer13 = sp + 56|0;
 $vararg_buffer11 = sp + 48|0;
 $vararg_buffer9 = sp + 40|0;
 $vararg_buffer7 = sp + 32|0;
 $vararg_buffer5 = sp + 24|0;
 $vararg_buffer3 = sp + 16|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $2 = $1 & 2;
 $3 = ($2|0)==(0);
 $$pre = HEAP32[52375]|0;
 if (!($3)) {
  $4 = ((($$pre)) + 176|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0|0);
  if ($6) {
   $7 = (_SDL_SetError(181953,$vararg_buffer)|0);
   $$036 = $7;
   STACKTOP = sp;return ($$036|0);
  }
 }
 $8 = ((($0)) + 48|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $9 & 2048;
 $11 = ($10|0)==(0);
 $12 = $1 | 2048;
 $13 = $1 & -2049;
 $$035 = $11 ? $13 : $12;
 $14 = ($$pre|0)==(0|0);
 do {
  if ($14) {
   (_SDL_SetError(175439,$vararg_buffer1)|0);
  } else {
   $15 = HEAP32[$0>>2]|0;
   $16 = ((($$pre)) + 280|0);
   $17 = ($15|0)==($16|0);
   if (!($17)) {
    (_SDL_SetError(195204,$vararg_buffer3)|0);
    break;
   }
   $18 = $9 & 4;
   $19 = ($18|0)==(0);
   if (!($19)) {
    $20 = ((($0)) + 116|0);
    HEAP32[$20>>2] = 1;
    (_SDL_UpdateFullscreenMode($0,0)|0);
    $21 = HEAP32[52375]|0;
    $22 = ((($21)) + 84|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = ($23|0)==(0|0);
    if (!($24)) {
     FUNCTION_TABLE_vii[$23 & 8191]($21,$0);
    }
    HEAP32[$20>>2] = 0;
    (_SDL_SendWindowEvent($0,2,0,0)|0);
   }
  }
 } while(0);
 $25 = ((($0)) + 108|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($26|0)==(0|0);
 if (!($27)) {
  $28 = HEAP32[$26>>2]|0;
  $29 = $28 & -5;
  HEAP32[$26>>2] = $29;
  _SDL_FreeSurface($26);
  HEAP32[$25>>2] = 0;
 }
 $30 = HEAP32[52375]|0;
 $31 = ((($30)) + 140|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = ($32|0)==(0|0);
 if ($33) {
  $35 = $30;
 } else {
  FUNCTION_TABLE_vii[$32 & 8191]($30,$0);
  $$pre39 = HEAP32[52375]|0;
  $35 = $$pre39;
 }
 $34 = ((($35)) + 128|0);
 $36 = HEAP32[$34>>2]|0;
 $37 = ($36|0)!=(0|0);
 $38 = $$035 & 2048;
 $39 = ($38|0)==(0);
 $or$cond = $39 & $37;
 if ($or$cond) {
  FUNCTION_TABLE_vii[$36 & 8191]($35,$0);
 }
 $40 = HEAP32[$8>>2]|0;
 $41 = $40 & 2;
 $42 = $$035 & 2;
 $43 = ($41|0)==($42|0);
 L26: do {
  if ($43) {
   $$0 = 0;
  } else {
   $44 = ($42|0)==(0);
   $45 = HEAP32[52375]|0;
   $46 = ($45|0)==(0|0);
   if ($44) {
    if ($46) {
     (_SDL_SetError(175439,$vararg_buffer9)|0);
     $$0 = 0;
     break;
    }
    $66 = ((($45)) + 388|0);
    $67 = HEAP32[$66>>2]|0;
    $68 = ($67|0)>(0);
    if (!($68)) {
     $$0 = 0;
     break;
    }
    $69 = (($67) + -1)|0;
    HEAP32[$66>>2] = $69;
    $70 = ($67|0)==(1);
    if (!($70)) {
     $$0 = 0;
     break;
    }
    $71 = ((($45)) + 172|0);
    $72 = HEAP32[$71>>2]|0;
    $73 = ($72|0)==(0|0);
    if ($73) {
     $$0 = 0;
     break;
    }
    FUNCTION_TABLE_vi[$72 & 8191]($45);
    $$0 = 0;
    break;
   }
   L37: do {
    if ($46) {
     $47 = (_SDL_SetError(175439,$vararg_buffer5)|0);
     $$06$i = $47;
    } else {
     $48 = ((($45)) + 388|0);
     $49 = HEAP32[$48>>2]|0;
     $50 = ($49|0)==(0);
     do {
      if ($50) {
       $51 = ((($45)) + 164|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = ($52|0)==(0|0);
       if ($53) {
        $54 = (_SDL_SetError(181719,$vararg_buffer7)|0);
        $$06$i = $54;
        break L37;
       }
       $55 = (FUNCTION_TABLE_iii[$52 & 8191]($45,0)|0);
       $56 = ($55|0)==(0);
       $57 = HEAP32[52375]|0;
       if ($56) {
        $$phi$trans$insert = ((($57)) + 388|0);
        $$pre40 = HEAP32[$$phi$trans$insert>>2]|0;
        $59 = $57;$61 = $$pre40;
        break;
       }
       $62 = ((($57)) + 172|0);
       $63 = HEAP32[$62>>2]|0;
       $64 = ($63|0)==(0|0);
       if ($64) {
        $$06$i = $55;
        break L37;
       }
       FUNCTION_TABLE_vi[$63 & 8191]($57);
       $$06$i = $55;
       break L37;
      } else {
       $59 = $45;$61 = $49;
      }
     } while(0);
     $58 = ((($59)) + 388|0);
     $60 = (($61) + 1)|0;
     HEAP32[$58>>2] = $60;
     $$0 = 1;
     break L26;
    }
   } while(0);
   $65 = ($$06$i|0)<(0);
   if ($65) {
    $$036 = -1;
    STACKTOP = sp;return ($$036|0);
   } else {
    $$0 = 1;
   }
  }
 } while(0);
 $74 = $$035 & 1024050;
 $75 = $74 | 8;
 HEAP32[$8>>2] = $75;
 $76 = ((($0)) + 52|0);
 HEAP32[$76>>2] = $75;
 $77 = ((($0)) + 120|0);
 HEAP32[$77>>2] = 0;
 $78 = HEAP32[52375]|0;
 $79 = ((($78)) + 32|0);
 $80 = HEAP32[$79>>2]|0;
 $81 = ($80|0)==(0|0);
 $82 = ($38|0)!=(0);
 $brmerge = $82 | $81;
 if (!($brmerge)) {
  $83 = (FUNCTION_TABLE_iii[$80 & 8191]($78,$0)|0);
  $84 = ($83|0)<(0);
  if ($84) {
   $85 = ($$0|0)==(0);
   if ($85) {
    $$036 = -1;
    STACKTOP = sp;return ($$036|0);
   }
   $86 = HEAP32[52375]|0;
   $87 = ($86|0)==(0|0);
   if ($87) {
    (_SDL_SetError(175439,$vararg_buffer11)|0);
   } else {
    $88 = ((($86)) + 388|0);
    $89 = HEAP32[$88>>2]|0;
    $90 = ($89|0)>(0);
    if ($90) {
     $91 = (($89) + -1)|0;
     HEAP32[$88>>2] = $91;
     $92 = ($89|0)==(1);
     if ($92) {
      $93 = ((($86)) + 172|0);
      $94 = HEAP32[$93>>2]|0;
      $95 = ($94|0)==(0|0);
      if (!($95)) {
       FUNCTION_TABLE_vi[$94 & 8191]($86);
      }
     }
    }
   }
   $96 = HEAP32[$8>>2]|0;
   $97 = $96 & -3;
   HEAP32[$8>>2] = $97;
   $$036 = -1;
   STACKTOP = sp;return ($$036|0);
  }
 }
 if ($82) {
  $98 = HEAP32[$8>>2]|0;
  $99 = $98 | 2048;
  HEAP32[$8>>2] = $99;
 }
 $100 = HEAP32[52375]|0;
 $101 = ((($100)) + 40|0);
 $102 = HEAP32[$101>>2]|0;
 $103 = ($102|0)==(0|0);
 if ($103) {
  $108 = $100;
 } else {
  $104 = ((($0)) + 8|0);
  $105 = HEAP32[$104>>2]|0;
  $106 = ($105|0)==(0|0);
  if ($106) {
   $108 = $100;
  } else {
   FUNCTION_TABLE_vii[$102 & 8191]($100,$0);
   $$pre41 = HEAP32[52375]|0;
   $108 = $$pre41;
  }
 }
 $107 = ((($108)) + 44|0);
 $109 = HEAP32[$107>>2]|0;
 $110 = ($109|0)==(0|0);
 if (!($110)) {
  $111 = ((($0)) + 12|0);
  $112 = HEAP32[$111>>2]|0;
  $113 = ($112|0)==(0|0);
  if (!($113)) {
   FUNCTION_TABLE_viii[$109 & 8191]($108,$0,$112);
  }
 }
 $114 = ((($0)) + 132|0);
 $115 = HEAP32[$114>>2]|0;
 $116 = ($115|0)==(0|0);
 if (!($116)) {
  $117 = HEAP32[52375]|0;
  $118 = ((($117)) + 256|0);
  $119 = HEAP32[$118>>2]|0;
  (FUNCTION_TABLE_iii[$119 & 8191]($0,1)|0);
 }
 $120 = $$035 & 128;
 $121 = ($120|0)==(0);
 do {
  if (!($121)) {
   $122 = HEAP32[52375]|0;
   $123 = ($122|0)==(0|0);
   if ($123) {
    (_SDL_SetError(175439,$vararg_buffer13)|0);
    break;
   }
   $124 = ($0|0)==(0|0);
   if (!($124)) {
    $125 = HEAP32[$0>>2]|0;
    $126 = ((($122)) + 280|0);
    $127 = ($125|0)==($126|0);
    if ($127) {
     $128 = HEAP32[$8>>2]|0;
     $129 = $128 & 128;
     $130 = ($129|0)==(0);
     if (!($130)) {
      break;
     }
     $131 = ((($122)) + 92|0);
     $132 = HEAP32[$131>>2]|0;
     $133 = ($132|0)==(0|0);
     if ($133) {
      break;
     }
     FUNCTION_TABLE_vii[$132 & 8191]($122,$0);
     break;
    }
   }
   (_SDL_SetError(195204,$vararg_buffer15)|0);
  }
 } while(0);
 $134 = $$035 & 64;
 $135 = ($134|0)==(0);
 do {
  if (!($135)) {
   $136 = HEAP32[52375]|0;
   $137 = ($136|0)==(0|0);
   if ($137) {
    (_SDL_SetError(175439,$vararg_buffer17)|0);
    break;
   }
   $138 = ($0|0)==(0|0);
   if (!($138)) {
    $139 = HEAP32[$0>>2]|0;
    $140 = ((($136)) + 280|0);
    $141 = ($139|0)==($140|0);
    if ($141) {
     $142 = HEAP32[$8>>2]|0;
     $143 = $142 & 64;
     $144 = ($143|0)==(0);
     if (!($144)) {
      break;
     }
     (_SDL_UpdateFullscreenMode($0,0)|0);
     $145 = HEAP32[52375]|0;
     $146 = ((($145)) + 96|0);
     $147 = HEAP32[$146>>2]|0;
     $148 = ($147|0)==(0|0);
     if ($148) {
      break;
     }
     FUNCTION_TABLE_vii[$147 & 8191]($145,$0);
     break;
    }
   }
   (_SDL_SetError(195204,$vararg_buffer19)|0);
  }
 } while(0);
 $149 = $$035 & 1;
 $150 = ($149|0)==(0);
 do {
  if (!($150)) {
   $151 = HEAP32[52375]|0;
   $152 = ($151|0)==(0|0);
   if ($152) {
    (_SDL_SetError(175439,$vararg_buffer21)|0);
    break;
   }
   $153 = ($0|0)==(0|0);
   if (!($153)) {
    $154 = HEAP32[$0>>2]|0;
    $155 = ((($151)) + 280|0);
    $156 = ($154|0)==($155|0);
    if ($156) {
     $157 = $$035 & 4097;
     $158 = HEAP32[$8>>2]|0;
     $159 = $158 & 4097;
     $160 = ($157|0)==($159|0);
     if ($160) {
      break;
     }
     $161 = $158 & -4098;
     $162 = $161 | $157;
     HEAP32[$8>>2] = $162;
     $163 = $158 & 68;
     $164 = ($163|0)==(4);
     $165 = $164&1;
     $166 = (_SDL_UpdateFullscreenMode($0,$165)|0);
     $167 = ($166|0)==(0);
     if ($167) {
      break;
     }
     $168 = HEAP32[$8>>2]|0;
     $169 = $168 & -4098;
     $170 = $169 | $159;
     HEAP32[$8>>2] = $170;
     break;
    }
   }
   (_SDL_SetError(195204,$vararg_buffer23)|0);
  }
 } while(0);
 $171 = $$035 & 256;
 $172 = ($171|0)==(0);
 if (!($172)) {
  _SDL_SetWindowGrab($0,1);
 }
 $173 = $$035 & 8;
 $174 = ($173|0)==(0);
 if (!($174)) {
  $$036 = 0;
  STACKTOP = sp;return ($$036|0);
 }
 $175 = HEAP32[52375]|0;
 $176 = ($175|0)==(0|0);
 if ($176) {
  (_SDL_SetError(175439,$vararg_buffer25)|0);
  $$036 = 0;
  STACKTOP = sp;return ($$036|0);
 }
 $177 = ($0|0)==(0|0);
 if (!($177)) {
  $178 = HEAP32[$0>>2]|0;
  $179 = ((($175)) + 280|0);
  $180 = ($178|0)==($179|0);
  if ($180) {
   $181 = HEAP32[$8>>2]|0;
   $182 = $181 & 4;
   $183 = ($182|0)==(0);
   if (!($183)) {
    $$036 = 0;
    STACKTOP = sp;return ($$036|0);
   }
   $184 = ((($175)) + 80|0);
   $185 = HEAP32[$184>>2]|0;
   $186 = ($185|0)==(0|0);
   if (!($186)) {
    FUNCTION_TABLE_vii[$185 & 8191]($175,$0);
   }
   (_SDL_SendWindowEvent($0,1,0,0)|0);
   $$036 = 0;
   STACKTOP = sp;return ($$036|0);
  }
 }
 (_SDL_SetError(195204,$vararg_buffer27)|0);
 $$036 = 0;
 STACKTOP = sp;return ($$036|0);
}
function _SDL_calloc($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_calloc($0,$1)|0);
 return ($2|0);
}
function _SDL_Error($0) {
 $0 = $0|0;
 var $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer3 = 0, $vararg_buffer5 = 0, $vararg_buffer7 = 0, $vararg_buffer9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $vararg_buffer9 = sp + 40|0;
 $vararg_buffer7 = sp + 32|0;
 $vararg_buffer5 = sp + 24|0;
 $vararg_buffer3 = sp + 16|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 switch ($0|0) {
 case 0:  {
  (_SDL_SetError(181803,$vararg_buffer)|0);
  break;
 }
 case 1:  {
  (_SDL_SetError(181817,$vararg_buffer1)|0);
  break;
 }
 case 2:  {
  (_SDL_SetError(181847,$vararg_buffer3)|0);
  break;
 }
 case 3:  {
  (_SDL_SetError(181875,$vararg_buffer5)|0);
  break;
 }
 case 4:  {
  (_SDL_SetError(181903,$vararg_buffer7)|0);
  break;
 }
 default: {
  (_SDL_SetError(181935,$vararg_buffer9)|0);
 }
 }
 STACKTOP = sp;return -1;
}
function _GLES2_DestroyRenderer($0) {
 $0 = $0|0;
 var $$0$i$i = 0, $$0211$i = 0, $$122$i = 0, $$cast = 0, $$in4349 = 0, $$in4445 = 0, $$pre = 0, $$pre$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0;
 var $vararg_ptr3 = 0, $vararg_ptr4 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $vararg_buffer = sp;
 $1 = ((($0)) + 320|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  _SDL_free($0);
  STACKTOP = sp;return;
 }
 $4 = HEAP32[52374]|0;
 $5 = HEAP32[$2>>2]|0;
 $6 = ($4|0)==($5|0);
 if ($6) {
  $14 = $2;
  label = 5;
 } else {
  $7 = ((($2)) + 268|0);
  HEAP32[$7>>2] = 0;
  $8 = ((($0)) + 188|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (_SDL_GL_MakeCurrent($9,$5)|0);
  $11 = ($10|0)<(0);
  if (!($11)) {
   $12 = HEAP32[$2>>2]|0;
   HEAP32[52374] = $12;
   (_GLES2_UpdateViewport($0)|0);
   $$pre$i = HEAP32[$1>>2]|0;
   $14 = $$pre$i;
   label = 5;
  }
 }
 if ((label|0) == 5) {
  $13 = ((($14)) + 4|0);
  $15 = HEAP32[$13>>2]|0;
  $16 = ($15|0)==(0);
  if (!($16)) {
   $17 = ((($14)) + 108|0);
   while(1) {
    $18 = HEAP32[$17>>2]|0;
    $19 = (FUNCTION_TABLE_i[$18 & 8191]()|0);
    $20 = ($19|0)==(0);
    if ($20) {
     break;
    }
   }
  }
 }
 $21 = ((($2)) + 252|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0|0);
 if (!($23)) {
  $24 = ((($2)) + 60|0);
  $$in4349 = $22;
  while(1) {
   $25 = HEAP32[$24>>2]|0;
   $26 = HEAP32[$$in4349>>2]|0;
   FUNCTION_TABLE_vi[$25 & 8191]($26);
   $27 = ((($$in4349)) + 24|0);
   $28 = HEAP32[$27>>2]|0;
   _SDL_free($$in4349);
   $29 = ($28|0)==(0|0);
   if ($29) {
    break;
   } else {
    $$in4349 = $28;
   }
  }
 }
 $30 = ((($2)) + 260|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ($31|0)==(0|0);
 if (!($32)) {
  $33 = ((($2)) + 56|0);
  $$in4445 = $31;
  while(1) {
   $34 = HEAP32[$33>>2]|0;
   $35 = HEAP32[$$in4445>>2]|0;
   FUNCTION_TABLE_vi[$34 & 8191]($35);
   $36 = ((($$in4445)) + 156|0);
   $37 = HEAP32[$36>>2]|0;
   _SDL_free($$in4445);
   $38 = ($37|0)==(0|0);
   if ($38) {
    break;
   } else {
    $$in4445 = $37;
   }
  }
 }
 $39 = HEAP32[$2>>2]|0;
 $40 = ($39|0)==(0|0);
 if (!($40)) {
  $41 = ((($2)) + 232|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = ($42|0)==(0|0);
  if ($43) {
   $67 = $39;
  } else {
   $44 = ((($2)) + 204|0);
   $46 = $42;
   while(1) {
    $45 = ((($46)) + 12|0);
    $47 = HEAP32[$45>>2]|0;
    $48 = HEAP32[$44>>2]|0;
    $49 = ((($46)) + 8|0);
    FUNCTION_TABLE_vii[$48 & 8191](1,$49);
    $50 = HEAP32[$1>>2]|0;
    $51 = ((($50)) + 4|0);
    $52 = HEAP32[$51>>2]|0;
    $53 = ($52|0)==(0);
    L29: do {
     if (!($53)) {
      $54 = ((($50)) + 108|0);
      $55 = HEAP32[$54>>2]|0;
      $56 = (FUNCTION_TABLE_i[$55 & 8191]()|0);
      $57 = ($56|0)==(0);
      if (!($57)) {
       $$0211$i = 221531;$61 = $56;
       while(1) {
        $58 = ($$0211$i|0)==(0|0);
        if ($58) {
         label = 21;
        } else {
         $59 = HEAP8[$$0211$i>>0]|0;
         $60 = ($59<<24>>24)==(0);
         if ($60) {
          label = 21;
         } else {
          $$122$i = $$0211$i;
         }
        }
        if ((label|0) == 21) {
         label = 0;
         $$122$i = 175195;
        }
        switch ($61|0) {
        case 1280:  {
         $$0$i$i = 175266;
         break;
        }
        case 1281:  {
         $$0$i$i = 175249;
         break;
        }
        case 1282:  {
         $$0$i$i = 175228;
         break;
        }
        case 1285:  {
         $$0$i$i = 175211;
         break;
        }
        default: {
         $$0$i$i = 175203;
        }
        }
        HEAP32[$vararg_buffer>>2] = $$122$i;
        $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
        HEAP32[$vararg_ptr1>>2] = 175308;
        $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
        HEAP32[$vararg_ptr2>>2] = 464;
        $vararg_ptr3 = ((($vararg_buffer)) + 12|0);
        HEAP32[$vararg_ptr3>>2] = 181760;
        $vararg_ptr4 = ((($vararg_buffer)) + 16|0);
        HEAP32[$vararg_ptr4>>2] = $$0$i$i;
        $vararg_ptr5 = ((($vararg_buffer)) + 20|0);
        HEAP32[$vararg_ptr5>>2] = $61;
        (_SDL_SetError(175282,$vararg_buffer)|0);
        $62 = HEAP32[$54>>2]|0;
        $63 = (FUNCTION_TABLE_i[$62 & 8191]()|0);
        $64 = ($63|0)==(0);
        if ($64) {
         break L29;
        } else {
         $$0211$i = $$122$i;$61 = $63;
        }
       }
      }
     }
    } while(0);
    $65 = HEAP32[$41>>2]|0;
    _SDL_free($65);
    HEAP32[$41>>2] = $47;
    $$cast = $47;
    $66 = ($47|0)==(0);
    if ($66) {
     break;
    } else {
     $46 = $$cast;
    }
   }
   $$pre = HEAP32[$2>>2]|0;
   $67 = $$pre;
  }
  _SDL_GL_DeleteContext($67);
 }
 $68 = ((($2)) + 244|0);
 $69 = HEAP32[$68>>2]|0;
 _SDL_free($69);
 _SDL_free($2);
 _SDL_free($0);
 STACKTOP = sp;return;
}
function _SDL_GL_CreateContext($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $vararg_buffer3 = sp + 16|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $1 = HEAP32[52375]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  (_SDL_SetError(175439,$vararg_buffer)|0);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = ($0|0)==(0|0);
 if (!($3)) {
  $4 = HEAP32[$0>>2]|0;
  $5 = ((($1)) + 280|0);
  $6 = ($4|0)==($5|0);
  if ($6) {
   $7 = ((($0)) + 48|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = $8 & 2;
   $10 = ($9|0)==(0);
   if ($10) {
    (_SDL_SetError(175480,$vararg_buffer3)|0);
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $11 = ((($1)) + 176|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = (FUNCTION_TABLE_iii[$12 & 8191]($1,$0)|0);
   $14 = ($13|0)==(0|0);
   if ($14) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $15 = HEAP32[52375]|0;
   $16 = ((($15)) + 652|0);
   HEAP32[$16>>2] = $0;
   $17 = ((($15)) + 656|0);
   HEAP32[$17>>2] = $13;
   $18 = ((($15)) + 660|0);
   $19 = HEAP32[$18>>2]|0;
   (_SDL_TLSSet($19,$0,0)|0);
   $20 = HEAP32[52375]|0;
   $21 = ((($20)) + 664|0);
   $22 = HEAP32[$21>>2]|0;
   (_SDL_TLSSet($22,$13,0)|0);
   $$0 = $13;
   STACKTOP = sp;return ($$0|0);
  }
 }
 (_SDL_SetError(195204,$vararg_buffer1)|0);
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _SDL_GL_MakeCurrent($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$0$i = 0, $$0$i16 = 0, $$015 = 0, $$pre = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer3 = 0, $vararg_buffer5 = 0, $vararg_buffer7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $vararg_buffer7 = sp + 32|0;
 $vararg_buffer5 = sp + 24|0;
 $vararg_buffer3 = sp + 16|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $2 = HEAP32[52375]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  (_SDL_SetError(175439,$vararg_buffer)|0);
  $$0$i = 0;
 } else {
  $4 = ((($2)) + 660|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (_SDL_TLSGet($5)|0);
  $$0$i = $6;
 }
 $7 = ($$0$i|0)==($0|0);
 if ($7) {
  $8 = HEAP32[52375]|0;
  $9 = ($8|0)==(0|0);
  if ($9) {
   (_SDL_SetError(175439,$vararg_buffer1)|0);
   $$0$i16 = 0;
  } else {
   $10 = ((($8)) + 664|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (_SDL_TLSGet($11)|0);
   $$0$i16 = $12;
  }
  $13 = ($$0$i16|0)==($1|0);
  if ($13) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $14 = ($1|0)==(0|0);
 $$pre = HEAP32[52375]|0;
 do {
  if ($14) {
   $$015 = 0;
  } else {
   $15 = ($$pre|0)==(0|0);
   if ($15) {
    (_SDL_SetError(175439,$vararg_buffer3)|0);
    $$0 = -1;
    STACKTOP = sp;return ($$0|0);
   }
   $16 = ($0|0)==(0|0);
   if (!($16)) {
    $17 = HEAP32[$0>>2]|0;
    $18 = ((($$pre)) + 280|0);
    $19 = ($17|0)==($18|0);
    if ($19) {
     $20 = ((($0)) + 48|0);
     $21 = HEAP32[$20>>2]|0;
     $22 = $21 & 2;
     $23 = ($22|0)==(0);
     if (!($23)) {
      $$015 = $0;
      break;
     }
     $24 = (_SDL_SetError(175480,$vararg_buffer7)|0);
     $$0 = $24;
     STACKTOP = sp;return ($$0|0);
    }
   }
   (_SDL_SetError(195204,$vararg_buffer5)|0);
   $$0 = -1;
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 $25 = ((($$pre)) + 180|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (FUNCTION_TABLE_iiii[$26 & 8191]($$pre,$$015,$1)|0);
 $28 = ($27|0)==(0);
 if (!($28)) {
  $$0 = $27;
  STACKTOP = sp;return ($$0|0);
 }
 $29 = HEAP32[52375]|0;
 $30 = ((($29)) + 652|0);
 HEAP32[$30>>2] = $$015;
 $31 = ((($29)) + 656|0);
 HEAP32[$31>>2] = $1;
 $32 = ((($29)) + 660|0);
 $33 = HEAP32[$32>>2]|0;
 (_SDL_TLSSet($33,$$015,0)|0);
 $34 = HEAP32[52375]|0;
 $35 = ((($34)) + 664|0);
 $36 = HEAP32[$35>>2]|0;
 (_SDL_TLSSet($36,$1,0)|0);
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _SDL_GL_GetProcAddress($0) {
 $0 = $0|0;
 var $$04 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $vararg_buffer3 = sp + 16|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $1 = HEAP32[52375]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   (_SDL_SetError(175439,$vararg_buffer)|0);
   $$04 = 0;
  } else {
   $3 = ((($1)) + 168|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = ($4|0)==(0|0);
   if ($5) {
    (_SDL_SetError(181719,$vararg_buffer3)|0);
    $$04 = 0;
    break;
   }
   $6 = ((($1)) + 388|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($7|0)==(0);
   if ($8) {
    (_SDL_SetError(181690,$vararg_buffer1)|0);
    $$04 = 0;
    break;
   } else {
    $9 = (FUNCTION_TABLE_iii[$4 & 8191]($1,$0)|0);
    $$04 = $9;
    break;
   }
  }
 } while(0);
 STACKTOP = sp;return ($$04|0);
}
function _SDL_GetError() {
 var $$$080$i = 0, $$$0802$i = 0, $$$0804$i = 0, $$$0806$i = 0, $$$085$i = 0, $$$0851$i = 0, $$$0853$i = 0, $$$0855$i = 0, $$0$i = 0, $$078$ph26$i = 0, $$080$lcssa$i = 0, $$080$ph25$i = 0, $$08019$i = 0, $$082$ph24$i = 0, $$08218$i = 0, $$085$lcssa$i = 0, $$085$ph23$i = 0, $$08517$i = 0, $$1$i = 0, $$179$i = 0;
 var $$181$i = 0, $$183$i = 0, $$186$i = 0, $$2$i = 0, $$284$i = 0, $$off$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0.0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer4 = 0, $vararg_buffer7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(64|0);
 $vararg_buffer7 = sp + 24|0;
 $vararg_buffer4 = sp + 16|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $0 = sp + 32|0;
 HEAP8[217378] = 0;
 $1 = HEAP32[51558]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return (217378|0);
 }
 $3 = HEAP8[(206236)>>0]|0;
 $4 = ($3<<24>>24)==(0);
 L4: do {
  if ($4) {
   $$080$lcssa$i = 217378;$$085$lcssa$i = 1023;
  } else {
   $5 = ((($0)) + 1|0);
   $6 = ((($0)) + 30|0);
   $$078$ph26$i = 0;$$080$ph25$i = 217378;$$082$ph24$i = (206236);$$085$ph23$i = 1023;$63 = $3;
   while(1) {
    $$08019$i = $$080$ph25$i;$$08218$i = $$082$ph24$i;$$08517$i = $$085$ph23$i;$7 = $63;
    while(1) {
     $8 = ($7<<24>>24)==(37);
     if ($8) {
      break;
     }
     $53 = ((($$08218$i)) + 1|0);
     $54 = ((($$08019$i)) + 1|0);
     HEAP8[$$08019$i>>0] = $7;
     $55 = (($$08517$i) + -1)|0;
     $56 = HEAP8[$53>>0]|0;
     $57 = ($56<<24>>24)!=(0);
     $58 = ($$08517$i|0)>(1);
     $59 = $58 & $57;
     if ($59) {
      $$08019$i = $54;$$08218$i = $53;$$08517$i = $55;$7 = $56;
     } else {
      $$080$lcssa$i = $54;$$085$lcssa$i = $55;
      break L4;
     }
    }
    $9 = ((($$08218$i)) + 1|0);
    HEAP8[$0>>0] = 37;
    $$0$i = $5;$$183$i = $9;
    while(1) {
     $10 = HEAP8[$$183$i>>0]|0;
     $11 = ($10<<24>>24)==(46);
     $$off$i = (($10) + -48)<<24>>24;
     $12 = ($$off$i&255)<(10);
     $or$cond$i = $11 | $12;
     if (!($or$cond$i)) {
      label = 9;
      break;
     }
     $13 = ($$0$i>>>0)<($6>>>0);
     $14 = ((($$183$i)) + 1|0);
     $15 = ((($$0$i)) + 1|0);
     HEAP8[$$0$i>>0] = $10;
     if ($13) {
      $$0$i = $15;$$183$i = $14;
     } else {
      $$1$i = $15;$$284$i = $14;
      break;
     }
    }
    if ((label|0) == 9) {
     label = 0;
     $16 = ((($$183$i)) + 1|0);
     $17 = ((($$0$i)) + 1|0);
     HEAP8[$$0$i>>0] = $10;
     $$1$i = $17;$$284$i = $16;
    }
    HEAP8[$$1$i>>0] = 0;
    $18 = HEAP8[$$0$i>>0]|0;
    $19 = $18 << 24 >> 24;
    switch ($19|0) {
    case 37:  {
     $20 = ((($$08019$i)) + 1|0);
     HEAP8[$$08019$i>>0] = 37;
     $21 = (($$08517$i) + -1)|0;
     $$179$i = $$078$ph26$i;$$181$i = $20;$$186$i = $21;
     break;
    }
    case 88: case 120: case 111: case 117: case 100: case 105: case 99:  {
     $22 = (($$078$ph26$i) + 1)|0;
     $23 = (206368 + ($$078$ph26$i<<7)|0);
     $24 = HEAP32[$23>>2]|0;
     HEAP32[$vararg_buffer>>2] = $24;
     $25 = (_SDL_snprintf($$08019$i,$$08517$i,$0,$vararg_buffer)|0);
     $26 = ($25|0)>(0);
     $27 = (($$08019$i) + ($25)|0);
     $28 = $26 ? $25 : 0;
     $$$085$i = (($$08517$i) - ($28))|0;
     $$$080$i = $26 ? $27 : $$08019$i;
     $$179$i = $22;$$181$i = $$$080$i;$$186$i = $$$085$i;
     break;
    }
    case 102:  {
     $29 = (($$078$ph26$i) + 1)|0;
     $30 = (206368 + ($$078$ph26$i<<7)|0);
     $31 = +HEAPF64[$30>>3];
     HEAPF64[$vararg_buffer1>>3] = $31;
     $32 = (_SDL_snprintf($$08019$i,$$08517$i,$0,$vararg_buffer1)|0);
     $33 = ($32|0)>(0);
     $34 = (($$08019$i) + ($32)|0);
     $35 = $33 ? $32 : 0;
     $$$0851$i = (($$08517$i) - ($35))|0;
     $$$0802$i = $33 ? $34 : $$08019$i;
     $$179$i = $29;$$181$i = $$$0802$i;$$186$i = $$$0851$i;
     break;
    }
    case 112:  {
     $36 = (($$078$ph26$i) + 1)|0;
     $37 = (206368 + ($$078$ph26$i<<7)|0);
     $38 = HEAP32[$37>>2]|0;
     HEAP32[$vararg_buffer4>>2] = $38;
     $39 = (_SDL_snprintf($$08019$i,$$08517$i,$0,$vararg_buffer4)|0);
     $40 = ($39|0)>(0);
     $41 = (($$08019$i) + ($39)|0);
     $42 = $40 ? $39 : 0;
     $$$0853$i = (($$08517$i) - ($42))|0;
     $$$0804$i = $40 ? $41 : $$08019$i;
     $$179$i = $36;$$181$i = $$$0804$i;$$186$i = $$$0853$i;
     break;
    }
    case 115:  {
     $43 = (($$078$ph26$i) + 1)|0;
     $44 = (206368 + ($$078$ph26$i<<7)|0);
     HEAP32[$vararg_buffer7>>2] = $44;
     $45 = (_SDL_snprintf($$08019$i,$$08517$i,$0,$vararg_buffer7)|0);
     $46 = ($45|0)>(0);
     $47 = (($$08019$i) + ($45)|0);
     $48 = $46 ? $45 : 0;
     $$$0855$i = (($$08517$i) - ($48))|0;
     $$$0806$i = $46 ? $47 : $$08019$i;
     $$179$i = $43;$$181$i = $$$0806$i;$$186$i = $$$0855$i;
     break;
    }
    default: {
     $$179$i = $$078$ph26$i;$$181$i = $$08019$i;$$186$i = $$08517$i;
    }
    }
    $49 = HEAP8[$$284$i>>0]|0;
    $50 = ($49<<24>>24)!=(0);
    $51 = ($$186$i|0)>(0);
    $52 = $51 & $50;
    if ($52) {
     $$078$ph26$i = $$179$i;$$080$ph25$i = $$181$i;$$082$ph24$i = $$284$i;$$085$ph23$i = $$186$i;$63 = $49;
    } else {
     $$080$lcssa$i = $$181$i;$$085$lcssa$i = $$186$i;
     break L4;
    }
   }
  }
 } while(0);
 $60 = ($$085$lcssa$i|0)<(0);
 $61 = (($$085$lcssa$i) + -1)|0;
 $62 = (($$080$lcssa$i) + ($61)|0);
 $$2$i = $60 ? $62 : $$080$lcssa$i;
 HEAP8[$$2$i>>0] = 0;
 STACKTOP = sp;return (217378|0);
}
function _SDL_SetError($0,$varargs) {
 $0 = $0|0;
 $varargs = $varargs|0;
 var $$ = 0, $$034$be = 0, $$03437 = 0, $$1 = 0, $$2 = 0, $$off = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $arglist_current = 0, $arglist_current2 = 0, $arglist_current5 = 0, $arglist_current8 = 0, $arglist_next = 0, $arglist_next3 = 0, $arglist_next6 = 0, $arglist_next9 = 0, $brmerge = 0, $expanded = 0, $expanded10 = 0, $expanded12 = 0, $expanded13 = 0, $expanded14 = 0, $expanded16 = 0, $expanded17 = 0, $expanded19 = 0, $expanded20 = 0;
 var $expanded21 = 0, $expanded23 = 0, $expanded24 = 0, $expanded26 = 0, $expanded27 = 0, $expanded28 = 0, $expanded3 = 0, $expanded5 = 0, $expanded6 = 0, $expanded7 = 0, $expanded9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $vararg_buffer = sp;
 $1 = sp + 8|0;
 $2 = ($0|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return -1;
 }
 HEAP32[51558] = 1;
 (_SDL_strlcpy((206236),$0,128)|0);
 HEAP32[$1>>2] = $varargs;
 HEAP32[(206364)>>2] = 0;
 $3 = HEAP8[$0>>0]|0;
 $4 = ($3<<24>>24)==(0);
 L4: do {
  if (!($4)) {
   $$03437 = $0;$21 = 0;$6 = $3;
   while(1) {
    $5 = ((($$03437)) + 1|0);
    $7 = ($6<<24>>24)==(37);
    if ($7) {
     $$1 = $5;
     while(1) {
      $8 = HEAP8[$$1>>0]|0;
      $9 = ($8<<24>>24)==(46);
      $$off = (($8) + -48)<<24>>24;
      $10 = ($$off&255)<(10);
      $11 = ((($$1)) + 1|0);
      $brmerge = $9 | $10;
      if ($brmerge) {
       $$1 = $11;
      } else {
       break;
      }
     }
     $12 = $8 << 24 >> 24;
     switch ($12|0) {
     case 0:  {
      $$2 = $$1;$52 = $21;
      break;
     }
     case 88: case 120: case 111: case 117: case 100: case 105: case 99:  {
      $arglist_current = HEAP32[$1>>2]|0;
      $13 = $arglist_current;
      $14 = ((0) + 4|0);
      $expanded3 = $14;
      $expanded = (($expanded3) - 1)|0;
      $15 = (($13) + ($expanded))|0;
      $16 = ((0) + 4|0);
      $expanded7 = $16;
      $expanded6 = (($expanded7) - 1)|0;
      $expanded5 = $expanded6 ^ -1;
      $17 = $15 & $expanded5;
      $18 = $17;
      $19 = HEAP32[$18>>2]|0;
      $arglist_next = ((($18)) + 4|0);
      HEAP32[$1>>2] = $arglist_next;
      $20 = (($21) + 1)|0;
      HEAP32[(206364)>>2] = $20;
      $22 = (206368 + ($21<<7)|0);
      HEAP32[$22>>2] = $19;
      $$2 = $11;$52 = $20;
      break;
     }
     case 102:  {
      $arglist_current2 = HEAP32[$1>>2]|0;
      $23 = $arglist_current2;
      $24 = ((0) + 8|0);
      $expanded10 = $24;
      $expanded9 = (($expanded10) - 1)|0;
      $25 = (($23) + ($expanded9))|0;
      $26 = ((0) + 8|0);
      $expanded14 = $26;
      $expanded13 = (($expanded14) - 1)|0;
      $expanded12 = $expanded13 ^ -1;
      $27 = $25 & $expanded12;
      $28 = $27;
      $29 = +HEAPF64[$28>>3];
      $arglist_next3 = ((($28)) + 8|0);
      HEAP32[$1>>2] = $arglist_next3;
      $30 = (($21) + 1)|0;
      HEAP32[(206364)>>2] = $30;
      $31 = (206368 + ($21<<7)|0);
      HEAPF64[$31>>3] = $29;
      $$2 = $11;$52 = $30;
      break;
     }
     case 112:  {
      $arglist_current5 = HEAP32[$1>>2]|0;
      $32 = $arglist_current5;
      $33 = ((0) + 4|0);
      $expanded17 = $33;
      $expanded16 = (($expanded17) - 1)|0;
      $34 = (($32) + ($expanded16))|0;
      $35 = ((0) + 4|0);
      $expanded21 = $35;
      $expanded20 = (($expanded21) - 1)|0;
      $expanded19 = $expanded20 ^ -1;
      $36 = $34 & $expanded19;
      $37 = $36;
      $38 = HEAP32[$37>>2]|0;
      $arglist_next6 = ((($37)) + 4|0);
      HEAP32[$1>>2] = $arglist_next6;
      $39 = (($21) + 1)|0;
      HEAP32[(206364)>>2] = $39;
      $40 = (206368 + ($21<<7)|0);
      HEAP32[$40>>2] = $38;
      $$2 = $11;$52 = $39;
      break;
     }
     case 115:  {
      $arglist_current8 = HEAP32[$1>>2]|0;
      $41 = $arglist_current8;
      $42 = ((0) + 4|0);
      $expanded24 = $42;
      $expanded23 = (($expanded24) - 1)|0;
      $43 = (($41) + ($expanded23))|0;
      $44 = ((0) + 4|0);
      $expanded28 = $44;
      $expanded27 = (($expanded28) - 1)|0;
      $expanded26 = $expanded27 ^ -1;
      $45 = $43 & $expanded26;
      $46 = $45;
      $47 = HEAP32[$46>>2]|0;
      $arglist_next9 = ((($46)) + 4|0);
      HEAP32[$1>>2] = $arglist_next9;
      $48 = ($47|0)==(0|0);
      $$ = $48 ? 199781 : $47;
      $49 = (206368 + ($21<<7)|0);
      (_SDL_strlcpy($49,$$,128)|0);
      $50 = HEAP32[(206364)>>2]|0;
      $51 = (($50) + 1)|0;
      HEAP32[(206364)>>2] = $51;
      $$2 = $11;$52 = $51;
      break;
     }
     default: {
      $$2 = $11;$52 = $21;
     }
     }
     $53 = ($52|0)>(4);
     if ($53) {
      break L4;
     } else {
      $$034$be = $$2;$56 = $52;
     }
    } else {
     $$034$be = $5;$56 = $21;
    }
    $54 = HEAP8[$$034$be>>0]|0;
    $55 = ($54<<24>>24)==(0);
    if ($55) {
     break;
    } else {
     $$03437 = $$034$be;$21 = $56;$6 = $54;
    }
   }
  }
 } while(0);
 (_SDL_GetError()|0);
 HEAP32[$vararg_buffer>>2] = 217378;
 _SDL_LogDebug(1,181640,$vararg_buffer);
 STACKTOP = sp;return -1;
}
function _SDL_GL_SetSwapInterval($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $vararg_buffer3 = sp + 16|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $1 = HEAP32[52375]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $3 = (_SDL_SetError(175439,$vararg_buffer)|0);
  $$0 = $3;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = ((($1)) + 664|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (_SDL_TLSGet($5)|0);
 $7 = ($6|0)==(0|0);
 if ($7) {
  $8 = (_SDL_SetError(181557,$vararg_buffer1)|0);
  $$0 = $8;
  STACKTOP = sp;return ($$0|0);
 }
 $9 = HEAP32[52375]|0;
 $10 = ((($9)) + 188|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0|0);
 if ($12) {
  $14 = (_SDL_SetError(181597,$vararg_buffer3)|0);
  $$0 = $14;
  STACKTOP = sp;return ($$0|0);
 } else {
  $13 = (FUNCTION_TABLE_iii[$11 & 8191]($9,$0)|0);
  $$0 = $13;
  STACKTOP = sp;return ($$0|0);
 }
 return (0)|0;
}
function _SDL_GL_GetSwapInterval() {
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[52375]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  $$0 = 0;
  return ($$0|0);
 }
 $2 = ((($0)) + 664|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (_SDL_TLSGet($3)|0);
 $5 = ($4|0)==(0|0);
 if ($5) {
  $$0 = 0;
  return ($$0|0);
 }
 $6 = HEAP32[52375]|0;
 $7 = ((($6)) + 192|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if ($9) {
  $$0 = 0;
  return ($$0|0);
 }
 $10 = (FUNCTION_TABLE_ii[$8 & 8191]($6)|0);
 $$0 = $10;
 return ($$0|0);
}
function _GLES2_WindowEvent($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 12|0);
 $3 = HEAP8[$2>>0]|0;
 switch ($3<<24>>24) {
 case 2: case 1: case 6:  {
  HEAP32[52374] = 0;
  return;
  break;
 }
 case 7:  {
  $4 = ((($0)) + 320|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ((($5)) + 88|0);
  $7 = HEAP32[$6>>2]|0;
  FUNCTION_TABLE_v[$7 & 8191]();
  return;
  break;
 }
 default: {
  return;
 }
 }
}
function _GLES2_GetOutputSize($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 188|0);
 $4 = HEAP32[$3>>2]|0;
 _SDL_GL_GetDrawableSize($4,$1,$2);
 return 0;
}
function _GLES2_CreateTexture($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$ = 0, $$$i = 0, $$0 = 0, $$0$i$i = 0, $$0$i$i173 = 0, $$0$i$i181 = 0, $$0$i$i189 = 0, $$0$i$i197 = 0, $$0$i$i205 = 0, $$0$i$i213 = 0, $$0$i$i221 = 0, $$0$i$i231 = 0, $$0$i226 = 0, $$0167 = 0, $$020$i = 0, $$0211$i = 0, $$0211$i228 = 0, $$022$i = 0, $$1 = 0, $$1165 = 0;
 var $$122$i = 0, $$122$i230 = 0, $$mask = 0, $$pre = 0, $$pre$i = 0, $$sink = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0;
 var $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0;
 var $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0;
 var $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0;
 var $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0;
 var $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0;
 var $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $cond$i = 0, $cond21$i = 0, $or$cond = 0, $phitmp = 0, $switch$split2D = 0, $switch$split722D = 0, $switch$split752D = 0;
 var $switch$split782D = 0, $switch$split812D = 0, $switch$split842D = 0, $switch$split872D = 0, $switch$split902D = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer16 = 0, $vararg_buffer24 = 0, $vararg_buffer32 = 0, $vararg_buffer40 = 0, $vararg_buffer48 = 0, $vararg_buffer56 = 0, $vararg_buffer64 = 0, $vararg_buffer8 = 0, $vararg_ptr11 = 0, $vararg_ptr12 = 0, $vararg_ptr13 = 0, $vararg_ptr14 = 0, $vararg_ptr15 = 0;
 var $vararg_ptr19 = 0, $vararg_ptr20 = 0, $vararg_ptr21 = 0, $vararg_ptr22 = 0, $vararg_ptr23 = 0, $vararg_ptr27 = 0, $vararg_ptr28 = 0, $vararg_ptr29 = 0, $vararg_ptr3 = 0, $vararg_ptr30 = 0, $vararg_ptr31 = 0, $vararg_ptr35 = 0, $vararg_ptr36 = 0, $vararg_ptr37 = 0, $vararg_ptr38 = 0, $vararg_ptr39 = 0, $vararg_ptr4 = 0, $vararg_ptr43 = 0, $vararg_ptr44 = 0, $vararg_ptr45 = 0;
 var $vararg_ptr46 = 0, $vararg_ptr47 = 0, $vararg_ptr5 = 0, $vararg_ptr51 = 0, $vararg_ptr52 = 0, $vararg_ptr53 = 0, $vararg_ptr54 = 0, $vararg_ptr55 = 0, $vararg_ptr59 = 0, $vararg_ptr6 = 0, $vararg_ptr60 = 0, $vararg_ptr61 = 0, $vararg_ptr62 = 0, $vararg_ptr63 = 0, $vararg_ptr67 = 0, $vararg_ptr68 = 0, $vararg_ptr69 = 0, $vararg_ptr7 = 0, $vararg_ptr70 = 0, $vararg_ptr71 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(224|0);
 $vararg_buffer64 = sp + 200|0;
 $vararg_buffer56 = sp + 176|0;
 $vararg_buffer48 = sp + 152|0;
 $vararg_buffer40 = sp + 128|0;
 $vararg_buffer32 = sp + 104|0;
 $vararg_buffer24 = sp + 80|0;
 $vararg_buffer16 = sp + 56|0;
 $vararg_buffer8 = sp + 32|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $2 = ((($0)) + 320|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[52374]|0;
 $5 = HEAP32[$3>>2]|0;
 $6 = ($4|0)==($5|0);
 if ($6) {
  $14 = $3;
  label = 4;
 } else {
  $7 = ((($3)) + 268|0);
  HEAP32[$7>>2] = 0;
  $8 = ((($0)) + 188|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (_SDL_GL_MakeCurrent($9,$5)|0);
  $11 = ($10|0)<(0);
  if (!($11)) {
   $12 = HEAP32[$3>>2]|0;
   HEAP32[52374] = $12;
   (_GLES2_UpdateViewport($0)|0);
   $$pre$i = HEAP32[$2>>2]|0;
   $14 = $$pre$i;
   label = 4;
  }
 }
 if ((label|0) == 4) {
  $13 = ((($14)) + 4|0);
  $15 = HEAP32[$13>>2]|0;
  $16 = ($15|0)==(0);
  if (!($16)) {
   $17 = ((($14)) + 108|0);
   while(1) {
    $18 = HEAP32[$17>>2]|0;
    $19 = (FUNCTION_TABLE_i[$18 & 8191]()|0);
    $20 = ($19|0)==(0);
    if ($20) {
     break;
    }
   }
  }
 }
 $21 = ((($1)) + 4|0);
 $22 = HEAP32[$21>>2]|0;
 $switch$split2D = ($22|0)<(825382478);
 L10: do {
  if ($switch$split2D) {
   $switch$split752D = ($22|0)<(374740996);
   if ($switch$split752D) {
    $switch$split812D = ($22|0)<(372645892);
    if ($switch$split812D) {
     switch ($22|0) {
     case 370546692:  {
      $$0167 = 6408;
      break L10;
      break;
     }
     default: {
      label = 9;
      break L10;
     }
     }
    } else {
     switch ($22|0) {
     case 372645892:  {
      $$0167 = 6408;
      break L10;
      break;
     }
     default: {
      label = 9;
      break L10;
     }
     }
    }
   } else {
    $switch$split842D = ($22|0)<(376840196);
    if ($switch$split842D) {
     switch ($22|0) {
     case 374740996:  {
      $$0167 = 6408;
      break L10;
      break;
     }
     default: {
      label = 9;
      break L10;
     }
     }
    } else {
     switch ($22|0) {
     case 376840196:  {
      $$0167 = 6408;
      break L10;
      break;
     }
     default: {
      label = 9;
      break L10;
     }
     }
    }
   }
  } else {
   $switch$split782D = ($22|0)<(842094169);
   L22: do {
    if ($switch$split782D) {
     $switch$split872D = ($22|0)<(842094158);
     if ($switch$split872D) {
      switch ($22|0) {
      case 825382478:  {
       break L22;
       break;
      }
      default: {
       label = 9;
       break L10;
      }
      }
     } else {
      switch ($22|0) {
      case 842094158:  {
       break L22;
       break;
      }
      default: {
       label = 9;
       break L10;
      }
      }
     }
    } else {
     $switch$split902D = ($22|0)<(1448433993);
     if ($switch$split902D) {
      switch ($22|0) {
      case 842094169:  {
       break L22;
       break;
      }
      default: {
       label = 9;
       break L10;
      }
      }
     } else {
      switch ($22|0) {
      case 1448433993:  {
       break L22;
       break;
      }
      default: {
       label = 9;
       break L10;
      }
      }
     }
    }
   } while(0);
   $$0167 = 6409;
  }
 } while(0);
 if ((label|0) == 9) {
  $23 = (_SDL_SetError(181443,$vararg_buffer)|0);
  $$1165 = $23;
  STACKTOP = sp;return ($$1165|0);
 }
 $24 = (_SDL_calloc(1,44)|0);
 $25 = ($24|0)==(0|0);
 if ($25) {
  $26 = (_SDL_Error(0)|0);
  $$1165 = $26;
  STACKTOP = sp;return ($$1165|0);
 }
 HEAP32[$24>>2] = 0;
 $27 = ((($24)) + 4|0);
 HEAP32[$27>>2] = 3553;
 $28 = ((($24)) + 8|0);
 HEAP32[$28>>2] = $$0167;
 $29 = ((($24)) + 12|0);
 HEAP32[$29>>2] = 5121;
 $30 = HEAP32[$21>>2]|0;
 $31 = ($30|0)==(1448433993);
 $32 = ($30|0)==(842094169);
 $$ = $31 | $32;
 $33 = $$&1;
 $34 = ((($24)) + 24|0);
 HEAP32[$34>>2] = $33;
 $35 = ($30|0)==(842094158);
 $36 = ($30|0)==(825382478);
 $37 = $35 | $36;
 $38 = $37&1;
 $39 = ((($24)) + 28|0);
 HEAP32[$39>>2] = $38;
 $40 = ((($24)) + 36|0);
 HEAP32[$40>>2] = 0;
 $41 = ((($24)) + 32|0);
 HEAP32[$41>>2] = 0;
 $42 = (_SDL_GetHint(182819)|0);
 $43 = ($42|0)==(0|0);
 if ($43) {
  $116 = 9728;
 } else {
  $44 = HEAP8[$42>>0]|0;
  $45 = ($44<<24>>24)==(48);
  if ($45) {
   $116 = 9728;
  } else {
   $46 = (_SDL_strcasecmp($42,182844)|0);
   $47 = ($46|0)==(0);
   $$$i = $47 ? 9728 : 9729;
   $116 = $$$i;
  }
 }
 $48 = ((($1)) + 8|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = ($49|0)==(1);
 if ($50) {
  $51 = ((($1)) + 12|0);
  $52 = HEAP32[$51>>2]|0;
  $53 = HEAP32[$21>>2]|0;
  $54 = ($53|0)==(0);
  $$mask = $53 & -268435456;
  $55 = ($$mask|0)==(268435456);
  $or$cond = $54 | $55;
  L46: do {
   if ($or$cond) {
    $57 = $53 & 255;
    $59 = $57;
   } else {
    $switch$split722D = ($53|0)<(1498831189);
    if ($switch$split722D) {
     switch ($53|0) {
     case 844715353:  {
      $59 = 2;
      break L46;
      break;
     }
     default: {
     }
     }
    } else {
     switch ($53|0) {
     case 1498831189:  {
      $59 = 2;
      break L46;
      break;
     }
     default: {
     }
     }
    }
    $56 = ($53|0)==(1431918169);
    $phitmp = $56 ? 2 : 1;
    $59 = $phitmp;
   }
  } while(0);
  $58 = Math_imul($59, $52)|0;
  $60 = ((($24)) + 20|0);
  HEAP32[$60>>2] = $58;
  $61 = ((($1)) + 16|0);
  $62 = HEAP32[$61>>2]|0;
  $63 = Math_imul($62, $58)|0;
  $64 = HEAP32[$34>>2]|0;
  $65 = ($64|0)==(0);
  if ($65) {
   $$0 = $63;
  } else {
   $66 = (($63|0) / 2)&-1;
   $67 = (($66) + ($63))|0;
   $$0 = $67;
  }
  $68 = HEAP32[$39>>2]|0;
  $69 = ($68|0)==(0);
  if ($69) {
   $$1 = $$0;
  } else {
   $70 = (($63|0) / 2)&-1;
   $71 = (($70) + ($$0))|0;
   $$1 = $71;
  }
  $72 = (_SDL_calloc(1,$$1)|0);
  $73 = ((($24)) + 16|0);
  HEAP32[$73>>2] = $72;
  $74 = ($72|0)==(0|0);
  if ($74) {
   _SDL_free($24);
   $75 = (_SDL_Error(0)|0);
   $$1165 = $75;
   STACKTOP = sp;return ($$1165|0);
  }
 }
 $76 = HEAP32[$2>>2]|0;
 $77 = ((($76)) + 4|0);
 $78 = HEAP32[$77>>2]|0;
 $79 = ($78|0)==(0);
 L63: do {
  if (!($79)) {
   $80 = ((($76)) + 108|0);
   $81 = HEAP32[$80>>2]|0;
   $82 = (FUNCTION_TABLE_i[$81 & 8191]()|0);
   $83 = ($82|0)==(0);
   if (!($83)) {
    $$0211$i = 221531;$87 = $82;
    while(1) {
     $84 = ($$0211$i|0)==(0|0);
     if ($84) {
      label = 30;
     } else {
      $85 = HEAP8[$$0211$i>>0]|0;
      $86 = ($85<<24>>24)==(0);
      if ($86) {
       label = 30;
      } else {
       $$122$i = $$0211$i;
      }
     }
     if ((label|0) == 30) {
      label = 0;
      $$122$i = 175195;
     }
     switch ($87|0) {
     case 1280:  {
      $$0$i$i = 175266;
      break;
     }
     case 1281:  {
      $$0$i$i = 175249;
      break;
     }
     case 1282:  {
      $$0$i$i = 175228;
      break;
     }
     case 1285:  {
      $$0$i$i = 175211;
      break;
     }
     default: {
      $$0$i$i = 175203;
     }
     }
     HEAP32[$vararg_buffer1>>2] = $$122$i;
     $vararg_ptr3 = ((($vararg_buffer1)) + 4|0);
     HEAP32[$vararg_ptr3>>2] = 175308;
     $vararg_ptr4 = ((($vararg_buffer1)) + 8|0);
     HEAP32[$vararg_ptr4>>2] = 574;
     $vararg_ptr5 = ((($vararg_buffer1)) + 12|0);
     HEAP32[$vararg_ptr5>>2] = 181472;
     $vararg_ptr6 = ((($vararg_buffer1)) + 16|0);
     HEAP32[$vararg_ptr6>>2] = $$0$i$i;
     $vararg_ptr7 = ((($vararg_buffer1)) + 20|0);
     HEAP32[$vararg_ptr7>>2] = $87;
     (_SDL_SetError(175282,$vararg_buffer1)|0);
     $88 = HEAP32[$80>>2]|0;
     $89 = (FUNCTION_TABLE_i[$88 & 8191]()|0);
     $90 = ($89|0)==(0);
     if ($90) {
      break L63;
     } else {
      $$0211$i = $$122$i;$87 = $89;
     }
    }
   }
  }
 } while(0);
 $91 = HEAP32[$34>>2]|0;
 $92 = ($91|0)==(0);
 if (!($92)) {
  $93 = ((($3)) + 96|0);
  $94 = HEAP32[$93>>2]|0;
  FUNCTION_TABLE_vii[$94 & 8191](1,$41);
  $95 = HEAP32[$2>>2]|0;
  $96 = ((($95)) + 4|0);
  $97 = HEAP32[$96>>2]|0;
  $98 = ($97|0)==(0);
  if (!($98)) {
   $99 = ((($95)) + 108|0);
   $100 = HEAP32[$99>>2]|0;
   $101 = (FUNCTION_TABLE_i[$100 & 8191]()|0);
   $102 = ($101|0)==(0);
   if (!($102)) {
    $103 = $101;
    while(1) {
     switch ($103|0) {
     case 1280:  {
      $$0$i$i173 = 175266;
      break;
     }
     case 1281:  {
      $$0$i$i173 = 175249;
      break;
     }
     case 1282:  {
      $$0$i$i173 = 175228;
      break;
     }
     case 1285:  {
      $$0$i$i173 = 175211;
      break;
     }
     default: {
      $$0$i$i173 = 175203;
     }
     }
     HEAP32[$vararg_buffer8>>2] = 181527;
     $vararg_ptr11 = ((($vararg_buffer8)) + 4|0);
     HEAP32[$vararg_ptr11>>2] = 175308;
     $vararg_ptr12 = ((($vararg_buffer8)) + 8|0);
     HEAP32[$vararg_ptr12>>2] = 578;
     $vararg_ptr13 = ((($vararg_buffer8)) + 12|0);
     HEAP32[$vararg_ptr13>>2] = 181472;
     $vararg_ptr14 = ((($vararg_buffer8)) + 16|0);
     HEAP32[$vararg_ptr14>>2] = $$0$i$i173;
     $vararg_ptr15 = ((($vararg_buffer8)) + 20|0);
     HEAP32[$vararg_ptr15>>2] = $103;
     (_SDL_SetError(175282,$vararg_buffer8)|0);
     $104 = HEAP32[$99>>2]|0;
     $105 = (FUNCTION_TABLE_i[$104 & 8191]()|0);
     $106 = ($105|0)==(0);
     if ($106) {
      $$1165 = -1;
      break;
     } else {
      $103 = $105;
     }
    }
    STACKTOP = sp;return ($$1165|0);
   }
  }
  $107 = ((($3)) + 16|0);
  $108 = HEAP32[$107>>2]|0;
  FUNCTION_TABLE_vi[$108 & 8191](33986);
  $109 = ((($3)) + 28|0);
  $110 = HEAP32[$109>>2]|0;
  $111 = HEAP32[$27>>2]|0;
  $112 = HEAP32[$41>>2]|0;
  FUNCTION_TABLE_vii[$110 & 8191]($111,$112);
  $113 = ((($3)) + 160|0);
  $114 = HEAP32[$113>>2]|0;
  $115 = HEAP32[$27>>2]|0;
  FUNCTION_TABLE_viii[$114 & 8191]($115,10241,$116);
  $117 = HEAP32[$113>>2]|0;
  $118 = HEAP32[$27>>2]|0;
  FUNCTION_TABLE_viii[$117 & 8191]($118,10240,$116);
  $119 = HEAP32[$113>>2]|0;
  $120 = HEAP32[$27>>2]|0;
  FUNCTION_TABLE_viii[$119 & 8191]($120,10242,33071);
  $121 = HEAP32[$113>>2]|0;
  $122 = HEAP32[$27>>2]|0;
  FUNCTION_TABLE_viii[$121 & 8191]($122,10243,33071);
  $123 = ((($3)) + 156|0);
  $124 = HEAP32[$123>>2]|0;
  $125 = HEAP32[$27>>2]|0;
  $126 = ((($1)) + 12|0);
  $127 = HEAP32[$126>>2]|0;
  $128 = (($127|0) / 2)&-1;
  $129 = ((($1)) + 16|0);
  $130 = HEAP32[$129>>2]|0;
  $131 = (($130|0) / 2)&-1;
  FUNCTION_TABLE_viiiiiiiii[$124 & 8191]($125,0,$$0167,$128,$131,0,$$0167,5121,0);
  $132 = HEAP32[$93>>2]|0;
  FUNCTION_TABLE_vii[$132 & 8191](1,$40);
  $133 = HEAP32[$2>>2]|0;
  $134 = ((($133)) + 4|0);
  $135 = HEAP32[$134>>2]|0;
  $136 = ($135|0)==(0);
  if (!($136)) {
   $137 = ((($133)) + 108|0);
   $138 = HEAP32[$137>>2]|0;
   $139 = (FUNCTION_TABLE_i[$138 & 8191]()|0);
   $140 = ($139|0)==(0);
   if (!($140)) {
    $141 = $139;
    while(1) {
     switch ($141|0) {
     case 1280:  {
      $$0$i$i181 = 175266;
      break;
     }
     case 1281:  {
      $$0$i$i181 = 175249;
      break;
     }
     case 1282:  {
      $$0$i$i181 = 175228;
      break;
     }
     case 1285:  {
      $$0$i$i181 = 175211;
      break;
     }
     default: {
      $$0$i$i181 = 175203;
     }
     }
     HEAP32[$vararg_buffer16>>2] = 181527;
     $vararg_ptr19 = ((($vararg_buffer16)) + 4|0);
     HEAP32[$vararg_ptr19>>2] = 175308;
     $vararg_ptr20 = ((($vararg_buffer16)) + 8|0);
     HEAP32[$vararg_ptr20>>2] = 590;
     $vararg_ptr21 = ((($vararg_buffer16)) + 12|0);
     HEAP32[$vararg_ptr21>>2] = 181472;
     $vararg_ptr22 = ((($vararg_buffer16)) + 16|0);
     HEAP32[$vararg_ptr22>>2] = $$0$i$i181;
     $vararg_ptr23 = ((($vararg_buffer16)) + 20|0);
     HEAP32[$vararg_ptr23>>2] = $141;
     (_SDL_SetError(175282,$vararg_buffer16)|0);
     $142 = HEAP32[$137>>2]|0;
     $143 = (FUNCTION_TABLE_i[$142 & 8191]()|0);
     $144 = ($143|0)==(0);
     if ($144) {
      $$1165 = -1;
      break;
     } else {
      $141 = $143;
     }
    }
    STACKTOP = sp;return ($$1165|0);
   }
  }
  $145 = HEAP32[$107>>2]|0;
  FUNCTION_TABLE_vi[$145 & 8191](33985);
  $146 = HEAP32[$109>>2]|0;
  $147 = HEAP32[$27>>2]|0;
  $148 = HEAP32[$40>>2]|0;
  FUNCTION_TABLE_vii[$146 & 8191]($147,$148);
  $149 = HEAP32[$113>>2]|0;
  $150 = HEAP32[$27>>2]|0;
  FUNCTION_TABLE_viii[$149 & 8191]($150,10241,$116);
  $151 = HEAP32[$113>>2]|0;
  $152 = HEAP32[$27>>2]|0;
  FUNCTION_TABLE_viii[$151 & 8191]($152,10240,$116);
  $153 = HEAP32[$113>>2]|0;
  $154 = HEAP32[$27>>2]|0;
  FUNCTION_TABLE_viii[$153 & 8191]($154,10242,33071);
  $155 = HEAP32[$113>>2]|0;
  $156 = HEAP32[$27>>2]|0;
  FUNCTION_TABLE_viii[$155 & 8191]($156,10243,33071);
  $157 = HEAP32[$123>>2]|0;
  $158 = HEAP32[$27>>2]|0;
  $159 = HEAP32[$126>>2]|0;
  $160 = (($159|0) / 2)&-1;
  $161 = HEAP32[$129>>2]|0;
  $162 = (($161|0) / 2)&-1;
  FUNCTION_TABLE_viiiiiiiii[$157 & 8191]($158,0,$$0167,$160,$162,0,$$0167,5121,0);
  $163 = HEAP32[$2>>2]|0;
  $164 = ((($163)) + 4|0);
  $165 = HEAP32[$164>>2]|0;
  $166 = ($165|0)==(0);
  if (!($166)) {
   $167 = ((($163)) + 108|0);
   $168 = HEAP32[$167>>2]|0;
   $169 = (FUNCTION_TABLE_i[$168 & 8191]()|0);
   $170 = ($169|0)==(0);
   if (!($170)) {
    $171 = $169;
    while(1) {
     switch ($171|0) {
     case 1280:  {
      $$0$i$i189 = 175266;
      break;
     }
     case 1281:  {
      $$0$i$i189 = 175249;
      break;
     }
     case 1282:  {
      $$0$i$i189 = 175228;
      break;
     }
     case 1285:  {
      $$0$i$i189 = 175211;
      break;
     }
     default: {
      $$0$i$i189 = 175203;
     }
     }
     HEAP32[$vararg_buffer24>>2] = 181542;
     $vararg_ptr27 = ((($vararg_buffer24)) + 4|0);
     HEAP32[$vararg_ptr27>>2] = 175308;
     $vararg_ptr28 = ((($vararg_buffer24)) + 8|0);
     HEAP32[$vararg_ptr28>>2] = 600;
     $vararg_ptr29 = ((($vararg_buffer24)) + 12|0);
     HEAP32[$vararg_ptr29>>2] = 181472;
     $vararg_ptr30 = ((($vararg_buffer24)) + 16|0);
     HEAP32[$vararg_ptr30>>2] = $$0$i$i189;
     $vararg_ptr31 = ((($vararg_buffer24)) + 20|0);
     HEAP32[$vararg_ptr31>>2] = $171;
     (_SDL_SetError(175282,$vararg_buffer24)|0);
     $172 = HEAP32[$167>>2]|0;
     $173 = (FUNCTION_TABLE_i[$172 & 8191]()|0);
     $174 = ($173|0)==(0);
     if ($174) {
      $$1165 = -1;
      break;
     } else {
      $171 = $173;
     }
    }
    STACKTOP = sp;return ($$1165|0);
   }
  }
 }
 $175 = HEAP32[$39>>2]|0;
 $176 = ($175|0)==(0);
 $$pre = ((($3)) + 96|0);
 if (!($176)) {
  $177 = HEAP32[$$pre>>2]|0;
  FUNCTION_TABLE_vii[$177 & 8191](1,$40);
  $178 = HEAP32[$2>>2]|0;
  $179 = ((($178)) + 4|0);
  $180 = HEAP32[$179>>2]|0;
  $181 = ($180|0)==(0);
  if (!($181)) {
   $182 = ((($178)) + 108|0);
   $183 = HEAP32[$182>>2]|0;
   $184 = (FUNCTION_TABLE_i[$183 & 8191]()|0);
   $185 = ($184|0)==(0);
   if (!($185)) {
    $186 = $184;
    while(1) {
     switch ($186|0) {
     case 1280:  {
      $$0$i$i197 = 175266;
      break;
     }
     case 1281:  {
      $$0$i$i197 = 175249;
      break;
     }
     case 1282:  {
      $$0$i$i197 = 175228;
      break;
     }
     case 1285:  {
      $$0$i$i197 = 175211;
      break;
     }
     default: {
      $$0$i$i197 = 175203;
     }
     }
     HEAP32[$vararg_buffer32>>2] = 181527;
     $vararg_ptr35 = ((($vararg_buffer32)) + 4|0);
     HEAP32[$vararg_ptr35>>2] = 175308;
     $vararg_ptr36 = ((($vararg_buffer32)) + 8|0);
     HEAP32[$vararg_ptr36>>2] = 607;
     $vararg_ptr37 = ((($vararg_buffer32)) + 12|0);
     HEAP32[$vararg_ptr37>>2] = 181472;
     $vararg_ptr38 = ((($vararg_buffer32)) + 16|0);
     HEAP32[$vararg_ptr38>>2] = $$0$i$i197;
     $vararg_ptr39 = ((($vararg_buffer32)) + 20|0);
     HEAP32[$vararg_ptr39>>2] = $186;
     (_SDL_SetError(175282,$vararg_buffer32)|0);
     $187 = HEAP32[$182>>2]|0;
     $188 = (FUNCTION_TABLE_i[$187 & 8191]()|0);
     $189 = ($188|0)==(0);
     if ($189) {
      $$1165 = -1;
      break;
     } else {
      $186 = $188;
     }
    }
    STACKTOP = sp;return ($$1165|0);
   }
  }
  $190 = ((($3)) + 16|0);
  $191 = HEAP32[$190>>2]|0;
  FUNCTION_TABLE_vi[$191 & 8191](33985);
  $192 = ((($3)) + 28|0);
  $193 = HEAP32[$192>>2]|0;
  $194 = HEAP32[$27>>2]|0;
  $195 = HEAP32[$40>>2]|0;
  FUNCTION_TABLE_vii[$193 & 8191]($194,$195);
  $196 = ((($3)) + 160|0);
  $197 = HEAP32[$196>>2]|0;
  $198 = HEAP32[$27>>2]|0;
  FUNCTION_TABLE_viii[$197 & 8191]($198,10241,$116);
  $199 = HEAP32[$196>>2]|0;
  $200 = HEAP32[$27>>2]|0;
  FUNCTION_TABLE_viii[$199 & 8191]($200,10240,$116);
  $201 = HEAP32[$196>>2]|0;
  $202 = HEAP32[$27>>2]|0;
  FUNCTION_TABLE_viii[$201 & 8191]($202,10242,33071);
  $203 = HEAP32[$196>>2]|0;
  $204 = HEAP32[$27>>2]|0;
  FUNCTION_TABLE_viii[$203 & 8191]($204,10243,33071);
  $205 = ((($3)) + 156|0);
  $206 = HEAP32[$205>>2]|0;
  $207 = HEAP32[$27>>2]|0;
  $208 = ((($1)) + 12|0);
  $209 = HEAP32[$208>>2]|0;
  $210 = (($209|0) / 2)&-1;
  $211 = ((($1)) + 16|0);
  $212 = HEAP32[$211>>2]|0;
  $213 = (($212|0) / 2)&-1;
  FUNCTION_TABLE_viiiiiiiii[$206 & 8191]($207,0,6410,$210,$213,0,6410,5121,0);
  $214 = HEAP32[$2>>2]|0;
  $215 = ((($214)) + 4|0);
  $216 = HEAP32[$215>>2]|0;
  $217 = ($216|0)==(0);
  if (!($217)) {
   $218 = ((($214)) + 108|0);
   $219 = HEAP32[$218>>2]|0;
   $220 = (FUNCTION_TABLE_i[$219 & 8191]()|0);
   $221 = ($220|0)==(0);
   if (!($221)) {
    $222 = $220;
    while(1) {
     switch ($222|0) {
     case 1280:  {
      $$0$i$i205 = 175266;
      break;
     }
     case 1281:  {
      $$0$i$i205 = 175249;
      break;
     }
     case 1282:  {
      $$0$i$i205 = 175228;
      break;
     }
     case 1285:  {
      $$0$i$i205 = 175211;
      break;
     }
     default: {
      $$0$i$i205 = 175203;
     }
     }
     HEAP32[$vararg_buffer40>>2] = 181542;
     $vararg_ptr43 = ((($vararg_buffer40)) + 4|0);
     HEAP32[$vararg_ptr43>>2] = 175308;
     $vararg_ptr44 = ((($vararg_buffer40)) + 8|0);
     HEAP32[$vararg_ptr44>>2] = 617;
     $vararg_ptr45 = ((($vararg_buffer40)) + 12|0);
     HEAP32[$vararg_ptr45>>2] = 181472;
     $vararg_ptr46 = ((($vararg_buffer40)) + 16|0);
     HEAP32[$vararg_ptr46>>2] = $$0$i$i205;
     $vararg_ptr47 = ((($vararg_buffer40)) + 20|0);
     HEAP32[$vararg_ptr47>>2] = $222;
     (_SDL_SetError(175282,$vararg_buffer40)|0);
     $223 = HEAP32[$218>>2]|0;
     $224 = (FUNCTION_TABLE_i[$223 & 8191]()|0);
     $225 = ($224|0)==(0);
     if ($225) {
      $$1165 = -1;
      break;
     } else {
      $222 = $224;
     }
    }
    STACKTOP = sp;return ($$1165|0);
   }
  }
 }
 $226 = HEAP32[$$pre>>2]|0;
 FUNCTION_TABLE_vii[$226 & 8191](1,$24);
 $227 = HEAP32[$2>>2]|0;
 $228 = ((($227)) + 4|0);
 $229 = HEAP32[$228>>2]|0;
 $230 = ($229|0)==(0);
 if (!($230)) {
  $231 = ((($227)) + 108|0);
  $232 = HEAP32[$231>>2]|0;
  $233 = (FUNCTION_TABLE_i[$232 & 8191]()|0);
  $234 = ($233|0)==(0);
  if (!($234)) {
   $235 = $233;
   while(1) {
    switch ($235|0) {
    case 1280:  {
     $$0$i$i213 = 175266;
     break;
    }
    case 1281:  {
     $$0$i$i213 = 175249;
     break;
    }
    case 1282:  {
     $$0$i$i213 = 175228;
     break;
    }
    case 1285:  {
     $$0$i$i213 = 175211;
     break;
    }
    default: {
     $$0$i$i213 = 175203;
    }
    }
    HEAP32[$vararg_buffer48>>2] = 181527;
    $vararg_ptr51 = ((($vararg_buffer48)) + 4|0);
    HEAP32[$vararg_ptr51>>2] = 175308;
    $vararg_ptr52 = ((($vararg_buffer48)) + 8|0);
    HEAP32[$vararg_ptr52>>2] = 623;
    $vararg_ptr53 = ((($vararg_buffer48)) + 12|0);
    HEAP32[$vararg_ptr53>>2] = 181472;
    $vararg_ptr54 = ((($vararg_buffer48)) + 16|0);
    HEAP32[$vararg_ptr54>>2] = $$0$i$i213;
    $vararg_ptr55 = ((($vararg_buffer48)) + 20|0);
    HEAP32[$vararg_ptr55>>2] = $235;
    (_SDL_SetError(175282,$vararg_buffer48)|0);
    $236 = HEAP32[$231>>2]|0;
    $237 = (FUNCTION_TABLE_i[$236 & 8191]()|0);
    $238 = ($237|0)==(0);
    if ($238) {
     $$1165 = -1;
     break;
    } else {
     $235 = $237;
    }
   }
   STACKTOP = sp;return ($$1165|0);
  }
 }
 $239 = ((($1)) + 68|0);
 HEAP32[$239>>2] = $24;
 $240 = ((($3)) + 16|0);
 $241 = HEAP32[$240>>2]|0;
 FUNCTION_TABLE_vi[$241 & 8191](33984);
 $242 = ((($3)) + 28|0);
 $243 = HEAP32[$242>>2]|0;
 $244 = HEAP32[$27>>2]|0;
 $245 = HEAP32[$24>>2]|0;
 FUNCTION_TABLE_vii[$243 & 8191]($244,$245);
 $246 = ((($3)) + 160|0);
 $247 = HEAP32[$246>>2]|0;
 $248 = HEAP32[$27>>2]|0;
 FUNCTION_TABLE_viii[$247 & 8191]($248,10241,$116);
 $249 = HEAP32[$246>>2]|0;
 $250 = HEAP32[$27>>2]|0;
 FUNCTION_TABLE_viii[$249 & 8191]($250,10240,$116);
 $251 = HEAP32[$246>>2]|0;
 $252 = HEAP32[$27>>2]|0;
 FUNCTION_TABLE_viii[$251 & 8191]($252,10242,33071);
 $253 = HEAP32[$246>>2]|0;
 $254 = HEAP32[$27>>2]|0;
 FUNCTION_TABLE_viii[$253 & 8191]($254,10243,33071);
 $255 = ((($3)) + 156|0);
 $256 = HEAP32[$255>>2]|0;
 $257 = HEAP32[$27>>2]|0;
 $258 = ((($1)) + 12|0);
 $259 = HEAP32[$258>>2]|0;
 $260 = ((($1)) + 16|0);
 $261 = HEAP32[$260>>2]|0;
 FUNCTION_TABLE_viiiiiiiii[$256 & 8191]($257,0,$$0167,$259,$261,0,$$0167,5121,0);
 $262 = HEAP32[$2>>2]|0;
 $263 = ((($262)) + 4|0);
 $264 = HEAP32[$263>>2]|0;
 $265 = ($264|0)==(0);
 if (!($265)) {
  $266 = ((($262)) + 108|0);
  $267 = HEAP32[$266>>2]|0;
  $268 = (FUNCTION_TABLE_i[$267 & 8191]()|0);
  $269 = ($268|0)==(0);
  if (!($269)) {
   $270 = $268;
   while(1) {
    switch ($270|0) {
    case 1280:  {
     $$0$i$i221 = 175266;
     break;
    }
    case 1281:  {
     $$0$i$i221 = 175249;
     break;
    }
    case 1282:  {
     $$0$i$i221 = 175228;
     break;
    }
    case 1285:  {
     $$0$i$i221 = 175211;
     break;
    }
    default: {
     $$0$i$i221 = 175203;
    }
    }
    HEAP32[$vararg_buffer56>>2] = 181542;
    $vararg_ptr59 = ((($vararg_buffer56)) + 4|0);
    HEAP32[$vararg_ptr59>>2] = 175308;
    $vararg_ptr60 = ((($vararg_buffer56)) + 8|0);
    HEAP32[$vararg_ptr60>>2] = 634;
    $vararg_ptr61 = ((($vararg_buffer56)) + 12|0);
    HEAP32[$vararg_ptr61>>2] = 181472;
    $vararg_ptr62 = ((($vararg_buffer56)) + 16|0);
    HEAP32[$vararg_ptr62>>2] = $$0$i$i221;
    $vararg_ptr63 = ((($vararg_buffer56)) + 20|0);
    HEAP32[$vararg_ptr63>>2] = $270;
    (_SDL_SetError(175282,$vararg_buffer56)|0);
    $271 = HEAP32[$266>>2]|0;
    $272 = (FUNCTION_TABLE_i[$271 & 8191]()|0);
    $273 = ($272|0)==(0);
    if ($273) {
     $$1165 = -1;
     break;
    } else {
     $270 = $272;
    }
   }
   STACKTOP = sp;return ($$1165|0);
  }
 }
 $274 = HEAP32[$48>>2]|0;
 $275 = ($274|0)==(2);
 L165: do {
  if ($275) {
   $276 = HEAP32[$2>>2]|0;
   $277 = HEAP32[$258>>2]|0;
   $278 = HEAP32[$260>>2]|0;
   $279 = ((($276)) + 232|0);
   $$020$i = HEAP32[$279>>2]|0;
   $cond21$i = ($$020$i|0)==(0|0);
   if (!($cond21$i)) {
    $$022$i = $$020$i;
    while(1) {
     $280 = HEAP32[$$022$i>>2]|0;
     $281 = ($280|0)==($277|0);
     if ($281) {
      $282 = ((($$022$i)) + 4|0);
      $283 = HEAP32[$282>>2]|0;
      $284 = ($283|0)==($278|0);
      if ($284) {
       $$sink = $$022$i;
       break L165;
      }
     }
     $285 = ((($$022$i)) + 12|0);
     $$0$i226 = HEAP32[$285>>2]|0;
     $cond$i = ($$0$i226|0)==(0|0);
     if ($cond$i) {
      break;
     } else {
      $$022$i = $$0$i226;
     }
    }
   }
   $286 = (_SDL_malloc(16)|0);
   HEAP32[$286>>2] = $277;
   $287 = ((($286)) + 4|0);
   HEAP32[$287>>2] = $278;
   $288 = ((($276)) + 92|0);
   $289 = HEAP32[$288>>2]|0;
   $290 = ((($286)) + 8|0);
   FUNCTION_TABLE_vii[$289 & 8191](1,$290);
   $291 = HEAP32[$279>>2]|0;
   $292 = ((($286)) + 12|0);
   HEAP32[$292>>2] = $291;
   HEAP32[$279>>2] = $286;
   $$sink = $286;
  } else {
   $$sink = 0;
  }
 } while(0);
 $293 = ((($24)) + 40|0);
 HEAP32[$293>>2] = $$sink;
 $294 = HEAP32[$2>>2]|0;
 $295 = ((($294)) + 4|0);
 $296 = HEAP32[$295>>2]|0;
 $297 = ($296|0)==(0);
 if ($297) {
  $$1165 = 0;
  STACKTOP = sp;return ($$1165|0);
 }
 $298 = ((($294)) + 108|0);
 $299 = HEAP32[$298>>2]|0;
 $300 = (FUNCTION_TABLE_i[$299 & 8191]()|0);
 $301 = ($300|0)==(0);
 if ($301) {
  $$1165 = 0;
  STACKTOP = sp;return ($$1165|0);
 } else {
  $$0211$i228 = 221531;$305 = $300;
 }
 while(1) {
  $302 = ($$0211$i228|0)==(0|0);
  if ($302) {
   label = 105;
  } else {
   $303 = HEAP8[$$0211$i228>>0]|0;
   $304 = ($303<<24>>24)==(0);
   if ($304) {
    label = 105;
   } else {
    $$122$i230 = $$0211$i228;
   }
  }
  if ((label|0) == 105) {
   label = 0;
   $$122$i230 = 175195;
  }
  switch ($305|0) {
  case 1280:  {
   $$0$i$i231 = 175266;
   break;
  }
  case 1281:  {
   $$0$i$i231 = 175249;
   break;
  }
  case 1282:  {
   $$0$i$i231 = 175228;
   break;
  }
  case 1285:  {
   $$0$i$i231 = 175211;
   break;
  }
  default: {
   $$0$i$i231 = 175203;
  }
  }
  HEAP32[$vararg_buffer64>>2] = $$122$i230;
  $vararg_ptr67 = ((($vararg_buffer64)) + 4|0);
  HEAP32[$vararg_ptr67>>2] = 175308;
  $vararg_ptr68 = ((($vararg_buffer64)) + 8|0);
  HEAP32[$vararg_ptr68>>2] = 644;
  $vararg_ptr69 = ((($vararg_buffer64)) + 12|0);
  HEAP32[$vararg_ptr69>>2] = 181472;
  $vararg_ptr70 = ((($vararg_buffer64)) + 16|0);
  HEAP32[$vararg_ptr70>>2] = $$0$i$i231;
  $vararg_ptr71 = ((($vararg_buffer64)) + 20|0);
  HEAP32[$vararg_ptr71>>2] = $305;
  (_SDL_SetError(175282,$vararg_buffer64)|0);
  $306 = HEAP32[$298>>2]|0;
  $307 = (FUNCTION_TABLE_i[$306 & 8191]()|0);
  $308 = ($307|0)==(0);
  if ($308) {
   $$1165 = -1;
   break;
  } else {
   $$0211$i228 = $$122$i230;$305 = $307;
  }
 }
 STACKTOP = sp;return ($$1165|0);
}
function _GLES2_UpdateTexture($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0 = 0, $$0$i$i = 0, $$03$i = 0, $$03$i101 = 0, $$03$i81 = 0, $$03$i91 = 0, $$0392$i = 0, $$0392$i102 = 0, $$0392$i82 = 0, $$0392$i92 = 0, $$040$i = 0, $$040$i106 = 0, $$040$i86 = 0, $$040$i96 = 0, $$0411$i = 0, $$0411$i103 = 0, $$0411$i83 = 0, $$0411$i93 = 0, $$078 = 0, $$1$i = 0;
 var $$1$i107 = 0, $$1$i87 = 0, $$1$i97 = 0, $$mask = 0, $$pre$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $exitcond$i = 0, $exitcond$i104 = 0, $exitcond$i84 = 0, $exitcond$i94 = 0, $or$cond = 0, $phitmp = 0, $switch$split2D = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, $vararg_ptr3 = 0, $vararg_ptr4 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $vararg_buffer = sp;
 $5 = ((($0)) + 320|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($1)) + 68|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[52374]|0;
 $10 = HEAP32[$6>>2]|0;
 $11 = ($9|0)==($10|0);
 if ($11) {
  $19 = $6;
  label = 4;
 } else {
  $12 = ((($6)) + 268|0);
  HEAP32[$12>>2] = 0;
  $13 = ((($0)) + 188|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (_SDL_GL_MakeCurrent($14,$10)|0);
  $16 = ($15|0)<(0);
  if (!($16)) {
   $17 = HEAP32[$6>>2]|0;
   HEAP32[52374] = $17;
   (_GLES2_UpdateViewport($0)|0);
   $$pre$i = HEAP32[$5>>2]|0;
   $19 = $$pre$i;
   label = 4;
  }
 }
 if ((label|0) == 4) {
  $18 = ((($19)) + 4|0);
  $20 = HEAP32[$18>>2]|0;
  $21 = ($20|0)==(0);
  if (!($21)) {
   $22 = ((($19)) + 108|0);
   while(1) {
    $23 = HEAP32[$22>>2]|0;
    $24 = (FUNCTION_TABLE_i[$23 & 8191]()|0);
    $25 = ($24|0)==(0);
    if ($25) {
     break;
    }
   }
  }
 }
 $26 = ((($2)) + 8|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ($27|0)<(1);
 if ($28) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $29 = ((($2)) + 12|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ($30|0)<(1);
 if ($31) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $32 = ((($6)) + 28|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ((($8)) + 4|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = HEAP32[$8>>2]|0;
 FUNCTION_TABLE_vii[$33 & 8191]($35,$36);
 $37 = HEAP32[$34>>2]|0;
 $38 = HEAP32[$2>>2]|0;
 $39 = ((($2)) + 4|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = HEAP32[$26>>2]|0;
 $42 = HEAP32[$29>>2]|0;
 $43 = ((($8)) + 8|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = ((($8)) + 12|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = ((($1)) + 4|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = ($48|0)==(0);
 $$mask = $48 & -268435456;
 $50 = ($$mask|0)==(268435456);
 $or$cond = $49 | $50;
 L16: do {
  if ($or$cond) {
   $52 = $48 & 255;
   $54 = $52;
  } else {
   $switch$split2D = ($48|0)<(1498831189);
   if ($switch$split2D) {
    switch ($48|0) {
    case 844715353:  {
     $54 = 2;
     break L16;
     break;
    }
    default: {
    }
    }
   } else {
    switch ($48|0) {
    case 1498831189:  {
     $54 = 2;
     break L16;
     break;
    }
    default: {
    }
    }
   }
   $51 = ($48|0)==(1431918169);
   $phitmp = $51 ? 2 : 1;
   $54 = $phitmp;
  }
 } while(0);
 $53 = Math_imul($54, $41)|0;
 $55 = ($53|0)==($4|0);
 do {
  if ($55) {
   $$040$i = 0;$$1$i = $3;
   label = 18;
  } else {
   $56 = Math_imul($53, $42)|0;
   $57 = (_SDL_malloc($56)|0);
   $58 = ($57|0)==(0|0);
   if ($58) {
    (_SDL_Error(0)|0);
    break;
   }
   $59 = ($42|0)>(0);
   if ($59) {
    $$03$i = 0;$$0392$i = $57;$$0411$i = $3;
    while(1) {
     (_SDL_memcpy($$0392$i,$$0411$i,$53)|0);
     $60 = (($$0392$i) + ($53)|0);
     $61 = (($$0411$i) + ($4)|0);
     $62 = (($$03$i) + 1)|0;
     $exitcond$i = ($62|0)==($42|0);
     if ($exitcond$i) {
      $$040$i = $57;$$1$i = $57;
      label = 18;
      break;
     } else {
      $$03$i = $62;$$0392$i = $60;$$0411$i = $61;
     }
    }
   } else {
    $$040$i = $57;$$1$i = $57;
    label = 18;
   }
  }
 } while(0);
 if ((label|0) == 18) {
  $63 = ((($6)) + 164|0);
  $64 = HEAP32[$63>>2]|0;
  FUNCTION_TABLE_viiiiiiiii[$64 & 8191]($37,0,$38,$40,$41,$42,$44,$46,$$1$i);
  $65 = ($$040$i|0)==(0|0);
  if (!($65)) {
   _SDL_free($$040$i);
  }
 }
 $66 = ((($8)) + 24|0);
 $67 = HEAP32[$66>>2]|0;
 $68 = ($67|0)==(0);
 do {
  if ($68) {
   $$078 = $3;
  } else {
   $69 = HEAP32[$29>>2]|0;
   $70 = Math_imul($69, $4)|0;
   $71 = (($3) + ($70)|0);
   $72 = HEAP32[$47>>2]|0;
   $73 = ($72|0)==(842094169);
   $74 = HEAP32[$32>>2]|0;
   $75 = HEAP32[$34>>2]|0;
   if ($73) {
    $76 = ((($8)) + 32|0);
    $77 = HEAP32[$76>>2]|0;
    FUNCTION_TABLE_vii[$74 & 8191]($75,$77);
   } else {
    $78 = ((($8)) + 36|0);
    $79 = HEAP32[$78>>2]|0;
    FUNCTION_TABLE_vii[$74 & 8191]($75,$79);
   }
   $80 = HEAP32[$34>>2]|0;
   $81 = HEAP32[$2>>2]|0;
   $82 = (($81|0) / 2)&-1;
   $83 = HEAP32[$39>>2]|0;
   $84 = (($83|0) / 2)&-1;
   $85 = HEAP32[$26>>2]|0;
   $86 = (($85|0) / 2)&-1;
   $87 = HEAP32[$29>>2]|0;
   $88 = (($87|0) / 2)&-1;
   $89 = HEAP32[$43>>2]|0;
   $90 = HEAP32[$45>>2]|0;
   $91 = (($4|0) / 2)&-1;
   $92 = ($86|0)==($91|0);
   do {
    if ($92) {
     $$040$i86 = 0;$$1$i87 = $71;
     label = 29;
    } else {
     $93 = Math_imul($88, $86)|0;
     $94 = (_SDL_malloc($93)|0);
     $95 = ($94|0)==(0|0);
     if ($95) {
      (_SDL_Error(0)|0);
      break;
     }
     $96 = ($87|0)>(1);
     if ($96) {
      $$03$i81 = 0;$$0392$i82 = $94;$$0411$i83 = $71;
      while(1) {
       (_SDL_memcpy($$0392$i82,$$0411$i83,$86)|0);
       $97 = (($$0392$i82) + ($86)|0);
       $98 = (($$0411$i83) + ($91)|0);
       $99 = (($$03$i81) + 1)|0;
       $exitcond$i84 = ($99|0)==($88|0);
       if ($exitcond$i84) {
        $$040$i86 = $94;$$1$i87 = $94;
        label = 29;
        break;
       } else {
        $$03$i81 = $99;$$0392$i82 = $97;$$0411$i83 = $98;
       }
      }
     } else {
      $$040$i86 = $94;$$1$i87 = $94;
      label = 29;
     }
    }
   } while(0);
   if ((label|0) == 29) {
    $100 = ((($6)) + 164|0);
    $101 = HEAP32[$100>>2]|0;
    FUNCTION_TABLE_viiiiiiiii[$101 & 8191]($80,0,$82,$84,$86,$88,$89,$90,$$1$i87);
    $102 = ($$040$i86|0)==(0|0);
    if (!($102)) {
     _SDL_free($$040$i86);
    }
   }
   $103 = HEAP32[$29>>2]|0;
   $104 = Math_imul($103, $4)|0;
   $105 = (($104|0) / 4)&-1;
   $106 = (($71) + ($105)|0);
   $107 = HEAP32[$47>>2]|0;
   $108 = ($107|0)==(842094169);
   $109 = HEAP32[$32>>2]|0;
   $110 = HEAP32[$34>>2]|0;
   if ($108) {
    $111 = ((($8)) + 36|0);
    $112 = HEAP32[$111>>2]|0;
    FUNCTION_TABLE_vii[$109 & 8191]($110,$112);
   } else {
    $113 = ((($8)) + 32|0);
    $114 = HEAP32[$113>>2]|0;
    FUNCTION_TABLE_vii[$109 & 8191]($110,$114);
   }
   $115 = HEAP32[$34>>2]|0;
   $116 = HEAP32[$2>>2]|0;
   $117 = (($116|0) / 2)&-1;
   $118 = HEAP32[$39>>2]|0;
   $119 = (($118|0) / 2)&-1;
   $120 = HEAP32[$26>>2]|0;
   $121 = (($120|0) / 2)&-1;
   $122 = HEAP32[$29>>2]|0;
   $123 = (($122|0) / 2)&-1;
   $124 = HEAP32[$43>>2]|0;
   $125 = HEAP32[$45>>2]|0;
   $126 = ($121|0)==($91|0);
   if ($126) {
    $$040$i96 = 0;$$1$i97 = $106;
   } else {
    $127 = Math_imul($123, $121)|0;
    $128 = (_SDL_malloc($127)|0);
    $129 = ($128|0)==(0|0);
    if ($129) {
     (_SDL_Error(0)|0);
     $$078 = $106;
     break;
    }
    $130 = ($122|0)>(1);
    if ($130) {
     $$03$i91 = 0;$$0392$i92 = $128;$$0411$i93 = $106;
     while(1) {
      (_SDL_memcpy($$0392$i92,$$0411$i93,$121)|0);
      $131 = (($$0392$i92) + ($121)|0);
      $132 = (($$0411$i93) + ($91)|0);
      $133 = (($$03$i91) + 1)|0;
      $exitcond$i94 = ($133|0)==($123|0);
      if ($exitcond$i94) {
       $$040$i96 = $128;$$1$i97 = $128;
       break;
      } else {
       $$03$i91 = $133;$$0392$i92 = $131;$$0411$i93 = $132;
      }
     }
    } else {
     $$040$i96 = $128;$$1$i97 = $128;
    }
   }
   $134 = ((($6)) + 164|0);
   $135 = HEAP32[$134>>2]|0;
   FUNCTION_TABLE_viiiiiiiii[$135 & 8191]($115,0,$117,$119,$121,$123,$124,$125,$$1$i97);
   $136 = ($$040$i96|0)==(0|0);
   if ($136) {
    $$078 = $106;
   } else {
    _SDL_free($$040$i96);
    $$078 = $106;
   }
  }
 } while(0);
 $137 = ((($8)) + 28|0);
 $138 = HEAP32[$137>>2]|0;
 $139 = ($138|0)==(0);
 do {
  if (!($139)) {
   $140 = HEAP32[$29>>2]|0;
   $141 = Math_imul($140, $4)|0;
   $142 = (($$078) + ($141)|0);
   $143 = HEAP32[$32>>2]|0;
   $144 = HEAP32[$34>>2]|0;
   $145 = ((($8)) + 36|0);
   $146 = HEAP32[$145>>2]|0;
   FUNCTION_TABLE_vii[$143 & 8191]($144,$146);
   $147 = HEAP32[$34>>2]|0;
   $148 = HEAP32[$2>>2]|0;
   $149 = (($148|0) / 2)&-1;
   $150 = HEAP32[$39>>2]|0;
   $151 = (($150|0) / 2)&-1;
   $152 = HEAP32[$26>>2]|0;
   $153 = (($152|0) / 2)&-1;
   $154 = HEAP32[$29>>2]|0;
   $155 = (($154|0) / 2)&-1;
   $156 = $153 << 1;
   $157 = ($156|0)==($4|0);
   if ($157) {
    $$040$i106 = 0;$$1$i107 = $142;
   } else {
    $158 = Math_imul($156, $155)|0;
    $159 = (_SDL_malloc($158)|0);
    $160 = ($159|0)==(0|0);
    if ($160) {
     (_SDL_Error(0)|0);
     break;
    }
    $161 = ($154|0)>(1);
    if ($161) {
     $$03$i101 = 0;$$0392$i102 = $159;$$0411$i103 = $142;
     while(1) {
      (_SDL_memcpy($$0392$i102,$$0411$i103,$156)|0);
      $162 = (($$0392$i102) + ($156)|0);
      $163 = (($$0411$i103) + ($4)|0);
      $164 = (($$03$i101) + 1)|0;
      $exitcond$i104 = ($164|0)==($155|0);
      if ($exitcond$i104) {
       $$040$i106 = $159;$$1$i107 = $159;
       break;
      } else {
       $$03$i101 = $164;$$0392$i102 = $162;$$0411$i103 = $163;
      }
     }
    } else {
     $$040$i106 = $159;$$1$i107 = $159;
    }
   }
   $165 = ((($6)) + 164|0);
   $166 = HEAP32[$165>>2]|0;
   FUNCTION_TABLE_viiiiiiiii[$166 & 8191]($147,0,$149,$151,$153,$155,6410,5121,$$1$i107);
   $167 = ($$040$i106|0)==(0|0);
   if (!($167)) {
    _SDL_free($$040$i106);
   }
  }
 } while(0);
 $168 = HEAP32[$5>>2]|0;
 $169 = ((($168)) + 4|0);
 $170 = HEAP32[$169>>2]|0;
 $171 = ($170|0)==(0);
 if ($171) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $172 = ((($168)) + 108|0);
 $173 = HEAP32[$172>>2]|0;
 $174 = (FUNCTION_TABLE_i[$173 & 8191]()|0);
 $175 = ($174|0)==(0);
 if ($175) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  $176 = $174;
 }
 while(1) {
  switch ($176|0) {
  case 1280:  {
   $$0$i$i = 175266;
   break;
  }
  case 1281:  {
   $$0$i$i = 175249;
   break;
  }
  case 1282:  {
   $$0$i$i = 175228;
   break;
  }
  case 1285:  {
   $$0$i$i = 175211;
   break;
  }
  default: {
   $$0$i$i = 175203;
  }
  }
  HEAP32[$vararg_buffer>>2] = 181197;
  $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
  HEAP32[$vararg_ptr1>>2] = 175308;
  $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
  HEAP32[$vararg_ptr2>>2] = 753;
  $vararg_ptr3 = ((($vararg_buffer)) + 12|0);
  HEAP32[$vararg_ptr3>>2] = 181351;
  $vararg_ptr4 = ((($vararg_buffer)) + 16|0);
  HEAP32[$vararg_ptr4>>2] = $$0$i$i;
  $vararg_ptr5 = ((($vararg_buffer)) + 20|0);
  HEAP32[$vararg_ptr5>>2] = $176;
  (_SDL_SetError(175282,$vararg_buffer)|0);
  $177 = HEAP32[$172>>2]|0;
  $178 = (FUNCTION_TABLE_i[$177 & 8191]()|0);
  $179 = ($178|0)==(0);
  if ($179) {
   $$0 = -1;
   break;
  } else {
   $176 = $178;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function _GLES2_UpdateTextureYUV($0,$1,$2,$3,$4,$5,$6,$7,$8) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 $8 = $8|0;
 var $$0 = 0, $$0$i$i = 0, $$03$i = 0, $$03$i49 = 0, $$03$i59 = 0, $$0392$i = 0, $$0392$i50 = 0, $$0392$i60 = 0, $$040$i = 0, $$040$i54 = 0, $$040$i64 = 0, $$0411$i = 0, $$0411$i51 = 0, $$0411$i61 = 0, $$1$i = 0, $$1$i55 = 0, $$1$i65 = 0, $$pre$i = 0, $10 = 0, $100 = 0;
 var $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0;
 var $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i = 0, $exitcond$i52 = 0, $exitcond$i62 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0;
 var $vararg_ptr2 = 0, $vararg_ptr3 = 0, $vararg_ptr4 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $vararg_buffer = sp;
 $9 = ((($0)) + 320|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ((($1)) + 68|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = HEAP32[52374]|0;
 $14 = HEAP32[$10>>2]|0;
 $15 = ($13|0)==($14|0);
 if ($15) {
  $23 = $10;
  label = 4;
 } else {
  $16 = ((($10)) + 268|0);
  HEAP32[$16>>2] = 0;
  $17 = ((($0)) + 188|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (_SDL_GL_MakeCurrent($18,$14)|0);
  $20 = ($19|0)<(0);
  if (!($20)) {
   $21 = HEAP32[$10>>2]|0;
   HEAP32[52374] = $21;
   (_GLES2_UpdateViewport($0)|0);
   $$pre$i = HEAP32[$9>>2]|0;
   $23 = $$pre$i;
   label = 4;
  }
 }
 if ((label|0) == 4) {
  $22 = ((($23)) + 4|0);
  $24 = HEAP32[$22>>2]|0;
  $25 = ($24|0)==(0);
  if (!($25)) {
   $26 = ((($23)) + 108|0);
   while(1) {
    $27 = HEAP32[$26>>2]|0;
    $28 = (FUNCTION_TABLE_i[$27 & 8191]()|0);
    $29 = ($28|0)==(0);
    if ($29) {
     break;
    }
   }
  }
 }
 $30 = ((($2)) + 8|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ($31|0)<(1);
 if ($32) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $33 = ((($2)) + 12|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)<(1);
 if ($35) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $36 = ((($10)) + 28|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = ((($12)) + 4|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = ((($12)) + 32|0);
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_vii[$37 & 8191]($39,$41);
 $42 = HEAP32[$38>>2]|0;
 $43 = HEAP32[$2>>2]|0;
 $44 = (($43|0) / 2)&-1;
 $45 = ((($2)) + 4|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = (($46|0) / 2)&-1;
 $48 = HEAP32[$30>>2]|0;
 $49 = (($48|0) / 2)&-1;
 $50 = HEAP32[$33>>2]|0;
 $51 = (($50|0) / 2)&-1;
 $52 = ((($12)) + 8|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = ((($12)) + 12|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = ($49|0)==($8|0);
 do {
  if ($56) {
   $$040$i = 0;$$1$i = $7;
   label = 14;
  } else {
   $57 = Math_imul($51, $49)|0;
   $58 = (_SDL_malloc($57)|0);
   $59 = ($58|0)==(0|0);
   if ($59) {
    (_SDL_Error(0)|0);
    break;
   }
   $60 = ($50|0)>(1);
   if ($60) {
    $$03$i = 0;$$0392$i = $58;$$0411$i = $7;
    while(1) {
     (_SDL_memcpy($$0392$i,$$0411$i,$49)|0);
     $61 = (($$0392$i) + ($49)|0);
     $62 = (($$0411$i) + ($8)|0);
     $63 = (($$03$i) + 1)|0;
     $exitcond$i = ($63|0)==($51|0);
     if ($exitcond$i) {
      $$040$i = $58;$$1$i = $58;
      label = 14;
      break;
     } else {
      $$03$i = $63;$$0392$i = $61;$$0411$i = $62;
     }
    }
   } else {
    $$040$i = $58;$$1$i = $58;
    label = 14;
   }
  }
 } while(0);
 if ((label|0) == 14) {
  $64 = ((($10)) + 164|0);
  $65 = HEAP32[$64>>2]|0;
  FUNCTION_TABLE_viiiiiiiii[$65 & 8191]($42,0,$44,$47,$49,$51,$53,$55,$$1$i);
  $66 = ($$040$i|0)==(0|0);
  if (!($66)) {
   _SDL_free($$040$i);
  }
 }
 $67 = HEAP32[$36>>2]|0;
 $68 = HEAP32[$38>>2]|0;
 $69 = ((($12)) + 36|0);
 $70 = HEAP32[$69>>2]|0;
 FUNCTION_TABLE_vii[$67 & 8191]($68,$70);
 $71 = HEAP32[$38>>2]|0;
 $72 = HEAP32[$2>>2]|0;
 $73 = (($72|0) / 2)&-1;
 $74 = HEAP32[$45>>2]|0;
 $75 = (($74|0) / 2)&-1;
 $76 = HEAP32[$30>>2]|0;
 $77 = (($76|0) / 2)&-1;
 $78 = HEAP32[$33>>2]|0;
 $79 = (($78|0) / 2)&-1;
 $80 = HEAP32[$52>>2]|0;
 $81 = HEAP32[$54>>2]|0;
 $82 = ($77|0)==($6|0);
 do {
  if ($82) {
   $$040$i54 = 0;$$1$i55 = $5;
   label = 21;
  } else {
   $83 = Math_imul($79, $77)|0;
   $84 = (_SDL_malloc($83)|0);
   $85 = ($84|0)==(0|0);
   if ($85) {
    (_SDL_Error(0)|0);
    break;
   }
   $86 = ($78|0)>(1);
   if ($86) {
    $$03$i49 = 0;$$0392$i50 = $84;$$0411$i51 = $5;
    while(1) {
     (_SDL_memcpy($$0392$i50,$$0411$i51,$77)|0);
     $87 = (($$0392$i50) + ($77)|0);
     $88 = (($$0411$i51) + ($6)|0);
     $89 = (($$03$i49) + 1)|0;
     $exitcond$i52 = ($89|0)==($79|0);
     if ($exitcond$i52) {
      $$040$i54 = $84;$$1$i55 = $84;
      label = 21;
      break;
     } else {
      $$03$i49 = $89;$$0392$i50 = $87;$$0411$i51 = $88;
     }
    }
   } else {
    $$040$i54 = $84;$$1$i55 = $84;
    label = 21;
   }
  }
 } while(0);
 if ((label|0) == 21) {
  $90 = ((($10)) + 164|0);
  $91 = HEAP32[$90>>2]|0;
  FUNCTION_TABLE_viiiiiiiii[$91 & 8191]($71,0,$73,$75,$77,$79,$80,$81,$$1$i55);
  $92 = ($$040$i54|0)==(0|0);
  if (!($92)) {
   _SDL_free($$040$i54);
  }
 }
 $93 = HEAP32[$36>>2]|0;
 $94 = HEAP32[$38>>2]|0;
 $95 = HEAP32[$12>>2]|0;
 FUNCTION_TABLE_vii[$93 & 8191]($94,$95);
 $96 = HEAP32[$38>>2]|0;
 $97 = HEAP32[$2>>2]|0;
 $98 = HEAP32[$45>>2]|0;
 $99 = HEAP32[$30>>2]|0;
 $100 = HEAP32[$33>>2]|0;
 $101 = HEAP32[$52>>2]|0;
 $102 = HEAP32[$54>>2]|0;
 $103 = ($99|0)==($4|0);
 do {
  if ($103) {
   $$040$i64 = 0;$$1$i65 = $3;
   label = 28;
  } else {
   $104 = Math_imul($100, $99)|0;
   $105 = (_SDL_malloc($104)|0);
   $106 = ($105|0)==(0|0);
   if ($106) {
    (_SDL_Error(0)|0);
    break;
   }
   $107 = ($100|0)>(0);
   if ($107) {
    $$03$i59 = 0;$$0392$i60 = $105;$$0411$i61 = $3;
    while(1) {
     (_SDL_memcpy($$0392$i60,$$0411$i61,$99)|0);
     $108 = (($$0392$i60) + ($99)|0);
     $109 = (($$0411$i61) + ($4)|0);
     $110 = (($$03$i59) + 1)|0;
     $exitcond$i62 = ($110|0)==($100|0);
     if ($exitcond$i62) {
      $$040$i64 = $105;$$1$i65 = $105;
      label = 28;
      break;
     } else {
      $$03$i59 = $110;$$0392$i60 = $108;$$0411$i61 = $109;
     }
    }
   } else {
    $$040$i64 = $105;$$1$i65 = $105;
    label = 28;
   }
  }
 } while(0);
 if ((label|0) == 28) {
  $111 = ((($10)) + 164|0);
  $112 = HEAP32[$111>>2]|0;
  FUNCTION_TABLE_viiiiiiiii[$112 & 8191]($96,0,$97,$98,$99,$100,$101,$102,$$1$i65);
  $113 = ($$040$i64|0)==(0|0);
  if (!($113)) {
   _SDL_free($$040$i64);
  }
 }
 $114 = HEAP32[$9>>2]|0;
 $115 = ((($114)) + 4|0);
 $116 = HEAP32[$115>>2]|0;
 $117 = ($116|0)==(0);
 if ($117) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $118 = ((($114)) + 108|0);
 $119 = HEAP32[$118>>2]|0;
 $120 = (FUNCTION_TABLE_i[$119 & 8191]()|0);
 $121 = ($120|0)==(0);
 if ($121) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  $122 = $120;
 }
 while(1) {
  switch ($122|0) {
  case 1280:  {
   $$0$i$i = 175266;
   break;
  }
  case 1281:  {
   $$0$i$i = 175249;
   break;
  }
  case 1282:  {
   $$0$i$i = 175228;
   break;
  }
  case 1285:  {
   $$0$i$i = 175211;
   break;
  }
  default: {
   $$0$i$i = 175203;
  }
  }
  HEAP32[$vararg_buffer>>2] = 181197;
  $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
  HEAP32[$vararg_ptr1>>2] = 175308;
  $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
  HEAP32[$vararg_ptr2>>2] = 803;
  $vararg_ptr3 = ((($vararg_buffer)) + 12|0);
  HEAP32[$vararg_ptr3>>2] = 181215;
  $vararg_ptr4 = ((($vararg_buffer)) + 16|0);
  HEAP32[$vararg_ptr4>>2] = $$0$i$i;
  $vararg_ptr5 = ((($vararg_buffer)) + 20|0);
  HEAP32[$vararg_ptr5>>2] = $122;
  (_SDL_SetError(175282,$vararg_buffer)|0);
  $123 = HEAP32[$118>>2]|0;
  $124 = (FUNCTION_TABLE_i[$123 & 8191]()|0);
  $125 = ($124|0)==(0);
  if ($125) {
   $$0 = -1;
   break;
  } else {
   $122 = $124;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function _GLES2_LockTexture($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$mask = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $or$cond = 0, $phitmp = 0, $switch$split2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = ((($1)) + 68|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($6)) + 16|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($6)) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ((($2)) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = Math_imul($12, $10)|0;
 $14 = (($8) + ($13)|0);
 $15 = HEAP32[$2>>2]|0;
 $16 = ((($1)) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==(0);
 $$mask = $17 & -268435456;
 $19 = ($$mask|0)==(268435456);
 $or$cond = $18 | $19;
 L1: do {
  if ($or$cond) {
   $21 = $17 & 255;
   $23 = $21;
  } else {
   $switch$split2D = ($17|0)<(1498831189);
   if ($switch$split2D) {
    switch ($17|0) {
    case 844715353:  {
     $23 = 2;
     break L1;
     break;
    }
    default: {
    }
    }
   } else {
    switch ($17|0) {
    case 1498831189:  {
     $23 = 2;
     break L1;
     break;
    }
    default: {
    }
    }
   }
   $20 = ($17|0)==(1431918169);
   $phitmp = $20 ? 2 : 1;
   $23 = $phitmp;
  }
 } while(0);
 $22 = Math_imul($23, $15)|0;
 $24 = (($14) + ($22)|0);
 HEAP32[$3>>2] = $24;
 HEAP32[$4>>2] = $10;
 return 0;
}
function _GLES2_UnlockTexture($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = ((($1)) + 68|0);
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$2>>2] = 0;
 $5 = ((($2)) + 4|0);
 HEAP32[$5>>2] = 0;
 $6 = ((($1)) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($2)) + 8|0);
 HEAP32[$8>>2] = $7;
 $9 = ((($1)) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ((($2)) + 12|0);
 HEAP32[$11>>2] = $10;
 $12 = ((($4)) + 16|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($4)) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 (_GLES2_UpdateTexture($0,$1,$2,$13,$15)|0);
 STACKTOP = sp;return;
}
function _GLES2_SetRenderTarget($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $2 = ((($0)) + 320|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)==(0|0);
 $5 = ((($3)) + 192|0);
 $6 = HEAP32[$5>>2]|0;
 if ($4) {
  $7 = ((($3)) + 236|0);
  $8 = HEAP32[$7>>2]|0;
  FUNCTION_TABLE_vii[$6 & 8191](36160,$8);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $9 = ((($1)) + 68|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ((($10)) + 40|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ((($12)) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 FUNCTION_TABLE_vii[$6 & 8191](36160,$14);
 $15 = ((($3)) + 196|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ((($10)) + 4|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = HEAP32[$10>>2]|0;
 FUNCTION_TABLE_viiiii[$16 & 8191](36160,36064,$18,$19,0);
 $20 = ((($3)) + 200|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (FUNCTION_TABLE_ii[$21 & 8191](36160)|0);
 $23 = ($22|0)==(36053);
 if ($23) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $24 = (_SDL_SetError(181165,$vararg_buffer)|0);
 $$0 = $24;
 STACKTOP = sp;return ($$0|0);
}
function _GLES2_UpdateViewport($0) {
 $0 = $0|0;
 var $$0 = 0, $$0$i$i = 0, $$0211$i = 0, $$122$i = 0, $$sink$i = 0.0, $$sink3$i = 0.0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0.0, $48 = 0.0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0.0, $53 = 0.0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $9 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, $vararg_ptr3 = 0, $vararg_ptr4 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(96|0);
 $vararg_buffer = sp;
 $1 = sp + 32|0;
 $2 = sp + 28|0;
 $3 = sp + 24|0;
 $4 = ((($0)) + 320|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[52374]|0;
 $7 = HEAP32[$5>>2]|0;
 $8 = ($6|0)==($7|0);
 if (!($8)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $9 = ((($0)) + 308|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  $22 = ((($0)) + 188|0);
  $23 = HEAP32[$22>>2]|0;
  _SDL_GL_GetDrawableSize($23,$2,$3);
  $24 = ((($5)) + 188|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = ((($0)) + 216|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = HEAP32[$3>>2]|0;
  $29 = ((($0)) + 220|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (($28) - ($30))|0;
  $32 = ((($0)) + 228|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = (($31) - ($33))|0;
  $35 = ((($0)) + 224|0);
  $36 = HEAP32[$35>>2]|0;
  FUNCTION_TABLE_viiii[$25 & 8191]($27,$34,$36,$33);
 } else {
  $12 = ((($5)) + 188|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ((($0)) + 216|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = ((($0)) + 220|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = ((($0)) + 224|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = ((($0)) + 228|0);
  $21 = HEAP32[$20>>2]|0;
  FUNCTION_TABLE_viiii[$13 & 8191]($15,$17,$19,$21);
 }
 $37 = ((($5)) + 268|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = ($38|0)==(0|0);
 if (!($39)) {
  $40 = HEAP32[$4>>2]|0;
  $41 = ((($0)) + 224|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = ($42|0)==(0);
  if (!($43)) {
   $44 = ((($0)) + 228|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = ($45|0)==(0);
   if (!($46)) {
    $47 = (+($42|0));
    $48 = 2.0 / $47;
    HEAPF32[$1>>2] = $48;
    $49 = ((($1)) + 4|0);
    ;HEAP32[$49>>2]=0|0;HEAP32[$49+4>>2]=0|0;HEAP32[$49+8>>2]=0|0;HEAP32[$49+12>>2]=0|0;
    $50 = HEAP32[$9>>2]|0;
    $51 = ($50|0)!=(0|0);
    $52 = (+($45|0));
    $$sink3$i = $51 ? 2.0 : -2.0;
    $53 = $$sink3$i / $52;
    $54 = ((($1)) + 20|0);
    HEAPF32[$54>>2] = $53;
    $55 = ((($1)) + 24|0);
    $56 = ((($1)) + 48|0);
    ;HEAP32[$55>>2]=0|0;HEAP32[$55+4>>2]=0|0;HEAP32[$55+8>>2]=0|0;HEAP32[$55+12>>2]=0|0;HEAP32[$55+16>>2]=0|0;HEAP32[$55+20>>2]=0|0;
    HEAPF32[$56>>2] = -1.0;
    $57 = ((($1)) + 52|0);
    $$sink$i = $51 ? -1.0 : 1.0;
    HEAPF32[$57>>2] = $$sink$i;
    $58 = ((($1)) + 56|0);
    HEAPF32[$58>>2] = 0.0;
    $59 = ((($1)) + 60|0);
    HEAPF32[$59>>2] = 1.0;
    $60 = ((($40)) + 268|0);
    $61 = HEAP32[$60>>2]|0;
    $62 = ((($61)) + 88|0);
    $63 = (_SDL_memcmp($62,$1,64)|0);
    $64 = ($63|0)==(0);
    if (!($64)) {
     $65 = HEAP32[$60>>2]|0;
     $66 = ((($65)) + 16|0);
     $67 = HEAP32[$66>>2]|0;
     $68 = ((($40)) + 176|0);
     $69 = HEAP32[$68>>2]|0;
     FUNCTION_TABLE_viiii[$69 & 8191]($67,1,0,$1);
     $70 = HEAP32[$60>>2]|0;
     $71 = ((($70)) + 88|0);
     (_SDL_memcpy($71,$1,64)|0);
    }
   }
  }
 }
 $72 = HEAP32[$4>>2]|0;
 $73 = ((($72)) + 4|0);
 $74 = HEAP32[$73>>2]|0;
 $75 = ($74|0)==(0);
 if ($75) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $76 = ((($72)) + 108|0);
 $77 = HEAP32[$76>>2]|0;
 $78 = (FUNCTION_TABLE_i[$77 & 8191]()|0);
 $79 = ($78|0)==(0);
 if ($79) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  $$0211$i = 221531;$83 = $78;
 }
 while(1) {
  $80 = ($$0211$i|0)==(0|0);
  if ($80) {
   label = 15;
  } else {
   $81 = HEAP8[$$0211$i>>0]|0;
   $82 = ($81<<24>>24)==(0);
   if ($82) {
    label = 15;
   } else {
    $$122$i = $$0211$i;
   }
  }
  if ((label|0) == 15) {
   label = 0;
   $$122$i = 175195;
  }
  switch ($83|0) {
  case 1280:  {
   $$0$i$i = 175266;
   break;
  }
  case 1281:  {
   $$0$i$i = 175249;
   break;
  }
  case 1282:  {
   $$0$i$i = 175228;
   break;
  }
  case 1285:  {
   $$0$i$i = 175211;
   break;
  }
  default: {
   $$0$i$i = 175203;
  }
  }
  HEAP32[$vararg_buffer>>2] = $$122$i;
  $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
  HEAP32[$vararg_ptr1>>2] = 175308;
  $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
  HEAP32[$vararg_ptr2>>2] = 399;
  $vararg_ptr3 = ((($vararg_buffer)) + 12|0);
  HEAP32[$vararg_ptr3>>2] = 181124;
  $vararg_ptr4 = ((($vararg_buffer)) + 16|0);
  HEAP32[$vararg_ptr4>>2] = $$0$i$i;
  $vararg_ptr5 = ((($vararg_buffer)) + 20|0);
  HEAP32[$vararg_ptr5>>2] = $83;
  (_SDL_SetError(175282,$vararg_buffer)|0);
  $84 = HEAP32[$76>>2]|0;
  $85 = (FUNCTION_TABLE_i[$84 & 8191]()|0);
  $86 = ($85|0)==(0);
  if ($86) {
   $$0 = -1;
   break;
  } else {
   $$0211$i = $$122$i;$83 = $85;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function _GLES2_UpdateClipRect($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp + 4|0;
 $2 = sp;
 $3 = ((($0)) + 320|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[52374]|0;
 $6 = HEAP32[$4>>2]|0;
 $7 = ($5|0)==($6|0);
 if (!($7)) {
  STACKTOP = sp;return 0;
 }
 $8 = ((($0)) + 280|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0);
 if ($10) {
  $52 = ((($4)) + 68|0);
  $53 = HEAP32[$52>>2]|0;
  FUNCTION_TABLE_vi[$53 & 8191](3089);
  STACKTOP = sp;return 0;
 }
 $11 = ((($0)) + 248|0);
 $12 = ((($4)) + 80|0);
 $13 = HEAP32[$12>>2]|0;
 FUNCTION_TABLE_vi[$13 & 8191](3089);
 $14 = ((($0)) + 308|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0|0);
 if ($16) {
  $32 = ((($0)) + 188|0);
  $33 = HEAP32[$32>>2]|0;
  _SDL_GL_GetDrawableSize($33,$1,$2);
  $34 = ((($4)) + 144|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = ((($0)) + 216|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = HEAP32[$11>>2]|0;
  $39 = (($38) + ($37))|0;
  $40 = HEAP32[$2>>2]|0;
  $41 = ((($0)) + 220|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = (($40) - ($42))|0;
  $44 = ((($0)) + 252|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = (($43) - ($45))|0;
  $47 = ((($0)) + 260|0);
  $48 = HEAP32[$47>>2]|0;
  $49 = (($46) - ($48))|0;
  $50 = ((($0)) + 256|0);
  $51 = HEAP32[$50>>2]|0;
  FUNCTION_TABLE_viiii[$35 & 8191]($39,$49,$51,$48);
  STACKTOP = sp;return 0;
 } else {
  $17 = ((($4)) + 144|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = ((($0)) + 216|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = HEAP32[$11>>2]|0;
  $22 = (($21) + ($20))|0;
  $23 = ((($0)) + 220|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = ((($0)) + 252|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + ($24))|0;
  $28 = ((($0)) + 256|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = ((($0)) + 260|0);
  $31 = HEAP32[$30>>2]|0;
  FUNCTION_TABLE_viiii[$18 & 8191]($22,$27,$29,$31);
  STACKTOP = sp;return 0;
 }
 return (0)|0;
}
function _GLES2_RenderClear($0) {
 $0 = $0|0;
 var $$0 = 0, $$037 = 0, $$pre$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0.0, $65 = 0.0, $66 = 0.0, $67 = 0.0, $68 = 0.0, $69 = 0.0, $7 = 0, $70 = 0.0, $71 = 0.0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $9 = 0, $switch$split2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 320|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[52374]|0;
 $4 = HEAP32[$2>>2]|0;
 $5 = ($3|0)==($4|0);
 if ($5) {
  $13 = $2;
  label = 4;
 } else {
  $6 = ((($2)) + 268|0);
  HEAP32[$6>>2] = 0;
  $7 = ((($0)) + 188|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (_SDL_GL_MakeCurrent($8,$4)|0);
  $10 = ($9|0)<(0);
  if (!($10)) {
   $11 = HEAP32[$2>>2]|0;
   HEAP32[52374] = $11;
   (_GLES2_UpdateViewport($0)|0);
   $$pre$i = HEAP32[$1>>2]|0;
   $13 = $$pre$i;
   label = 4;
  }
 }
 if ((label|0) == 4) {
  $12 = ((($13)) + 4|0);
  $14 = HEAP32[$12>>2]|0;
  $15 = ($14|0)==(0);
  if (!($15)) {
   $16 = ((($13)) + 108|0);
   while(1) {
    $17 = HEAP32[$16>>2]|0;
    $18 = (FUNCTION_TABLE_i[$17 & 8191]()|0);
    $19 = ($18|0)==(0);
    if ($19) {
     break;
    }
   }
  }
 }
 $20 = ((($2)) + 272|0);
 $21 = HEAP8[$20>>0]|0;
 $22 = ((($2)) + 273|0);
 $23 = HEAP8[$22>>0]|0;
 $24 = ((($2)) + 274|0);
 $25 = HEAP8[$24>>0]|0;
 $26 = ((($2)) + 275|0);
 $27 = HEAP8[$26>>0]|0;
 $28 = ((($0)) + 312|0);
 $29 = HEAP8[$28>>0]|0;
 $30 = ((($0)) + 313|0);
 $31 = HEAP8[$30>>0]|0;
 $32 = ((($0)) + 314|0);
 $33 = HEAP8[$32>>0]|0;
 $34 = ((($0)) + 315|0);
 $35 = HEAP8[$34>>0]|0;
 $36 = $21&255;
 $37 = $36 << 24;
 $38 = $23&255;
 $39 = $38 << 16;
 $40 = $39 | $37;
 $41 = $25&255;
 $42 = $41 << 8;
 $43 = $40 | $42;
 $44 = $27&255;
 $45 = $43 | $44;
 $46 = $29&255;
 $47 = $46 << 24;
 $48 = $31&255;
 $49 = $48 << 16;
 $50 = $49 | $47;
 $51 = $33&255;
 $52 = $51 << 8;
 $53 = $50 | $52;
 $54 = $35&255;
 $55 = $53 | $54;
 $56 = ($45|0)==($55|0);
 if (!($56)) {
  $57 = ((($0)) + 308|0);
  $58 = HEAP32[$57>>2]|0;
  $59 = ($58|0)==(0|0);
  L12: do {
   if ($59) {
    label = 10;
   } else {
    $60 = ((($58)) + 4|0);
    $61 = HEAP32[$60>>2]|0;
    $switch$split2D = ($61|0)<(372645892);
    if ($switch$split2D) {
     switch ($61|0) {
     case 370546692:  {
      $$0 = $33;$$037 = $29;
      break L12;
      break;
     }
     default: {
      label = 10;
      break L12;
     }
     }
    } else {
     switch ($61|0) {
     case 372645892:  {
      $$0 = $33;$$037 = $29;
      break L12;
      break;
     }
     default: {
      label = 10;
      break L12;
     }
     }
    }
   }
  } while(0);
  if ((label|0) == 10) {
   $$0 = $29;$$037 = $33;
  }
  $62 = ((($2)) + 40|0);
  $63 = HEAP32[$62>>2]|0;
  $64 = (+($$0&255));
  $65 = $64 * 0.0039215688593685627;
  $66 = (+($31&255));
  $67 = $66 * 0.0039215688593685627;
  $68 = (+($$037&255));
  $69 = $68 * 0.0039215688593685627;
  $70 = (+($35&255));
  $71 = $70 * 0.0039215688593685627;
  FUNCTION_TABLE_vdddd[$63 & 8191]($65,$67,$69,$71);
  $72 = HEAP8[$28>>0]|0;
  HEAP8[$20>>0] = $72;
  $73 = HEAP8[$30>>0]|0;
  HEAP8[$22>>0] = $73;
  $74 = HEAP8[$32>>0]|0;
  HEAP8[$24>>0] = $74;
  $75 = HEAP8[$34>>0]|0;
  HEAP8[$26>>0] = $75;
 }
 $76 = ((($0)) + 280|0);
 $77 = HEAP32[$76>>2]|0;
 $78 = ($77|0)==(0);
 if (!($78)) {
  $79 = ((($2)) + 68|0);
  $80 = HEAP32[$79>>2]|0;
  FUNCTION_TABLE_vi[$80 & 8191](3089);
 }
 $81 = ((($2)) + 36|0);
 $82 = HEAP32[$81>>2]|0;
 FUNCTION_TABLE_vi[$82 & 8191](16384);
 $83 = HEAP32[$76>>2]|0;
 $84 = ($83|0)==(0);
 if ($84) {
  return 0;
 }
 $85 = ((($2)) + 80|0);
 $86 = HEAP32[$85>>2]|0;
 FUNCTION_TABLE_vi[$86 & 8191](3089);
 return 0;
}
function _GLES2_RenderDrawPoints($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$03031 = 0, $$alloca_mul = 0, $$pre$i = 0, $10 = 0, $11 = 0.0, $12 = 0.0, $13 = 0, $14 = 0.0, $15 = 0.0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $exitcond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 320|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (_GLES2_SetDrawingState($0)|0);
 $6 = ($5|0)<(0);
 if ($6) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 $7 = $2 << 3;
 $$alloca_mul = $7;
 $8 = STACKTOP; STACKTOP = STACKTOP + ((((1*$$alloca_mul)|0)+15)&-16)|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(((((1*$$alloca_mul)|0)+15)&-16)|0);;
 $9 = ($2|0)>(0);
 if ($9) {
  $$03031 = 0;
  while(1) {
   $10 = (($1) + ($$03031<<3)|0);
   $11 = +HEAPF32[$10>>2];
   $12 = $11 + 0.5;
   $13 = (((($1) + ($$03031<<3)|0)) + 4|0);
   $14 = +HEAPF32[$13>>2];
   $15 = $14 + 0.5;
   $16 = $$03031 << 1;
   $17 = (($8) + ($16<<2)|0);
   HEAPF32[$17>>2] = $12;
   $18 = $16 | 1;
   $19 = (($8) + ($18<<2)|0);
   HEAPF32[$19>>2] = $15;
   $20 = (($$03031) + 1)|0;
   $exitcond = ($20|0)==($2|0);
   if ($exitcond) {
    break;
   } else {
    $$03031 = $20;
   }
  }
 }
 $21 = HEAP32[$3>>2]|0;
 $22 = ((($21)) + 276|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)==(0);
 if ($24) {
  $25 = ((($21)) + 216|0);
  $26 = HEAP32[$25>>2]|0;
  FUNCTION_TABLE_vii[$26 & 8191](1,$22);
  $$pre$i = HEAP32[$22>>2]|0;
  $29 = $$pre$i;
 } else {
  $29 = $23;
 }
 $27 = ((($21)) + 220|0);
 $28 = HEAP32[$27>>2]|0;
 FUNCTION_TABLE_vii[$28 & 8191](34962,$29);
 $30 = ((($21)) + 292|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ($31>>>0)<($7>>>0);
 if ($32) {
  $33 = ((($21)) + 224|0);
  $34 = HEAP32[$33>>2]|0;
  FUNCTION_TABLE_viiii[$34 & 8191](34962,$7,$8,35040);
  HEAP32[$30>>2] = $7;
 } else {
  $35 = ((($21)) + 228|0);
  $36 = HEAP32[$35>>2]|0;
  FUNCTION_TABLE_viiii[$36 & 8191](34962,0,$7,$8);
 }
 $37 = ((($21)) + 184|0);
 $38 = HEAP32[$37>>2]|0;
 FUNCTION_TABLE_viiiiii[$38 & 8191](0,2,5126,0,0,0);
 $39 = ((($4)) + 76|0);
 $40 = HEAP32[$39>>2]|0;
 FUNCTION_TABLE_viii[$40 & 8191](0,0,$2);
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _GLES2_RenderDrawLines($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$0$i$i = 0, $$0211$i = 0, $$04041 = 0, $$122$i = 0, $$alloca_mul = 0, $$pre$i = 0, $10 = 0, $11 = 0.0, $12 = 0.0, $13 = 0, $14 = 0.0, $15 = 0.0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0.0, $44 = 0, $45 = 0.0, $46 = 0, $47 = 0, $48 = 0.0, $49 = 0, $5 = 0, $50 = 0.0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, $vararg_ptr3 = 0, $vararg_ptr4 = 0, $vararg_ptr5 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $vararg_buffer = sp;
 $3 = ((($0)) + 320|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (_GLES2_SetDrawingState($0)|0);
 $6 = ($5|0)<(0);
 if ($6) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 $7 = $2 << 3;
 $$alloca_mul = $7;
 $8 = STACKTOP; STACKTOP = STACKTOP + ((((1*$$alloca_mul)|0)+15)&-16)|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(((((1*$$alloca_mul)|0)+15)&-16)|0);;
 $9 = ($2|0)>(0);
 if ($9) {
  $$04041 = 0;
  while(1) {
   $10 = (($1) + ($$04041<<3)|0);
   $11 = +HEAPF32[$10>>2];
   $12 = $11 + 0.5;
   $13 = (((($1) + ($$04041<<3)|0)) + 4|0);
   $14 = +HEAPF32[$13>>2];
   $15 = $14 + 0.5;
   $16 = $$04041 << 1;
   $17 = (($8) + ($16<<2)|0);
   HEAPF32[$17>>2] = $12;
   $18 = $16 | 1;
   $19 = (($8) + ($18<<2)|0);
   HEAPF32[$19>>2] = $15;
   $20 = (($$04041) + 1)|0;
   $exitcond = ($20|0)==($2|0);
   if ($exitcond) {
    break;
   } else {
    $$04041 = $20;
   }
  }
 }
 $21 = HEAP32[$3>>2]|0;
 $22 = ((($21)) + 276|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)==(0);
 if ($24) {
  $25 = ((($21)) + 216|0);
  $26 = HEAP32[$25>>2]|0;
  FUNCTION_TABLE_vii[$26 & 8191](1,$22);
  $$pre$i = HEAP32[$22>>2]|0;
  $29 = $$pre$i;
 } else {
  $29 = $23;
 }
 $27 = ((($21)) + 220|0);
 $28 = HEAP32[$27>>2]|0;
 FUNCTION_TABLE_vii[$28 & 8191](34962,$29);
 $30 = ((($21)) + 292|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ($31>>>0)<($7>>>0);
 if ($32) {
  $33 = ((($21)) + 224|0);
  $34 = HEAP32[$33>>2]|0;
  FUNCTION_TABLE_viiii[$34 & 8191](34962,$7,$8,35040);
  HEAP32[$30>>2] = $7;
 } else {
  $35 = ((($21)) + 228|0);
  $36 = HEAP32[$35>>2]|0;
  FUNCTION_TABLE_viiii[$36 & 8191](34962,0,$7,$8);
 }
 $37 = ((($21)) + 184|0);
 $38 = HEAP32[$37>>2]|0;
 FUNCTION_TABLE_viiiiii[$38 & 8191](0,2,5126,0,0,0);
 $39 = ((($4)) + 76|0);
 $40 = HEAP32[$39>>2]|0;
 FUNCTION_TABLE_viii[$40 & 8191](3,0,$2);
 $41 = ($2|0)==(2);
 $42 = (($2) + -1)|0;
 if ($41) {
  label = 12;
 } else {
  $43 = +HEAPF32[$1>>2];
  $44 = (($1) + ($42<<3)|0);
  $45 = +HEAPF32[$44>>2];
  $46 = $43 != $45;
  if ($46) {
   label = 12;
  } else {
   $47 = ((($1)) + 4|0);
   $48 = +HEAPF32[$47>>2];
   $49 = (((($1) + ($42<<3)|0)) + 4|0);
   $50 = +HEAPF32[$49>>2];
   $51 = $48 != $50;
   if ($51) {
    label = 12;
   }
  }
 }
 if ((label|0) == 12) {
  $52 = HEAP32[$39>>2]|0;
  FUNCTION_TABLE_viii[$52 & 8191](0,$42,1);
 }
 $53 = HEAP32[$3>>2]|0;
 $54 = ((($53)) + 4|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = ($55|0)==(0);
 if ($56) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $57 = ((($53)) + 108|0);
 $58 = HEAP32[$57>>2]|0;
 $59 = (FUNCTION_TABLE_i[$58 & 8191]()|0);
 $60 = ($59|0)==(0);
 if ($60) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  $$0211$i = 221531;$64 = $59;
 }
 while(1) {
  $61 = ($$0211$i|0)==(0|0);
  if ($61) {
   label = 17;
  } else {
   $62 = HEAP8[$$0211$i>>0]|0;
   $63 = ($62<<24>>24)==(0);
   if ($63) {
    label = 17;
   } else {
    $$122$i = $$0211$i;
   }
  }
  if ((label|0) == 17) {
   label = 0;
   $$122$i = 175195;
  }
  switch ($64|0) {
  case 1280:  {
   $$0$i$i = 175266;
   break;
  }
  case 1281:  {
   $$0$i$i = 175249;
   break;
  }
  case 1282:  {
   $$0$i$i = 175228;
   break;
  }
  case 1285:  {
   $$0$i$i = 175211;
   break;
  }
  default: {
   $$0$i$i = 175203;
  }
  }
  HEAP32[$vararg_buffer>>2] = $$122$i;
  $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
  HEAP32[$vararg_ptr1>>2] = 175308;
  $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
  HEAP32[$vararg_ptr2>>2] = 1514;
  $vararg_ptr3 = ((($vararg_buffer)) + 12|0);
  HEAP32[$vararg_ptr3>>2] = 181057;
  $vararg_ptr4 = ((($vararg_buffer)) + 16|0);
  HEAP32[$vararg_ptr4>>2] = $$0$i$i;
  $vararg_ptr5 = ((($vararg_buffer)) + 20|0);
  HEAP32[$vararg_ptr5>>2] = $64;
  (_SDL_SetError(175282,$vararg_buffer)|0);
  $65 = HEAP32[$57>>2]|0;
  $66 = (FUNCTION_TABLE_i[$65 & 8191]()|0);
  $67 = ($66|0)==(0);
  if ($67) {
   $$0 = -1;
   break;
  } else {
   $$0211$i = $$122$i;$64 = $66;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function _GLES2_RenderFillRects($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$0$i$i = 0, $$0211$i = 0, $$03738 = 0, $$122$i = 0, $$pre$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0.0, $19 = 0, $20 = 0.0, $21 = 0.0, $22 = 0, $23 = 0.0;
 var $24 = 0, $25 = 0.0, $26 = 0.0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, $vararg_ptr3 = 0, $vararg_ptr4 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(64|0);
 $vararg_buffer = sp;
 $3 = sp + 24|0;
 $4 = ((($0)) + 320|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (_GLES2_SetDrawingState($0)|0);
 $7 = ($6|0)<(0);
 if ($7) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 $8 = ($2|0)>(0);
 if ($8) {
  $9 = ((($3)) + 4|0);
  $10 = ((($3)) + 8|0);
  $11 = ((($3)) + 12|0);
  $12 = ((($3)) + 16|0);
  $13 = ((($3)) + 20|0);
  $14 = ((($3)) + 24|0);
  $15 = ((($3)) + 28|0);
  $16 = ((($5)) + 76|0);
  $$03738 = 0;
  while(1) {
   $17 = (($1) + ($$03738<<4)|0);
   $18 = +HEAPF32[$17>>2];
   $19 = (((($1) + ($$03738<<4)|0)) + 8|0);
   $20 = +HEAPF32[$19>>2];
   $21 = $18 + $20;
   $22 = (((($1) + ($$03738<<4)|0)) + 4|0);
   $23 = +HEAPF32[$22>>2];
   $24 = (((($1) + ($$03738<<4)|0)) + 12|0);
   $25 = +HEAPF32[$24>>2];
   $26 = $23 + $25;
   HEAPF32[$3>>2] = $18;
   HEAPF32[$9>>2] = $23;
   HEAPF32[$10>>2] = $21;
   HEAPF32[$11>>2] = $23;
   HEAPF32[$12>>2] = $18;
   HEAPF32[$13>>2] = $26;
   HEAPF32[$14>>2] = $21;
   HEAPF32[$15>>2] = $26;
   $27 = HEAP32[$4>>2]|0;
   $28 = ((($27)) + 276|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = ($29|0)==(0);
   if ($30) {
    $31 = ((($27)) + 216|0);
    $32 = HEAP32[$31>>2]|0;
    FUNCTION_TABLE_vii[$32 & 8191](1,$28);
    $$pre$i = HEAP32[$28>>2]|0;
    $35 = $$pre$i;
   } else {
    $35 = $29;
   }
   $33 = ((($27)) + 220|0);
   $34 = HEAP32[$33>>2]|0;
   FUNCTION_TABLE_vii[$34 & 8191](34962,$35);
   $36 = ((($27)) + 292|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = ($37>>>0)<(32);
   if ($38) {
    $39 = ((($27)) + 224|0);
    $40 = HEAP32[$39>>2]|0;
    FUNCTION_TABLE_viiii[$40 & 8191](34962,32,$3,35040);
    HEAP32[$36>>2] = 32;
   } else {
    $41 = ((($27)) + 228|0);
    $42 = HEAP32[$41>>2]|0;
    FUNCTION_TABLE_viiii[$42 & 8191](34962,0,32,$3);
   }
   $43 = ((($27)) + 184|0);
   $44 = HEAP32[$43>>2]|0;
   FUNCTION_TABLE_viiiiii[$44 & 8191](0,2,5126,0,0,0);
   $45 = HEAP32[$16>>2]|0;
   FUNCTION_TABLE_viii[$45 & 8191](5,0,4);
   $46 = (($$03738) + 1)|0;
   $exitcond = ($46|0)==($2|0);
   if ($exitcond) {
    break;
   } else {
    $$03738 = $46;
   }
  }
 }
 $47 = HEAP32[$4>>2]|0;
 $48 = ((($47)) + 4|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = ($49|0)==(0);
 if ($50) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $51 = ((($47)) + 108|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = (FUNCTION_TABLE_i[$52 & 8191]()|0);
 $54 = ($53|0)==(0);
 if ($54) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  $$0211$i = 221531;$58 = $53;
 }
 while(1) {
  $55 = ($$0211$i|0)==(0|0);
  if ($55) {
   label = 14;
  } else {
   $56 = HEAP8[$$0211$i>>0]|0;
   $57 = ($56<<24>>24)==(0);
   if ($57) {
    label = 14;
   } else {
    $$122$i = $$0211$i;
   }
  }
  if ((label|0) == 14) {
   label = 0;
   $$122$i = 175195;
  }
  switch ($58|0) {
  case 1280:  {
   $$0$i$i = 175266;
   break;
  }
  case 1281:  {
   $$0$i$i = 175249;
   break;
  }
  case 1282:  {
   $$0$i$i = 175228;
   break;
  }
  case 1285:  {
   $$0$i$i = 175211;
   break;
  }
  default: {
   $$0$i$i = 175203;
  }
  }
  HEAP32[$vararg_buffer>>2] = $$122$i;
  $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
  HEAP32[$vararg_ptr1>>2] = 175308;
  $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
  HEAP32[$vararg_ptr2>>2] = 1549;
  $vararg_ptr3 = ((($vararg_buffer)) + 12|0);
  HEAP32[$vararg_ptr3>>2] = 180991;
  $vararg_ptr4 = ((($vararg_buffer)) + 16|0);
  HEAP32[$vararg_ptr4>>2] = $$0$i$i;
  $vararg_ptr5 = ((($vararg_buffer)) + 20|0);
  HEAP32[$vararg_ptr5>>2] = $58;
  (_SDL_SetError(175282,$vararg_buffer)|0);
  $59 = HEAP32[$51>>2]|0;
  $60 = (FUNCTION_TABLE_i[$59 & 8191]()|0);
  $61 = ($60|0)==(0);
  if ($61) {
   $$0 = -1;
   break;
  } else {
   $$0211$i = $$122$i;$58 = $60;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function _GLES2_RenderCopy($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $$0$i$i = 0, $$0211$i = 0, $$122$i = 0, $$pre$i = 0, $$pre$i41 = 0, $$pre$i42 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0.0, $28 = 0, $29 = 0.0, $30 = 0, $31 = 0, $32 = 0.0, $33 = 0.0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0.0, $39 = 0.0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0.0, $63 = 0, $64 = 0, $65 = 0.0, $66 = 0.0, $67 = 0, $68 = 0, $69 = 0.0, $7 = 0, $70 = 0, $71 = 0, $72 = 0.0;
 var $73 = 0.0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0.0, $79 = 0.0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0.0, $87 = 0.0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, $vararg_ptr3 = 0, $vararg_ptr4 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(96|0);
 $vararg_buffer = sp;
 $4 = sp + 56|0;
 $5 = sp + 24|0;
 $6 = ((($0)) + 320|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[52374]|0;
 $9 = HEAP32[$7>>2]|0;
 $10 = ($8|0)==($9|0);
 if ($10) {
  $18 = $7;
  label = 4;
 } else {
  $11 = ((($7)) + 268|0);
  HEAP32[$11>>2] = 0;
  $12 = ((($0)) + 188|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (_SDL_GL_MakeCurrent($13,$9)|0);
  $15 = ($14|0)<(0);
  if (!($15)) {
   $16 = HEAP32[$7>>2]|0;
   HEAP32[52374] = $16;
   (_GLES2_UpdateViewport($0)|0);
   $$pre$i = HEAP32[$6>>2]|0;
   $18 = $$pre$i;
   label = 4;
  }
 }
 if ((label|0) == 4) {
  $17 = ((($18)) + 4|0);
  $19 = HEAP32[$17>>2]|0;
  $20 = ($19|0)==(0);
  if (!($20)) {
   $21 = ((($18)) + 108|0);
   while(1) {
    $22 = HEAP32[$21>>2]|0;
    $23 = (FUNCTION_TABLE_i[$22 & 8191]()|0);
    $24 = ($23|0)==(0);
    if ($24) {
     break;
    }
   }
  }
 }
 $25 = (_GLES2_SetupCopy($0,$1)|0);
 $26 = ($25|0)<(0);
 if ($26) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 $27 = +HEAPF32[$3>>2];
 HEAPF32[$4>>2] = $27;
 $28 = ((($3)) + 4|0);
 $29 = +HEAPF32[$28>>2];
 $30 = ((($4)) + 4|0);
 HEAPF32[$30>>2] = $29;
 $31 = ((($3)) + 8|0);
 $32 = +HEAPF32[$31>>2];
 $33 = $27 + $32;
 $34 = ((($4)) + 8|0);
 HEAPF32[$34>>2] = $33;
 $35 = ((($4)) + 12|0);
 HEAPF32[$35>>2] = $29;
 $36 = ((($4)) + 16|0);
 HEAPF32[$36>>2] = $27;
 $37 = ((($3)) + 12|0);
 $38 = +HEAPF32[$37>>2];
 $39 = $29 + $38;
 $40 = ((($4)) + 20|0);
 HEAPF32[$40>>2] = $39;
 $41 = ((($4)) + 24|0);
 HEAPF32[$41>>2] = $33;
 $42 = ((($4)) + 28|0);
 HEAPF32[$42>>2] = $39;
 $43 = HEAP32[$6>>2]|0;
 $44 = ((($43)) + 276|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = ($45|0)==(0);
 if ($46) {
  $47 = ((($43)) + 216|0);
  $48 = HEAP32[$47>>2]|0;
  FUNCTION_TABLE_vii[$48 & 8191](1,$44);
  $$pre$i41 = HEAP32[$44>>2]|0;
  $51 = $$pre$i41;
 } else {
  $51 = $45;
 }
 $49 = ((($43)) + 220|0);
 $50 = HEAP32[$49>>2]|0;
 FUNCTION_TABLE_vii[$50 & 8191](34962,$51);
 $52 = ((($43)) + 292|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = ($53>>>0)<(32);
 if ($54) {
  $55 = ((($43)) + 224|0);
  $56 = HEAP32[$55>>2]|0;
  FUNCTION_TABLE_viiii[$56 & 8191](34962,32,$4,35040);
  HEAP32[$52>>2] = 32;
 } else {
  $57 = ((($43)) + 228|0);
  $58 = HEAP32[$57>>2]|0;
  FUNCTION_TABLE_viiii[$58 & 8191](34962,0,32,$4);
 }
 $59 = ((($43)) + 184|0);
 $60 = HEAP32[$59>>2]|0;
 FUNCTION_TABLE_viiiiii[$60 & 8191](0,2,5126,0,0,0);
 $61 = HEAP32[$2>>2]|0;
 $62 = (+($61|0));
 $63 = ((($1)) + 12|0);
 $64 = HEAP32[$63>>2]|0;
 $65 = (+($64|0));
 $66 = $62 / $65;
 HEAPF32[$5>>2] = $66;
 $67 = ((($2)) + 4|0);
 $68 = HEAP32[$67>>2]|0;
 $69 = (+($68|0));
 $70 = ((($1)) + 16|0);
 $71 = HEAP32[$70>>2]|0;
 $72 = (+($71|0));
 $73 = $69 / $72;
 $74 = ((($5)) + 4|0);
 HEAPF32[$74>>2] = $73;
 $75 = ((($2)) + 8|0);
 $76 = HEAP32[$75>>2]|0;
 $77 = (($76) + ($61))|0;
 $78 = (+($77|0));
 $79 = $78 / $65;
 $80 = ((($5)) + 8|0);
 HEAPF32[$80>>2] = $79;
 $81 = ((($5)) + 12|0);
 HEAPF32[$81>>2] = $73;
 $82 = ((($5)) + 16|0);
 HEAPF32[$82>>2] = $66;
 $83 = ((($2)) + 12|0);
 $84 = HEAP32[$83>>2]|0;
 $85 = (($84) + ($68))|0;
 $86 = (+($85|0));
 $87 = $86 / $72;
 $88 = ((($5)) + 20|0);
 HEAPF32[$88>>2] = $87;
 $89 = ((($5)) + 24|0);
 HEAPF32[$89>>2] = $79;
 $90 = ((($5)) + 28|0);
 HEAPF32[$90>>2] = $87;
 $91 = HEAP32[$6>>2]|0;
 $92 = ((($91)) + 280|0);
 $93 = HEAP32[$92>>2]|0;
 $94 = ($93|0)==(0);
 if ($94) {
  $95 = ((($91)) + 216|0);
  $96 = HEAP32[$95>>2]|0;
  FUNCTION_TABLE_vii[$96 & 8191](1,$92);
  $$pre$i42 = HEAP32[$92>>2]|0;
  $99 = $$pre$i42;
 } else {
  $99 = $93;
 }
 $97 = ((($91)) + 220|0);
 $98 = HEAP32[$97>>2]|0;
 FUNCTION_TABLE_vii[$98 & 8191](34962,$99);
 $100 = ((($91)) + 296|0);
 $101 = HEAP32[$100>>2]|0;
 $102 = ($101>>>0)<(32);
 if ($102) {
  $103 = ((($91)) + 224|0);
  $104 = HEAP32[$103>>2]|0;
  FUNCTION_TABLE_viiii[$104 & 8191](34962,32,$5,35040);
  HEAP32[$100>>2] = 32;
 } else {
  $105 = ((($91)) + 228|0);
  $106 = HEAP32[$105>>2]|0;
  FUNCTION_TABLE_viiii[$106 & 8191](34962,0,32,$5);
 }
 $107 = ((($91)) + 184|0);
 $108 = HEAP32[$107>>2]|0;
 FUNCTION_TABLE_viiiiii[$108 & 8191](1,2,5126,0,0,0);
 $109 = ((($7)) + 76|0);
 $110 = HEAP32[$109>>2]|0;
 FUNCTION_TABLE_viii[$110 & 8191](5,0,4);
 $111 = HEAP32[$6>>2]|0;
 $112 = ((($111)) + 4|0);
 $113 = HEAP32[$112>>2]|0;
 $114 = ($113|0)==(0);
 if ($114) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $115 = ((($111)) + 108|0);
 $116 = HEAP32[$115>>2]|0;
 $117 = (FUNCTION_TABLE_i[$116 & 8191]()|0);
 $118 = ($117|0)==(0);
 if ($118) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  $$0211$i = 221531;$122 = $117;
 }
 while(1) {
  $119 = ($$0211$i|0)==(0|0);
  if ($119) {
   label = 22;
  } else {
   $120 = HEAP8[$$0211$i>>0]|0;
   $121 = ($120<<24>>24)==(0);
   if ($121) {
    label = 22;
   } else {
    $$122$i = $$0211$i;
   }
  }
  if ((label|0) == 22) {
   label = 0;
   $$122$i = 175195;
  }
  switch ($122|0) {
  case 1280:  {
   $$0$i$i = 175266;
   break;
  }
  case 1281:  {
   $$0$i$i = 175249;
   break;
  }
  case 1282:  {
   $$0$i$i = 175228;
   break;
  }
  case 1285:  {
   $$0$i$i = 175211;
   break;
  }
  default: {
   $$0$i$i = 175203;
  }
  }
  HEAP32[$vararg_buffer>>2] = $$122$i;
  $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
  HEAP32[$vararg_ptr1>>2] = 175308;
  $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
  HEAP32[$vararg_ptr2>>2] = 1751;
  $vararg_ptr3 = ((($vararg_buffer)) + 12|0);
  HEAP32[$vararg_ptr3>>2] = 180902;
  $vararg_ptr4 = ((($vararg_buffer)) + 16|0);
  HEAP32[$vararg_ptr4>>2] = $$0$i$i;
  $vararg_ptr5 = ((($vararg_buffer)) + 20|0);
  HEAP32[$vararg_ptr5>>2] = $122;
  (_SDL_SetError(175282,$vararg_buffer)|0);
  $123 = HEAP32[$115>>2]|0;
  $124 = (FUNCTION_TABLE_i[$123 & 8191]()|0);
  $125 = ($124|0)==(0);
  if ($125) {
   $$0 = -1;
   break;
  } else {
   $$0211$i = $$122$i;$122 = $124;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function _GLES2_RenderCopyEx($0,$1,$2,$3,$4,$5,$6) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = +$4;
 $5 = $5|0;
 $6 = $6|0;
 var $$0 = 0, $$0$i$i = 0, $$0211$i = 0, $$122$i = 0, $$pre$i = 0, $$pre$i58 = 0, $$pre$i59 = 0, $$pre$i61 = 0, $$pre$i63 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0.0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0.0, $131 = 0.0, $132 = 0, $133 = 0, $134 = 0.0, $135 = 0, $136 = 0, $137 = 0.0, $138 = 0.0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0.0, $144 = 0.0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0.0, $152 = 0.0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0;
 var $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0;
 var $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0.0, $36 = 0.0, $37 = 0, $38 = 0, $39 = 0, $40 = 0.0, $41 = 0.0, $42 = 0.0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0.0, $48 = 0, $49 = 0.0, $50 = 0.0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0.0, $58 = 0.0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0.0, $64 = 0.0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, $vararg_ptr3 = 0;
 var $vararg_ptr4 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(144|0);
 $vararg_buffer = sp;
 $7 = sp + 104|0;
 $8 = sp + 72|0;
 $9 = sp + 40|0;
 $10 = sp + 24|0;
 $11 = ((($0)) + 320|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = HEAP32[52374]|0;
 $14 = HEAP32[$12>>2]|0;
 $15 = ($13|0)==($14|0);
 if ($15) {
  $23 = $12;
  label = 4;
 } else {
  $16 = ((($12)) + 268|0);
  HEAP32[$16>>2] = 0;
  $17 = ((($0)) + 188|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (_SDL_GL_MakeCurrent($18,$14)|0);
  $20 = ($19|0)<(0);
  if (!($20)) {
   $21 = HEAP32[$12>>2]|0;
   HEAP32[52374] = $21;
   (_GLES2_UpdateViewport($0)|0);
   $$pre$i = HEAP32[$11>>2]|0;
   $23 = $$pre$i;
   label = 4;
  }
 }
 if ((label|0) == 4) {
  $22 = ((($23)) + 4|0);
  $24 = HEAP32[$22>>2]|0;
  $25 = ($24|0)==(0);
  if (!($25)) {
   $26 = ((($23)) + 108|0);
   while(1) {
    $27 = HEAP32[$26>>2]|0;
    $28 = (FUNCTION_TABLE_i[$27 & 8191]()|0);
    $29 = ($28|0)==(0);
    if ($29) {
     break;
    }
   }
  }
 }
 $30 = (_GLES2_SetupCopy($0,$1)|0);
 $31 = ($30|0)<(0);
 if ($31) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 $32 = ((($12)) + 84|0);
 $33 = HEAP32[$32>>2]|0;
 FUNCTION_TABLE_vi[$33 & 8191](3);
 $34 = HEAP32[$32>>2]|0;
 FUNCTION_TABLE_vi[$34 & 8191](2);
 $35 = 360.0 - $4;
 $36 = $35;
 $37 = ((($10)) + 12|0);
 HEAPF32[$37>>2] = $36;
 $38 = ((($10)) + 8|0);
 HEAPF32[$38>>2] = $36;
 $39 = ((($10)) + 4|0);
 HEAPF32[$39>>2] = $36;
 HEAPF32[$10>>2] = $36;
 $40 = +HEAPF32[$5>>2];
 $41 = +HEAPF32[$3>>2];
 $42 = $40 + $41;
 $43 = ((($9)) + 24|0);
 HEAPF32[$43>>2] = $42;
 $44 = ((($9)) + 16|0);
 HEAPF32[$44>>2] = $42;
 $45 = ((($9)) + 8|0);
 HEAPF32[$45>>2] = $42;
 HEAPF32[$9>>2] = $42;
 $46 = ((($5)) + 4|0);
 $47 = +HEAPF32[$46>>2];
 $48 = ((($3)) + 4|0);
 $49 = +HEAPF32[$48>>2];
 $50 = $47 + $49;
 $51 = ((($9)) + 28|0);
 HEAPF32[$51>>2] = $50;
 $52 = ((($9)) + 20|0);
 HEAPF32[$52>>2] = $50;
 $53 = ((($9)) + 12|0);
 HEAPF32[$53>>2] = $50;
 $54 = ((($9)) + 4|0);
 HEAPF32[$54>>2] = $50;
 HEAPF32[$7>>2] = $41;
 $55 = ((($7)) + 4|0);
 HEAPF32[$55>>2] = $49;
 $56 = ((($3)) + 8|0);
 $57 = +HEAPF32[$56>>2];
 $58 = $41 + $57;
 $59 = ((($7)) + 8|0);
 HEAPF32[$59>>2] = $58;
 $60 = ((($7)) + 12|0);
 HEAPF32[$60>>2] = $49;
 $61 = ((($7)) + 16|0);
 HEAPF32[$61>>2] = $41;
 $62 = ((($3)) + 12|0);
 $63 = +HEAPF32[$62>>2];
 $64 = $49 + $63;
 $65 = ((($7)) + 20|0);
 HEAPF32[$65>>2] = $64;
 $66 = ((($7)) + 24|0);
 HEAPF32[$66>>2] = $58;
 $67 = ((($7)) + 28|0);
 HEAPF32[$67>>2] = $64;
 $68 = $6 & 1;
 $69 = ($68|0)==(0);
 if (!($69)) {
  HEAPF32[$61>>2] = $58;
  HEAPF32[$7>>2] = $58;
  HEAPF32[$66>>2] = $41;
  HEAPF32[$59>>2] = $41;
 }
 $70 = $6 & 2;
 $71 = ($70|0)==(0);
 if (!($71)) {
  HEAPF32[$60>>2] = $64;
  HEAPF32[$55>>2] = $64;
  HEAPF32[$67>>2] = $49;
  HEAPF32[$65>>2] = $49;
 }
 $72 = HEAP32[$11>>2]|0;
 $73 = ((($72)) + 284|0);
 $74 = HEAP32[$73>>2]|0;
 $75 = ($74|0)==(0);
 if ($75) {
  $76 = ((($72)) + 216|0);
  $77 = HEAP32[$76>>2]|0;
  FUNCTION_TABLE_vii[$77 & 8191](1,$73);
  $$pre$i58 = HEAP32[$73>>2]|0;
  $80 = $$pre$i58;
 } else {
  $80 = $74;
 }
 $78 = ((($72)) + 220|0);
 $79 = HEAP32[$78>>2]|0;
 FUNCTION_TABLE_vii[$79 & 8191](34962,$80);
 $81 = ((($72)) + 300|0);
 $82 = HEAP32[$81>>2]|0;
 $83 = ($82>>>0)<(16);
 if ($83) {
  $84 = ((($72)) + 224|0);
  $85 = HEAP32[$84>>2]|0;
  FUNCTION_TABLE_viiii[$85 & 8191](34962,16,$10,35040);
  HEAP32[$81>>2] = 16;
 } else {
  $86 = ((($72)) + 228|0);
  $87 = HEAP32[$86>>2]|0;
  FUNCTION_TABLE_viiii[$87 & 8191](34962,0,16,$10);
 }
 $88 = ((($72)) + 184|0);
 $89 = HEAP32[$88>>2]|0;
 FUNCTION_TABLE_viiiiii[$89 & 8191](2,1,5126,0,0,0);
 $90 = HEAP32[$11>>2]|0;
 $91 = ((($90)) + 288|0);
 $92 = HEAP32[$91>>2]|0;
 $93 = ($92|0)==(0);
 if ($93) {
  $94 = ((($90)) + 216|0);
  $95 = HEAP32[$94>>2]|0;
  FUNCTION_TABLE_vii[$95 & 8191](1,$91);
  $$pre$i59 = HEAP32[$91>>2]|0;
  $98 = $$pre$i59;
 } else {
  $98 = $92;
 }
 $96 = ((($90)) + 220|0);
 $97 = HEAP32[$96>>2]|0;
 FUNCTION_TABLE_vii[$97 & 8191](34962,$98);
 $99 = ((($90)) + 304|0);
 $100 = HEAP32[$99>>2]|0;
 $101 = ($100>>>0)<(32);
 if ($101) {
  $102 = ((($90)) + 224|0);
  $103 = HEAP32[$102>>2]|0;
  FUNCTION_TABLE_viiii[$103 & 8191](34962,32,$9,35040);
  HEAP32[$99>>2] = 32;
 } else {
  $104 = ((($90)) + 228|0);
  $105 = HEAP32[$104>>2]|0;
  FUNCTION_TABLE_viiii[$105 & 8191](34962,0,32,$9);
 }
 $106 = ((($90)) + 184|0);
 $107 = HEAP32[$106>>2]|0;
 FUNCTION_TABLE_viiiiii[$107 & 8191](3,2,5126,0,0,0);
 $108 = HEAP32[$11>>2]|0;
 $109 = ((($108)) + 276|0);
 $110 = HEAP32[$109>>2]|0;
 $111 = ($110|0)==(0);
 if ($111) {
  $112 = ((($108)) + 216|0);
  $113 = HEAP32[$112>>2]|0;
  FUNCTION_TABLE_vii[$113 & 8191](1,$109);
  $$pre$i61 = HEAP32[$109>>2]|0;
  $116 = $$pre$i61;
 } else {
  $116 = $110;
 }
 $114 = ((($108)) + 220|0);
 $115 = HEAP32[$114>>2]|0;
 FUNCTION_TABLE_vii[$115 & 8191](34962,$116);
 $117 = ((($108)) + 292|0);
 $118 = HEAP32[$117>>2]|0;
 $119 = ($118>>>0)<(32);
 if ($119) {
  $120 = ((($108)) + 224|0);
  $121 = HEAP32[$120>>2]|0;
  FUNCTION_TABLE_viiii[$121 & 8191](34962,32,$7,35040);
  HEAP32[$117>>2] = 32;
 } else {
  $122 = ((($108)) + 228|0);
  $123 = HEAP32[$122>>2]|0;
  FUNCTION_TABLE_viiii[$123 & 8191](34962,0,32,$7);
 }
 $124 = ((($108)) + 184|0);
 $125 = HEAP32[$124>>2]|0;
 FUNCTION_TABLE_viiiiii[$125 & 8191](0,2,5126,0,0,0);
 $126 = HEAP32[$2>>2]|0;
 $127 = (+($126|0));
 $128 = ((($1)) + 12|0);
 $129 = HEAP32[$128>>2]|0;
 $130 = (+($129|0));
 $131 = $127 / $130;
 HEAPF32[$8>>2] = $131;
 $132 = ((($2)) + 4|0);
 $133 = HEAP32[$132>>2]|0;
 $134 = (+($133|0));
 $135 = ((($1)) + 16|0);
 $136 = HEAP32[$135>>2]|0;
 $137 = (+($136|0));
 $138 = $134 / $137;
 $139 = ((($8)) + 4|0);
 HEAPF32[$139>>2] = $138;
 $140 = ((($2)) + 8|0);
 $141 = HEAP32[$140>>2]|0;
 $142 = (($141) + ($126))|0;
 $143 = (+($142|0));
 $144 = $143 / $130;
 $145 = ((($8)) + 8|0);
 HEAPF32[$145>>2] = $144;
 $146 = ((($8)) + 12|0);
 HEAPF32[$146>>2] = $138;
 $147 = ((($8)) + 16|0);
 HEAPF32[$147>>2] = $131;
 $148 = ((($2)) + 12|0);
 $149 = HEAP32[$148>>2]|0;
 $150 = (($149) + ($133))|0;
 $151 = (+($150|0));
 $152 = $151 / $137;
 $153 = ((($8)) + 20|0);
 HEAPF32[$153>>2] = $152;
 $154 = ((($8)) + 24|0);
 HEAPF32[$154>>2] = $144;
 $155 = ((($8)) + 28|0);
 HEAPF32[$155>>2] = $152;
 $156 = HEAP32[$11>>2]|0;
 $157 = ((($156)) + 280|0);
 $158 = HEAP32[$157>>2]|0;
 $159 = ($158|0)==(0);
 if ($159) {
  $160 = ((($156)) + 216|0);
  $161 = HEAP32[$160>>2]|0;
  FUNCTION_TABLE_vii[$161 & 8191](1,$157);
  $$pre$i63 = HEAP32[$157>>2]|0;
  $164 = $$pre$i63;
 } else {
  $164 = $158;
 }
 $162 = ((($156)) + 220|0);
 $163 = HEAP32[$162>>2]|0;
 FUNCTION_TABLE_vii[$163 & 8191](34962,$164);
 $165 = ((($156)) + 296|0);
 $166 = HEAP32[$165>>2]|0;
 $167 = ($166>>>0)<(32);
 if ($167) {
  $168 = ((($156)) + 224|0);
  $169 = HEAP32[$168>>2]|0;
  FUNCTION_TABLE_viiii[$169 & 8191](34962,32,$8,35040);
  HEAP32[$165>>2] = 32;
 } else {
  $170 = ((($156)) + 228|0);
  $171 = HEAP32[$170>>2]|0;
  FUNCTION_TABLE_viiii[$171 & 8191](34962,0,32,$8);
 }
 $172 = ((($156)) + 184|0);
 $173 = HEAP32[$172>>2]|0;
 FUNCTION_TABLE_viiiiii[$173 & 8191](1,2,5126,0,0,0);
 $174 = ((($12)) + 76|0);
 $175 = HEAP32[$174>>2]|0;
 FUNCTION_TABLE_viii[$175 & 8191](5,0,4);
 $176 = ((($12)) + 72|0);
 $177 = HEAP32[$176>>2]|0;
 FUNCTION_TABLE_vi[$177 & 8191](3);
 $178 = HEAP32[$176>>2]|0;
 FUNCTION_TABLE_vi[$178 & 8191](2);
 $179 = HEAP32[$11>>2]|0;
 $180 = ((($179)) + 4|0);
 $181 = HEAP32[$180>>2]|0;
 $182 = ($181|0)==(0);
 if ($182) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $183 = ((($179)) + 108|0);
 $184 = HEAP32[$183>>2]|0;
 $185 = (FUNCTION_TABLE_i[$184 & 8191]()|0);
 $186 = ($185|0)==(0);
 if ($186) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  $$0211$i = 221531;$190 = $185;
 }
 while(1) {
  $187 = ($$0211$i|0)==(0|0);
  if ($187) {
   label = 36;
  } else {
   $188 = HEAP8[$$0211$i>>0]|0;
   $189 = ($188<<24>>24)==(0);
   if ($189) {
    label = 36;
   } else {
    $$122$i = $$0211$i;
   }
  }
  if ((label|0) == 36) {
   label = 0;
   $$122$i = 175195;
  }
  switch ($190|0) {
  case 1280:  {
   $$0$i$i = 175266;
   break;
  }
  case 1281:  {
   $$0$i$i = 175249;
   break;
  }
  case 1282:  {
   $$0$i$i = 175228;
   break;
  }
  case 1285:  {
   $$0$i$i = 175211;
   break;
  }
  default: {
   $$0$i$i = 175203;
  }
  }
  HEAP32[$vararg_buffer>>2] = $$122$i;
  $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
  HEAP32[$vararg_ptr1>>2] = 175308;
  $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
  HEAP32[$vararg_ptr2>>2] = 1820;
  $vararg_ptr3 = ((($vararg_buffer)) + 12|0);
  HEAP32[$vararg_ptr3>>2] = 176651;
  $vararg_ptr4 = ((($vararg_buffer)) + 16|0);
  HEAP32[$vararg_ptr4>>2] = $$0$i$i;
  $vararg_ptr5 = ((($vararg_buffer)) + 20|0);
  HEAP32[$vararg_ptr5>>2] = $190;
  (_SDL_SetError(175282,$vararg_buffer)|0);
  $191 = HEAP32[$183>>2]|0;
  $192 = (FUNCTION_TABLE_i[$191 & 8191]()|0);
  $193 = ($192|0)==(0);
  if ($193) {
   $$0 = -1;
   break;
  } else {
   $$0211$i = $$122$i;$190 = $192;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function _GLES2_RenderReadPixels($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0 = 0, $$0$i$i = 0, $$08597 = 0, $$08696 = 0, $$08795 = 0, $$alloca_mul = 0, $$mask88 = 0, $$not = 0, $$off = 0, $$pre = 0, $$pre$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $or$cond91 = 0;
 var $phitmp = 0, $phitmp89 = 0, $switch$split2D = 0, $switch$split82D = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, $vararg_ptr3 = 0, $vararg_ptr4 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $vararg_buffer = sp;
 $5 = sp + 28|0;
 $6 = sp + 24|0;
 $7 = ((($0)) + 320|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($0)) + 308|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  $33 = 376840196;
 } else {
  $12 = ((($10)) + 4|0);
  $13 = HEAP32[$12>>2]|0;
  $33 = $13;
 }
 $14 = HEAP32[52374]|0;
 $15 = HEAP32[$8>>2]|0;
 $16 = ($14|0)==($15|0);
 if ($16) {
  $24 = $8;
  label = 6;
 } else {
  $17 = ((($8)) + 268|0);
  HEAP32[$17>>2] = 0;
  $18 = ((($0)) + 188|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = (_SDL_GL_MakeCurrent($19,$15)|0);
  $21 = ($20|0)<(0);
  if (!($21)) {
   $22 = HEAP32[$8>>2]|0;
   HEAP32[52374] = $22;
   (_GLES2_UpdateViewport($0)|0);
   $$pre$i = HEAP32[$7>>2]|0;
   $24 = $$pre$i;
   label = 6;
  }
 }
 if ((label|0) == 6) {
  $23 = ((($24)) + 4|0);
  $25 = HEAP32[$23>>2]|0;
  $26 = ($25|0)==(0);
  if (!($26)) {
   $27 = ((($24)) + 108|0);
   while(1) {
    $28 = HEAP32[$27>>2]|0;
    $29 = (FUNCTION_TABLE_i[$28 & 8191]()|0);
    $30 = ($29|0)==(0);
    if ($30) {
     break;
    }
   }
  }
 }
 $31 = ((($1)) + 8|0);
 $32 = HEAP32[$31>>2]|0;
 $$not = ($33|0)==(0);
 $$mask88 = $33 & -268435456;
 $34 = ($$mask88|0)==(268435456);
 $or$cond91 = $$not | $34;
 L13: do {
  if ($or$cond91) {
   $36 = $33 & 255;
   $38 = $36;
  } else {
   $switch$split2D = ($33|0)<(1498831189);
   if ($switch$split2D) {
    switch ($33|0) {
    case 844715353:  {
     $38 = 2;
     break L13;
     break;
    }
    default: {
    }
    }
   } else {
    switch ($33|0) {
    case 1498831189:  {
     $38 = 2;
     break L13;
     break;
    }
    default: {
    }
    }
   }
   $35 = ($33|0)==(1431918169);
   $phitmp89 = $35 ? 2 : 1;
   $38 = $phitmp89;
  }
 } while(0);
 $37 = Math_imul($38, $32)|0;
 $39 = ((($1)) + 12|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = Math_imul($40, $37)|0;
 $42 = (_SDL_malloc($41)|0);
 $43 = ($42|0)==(0|0);
 if ($43) {
  $44 = (_SDL_Error(0)|0);
  $$0 = $44;
  STACKTOP = sp;return ($$0|0);
 }
 (_SDL_GetRendererOutputSize($0,$5,$6)|0);
 $45 = ((($8)) + 140|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = HEAP32[$1>>2]|0;
 $48 = HEAP32[$9>>2]|0;
 $49 = ($48|0)==(0|0);
 $50 = ((($1)) + 4|0);
 $51 = HEAP32[$50>>2]|0;
 if ($49) {
  $52 = HEAP32[$6>>2]|0;
  $53 = (($52) - ($51))|0;
  $54 = HEAP32[$39>>2]|0;
  $55 = (($53) - ($54))|0;
  $57 = $55;$58 = $54;
 } else {
  $$pre = HEAP32[$39>>2]|0;
  $57 = $51;$58 = $$pre;
 }
 $56 = HEAP32[$31>>2]|0;
 FUNCTION_TABLE_viiiiiii[$46 & 8191]($47,$57,$56,$58,6408,5121,$42);
 $59 = HEAP32[$7>>2]|0;
 $60 = ((($59)) + 4|0);
 $61 = HEAP32[$60>>2]|0;
 $62 = ($61|0)==(0);
 if (!($62)) {
  $63 = ((($59)) + 108|0);
  $64 = HEAP32[$63>>2]|0;
  $65 = (FUNCTION_TABLE_i[$64 & 8191]()|0);
  $66 = ($65|0)==(0);
  if (!($66)) {
   $67 = $65;
   while(1) {
    switch ($67|0) {
    case 1280:  {
     $$0$i$i = 175266;
     break;
    }
    case 1281:  {
     $$0$i$i = 175249;
     break;
    }
    case 1282:  {
     $$0$i$i = 175228;
     break;
    }
    case 1285:  {
     $$0$i$i = 175211;
     break;
    }
    default: {
     $$0$i$i = 175203;
    }
    }
    HEAP32[$vararg_buffer>>2] = 175571;
    $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
    HEAP32[$vararg_ptr1>>2] = 175308;
    $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
    HEAP32[$vararg_ptr2>>2] = 1847;
    $vararg_ptr3 = ((($vararg_buffer)) + 12|0);
    HEAP32[$vararg_ptr3>>2] = 175586;
    $vararg_ptr4 = ((($vararg_buffer)) + 16|0);
    HEAP32[$vararg_ptr4>>2] = $$0$i$i;
    $vararg_ptr5 = ((($vararg_buffer)) + 20|0);
    HEAP32[$vararg_ptr5>>2] = $67;
    (_SDL_SetError(175282,$vararg_buffer)|0);
    $68 = HEAP32[$63>>2]|0;
    $69 = (FUNCTION_TABLE_i[$68 & 8191]()|0);
    $70 = ($69|0)==(0);
    if ($70) {
     $$0 = -1;
     break;
    } else {
     $67 = $69;
    }
   }
   STACKTOP = sp;return ($$0|0);
  }
 }
 $71 = HEAP32[$9>>2]|0;
 $72 = ($71|0)==(0|0);
 if ($72) {
  $73 = HEAP32[$31>>2]|0;
  L43: do {
   if ($or$cond91) {
    $75 = $33 & 255;
    $77 = $75;
   } else {
    $switch$split82D = ($33|0)<(1498831189);
    if ($switch$split82D) {
     switch ($33|0) {
     case 844715353:  {
      $77 = 2;
      break L43;
      break;
     }
     default: {
     }
     }
    } else {
     switch ($33|0) {
     case 1498831189:  {
      $77 = 2;
      break L43;
      break;
     }
     default: {
     }
     }
    }
    $74 = ($33|0)==(1431918169);
    $phitmp = $74 ? 2 : 1;
    $77 = $phitmp;
   }
  } while(0);
  $76 = Math_imul($77, $73)|0;
  $78 = HEAP32[$39>>2]|0;
  $$alloca_mul = $76;
  $79 = STACKTOP; STACKTOP = STACKTOP + ((((1*$$alloca_mul)|0)+15)&-16)|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(((((1*$$alloca_mul)|0)+15)&-16)|0);;
  $$off = (($78) + 1)|0;
  $80 = ($$off>>>0)<(3);
  if (!($80)) {
   $81 = (($78|0) / 2)&-1;
   $82 = (($78) + -1)|0;
   $83 = Math_imul($82, $37)|0;
   $84 = (($42) + ($83)|0);
   $85 = (0 - ($37))|0;
   $$08597 = $81;$$08696 = $84;$$08795 = $42;
   while(1) {
    $86 = (($$08597) + -1)|0;
    (_SDL_memcpy($79,$$08795,$76)|0);
    (_SDL_memcpy($$08795,$$08696,$76)|0);
    (_SDL_memcpy($$08696,$79,$76)|0);
    $87 = (($$08795) + ($37)|0);
    $88 = (($$08696) + ($85)|0);
    $89 = ($86|0)==(0);
    if ($89) {
     break;
    } else {
     $$08597 = $86;$$08696 = $88;$$08795 = $87;
    }
   }
  }
 }
 $90 = HEAP32[$31>>2]|0;
 $91 = HEAP32[$39>>2]|0;
 $92 = (_SDL_ConvertPixels($90,$91,$33,$42,$37,$2,$3,$4)|0);
 _SDL_free($42);
 $$0 = $92;
 STACKTOP = sp;return ($$0|0);
}
function _GLES2_RenderPresent($0) {
 $0 = $0|0;
 var $$pre$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 320|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[52374]|0;
 $4 = HEAP32[$2>>2]|0;
 $5 = ($3|0)==($4|0);
 if ($5) {
  $13 = $2;
  label = 4;
 } else {
  $6 = ((($2)) + 268|0);
  HEAP32[$6>>2] = 0;
  $7 = ((($0)) + 188|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (_SDL_GL_MakeCurrent($8,$4)|0);
  $10 = ($9|0)<(0);
  if (!($10)) {
   $11 = HEAP32[$2>>2]|0;
   HEAP32[52374] = $11;
   (_GLES2_UpdateViewport($0)|0);
   $$pre$i = HEAP32[$1>>2]|0;
   $13 = $$pre$i;
   label = 4;
  }
 }
 if ((label|0) == 4) {
  $12 = ((($13)) + 4|0);
  $14 = HEAP32[$12>>2]|0;
  $15 = ($14|0)==(0);
  if (!($15)) {
   $16 = ((($13)) + 108|0);
   while(1) {
    $17 = HEAP32[$16>>2]|0;
    $18 = (FUNCTION_TABLE_i[$17 & 8191]()|0);
    $19 = ($18|0)==(0);
    if ($19) {
     break;
    }
   }
  }
 }
 $20 = ((($0)) + 188|0);
 $21 = HEAP32[$20>>2]|0;
 _SDL_GL_SwapWindow($21);
 return;
}
function _GLES2_DestroyTexture($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$pre$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 320|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($1)) + 68|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[52374]|0;
 $7 = HEAP32[$3>>2]|0;
 $8 = ($6|0)==($7|0);
 if ($8) {
  $16 = $3;
  label = 4;
 } else {
  $9 = ((($3)) + 268|0);
  HEAP32[$9>>2] = 0;
  $10 = ((($0)) + 188|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (_SDL_GL_MakeCurrent($11,$7)|0);
  $13 = ($12|0)<(0);
  if (!($13)) {
   $14 = HEAP32[$3>>2]|0;
   HEAP32[52374] = $14;
   (_GLES2_UpdateViewport($0)|0);
   $$pre$i = HEAP32[$2>>2]|0;
   $16 = $$pre$i;
   label = 4;
  }
 }
 if ((label|0) == 4) {
  $15 = ((($16)) + 4|0);
  $17 = HEAP32[$15>>2]|0;
  $18 = ($17|0)==(0);
  if (!($18)) {
   $19 = ((($16)) + 108|0);
   while(1) {
    $20 = HEAP32[$19>>2]|0;
    $21 = (FUNCTION_TABLE_i[$20 & 8191]()|0);
    $22 = ($21|0)==(0);
    if ($22) {
     break;
    }
   }
  }
 }
 $23 = ($5|0)==(0|0);
 if ($23) {
  return;
 }
 $24 = ((($3)) + 64|0);
 $25 = HEAP32[$24>>2]|0;
 FUNCTION_TABLE_vii[$25 & 8191](1,$5);
 $26 = ((($5)) + 32|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ($27|0)==(0);
 if (!($28)) {
  $29 = HEAP32[$24>>2]|0;
  FUNCTION_TABLE_vii[$29 & 8191](1,$26);
 }
 $30 = ((($5)) + 36|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ($31|0)==(0);
 if (!($32)) {
  $33 = HEAP32[$24>>2]|0;
  FUNCTION_TABLE_vii[$33 & 8191](1,$30);
 }
 $34 = ((($5)) + 16|0);
 $35 = HEAP32[$34>>2]|0;
 _SDL_free($35);
 _SDL_free($5);
 HEAP32[$4>>2] = 0;
 return;
}
function _GLES2_BindTexture($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$pre$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ((($0)) + 320|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($1)) + 68|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[52374]|0;
 $9 = HEAP32[$5>>2]|0;
 $10 = ($8|0)==($9|0);
 if ($10) {
  $18 = $5;
  label = 4;
 } else {
  $11 = ((($5)) + 268|0);
  HEAP32[$11>>2] = 0;
  $12 = ((($0)) + 188|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (_SDL_GL_MakeCurrent($13,$9)|0);
  $15 = ($14|0)<(0);
  if (!($15)) {
   $16 = HEAP32[$5>>2]|0;
   HEAP32[52374] = $16;
   (_GLES2_UpdateViewport($0)|0);
   $$pre$i = HEAP32[$4>>2]|0;
   $18 = $$pre$i;
   label = 4;
  }
 }
 if ((label|0) == 4) {
  $17 = ((($18)) + 4|0);
  $19 = HEAP32[$17>>2]|0;
  $20 = ($19|0)==(0);
  if (!($20)) {
   $21 = ((($18)) + 108|0);
   while(1) {
    $22 = HEAP32[$21>>2]|0;
    $23 = (FUNCTION_TABLE_i[$22 & 8191]()|0);
    $24 = ($23|0)==(0);
    if ($24) {
     break;
    }
   }
  }
 }
 $25 = ((($5)) + 28|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ((($7)) + 4|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = HEAP32[$7>>2]|0;
 FUNCTION_TABLE_vii[$26 & 8191]($28,$29);
 $30 = ($2|0)==(0|0);
 if (!($30)) {
  HEAPF32[$2>>2] = 1.0;
 }
 $31 = ($3|0)==(0|0);
 if ($31) {
  return 0;
 }
 HEAPF32[$3>>2] = 1.0;
 return 0;
}
function _GLES2_UnbindTexture($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$pre$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 320|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($1)) + 68|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[52374]|0;
 $7 = HEAP32[$3>>2]|0;
 $8 = ($6|0)==($7|0);
 if ($8) {
  $16 = $3;
  label = 4;
 } else {
  $9 = ((($3)) + 268|0);
  HEAP32[$9>>2] = 0;
  $10 = ((($0)) + 188|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (_SDL_GL_MakeCurrent($11,$7)|0);
  $13 = ($12|0)<(0);
  if (!($13)) {
   $14 = HEAP32[$3>>2]|0;
   HEAP32[52374] = $14;
   (_GLES2_UpdateViewport($0)|0);
   $$pre$i = HEAP32[$2>>2]|0;
   $16 = $$pre$i;
   label = 4;
  }
 }
 if ((label|0) == 4) {
  $15 = ((($16)) + 4|0);
  $17 = HEAP32[$15>>2]|0;
  $18 = ($17|0)==(0);
  if (!($18)) {
   $19 = ((($16)) + 108|0);
   while(1) {
    $20 = HEAP32[$19>>2]|0;
    $21 = (FUNCTION_TABLE_i[$20 & 8191]()|0);
    $22 = ($21|0)==(0);
    if ($22) {
     break;
    }
   }
  }
 }
 $23 = ((($3)) + 28|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ((($5)) + 4|0);
 $26 = HEAP32[$25>>2]|0;
 FUNCTION_TABLE_vii[$24 & 8191]($26,0);
 return 0;
}
function _SDL_free($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 _free($0);
 return;
}
function _SDL_GL_SwapWindow($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer3 = 0;
 var $vararg_buffer5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $vararg_buffer5 = sp + 24|0;
 $vararg_buffer3 = sp + 16|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $1 = HEAP32[52375]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  (_SDL_SetError(175439,$vararg_buffer)|0);
  STACKTOP = sp;return;
 }
 $3 = ($0|0)==(0|0);
 if (!($3)) {
  $4 = HEAP32[$0>>2]|0;
  $5 = ((($1)) + 280|0);
  $6 = ($4|0)==($5|0);
  if ($6) {
   $7 = ((($0)) + 48|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = $8 & 2;
   $10 = ($9|0)==(0);
   if ($10) {
    (_SDL_SetError(175480,$vararg_buffer3)|0);
    STACKTOP = sp;return;
   }
   $11 = ((($1)) + 660|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = (_SDL_TLSGet($12)|0);
   $14 = ($13|0)==($0|0);
   if ($14) {
    $15 = HEAP32[52375]|0;
    $16 = ((($15)) + 196|0);
    $17 = HEAP32[$16>>2]|0;
    FUNCTION_TABLE_vii[$17 & 8191]($15,$0);
    STACKTOP = sp;return;
   } else {
    (_SDL_SetError(175524,$vararg_buffer5)|0);
    STACKTOP = sp;return;
   }
  }
 }
 (_SDL_SetError(195204,$vararg_buffer1)|0);
 STACKTOP = sp;return;
}
function _SDL_TLSGet($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (_SDL_SYS_GetTLSData()|0);
 $2 = ($1|0)==(0|0);
 $3 = ($0|0)==(0);
 $or$cond = $3 | $2;
 if ($or$cond) {
  $$0 = 0;
  return ($$0|0);
 }
 $4 = HEAP32[$1>>2]|0;
 $5 = ($4>>>0)<($0>>>0);
 if ($5) {
  $$0 = 0;
  return ($$0|0);
 }
 $6 = (($0) + -1)|0;
 $7 = (((($1)) + 4|0) + ($6<<3)|0);
 $8 = HEAP32[$7>>2]|0;
 $$0 = $8;
 return ($$0|0);
}
function _SDL_SYS_GetTLSData() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_SDL_Generic_GetTLSData()|0);
 return ($0|0);
}
function _SDL_Generic_GetTLSData() {
 var $$0 = 0, $$09 = 0, $$0911 = 0, $$0912 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $0 = sp;
 $1 = (_SDL_ThreadID()|0);
 HEAP32[$0>>2] = 0;
 _SDL_AtomicLock($0);
 _SDL_AtomicUnlock($0);
 $$0911 = HEAP32[52376]|0;
 $2 = ($$0911|0)==(0|0);
 if ($2) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  $$0912 = $$0911;
 }
 while(1) {
  $3 = HEAP32[$$0912>>2]|0;
  $4 = ($3|0)==($1|0);
  if ($4) {
   break;
  }
  $7 = ((($$0912)) + 8|0);
  $$09 = HEAP32[$7>>2]|0;
  $8 = ($$09|0)==(0|0);
  if ($8) {
   $$0 = 0;
   label = 5;
   break;
  } else {
   $$0912 = $$09;
  }
 }
 if ((label|0) == 5) {
  STACKTOP = sp;return ($$0|0);
 }
 $5 = ((($$0912)) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $$0 = $6;
 STACKTOP = sp;return ($$0|0);
}
function _SDL_ThreadID() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function _SDL_AtomicLock($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;HEAP32[$0>>2] = 1;
 $2 = ($1|0)==(0);
 if ($2) {
  return;
 }
 while(1) {
  _SDL_Delay(0);
  $3 = HEAP32[$0>>2]|0;HEAP32[$0>>2] = 1;
  $4 = ($3|0)==(0);
  if ($4) {
   break;
  }
 }
 return;
}
function _SDL_AtomicUnlock($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = 0;
 return;
}
function _SDL_LockMutex($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function _SDL_Delay($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp + 8|0;
 $2 = sp;
 $3 = (($0>>>0) / 1000)&-1;
 HEAP32[$1>>2] = $3;
 $4 = (($0>>>0) % 1000)&-1;
 $5 = ($4*1000000)|0;
 $6 = ((($1)) + 4|0);
 HEAP32[$6>>2] = $5;
 $7 = ((($2)) + 4|0);
 while(1) {
  $8 = (___errno_location()|0);
  HEAP32[$8>>2] = 0;
  $9 = HEAP32[$1>>2]|0;
  HEAP32[$2>>2] = $9;
  $10 = HEAP32[$6>>2]|0;
  HEAP32[$7>>2] = $10;
  $11 = (_nanosleep(($2|0),($1|0))|0);
  $12 = ($11|0)==(0);
  if ($12) {
   label = 4;
   break;
  }
  $13 = (___errno_location()|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = ($14|0)==(4);
  if (!($15)) {
   label = 4;
   break;
  }
 }
 if ((label|0) == 4) {
  STACKTOP = sp;return;
 }
}
function _SDL_malloc($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (_malloc($0)|0);
 return ($1|0);
}
function _SDL_GetRendererOutputSize($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $vararg_buffer3 = sp + 16|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $3 = ($0|0)==(0|0);
 do {
  if ($3) {
   label = 3;
  } else {
   $4 = HEAP32[$0>>2]|0;
   $5 = ($4|0)==(217376|0);
   if ($5) {
    $6 = ((($0)) + 308|0);
    $7 = HEAP32[$6>>2]|0;
    $8 = ($7|0)==(0|0);
    if ($8) {
     $17 = ((($0)) + 8|0);
     $18 = HEAP32[$17>>2]|0;
     $19 = ($18|0)==(0|0);
     if (!($19)) {
      $20 = (FUNCTION_TABLE_iiii[$18 & 8191]($0,$1,$2)|0);
      $$0 = $20;
      break;
     }
     $21 = ((($0)) + 188|0);
     $22 = HEAP32[$21>>2]|0;
     $23 = ($22|0)==(0|0);
     if ($23) {
      $24 = (_SDL_SetError(176605,$vararg_buffer3)|0);
      $$0 = $24;
      break;
     } else {
      _SDL_GetWindowSize($22,$1,$2);
      $$0 = 0;
      break;
     }
    }
    $9 = HEAP32[$7>>2]|0;
    $10 = ($9|0)==(217377|0);
    if (!($10)) {
     (_SDL_SetError(176589,$vararg_buffer1)|0);
     $$0 = -1;
     break;
    }
    $11 = ($1|0)==(0|0);
    if (!($11)) {
     $12 = ((($7)) + 12|0);
     $13 = HEAP32[$12>>2]|0;
     HEAP32[$1>>2] = $13;
    }
    $14 = ($2|0)==(0|0);
    if ($14) {
     $$0 = 0;
    } else {
     $15 = ((($7)) + 16|0);
     $16 = HEAP32[$15>>2]|0;
     HEAP32[$2>>2] = $16;
     $$0 = 0;
    }
   } else {
    label = 3;
   }
  }
 } while(0);
 if ((label|0) == 3) {
  (_SDL_SetError(176572,$vararg_buffer)|0);
  $$0 = -1;
 }
 STACKTOP = sp;return ($$0|0);
}
function _SDL_memcpy($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 _memcpy(($0|0),($1|0),($2|0))|0;
 return ($0|0);
}
function _SDL_ConvertPixels($0,$1,$2,$3,$4,$5,$6,$7) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 var $$0106 = 0, $$074 = 0, $$077$lcssa = 0, $$077105 = 0, $$080$lcssa = 0, $$080104 = 0, $$176 = 0, $$17898 = 0, $$18197 = 0, $$199 = 0, $$2102 = 0, $$279101 = 0, $$282100 = 0, $$mask$i89 = 0, $$mask83 = 0, $$not = 0, $$off = 0, $$off$i = 0, $$off$i91 = 0, $$off109 = 0;
 var $$pre$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond$i90 = 0, $or$cond85 = 0, $scevgep = 0, $scevgep112 = 0;
 var $switch$i = 0, $switch$i92 = 0, $switch$split162D = 0, $switch$split192D = 0, $switch$split222D = 0, $switch$split252D = 0, $switch$split282D = 0, $switch$split2D = 0, $switch$split312D = 0, $switch$split342D = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer4 = 0, $vararg_buffer6 = 0, $vararg_buffer8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 448|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(448|0);
 $vararg_buffer8 = sp + 32|0;
 $vararg_buffer6 = sp + 24|0;
 $vararg_buffer4 = sp + 16|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $8 = sp + 380|0;
 $9 = sp + 320|0;
 $10 = sp + 276|0;
 $11 = sp + 232|0;
 $12 = sp + 144|0;
 $13 = sp + 56|0;
 $14 = sp + 40|0;
 $15 = ($6|0)==(0|0);
 if ($15) {
  HEAP32[$vararg_buffer>>2] = 175668;
  $16 = (_SDL_SetError(194740,$vararg_buffer)|0);
  $$176 = $16;
  STACKTOP = sp;return ($$176|0);
 }
 $17 = ($7|0)==(0);
 if ($17) {
  HEAP32[$vararg_buffer1>>2] = 175672;
  $18 = (_SDL_SetError(194740,$vararg_buffer1)|0);
  $$176 = $18;
  STACKTOP = sp;return ($$176|0);
 }
 $19 = ($2|0)==($5|0);
 $$not = ($2|0)==(0);
 $$mask83 = $2 & -268435456;
 $20 = ($$mask83|0)==(268435456);
 $or$cond85 = $$not | $20;
 if (!($19)) {
  if ($or$cond85) {
   $47 = $2 >>> 24;
   $48 = $47 & 15;
   $$off$i = (($48) + -1)|0;
   $switch$i = ($$off$i>>>0)<(3);
   if ($switch$i) {
    (_SDL_SetError(175710,$vararg_buffer6)|0);
    $$176 = -1;
    STACKTOP = sp;return ($$176|0);
   }
  }
  $49 = (_SDL_InitFormat($10,$2)|0);
  $50 = ($49|0)<(0);
  if ($50) {
   $$176 = -1;
   STACKTOP = sp;return ($$176|0);
  }
  (_SDL_memset($8,0,60)|0);
  HEAP32[$8>>2] = 1;
  $51 = ((($8)) + 4|0);
  HEAP32[$51>>2] = $10;
  $52 = ((($8)) + 20|0);
  HEAP32[$52>>2] = $3;
  $53 = ((($8)) + 8|0);
  HEAP32[$53>>2] = $0;
  $54 = ((($8)) + 12|0);
  HEAP32[$54>>2] = $1;
  $55 = ((($8)) + 16|0);
  HEAP32[$55>>2] = $4;
  (_SDL_memset($12,0,88)|0);
  $56 = ((($12)) + 76|0);
  $57 = ((($8)) + 52|0);
  HEAP32[$56>>2] = -1;
  HEAP32[$57>>2] = $12;
  $58 = ((($8)) + 56|0);
  HEAP32[$58>>2] = 1;
  $59 = ($5|0)==(0);
  $$mask$i89 = $5 & -268435456;
  $60 = ($$mask$i89|0)==(268435456);
  $or$cond$i90 = $59 | $60;
  if ($or$cond$i90) {
   $61 = $5 >>> 24;
   $62 = $61 & 15;
   $$off$i91 = (($62) + -1)|0;
   $switch$i92 = ($$off$i91>>>0)<(3);
   if ($switch$i92) {
    (_SDL_SetError(175710,$vararg_buffer8)|0);
    $$176 = -1;
    STACKTOP = sp;return ($$176|0);
   }
  }
  $63 = (_SDL_InitFormat($11,$5)|0);
  $64 = ($63|0)<(0);
  if ($64) {
   $$176 = -1;
   STACKTOP = sp;return ($$176|0);
  }
  (_SDL_memset($9,0,60)|0);
  HEAP32[$9>>2] = 1;
  $65 = ((($9)) + 4|0);
  HEAP32[$65>>2] = $11;
  $66 = ((($9)) + 20|0);
  HEAP32[$66>>2] = $6;
  $67 = ((($9)) + 8|0);
  HEAP32[$67>>2] = $0;
  $68 = ((($9)) + 12|0);
  HEAP32[$68>>2] = $1;
  $69 = ((($9)) + 16|0);
  HEAP32[$69>>2] = $7;
  (_SDL_memset($13,0,88)|0);
  $70 = ((($13)) + 76|0);
  $71 = ((($9)) + 52|0);
  HEAP32[$70>>2] = -1;
  HEAP32[$71>>2] = $13;
  $72 = ((($9)) + 56|0);
  HEAP32[$72>>2] = 1;
  HEAP32[$14>>2] = 0;
  $73 = ((($14)) + 4|0);
  HEAP32[$73>>2] = 0;
  $74 = ((($14)) + 8|0);
  HEAP32[$74>>2] = $0;
  $75 = ((($14)) + 12|0);
  HEAP32[$75>>2] = $1;
  $76 = HEAP32[$57>>2]|0;
  $77 = HEAP32[$76>>2]|0;
  $78 = ($77|0)==($9|0);
  do {
   if ($78) {
    $79 = HEAP32[$65>>2]|0;
    $80 = ((($79)) + 4|0);
    $81 = HEAP32[$80>>2]|0;
    $82 = ($81|0)==(0|0);
    if (!($82)) {
     $83 = ((($76)) + 80|0);
     $84 = HEAP32[$83>>2]|0;
     $85 = ((($81)) + 8|0);
     $86 = HEAP32[$85>>2]|0;
     $87 = ($84|0)==($86|0);
     if (!($87)) {
      label = 35;
      break;
     }
    }
    $88 = HEAP32[$51>>2]|0;
    $89 = ((($88)) + 4|0);
    $90 = HEAP32[$89>>2]|0;
    $91 = ($90|0)==(0|0);
    if ($91) {
     $100 = $76;
    } else {
     $92 = ((($76)) + 84|0);
     $93 = HEAP32[$92>>2]|0;
     $94 = ((($90)) + 8|0);
     $95 = HEAP32[$94>>2]|0;
     $96 = ($93|0)==($95|0);
     if ($96) {
      $100 = $76;
     } else {
      label = 35;
     }
    }
   } else {
    label = 35;
   }
  } while(0);
  do {
   if ((label|0) == 35) {
    $97 = (_SDL_MapSurface($8,$9)|0);
    $98 = ($97|0)<(0);
    if ($98) {
     $$176 = -1;
     STACKTOP = sp;return ($$176|0);
    } else {
     $$pre$i = HEAP32[$57>>2]|0;
     $100 = $$pre$i;
     break;
    }
   }
  } while(0);
  $99 = ((($100)) + 8|0);
  $101 = HEAP32[$99>>2]|0;
  $102 = (FUNCTION_TABLE_iiiii[$101 & 8191]($8,$14,$9,$14)|0);
  $$176 = $102;
  STACKTOP = sp;return ($$176|0);
 }
 L41: do {
  if ($or$cond85) {
   $22 = $2 & 255;
   $$074 = $22;
  } else {
   $switch$split2D = ($2|0)<(844715353);
   L44: do {
    if ($switch$split2D) {
     $switch$split192D = ($2|0)<(842094158);
     if ($switch$split192D) {
      switch ($2|0) {
      case 825382478:  {
       label = 8;
       break L44;
       break;
      }
      default: {
       break L44;
      }
      }
     } else {
      switch ($2|0) {
      case 842094158: case 842094169:  {
       label = 8;
       break L44;
       break;
      }
      default: {
       break L44;
      }
      }
     }
    } else {
     $switch$split222D = ($2|0)<(1448433993);
     if ($switch$split222D) {
      $switch$split312D = ($2|0)<(1431918169);
      if ($switch$split312D) {
       switch ($2|0) {
       case 844715353:  {
        $$074 = 2;
        break L41;
        break;
       }
       default: {
        break L44;
       }
       }
      } else {
       switch ($2|0) {
       case 1431918169:  {
        $$074 = 2;
        break L41;
        break;
       }
       default: {
        break L44;
       }
       }
      }
     } else {
      $switch$split342D = ($2|0)<(1498831189);
      if ($switch$split342D) {
       switch ($2|0) {
       case 1448433993:  {
        label = 8;
        break L44;
        break;
       }
       default: {
        break L44;
       }
       }
      } else {
       switch ($2|0) {
       case 1498831189:  {
        $$074 = 2;
        break L41;
        break;
       }
       default: {
        break L44;
       }
       }
      }
     }
    }
   } while(0);
   if ((label|0) == 8) {
    $$074 = 1;
    break;
   }
   $21 = (_SDL_SetError(175682,$vararg_buffer4)|0);
   $$176 = $21;
   STACKTOP = sp;return ($$176|0);
  }
 } while(0);
 $23 = Math_imul($$074, $0)|0;
 $24 = ($1|0)==(0);
 if ($24) {
  $$077$lcssa = $6;$$080$lcssa = $3;
 } else {
  $25 = Math_imul($4, $1)|0;
  $26 = Math_imul($7, $1)|0;
  $$0106 = $1;$$077105 = $6;$$080104 = $3;
  while(1) {
   $27 = (($$0106) + -1)|0;
   (_SDL_memcpy($$077105,$$080104,$23)|0);
   $28 = (($$080104) + ($4)|0);
   $29 = (($$077105) + ($7)|0);
   $30 = ($27|0)==(0);
   if ($30) {
    break;
   } else {
    $$0106 = $27;$$077105 = $29;$$080104 = $28;
   }
  }
  $scevgep = (($3) + ($25)|0);
  $scevgep112 = (($6) + ($26)|0);
  $$077$lcssa = $scevgep112;$$080$lcssa = $scevgep;
 }
 $switch$split162D = ($2|0)<(842094169);
 if ($switch$split162D) {
  $switch$split252D = ($2|0)<(842094158);
  L72: do {
   if ($switch$split252D) {
    switch ($2|0) {
    case 825382478:  {
     break L72;
     break;
    }
    default: {
     $$176 = 0;
    }
    }
    STACKTOP = sp;return ($$176|0);
   } else {
    switch ($2|0) {
    case 842094158:  {
     break L72;
     break;
    }
    default: {
     $$176 = 0;
    }
    }
    STACKTOP = sp;return ($$176|0);
   }
  } while(0);
  $$off = (($1) + 1)|0;
  $41 = ($$off>>>0)<(3);
  if ($41) {
   $$176 = 0;
   STACKTOP = sp;return ($$176|0);
  }
  $42 = (($1|0) / 2)&-1;
  $$2102 = $42;$$279101 = $$077$lcssa;$$282100 = $$080$lcssa;
  while(1) {
   $43 = (($$2102) + -1)|0;
   (_SDL_memcpy($$279101,$$282100,$23)|0);
   $44 = (($$282100) + ($4)|0);
   $45 = (($$279101) + ($7)|0);
   $46 = ($43|0)==(0);
   if ($46) {
    $$176 = 0;
    break;
   } else {
    $$2102 = $43;$$279101 = $45;$$282100 = $44;
   }
  }
  STACKTOP = sp;return ($$176|0);
 } else {
  $switch$split282D = ($2|0)<(1448433993);
  L85: do {
   if ($switch$split282D) {
    switch ($2|0) {
    case 842094169:  {
     break L85;
     break;
    }
    default: {
     $$176 = 0;
    }
    }
    STACKTOP = sp;return ($$176|0);
   } else {
    switch ($2|0) {
    case 1448433993:  {
     break L85;
     break;
    }
    default: {
     $$176 = 0;
    }
    }
    STACKTOP = sp;return ($$176|0);
   }
  } while(0);
  $31 = (($23|0) / 2)&-1;
  $32 = (($4|0) / 2)&-1;
  $33 = (($7|0) / 2)&-1;
  $$off109 = (($1) + 1)|0;
  $34 = ($$off109>>>0)<(3);
  if ($34) {
   $$176 = 0;
   STACKTOP = sp;return ($$176|0);
  }
  $35 = (($1|0) / 2)&-1;
  $36 = $35 << 1;
  $$17898 = $$077$lcssa;$$18197 = $$080$lcssa;$$199 = $36;
  while(1) {
   $37 = (($$199) + -1)|0;
   (_SDL_memcpy($$17898,$$18197,$31)|0);
   $38 = (($$18197) + ($32)|0);
   $39 = (($$17898) + ($33)|0);
   $40 = ($37|0)==(0);
   if ($40) {
    $$176 = 0;
    break;
   } else {
    $$17898 = $39;$$18197 = $38;$$199 = $37;
   }
  }
  STACKTOP = sp;return ($$176|0);
 }
 return (0)|0;
}
function _SDL_InitFormat($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$lcssa = 0, $$046 = 0, $$084 = 0, $$180 = 0, $$2$lcssa = 0, $$275 = 0, $$371 = 0, $$4$lcssa = 0, $$466 = 0, $$562 = 0, $$6$lcssa = 0, $$658 = 0, $$757 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $2 = sp + 16|0;
 $3 = sp + 12|0;
 $4 = sp + 8|0;
 $5 = sp + 4|0;
 $6 = sp;
 $7 = (_SDL_PixelFormatEnumToMasks($1,$2,$3,$4,$5,$6)|0);
 $8 = ($7|0)==(0);
 if ($8) {
  $$046 = -1;
  STACKTOP = sp;return ($$046|0);
 }
 (_SDL_memset($0,0,44)|0);
 HEAP32[$0>>2] = $1;
 $9 = HEAP32[$2>>2]|0;
 $10 = $9&255;
 $11 = ((($0)) + 8|0);
 HEAP8[$11>>0] = $10;
 $12 = (($9) + 7)|0;
 $13 = (($12|0) / 8)&-1;
 $14 = $13&255;
 $15 = ((($0)) + 9|0);
 HEAP8[$15>>0] = $14;
 $16 = HEAP32[$3>>2]|0;
 $17 = ((($0)) + 12|0);
 HEAP32[$17>>2] = $16;
 $18 = ((($0)) + 32|0);
 HEAP8[$18>>0] = 0;
 $19 = ((($0)) + 28|0);
 HEAP8[$19>>0] = 8;
 $20 = ($16|0)==(0);
 if (!($20)) {
  $21 = $16 & 1;
  $22 = ($21|0)==(0);
  if ($22) {
   $$084 = $16;$26 = 0;
   while(1) {
    $23 = (($26) + 1)<<24>>24;
    $27 = $$084 >>> 1;
    $28 = $27 & 1;
    $29 = ($28|0)==(0);
    if ($29) {
     $$084 = $27;$26 = $23;
    } else {
     break;
    }
   }
   HEAP8[$18>>0] = $23;
   $$0$lcssa = $27;
  } else {
   $$0$lcssa = $16;
  }
  $24 = $$0$lcssa & 1;
  $25 = ($24|0)==(0);
  if (!($25)) {
   $$180 = $$0$lcssa;$31 = 8;
   while(1) {
    $30 = (($31) + -1)<<24>>24;
    $32 = $$180 >>> 1;
    $33 = $32 & 1;
    $34 = ($33|0)==(0);
    if ($34) {
     break;
    } else {
     $$180 = $32;$31 = $30;
    }
   }
   HEAP8[$19>>0] = $30;
  }
 }
 $35 = HEAP32[$4>>2]|0;
 $36 = ((($0)) + 16|0);
 HEAP32[$36>>2] = $35;
 $37 = ((($0)) + 33|0);
 HEAP8[$37>>0] = 0;
 $38 = ((($0)) + 29|0);
 HEAP8[$38>>0] = 8;
 $39 = ($35|0)==(0);
 if (!($39)) {
  $40 = $35 & 1;
  $41 = ($40|0)==(0);
  if ($41) {
   $$275 = $35;$45 = 0;
   while(1) {
    $42 = (($45) + 1)<<24>>24;
    $46 = $$275 >>> 1;
    $47 = $46 & 1;
    $48 = ($47|0)==(0);
    if ($48) {
     $$275 = $46;$45 = $42;
    } else {
     break;
    }
   }
   HEAP8[$37>>0] = $42;
   $$2$lcssa = $46;
  } else {
   $$2$lcssa = $35;
  }
  $43 = $$2$lcssa & 1;
  $44 = ($43|0)==(0);
  if (!($44)) {
   $$371 = $$2$lcssa;$50 = 8;
   while(1) {
    $49 = (($50) + -1)<<24>>24;
    $51 = $$371 >>> 1;
    $52 = $51 & 1;
    $53 = ($52|0)==(0);
    if ($53) {
     break;
    } else {
     $$371 = $51;$50 = $49;
    }
   }
   HEAP8[$38>>0] = $49;
  }
 }
 $54 = HEAP32[$5>>2]|0;
 $55 = ((($0)) + 20|0);
 HEAP32[$55>>2] = $54;
 $56 = ((($0)) + 34|0);
 HEAP8[$56>>0] = 0;
 $57 = ((($0)) + 30|0);
 HEAP8[$57>>0] = 8;
 $58 = ($54|0)==(0);
 if (!($58)) {
  $59 = $54 & 1;
  $60 = ($59|0)==(0);
  if ($60) {
   $$466 = $54;$64 = 0;
   while(1) {
    $61 = (($64) + 1)<<24>>24;
    $65 = $$466 >>> 1;
    $66 = $65 & 1;
    $67 = ($66|0)==(0);
    if ($67) {
     $$466 = $65;$64 = $61;
    } else {
     break;
    }
   }
   HEAP8[$56>>0] = $61;
   $$4$lcssa = $65;
  } else {
   $$4$lcssa = $54;
  }
  $62 = $$4$lcssa & 1;
  $63 = ($62|0)==(0);
  if (!($63)) {
   $$562 = $$4$lcssa;$69 = 8;
   while(1) {
    $68 = (($69) + -1)<<24>>24;
    $70 = $$562 >>> 1;
    $71 = $70 & 1;
    $72 = ($71|0)==(0);
    if ($72) {
     break;
    } else {
     $$562 = $70;$69 = $68;
    }
   }
   HEAP8[$57>>0] = $68;
  }
 }
 $73 = HEAP32[$6>>2]|0;
 $74 = ((($0)) + 24|0);
 HEAP32[$74>>2] = $73;
 $75 = ((($0)) + 35|0);
 HEAP8[$75>>0] = 0;
 $76 = ((($0)) + 31|0);
 HEAP8[$76>>0] = 8;
 $77 = ($73|0)==(0);
 if (!($77)) {
  $78 = $73 & 1;
  $79 = ($78|0)==(0);
  if ($79) {
   $$658 = $73;$83 = 0;
   while(1) {
    $80 = (($83) + 1)<<24>>24;
    $84 = $$658 >>> 1;
    $85 = $84 & 1;
    $86 = ($85|0)==(0);
    if ($86) {
     $$658 = $84;$83 = $80;
    } else {
     break;
    }
   }
   HEAP8[$75>>0] = $80;
   $$6$lcssa = $84;
  } else {
   $$6$lcssa = $73;
  }
  $81 = $$6$lcssa & 1;
  $82 = ($81|0)==(0);
  if (!($82)) {
   $$757 = $$6$lcssa;$88 = 8;
   while(1) {
    $87 = (($88) + -1)<<24>>24;
    $89 = $$757 >>> 1;
    $90 = $89 & 1;
    $91 = ($90|0)==(0);
    if ($91) {
     break;
    } else {
     $$757 = $89;$88 = $87;
    }
   }
   HEAP8[$76>>0] = $87;
  }
 }
 $92 = ((($0)) + 4|0);
 HEAP32[$92>>2] = 0;
 $93 = ((($0)) + 36|0);
 HEAP32[$93>>2] = 1;
 $94 = ((($0)) + 40|0);
 HEAP32[$94>>2] = 0;
 $$046 = 0;
 STACKTOP = sp;return ($$046|0);
}
function _SDL_memset($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = $1&255;
 _memset(($0|0),($3|0),($2|0))|0;
 return ($0|0);
}
function _SDL_MapSurface($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$$i = 0, $$0 = 0, $$033$i$i = 0, $$0971$i = 0, $$idx = 0, $$idx$val = 0, $$idx85 = 0, $$idx85$val = 0, $$mask = 0, $$mask72 = 0, $$mask73 = 0, $$off = 0, $$off81 = 0, $$off83 = 0, $$sink = 0, $$sink3 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0;
 var $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0;
 var $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0;
 var $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0;
 var $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0;
 var $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0;
 var $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0;
 var $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0;
 var $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $div$i = 0, $div98$i = 0, $div99$i = 0, $exitcond$i$i = 0, $or$cond = 0, $or$cond76 = 0, $or$cond77 = 0, $or$cond79 = 0, $or$cond80 = 0;
 var $switch = 0, $switch82 = 0, $switch84 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1040|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(1040|0);
 $2 = sp;
 $3 = sp + 16|0;
 $4 = ((($0)) + 52|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$0>>2]|0;
 $7 = $6 & 2;
 $8 = ($7|0)==(0);
 if (!($8)) {
  _SDL_UnRLESurface($0,1);
 }
 $9 = ($5|0)==(0|0);
 if (!($9)) {
  $10 = HEAP32[$5>>2]|0;
  $11 = ($10|0)==(0|0);
  if (!($11)) {
   $12 = ((($10)) + 56|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + -1)|0;
   HEAP32[$12>>2] = $14;
   $15 = ($13|0)<(2);
   if ($15) {
    _SDL_FreeSurface($10);
   }
  }
  HEAP32[$5>>2] = 0;
  $16 = ((($5)) + 84|0);
  HEAP32[$16>>2] = 0;
  $17 = ((($5)) + 80|0);
  HEAP32[$17>>2] = 0;
  $18 = ((($5)) + 64|0);
  $19 = HEAP32[$18>>2]|0;
  _SDL_free($19);
  HEAP32[$18>>2] = 0;
 }
 $20 = ((($5)) + 4|0);
 HEAP32[$20>>2] = 0;
 $21 = ((($0)) + 4|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ((($1)) + 4|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = HEAP32[$22>>2]|0;
 $26 = ($25|0)==(0);
 $$mask73 = $25 & -268435456;
 $27 = ($$mask73|0)==(268435456);
 $or$cond = $26 | $27;
 do {
  if ($or$cond) {
   $28 = $25 >>> 24;
   $29 = $28 & 15;
   $$off = (($29) + -1)|0;
   $switch = ($$off>>>0)<(3);
   if ($switch) {
    $30 = HEAP32[$24>>2]|0;
    $31 = ($30|0)==(0);
    $$mask72 = $30 & -268435456;
    $32 = ($$mask72|0)==(268435456);
    $or$cond76 = $31 | $32;
    if ($or$cond76) {
     $33 = $30 >>> 24;
     $34 = $33 & 15;
     $$off81 = (($34) + -1)|0;
     $switch82 = ($$off81>>>0)<(3);
     if ($switch82) {
      $35 = ((($22)) + 4|0);
      $36 = HEAP32[$35>>2]|0;
      $37 = ((($24)) + 4|0);
      $38 = HEAP32[$37>>2]|0;
      $39 = (_Map1to1($36,$38,$20)|0);
      $40 = ((($5)) + 64|0);
      HEAP32[$40>>2] = $39;
      $41 = HEAP32[$20>>2]|0;
      $42 = ($41|0)==(0);
      $43 = ($39|0)==(0|0);
      $or$cond77 = $43 & $42;
      if ($or$cond77) {
       $$0 = -1;
       STACKTOP = sp;return ($$0|0);
      }
      $44 = ((($22)) + 8|0);
      $45 = HEAP8[$44>>0]|0;
      $46 = ((($24)) + 8|0);
      $47 = HEAP8[$46>>0]|0;
      $48 = ($45<<24>>24)==($47<<24>>24);
      if ($48) {
       label = 35;
       break;
      }
      HEAP32[$20>>2] = 0;
      label = 35;
      break;
     }
    }
    $49 = HEAP32[$4>>2]|0;
    $50 = ((($49)) + 76|0);
    $51 = HEAP8[$50>>0]|0;
    $52 = ((($49)) + 77|0);
    $53 = HEAP8[$52>>0]|0;
    $54 = ((($49)) + 78|0);
    $55 = HEAP8[$54>>0]|0;
    $56 = ((($49)) + 79|0);
    $57 = HEAP8[$56>>0]|0;
    $$idx = ((($22)) + 4|0);
    $$idx$val = HEAP32[$$idx>>2]|0;
    $58 = ((($24)) + 9|0);
    $59 = HEAP8[$58>>0]|0;
    $60 = ($59<<24>>24)==(3);
    $61 = $59&255;
    $$$i = $60 ? 4 : $61;
    $62 = HEAP32[$$idx$val>>2]|0;
    $63 = Math_imul($$$i, $62)|0;
    $64 = (_SDL_malloc($63)|0);
    $65 = ($64|0)==(0|0);
    if ($65) {
     (_SDL_Error(0)|0);
     $82 = ((($5)) + 64|0);
     HEAP32[$82>>2] = 0;
     $$0 = -1;
     STACKTOP = sp;return ($$0|0);
    }
    $66 = HEAP32[$$idx$val>>2]|0;
    $67 = ($66|0)>(0);
    if (!($67)) {
     $68 = ((($5)) + 64|0);
     HEAP32[$68>>2] = $64;
     label = 35;
     break;
    }
    $69 = ((($$idx$val)) + 4|0);
    $70 = $51&255;
    $71 = $53&255;
    $72 = $55&255;
    $73 = $57&255;
    $74 = ((($24)) + 28|0);
    $75 = ((($24)) + 32|0);
    $76 = ((($24)) + 29|0);
    $77 = ((($24)) + 33|0);
    $78 = ((($24)) + 30|0);
    $79 = ((($24)) + 34|0);
    $80 = ((($24)) + 31|0);
    $81 = ((($24)) + 35|0);
    $$0971$i = 0;
    while(1) {
     $83 = HEAP32[$69>>2]|0;
     $84 = (($83) + ($$0971$i<<2)|0);
     $85 = HEAP8[$84>>0]|0;
     $86 = $85&255;
     $87 = Math_imul($86, $70)|0;
     $88 = (($87>>>0) / 255)&-1;
     $89 = (((($83) + ($$0971$i<<2)|0)) + 1|0);
     $90 = HEAP8[$89>>0]|0;
     $91 = $90&255;
     $92 = Math_imul($91, $71)|0;
     $93 = (($92>>>0) / 255)&-1;
     $94 = (((($83) + ($$0971$i<<2)|0)) + 2|0);
     $95 = HEAP8[$94>>0]|0;
     $96 = $95&255;
     $97 = Math_imul($96, $72)|0;
     $98 = (($97>>>0) / 255)&-1;
     $99 = (((($83) + ($$0971$i<<2)|0)) + 3|0);
     $100 = HEAP8[$99>>0]|0;
     $101 = $100&255;
     $102 = Math_imul($101, $73)|0;
     $103 = (($102>>>0) / 255)&-1;
     $104 = HEAP8[$58>>0]|0;
     switch ($104<<24>>24) {
     case 1:  {
      $105 = $88 & 255;
      $106 = HEAP8[$74>>0]|0;
      $107 = $106&255;
      $108 = $105 >>> $107;
      $109 = HEAP8[$75>>0]|0;
      $110 = $109&255;
      $111 = $108 << $110;
      $112 = $93 & 255;
      $113 = HEAP8[$76>>0]|0;
      $114 = $113&255;
      $115 = $112 >>> $114;
      $116 = HEAP8[$77>>0]|0;
      $117 = $116&255;
      $118 = $115 << $117;
      $119 = $118 | $111;
      $120 = $98 & 255;
      $121 = HEAP8[$78>>0]|0;
      $122 = $121&255;
      $123 = $120 >>> $122;
      $124 = HEAP8[$79>>0]|0;
      $125 = $124&255;
      $126 = $123 << $125;
      $127 = $119 | $126;
      $128 = $103 & 255;
      $129 = HEAP8[$80>>0]|0;
      $130 = $129&255;
      $131 = $128 >>> $130;
      $132 = HEAP8[$81>>0]|0;
      $133 = $132&255;
      $134 = $131 << $133;
      $135 = $127 | $134;
      $136 = $135&255;
      $137 = Math_imul($$0971$i, $$$i)|0;
      $138 = (($64) + ($137)|0);
      HEAP8[$138>>0] = $136;
      break;
     }
     case 2:  {
      $139 = $88 & 255;
      $140 = HEAP8[$74>>0]|0;
      $141 = $140&255;
      $142 = $139 >>> $141;
      $143 = HEAP8[$75>>0]|0;
      $144 = $143&255;
      $145 = $142 << $144;
      $146 = $93 & 255;
      $147 = HEAP8[$76>>0]|0;
      $148 = $147&255;
      $149 = $146 >>> $148;
      $150 = HEAP8[$77>>0]|0;
      $151 = $150&255;
      $152 = $149 << $151;
      $153 = $152 | $145;
      $154 = $98 & 255;
      $155 = HEAP8[$78>>0]|0;
      $156 = $155&255;
      $157 = $154 >>> $156;
      $158 = HEAP8[$79>>0]|0;
      $159 = $158&255;
      $160 = $157 << $159;
      $161 = $153 | $160;
      $162 = $103 & 255;
      $163 = HEAP8[$80>>0]|0;
      $164 = $163&255;
      $165 = $162 >>> $164;
      $166 = HEAP8[$81>>0]|0;
      $167 = $166&255;
      $168 = $165 << $167;
      $169 = $161 | $168;
      $170 = $169&65535;
      $171 = Math_imul($$0971$i, $$$i)|0;
      $172 = (($64) + ($171)|0);
      HEAP16[$172>>1] = $170;
      break;
     }
     case 3:  {
      $173 = $98&255;
      $174 = $93&255;
      $175 = $88&255;
      $176 = Math_imul($$0971$i, $$$i)|0;
      $177 = (($64) + ($176)|0);
      $178 = HEAP8[$75>>0]|0;
      $div$i = ($178&255) >>> 3;
      $179 = $div$i&255;
      $180 = (($177) + ($179)|0);
      HEAP8[$180>>0] = $175;
      $181 = HEAP8[$77>>0]|0;
      $div98$i = ($181&255) >>> 3;
      $182 = $div98$i&255;
      $183 = (($177) + ($182)|0);
      HEAP8[$183>>0] = $174;
      $184 = HEAP8[$79>>0]|0;
      $div99$i = ($184&255) >>> 3;
      $185 = $div99$i&255;
      $186 = (($177) + ($185)|0);
      HEAP8[$186>>0] = $173;
      break;
     }
     case 4:  {
      $187 = $88 & 255;
      $188 = HEAP8[$74>>0]|0;
      $189 = $188&255;
      $190 = $187 >>> $189;
      $191 = HEAP8[$75>>0]|0;
      $192 = $191&255;
      $193 = $190 << $192;
      $194 = $93 & 255;
      $195 = HEAP8[$76>>0]|0;
      $196 = $195&255;
      $197 = $194 >>> $196;
      $198 = HEAP8[$77>>0]|0;
      $199 = $198&255;
      $200 = $197 << $199;
      $201 = $200 | $193;
      $202 = $98 & 255;
      $203 = HEAP8[$78>>0]|0;
      $204 = $203&255;
      $205 = $202 >>> $204;
      $206 = HEAP8[$79>>0]|0;
      $207 = $206&255;
      $208 = $205 << $207;
      $209 = $201 | $208;
      $210 = $103 & 255;
      $211 = HEAP8[$80>>0]|0;
      $212 = $211&255;
      $213 = $210 >>> $212;
      $214 = HEAP8[$81>>0]|0;
      $215 = $214&255;
      $216 = $213 << $215;
      $217 = $209 | $216;
      $218 = Math_imul($$0971$i, $$$i)|0;
      $219 = (($64) + ($218)|0);
      HEAP32[$219>>2] = $217;
      break;
     }
     default: {
     }
     }
     $220 = (($$0971$i) + 1)|0;
     $221 = HEAP32[$$idx$val>>2]|0;
     $222 = ($220|0)<($221|0);
     if ($222) {
      $$0971$i = $220;
     } else {
      break;
     }
    }
    $223 = ((($5)) + 64|0);
    HEAP32[$223>>2] = $64;
    label = 36;
   } else {
    label = 27;
   }
  } else {
   label = 27;
  }
 } while(0);
 do {
  if ((label|0) == 27) {
   $224 = HEAP32[$24>>2]|0;
   $225 = ($224|0)==(0);
   $$mask = $224 & -268435456;
   $226 = ($$mask|0)==(268435456);
   $or$cond79 = $225 | $226;
   if ($or$cond79) {
    $227 = $224 >>> 24;
    $228 = $227 & 15;
    $$off83 = (($228) + -1)|0;
    $switch84 = ($$off83>>>0)<(3);
    if ($switch84) {
     $$idx85 = ((($24)) + 4|0);
     $$idx85$val = HEAP32[$$idx85>>2]|0;
     HEAP32[$2>>2] = 256;
     $$033$i$i = 0;
     while(1) {
      $229 = $$033$i$i & 224;
      $230 = $229 >>> 3;
      $231 = $229 >>> 6;
      $232 = $231 | $229;
      $233 = $232 | $230;
      $234 = $233&255;
      $235 = (($3) + ($$033$i$i<<2)|0);
      HEAP8[$235>>0] = $234;
      $236 = $$033$i$i << 3;
      $237 = $236 & 224;
      $238 = $237 >>> 3;
      $239 = $237 >>> 6;
      $240 = $239 | $237;
      $241 = $240 | $238;
      $242 = $241&255;
      $243 = (((($3) + ($$033$i$i<<2)|0)) + 1|0);
      HEAP8[$243>>0] = $242;
      $244 = $$033$i$i & 3;
      $245 = $244 << 2;
      $246 = $245 | $244;
      $247 = $246 << 4;
      $248 = $247 | $246;
      $249 = $248&255;
      $250 = (((($3) + ($$033$i$i<<2)|0)) + 2|0);
      HEAP8[$250>>0] = $249;
      $251 = (((($3) + ($$033$i$i<<2)|0)) + 3|0);
      HEAP8[$251>>0] = -1;
      $252 = (($$033$i$i) + 1)|0;
      $exitcond$i$i = ($252|0)==(256);
      if ($exitcond$i$i) {
       break;
      } else {
       $$033$i$i = $252;
      }
     }
     $253 = ((($2)) + 4|0);
     HEAP32[$253>>2] = $3;
     $254 = (_Map1to1($2,$$idx85$val,$20)|0);
     $255 = ((($5)) + 64|0);
     HEAP32[$255>>2] = $254;
     $256 = HEAP32[$20>>2]|0;
     $257 = ($256|0)==(0);
     $258 = ($254|0)==(0|0);
     $or$cond80 = $258 & $257;
     if ($or$cond80) {
      $$0 = -1;
      STACKTOP = sp;return ($$0|0);
     } else {
      HEAP32[$20>>2] = 0;
      label = 36;
      break;
     }
    }
   }
   $259 = ($22|0)==($24|0);
   if ($259) {
    HEAP32[$20>>2] = 1;
    label = 35;
   } else {
    label = 35;
   }
  }
 } while(0);
 if ((label|0) == 35) {
  HEAP32[$5>>2] = $1;
  label = 37;
 }
 else if ((label|0) == 36) {
  HEAP32[$5>>2] = $1;
  $260 = ($1|0)==(0|0);
  if (!($260)) {
   label = 37;
  }
 }
 if ((label|0) == 37) {
  $261 = ((($1)) + 56|0);
  $262 = HEAP32[$261>>2]|0;
  $263 = (($262) + 1)|0;
  HEAP32[$261>>2] = $263;
 }
 $264 = ((($24)) + 4|0);
 $265 = HEAP32[$264>>2]|0;
 $266 = ($265|0)==(0|0);
 if ($266) {
  $$sink = 0;
 } else {
  $267 = ((($265)) + 8|0);
  $268 = HEAP32[$267>>2]|0;
  $$sink = $268;
 }
 $269 = ((($5)) + 80|0);
 HEAP32[$269>>2] = $$sink;
 $270 = ((($22)) + 4|0);
 $271 = HEAP32[$270>>2]|0;
 $272 = ($271|0)==(0|0);
 if ($272) {
  $$sink3 = 0;
 } else {
  $273 = ((($271)) + 8|0);
  $274 = HEAP32[$273>>2]|0;
  $$sink3 = $274;
 }
 $275 = ((($5)) + 84|0);
 HEAP32[$275>>2] = $$sink3;
 $276 = (_SDL_CalculateBlit($0)|0);
 $$0 = $276;
 STACKTOP = sp;return ($$0|0);
}
function _SDL_UnRLESurface($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$083$i = 0, $$083$us$us$i = 0, $$089$i = 0, $$089$us$i = 0, $$095$i = 0, $$095$us$i = 0, $$184$i = 0, $$184$us$us$i = 0, $$190$i = 0, $$190$us$us$i = 0, $$285$i = 0, $$285$us$us$i = 0, $$392$i = 0, $$392$us$us$i = 0, $$4$i = 0, $$4$us$i = 0, $$5$i = 0, $$5$us$i = 0, $$6$i = 0, $$6$us$i = 0;
 var $$7$i = 0, $$7$us$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $uncopy_opaque_16$uncopy_32$i = 0, $uncopy_transl_16$uncopy_32$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = HEAP32[$0>>2]|0;
 $4 = $3 & 2;
 $5 = ($4|0)==(0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $6 = $3 & -3;
 HEAP32[$0>>2] = $6;
 $7 = ($1|0)!=(0);
 $8 = $3 & 1;
 $9 = ($8|0)==(0);
 $or$cond = $7 & $9;
 $10 = ((($0)) + 52|0);
 L4: do {
  if ($or$cond) {
   $11 = HEAP32[$10>>2]|0;
   $12 = ((($11)) + 68|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = $13 & 8192;
   $15 = ($14|0)==(0);
   if (!($15)) {
    $16 = ((($0)) + 12|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = ((($0)) + 16|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = Math_imul($19, $17)|0;
    $21 = (_SDL_malloc($20)|0);
    $22 = ((($0)) + 20|0);
    HEAP32[$22>>2] = $21;
    $23 = ($21|0)==(0|0);
    if (!($23)) {
     $26 = HEAP32[$10>>2]|0;
     $27 = ((($26)) + 72|0);
     $28 = HEAP32[$27>>2]|0;
     (_SDL_FillRect($0,0,$28)|0);
     $29 = ((($2)) + 4|0);
     HEAP32[$29>>2] = 0;
     HEAP32[$2>>2] = 0;
     $30 = ((($0)) + 8|0);
     $31 = HEAP32[$30>>2]|0;
     $32 = ((($2)) + 8|0);
     HEAP32[$32>>2] = $31;
     $33 = HEAP32[$16>>2]|0;
     $34 = ((($2)) + 12|0);
     HEAP32[$34>>2] = $33;
     (_SDL_RLEBlit($0,$2,$0,$2)|0);
     break;
    }
    $24 = HEAP32[$0>>2]|0;
    $25 = $24 | 2;
    HEAP32[$0>>2] = $25;
    STACKTOP = sp;return;
   }
   $35 = ((($0)) + 4|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = ((($11)) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = ((($0)) + 8|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = HEAP8[$38>>0]|0;
   $42 = ($41<<24>>24)==(2);
   $uncopy_opaque_16$uncopy_32$i = $42 ? 4282 : 4281;
   $uncopy_transl_16$uncopy_32$i = $42 ? 4283 : 4281;
   $43 = ((($0)) + 12|0);
   $44 = HEAP32[$43>>2]|0;
   $45 = ((($0)) + 16|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = Math_imul($46, $44)|0;
   $48 = (_SDL_malloc($47)|0);
   $49 = ((($0)) + 20|0);
   HEAP32[$49>>2] = $48;
   $50 = ($48|0)==(0|0);
   if ($50) {
    $117 = HEAP32[$0>>2]|0;
    $118 = $117 | 2;
    HEAP32[$0>>2] = $118;
    STACKTOP = sp;return;
   }
   $51 = HEAP32[$43>>2]|0;
   $52 = HEAP32[$45>>2]|0;
   $53 = Math_imul($52, $51)|0;
   (_SDL_memset($48,0,$53)|0);
   $54 = HEAP32[$49>>2]|0;
   $55 = ((($38)) + 28|0);
   if ($42) {
    $$089$us$i = $55;$$095$us$i = $54;
   } else {
    $$089$i = $55;$$095$i = $54;
    while(1) {
     $$083$i = 0;$$190$i = $$089$i;
     while(1) {
      $88 = HEAP16[$$190$i>>1]|0;
      $89 = $88&65535;
      $90 = ((($$190$i)) + 2|0);
      $91 = HEAP16[$90>>1]|0;
      $92 = $91&65535;
      $93 = ((($$190$i)) + 4|0);
      $$184$i = (($89) + ($$083$i))|0;
      $94 = ($91<<16>>16)==(0);
      if ($94) {
       $99 = ($$184$i|0)==(0);
       if ($99) {
        break L4;
       } else {
        $$285$i = $$184$i;$$392$i = $93;
       }
      } else {
       $95 = (($$095$i) + ($$184$i<<2)|0);
       $96 = (FUNCTION_TABLE_iiiiii[$uncopy_opaque_16$uncopy_32$i & 8191]($95,$93,$92,$38,$36)|0);
       $97 = (($93) + ($96)|0);
       $98 = (($$184$i) + ($92))|0;
       $$285$i = $98;$$392$i = $97;
      }
      $100 = ($$285$i|0)<($40|0);
      if ($100) {
       $$083$i = $$285$i;$$190$i = $$392$i;
      } else {
       $$4$i = 0;$$6$i = $$392$i;
       break;
      }
     }
     while(1) {
      $101 = HEAP16[$$6$i>>1]|0;
      $102 = $101&65535;
      $103 = (($102) + ($$4$i))|0;
      $104 = ((($$6$i)) + 2|0);
      $105 = HEAP16[$104>>1]|0;
      $106 = $105&65535;
      $107 = ((($$6$i)) + 4|0);
      $108 = ($105<<16>>16)==(0);
      if ($108) {
       $$5$i = $103;$$7$i = $107;
      } else {
       $109 = (($$095$i) + ($103<<2)|0);
       $110 = (($103) + ($106))|0;
       $111 = (FUNCTION_TABLE_iiiiii[$uncopy_transl_16$uncopy_32$i & 8191]($109,$107,$106,$38,$36)|0);
       $112 = (($107) + ($111)|0);
       $$5$i = $110;$$7$i = $112;
      }
      $113 = ($$5$i|0)<($40|0);
      if ($113) {
       $$4$i = $$5$i;$$6$i = $$7$i;
      } else {
       break;
      }
     }
     $114 = HEAP32[$45>>2]|0;
     $115 = $114 >> 2;
     $116 = (($$095$i) + ($115<<2)|0);
     $$089$i = $$7$i;$$095$i = $116;
    }
   }
   while(1) {
    $$083$us$us$i = 0;$$190$us$us$i = $$089$us$i;
    while(1) {
     $72 = HEAP8[$$190$us$us$i>>0]|0;
     $73 = $72&255;
     $74 = ((($$190$us$us$i)) + 1|0);
     $75 = HEAP8[$74>>0]|0;
     $76 = $75&255;
     $77 = ((($$190$us$us$i)) + 2|0);
     $$184$us$us$i = (($73) + ($$083$us$us$i))|0;
     $78 = ($75<<24>>24)==(0);
     if ($78) {
      $83 = ($$184$us$us$i|0)==(0);
      if ($83) {
       break L4;
      } else {
       $$285$us$us$i = $$184$us$us$i;$$392$us$us$i = $77;
      }
     } else {
      $79 = (($$095$us$i) + ($$184$us$us$i<<2)|0);
      $80 = (FUNCTION_TABLE_iiiiii[$uncopy_opaque_16$uncopy_32$i & 8191]($79,$77,$76,$38,$36)|0);
      $81 = (($77) + ($80)|0);
      $82 = (($$184$us$us$i) + ($76))|0;
      $$285$us$us$i = $82;$$392$us$us$i = $81;
     }
     $84 = ($$285$us$us$i|0)<($40|0);
     if ($84) {
      $$083$us$us$i = $$285$us$us$i;$$190$us$us$i = $$392$us$us$i;
     } else {
      break;
     }
    }
    $85 = $$392$us$us$i;
    $86 = $85 & 2;
    $87 = (($$392$us$us$i) + ($86)|0);
    $$4$us$i = 0;$$6$us$i = $87;
    while(1) {
     $56 = HEAP16[$$6$us$i>>1]|0;
     $57 = $56&65535;
     $58 = (($57) + ($$4$us$i))|0;
     $59 = ((($$6$us$i)) + 2|0);
     $60 = HEAP16[$59>>1]|0;
     $61 = $60&65535;
     $62 = ((($$6$us$i)) + 4|0);
     $63 = ($60<<16>>16)==(0);
     if ($63) {
      $$5$us$i = $58;$$7$us$i = $62;
     } else {
      $64 = (($$095$us$i) + ($58<<2)|0);
      $65 = (($58) + ($61))|0;
      $66 = (FUNCTION_TABLE_iiiiii[$uncopy_transl_16$uncopy_32$i & 8191]($64,$62,$61,$38,$36)|0);
      $67 = (($62) + ($66)|0);
      $$5$us$i = $65;$$7$us$i = $67;
     }
     $68 = ($$5$us$i|0)<($40|0);
     if ($68) {
      $$4$us$i = $$5$us$i;$$6$us$i = $$7$us$i;
     } else {
      break;
     }
    }
    $69 = HEAP32[$45>>2]|0;
    $70 = $69 >> 2;
    $71 = (($$095$us$i) + ($70<<2)|0);
    $$089$us$i = $$7$us$i;$$095$us$i = $71;
   }
  }
 } while(0);
 $119 = HEAP32[$10>>2]|0;
 $120 = ((($119)) + 68|0);
 $121 = HEAP32[$120>>2]|0;
 $122 = $121 & -24577;
 HEAP32[$120>>2] = $122;
 $123 = ((($119)) + 12|0);
 $124 = HEAP32[$123>>2]|0;
 _SDL_free($124);
 $125 = HEAP32[$10>>2]|0;
 $126 = ((($125)) + 12|0);
 HEAP32[$126>>2] = 0;
 STACKTOP = sp;return;
}
function _SDL_FreeSurface($0) {
 $0 = $0|0;
 var $$pre = 0, $$pre16 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ($0|0)==(0|0);
 if ($1) {
  return;
 }
 $2 = HEAP32[$0>>2]|0;
 $3 = $2 & 4;
 $4 = ($3|0)==(0);
 if (!($4)) {
  return;
 }
 $5 = ((($0)) + 56|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + -1)|0;
 HEAP32[$5>>2] = $7;
 $8 = ($6|0)>(1);
 if ($8) {
  return;
 }
 $9 = ((($0)) + 28|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)>(0);
 if ($11) {
  $13 = $10;
  while(1) {
   $12 = (($13) + -1)|0;
   HEAP32[$9>>2] = $12;
   $14 = ($13|0)==(1);
   if ($14) {
    $15 = HEAP32[$0>>2]|0;
    $16 = $15 & 2;
    $17 = ($16|0)==(0);
    if ($17) {
     $18 = $12;
    } else {
     $20 = $15 & -3;
     HEAP32[$0>>2] = $20;
     (_SDL_RLESurface($0)|0);
     $$pre = HEAP32[$9>>2]|0;
     $18 = $$pre;
    }
   } else {
    $18 = $12;
   }
   $19 = ($18|0)>(0);
   if ($19) {
    $13 = $18;
   } else {
    break;
   }
  }
  $$pre16 = HEAP32[$0>>2]|0;
  $22 = $$pre16;
 } else {
  $22 = $2;
 }
 $21 = $22 & 2;
 $23 = ($21|0)==(0);
 if (!($23)) {
  _SDL_UnRLESurface($0,0);
 }
 $24 = ((($0)) + 4|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)==(0|0);
 if (!($26)) {
  $27 = (_SDL_SetPixelFormatPalette($25,0)|0);
  $28 = ($27|0)<(0);
  if (!($28)) {
   $29 = ((($0)) + 52|0);
   $30 = HEAP32[$29>>2]|0;
   _SDL_InvalidateMap($30);
  }
  $31 = HEAP32[$24>>2]|0;
  _SDL_FreeFormat($31);
  HEAP32[$24>>2] = 0;
 }
 $32 = ((($0)) + 52|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ($33|0)==(0|0);
 if (!($34)) {
  _SDL_FreeBlitMap($33);
  HEAP32[$32>>2] = 0;
 }
 $35 = HEAP32[$0>>2]|0;
 $36 = $35 & 1;
 $37 = ($36|0)==(0);
 if ($37) {
  $38 = ((($0)) + 20|0);
  $39 = HEAP32[$38>>2]|0;
  _SDL_free($39);
 }
 _SDL_free($0);
 return;
}
function _Map1to1($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$030 = 0, $$031 = 0, $$04145$i = 0, $$04244$i = 0, $$046$i = 0, $$1$i = 0, $$143$i = 0, $$2$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = HEAP32[$0>>2]|0;
  $5 = HEAP32[$1>>2]|0;
  $6 = ($4|0)>($5|0);
  do {
   if (!($6)) {
    $7 = ($0|0)==($1|0);
    if (!($7)) {
     $8 = ((($0)) + 4|0);
     $9 = HEAP32[$8>>2]|0;
     $10 = ((($1)) + 4|0);
     $11 = HEAP32[$10>>2]|0;
     $12 = $4 << 2;
     $13 = (_SDL_memcmp($9,$11,$12)|0);
     $14 = ($13|0)==(0);
     if (!($14)) {
      break;
     }
    }
    HEAP32[$2>>2] = 1;
    $$030 = 0;
    return ($$030|0);
   }
  } while(0);
  HEAP32[$2>>2] = 0;
 }
 $15 = HEAP32[$0>>2]|0;
 $16 = (_SDL_malloc($15)|0);
 $17 = ($16|0)==(0|0);
 if ($17) {
  (_SDL_Error(0)|0);
  $$030 = 0;
  return ($$030|0);
 }
 $18 = HEAP32[$0>>2]|0;
 $19 = ($18|0)>(0);
 if (!($19)) {
  $$030 = $16;
  return ($$030|0);
 }
 $20 = ((($0)) + 4|0);
 $21 = ((($1)) + 4|0);
 $$031 = 0;
 while(1) {
  $22 = HEAP32[$20>>2]|0;
  $23 = HEAP32[$1>>2]|0;
  $24 = ($23|0)>(0);
  L20: do {
   if ($24) {
    $25 = (((($22) + ($$031<<2)|0)) + 3|0);
    $26 = HEAP8[$25>>0]|0;
    $27 = (((($22) + ($$031<<2)|0)) + 2|0);
    $28 = HEAP8[$27>>0]|0;
    $29 = (((($22) + ($$031<<2)|0)) + 1|0);
    $30 = HEAP8[$29>>0]|0;
    $31 = (($22) + ($$031<<2)|0);
    $32 = HEAP8[$31>>0]|0;
    $33 = HEAP32[$21>>2]|0;
    $34 = $32&255;
    $35 = $30&255;
    $36 = $28&255;
    $37 = $26&255;
    $$04145$i = 0;$$04244$i = -1;$$046$i = 0;
    while(1) {
     $38 = (($33) + ($$04145$i<<2)|0);
     $39 = HEAP8[$38>>0]|0;
     $40 = $39&255;
     $41 = (($40) - ($34))|0;
     $42 = (((($33) + ($$04145$i<<2)|0)) + 1|0);
     $43 = HEAP8[$42>>0]|0;
     $44 = $43&255;
     $45 = (($44) - ($35))|0;
     $46 = (((($33) + ($$04145$i<<2)|0)) + 2|0);
     $47 = HEAP8[$46>>0]|0;
     $48 = $47&255;
     $49 = (($48) - ($36))|0;
     $50 = (((($33) + ($$04145$i<<2)|0)) + 3|0);
     $51 = HEAP8[$50>>0]|0;
     $52 = $51&255;
     $53 = (($52) - ($37))|0;
     $54 = Math_imul($41, $41)|0;
     $55 = Math_imul($45, $45)|0;
     $56 = (($55) + ($54))|0;
     $57 = Math_imul($49, $49)|0;
     $58 = (($56) + ($57))|0;
     $59 = Math_imul($53, $53)|0;
     $60 = (($58) + ($59))|0;
     $61 = ($60>>>0)<($$04244$i>>>0);
     if ($61) {
      $62 = $$04145$i&255;
      $63 = ($60|0)==(0);
      if ($63) {
       $$2$i = $62;
       break L20;
      } else {
       $$1$i = $62;$$143$i = $60;
      }
     } else {
      $$1$i = $$046$i;$$143$i = $$04244$i;
     }
     $64 = (($$04145$i) + 1)|0;
     $65 = ($64|0)<($23|0);
     if ($65) {
      $$04145$i = $64;$$04244$i = $$143$i;$$046$i = $$1$i;
     } else {
      $$2$i = $$1$i;
      break;
     }
    }
   } else {
    $$2$i = 0;
   }
  } while(0);
  $66 = (($16) + ($$031)|0);
  HEAP8[$66>>0] = $$2$i;
  $67 = (($$031) + 1)|0;
  $68 = HEAP32[$0>>2]|0;
  $69 = ($67|0)<($68|0);
  if ($69) {
   $$031 = $67;
  } else {
   $$030 = $16;
   break;
  }
 }
 return ($$030|0);
}
function _SDL_CalculateBlit($0) {
 $0 = $0|0;
 var $$0 = 0, $$0431$i = 0, $$073 = 0, $$1$ph = 0, $$mask74 = 0, $$mask76 = 0, $$mask77 = 0, $$mask78 = 0, $$not = 0, $$not87 = 0, $$off = 0, $$off93 = 0, $$off95 = 0, $$off97 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0;
 var $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0;
 var $122 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $or$cond81 = 0, $or$cond83 = 0, $or$cond89 = 0;
 var $switch = 0, $switch94 = 0, $switch96 = 0, $switch98 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = $4 & 2;
 $6 = ($5|0)==(0);
 if (!($6)) {
  _SDL_UnRLESurface($0,1);
 }
 $7 = ((($2)) + 8|0);
 HEAP32[$7>>2] = 4284;
 $8 = ((($0)) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($2)) + 56|0);
 HEAP32[$10>>2] = $9;
 $11 = ((($0)) + 16|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ((($2)) + 28|0);
 HEAP32[$13>>2] = $12;
 $14 = ((($3)) + 4|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ((($2)) + 60|0);
 HEAP32[$16>>2] = $15;
 $17 = ((($3)) + 16|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ((($2)) + 48|0);
 HEAP32[$19>>2] = $18;
 $20 = ((($2)) + 68|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = $21 & 4096;
 $23 = ($22|0)==(0);
 if (!($23)) {
  $24 = (_SDL_RLESurface($0)|0);
  $25 = ($24|0)==(0);
  if ($25) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $26 = ((($2)) + 4|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ($27|0)==(0);
 if ($28) {
  label = 7;
 } else {
  $29 = HEAP32[$20>>2]|0;
  $30 = $29 & -4097;
  $31 = ($30|0)==(0);
  if ($31) {
   $$1$ph = 4286;
  } else {
   label = 7;
  }
 }
 L10: do {
  if ((label|0) == 7) {
   $32 = HEAP32[$8>>2]|0;
   $33 = ((($32)) + 8|0);
   $34 = HEAP8[$33>>0]|0;
   $35 = ($34&255)<(8);
   if ($35) {
    $36 = HEAP32[$32>>2]|0;
    $37 = ($36|0)==(0);
    $$mask78 = $36 & -268435456;
    $38 = ($$mask78|0)==(268435456);
    $or$cond = $37 | $38;
    if ($or$cond) {
     $39 = $36 >>> 24;
     $40 = $39 & 15;
     $$off = (($40) + -1)|0;
     $switch = ($$off>>>0)<(3);
     if ($switch) {
      $41 = (_SDL_CalculateBlit0($0)|0);
      $$073 = $41;
     } else {
      label = 11;
     }
    } else {
     label = 11;
    }
   } else {
    label = 11;
   }
   do {
    if ((label|0) == 11) {
     $42 = ((($32)) + 9|0);
     $43 = HEAP8[$42>>0]|0;
     $44 = ($43<<24>>24)==(1);
     if ($44) {
      $45 = HEAP32[$32>>2]|0;
      $46 = ($45|0)==(0);
      $$mask77 = $45 & -268435456;
      $47 = ($$mask77|0)==(268435456);
      $or$cond81 = $46 | $47;
      if ($or$cond81) {
       $48 = $45 >>> 24;
       $49 = $48 & 15;
       $$off93 = (($49) + -1)|0;
       $switch94 = ($$off93>>>0)<(3);
       if ($switch94) {
        $50 = (_SDL_CalculateBlit1($0)|0);
        $$073 = $50;
        break;
       }
      }
     }
     $51 = HEAP32[$20>>2]|0;
     $52 = $51 & 16;
     $53 = ($52|0)==(0);
     if ($53) {
      $55 = (_SDL_CalculateBlitN($0)|0);
      $$073 = $55;
      break;
     } else {
      $54 = (_SDL_CalculateBlitA($0)|0);
      $$073 = $54;
      break;
     }
    }
   } while(0);
   $56 = ($$073|0)==(0|0);
   if ($56) {
    $57 = HEAP32[$8>>2]|0;
    $58 = HEAP32[$57>>2]|0;
    $59 = HEAP32[$14>>2]|0;
    $60 = HEAP32[$59>>2]|0;
    $61 = HEAP32[$20>>2]|0;
    $62 = HEAP32[19167]|0;
    $63 = ($62|0)==(-1);
    do {
     if ($63) {
      $64 = (_SDL_getenv(175746)|0);
      HEAP32[19167] = 0;
      $65 = ($64|0)==(0|0);
      if (!($65)) {
       HEAP32[$vararg_buffer>>2] = 76668;
       (_SDL_sscanf($64,204944,$vararg_buffer)|0);
       break;
      }
      $66 = (_SDL_HasMMX()|0);
      $67 = ($66|0)==(0);
      if (!($67)) {
       $68 = HEAP32[19167]|0;
       $69 = $68 | 1;
       HEAP32[19167] = $69;
      }
      $70 = (_SDL_Has3DNow()|0);
      $71 = ($70|0)==(0);
      if (!($71)) {
       $72 = HEAP32[19167]|0;
       $73 = $72 | 2;
       HEAP32[19167] = $73;
      }
      $74 = (_SDL_HasSSE()|0);
      $75 = ($74|0)==(0);
      if (!($75)) {
       $76 = HEAP32[19167]|0;
       $77 = $76 | 4;
       HEAP32[19167] = $77;
      }
      $78 = (_SDL_HasSSE2()|0);
      $79 = ($78|0)==(0);
      if (!($79)) {
       $80 = HEAP32[19167]|0;
       $81 = $80 | 8;
       HEAP32[19167] = $81;
      }
      $82 = (_SDL_HasAltiVec()|0);
      $83 = ($82|0)==(0);
      if (!($83)) {
       $84 = HEAP32[19167]|0;
       $85 = $84 | 16;
       HEAP32[19167] = $85;
      }
     }
    } while(0);
    $86 = HEAP32[(76688)>>2]|0;
    $87 = ($86|0)==(0|0);
    if (!($87)) {
     $88 = HEAP32[19167]|0;
     $89 = $61 & 883;
     $$0431$i = 0;$122 = $86;
     while(1) {
      $90 = (76672 + (($$0431$i*20)|0)|0);
      $91 = HEAP32[$90>>2]|0;
      $92 = ($91|0)==($58|0);
      if ($92) {
       $93 = (((76672 + (($$0431$i*20)|0)|0)) + 4|0);
       $94 = HEAP32[$93>>2]|0;
       $95 = ($94|0)==($60|0);
       if ($95) {
        $96 = (((76672 + (($$0431$i*20)|0)|0)) + 8|0);
        $97 = HEAP32[$96>>2]|0;
        $98 = $97 & $89;
        $99 = ($98|0)==($89|0);
        if ($99) {
         $100 = (((76672 + (($$0431$i*20)|0)|0)) + 12|0);
         $101 = HEAP32[$100>>2]|0;
         $102 = $101 & $88;
         $103 = ($102|0)==($101|0);
         if ($103) {
          $$1$ph = $122;
          break L10;
         }
        }
       }
      }
      $104 = (($$0431$i) + 1)|0;
      $105 = (((76672 + (($104*20)|0)|0)) + 16|0);
      $106 = HEAP32[$105>>2]|0;
      $107 = ($106|0)==(0|0);
      if ($107) {
       break;
      } else {
       $$0431$i = $104;$122 = $106;
      }
     }
    }
    $108 = HEAP32[$8>>2]|0;
    $109 = HEAP32[$108>>2]|0;
    $110 = HEAP32[$14>>2]|0;
    $111 = HEAP32[$110>>2]|0;
    $$not = ($109|0)==(0);
    $$mask76 = $109 & -268435456;
    $112 = ($$mask76|0)==(268435456);
    $or$cond83 = $$not | $112;
    if ($or$cond83) {
     $113 = $109 >>> 24;
     $114 = $113 & 15;
     $$off95 = (($114) + -1)|0;
     $switch96 = ($$off95>>>0)<(3);
     if (!($switch96)) {
      $$not87 = ($111|0)==(0);
      $$mask74 = $111 & -268435456;
      $115 = ($$mask74|0)==(268435456);
      $or$cond89 = $$not87 | $115;
      if ($or$cond89) {
       $116 = $111 >>> 24;
       $117 = $116 & 15;
       $$off97 = (($117) + -1)|0;
       $switch98 = ($$off97>>>0)<(3);
       if (!($switch98)) {
        $118 = ((($2)) + 12|0);
        HEAP32[$118>>2] = 4285;
        $$0 = 0;
        STACKTOP = sp;return ($$0|0);
       }
      }
     }
    }
    $120 = ((($2)) + 12|0);
    HEAP32[$120>>2] = 0;
    _SDL_InvalidateMap($2);
    $121 = (_SDL_SetError(175768,$vararg_buffer1)|0);
    $$0 = $121;
    STACKTOP = sp;return ($$0|0);
   } else {
    $$1$ph = $$073;
   }
  }
 } while(0);
 $119 = ((($2)) + 12|0);
 HEAP32[$119>>2] = $$1$ph;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _SDL_SoftBlit($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $$055 = 0, $$05558 = 0, $$056 = 0, $$lobit = 0, $$lobit$not = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = HEAP32[$2>>2]|0;
 $5 = $4 & 2;
 $6 = ($5|0)==(0);
 if ($6) {
  $$0 = 1;$$056 = 0;
 } else {
  $7 = (_SDL_LockSurface($2)|0);
  $$lobit = $7 >>> 31;
  $$lobit$not = $$lobit ^ 1;
  $$0 = $$lobit$not;$$056 = $$lobit$not;
 }
 $8 = HEAP32[$0>>2]|0;
 $9 = $8 & 2;
 $10 = ($9|0)==(0);
 if ($10) {
  $$055 = 0;
  label = 5;
 } else {
  $11 = (_SDL_LockSurface($0)|0);
  $12 = ($11|0)<(0);
  if ($12) {
   $$05558 = 0;$81 = -1;
  } else {
   $$055 = 1;
   label = 5;
  }
 }
 if ((label|0) == 5) {
  $13 = ($$0|0)==(0);
  if ($13) {
   $$05558 = $$055;$81 = -1;
  } else {
   $14 = ($1|0)==(0|0);
   if ($14) {
    $$05558 = $$055;$81 = 0;
   } else {
    $15 = ((($1)) + 8|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = ($16|0)<(1);
    if ($17) {
     $$05558 = $$055;$81 = 0;
    } else {
     $18 = ((($1)) + 12|0);
     $19 = HEAP32[$18>>2]|0;
     $20 = ($19|0)<(1);
     if ($20) {
      $$05558 = $$055;$81 = 0;
     } else {
      $21 = ((($0)) + 52|0);
      $22 = HEAP32[$21>>2]|0;
      $23 = ((($22)) + 16|0);
      $24 = ((($0)) + 20|0);
      $25 = HEAP32[$24>>2]|0;
      $26 = ((($1)) + 4|0);
      $27 = HEAP32[$26>>2]|0;
      $28 = $27 & 65535;
      $29 = ((($0)) + 16|0);
      $30 = HEAP32[$29>>2]|0;
      $31 = Math_imul($28, $30)|0;
      $32 = (($25) + ($31)|0);
      $33 = HEAP32[$1>>2]|0;
      $34 = $33 & 65535;
      $35 = ((($22)) + 56|0);
      $36 = HEAP32[$35>>2]|0;
      $37 = ((($36)) + 9|0);
      $38 = HEAP8[$37>>0]|0;
      $39 = $38&255;
      $40 = Math_imul($39, $34)|0;
      $41 = (($32) + ($40)|0);
      HEAP32[$23>>2] = $41;
      $42 = ((($22)) + 20|0);
      HEAP32[$42>>2] = $16;
      $43 = ((($22)) + 24|0);
      HEAP32[$43>>2] = $19;
      $44 = ((($22)) + 28|0);
      HEAP32[$44>>2] = $30;
      $45 = Math_imul($16, $39)|0;
      $46 = (($30) - ($45))|0;
      $47 = ((($22)) + 32|0);
      HEAP32[$47>>2] = $46;
      $48 = ((($2)) + 20|0);
      $49 = HEAP32[$48>>2]|0;
      $50 = ((($3)) + 4|0);
      $51 = HEAP32[$50>>2]|0;
      $52 = $51 & 65535;
      $53 = ((($2)) + 16|0);
      $54 = HEAP32[$53>>2]|0;
      $55 = Math_imul($52, $54)|0;
      $56 = (($49) + ($55)|0);
      $57 = HEAP32[$3>>2]|0;
      $58 = $57 & 65535;
      $59 = ((($22)) + 60|0);
      $60 = HEAP32[$59>>2]|0;
      $61 = ((($60)) + 9|0);
      $62 = HEAP8[$61>>0]|0;
      $63 = $62&255;
      $64 = Math_imul($63, $58)|0;
      $65 = (($56) + ($64)|0);
      $66 = ((($22)) + 36|0);
      HEAP32[$66>>2] = $65;
      $67 = ((($3)) + 8|0);
      $68 = HEAP32[$67>>2]|0;
      $69 = ((($22)) + 40|0);
      HEAP32[$69>>2] = $68;
      $70 = ((($3)) + 12|0);
      $71 = HEAP32[$70>>2]|0;
      $72 = ((($22)) + 44|0);
      HEAP32[$72>>2] = $71;
      $73 = ((($22)) + 48|0);
      HEAP32[$73>>2] = $54;
      $74 = Math_imul($68, $63)|0;
      $75 = (($54) - ($74))|0;
      $76 = ((($22)) + 52|0);
      HEAP32[$76>>2] = $75;
      $77 = ((($22)) + 12|0);
      $78 = HEAP32[$77>>2]|0;
      FUNCTION_TABLE_vi[$78 & 8191]($23);
      $$05558 = $$055;$81 = 0;
     }
    }
   }
  }
 }
 $79 = ($$056|0)==(0);
 if (!($79)) {
  _SDL_UnlockSurface($2);
 }
 $80 = ($$05558|0)==(0);
 if ($80) {
  return ($81|0);
 }
 _SDL_UnlockSurface($0);
 return ($81|0);
}
function _SDL_RLESurface($0) {
 $0 = $0|0;
 var $$$0184$i = 0, $$$0302$i = 0, $$$i = 0, $$$i48 = 0, $$0 = 0, $$0181217$i = 0, $$0181217$us$i = 0, $$0182$lcssa$i = 0, $$0182211$i = 0, $$0182211$us$i = 0, $$0183216$i = 0, $$0183216$us$i = 0, $$0184$i = 0, $$0185$i = 0, $$0187225$i = 0, $$0190224$i = 0, $$0191223$i = 0, $$0192$lcssa$i = 0, $$0192222$i = 0, $$0195$i = 0;
 var $$0298$lcssa$i = 0, $$0298372$i = 0, $$0299380$i = 0, $$0300$lcssa$i = 0, $$0300347$i = 0, $$0301354$i = 0, $$0302$i = 0, $$0303353$i = 0, $$0305$lcssa$i = 0, $$0305388$i = 0, $$0308387$i = 0, $$0310$i = 0, $$0312386$i = 0, $$0313$i = 0, $$0316385$i = 0, $$0322$i = 0, $$1186$lcssa$i = 0, $$1186201$i = 0, $$1188$i = 0, $$1193$i = 0;
 var $$1304379$i = 0, $$1306$i = 0, $$1314$lcssa$i = 0, $$1314337$i = 0, $$1317$i = 0, $$1323$i = 0, $$1325$i = 0, $$2$i = 0, $$2$lcssa$i = 0, $$2189$lcssa$i = 0, $$2189210$i = 0, $$2189210$us$i = 0, $$2204$i = 0, $$2315$lcssa$i = 0, $$2315340$i = 0, $$2318$lcssa$i = 0, $$2318346$i = 0, $$3$i = 0, $$4$lcssa$i = 0, $$4359$i = 0;
 var $$5$$1193$i = 0, $$5$lcssa$i = 0, $$5$lcssa$i46 = 0, $$5215$i = 0, $$5215$us$i = 0, $$5321$lcssa$i = 0, $$5321352$i = 0, $$5365$i = 0, $$7$i = 0, $$8$lcssa$i = 0, $$9$$1306$i = 0, $$9$lcssa$i = 0, $$9378$i = 0, $$lcssa$i = 0, $$lcssa$i43 = 0, $$lcssa334$i = 0, $$lcssa335$i = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre$i = 0;
 var $$pre401$i = 0, $$sink$i = 0, $$sink197$i = 0, $$sink199$i = 0, $$sink3 = 0, $$sink330$i = 0, $$sink331$i = 0, $$sink333$i = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0;
 var $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0;
 var $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0;
 var $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0;
 var $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0;
 var $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0;
 var $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0;
 var $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0;
 var $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0;
 var $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0;
 var $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0;
 var $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0;
 var $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0;
 var $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0;
 var $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0;
 var $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $SDL_RLEAlphaBlit$sink = 0, $exitcond$i = 0, $exitcond$i47 = 0, $or$cond$i = 0, $or$cond326$i = 0, $or$cond327$i = 0, $or$cond328$i = 0, $or$cond35 = 0, $or$cond39 = 0, $switch$split2D = 0, $tmp$i = 0;
 var $tmp200$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2;
 $3 = ($2|0)==(0);
 if (!($3)) {
  _SDL_UnRLESurface($0,1);
 }
 $4 = ((($0)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($5)) + 8|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = ($7&255)<(8);
 if ($8) {
  $$0 = -1;
  return ($$0|0);
 }
 $9 = ((($0)) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  $$0 = -1;
  return ($$0|0);
 }
 $12 = ((($0)) + 52|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($13)) + 68|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = $15 & 272;
 $17 = ($16|0)!=(0);
 $18 = $15 & 1;
 $19 = ($18|0)==(0);
 $or$cond39 = $17 & $19;
 if (!($or$cond39)) {
  $$0 = -1;
  return ($$0|0);
 }
 $20 = $15 & 2;
 $21 = ($20|0)==(0);
 do {
  if ($21) {
   $27 = $15 & 608;
   $28 = ($27|0)==(0);
   if ($28) {
    $$phi$trans$insert = ((($5)) + 24|0);
    $$pre = HEAP32[$$phi$trans$insert>>2]|0;
    $29 = $$pre;
    break;
   } else {
    $$0 = -1;
    return ($$0|0);
   }
  } else {
   $22 = ((($5)) + 24|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = $15 & 608;
   $25 = $24 | $23;
   $26 = ($25|0)==(0);
   if ($26) {
    $29 = $23;
   } else {
    $$0 = -1;
    return ($$0|0);
   }
  }
 } while(0);
 $30 = ($29|0)==(0);
 $31 = $15 & 16;
 $32 = ($31|0)==(0);
 $or$cond35 = $32 | $30;
 do {
  if ($or$cond35) {
   $33 = ((($13)) + 4|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = ($34|0)==(0);
   if ($35) {
    $$0 = -1;
    return ($$0|0);
   }
   $36 = ((($5)) + 9|0);
   $37 = HEAP8[$36>>0]|0;
   $38 = $37&255;
   switch ($37<<24>>24) {
   case 1:  {
    $39 = ((($0)) + 12|0);
    $40 = HEAP32[$39>>2]|0;
    $41 = ($40*3)|0;
    $42 = ((($0)) + 8|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = (($43|0) / 2)&-1;
    $45 = (($44) + 1)|0;
    $46 = Math_imul($41, $45)|0;
    $47 = (($46) + 2)|0;
    $$0195$i = $47;
    break;
   }
   case 3: case 2:  {
    $48 = ((($0)) + 12|0);
    $49 = HEAP32[$48>>2]|0;
    $50 = ((($0)) + 8|0);
    $51 = HEAP32[$50>>2]|0;
    $52 = (($51|0) / 255)&-1;
    $53 = $52 << 1;
    $54 = Math_imul($51, $38)|0;
    $55 = (($54) + 2)|0;
    $56 = (($55) + ($53))|0;
    $57 = Math_imul($56, $49)|0;
    $58 = (($57) + 2)|0;
    $$0195$i = $58;
    break;
   }
   case 4:  {
    $59 = ((($0)) + 12|0);
    $60 = HEAP32[$59>>2]|0;
    $61 = ((($0)) + 8|0);
    $62 = HEAP32[$61>>2]|0;
    $63 = (($62|0) / 65535)&-1;
    $tmp$i = (($63) + ($62))|0;
    $tmp200$i = $tmp$i << 2;
    $64 = (($tmp200$i) + 4)|0;
    $65 = Math_imul($64, $60)|0;
    $66 = (($65) + 4)|0;
    $$0195$i = $66;
    break;
   }
   default: {
    $$0195$i = 0;
   }
   }
   $67 = (_SDL_malloc($$0195$i)|0);
   $68 = ($67|0)==(0|0);
   if ($68) {
    $176 = (_SDL_Error(0)|0);
    $177 = ($176|0)<(0);
    if ($177) {
     $$0 = -1;
    } else {
     $$sink3 = 8192;$SDL_RLEAlphaBlit$sink = 4287;
     break;
    }
    return ($$0|0);
   }
   $69 = ($37<<24>>24)==(4);
   $70 = $69 ? 65535 : 255;
   $71 = HEAP32[$4>>2]|0;
   $72 = ((($71)) + 24|0);
   $73 = HEAP32[$72>>2]|0;
   $74 = $73 ^ -1;
   $75 = HEAP32[$12>>2]|0;
   $76 = ((($75)) + 72|0);
   $77 = HEAP32[$76>>2]|0;
   $78 = $77 & $74;
   $79 = (($38) + -1)|0;
   $80 = (87940 + ($79<<2)|0);
   $81 = HEAP32[$80>>2]|0;
   $82 = ((($0)) + 8|0);
   $83 = HEAP32[$82>>2]|0;
   $84 = ((($0)) + 12|0);
   $85 = HEAP32[$84>>2]|0;
   $86 = ($85|0)>(0);
   if ($86) {
    $87 = HEAP32[$9>>2]|0;
    $88 = $70&65535;
    $89 = ((($0)) + 16|0);
    $$0187225$i = $67;$$0190224$i = 0;$$0191223$i = $87;$$0192222$i = $67;
    while(1) {
     $$0184$i = 0;$$0185$i = 0;$$1188$i = $$0187225$i;$$1193$i = $$0192222$i;
     while(1) {
      $90 = ($$0185$i|0)<($83|0);
      L41: do {
       if ($90) {
        $$1186201$i = $$0185$i;
        while(1) {
         $91 = Math_imul($$1186201$i, $38)|0;
         $92 = (($$0191223$i) + ($91)|0);
         $93 = (FUNCTION_TABLE_ii[$81 & 8191]($92)|0);
         $94 = $93 & $74;
         $95 = ($94|0)==($78|0);
         if (!($95)) {
          $$1186$lcssa$i = $$1186201$i;
          break L41;
         }
         $97 = (($$1186201$i) + 1)|0;
         $98 = ($97|0)<($83|0);
         if ($98) {
          $$1186201$i = $97;
         } else {
          $$1186$lcssa$i = $97;
          break;
         }
        }
       } else {
        $$1186$lcssa$i = $$0185$i;
       }
      } while(0);
      $96 = ($$1186$lcssa$i|0)<($83|0);
      L46: do {
       if ($96) {
        $$2204$i = $$1186$lcssa$i;
        while(1) {
         $99 = Math_imul($$2204$i, $38)|0;
         $100 = (($$0191223$i) + ($99)|0);
         $101 = (FUNCTION_TABLE_ii[$81 & 8191]($100)|0);
         $102 = $101 & $74;
         $103 = ($102|0)==($78|0);
         if ($103) {
          $$2$lcssa$i = $$2204$i;$$lcssa$i = 1;
          break L46;
         }
         $104 = (($$2204$i) + 1)|0;
         $105 = ($104|0)<($83|0);
         if ($105) {
          $$2204$i = $104;
         } else {
          $$2$lcssa$i = $104;$$lcssa$i = 0;
          break;
         }
        }
       } else {
        $$2$lcssa$i = $$1186$lcssa$i;$$lcssa$i = 0;
       }
      } while(0);
      $106 = (($$1186$lcssa$i) - ($$0185$i))|0;
      $107 = ($106|0)==($83|0);
      $$$0184$i = $107 ? 1 : $$0184$i;
      $108 = (($$2$lcssa$i) - ($$1186$lcssa$i))|0;
      $109 = ($106|0)>($70|0);
      if ($109) {
       if ($69) {
        $$0182211$us$i = $106;$$2189210$us$i = $$1188$i;
        while(1) {
         HEAP16[$$2189210$us$i>>1] = $88;
         $110 = ((($$2189210$us$i)) + 2|0);
         HEAP16[$110>>1] = 0;
         $111 = ((($$2189210$us$i)) + 4|0);
         $112 = (($$0182211$us$i) - ($70))|0;
         $113 = ($112|0)>($70|0);
         if ($113) {
          $$0182211$us$i = $112;$$2189210$us$i = $111;
         } else {
          $$0182$lcssa$i = $112;$$2189$lcssa$i = $111;
          break;
         }
        }
       } else {
        $$0182211$i = $106;$$2189210$i = $$1188$i;
        while(1) {
         HEAP8[$$2189210$i>>0] = -1;
         $114 = ((($$2189210$i)) + 1|0);
         HEAP8[$114>>0] = 0;
         $115 = ((($$2189210$i)) + 2|0);
         $116 = (($$0182211$i) - ($70))|0;
         $117 = ($116|0)>($70|0);
         if ($117) {
          $$0182211$i = $116;$$2189210$i = $115;
         } else {
          $$0182$lcssa$i = $116;$$2189$lcssa$i = $115;
          break;
         }
        }
       }
      } else {
       $$0182$lcssa$i = $106;$$2189$lcssa$i = $$1188$i;
      }
      $118 = ($108|0)<($70|0);
      $119 = $118 ? $108 : $70;
      if ($69) {
       $120 = $$0182$lcssa$i&65535;
       HEAP16[$$2189$lcssa$i>>1] = $120;
       $121 = $119&65535;
       $122 = ((($$2189$lcssa$i)) + 2|0);
       HEAP16[$122>>1] = $121;
       $$sink197$i = 4;
      } else {
       $123 = $$0182$lcssa$i&255;
       HEAP8[$$2189$lcssa$i>>0] = $123;
       $124 = $119&255;
       $125 = ((($$2189$lcssa$i)) + 1|0);
       HEAP8[$125>>0] = $124;
       $$sink197$i = 2;
      }
      $126 = (($$2189$lcssa$i) + ($$sink197$i)|0);
      $127 = Math_imul($$1186$lcssa$i, $38)|0;
      $128 = (($$0191223$i) + ($127)|0);
      $129 = Math_imul($119, $38)|0;
      (_SDL_memcpy($126,$128,$129)|0);
      $130 = (($126) + ($129)|0);
      $131 = (($108) - ($119))|0;
      $132 = (($119) + ($$1186$lcssa$i))|0;
      $133 = ($131|0)==(0);
      if ($133) {
       $$5$lcssa$i = $130;
      } else {
       if ($69) {
        $$0181217$us$i = $132;$$0183216$us$i = $131;$$5215$us$i = $130;
        while(1) {
         $134 = ($$0183216$us$i|0)<($70|0);
         $135 = $134 ? $$0183216$us$i : $70;
         HEAP16[$$5215$us$i>>1] = 0;
         $136 = $135&65535;
         $137 = ((($$5215$us$i)) + 2|0);
         HEAP16[$137>>1] = $136;
         $138 = ((($$5215$us$i)) + 4|0);
         $139 = Math_imul($$0181217$us$i, $38)|0;
         $140 = (($$0191223$i) + ($139)|0);
         $141 = Math_imul($135, $38)|0;
         (_SDL_memcpy($138,$140,$141)|0);
         $142 = (($138) + ($141)|0);
         $143 = (($135) + ($$0181217$us$i))|0;
         $144 = (($$0183216$us$i) - ($135))|0;
         $145 = ($144|0)==(0);
         if ($145) {
          $$5$lcssa$i = $142;
          break;
         } else {
          $$0181217$us$i = $143;$$0183216$us$i = $144;$$5215$us$i = $142;
         }
        }
       } else {
        $$0181217$i = $132;$$0183216$i = $131;$$5215$i = $130;
        while(1) {
         $146 = ($$0183216$i|0)<($70|0);
         $147 = $146 ? $$0183216$i : $70;
         HEAP8[$$5215$i>>0] = 0;
         $148 = $147&255;
         $149 = ((($$5215$i)) + 1|0);
         HEAP8[$149>>0] = $148;
         $150 = ((($$5215$i)) + 2|0);
         $151 = Math_imul($$0181217$i, $38)|0;
         $152 = (($$0191223$i) + ($151)|0);
         $153 = Math_imul($147, $38)|0;
         (_SDL_memcpy($150,$152,$153)|0);
         $154 = (($150) + ($153)|0);
         $155 = (($147) + ($$0181217$i))|0;
         $156 = (($$0183216$i) - ($147))|0;
         $157 = ($156|0)==(0);
         if ($157) {
          $$5$lcssa$i = $154;
          break;
         } else {
          $$0181217$i = $155;$$0183216$i = $156;$$5215$i = $154;
         }
        }
       }
      }
      $158 = ($$$0184$i|0)==(0);
      $$5$$1193$i = $158 ? $$5$lcssa$i : $$1193$i;
      if ($$lcssa$i) {
       $$0184$i = $$$0184$i;$$0185$i = $$2$lcssa$i;$$1188$i = $$5$lcssa$i;$$1193$i = $$5$$1193$i;
      } else {
       break;
      }
     }
     $159 = HEAP32[$89>>2]|0;
     $160 = (($$0191223$i) + ($159)|0);
     $161 = (($$0190224$i) + 1)|0;
     $exitcond$i = ($161|0)==($85|0);
     if ($exitcond$i) {
      $$0192$lcssa$i = $$5$$1193$i;
      break;
     } else {
      $$0187225$i = $$5$lcssa$i;$$0190224$i = $161;$$0191223$i = $160;$$0192222$i = $$5$$1193$i;
     }
    }
   } else {
    $$0192$lcssa$i = $67;
   }
   if ($69) {
    HEAP16[$$0192$lcssa$i>>1] = 0;
    $162 = ((($$0192$lcssa$i)) + 2|0);
    HEAP16[$162>>1] = 0;
    $$sink199$i = 4;
   } else {
    HEAP8[$$0192$lcssa$i>>0] = 0;
    $163 = ((($$0192$lcssa$i)) + 1|0);
    HEAP8[$163>>0] = 0;
    $$sink199$i = 2;
   }
   $164 = (($$0192$lcssa$i) + ($$sink199$i)|0);
   $165 = HEAP32[$0>>2]|0;
   $166 = $165 & 1;
   $167 = ($166|0)==(0);
   if ($167) {
    $168 = HEAP32[$9>>2]|0;
    _SDL_free($168);
    HEAP32[$9>>2] = 0;
   }
   $169 = $164;
   $170 = $67;
   $171 = (($169) - ($170))|0;
   $172 = (_SDL_realloc($67,$171)|0);
   $173 = ($172|0)==(0|0);
   $$$i = $173 ? $67 : $172;
   $174 = HEAP32[$12>>2]|0;
   $175 = ((($174)) + 12|0);
   HEAP32[$175>>2] = $$$i;
   $$sink3 = 8192;$SDL_RLEAlphaBlit$sink = 4287;
  } else {
   $178 = HEAP32[$13>>2]|0;
   $179 = ($178|0)==(0|0);
   if ($179) {
    $$0 = -1;
    return ($$0|0);
   }
   $180 = ((($178)) + 4|0);
   $181 = HEAP32[$180>>2]|0;
   $182 = ($7<<24>>24)==(32);
   if (!($182)) {
    $$0 = -1;
    return ($$0|0);
   }
   $183 = ((($181)) + 12|0);
   $184 = HEAP32[$183>>2]|0;
   $185 = ((($181)) + 16|0);
   $186 = HEAP32[$185>>2]|0;
   $187 = $186 | $184;
   $188 = ((($181)) + 20|0);
   $189 = HEAP32[$188>>2]|0;
   $190 = $187 | $189;
   $191 = ((($181)) + 9|0);
   $192 = HEAP8[$191>>0]|0;
   L87: do {
    switch ($192<<24>>24) {
    case 2:  {
     $switch$split2D = ($190|0)<(65535);
     if ($switch$split2D) {
      switch ($190|0) {
      case 32767:  {
       break;
      }
      default: {
       $$0 = -1;
       return ($$0|0);
      }
      }
      $196 = ($186|0)==(992);
      $197 = ($184|0)==(992);
      $or$cond327$i = $197 | $196;
      $198 = ($189|0)==(992);
      $or$cond328$i = $or$cond327$i | $198;
      if ($or$cond328$i) {
       $$0322$i = 4289;
      } else {
       $$0 = -1;
       return ($$0|0);
      }
     } else {
      switch ($190|0) {
      case 65535:  {
       break;
      }
      default: {
       $$0 = -1;
       return ($$0|0);
      }
      }
      $193 = ($186|0)==(2016);
      $194 = ($184|0)==(2016);
      $or$cond$i = $194 | $193;
      $195 = ($189|0)==(2016);
      $or$cond326$i = $or$cond$i | $195;
      if ($or$cond326$i) {
       $$0322$i = 4288;
      } else {
       $$0 = -1;
       return ($$0|0);
      }
     }
     $199 = ((($0)) + 12|0);
     $200 = HEAP32[$199>>2]|0;
     $201 = ((($0)) + 8|0);
     $202 = HEAP32[$201>>2]|0;
     $203 = ($202*6)|0;
     $204 = (($203) + 8)|0;
     $205 = Math_imul($204, $200)|0;
     $206 = (($205) + 2)|0;
     $$0310$i = $206;$$1323$i = $$0322$i;$$1325$i = 4290;
     break;
    }
    case 4:  {
     $207 = ($190|0)==(16777215);
     if ($207) {
      $208 = ((($0)) + 12|0);
      $209 = HEAP32[$208>>2]|0;
      $210 = $209 << 3;
      $211 = ((($0)) + 8|0);
      $212 = HEAP32[$211>>2]|0;
      $213 = (($212) + 1)|0;
      $214 = Math_imul($210, $213)|0;
      $215 = $214 | 4;
      $$0310$i = $215;$$1323$i = 4291;$$1325$i = 4291;
      break L87;
     } else {
      $$0 = -1;
      return ($$0|0);
     }
     break;
    }
    default: {
     $$0 = -1;
     return ($$0|0);
    }
    }
   } while(0);
   $216 = (($$0310$i) + 28)|0;
   $217 = (_SDL_malloc($216)|0);
   $218 = ($217|0)==(0|0);
   if ($218) {
    $411 = (_SDL_Error(0)|0);
    $412 = ($411|0)<(0);
    if ($412) {
     $$0 = -1;
    } else {
     $$sink3 = 16384;$SDL_RLEAlphaBlit$sink = 4292;
     break;
    }
    return ($$0|0);
   }
   $219 = HEAP8[$191>>0]|0;
   HEAP8[$217>>0] = $219;
   $220 = HEAP32[$183>>2]|0;
   $221 = ((($217)) + 4|0);
   HEAP32[$221>>2] = $220;
   $222 = HEAP32[$185>>2]|0;
   $223 = ((($217)) + 8|0);
   HEAP32[$223>>2] = $222;
   $224 = HEAP32[$188>>2]|0;
   $225 = ((($217)) + 12|0);
   HEAP32[$225>>2] = $224;
   $226 = ((($181)) + 24|0);
   $227 = HEAP32[$226>>2]|0;
   $228 = ((($217)) + 16|0);
   HEAP32[$228>>2] = $227;
   $229 = ((($181)) + 28|0);
   $230 = HEAP8[$229>>0]|0;
   $231 = ((($217)) + 20|0);
   HEAP8[$231>>0] = $230;
   $232 = ((($181)) + 29|0);
   $233 = HEAP8[$232>>0]|0;
   $234 = ((($217)) + 21|0);
   HEAP8[$234>>0] = $233;
   $235 = ((($181)) + 30|0);
   $236 = HEAP8[$235>>0]|0;
   $237 = ((($217)) + 22|0);
   HEAP8[$237>>0] = $236;
   $238 = ((($181)) + 31|0);
   $239 = HEAP8[$238>>0]|0;
   $240 = ((($217)) + 23|0);
   HEAP8[$240>>0] = $239;
   $241 = ((($181)) + 32|0);
   $242 = HEAP8[$241>>0]|0;
   $243 = ((($217)) + 24|0);
   HEAP8[$243>>0] = $242;
   $244 = ((($181)) + 33|0);
   $245 = HEAP8[$244>>0]|0;
   $246 = ((($217)) + 25|0);
   HEAP8[$246>>0] = $245;
   $247 = ((($181)) + 34|0);
   $248 = HEAP8[$247>>0]|0;
   $249 = ((($217)) + 26|0);
   HEAP8[$249>>0] = $248;
   $250 = ((($181)) + 35|0);
   $251 = HEAP8[$250>>0]|0;
   $252 = ((($217)) + 27|0);
   HEAP8[$252>>0] = $251;
   $253 = ((($217)) + 28|0);
   $254 = ((($0)) + 12|0);
   $255 = HEAP32[$254>>2]|0;
   $256 = ((($0)) + 8|0);
   $257 = HEAP32[$256>>2]|0;
   $258 = HEAP32[$4>>2]|0;
   $259 = ($255|0)>(0);
   if ($259) {
    $260 = HEAP32[$9>>2]|0;
    $261 = ((($258)) + 24|0);
    $262 = ((($258)) + 35|0);
    $263 = ((($0)) + 16|0);
    $$0305388$i = $253;$$0308387$i = $260;$$0312386$i = 0;$$0316385$i = $253;
    while(1) {
     $$0302$i = 0;$$0313$i = 0;$$1317$i = $$0316385$i;
     while(1) {
      $264 = ($$0313$i|0)<($257|0);
      L117: do {
       if ($264) {
        $265 = HEAP32[$261>>2]|0;
        $266 = HEAP8[$262>>0]|0;
        $267 = $266&255;
        $$1314337$i = $$0313$i;
        while(1) {
         $268 = (($$0308387$i) + ($$1314337$i<<2)|0);
         $269 = HEAP32[$268>>2]|0;
         $270 = $269 & $265;
         $271 = $270 >>> $267;
         $272 = ($271|0)==(255);
         if ($272) {
          $$1314$lcssa$i = $$1314337$i;
          break L117;
         }
         $277 = (($$1314337$i) + 1)|0;
         $278 = ($277|0)<($257|0);
         if ($278) {
          $$1314337$i = $277;
         } else {
          $$1314$lcssa$i = $277;
          break;
         }
        }
       } else {
        $$1314$lcssa$i = $$0313$i;
       }
      } while(0);
      $273 = ($$1314$lcssa$i|0)<($257|0);
      L123: do {
       if ($273) {
        $274 = HEAP32[$261>>2]|0;
        $275 = HEAP8[$262>>0]|0;
        $276 = $275&255;
        $$2315340$i = $$1314$lcssa$i;
        while(1) {
         $279 = (($$0308387$i) + ($$2315340$i<<2)|0);
         $280 = HEAP32[$279>>2]|0;
         $281 = $280 & $274;
         $282 = $281 >>> $276;
         $283 = ($282|0)==(255);
         if (!($283)) {
          $$2315$lcssa$i = $$2315340$i;$$lcssa$i43 = 1;
          break L123;
         }
         $284 = (($$2315340$i) + 1)|0;
         $285 = ($284|0)<($257|0);
         if ($285) {
          $$2315340$i = $284;
         } else {
          $$2315$lcssa$i = $284;$$lcssa$i43 = 0;
          break;
         }
        }
       } else {
        $$2315$lcssa$i = $$1314$lcssa$i;$$lcssa$i43 = 0;
       }
      } while(0);
      $286 = (($$1314$lcssa$i) - ($$0313$i))|0;
      $287 = ($286|0)==($257|0);
      $$$0302$i = $287 ? 1 : $$0302$i;
      $288 = (($$2315$lcssa$i) - ($$1314$lcssa$i))|0;
      $289 = ($286|0)>(255);
      $290 = HEAP8[$191>>0]|0;
      $291 = ($290<<24>>24)==(4);
      if ($289) {
       $$0300347$i = $286;$$2318346$i = $$1317$i;$420 = $290;$421 = $291;
       while(1) {
        if ($421) {
         HEAP16[$$2318346$i>>1] = 255;
         $292 = ((($$2318346$i)) + 2|0);
         HEAP16[$292>>1] = 0;
         $$sink$i = 4;$297 = $420;
        } else {
         HEAP8[$$2318346$i>>0] = -1;
         $293 = ((($$2318346$i)) + 1|0);
         HEAP8[$293>>0] = 0;
         $$pre$i = HEAP8[$191>>0]|0;
         $$sink$i = 2;$297 = $$pre$i;
        }
        $294 = (($$2318346$i) + ($$sink$i)|0);
        $295 = (($$0300347$i) + -255)|0;
        $296 = ($295|0)>(255);
        $298 = ($297<<24>>24)==(4);
        if ($296) {
         $$0300347$i = $295;$$2318346$i = $294;$420 = $297;$421 = $298;
        } else {
         $$0300$lcssa$i = $295;$$2318$lcssa$i = $294;$$lcssa334$i = $298;
         break;
        }
       }
      } else {
       $$0300$lcssa$i = $286;$$2318$lcssa$i = $$1317$i;$$lcssa334$i = $291;
      }
      $299 = ($288|0)<(255);
      $300 = $299 ? $288 : 255;
      if ($$lcssa334$i) {
       $301 = $$0300$lcssa$i&65535;
       HEAP16[$$2318$lcssa$i>>1] = $301;
       $302 = $300&65535;
       $303 = ((($$2318$lcssa$i)) + 2|0);
       HEAP16[$303>>1] = $302;
       $$sink330$i = 4;
      } else {
       $304 = $$0300$lcssa$i&255;
       HEAP8[$$2318$lcssa$i>>0] = $304;
       $305 = $300&255;
       $306 = ((($$2318$lcssa$i)) + 1|0);
       HEAP8[$306>>0] = $305;
       $$sink330$i = 2;
      }
      $307 = (($$2318$lcssa$i) + ($$sink330$i)|0);
      $308 = (($$0308387$i) + ($$1314$lcssa$i<<2)|0);
      $309 = (FUNCTION_TABLE_iiiiii[$$1325$i & 8191]($307,$308,$300,$258,$181)|0);
      $310 = (($307) + ($309)|0);
      $311 = (($288) - ($300))|0;
      $312 = ($311|0)==(0);
      if ($312) {
       $$5321$lcssa$i = $310;
      } else {
       $313 = (($300) + ($$1314$lcssa$i))|0;
       $$0301354$i = $311;$$0303353$i = $313;$$5321352$i = $310;
       while(1) {
        $314 = ($$0301354$i|0)<(255);
        $315 = $314 ? $$0301354$i : 255;
        $316 = HEAP8[$191>>0]|0;
        $317 = ($316<<24>>24)==(4);
        if ($317) {
         HEAP16[$$5321352$i>>1] = 0;
         $318 = $315&65535;
         $319 = ((($$5321352$i)) + 2|0);
         HEAP16[$319>>1] = $318;
         $$sink331$i = 4;
        } else {
         HEAP8[$$5321352$i>>0] = 0;
         $320 = $315&255;
         $321 = ((($$5321352$i)) + 1|0);
         HEAP8[$321>>0] = $320;
         $$sink331$i = 2;
        }
        $322 = (($$5321352$i) + ($$sink331$i)|0);
        $323 = (($$0308387$i) + ($$0303353$i<<2)|0);
        $324 = (FUNCTION_TABLE_iiiiii[$$1325$i & 8191]($322,$323,$315,$258,$181)|0);
        $325 = (($322) + ($324)|0);
        $326 = (($315) + ($$0303353$i))|0;
        $327 = (($$0301354$i) - ($315))|0;
        $328 = ($327|0)==(0);
        if ($328) {
         $$5321$lcssa$i = $325;
         break;
        } else {
         $$0301354$i = $327;$$0303353$i = $326;$$5321352$i = $325;
        }
       }
      }
      if ($$lcssa$i43) {
       $$0302$i = $$$0302$i;$$0313$i = $$2315$lcssa$i;$$1317$i = $$5321$lcssa$i;
      } else {
       break;
      }
     }
     $329 = $$5321$lcssa$i;
     $330 = $329 & 2;
     $331 = (($$5321$lcssa$i) + ($330)|0);
     $$1306$i = $$0305388$i;$$2$i = $$$0302$i;$$3$i = 0;$$7$i = $331;
     while(1) {
      $332 = ($$3$i|0)<($257|0);
      L153: do {
       if ($332) {
        $333 = HEAP32[$261>>2]|0;
        $334 = HEAP8[$262>>0]|0;
        $335 = $334&255;
        $$4359$i = $$3$i;
        while(1) {
         $336 = (($$0308387$i) + ($$4359$i<<2)|0);
         $337 = HEAP32[$336>>2]|0;
         $338 = $337 & $333;
         $339 = $338 >>> $335;
         $340 = (($339) + -1)|0;
         $341 = ($340>>>0)>(253);
         if (!($341)) {
          $$4$lcssa$i = $$4359$i;
          break L153;
         }
         $346 = (($$4359$i) + 1)|0;
         $347 = ($346|0)<($257|0);
         if ($347) {
          $$4359$i = $346;
         } else {
          $$4$lcssa$i = $346;
          break;
         }
        }
       } else {
        $$4$lcssa$i = $$3$i;
       }
      } while(0);
      $342 = ($$4$lcssa$i|0)<($257|0);
      L159: do {
       if ($342) {
        $343 = HEAP32[$261>>2]|0;
        $344 = HEAP8[$262>>0]|0;
        $345 = $344&255;
        $$5365$i = $$4$lcssa$i;
        while(1) {
         $348 = (($$0308387$i) + ($$5365$i<<2)|0);
         $349 = HEAP32[$348>>2]|0;
         $350 = $349 & $343;
         $351 = $350 >>> $345;
         $352 = (($351) + -1)|0;
         $353 = ($352>>>0)<(254);
         if (!($353)) {
          $$5$lcssa$i46 = $$5365$i;$$lcssa335$i = 1;
          break L159;
         }
         $354 = (($$5365$i) + 1)|0;
         $355 = ($354|0)<($257|0);
         if ($355) {
          $$5365$i = $354;
         } else {
          $$5$lcssa$i46 = $354;$$lcssa335$i = 0;
          break;
         }
        }
       } else {
        $$5$lcssa$i46 = $$4$lcssa$i;$$lcssa335$i = 0;
       }
      } while(0);
      $356 = (($$4$lcssa$i) - ($$3$i))|0;
      $357 = ($356|0)==($257|0);
      $358 = $357&1;
      $359 = $358 & $$2$i;
      $360 = (($$5$lcssa$i46) - ($$4$lcssa$i))|0;
      $361 = ($356|0)>(65535);
      if ($361) {
       $$0298372$i = $356;$362 = $$7$i;
       while(1) {
        HEAP16[$362>>1] = -1;
        $363 = ((($362)) + 2|0);
        HEAP16[$363>>1] = 0;
        $364 = ((($362)) + 4|0);
        $365 = (($$0298372$i) + -65535)|0;
        $366 = ($365|0)>(65535);
        if ($366) {
         $$0298372$i = $365;$362 = $364;
        } else {
         $$0298$lcssa$i = $365;$$8$lcssa$i = $364;
         break;
        }
       }
      } else {
       $$0298$lcssa$i = $356;$$8$lcssa$i = $$7$i;
      }
      $367 = ($360|0)<(65535);
      $368 = $367 ? $360 : 65535;
      $369 = $$0298$lcssa$i&65535;
      HEAP16[$$8$lcssa$i>>1] = $369;
      $370 = $368&65535;
      $371 = ((($$8$lcssa$i)) + 2|0);
      HEAP16[$371>>1] = $370;
      $372 = ((($$8$lcssa$i)) + 4|0);
      $373 = (($$0308387$i) + ($$4$lcssa$i<<2)|0);
      $374 = (FUNCTION_TABLE_iiiiii[$$1323$i & 8191]($372,$373,$368,$258,$181)|0);
      $375 = (($372) + ($374)|0);
      $376 = (($360) - ($368))|0;
      $377 = ($376|0)==(0);
      if ($377) {
       $$9$lcssa$i = $375;
      } else {
       $378 = (($368) + ($$4$lcssa$i))|0;
       $$0299380$i = $376;$$1304379$i = $378;$$9378$i = $375;
       while(1) {
        $379 = ($$0299380$i|0)<(65535);
        $380 = $379 ? $$0299380$i : 65535;
        HEAP16[$$9378$i>>1] = 0;
        $381 = $380&65535;
        $382 = ((($$9378$i)) + 2|0);
        HEAP16[$382>>1] = $381;
        $383 = ((($$9378$i)) + 4|0);
        $384 = (($$0308387$i) + ($$1304379$i<<2)|0);
        $385 = (FUNCTION_TABLE_iiiiii[$$1323$i & 8191]($383,$384,$380,$258,$181)|0);
        $386 = (($383) + ($385)|0);
        $387 = (($380) + ($$1304379$i))|0;
        $388 = (($$0299380$i) - ($380))|0;
        $389 = ($388|0)==(0);
        if ($389) {
         $$9$lcssa$i = $386;
         break;
        } else {
         $$0299380$i = $388;$$1304379$i = $387;$$9378$i = $386;
        }
       }
      }
      $390 = ($359|0)==(0);
      $$9$$1306$i = $390 ? $$9$lcssa$i : $$1306$i;
      if ($$lcssa335$i) {
       $$1306$i = $$9$$1306$i;$$2$i = $359;$$3$i = $$5$lcssa$i46;$$7$i = $$9$lcssa$i;
      } else {
       break;
      }
     }
     $391 = HEAP32[$263>>2]|0;
     $392 = $391 >> 2;
     $393 = (($$0308387$i) + ($392<<2)|0);
     $394 = (($$0312386$i) + 1)|0;
     $exitcond$i47 = ($394|0)==($255|0);
     if ($exitcond$i47) {
      break;
     } else {
      $$0305388$i = $$9$$1306$i;$$0308387$i = $393;$$0312386$i = $394;$$0316385$i = $$9$lcssa$i;
     }
    }
    $$pre401$i = HEAP8[$191>>0]|0;
    $$0305$lcssa$i = $$9$$1306$i;$395 = $$pre401$i;
   } else {
    $$0305$lcssa$i = $253;$395 = $219;
   }
   $396 = ($395<<24>>24)==(4);
   if ($396) {
    HEAP16[$$0305$lcssa$i>>1] = 0;
    $397 = ((($$0305$lcssa$i)) + 2|0);
    HEAP16[$397>>1] = 0;
    $$sink333$i = 4;
   } else {
    HEAP8[$$0305$lcssa$i>>0] = 0;
    $398 = ((($$0305$lcssa$i)) + 1|0);
    HEAP8[$398>>0] = 0;
    $$sink333$i = 2;
   }
   $399 = (($$0305$lcssa$i) + ($$sink333$i)|0);
   $400 = HEAP32[$0>>2]|0;
   $401 = $400 & 1;
   $402 = ($401|0)==(0);
   if ($402) {
    $403 = HEAP32[$9>>2]|0;
    _SDL_free($403);
    HEAP32[$9>>2] = 0;
   }
   $404 = $399;
   $405 = $217;
   $406 = (($404) - ($405))|0;
   $407 = (_SDL_realloc($217,$406)|0);
   $408 = ($407|0)==(0|0);
   $$$i48 = $408 ? $217 : $407;
   $409 = HEAP32[$12>>2]|0;
   $410 = ((($409)) + 12|0);
   HEAP32[$410>>2] = $$$i48;
   $$sink3 = 16384;$SDL_RLEAlphaBlit$sink = 4292;
  }
 } while(0);
 $413 = HEAP32[$12>>2]|0;
 $414 = ((($413)) + 8|0);
 HEAP32[$414>>2] = $SDL_RLEAlphaBlit$sink;
 $415 = ((($413)) + 68|0);
 $416 = HEAP32[$415>>2]|0;
 $417 = $416 | $$sink3;
 HEAP32[$415>>2] = $417;
 $418 = HEAP32[$0>>2]|0;
 $419 = $418 | 2;
 HEAP32[$0>>2] = $419;
 $$0 = 0;
 return ($$0|0);
}
function _SDL_CalculateBlit0($0) {
 $0 = $0|0;
 var $$0 = 0, $$09 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 8|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)==(1);
 if (!($5)) {
  $$09 = 0;
  return ($$09|0);
 }
 $6 = ((($0)) + 52|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($8)) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ((($10)) + 8|0);
 $12 = HEAP8[$11>>0]|0;
 $13 = ($12&255)<(8);
 if ($13) {
  $$0 = 0;
 } else {
  $14 = ((($10)) + 9|0);
  $15 = HEAP8[$14>>0]|0;
  $16 = $15&255;
  $$0 = $16;
 }
 $17 = ((($7)) + 68|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = $18 & -28673;
 switch ($19|0) {
 case 0:  {
  $20 = (87900 + ($$0<<2)|0);
  $21 = HEAP32[$20>>2]|0;
  $$09 = $21;
  return ($$09|0);
  break;
 }
 case 256:  {
  $22 = (87920 + ($$0<<2)|0);
  $23 = HEAP32[$22>>2]|0;
  $$09 = $23;
  return ($$09|0);
  break;
 }
 case 18:  {
  $24 = ($$0>>>0)>(1);
  $25 = $24 ? 4293 : 0;
  $$09 = $25;
  return ($$09|0);
  break;
 }
 case 274:  {
  $26 = ($$0>>>0)>(1);
  $27 = $26 ? 4294 : 0;
  $$09 = $27;
  return ($$09|0);
  break;
 }
 default: {
  $$09 = 0;
  return ($$09|0);
 }
 }
 return (0)|0;
}
function _SDL_CalculateBlit1($0) {
 $0 = $0|0;
 var $$0 = 0, $$011 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($5)) + 8|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = ($7&255)<(8);
 if ($8) {
  $$011 = 0;
 } else {
  $9 = ((($5)) + 9|0);
  $10 = HEAP8[$9>>0]|0;
  $11 = $10&255;
  $$011 = $11;
 }
 $12 = ((($2)) + 68|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13 & -28673;
 switch ($14|0) {
 case 0:  {
  $15 = (87860 + ($$011<<2)|0);
  $16 = HEAP32[$15>>2]|0;
  $$0 = $16;
  return ($$0|0);
  break;
 }
 case 256:  {
  $17 = (87880 + ($$011<<2)|0);
  $18 = HEAP32[$17>>2]|0;
  $$0 = $18;
  return ($$0|0);
  break;
 }
 case 18:  {
  $19 = ($$011>>>0)>(1);
  $20 = $19 ? 4295 : 0;
  $$0 = $20;
  return ($$0|0);
  break;
 }
 case 274:  {
  $21 = ($$011>>>0)>(1);
  $22 = $21 ? 4296 : 0;
  $$0 = $22;
  return ($$0|0);
  break;
 }
 default: {
  $$0 = 0;
  return ($$0|0);
 }
 }
 return (0)|0;
}
function _SDL_CalculateBlitA($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $BlitNto1SurfaceAlphaKey$BlitNtoNSurfaceAlphaKey = 0, $switch$select = 0, $switch$select43 = 0, $switch$select45 = 0, $switch$select47 = 0, $switch$selectcmp = 0;
 var $switch$selectcmp42 = 0, $switch$selectcmp44 = 0, $switch$selectcmp46 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 52|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($5)) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($4)) + 68|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $9 & -28673;
 switch ($10|0) {
 case 16:  {
  $11 = ((($7)) + 9|0);
  $12 = HEAP8[$11>>0]|0;
  switch ($12<<24>>24) {
  case 2:  {
   $13 = ((($2)) + 9|0);
   $14 = HEAP8[$13>>0]|0;
   $15 = ($14<<24>>24)==(4);
   if (!($15)) {
    $$0 = 4297;
    return ($$0|0);
   }
   $16 = ((($2)) + 24|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = ($17|0)==(-16777216);
   if (!($18)) {
    $$0 = 4297;
    return ($$0|0);
   }
   $19 = ((($2)) + 16|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = ($20|0)==(65280);
   if (!($21)) {
    $$0 = 4297;
    return ($$0|0);
   }
   $22 = ((($2)) + 12|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = ($23|0)==(255);
   if ($24) {
    $25 = ((($7)) + 12|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = ($26|0)==(31);
    if (!($27)) {
     label = 8;
    }
   } else {
    label = 8;
   }
   if ((label|0) == 8) {
    $28 = ((($2)) + 20|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = ($29|0)==(255);
    if (!($30)) {
     $$0 = 4297;
     return ($$0|0);
    }
    $31 = ((($7)) + 20|0);
    $32 = HEAP32[$31>>2]|0;
    $33 = ($32|0)==(31);
    if (!($33)) {
     $$0 = 4297;
     return ($$0|0);
    }
   }
   $34 = ((($7)) + 16|0);
   $35 = HEAP32[$34>>2]|0;
   $switch$selectcmp = ($35|0)==(992);
   $switch$select = $switch$selectcmp ? 4298 : 4297;
   $switch$selectcmp42 = ($35|0)==(2016);
   $switch$select43 = $switch$selectcmp42 ? 4299 : $switch$select;
   $$0 = $switch$select43;
   return ($$0|0);
   break;
  }
  case 4:  {
   $36 = ((($2)) + 12|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = ((($7)) + 12|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = ($37|0)==($39|0);
   if ($40) {
    $41 = ((($2)) + 16|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = ((($7)) + 16|0);
    $44 = HEAP32[$43>>2]|0;
    $45 = ($42|0)==($44|0);
    if ($45) {
     $46 = ((($2)) + 20|0);
     $47 = HEAP32[$46>>2]|0;
     $48 = ((($7)) + 20|0);
     $49 = HEAP32[$48>>2]|0;
     $50 = ($47|0)==($49|0);
     if ($50) {
      $51 = ((($2)) + 9|0);
      $52 = HEAP8[$51>>0]|0;
      $53 = ($52<<24>>24)==(4);
      if ($53) {
       $54 = ((($2)) + 24|0);
       $55 = HEAP32[$54>>2]|0;
       $56 = ($55|0)==(-16777216);
       if ($56) {
        $$0 = 4306;
        return ($$0|0);
       }
      }
     }
    }
   }
   $$0 = 4297;
   return ($$0|0);
   break;
  }
  case 1:  {
   $$0 = 4305;
   return ($$0|0);
   break;
  }
  default: {
   $$0 = 4297;
   return ($$0|0);
  }
  }
  break;
 }
 case 18:  {
  $57 = ((($2)) + 24|0);
  $58 = HEAP32[$57>>2]|0;
  $59 = ($58|0)==(0);
  if (!($59)) {
   $$0 = 0;
   return ($$0|0);
  }
  $60 = ((($7)) + 9|0);
  $61 = HEAP8[$60>>0]|0;
  switch ($61<<24>>24) {
  case 2:  {
   $62 = ((($4)) + 4|0);
   $63 = HEAP32[$62>>2]|0;
   $64 = ($63|0)==(0);
   if ($64) {
    $$0 = 4300;
    return ($$0|0);
   }
   $65 = ((($7)) + 16|0);
   $66 = HEAP32[$65>>2]|0;
   $switch$selectcmp44 = ($66|0)==(992);
   $switch$select45 = $switch$selectcmp44 ? 4301 : 4300;
   $switch$selectcmp46 = ($66|0)==(2016);
   $switch$select47 = $switch$selectcmp46 ? 4302 : $switch$select45;
   $$0 = $switch$select47;
   return ($$0|0);
   break;
  }
  case 4:  {
   $67 = ((($2)) + 12|0);
   $68 = HEAP32[$67>>2]|0;
   $69 = ((($7)) + 12|0);
   $70 = HEAP32[$69>>2]|0;
   $71 = ($68|0)==($70|0);
   if ($71) {
    $72 = ((($2)) + 16|0);
    $73 = HEAP32[$72>>2]|0;
    $74 = ((($7)) + 16|0);
    $75 = HEAP32[$74>>2]|0;
    $76 = ($73|0)==($75|0);
    if ($76) {
     $77 = ((($2)) + 20|0);
     $78 = HEAP32[$77>>2]|0;
     $79 = ((($7)) + 20|0);
     $80 = HEAP32[$79>>2]|0;
     $81 = ($78|0)==($80|0);
     if ($81) {
      $82 = ((($2)) + 9|0);
      $83 = HEAP8[$82>>0]|0;
      $84 = ($83<<24>>24)==(4);
      if ($84) {
       $85 = $73 | $68;
       $86 = $85 | $78;
       $87 = ($86|0)==(16777215);
       if ($87) {
        $$0 = 4308;
        return ($$0|0);
       }
      }
     }
    }
   }
   $$0 = 4300;
   return ($$0|0);
   break;
  }
  case 1:  {
   $$0 = 4307;
   return ($$0|0);
   break;
  }
  default: {
   $$0 = 4300;
   return ($$0|0);
  }
  }
  break;
 }
 case 274:  {
  $88 = ((($2)) + 24|0);
  $89 = HEAP32[$88>>2]|0;
  $90 = ($89|0)==(0);
  if (!($90)) {
   $$0 = 0;
   return ($$0|0);
  }
  $91 = ((($7)) + 9|0);
  $92 = HEAP8[$91>>0]|0;
  $93 = ($92<<24>>24)==(1);
  $BlitNto1SurfaceAlphaKey$BlitNtoNSurfaceAlphaKey = $93 ? 4304 : 4303;
  $$0 = $BlitNto1SurfaceAlphaKey$BlitNtoNSurfaceAlphaKey;
  return ($$0|0);
  break;
 }
 default: {
  $$0 = 0;
  return ($$0|0);
 }
 }
 return (0)|0;
}
function _SDL_CalculateBlitN($0) {
 $0 = $0|0;
 var $$0 = 0, $$095$lcssa = 0, $$095102 = 0, $$096 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $Blit4to4CopyAlpha$BlitNtoNCopyAlpha = 0, $BlitNtoNCopyAlpha$ = 0, $or$cond = 0, $or$cond100 = 0, $or$cond101 = 0, $or$cond97 = 0;
 var $or$cond98 = 0, $or$cond99 = 0, $switch$split2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 52|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($5)) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($7)) + 8|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = ($9&255)<(8);
 if ($10) {
  $$096 = 0;
  return ($$096|0);
 }
 $11 = ((($4)) + 68|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = $12 & -28673;
 switch ($13|0) {
 case 0:  {
  $14 = ($9<<24>>24)==(8);
  $15 = ((($2)) + 9|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = $16&255;
  if ($14) {
   $18 = ($16<<24>>24)==(4);
   L8: do {
    if ($18) {
     $19 = ((($2)) + 12|0);
     $20 = HEAP32[$19>>2]|0;
     $switch$split2D = ($20|0)<(1072693248);
     if ($switch$split2D) {
      switch ($20|0) {
      case 16711680:  {
       break;
      }
      default: {
       break L8;
      }
      }
      $21 = ((($2)) + 16|0);
      $22 = HEAP32[$21>>2]|0;
      $23 = ($22|0)==(65280);
      if (!($23)) {
       break;
      }
      $24 = ((($2)) + 20|0);
      $25 = HEAP32[$24>>2]|0;
      $26 = ($25|0)==(255);
      if ($26) {
       $$096 = 4311;
      } else {
       break;
      }
      return ($$096|0);
     } else {
      switch ($20|0) {
      case 1072693248:  {
       break;
      }
      default: {
       break L8;
      }
      }
      $27 = ((($2)) + 16|0);
      $28 = HEAP32[$27>>2]|0;
      $29 = ($28|0)==(1047552);
      if (!($29)) {
       break;
      }
      $30 = ((($2)) + 20|0);
      $31 = HEAP32[$30>>2]|0;
      $32 = ($31|0)==(1023);
      if ($32) {
       $$096 = 4312;
      } else {
       break;
      }
      return ($$096|0);
     }
    }
   } while(0);
   $$096 = 4313;
   return ($$096|0);
  }
  $33 = ((($7)) + 24|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = ($34|0)==(0);
  if ($35) {
   $$0 = 1;
  } else {
   $36 = ((($2)) + 24|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = ($37|0)!=(0);
   $39 = $38 ? 4 : 2;
   $$0 = $39;
  }
  $40 = (($17) + -1)|0;
  $41 = (79252 + ($40<<2)|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = ((($42)) + 12|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = ($44|0)==(0);
  L25: do {
   if ($45) {
    $$095$lcssa = 0;
   } else {
    $46 = ((($2)) + 12|0);
    $47 = ((($2)) + 16|0);
    $48 = ((($2)) + 20|0);
    $49 = ((($7)) + 12|0);
    $50 = ((($7)) + 16|0);
    $51 = ((($7)) + 20|0);
    $52 = ((($7)) + 9|0);
    $$095102 = 0;$86 = $44;
    while(1) {
     $53 = HEAP32[$46>>2]|0;
     $54 = (($42) + (($$095102*40)|0)|0);
     $55 = HEAP32[$54>>2]|0;
     $56 = ($53|0)==($55|0);
     $57 = ($55|0)==(0);
     $or$cond = $56 | $57;
     if ($or$cond) {
      $58 = HEAP32[$47>>2]|0;
      $59 = (((($42) + (($$095102*40)|0)|0)) + 4|0);
      $60 = HEAP32[$59>>2]|0;
      $61 = ($58|0)==($60|0);
      $62 = ($60|0)==(0);
      $or$cond97 = $61 | $62;
      if ($or$cond97) {
       $63 = HEAP32[$48>>2]|0;
       $64 = (((($42) + (($$095102*40)|0)|0)) + 8|0);
       $65 = HEAP32[$64>>2]|0;
       $66 = ($63|0)==($65|0);
       $67 = ($65|0)==(0);
       $or$cond98 = $66 | $67;
       if ($or$cond98) {
        $68 = HEAP32[$49>>2]|0;
        $69 = (((($42) + (($$095102*40)|0)|0)) + 16|0);
        $70 = HEAP32[$69>>2]|0;
        $71 = ($68|0)==($70|0);
        $72 = ($70|0)==(0);
        $or$cond99 = $71 | $72;
        if ($or$cond99) {
         $73 = HEAP32[$50>>2]|0;
         $74 = (((($42) + (($$095102*40)|0)|0)) + 20|0);
         $75 = HEAP32[$74>>2]|0;
         $76 = ($73|0)==($75|0);
         $77 = ($75|0)==(0);
         $or$cond100 = $76 | $77;
         if ($or$cond100) {
          $78 = HEAP32[$51>>2]|0;
          $79 = (((($42) + (($$095102*40)|0)|0)) + 24|0);
          $80 = HEAP32[$79>>2]|0;
          $81 = ($78|0)==($80|0);
          $82 = ($80|0)==(0);
          $or$cond101 = $81 | $82;
          if ($or$cond101) {
           $83 = HEAP8[$52>>0]|0;
           $84 = $83&255;
           $85 = ($84|0)==($86|0);
           if ($85) {
            $87 = (((($42) + (($$095102*40)|0)|0)) + 36|0);
            $88 = HEAP32[$87>>2]|0;
            $89 = $88 & $$0;
            $90 = ($89|0)==($$0|0);
            if ($90) {
             $91 = (((($42) + (($$095102*40)|0)|0)) + 28|0);
             $92 = HEAP32[$91>>2]|0;
             $93 = (_SDL_HasMMX()|0);
             $94 = ($93|0)!=(0);
             $95 = $94&1;
             $96 = $95 & $92;
             $97 = HEAP32[$91>>2]|0;
             $98 = ($96|0)==($97|0);
             if ($98) {
              $$095$lcssa = $$095102;
              break L25;
             }
            }
           }
          }
         }
        }
       }
      }
     }
     $99 = (($$095102) + 1)|0;
     $100 = (((($42) + (($99*40)|0)|0)) + 12|0);
     $101 = HEAP32[$100>>2]|0;
     $102 = ($101|0)==(0);
     if ($102) {
      $$095$lcssa = $99;
      break;
     } else {
      $$095102 = $99;$86 = $101;
     }
    }
   }
  } while(0);
  $103 = (((($42) + (($$095$lcssa*40)|0)|0)) + 32|0);
  $104 = HEAP32[$103>>2]|0;
  $105 = ($104|0)==(2864|0);
  if (!($105)) {
   $$096 = $104;
   return ($$096|0);
  }
  $106 = HEAP32[$2>>2]|0;
  $107 = ($106|0)==(372711428);
  if ($107) {
   $$096 = 4314;
   return ($$096|0);
  }
  $108 = HEAP32[$7>>2]|0;
  $109 = ($108|0)==(372711428);
  if ($109) {
   $$096 = 4315;
   return ($$096|0);
  }
  $110 = HEAP8[$15>>0]|0;
  $111 = ($110<<24>>24)==(4);
  if (!($111)) {
   $135 = ($$0|0)==(4);
   $BlitNtoNCopyAlpha$ = $135 ? 4309 : 2864;
   return ($BlitNtoNCopyAlpha$|0);
  }
  $112 = ((($7)) + 9|0);
  $113 = HEAP8[$112>>0]|0;
  $114 = ($113<<24>>24)==(4);
  if (!($114)) {
   $135 = ($$0|0)==(4);
   $BlitNtoNCopyAlpha$ = $135 ? 4309 : 2864;
   return ($BlitNtoNCopyAlpha$|0);
  }
  $115 = ((($2)) + 12|0);
  $116 = HEAP32[$115>>2]|0;
  $117 = ((($7)) + 12|0);
  $118 = HEAP32[$117>>2]|0;
  $119 = ($116|0)==($118|0);
  if (!($119)) {
   $135 = ($$0|0)==(4);
   $BlitNtoNCopyAlpha$ = $135 ? 4309 : 2864;
   return ($BlitNtoNCopyAlpha$|0);
  }
  $120 = ((($2)) + 16|0);
  $121 = HEAP32[$120>>2]|0;
  $122 = ((($7)) + 16|0);
  $123 = HEAP32[$122>>2]|0;
  $124 = ($121|0)==($123|0);
  if (!($124)) {
   $135 = ($$0|0)==(4);
   $BlitNtoNCopyAlpha$ = $135 ? 4309 : 2864;
   return ($BlitNtoNCopyAlpha$|0);
  }
  $125 = ((($2)) + 20|0);
  $126 = HEAP32[$125>>2]|0;
  $127 = ((($7)) + 20|0);
  $128 = HEAP32[$127>>2]|0;
  $129 = ($126|0)==($128|0);
  if (!($129)) {
   $135 = ($$0|0)==(4);
   $BlitNtoNCopyAlpha$ = $135 ? 4309 : 2864;
   return ($BlitNtoNCopyAlpha$|0);
  }
  $130 = ($$0|0)==(4);
  if (!($130)) {
   $$096 = 4316;
   return ($$096|0);
  }
  $131 = ((($2)) + 24|0);
  $132 = HEAP32[$131>>2]|0;
  $133 = HEAP32[$33>>2]|0;
  $134 = ($132|0)==($133|0);
  $Blit4to4CopyAlpha$BlitNtoNCopyAlpha = $134 ? 4310 : 4309;
  $$096 = $Blit4to4CopyAlpha$BlitNtoNCopyAlpha;
  return ($$096|0);
  break;
 }
 case 256:  {
  $136 = ((($2)) + 9|0);
  $137 = HEAP8[$136>>0]|0;
  $138 = ($137<<24>>24)==(2);
  if ($138) {
   $139 = ((($4)) + 4|0);
   $140 = HEAP32[$139>>2]|0;
   $141 = ($140|0)==(0);
   if (!($141)) {
    $$096 = 4317;
    return ($$096|0);
   }
  }
  $142 = ((($7)) + 9|0);
  $143 = HEAP8[$142>>0]|0;
  $144 = ($143<<24>>24)==(1);
  if ($144) {
   $$096 = 4318;
   return ($$096|0);
  }
  $145 = ((($2)) + 24|0);
  $146 = HEAP32[$145>>2]|0;
  $147 = ($146|0)==(0);
  if (!($147)) {
   $148 = ((($7)) + 24|0);
   $149 = HEAP32[$148>>2]|0;
   $150 = ($149|0)==(0);
   if (!($150)) {
    $$096 = 4319;
    return ($$096|0);
   }
  }
  $$096 = 4320;
  return ($$096|0);
  break;
 }
 default: {
  $$096 = 0;
  return ($$096|0);
 }
 }
 return (0)|0;
}
function _SDL_getenv($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ($0|0)==(0|0);
 if ($1) {
  $$0 = 0;
 } else {
  $2 = (_SDL_strlen($0)|0);
  $3 = ($2|0)==(0);
  if ($3) {
   $$0 = 0;
  } else {
   $4 = (_getenv(($0|0))|0);
   $$0 = $4;
  }
 }
 return ($$0|0);
}
function _SDL_sscanf($0,$1,$varargs) {
 $0 = $0|0;
 $1 = $1|0;
 $varargs = $varargs|0;
 var $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 HEAP32[$2>>2] = $varargs;
 $3 = (_vsscanf($0,$1,$2)|0);
 STACKTOP = sp;return ($3|0);
}
function _SDL_HasMMX() {
 var $$0$$0$$0$$0$$i$i = 0, $$lobit = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $0 = sp;
 $1 = HEAP32[19812]|0;
 $2 = ($1|0)==(-1);
 if ($2) {
  HEAP32[19812] = 0;
  HEAP32[$0>>2] = 0;
  $$0$$0$$0$$0$$i$i = HEAP32[$0>>2]|0;
  $3 = ($$0$$0$$0$$0$$i$i|0)==(0);
  if ($3) {
   $5 = 0;
  } else {
   HEAP32[19812] = 2;
   $5 = 2;
  }
 } else {
  $5 = $1;
 }
 $4 = $5 >>> 2;
 $$lobit = $4 & 1;
 STACKTOP = sp;return ($$lobit|0);
}
function _SDL_Has3DNow() {
 var $$0$$0$$0$$0$$i$i = 0, $$lobit = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $0 = sp;
 $1 = HEAP32[19812]|0;
 $2 = ($1|0)==(-1);
 if ($2) {
  HEAP32[19812] = 0;
  HEAP32[$0>>2] = 0;
  $$0$$0$$0$$0$$i$i = HEAP32[$0>>2]|0;
  $3 = ($$0$$0$$0$$0$$i$i|0)==(0);
  if ($3) {
   $5 = 0;
  } else {
   HEAP32[19812] = 2;
   $5 = 2;
  }
 } else {
  $5 = $1;
 }
 $4 = $5 >>> 3;
 $$lobit = $4 & 1;
 STACKTOP = sp;return ($$lobit|0);
}
function _SDL_HasSSE() {
 var $$0$$0$$0$$0$$i$i = 0, $$lobit = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $0 = sp;
 $1 = HEAP32[19812]|0;
 $2 = ($1|0)==(-1);
 if ($2) {
  HEAP32[19812] = 0;
  HEAP32[$0>>2] = 0;
  $$0$$0$$0$$0$$i$i = HEAP32[$0>>2]|0;
  $3 = ($$0$$0$$0$$0$$i$i|0)==(0);
  if ($3) {
   $5 = 0;
  } else {
   HEAP32[19812] = 2;
   $5 = 2;
  }
 } else {
  $5 = $1;
 }
 $4 = $5 >>> 4;
 $$lobit = $4 & 1;
 STACKTOP = sp;return ($$lobit|0);
}
function _SDL_HasSSE2() {
 var $$0$$0$$0$$0$$i$i = 0, $$lobit = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $0 = sp;
 $1 = HEAP32[19812]|0;
 $2 = ($1|0)==(-1);
 if ($2) {
  HEAP32[19812] = 0;
  HEAP32[$0>>2] = 0;
  $$0$$0$$0$$0$$i$i = HEAP32[$0>>2]|0;
  $3 = ($$0$$0$$0$$0$$i$i|0)==(0);
  if ($3) {
   $5 = 0;
  } else {
   HEAP32[19812] = 2;
   $5 = 2;
  }
 } else {
  $5 = $1;
 }
 $4 = $5 >>> 5;
 $$lobit = $4 & 1;
 STACKTOP = sp;return ($$lobit|0);
}
function _SDL_HasAltiVec() {
 var $$0$$0$$0$$0$$i$i = 0, $$lobit = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $0 = sp;
 $1 = HEAP32[19812]|0;
 $2 = ($1|0)==(-1);
 if ($2) {
  HEAP32[19812] = 0;
  HEAP32[$0>>2] = 0;
  $$0$$0$$0$$0$$i$i = HEAP32[$0>>2]|0;
  $3 = ($$0$$0$$0$$0$$i$i|0)==(0);
  if ($3) {
   $5 = 0;
  } else {
   HEAP32[19812] = 2;
   $5 = 2;
  }
 } else {
  $5 = $1;
 }
 $4 = $5 >>> 1;
 $$lobit = $4 & 1;
 STACKTOP = sp;return ($$lobit|0);
}
function _SDL_Blit_Slow($0) {
 $0 = $0|0;
 var $$ = 0, $$0493 = 0, $$0493$shrunk = 0, $$0496553 = 0, $$0497552 = 0, $$0508 = 0, $$0508$shrunk = 0, $$0510557 = 0, $$0512551 = 0, $$0515556 = 0, $$0517550 = 0, $$1 = 0, $$1480 = 0, $$1482 = 0, $$1482$shrunk = 0, $$1486 = 0, $$1486$shrunk = 0, $$1490 = 0, $$1490$shrunk = 0, $$1494 = 0;
 var $$1498 = 0, $$1500 = 0, $$1500$shrunk = 0, $$1503 = 0, $$1503$shrunk = 0, $$1506 = 0, $$1506$shrunk = 0, $$1509 = 0, $$1511$lcssa = 0, $$1516$lcssa = 0, $$2 = 0, $$2483 = 0, $$2487 = 0, $$2491 = 0, $$2501 = 0, $$2504 = 0, $$2507 = 0, $$2514 = 0, $$2519 = 0, $$3 = 0;
 var $$3484 = 0, $$3488 = 0, $$3492 = 0, $$in = 0, $$pre = 0, $$pre564 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0;
 var $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0;
 var $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0;
 var $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0;
 var $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0;
 var $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0;
 var $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0;
 var $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0;
 var $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0;
 var $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0;
 var $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0;
 var $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0;
 var $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0;
 var $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0;
 var $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0;
 var $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0;
 var $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0;
 var $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0;
 var $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0;
 var $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0;
 var $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0;
 var $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0;
 var $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0;
 var $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0;
 var $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0;
 var $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0;
 var $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0;
 var $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0;
 var $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0;
 var $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0;
 var $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0;
 var $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0;
 var $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0;
 var $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0;
 var $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0;
 var $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0;
 var $832 = 0, $833 = 0, $834 = 0, $835 = 0, $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0;
 var $850 = 0, $851 = 0, $852 = 0, $853 = 0, $854 = 0, $855 = 0, $856 = 0, $857 = 0, $858 = 0, $859 = 0, $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $div = 0, $div521 = 0, $div522 = 0, $div524 = 0, $div525 = 0, $div526 = 0, $div527 = 0, $div528 = 0, $div529 = 0, $div531 = 0;
 var $div532 = 0, $div533 = 0, $div534 = 0, $div535 = 0, $div536 = 0, $div538 = 0, $div539 = 0, $div540 = 0, $or$cond = 0, $trunc = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = ((($0)) + 61|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = ((($0)) + 62|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = ((($0)) + 63|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = $13&255;
 $15 = ((($0)) + 40|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ((($0)) + 44|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ((($16)) + 9|0);
 $20 = HEAP8[$19>>0]|0;
 $21 = $20&255;
 $22 = ((($18)) + 9|0);
 $23 = HEAP8[$22>>0]|0;
 $24 = $23&255;
 $25 = ((($16)) + 24|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = $26 ^ -1;
 $28 = ((($0)) + 56|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ((($0)) + 8|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = $31 << 16;
 $33 = ((($0)) + 28|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = (($32|0) / ($34|0))&-1;
 $36 = ((($0)) + 4|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = $37 << 16;
 $39 = ((($0)) + 24|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = (($38|0) / ($40|0))&-1;
 $42 = (($34) + -1)|0;
 HEAP32[$33>>2] = $42;
 $43 = ($34|0)==(0);
 if ($43) {
  return;
 }
 $44 = ((($0)) + 20|0);
 $45 = ((($0)) + 32|0);
 $46 = ((($16)) + 28|0);
 $47 = ((($16)) + 12|0);
 $48 = ((($16)) + 32|0);
 $49 = ((($16)) + 29|0);
 $50 = ((($16)) + 16|0);
 $51 = ((($16)) + 33|0);
 $52 = ((($16)) + 30|0);
 $53 = ((($16)) + 20|0);
 $54 = ((($16)) + 34|0);
 $55 = $2 & 256;
 $56 = ($55|0)==(0);
 $57 = ((($18)) + 24|0);
 $58 = ((($18)) + 28|0);
 $59 = ((($18)) + 12|0);
 $60 = ((($18)) + 32|0);
 $61 = ((($18)) + 29|0);
 $62 = ((($18)) + 16|0);
 $63 = ((($18)) + 33|0);
 $64 = ((($18)) + 30|0);
 $65 = ((($18)) + 20|0);
 $66 = ((($18)) + 34|0);
 $67 = $2 & 1;
 $68 = ($67|0)==(0);
 $69 = $2 & 2;
 $70 = ($69|0)==(0);
 $71 = $2 & 48;
 $72 = ($71|0)!=(0);
 $73 = $2 >>> 4;
 $trunc = $73&255;
 $74 = ((($18)) + 31|0);
 $75 = ((($18)) + 35|0);
 $76 = ($20<<24>>24)==(3);
 $77 = ((($16)) + 31|0);
 $78 = ((($16)) + 35|0);
 $79 = ((($0)) + 12|0);
 $$pre = HEAP32[$44>>2]|0;
 $$0510557 = 0;$$0515556 = 0;$864 = $$pre;$87 = $40;
 while(1) {
  $80 = ($$0515556|0)>(65535);
  if ($80) {
   $81 = (($$0515556) + -65536)|0;
   $82 = $81 >>> 16;
   $83 = $82 << 16;
   $84 = (($$0510557) + 1)|0;
   $85 = (($84) + ($82))|0;
   $86 = (($81) - ($83))|0;
   $$1511$lcssa = $85;$$1516$lcssa = $86;
  } else {
   $$1511$lcssa = $$0510557;$$1516$lcssa = $$0515556;
  }
  $88 = ($87|0)==(0);
  if (!($88)) {
   $$0496553 = $864;$$0497552 = 0;$$0512551 = -1;$$0517550 = 65536;$$in = $87;
   while(1) {
    $89 = (($$in) + -1)|0;
    $90 = ($$0517550|0)>(65535);
    if ($90) {
     $91 = (($$0517550) + -65536)|0;
     $92 = $91 >>> 16;
     $93 = $92 << 16;
     $94 = (($$0512551) + 1)|0;
     $95 = (($94) + ($92))|0;
     $96 = (($91) - ($93))|0;
     $97 = HEAP32[$0>>2]|0;
     $98 = HEAP32[$79>>2]|0;
     $99 = Math_imul($98, $$1511$lcssa)|0;
     $100 = (($97) + ($99)|0);
     $101 = Math_imul($95, $21)|0;
     $102 = (($100) + ($101)|0);
     $$1498 = $102;$$2514 = $95;$$2519 = $96;
    } else {
     $$1498 = $$0497552;$$2514 = $$0512551;$$2519 = $$0517550;
    }
    $103 = HEAP32[$25>>2]|0;
    $104 = ($103|0)==(0);
    L15: do {
     if ($104) {
      switch ($20<<24>>24) {
      case 1:  {
       $251 = HEAP8[$$1498>>0]|0;
       $252 = $251&255;
       $253 = HEAP8[$46>>0]|0;
       $254 = $253&255;
       $255 = (79212 + ($254<<2)|0);
       $256 = HEAP32[$255>>2]|0;
       $257 = HEAP32[$47>>2]|0;
       $258 = $257 & $252;
       $259 = HEAP8[$48>>0]|0;
       $260 = $259&255;
       $261 = $258 >>> $260;
       $262 = (($256) + ($261)|0);
       $263 = HEAP8[$262>>0]|0;
       $264 = HEAP8[$49>>0]|0;
       $265 = $264&255;
       $266 = (79212 + ($265<<2)|0);
       $267 = HEAP32[$266>>2]|0;
       $268 = HEAP32[$50>>2]|0;
       $269 = $268 & $252;
       $270 = HEAP8[$51>>0]|0;
       $271 = $270&255;
       $272 = $269 >>> $271;
       $273 = (($267) + ($272)|0);
       $274 = HEAP8[$273>>0]|0;
       $275 = HEAP8[$52>>0]|0;
       $276 = $275&255;
       $277 = (79212 + ($276<<2)|0);
       $278 = HEAP32[$277>>2]|0;
       $279 = HEAP32[$53>>2]|0;
       $280 = $279 & $252;
       $281 = HEAP8[$54>>0]|0;
       $282 = $281&255;
       $283 = $280 >>> $282;
       $284 = (($278) + ($283)|0);
       $285 = HEAP8[$284>>0]|0;
       $$0493$shrunk = -1;$$1480 = $252;$$1482$shrunk = $263;$$1486$shrunk = $274;$$1490$shrunk = $285;
       break L15;
       break;
      }
      case 2:  {
       $286 = HEAP16[$$1498>>1]|0;
       $287 = $286&65535;
       $288 = HEAP8[$46>>0]|0;
       $289 = $288&255;
       $290 = (79212 + ($289<<2)|0);
       $291 = HEAP32[$290>>2]|0;
       $292 = HEAP32[$47>>2]|0;
       $293 = $292 & $287;
       $294 = HEAP8[$48>>0]|0;
       $295 = $294&255;
       $296 = $293 >>> $295;
       $297 = (($291) + ($296)|0);
       $298 = HEAP8[$297>>0]|0;
       $299 = HEAP8[$49>>0]|0;
       $300 = $299&255;
       $301 = (79212 + ($300<<2)|0);
       $302 = HEAP32[$301>>2]|0;
       $303 = HEAP32[$50>>2]|0;
       $304 = $303 & $287;
       $305 = HEAP8[$51>>0]|0;
       $306 = $305&255;
       $307 = $304 >>> $306;
       $308 = (($302) + ($307)|0);
       $309 = HEAP8[$308>>0]|0;
       $310 = HEAP8[$52>>0]|0;
       $311 = $310&255;
       $312 = (79212 + ($311<<2)|0);
       $313 = HEAP32[$312>>2]|0;
       $314 = HEAP32[$53>>2]|0;
       $315 = $314 & $287;
       $316 = HEAP8[$54>>0]|0;
       $317 = $316&255;
       $318 = $315 >>> $317;
       $319 = (($313) + ($318)|0);
       $320 = HEAP8[$319>>0]|0;
       $$0493$shrunk = -1;$$1480 = $287;$$1482$shrunk = $298;$$1486$shrunk = $309;$$1490$shrunk = $320;
       break L15;
       break;
      }
      case 3:  {
       $321 = HEAP8[$48>>0]|0;
       $div534 = ($321&255) >>> 3;
       $322 = $div534&255;
       $323 = (($$1498) + ($322)|0);
       $324 = HEAP8[$323>>0]|0;
       $325 = HEAP8[$51>>0]|0;
       $div535 = ($325&255) >>> 3;
       $326 = $div535&255;
       $327 = (($$1498) + ($326)|0);
       $328 = HEAP8[$327>>0]|0;
       $329 = HEAP8[$54>>0]|0;
       $div536 = ($329&255) >>> 3;
       $330 = $div536&255;
       $331 = (($$1498) + ($330)|0);
       $332 = HEAP8[$331>>0]|0;
       $$0493$shrunk = -1;$$1480 = 0;$$1482$shrunk = $324;$$1486$shrunk = $328;$$1490$shrunk = $332;
       break L15;
       break;
      }
      case 4:  {
       $333 = HEAP32[$$1498>>2]|0;
       $334 = HEAP8[$46>>0]|0;
       $335 = $334&255;
       $336 = (79212 + ($335<<2)|0);
       $337 = HEAP32[$336>>2]|0;
       $338 = HEAP32[$47>>2]|0;
       $339 = $338 & $333;
       $340 = HEAP8[$48>>0]|0;
       $341 = $340&255;
       $342 = $339 >>> $341;
       $343 = (($337) + ($342)|0);
       $344 = HEAP8[$343>>0]|0;
       $345 = HEAP8[$49>>0]|0;
       $346 = $345&255;
       $347 = (79212 + ($346<<2)|0);
       $348 = HEAP32[$347>>2]|0;
       $349 = HEAP32[$50>>2]|0;
       $350 = $349 & $333;
       $351 = HEAP8[$51>>0]|0;
       $352 = $351&255;
       $353 = $350 >>> $352;
       $354 = (($348) + ($353)|0);
       $355 = HEAP8[$354>>0]|0;
       $356 = HEAP8[$52>>0]|0;
       $357 = $356&255;
       $358 = (79212 + ($357<<2)|0);
       $359 = HEAP32[$358>>2]|0;
       $360 = HEAP32[$53>>2]|0;
       $361 = $360 & $333;
       $362 = HEAP8[$54>>0]|0;
       $363 = $362&255;
       $364 = $361 >>> $363;
       $365 = (($359) + ($364)|0);
       $366 = HEAP8[$365>>0]|0;
       $$0493$shrunk = -1;$$1480 = $333;$$1482$shrunk = $344;$$1486$shrunk = $355;$$1490$shrunk = $366;
       break L15;
       break;
      }
      default: {
       $$0493$shrunk = -1;$$1480 = 0;$$1482$shrunk = 0;$$1486$shrunk = 0;$$1490$shrunk = 0;
       break L15;
      }
      }
     } else {
      switch ($20<<24>>24) {
      case 1:  {
       $105 = HEAP8[$$1498>>0]|0;
       $106 = $105&255;
       $107 = HEAP8[$46>>0]|0;
       $108 = $107&255;
       $109 = (79212 + ($108<<2)|0);
       $110 = HEAP32[$109>>2]|0;
       $111 = HEAP32[$47>>2]|0;
       $112 = $111 & $106;
       $113 = HEAP8[$48>>0]|0;
       $114 = $113&255;
       $115 = $112 >>> $114;
       $116 = (($110) + ($115)|0);
       $117 = HEAP8[$116>>0]|0;
       $118 = HEAP8[$49>>0]|0;
       $119 = $118&255;
       $120 = (79212 + ($119<<2)|0);
       $121 = HEAP32[$120>>2]|0;
       $122 = HEAP32[$50>>2]|0;
       $123 = $122 & $106;
       $124 = HEAP8[$51>>0]|0;
       $125 = $124&255;
       $126 = $123 >>> $125;
       $127 = (($121) + ($126)|0);
       $128 = HEAP8[$127>>0]|0;
       $129 = HEAP8[$52>>0]|0;
       $130 = $129&255;
       $131 = (79212 + ($130<<2)|0);
       $132 = HEAP32[$131>>2]|0;
       $133 = HEAP32[$53>>2]|0;
       $134 = $133 & $106;
       $135 = HEAP8[$54>>0]|0;
       $136 = $135&255;
       $137 = $134 >>> $136;
       $138 = (($132) + ($137)|0);
       $139 = HEAP8[$138>>0]|0;
       $140 = HEAP8[$77>>0]|0;
       $141 = $140&255;
       $142 = (79212 + ($141<<2)|0);
       $143 = HEAP32[$142>>2]|0;
       $144 = $106 & $103;
       $145 = HEAP8[$78>>0]|0;
       $146 = $145&255;
       $147 = $144 >>> $146;
       $148 = (($143) + ($147)|0);
       $149 = HEAP8[$148>>0]|0;
       $$0493$shrunk = $149;$$1480 = $106;$$1482$shrunk = $117;$$1486$shrunk = $128;$$1490$shrunk = $139;
       break L15;
       break;
      }
      case 2:  {
       $150 = HEAP16[$$1498>>1]|0;
       $151 = $150&65535;
       $152 = HEAP8[$46>>0]|0;
       $153 = $152&255;
       $154 = (79212 + ($153<<2)|0);
       $155 = HEAP32[$154>>2]|0;
       $156 = HEAP32[$47>>2]|0;
       $157 = $156 & $151;
       $158 = HEAP8[$48>>0]|0;
       $159 = $158&255;
       $160 = $157 >>> $159;
       $161 = (($155) + ($160)|0);
       $162 = HEAP8[$161>>0]|0;
       $163 = HEAP8[$49>>0]|0;
       $164 = $163&255;
       $165 = (79212 + ($164<<2)|0);
       $166 = HEAP32[$165>>2]|0;
       $167 = HEAP32[$50>>2]|0;
       $168 = $167 & $151;
       $169 = HEAP8[$51>>0]|0;
       $170 = $169&255;
       $171 = $168 >>> $170;
       $172 = (($166) + ($171)|0);
       $173 = HEAP8[$172>>0]|0;
       $174 = HEAP8[$52>>0]|0;
       $175 = $174&255;
       $176 = (79212 + ($175<<2)|0);
       $177 = HEAP32[$176>>2]|0;
       $178 = HEAP32[$53>>2]|0;
       $179 = $178 & $151;
       $180 = HEAP8[$54>>0]|0;
       $181 = $180&255;
       $182 = $179 >>> $181;
       $183 = (($177) + ($182)|0);
       $184 = HEAP8[$183>>0]|0;
       $185 = HEAP8[$77>>0]|0;
       $186 = $185&255;
       $187 = (79212 + ($186<<2)|0);
       $188 = HEAP32[$187>>2]|0;
       $189 = $151 & $103;
       $190 = HEAP8[$78>>0]|0;
       $191 = $190&255;
       $192 = $189 >>> $191;
       $193 = (($188) + ($192)|0);
       $194 = HEAP8[$193>>0]|0;
       $$0493$shrunk = $194;$$1480 = $151;$$1482$shrunk = $162;$$1486$shrunk = $173;$$1490$shrunk = $184;
       break L15;
       break;
      }
      case 3:  {
       $195 = HEAP8[$48>>0]|0;
       $div538 = ($195&255) >>> 3;
       $196 = $div538&255;
       $197 = (($$1498) + ($196)|0);
       $198 = HEAP8[$197>>0]|0;
       $199 = HEAP8[$51>>0]|0;
       $div539 = ($199&255) >>> 3;
       $200 = $div539&255;
       $201 = (($$1498) + ($200)|0);
       $202 = HEAP8[$201>>0]|0;
       $203 = HEAP8[$54>>0]|0;
       $div540 = ($203&255) >>> 3;
       $204 = $div540&255;
       $205 = (($$1498) + ($204)|0);
       $206 = HEAP8[$205>>0]|0;
       $$0493$shrunk = -1;$$1480 = 0;$$1482$shrunk = $198;$$1486$shrunk = $202;$$1490$shrunk = $206;
       break L15;
       break;
      }
      case 4:  {
       $207 = HEAP32[$$1498>>2]|0;
       $208 = HEAP8[$46>>0]|0;
       $209 = $208&255;
       $210 = (79212 + ($209<<2)|0);
       $211 = HEAP32[$210>>2]|0;
       $212 = HEAP32[$47>>2]|0;
       $213 = $212 & $207;
       $214 = HEAP8[$48>>0]|0;
       $215 = $214&255;
       $216 = $213 >>> $215;
       $217 = (($211) + ($216)|0);
       $218 = HEAP8[$217>>0]|0;
       $219 = HEAP8[$49>>0]|0;
       $220 = $219&255;
       $221 = (79212 + ($220<<2)|0);
       $222 = HEAP32[$221>>2]|0;
       $223 = HEAP32[$50>>2]|0;
       $224 = $223 & $207;
       $225 = HEAP8[$51>>0]|0;
       $226 = $225&255;
       $227 = $224 >>> $226;
       $228 = (($222) + ($227)|0);
       $229 = HEAP8[$228>>0]|0;
       $230 = HEAP8[$52>>0]|0;
       $231 = $230&255;
       $232 = (79212 + ($231<<2)|0);
       $233 = HEAP32[$232>>2]|0;
       $234 = HEAP32[$53>>2]|0;
       $235 = $234 & $207;
       $236 = HEAP8[$54>>0]|0;
       $237 = $236&255;
       $238 = $235 >>> $237;
       $239 = (($233) + ($238)|0);
       $240 = HEAP8[$239>>0]|0;
       $241 = HEAP8[$77>>0]|0;
       $242 = $241&255;
       $243 = (79212 + ($242<<2)|0);
       $244 = HEAP32[$243>>2]|0;
       $245 = $207 & $103;
       $246 = HEAP8[$78>>0]|0;
       $247 = $246&255;
       $248 = $245 >>> $247;
       $249 = (($244) + ($248)|0);
       $250 = HEAP8[$249>>0]|0;
       $$0493$shrunk = $250;$$1480 = $207;$$1482$shrunk = $218;$$1486$shrunk = $229;$$1490$shrunk = $240;
       break L15;
       break;
      }
      default: {
       $$0493$shrunk = 0;$$1480 = 0;$$1482$shrunk = 0;$$1486$shrunk = 0;$$1490$shrunk = 0;
       break L15;
      }
      }
     }
    } while(0);
    $$1482 = $$1482$shrunk&255;
    $$1486 = $$1486$shrunk&255;
    $$1490 = $$1490$shrunk&255;
    $$0493 = $$0493$shrunk&255;
    if ($56) {
     label = 24;
    } else {
     if ($76) {
      $367 = HEAP8[$48>>0]|0;
      $368 = $367&255;
      $369 = $$1482 << $368;
      $370 = HEAP8[$51>>0]|0;
      $371 = $370&255;
      $372 = $$1486 << $371;
      $373 = $372 | $369;
      $374 = HEAP8[$54>>0]|0;
      $375 = $374&255;
      $376 = $$1490 << $375;
      $377 = $373 | $376;
      $$2 = $377;
     } else {
      $$2 = $$1480;
     }
     $378 = $$2 ^ $29;
     $379 = $378 & $27;
     $380 = ($379|0)==(0);
     if (!($380)) {
      label = 24;
     }
    }
    L34: do {
     if ((label|0) == 24) {
      label = 0;
      $384 = HEAP32[$57>>2]|0;
      $385 = ($384|0)==(0);
      L36: do {
       if ($385) {
        switch ($23<<24>>24) {
        case 1:  {
         $532 = HEAP8[$$0496553>>0]|0;
         $533 = $532&255;
         $534 = HEAP8[$58>>0]|0;
         $535 = $534&255;
         $536 = (79212 + ($535<<2)|0);
         $537 = HEAP32[$536>>2]|0;
         $538 = HEAP32[$59>>2]|0;
         $539 = $538 & $533;
         $540 = HEAP8[$60>>0]|0;
         $541 = $540&255;
         $542 = $539 >>> $541;
         $543 = (($537) + ($542)|0);
         $544 = HEAP8[$543>>0]|0;
         $545 = HEAP8[$61>>0]|0;
         $546 = $545&255;
         $547 = (79212 + ($546<<2)|0);
         $548 = HEAP32[$547>>2]|0;
         $549 = HEAP32[$62>>2]|0;
         $550 = $549 & $533;
         $551 = HEAP8[$63>>0]|0;
         $552 = $551&255;
         $553 = $550 >>> $552;
         $554 = (($548) + ($553)|0);
         $555 = HEAP8[$554>>0]|0;
         $556 = HEAP8[$64>>0]|0;
         $557 = $556&255;
         $558 = (79212 + ($557<<2)|0);
         $559 = HEAP32[$558>>2]|0;
         $560 = HEAP32[$65>>2]|0;
         $561 = $560 & $533;
         $562 = HEAP8[$66>>0]|0;
         $563 = $562&255;
         $564 = $561 >>> $563;
         $565 = (($559) + ($564)|0);
         $566 = HEAP8[$565>>0]|0;
         $$0508$shrunk = -1;$$1500$shrunk = $544;$$1503$shrunk = $555;$$1506$shrunk = $566;
         break L36;
         break;
        }
        case 2:  {
         $567 = HEAP16[$$0496553>>1]|0;
         $568 = $567&65535;
         $569 = HEAP8[$58>>0]|0;
         $570 = $569&255;
         $571 = (79212 + ($570<<2)|0);
         $572 = HEAP32[$571>>2]|0;
         $573 = HEAP32[$59>>2]|0;
         $574 = $573 & $568;
         $575 = HEAP8[$60>>0]|0;
         $576 = $575&255;
         $577 = $574 >>> $576;
         $578 = (($572) + ($577)|0);
         $579 = HEAP8[$578>>0]|0;
         $580 = HEAP8[$61>>0]|0;
         $581 = $580&255;
         $582 = (79212 + ($581<<2)|0);
         $583 = HEAP32[$582>>2]|0;
         $584 = HEAP32[$62>>2]|0;
         $585 = $584 & $568;
         $586 = HEAP8[$63>>0]|0;
         $587 = $586&255;
         $588 = $585 >>> $587;
         $589 = (($583) + ($588)|0);
         $590 = HEAP8[$589>>0]|0;
         $591 = HEAP8[$64>>0]|0;
         $592 = $591&255;
         $593 = (79212 + ($592<<2)|0);
         $594 = HEAP32[$593>>2]|0;
         $595 = HEAP32[$65>>2]|0;
         $596 = $595 & $568;
         $597 = HEAP8[$66>>0]|0;
         $598 = $597&255;
         $599 = $596 >>> $598;
         $600 = (($594) + ($599)|0);
         $601 = HEAP8[$600>>0]|0;
         $$0508$shrunk = -1;$$1500$shrunk = $579;$$1503$shrunk = $590;$$1506$shrunk = $601;
         break L36;
         break;
        }
        case 3:  {
         $602 = HEAP8[$60>>0]|0;
         $div527 = ($602&255) >>> 3;
         $603 = $div527&255;
         $604 = (($$0496553) + ($603)|0);
         $605 = HEAP8[$604>>0]|0;
         $606 = HEAP8[$63>>0]|0;
         $div528 = ($606&255) >>> 3;
         $607 = $div528&255;
         $608 = (($$0496553) + ($607)|0);
         $609 = HEAP8[$608>>0]|0;
         $610 = HEAP8[$66>>0]|0;
         $div529 = ($610&255) >>> 3;
         $611 = $div529&255;
         $612 = (($$0496553) + ($611)|0);
         $613 = HEAP8[$612>>0]|0;
         $$0508$shrunk = -1;$$1500$shrunk = $605;$$1503$shrunk = $609;$$1506$shrunk = $613;
         break L36;
         break;
        }
        case 4:  {
         $614 = HEAP32[$$0496553>>2]|0;
         $615 = HEAP8[$58>>0]|0;
         $616 = $615&255;
         $617 = (79212 + ($616<<2)|0);
         $618 = HEAP32[$617>>2]|0;
         $619 = HEAP32[$59>>2]|0;
         $620 = $619 & $614;
         $621 = HEAP8[$60>>0]|0;
         $622 = $621&255;
         $623 = $620 >>> $622;
         $624 = (($618) + ($623)|0);
         $625 = HEAP8[$624>>0]|0;
         $626 = HEAP8[$61>>0]|0;
         $627 = $626&255;
         $628 = (79212 + ($627<<2)|0);
         $629 = HEAP32[$628>>2]|0;
         $630 = HEAP32[$62>>2]|0;
         $631 = $630 & $614;
         $632 = HEAP8[$63>>0]|0;
         $633 = $632&255;
         $634 = $631 >>> $633;
         $635 = (($629) + ($634)|0);
         $636 = HEAP8[$635>>0]|0;
         $637 = HEAP8[$64>>0]|0;
         $638 = $637&255;
         $639 = (79212 + ($638<<2)|0);
         $640 = HEAP32[$639>>2]|0;
         $641 = HEAP32[$65>>2]|0;
         $642 = $641 & $614;
         $643 = HEAP8[$66>>0]|0;
         $644 = $643&255;
         $645 = $642 >>> $644;
         $646 = (($640) + ($645)|0);
         $647 = HEAP8[$646>>0]|0;
         $$0508$shrunk = -1;$$1500$shrunk = $625;$$1503$shrunk = $636;$$1506$shrunk = $647;
         break L36;
         break;
        }
        default: {
         $$0508$shrunk = -1;$$1500$shrunk = 0;$$1503$shrunk = 0;$$1506$shrunk = 0;
         break L36;
        }
        }
       } else {
        switch ($23<<24>>24) {
        case 1:  {
         $386 = HEAP8[$$0496553>>0]|0;
         $387 = $386&255;
         $388 = HEAP8[$58>>0]|0;
         $389 = $388&255;
         $390 = (79212 + ($389<<2)|0);
         $391 = HEAP32[$390>>2]|0;
         $392 = HEAP32[$59>>2]|0;
         $393 = $392 & $387;
         $394 = HEAP8[$60>>0]|0;
         $395 = $394&255;
         $396 = $393 >>> $395;
         $397 = (($391) + ($396)|0);
         $398 = HEAP8[$397>>0]|0;
         $399 = HEAP8[$61>>0]|0;
         $400 = $399&255;
         $401 = (79212 + ($400<<2)|0);
         $402 = HEAP32[$401>>2]|0;
         $403 = HEAP32[$62>>2]|0;
         $404 = $403 & $387;
         $405 = HEAP8[$63>>0]|0;
         $406 = $405&255;
         $407 = $404 >>> $406;
         $408 = (($402) + ($407)|0);
         $409 = HEAP8[$408>>0]|0;
         $410 = HEAP8[$64>>0]|0;
         $411 = $410&255;
         $412 = (79212 + ($411<<2)|0);
         $413 = HEAP32[$412>>2]|0;
         $414 = HEAP32[$65>>2]|0;
         $415 = $414 & $387;
         $416 = HEAP8[$66>>0]|0;
         $417 = $416&255;
         $418 = $415 >>> $417;
         $419 = (($413) + ($418)|0);
         $420 = HEAP8[$419>>0]|0;
         $421 = HEAP8[$74>>0]|0;
         $422 = $421&255;
         $423 = (79212 + ($422<<2)|0);
         $424 = HEAP32[$423>>2]|0;
         $425 = $387 & $384;
         $426 = HEAP8[$75>>0]|0;
         $427 = $426&255;
         $428 = $425 >>> $427;
         $429 = (($424) + ($428)|0);
         $430 = HEAP8[$429>>0]|0;
         $$0508$shrunk = $430;$$1500$shrunk = $398;$$1503$shrunk = $409;$$1506$shrunk = $420;
         break L36;
         break;
        }
        case 2:  {
         $431 = HEAP16[$$0496553>>1]|0;
         $432 = $431&65535;
         $433 = HEAP8[$58>>0]|0;
         $434 = $433&255;
         $435 = (79212 + ($434<<2)|0);
         $436 = HEAP32[$435>>2]|0;
         $437 = HEAP32[$59>>2]|0;
         $438 = $437 & $432;
         $439 = HEAP8[$60>>0]|0;
         $440 = $439&255;
         $441 = $438 >>> $440;
         $442 = (($436) + ($441)|0);
         $443 = HEAP8[$442>>0]|0;
         $444 = HEAP8[$61>>0]|0;
         $445 = $444&255;
         $446 = (79212 + ($445<<2)|0);
         $447 = HEAP32[$446>>2]|0;
         $448 = HEAP32[$62>>2]|0;
         $449 = $448 & $432;
         $450 = HEAP8[$63>>0]|0;
         $451 = $450&255;
         $452 = $449 >>> $451;
         $453 = (($447) + ($452)|0);
         $454 = HEAP8[$453>>0]|0;
         $455 = HEAP8[$64>>0]|0;
         $456 = $455&255;
         $457 = (79212 + ($456<<2)|0);
         $458 = HEAP32[$457>>2]|0;
         $459 = HEAP32[$65>>2]|0;
         $460 = $459 & $432;
         $461 = HEAP8[$66>>0]|0;
         $462 = $461&255;
         $463 = $460 >>> $462;
         $464 = (($458) + ($463)|0);
         $465 = HEAP8[$464>>0]|0;
         $466 = HEAP8[$74>>0]|0;
         $467 = $466&255;
         $468 = (79212 + ($467<<2)|0);
         $469 = HEAP32[$468>>2]|0;
         $470 = $432 & $384;
         $471 = HEAP8[$75>>0]|0;
         $472 = $471&255;
         $473 = $470 >>> $472;
         $474 = (($469) + ($473)|0);
         $475 = HEAP8[$474>>0]|0;
         $$0508$shrunk = $475;$$1500$shrunk = $443;$$1503$shrunk = $454;$$1506$shrunk = $465;
         break L36;
         break;
        }
        case 3:  {
         $476 = HEAP8[$60>>0]|0;
         $div531 = ($476&255) >>> 3;
         $477 = $div531&255;
         $478 = (($$0496553) + ($477)|0);
         $479 = HEAP8[$478>>0]|0;
         $480 = HEAP8[$63>>0]|0;
         $div532 = ($480&255) >>> 3;
         $481 = $div532&255;
         $482 = (($$0496553) + ($481)|0);
         $483 = HEAP8[$482>>0]|0;
         $484 = HEAP8[$66>>0]|0;
         $div533 = ($484&255) >>> 3;
         $485 = $div533&255;
         $486 = (($$0496553) + ($485)|0);
         $487 = HEAP8[$486>>0]|0;
         $$0508$shrunk = -1;$$1500$shrunk = $479;$$1503$shrunk = $483;$$1506$shrunk = $487;
         break L36;
         break;
        }
        case 4:  {
         $488 = HEAP32[$$0496553>>2]|0;
         $489 = HEAP8[$58>>0]|0;
         $490 = $489&255;
         $491 = (79212 + ($490<<2)|0);
         $492 = HEAP32[$491>>2]|0;
         $493 = HEAP32[$59>>2]|0;
         $494 = $493 & $488;
         $495 = HEAP8[$60>>0]|0;
         $496 = $495&255;
         $497 = $494 >>> $496;
         $498 = (($492) + ($497)|0);
         $499 = HEAP8[$498>>0]|0;
         $500 = HEAP8[$61>>0]|0;
         $501 = $500&255;
         $502 = (79212 + ($501<<2)|0);
         $503 = HEAP32[$502>>2]|0;
         $504 = HEAP32[$62>>2]|0;
         $505 = $504 & $488;
         $506 = HEAP8[$63>>0]|0;
         $507 = $506&255;
         $508 = $505 >>> $507;
         $509 = (($503) + ($508)|0);
         $510 = HEAP8[$509>>0]|0;
         $511 = HEAP8[$64>>0]|0;
         $512 = $511&255;
         $513 = (79212 + ($512<<2)|0);
         $514 = HEAP32[$513>>2]|0;
         $515 = HEAP32[$65>>2]|0;
         $516 = $515 & $488;
         $517 = HEAP8[$66>>0]|0;
         $518 = $517&255;
         $519 = $516 >>> $518;
         $520 = (($514) + ($519)|0);
         $521 = HEAP8[$520>>0]|0;
         $522 = HEAP8[$74>>0]|0;
         $523 = $522&255;
         $524 = (79212 + ($523<<2)|0);
         $525 = HEAP32[$524>>2]|0;
         $526 = $488 & $384;
         $527 = HEAP8[$75>>0]|0;
         $528 = $527&255;
         $529 = $526 >>> $528;
         $530 = (($525) + ($529)|0);
         $531 = HEAP8[$530>>0]|0;
         $$0508$shrunk = $531;$$1500$shrunk = $499;$$1503$shrunk = $510;$$1506$shrunk = $521;
         break L36;
         break;
        }
        default: {
         $$0508$shrunk = 0;$$1500$shrunk = 0;$$1503$shrunk = 0;$$1506$shrunk = 0;
         break L36;
        }
        }
       }
      } while(0);
      $$1500 = $$1500$shrunk&255;
      $$1503 = $$1503$shrunk&255;
      $$1506 = $$1506$shrunk&255;
      $$0508 = $$0508$shrunk&255;
      if ($68) {
       $$2483 = $$1482;$$2487 = $$1486;$$2491 = $$1490;
      } else {
       $648 = Math_imul($$1490, $11)|0;
       $649 = Math_imul($$1486, $8)|0;
       $650 = Math_imul($$1482, $5)|0;
       $651 = (($650>>>0) / 255)&-1;
       $652 = (($649>>>0) / 255)&-1;
       $653 = (($648>>>0) / 255)&-1;
       $$2483 = $651;$$2487 = $652;$$2491 = $653;
      }
      $654 = Math_imul($$0493, $14)|0;
      $655 = (($654>>>0) / 255)&-1;
      $$1494 = $70 ? $$0493 : $655;
      $656 = ($$1494>>>0)<(255);
      $or$cond = $72 & $656;
      if ($or$cond) {
       $657 = Math_imul($$2491, $$1494)|0;
       $658 = Math_imul($$2487, $$1494)|0;
       $659 = Math_imul($$2483, $$1494)|0;
       $660 = (($659>>>0) / 255)&-1;
       $661 = (($658>>>0) / 255)&-1;
       $662 = (($657>>>0) / 255)&-1;
       $$3484 = $660;$$3488 = $661;$$3492 = $662;
      } else {
       $$3484 = $$2483;$$3488 = $$2487;$$3492 = $$2491;
      }
      $trunc$clear = $trunc & 7;
      switch ($trunc$clear<<24>>24) {
      case 0:  {
       $$1509 = $$1494;$$2501 = $$3484;$$2504 = $$3488;$$2507 = $$3492;
       break;
      }
      case 1:  {
       $663 = (255 - ($$1494))|0;
       $664 = Math_imul($$1500, $663)|0;
       $665 = (($664>>>0) / 255)&-1;
       $666 = (($$3484) + ($665))|0;
       $667 = Math_imul($$1503, $663)|0;
       $668 = (($667>>>0) / 255)&-1;
       $669 = (($$3488) + ($668))|0;
       $670 = Math_imul($$1506, $663)|0;
       $671 = (($670>>>0) / 255)&-1;
       $672 = (($$3492) + ($671))|0;
       $673 = Math_imul($$0508, $663)|0;
       $674 = (($673>>>0) / 255)&-1;
       $675 = (($674) + ($$1494))|0;
       $$1509 = $675;$$2501 = $666;$$2504 = $669;$$2507 = $672;
       break;
      }
      case 2:  {
       $676 = (($$3484) + ($$1500))|0;
       $677 = ($676>>>0)<(255);
       $$ = $677 ? $676 : 255;
       $678 = (($$3488) + ($$1503))|0;
       $679 = ($678>>>0)<(255);
       $$3 = $679 ? $678 : 255;
       $680 = (($$3492) + ($$1506))|0;
       $681 = ($680>>>0)<(255);
       $$1 = $681 ? $680 : 255;
       $$1509 = $$0508;$$2501 = $$;$$2504 = $$3;$$2507 = $$1;
       break;
      }
      case 4:  {
       $682 = Math_imul($$3484, $$1500)|0;
       $683 = (($682>>>0) / 255)&-1;
       $684 = Math_imul($$3488, $$1503)|0;
       $685 = (($684>>>0) / 255)&-1;
       $686 = Math_imul($$3492, $$1506)|0;
       $687 = (($686>>>0) / 255)&-1;
       $$1509 = $$0508;$$2501 = $683;$$2504 = $685;$$2507 = $687;
       break;
      }
      default: {
       $$1509 = $$0508;$$2501 = $$1500;$$2504 = $$1503;$$2507 = $$1506;
      }
      }
      if ($385) {
       switch ($23<<24>>24) {
       case 1:  {
        $783 = HEAP8[$58>>0]|0;
        $784 = $783&255;
        $785 = $$2501 >>> $784;
        $786 = HEAP8[$60>>0]|0;
        $787 = $786&255;
        $788 = $785 << $787;
        $789 = HEAP8[$61>>0]|0;
        $790 = $789&255;
        $791 = $$2504 >>> $790;
        $792 = HEAP8[$63>>0]|0;
        $793 = $792&255;
        $794 = $791 << $793;
        $795 = HEAP8[$64>>0]|0;
        $796 = $795&255;
        $797 = $$2507 >>> $796;
        $798 = HEAP8[$66>>0]|0;
        $799 = $798&255;
        $800 = $797 << $799;
        $801 = $788 | $794;
        $802 = $801 | $800;
        $803 = $802&255;
        HEAP8[$$0496553>>0] = $803;
        break L34;
        break;
       }
       case 2:  {
        $804 = HEAP8[$58>>0]|0;
        $805 = $804&255;
        $806 = $$2501 >>> $805;
        $807 = HEAP8[$60>>0]|0;
        $808 = $807&255;
        $809 = $806 << $808;
        $810 = HEAP8[$61>>0]|0;
        $811 = $810&255;
        $812 = $$2504 >>> $811;
        $813 = HEAP8[$63>>0]|0;
        $814 = $813&255;
        $815 = $812 << $814;
        $816 = HEAP8[$64>>0]|0;
        $817 = $816&255;
        $818 = $$2507 >>> $817;
        $819 = HEAP8[$66>>0]|0;
        $820 = $819&255;
        $821 = $818 << $820;
        $822 = $809 | $815;
        $823 = $822 | $821;
        $824 = $823&65535;
        HEAP16[$$0496553>>1] = $824;
        break L34;
        break;
       }
       case 3:  {
        $825 = $$2501&255;
        $826 = HEAP8[$60>>0]|0;
        $div = ($826&255) >>> 3;
        $827 = $div&255;
        $828 = (($$0496553) + ($827)|0);
        HEAP8[$828>>0] = $825;
        $829 = $$2504&255;
        $830 = HEAP8[$63>>0]|0;
        $div521 = ($830&255) >>> 3;
        $831 = $div521&255;
        $832 = (($$0496553) + ($831)|0);
        HEAP8[$832>>0] = $829;
        $833 = $$2507&255;
        $834 = HEAP8[$66>>0]|0;
        $div522 = ($834&255) >>> 3;
        $835 = $div522&255;
        $836 = (($$0496553) + ($835)|0);
        HEAP8[$836>>0] = $833;
        break L34;
        break;
       }
       case 4:  {
        $837 = HEAP8[$58>>0]|0;
        $838 = $837&255;
        $839 = $$2501 >>> $838;
        $840 = HEAP8[$60>>0]|0;
        $841 = $840&255;
        $842 = $839 << $841;
        $843 = HEAP8[$61>>0]|0;
        $844 = $843&255;
        $845 = $$2504 >>> $844;
        $846 = HEAP8[$63>>0]|0;
        $847 = $846&255;
        $848 = $845 << $847;
        $849 = HEAP8[$64>>0]|0;
        $850 = $849&255;
        $851 = $$2507 >>> $850;
        $852 = HEAP8[$66>>0]|0;
        $853 = $852&255;
        $854 = $851 << $853;
        $855 = $842 | $848;
        $856 = $855 | $854;
        HEAP32[$$0496553>>2] = $856;
        break L34;
        break;
       }
       default: {
        break L34;
       }
       }
      } else {
       switch ($23<<24>>24) {
       case 1:  {
        $688 = HEAP8[$58>>0]|0;
        $689 = $688&255;
        $690 = $$2501 >>> $689;
        $691 = HEAP8[$60>>0]|0;
        $692 = $691&255;
        $693 = $690 << $692;
        $694 = HEAP8[$61>>0]|0;
        $695 = $694&255;
        $696 = $$2504 >>> $695;
        $697 = HEAP8[$63>>0]|0;
        $698 = $697&255;
        $699 = $696 << $698;
        $700 = $699 | $693;
        $701 = HEAP8[$64>>0]|0;
        $702 = $701&255;
        $703 = $$2507 >>> $702;
        $704 = HEAP8[$66>>0]|0;
        $705 = $704&255;
        $706 = $703 << $705;
        $707 = $700 | $706;
        $708 = HEAP8[$74>>0]|0;
        $709 = $708&255;
        $710 = $$1509 >>> $709;
        $711 = HEAP8[$75>>0]|0;
        $712 = $711&255;
        $713 = $710 << $712;
        $714 = $707 | $713;
        $715 = $714&255;
        HEAP8[$$0496553>>0] = $715;
        break L34;
        break;
       }
       case 2:  {
        $716 = HEAP8[$58>>0]|0;
        $717 = $716&255;
        $718 = $$2501 >>> $717;
        $719 = HEAP8[$60>>0]|0;
        $720 = $719&255;
        $721 = $718 << $720;
        $722 = HEAP8[$61>>0]|0;
        $723 = $722&255;
        $724 = $$2504 >>> $723;
        $725 = HEAP8[$63>>0]|0;
        $726 = $725&255;
        $727 = $724 << $726;
        $728 = $727 | $721;
        $729 = HEAP8[$64>>0]|0;
        $730 = $729&255;
        $731 = $$2507 >>> $730;
        $732 = HEAP8[$66>>0]|0;
        $733 = $732&255;
        $734 = $731 << $733;
        $735 = $728 | $734;
        $736 = HEAP8[$74>>0]|0;
        $737 = $736&255;
        $738 = $$1509 >>> $737;
        $739 = HEAP8[$75>>0]|0;
        $740 = $739&255;
        $741 = $738 << $740;
        $742 = $735 | $741;
        $743 = $742&65535;
        HEAP16[$$0496553>>1] = $743;
        break L34;
        break;
       }
       case 3:  {
        $744 = $$2501&255;
        $745 = HEAP8[$60>>0]|0;
        $div524 = ($745&255) >>> 3;
        $746 = $div524&255;
        $747 = (($$0496553) + ($746)|0);
        HEAP8[$747>>0] = $744;
        $748 = $$2504&255;
        $749 = HEAP8[$63>>0]|0;
        $div525 = ($749&255) >>> 3;
        $750 = $div525&255;
        $751 = (($$0496553) + ($750)|0);
        HEAP8[$751>>0] = $748;
        $752 = $$2507&255;
        $753 = HEAP8[$66>>0]|0;
        $div526 = ($753&255) >>> 3;
        $754 = $div526&255;
        $755 = (($$0496553) + ($754)|0);
        HEAP8[$755>>0] = $752;
        break L34;
        break;
       }
       case 4:  {
        $756 = HEAP8[$58>>0]|0;
        $757 = $756&255;
        $758 = $$2501 >>> $757;
        $759 = HEAP8[$60>>0]|0;
        $760 = $759&255;
        $761 = $758 << $760;
        $762 = HEAP8[$61>>0]|0;
        $763 = $762&255;
        $764 = $$2504 >>> $763;
        $765 = HEAP8[$63>>0]|0;
        $766 = $765&255;
        $767 = $764 << $766;
        $768 = $767 | $761;
        $769 = HEAP8[$64>>0]|0;
        $770 = $769&255;
        $771 = $$2507 >>> $770;
        $772 = HEAP8[$66>>0]|0;
        $773 = $772&255;
        $774 = $771 << $773;
        $775 = $768 | $774;
        $776 = HEAP8[$74>>0]|0;
        $777 = $776&255;
        $778 = $$1509 >>> $777;
        $779 = HEAP8[$75>>0]|0;
        $780 = $779&255;
        $781 = $778 << $780;
        $782 = $775 | $781;
        HEAP32[$$0496553>>2] = $782;
        break L34;
        break;
       }
       default: {
        break L34;
       }
       }
      }
     }
    } while(0);
    $381 = (($$2519) + ($41))|0;
    $382 = (($$0496553) + ($24)|0);
    $383 = ($89|0)==(0);
    if ($383) {
     break;
    } else {
     $$0496553 = $382;$$0497552 = $$1498;$$0512551 = $$2514;$$0517550 = $381;$$in = $89;
    }
   }
  }
  $857 = HEAP32[$45>>2]|0;
  $858 = HEAP32[$44>>2]|0;
  $859 = (($858) + ($857)|0);
  HEAP32[$44>>2] = $859;
  $860 = HEAP32[$33>>2]|0;
  $861 = (($860) + -1)|0;
  HEAP32[$33>>2] = $861;
  $862 = ($860|0)==(0);
  if ($862) {
   break;
  }
  $863 = (($$1516$lcssa) + ($35))|0;
  $$pre564 = HEAP32[$39>>2]|0;
  $$0510557 = $$1511$lcssa;$$0515556 = $863;$864 = $859;$87 = $$pre564;
 }
 return;
}
function _SDL_BlitCopy($0) {
 $0 = $0|0;
 var $$06278 = 0, $$06377 = 0, $$06676 = 0, $$16480 = 0, $$16779 = 0, $$181 = 0, $$26584 = 0, $$26883 = 0, $$285 = 0, $$sink = 0, $$sink69 = 0, $$sink72 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 44|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($4)) + 9|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = $6&255;
 $8 = Math_imul($7, $2)|0;
 $9 = ((($0)) + 28|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$0>>2]|0;
 $12 = ((($0)) + 20|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($0)) + 12|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ((($0)) + 32|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($11>>>0)<($13>>>0);
 $$sink72 = $18 ? $15 : $17;
 $$sink = $18 ? $11 : $13;
 $$sink69 = $18 ? $13 : $11;
 $19 = Math_imul($$sink72, $10)|0;
 $20 = (($$sink) + ($19)|0);
 $21 = ($$sink69>>>0)<($20>>>0);
 if (!($21)) {
  $22 = ($10|0)==(0);
  if ($22) {
   return;
  } else {
   $$26584 = $10;$$26883 = $13;$$285 = $11;
  }
  while(1) {
   $41 = (($$26584) + -1)|0;
   (_SDL_memcpy($$26883,$$285,$8)|0);
   $42 = (($$285) + ($15)|0);
   $43 = (($$26883) + ($17)|0);
   $44 = ($41|0)==(0);
   if ($44) {
    break;
   } else {
    $$26584 = $41;$$26883 = $43;$$285 = $42;
   }
  }
  return;
 }
 $23 = ($13>>>0)<($11>>>0);
 if ($23) {
  $24 = ($10|0)==(0);
  if ($24) {
   return;
  } else {
   $$06278 = $11;$$06377 = $10;$$06676 = $13;
  }
  while(1) {
   $25 = (($$06377) + -1)|0;
   (_SDL_memmove($$06676,$$06278,$8)|0);
   $26 = (($$06278) + ($15)|0);
   $27 = (($$06676) + ($17)|0);
   $28 = ($25|0)==(0);
   if ($28) {
    break;
   } else {
    $$06278 = $26;$$06377 = $25;$$06676 = $27;
   }
  }
  return;
 }
 $29 = (($10) + -1)|0;
 $30 = ($10|0)==(0);
 if ($30) {
  return;
 }
 $31 = Math_imul($17, $29)|0;
 $32 = (($13) + ($31)|0);
 $33 = Math_imul($15, $29)|0;
 $34 = (($11) + ($33)|0);
 $35 = (0 - ($15))|0;
 $36 = (0 - ($17))|0;
 $$16480 = $10;$$16779 = $32;$$181 = $34;
 while(1) {
  $37 = (($$16480) + -1)|0;
  (_SDL_memmove($$16779,$$181,$8)|0);
  $38 = (($$181) + ($35)|0);
  $39 = (($$16779) + ($36)|0);
  $40 = ($37|0)==(0);
  if ($40) {
   break;
  } else {
   $$16480 = $37;$$16779 = $39;$$181 = $38;
  }
 }
 return;
}
function _SDL_InvalidateMap($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ($0|0)==(0|0);
 if ($1) {
  return;
 }
 $2 = HEAP32[$0>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = ((($2)) + 56|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($5) + -1)|0;
  HEAP32[$4>>2] = $6;
  $7 = ($5|0)<(2);
  if ($7) {
   _SDL_FreeSurface($2);
  }
 }
 HEAP32[$0>>2] = 0;
 $8 = ((($0)) + 84|0);
 HEAP32[$8>>2] = 0;
 $9 = ((($0)) + 80|0);
 HEAP32[$9>>2] = 0;
 $10 = ((($0)) + 64|0);
 $11 = HEAP32[$10>>2]|0;
 _SDL_free($11);
 HEAP32[$10>>2] = 0;
 return;
}
function _SDL_memmove($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 _memmove(($0|0),($1|0),($2|0))|0;
 return ($0|0);
}
function _SDL_Blit_RGB888_RGB888_Scale($0) {
 $0 = $0|0;
 var $$04467 = 0, $$04566 = 0, $$04671 = 0, $$04865 = 0, $$05064 = 0, $$05370 = 0, $$1 = 0, $$147$lcssa = 0, $$154$lcssa = 0, $$2 = 0, $$252 = 0, $$in = 0, $$pre = 0, $$pre78 = 0, $$pre79 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 << 16;
 $4 = ((($0)) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3|0) / ($5|0))&-1;
 $7 = ((($0)) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 << 16;
 $10 = ((($0)) + 24|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($9|0) / ($11|0))&-1;
 $13 = (($5) + -1)|0;
 HEAP32[$4>>2] = $13;
 $14 = ($5|0)==(0);
 if ($14) {
  return;
 }
 $15 = ((($0)) + 20|0);
 $16 = ((($0)) + 32|0);
 $17 = ((($0)) + 12|0);
 $$pre = HEAP32[$15>>2]|0;
 $$04671 = 0;$$05370 = 0;$25 = $11;$47 = $$pre;$52 = $13;$53 = $$pre;
 while(1) {
  $18 = ($$05370|0)>(65535);
  if ($18) {
   $19 = (($$05370) + -65536)|0;
   $20 = $19 >>> 16;
   $21 = $20 << 16;
   $22 = (($$04671) + 1)|0;
   $23 = (($22) + ($20))|0;
   $24 = (($19) - ($21))|0;
   $$147$lcssa = $23;$$154$lcssa = $24;
  } else {
   $$147$lcssa = $$04671;$$154$lcssa = $$05370;
  }
  $26 = ($25|0)==(0);
  if ($26) {
   $49 = $52;
  } else {
   $$04467 = $53;$$04566 = 0;$$04865 = -1;$$05064 = 65536;$$in = $25;
   while(1) {
    $27 = (($$in) + -1)|0;
    $28 = ($$05064|0)>(65535);
    if ($28) {
     $29 = (($$05064) + -65536)|0;
     $30 = $29 >>> 16;
     $31 = $30 << 16;
     $32 = (($$04865) + 1)|0;
     $33 = (($32) + ($30))|0;
     $34 = (($29) - ($31))|0;
     $35 = HEAP32[$0>>2]|0;
     $36 = HEAP32[$17>>2]|0;
     $37 = Math_imul($36, $$147$lcssa)|0;
     $38 = (($35) + ($37)|0);
     $39 = $33 << 2;
     $40 = (($38) + ($39)|0);
     $$1 = $40;$$2 = $33;$$252 = $34;
    } else {
     $$1 = $$04566;$$2 = $$04865;$$252 = $$05064;
    }
    $41 = HEAP32[$$1>>2]|0;
    HEAP32[$$04467>>2] = $41;
    $42 = (($$252) + ($12))|0;
    $43 = ((($$04467)) + 4|0);
    $44 = ($27|0)==(0);
    if ($44) {
     break;
    } else {
     $$04467 = $43;$$04566 = $$1;$$04865 = $$2;$$05064 = $42;$$in = $27;
    }
   }
   $$pre79 = HEAP32[$4>>2]|0;
   $49 = $$pre79;
  }
  $45 = HEAP32[$16>>2]|0;
  $46 = (($47) + ($45)|0);
  $48 = (($49) + -1)|0;
  HEAP32[$4>>2] = $48;
  $50 = ($49|0)==(0);
  if ($50) {
   break;
  }
  $51 = (($$154$lcssa) + ($6))|0;
  $$pre78 = HEAP32[$10>>2]|0;
  $$04671 = $$147$lcssa;$$05370 = $51;$25 = $$pre78;$47 = $46;$52 = $48;$53 = $46;
 }
 HEAP32[$15>>2] = $46;
 return;
}
function _SDL_Blit_RGB888_RGB888_Blend($0) {
 $0 = $0|0;
 var $$$us97 = 0, $$08594 = 0, $$08594$us = 0, $$08594$us95 = 0, $$08693 = 0, $$08693$us = 0, $$08693$us96 = 0, $$087 = 0, $$088 = 0, $$089 = 0, $$1$us99 = 0, $$3$us98 = 0, $$pre = 0, $$pre110 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $9 = 0;
 var $cond = 0, $trunc = 0, $trunc$clear = 0, $trunc$clear1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + -1)|0;
 HEAP32[$3>>2] = $5;
 $6 = ($4|0)==(0);
 if ($6) {
  return;
 }
 $7 = ((($0)) + 20|0);
 $8 = ((($0)) + 24|0);
 $9 = ((($0)) + 12|0);
 $10 = ((($0)) + 32|0);
 $11 = $2 & 112;
 $trunc = $11&255;
 $$pre = HEAP32[$0>>2]|0;
 $$pre110 = HEAP32[$7>>2]|0;
 $trunc$clear = $trunc & 127;
 $cond = ($trunc$clear<<24>>24)==(64);
 $78 = $$pre;$81 = $$pre110;$85 = $$pre110;$86 = $$pre;
 while(1) {
  $12 = HEAP32[$8>>2]|0;
  $13 = (($12) + -1)|0;
  $14 = ($12|0)==(0);
  if (!($14)) {
   $trunc$clear1 = $trunc & 127;
   switch ($trunc$clear1<<24>>24) {
   case 16:  {
    $$08594$us = $85;$$08693$us = $86;$20 = $13;
    while(1) {
     $15 = HEAP32[$$08693$us>>2]|0;
     $16 = $15 & 16777215;
     HEAP32[$$08594$us>>2] = $16;
     $17 = ((($$08693$us)) + 4|0);
     $18 = ((($$08594$us)) + 4|0);
     $19 = (($20) + -1)|0;
     $21 = ($20|0)==(0);
     if ($21) {
      break;
     } else {
      $$08594$us = $18;$$08693$us = $17;$20 = $19;
     }
    }
    break;
   }
   case 32:  {
    $$08594$us95 = $85;$$08693$us96 = $86;$47 = $13;
    while(1) {
     $22 = HEAP32[$$08693$us96>>2]|0;
     $23 = $22 >>> 16;
     $24 = $23 & 255;
     $25 = $22 >>> 8;
     $26 = $25 & 255;
     $27 = $22 & 255;
     $28 = HEAP32[$$08594$us95>>2]|0;
     $29 = $28 >>> 16;
     $30 = $29 & 255;
     $31 = $28 >>> 8;
     $32 = $31 & 255;
     $33 = $28 & 255;
     $34 = (($30) + ($24))|0;
     $35 = ($34>>>0)<(255);
     $$$us97 = $35 ? $34 : 255;
     $36 = (($32) + ($26))|0;
     $37 = ($36>>>0)<(255);
     $$3$us98 = $37 ? $36 : 255;
     $38 = (($33) + ($27))|0;
     $39 = ($38>>>0)<(255);
     $$1$us99 = $39 ? $38 : 255;
     $40 = $$$us97 << 16;
     $41 = $$3$us98 << 8;
     $42 = $41 | $40;
     $43 = $42 | $$1$us99;
     HEAP32[$$08594$us95>>2] = $43;
     $44 = ((($$08693$us96)) + 4|0);
     $45 = ((($$08594$us95)) + 4|0);
     $46 = (($47) + -1)|0;
     $48 = ($47|0)==(0);
     if ($48) {
      break;
     } else {
      $$08594$us95 = $45;$$08693$us96 = $44;$47 = $46;
     }
    }
    break;
   }
   default: {
    $$08594 = $85;$$08693 = $86;$74 = $13;
    while(1) {
     $49 = HEAP32[$$08693>>2]|0;
     $50 = HEAP32[$$08594>>2]|0;
     $51 = $50 >>> 16;
     $52 = $51 & 255;
     $53 = $50 >>> 8;
     $54 = $53 & 255;
     $55 = $50 & 255;
     if ($cond) {
      $56 = $49 & 255;
      $57 = $49 >>> 8;
      $58 = $57 & 255;
      $59 = $49 >>> 16;
      $60 = $59 & 255;
      $61 = Math_imul($52, $60)|0;
      $62 = (($61>>>0) / 255)&-1;
      $63 = Math_imul($54, $58)|0;
      $64 = (($63>>>0) / 255)&-1;
      $65 = Math_imul($55, $56)|0;
      $66 = (($65>>>0) / 255)&-1;
      $$087 = $66;$$088 = $64;$$089 = $62;
     } else {
      $$087 = $55;$$088 = $54;$$089 = $52;
     }
     $67 = $$089 << 16;
     $68 = $$088 << 8;
     $69 = $68 | $67;
     $70 = $69 | $$087;
     HEAP32[$$08594>>2] = $70;
     $71 = ((($$08693)) + 4|0);
     $72 = ((($$08594)) + 4|0);
     $73 = (($74) + -1)|0;
     $75 = ($74|0)==(0);
     if ($75) {
      break;
     } else {
      $$08594 = $72;$$08693 = $71;$74 = $73;
     }
    }
   }
   }
  }
  $76 = HEAP32[$9>>2]|0;
  $77 = (($78) + ($76)|0);
  $79 = HEAP32[$10>>2]|0;
  $80 = (($81) + ($79)|0);
  $82 = HEAP32[$3>>2]|0;
  $83 = (($82) + -1)|0;
  HEAP32[$3>>2] = $83;
  $84 = ($82|0)==(0);
  if ($84) {
   break;
  } else {
   $78 = $77;$81 = $80;$85 = $80;$86 = $77;
  }
 }
 HEAP32[$0>>2] = $77;
 HEAP32[$7>>2] = $80;
 return;
}
function _SDL_Blit_RGB888_RGB888_Blend_Scale($0) {
 $0 = $0|0;
 var $$ = 0, $$0112142 = 0, $$0112142$us = 0, $$0113141 = 0, $$0113141$us = 0, $$0117140 = 0, $$0117140$us = 0, $$0119146 = 0, $$0121139 = 0, $$0121139$us = 0, $$0124145 = 0, $$0126 = 0, $$0127 = 0, $$0128 = 0, $$1 = 0, $$1114 = 0, $$1114$us = 0, $$1120$lcssa = 0, $$1125$lcssa = 0, $$2 = 0;
 var $$2$us = 0, $$2123 = 0, $$2123$us = 0, $$3 = 0, $$pre = 0, $$pre156 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $trunc = 0, $trunc$clear = 0, $trunc$clear1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 << 16;
 $6 = ((($0)) + 28|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5|0) / ($7|0))&-1;
 $9 = ((($0)) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10 << 16;
 $12 = ((($0)) + 24|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($11|0) / ($13|0))&-1;
 $15 = (($7) + -1)|0;
 HEAP32[$6>>2] = $15;
 $16 = ($7|0)==(0);
 if ($16) {
  return;
 }
 $17 = ((($0)) + 20|0);
 $18 = ((($0)) + 32|0);
 $19 = $2 & 112;
 $trunc = $19&255;
 $20 = ((($0)) + 12|0);
 $trunc$clear = $trunc & 127;
 $21 = ($trunc$clear<<24>>24)==(16);
 $$pre = HEAP32[$17>>2]|0;
 $$0119146 = 0;$$0124145 = 0;$100 = $$pre;$105 = $$pre;$30 = $13;
 while(1) {
  $22 = ($$0119146|0)>(65535);
  if ($22) {
   $23 = (($$0119146) + -65536)|0;
   $24 = $23 >>> 16;
   $25 = $24 << 16;
   $26 = (($$0124145) + 1)|0;
   $27 = (($26) + ($24))|0;
   $28 = (($23) - ($25))|0;
   $$1120$lcssa = $28;$$1125$lcssa = $27;
  } else {
   $$1120$lcssa = $$0119146;$$1125$lcssa = $$0124145;
  }
  $29 = (($30) + -1)|0;
  $31 = ($30|0)==(0);
  L9: do {
   if (!($31)) {
    if ($21) {
     $$0112142$us = $105;$$0113141$us = 0;$$0117140$us = 65536;$$0121139$us = -1;$50 = $29;
     while(1) {
      $32 = ($$0117140$us|0)>(65535);
      if ($32) {
       $33 = (($$0117140$us) + -65536)|0;
       $34 = $33 >>> 16;
       $35 = $34 << 16;
       $36 = (($$0121139$us) + 1)|0;
       $37 = (($36) + ($34))|0;
       $38 = (($33) - ($35))|0;
       $39 = HEAP32[$0>>2]|0;
       $40 = HEAP32[$20>>2]|0;
       $41 = Math_imul($40, $$1125$lcssa)|0;
       $42 = (($39) + ($41)|0);
       $43 = $37 << 2;
       $44 = (($42) + ($43)|0);
       $$1114$us = $44;$$2$us = $38;$$2123$us = $37;
      } else {
       $$1114$us = $$0113141$us;$$2$us = $$0117140$us;$$2123$us = $$0121139$us;
      }
      $45 = HEAP32[$$1114$us>>2]|0;
      $46 = $45 & 16777215;
      HEAP32[$$0112142$us>>2] = $46;
      $47 = (($$2$us) + ($14))|0;
      $48 = ((($$0112142$us)) + 4|0);
      $49 = (($50) + -1)|0;
      $51 = ($50|0)==(0);
      if ($51) {
       break L9;
      } else {
       $$0112142$us = $48;$$0113141$us = $$1114$us;$$0117140$us = $47;$$0121139$us = $$2123$us;$50 = $49;
      }
     }
    } else {
     $$0112142 = $105;$$0113141 = 0;$$0117140 = 65536;$$0121139 = -1;$96 = $29;
    }
    while(1) {
     $52 = ($$0117140|0)>(65535);
     if ($52) {
      $53 = (($$0117140) + -65536)|0;
      $54 = $53 >>> 16;
      $55 = $54 << 16;
      $56 = (($$0121139) + 1)|0;
      $57 = (($56) + ($54))|0;
      $58 = (($53) - ($55))|0;
      $59 = HEAP32[$0>>2]|0;
      $60 = HEAP32[$20>>2]|0;
      $61 = Math_imul($60, $$1125$lcssa)|0;
      $62 = (($59) + ($61)|0);
      $63 = $57 << 2;
      $64 = (($62) + ($63)|0);
      $$1114 = $64;$$2 = $58;$$2123 = $57;
     } else {
      $$1114 = $$0113141;$$2 = $$0117140;$$2123 = $$0121139;
     }
     $65 = HEAP32[$$1114>>2]|0;
     $66 = $65 >>> 16;
     $67 = $66 & 255;
     $68 = $65 >>> 8;
     $69 = $68 & 255;
     $70 = $65 & 255;
     $71 = HEAP32[$$0112142>>2]|0;
     $72 = $71 >>> 16;
     $73 = $72 & 255;
     $74 = $71 >>> 8;
     $75 = $74 & 255;
     $76 = $71 & 255;
     $trunc$clear1 = $trunc & 127;
     switch ($trunc$clear1<<24>>24) {
     case 64:  {
      $83 = Math_imul($73, $67)|0;
      $84 = (($83>>>0) / 255)&-1;
      $85 = Math_imul($75, $69)|0;
      $86 = (($85>>>0) / 255)&-1;
      $87 = Math_imul($76, $70)|0;
      $88 = (($87>>>0) / 255)&-1;
      $$0126 = $88;$$0127 = $86;$$0128 = $84;
      break;
     }
     case 32:  {
      $77 = (($73) + ($67))|0;
      $78 = ($77>>>0)<(255);
      $$ = $78 ? $77 : 255;
      $79 = (($75) + ($69))|0;
      $80 = ($79>>>0)<(255);
      $$3 = $80 ? $79 : 255;
      $81 = (($76) + ($70))|0;
      $82 = ($81>>>0)<(255);
      $$1 = $82 ? $81 : 255;
      $$0126 = $$1;$$0127 = $$3;$$0128 = $$;
      break;
     }
     default: {
      $$0126 = $76;$$0127 = $75;$$0128 = $73;
     }
     }
     $89 = $$0128 << 16;
     $90 = $$0127 << 8;
     $91 = $90 | $89;
     $92 = $91 | $$0126;
     HEAP32[$$0112142>>2] = $92;
     $93 = (($$2) + ($14))|0;
     $94 = ((($$0112142)) + 4|0);
     $95 = (($96) + -1)|0;
     $97 = ($96|0)==(0);
     if ($97) {
      break L9;
     } else {
      $$0112142 = $94;$$0113141 = $$1114;$$0117140 = $93;$$0121139 = $$2123;$96 = $95;
     }
    }
   }
  } while(0);
  $98 = HEAP32[$18>>2]|0;
  $99 = (($100) + ($98)|0);
  $101 = HEAP32[$6>>2]|0;
  $102 = (($101) + -1)|0;
  HEAP32[$6>>2] = $102;
  $103 = ($101|0)==(0);
  if ($103) {
   break;
  }
  $104 = (($$1120$lcssa) + ($8))|0;
  $$pre156 = HEAP32[$12>>2]|0;
  $$0119146 = $104;$$0124145 = $$1125$lcssa;$100 = $99;$105 = $99;$30 = $$pre156;
 }
 HEAP32[$17>>2] = $99;
 return;
}
function _SDL_Blit_RGB888_RGB888_Modulate($0) {
 $0 = $0|0;
 var $$05157 = 0, $$05157$us$us = 0, $$05256 = 0, $$05256$us$us = 0, $$in = 0, $$in68 = 0, $$lcssa77$sink = 0, $$lcssa78$sink = 0, $$pre71 = 0, $$pre72 = 0, $$pre73 = 0, $$pre74 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = ((($0)) + 61|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = ((($0)) + 62|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = ((($0)) + 28|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($13) + -1)|0;
 HEAP32[$12>>2] = $14;
 $15 = ($13|0)==(0);
 if ($15) {
  return;
 }
 $16 = ((($0)) + 20|0);
 $17 = ((($0)) + 24|0);
 $18 = ((($0)) + 12|0);
 $19 = ((($0)) + 32|0);
 $20 = $2 & 1;
 $21 = ($20|0)==(0);
 $$pre72 = HEAP32[$0>>2]|0;
 $$pre73 = HEAP32[$16>>2]|0;
 if ($21) {
  $26 = $$pre72;$29 = $$pre73;$70 = $14;$71 = $$pre73;$72 = $$pre72;
  while(1) {
   $22 = HEAP32[$17>>2]|0;
   $23 = ($22|0)==(0);
   if ($23) {
    $31 = $70;
   } else {
    $$05157$us$us = $71;$$05256$us$us = $72;$$in68 = $22;
    while(1) {
     $33 = (($$in68) + -1)|0;
     $34 = HEAP32[$$05256$us$us>>2]|0;
     $35 = $34 & 16777215;
     HEAP32[$$05157$us$us>>2] = $35;
     $36 = ((($$05256$us$us)) + 4|0);
     $37 = ((($$05157$us$us)) + 4|0);
     $38 = ($33|0)==(0);
     if ($38) {
      break;
     } else {
      $$05157$us$us = $37;$$05256$us$us = $36;$$in68 = $33;
     }
    }
    $$pre74 = HEAP32[$12>>2]|0;
    $31 = $$pre74;
   }
   $24 = HEAP32[$18>>2]|0;
   $25 = (($26) + ($24)|0);
   $27 = HEAP32[$19>>2]|0;
   $28 = (($29) + ($27)|0);
   $30 = (($31) + -1)|0;
   HEAP32[$12>>2] = $30;
   $32 = ($31|0)==(0);
   if ($32) {
    $$lcssa77$sink = $25;$$lcssa78$sink = $28;
    break;
   } else {
    $26 = $25;$29 = $28;$70 = $30;$71 = $28;$72 = $25;
   }
  }
 } else {
  $63 = $$pre72;$66 = $$pre73;$73 = $14;$74 = $$pre73;$75 = $$pre72;
  while(1) {
   $39 = HEAP32[$17>>2]|0;
   $40 = ($39|0)==(0);
   if ($40) {
    $68 = $73;
   } else {
    $$05157 = $74;$$05256 = $75;$$in = $39;
    while(1) {
     $41 = (($$in) + -1)|0;
     $42 = HEAP32[$$05256>>2]|0;
     $43 = $42 >>> 16;
     $44 = $43 & 255;
     $45 = $42 >>> 8;
     $46 = $45 & 255;
     $47 = $42 & 255;
     $48 = Math_imul($47, $11)|0;
     $49 = Math_imul($46, $8)|0;
     $50 = Math_imul($44, $5)|0;
     $51 = (($50>>>0) / 255)&-1;
     $52 = (($49>>>0) / 255)&-1;
     $53 = (($48>>>0) / 255)&-1;
     $54 = $51 << 16;
     $55 = $52 << 8;
     $56 = $55 | $54;
     $57 = $56 | $53;
     HEAP32[$$05157>>2] = $57;
     $58 = ((($$05256)) + 4|0);
     $59 = ((($$05157)) + 4|0);
     $60 = ($41|0)==(0);
     if ($60) {
      break;
     } else {
      $$05157 = $59;$$05256 = $58;$$in = $41;
     }
    }
    $$pre71 = HEAP32[$12>>2]|0;
    $68 = $$pre71;
   }
   $61 = HEAP32[$18>>2]|0;
   $62 = (($63) + ($61)|0);
   $64 = HEAP32[$19>>2]|0;
   $65 = (($66) + ($64)|0);
   $67 = (($68) + -1)|0;
   HEAP32[$12>>2] = $67;
   $69 = ($68|0)==(0);
   if ($69) {
    $$lcssa77$sink = $62;$$lcssa78$sink = $65;
    break;
   } else {
    $63 = $62;$66 = $65;$73 = $67;$74 = $65;$75 = $62;
   }
  }
 }
 HEAP32[$0>>2] = $$lcssa77$sink;
 HEAP32[$16>>2] = $$lcssa78$sink;
 return;
}
function _SDL_Blit_RGB888_RGB888_Modulate_Scale($0) {
 $0 = $0|0;
 var $$078104 = 0, $$078104$us = 0, $$079103 = 0, $$079103$us = 0, $$081102 = 0, $$081102$us = 0, $$083108 = 0, $$085101 = 0, $$085101$us = 0, $$088107 = 0, $$1 = 0, $$1$us = 0, $$184$lcssa = 0, $$189$lcssa = 0, $$2 = 0, $$2$us = 0, $$287 = 0, $$287$us = 0, $$pre = 0, $$pre118 = 0;
 var $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = ((($0)) + 61|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = ((($0)) + 62|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = ((($0)) + 8|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13 << 16;
 $15 = ((($0)) + 28|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($14|0) / ($16|0))&-1;
 $18 = ((($0)) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = $19 << 16;
 $21 = ((($0)) + 24|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($20|0) / ($22|0))&-1;
 $24 = (($16) + -1)|0;
 HEAP32[$15>>2] = $24;
 $25 = ($16|0)==(0);
 if ($25) {
  return;
 }
 $26 = ((($0)) + 20|0);
 $27 = ((($0)) + 32|0);
 $28 = $2 & 1;
 $29 = ($28|0)==(0);
 $30 = ((($0)) + 12|0);
 $$pre = HEAP32[$26>>2]|0;
 $$083108 = 0;$$088107 = 0;$102 = $$pre;$39 = $22;$97 = $$pre;
 while(1) {
  $31 = ($$083108|0)>(65535);
  if ($31) {
   $32 = (($$083108) + -65536)|0;
   $33 = $32 >>> 16;
   $34 = $33 << 16;
   $35 = (($$088107) + 1)|0;
   $36 = (($35) + ($33))|0;
   $37 = (($32) - ($34))|0;
   $$184$lcssa = $37;$$189$lcssa = $36;
  } else {
   $$184$lcssa = $$083108;$$189$lcssa = $$088107;
  }
  $38 = (($39) + -1)|0;
  $40 = ($39|0)==(0);
  if (!($40)) {
   if ($29) {
    $$078104$us = $102;$$079103$us = 0;$$081102$us = 65536;$$085101$us = -1;$59 = $38;
    while(1) {
     $41 = ($$081102$us|0)>(65535);
     if ($41) {
      $42 = (($$081102$us) + -65536)|0;
      $43 = $42 >>> 16;
      $44 = $43 << 16;
      $45 = (($$085101$us) + 1)|0;
      $46 = (($45) + ($43))|0;
      $47 = (($42) - ($44))|0;
      $48 = HEAP32[$0>>2]|0;
      $49 = HEAP32[$30>>2]|0;
      $50 = Math_imul($49, $$189$lcssa)|0;
      $51 = (($48) + ($50)|0);
      $52 = $46 << 2;
      $53 = (($51) + ($52)|0);
      $$1$us = $53;$$2$us = $47;$$287$us = $46;
     } else {
      $$1$us = $$079103$us;$$2$us = $$081102$us;$$287$us = $$085101$us;
     }
     $54 = HEAP32[$$1$us>>2]|0;
     $55 = $54 & 16777215;
     HEAP32[$$078104$us>>2] = $55;
     $56 = (($$2$us) + ($23))|0;
     $57 = ((($$078104$us)) + 4|0);
     $58 = (($59) + -1)|0;
     $60 = ($59|0)==(0);
     if ($60) {
      break;
     } else {
      $$078104$us = $57;$$079103$us = $$1$us;$$081102$us = $56;$$085101$us = $$287$us;$59 = $58;
     }
    }
   } else {
    $$078104 = $102;$$079103 = 0;$$081102 = 65536;$$085101 = -1;$93 = $38;
    while(1) {
     $61 = ($$081102|0)>(65535);
     if ($61) {
      $62 = (($$081102) + -65536)|0;
      $63 = $62 >>> 16;
      $64 = $63 << 16;
      $65 = (($$085101) + 1)|0;
      $66 = (($65) + ($63))|0;
      $67 = (($62) - ($64))|0;
      $68 = HEAP32[$0>>2]|0;
      $69 = HEAP32[$30>>2]|0;
      $70 = Math_imul($69, $$189$lcssa)|0;
      $71 = (($68) + ($70)|0);
      $72 = $66 << 2;
      $73 = (($71) + ($72)|0);
      $$1 = $73;$$2 = $67;$$287 = $66;
     } else {
      $$1 = $$079103;$$2 = $$081102;$$287 = $$085101;
     }
     $74 = HEAP32[$$1>>2]|0;
     $75 = $74 >>> 16;
     $76 = $75 & 255;
     $77 = $74 >>> 8;
     $78 = $77 & 255;
     $79 = $74 & 255;
     $80 = Math_imul($79, $11)|0;
     $81 = Math_imul($78, $8)|0;
     $82 = Math_imul($76, $5)|0;
     $83 = (($82>>>0) / 255)&-1;
     $84 = (($81>>>0) / 255)&-1;
     $85 = (($80>>>0) / 255)&-1;
     $86 = $83 << 16;
     $87 = $84 << 8;
     $88 = $85 | $87;
     $89 = $88 | $86;
     HEAP32[$$078104>>2] = $89;
     $90 = (($$2) + ($23))|0;
     $91 = ((($$078104)) + 4|0);
     $92 = (($93) + -1)|0;
     $94 = ($93|0)==(0);
     if ($94) {
      break;
     } else {
      $$078104 = $91;$$079103 = $$1;$$081102 = $90;$$085101 = $$287;$93 = $92;
     }
    }
   }
  }
  $95 = HEAP32[$27>>2]|0;
  $96 = (($97) + ($95)|0);
  $98 = HEAP32[$15>>2]|0;
  $99 = (($98) + -1)|0;
  HEAP32[$15>>2] = $99;
  $100 = ($98|0)==(0);
  if ($100) {
   break;
  }
  $101 = (($$184$lcssa) + ($17))|0;
  $$pre118 = HEAP32[$21>>2]|0;
  $$083108 = $101;$$088107 = $$189$lcssa;$102 = $96;$39 = $$pre118;$97 = $96;
 }
 HEAP32[$26>>2] = $96;
 return;
}
function _SDL_Blit_RGB888_RGB888_Modulate_Blend($0) {
 $0 = $0|0;
 var $$ = 0, $$$us = 0, $$0107121 = 0, $$0107121$us = 0, $$0108120 = 0, $$0108120$us = 0, $$0109 = 0, $$0109$us = 0, $$0110 = 0, $$0110$us = 0, $$0111 = 0, $$0111$us = 0, $$1 = 0, $$1$us = 0, $$1114 = 0, $$1114$us = 0, $$1116 = 0, $$1116$us = 0, $$1118 = 0, $$1118$us = 0;
 var $$119 = 0, $$3 = 0, $$3$us = 0, $$pre = 0, $$pre126 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $trunc = 0, $trunc$clear = 0, $trunc$clear1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = ((($0)) + 61|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = ((($0)) + 62|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = ((($0)) + 63|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = ((($0)) + 28|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($15) + -1)|0;
 HEAP32[$14>>2] = $16;
 $17 = ($15|0)==(0);
 if ($17) {
  return;
 }
 $18 = $13&255;
 $19 = ((($0)) + 20|0);
 $20 = ((($0)) + 24|0);
 $21 = ((($0)) + 12|0);
 $22 = ((($0)) + 32|0);
 $23 = $2 & 1;
 $24 = ($23|0)==(0);
 $25 = $2 & 2;
 $26 = ($25|0)==(0);
 $$119 = $26 ? 255 : $18;
 $27 = $2 & 48;
 $28 = ($27|0)!=(0);
 $29 = ($$119|0)!=(255);
 $or$cond = $28 & $29;
 $30 = $2 & 112;
 $trunc = $30&255;
 $31 = $$119 ^ 255;
 $$pre = HEAP32[$0>>2]|0;
 $$pre126 = HEAP32[$19>>2]|0;
 $139 = $$pre;$142 = $$pre126;$146 = $$pre126;$147 = $$pre;
 while(1) {
  $32 = HEAP32[$20>>2]|0;
  $33 = (($32) + -1)|0;
  $34 = ($32|0)==(0);
  L6: do {
   if (!($34)) {
    if ($24) {
     $$0107121$us = $146;$$0108120$us = $147;$81 = $33;
     while(1) {
      $35 = HEAP32[$$0108120$us>>2]|0;
      $36 = $35 >>> 16;
      $37 = $36 & 255;
      $38 = $35 >>> 8;
      $39 = $38 & 255;
      $40 = $35 & 255;
      $41 = HEAP32[$$0107121$us>>2]|0;
      $42 = $41 >>> 16;
      $43 = $42 & 255;
      $44 = $41 >>> 8;
      $45 = $44 & 255;
      $46 = $41 & 255;
      if ($or$cond) {
       $47 = Math_imul($40, $$119)|0;
       $48 = Math_imul($39, $$119)|0;
       $49 = Math_imul($37, $$119)|0;
       $50 = (($49>>>0) / 255)&-1;
       $51 = (($48>>>0) / 255)&-1;
       $52 = (($47>>>0) / 255)&-1;
       $$1114$us = $52;$$1116$us = $51;$$1118$us = $50;
      } else {
       $$1114$us = $40;$$1116$us = $39;$$1118$us = $37;
      }
      $trunc$clear = $trunc & 127;
      switch ($trunc$clear<<24>>24) {
      case 16:  {
       $65 = Math_imul($43, $31)|0;
       $66 = (($65>>>0) / 255)&-1;
       $67 = (($$1118$us) + ($66))|0;
       $68 = Math_imul($45, $31)|0;
       $69 = (($68>>>0) / 255)&-1;
       $70 = (($$1116$us) + ($69))|0;
       $71 = Math_imul($46, $31)|0;
       $72 = (($71>>>0) / 255)&-1;
       $73 = (($$1114$us) + ($72))|0;
       $$0109$us = $73;$$0110$us = $70;$$0111$us = $67;
       break;
      }
      case 32:  {
       $59 = (($$1118$us) + ($43))|0;
       $60 = ($59>>>0)<(255);
       $$$us = $60 ? $59 : 255;
       $61 = (($$1116$us) + ($45))|0;
       $62 = ($61>>>0)<(255);
       $$3$us = $62 ? $61 : 255;
       $63 = (($$1114$us) + ($46))|0;
       $64 = ($63>>>0)<(255);
       $$1$us = $64 ? $63 : 255;
       $$0109$us = $$1$us;$$0110$us = $$3$us;$$0111$us = $$$us;
       break;
      }
      case 64:  {
       $53 = Math_imul($$1118$us, $43)|0;
       $54 = (($53>>>0) / 255)&-1;
       $55 = Math_imul($$1116$us, $45)|0;
       $56 = (($55>>>0) / 255)&-1;
       $57 = Math_imul($$1114$us, $46)|0;
       $58 = (($57>>>0) / 255)&-1;
       $$0109$us = $58;$$0110$us = $56;$$0111$us = $54;
       break;
      }
      default: {
       $$0109$us = $46;$$0110$us = $45;$$0111$us = $43;
      }
      }
      $74 = $$0111$us << 16;
      $75 = $$0110$us << 8;
      $76 = $75 | $74;
      $77 = $76 | $$0109$us;
      HEAP32[$$0107121$us>>2] = $77;
      $78 = ((($$0108120$us)) + 4|0);
      $79 = ((($$0107121$us)) + 4|0);
      $80 = (($81) + -1)|0;
      $82 = ($81|0)==(0);
      if ($82) {
       break L6;
      } else {
       $$0107121$us = $79;$$0108120$us = $78;$81 = $80;
      }
     }
    } else {
     $$0107121 = $146;$$0108120 = $147;$135 = $33;
     while(1) {
      $83 = HEAP32[$$0108120>>2]|0;
      $84 = $83 >>> 16;
      $85 = $84 & 255;
      $86 = $83 >>> 8;
      $87 = $86 & 255;
      $88 = $83 & 255;
      $89 = HEAP32[$$0107121>>2]|0;
      $90 = $89 >>> 16;
      $91 = $90 & 255;
      $92 = $89 >>> 8;
      $93 = $92 & 255;
      $94 = $89 & 255;
      $95 = Math_imul($88, $11)|0;
      $96 = Math_imul($87, $8)|0;
      $97 = Math_imul($85, $5)|0;
      $98 = (($97>>>0) / 255)&-1;
      $99 = (($96>>>0) / 255)&-1;
      $100 = (($95>>>0) / 255)&-1;
      if ($or$cond) {
       $101 = Math_imul($100, $$119)|0;
       $102 = Math_imul($99, $$119)|0;
       $103 = Math_imul($98, $$119)|0;
       $104 = (($103>>>0) / 255)&-1;
       $105 = (($102>>>0) / 255)&-1;
       $106 = (($101>>>0) / 255)&-1;
       $$1114 = $106;$$1116 = $105;$$1118 = $104;
      } else {
       $$1114 = $100;$$1116 = $99;$$1118 = $98;
      }
      $trunc$clear1 = $trunc & 127;
      switch ($trunc$clear1<<24>>24) {
      case 16:  {
       $107 = Math_imul($91, $31)|0;
       $108 = (($107>>>0) / 255)&-1;
       $109 = (($$1118) + ($108))|0;
       $110 = Math_imul($93, $31)|0;
       $111 = (($110>>>0) / 255)&-1;
       $112 = (($$1116) + ($111))|0;
       $113 = Math_imul($94, $31)|0;
       $114 = (($113>>>0) / 255)&-1;
       $115 = (($$1114) + ($114))|0;
       $$0109 = $115;$$0110 = $112;$$0111 = $109;
       break;
      }
      case 32:  {
       $116 = (($$1118) + ($91))|0;
       $117 = ($116>>>0)<(255);
       $$ = $117 ? $116 : 255;
       $118 = (($$1116) + ($93))|0;
       $119 = ($118>>>0)<(255);
       $$3 = $119 ? $118 : 255;
       $120 = (($$1114) + ($94))|0;
       $121 = ($120>>>0)<(255);
       $$1 = $121 ? $120 : 255;
       $$0109 = $$1;$$0110 = $$3;$$0111 = $$;
       break;
      }
      case 64:  {
       $122 = Math_imul($$1118, $91)|0;
       $123 = (($122>>>0) / 255)&-1;
       $124 = Math_imul($$1116, $93)|0;
       $125 = (($124>>>0) / 255)&-1;
       $126 = Math_imul($$1114, $94)|0;
       $127 = (($126>>>0) / 255)&-1;
       $$0109 = $127;$$0110 = $125;$$0111 = $123;
       break;
      }
      default: {
       $$0109 = $94;$$0110 = $93;$$0111 = $91;
      }
      }
      $128 = $$0111 << 16;
      $129 = $$0110 << 8;
      $130 = $129 | $128;
      $131 = $130 | $$0109;
      HEAP32[$$0107121>>2] = $131;
      $132 = ((($$0108120)) + 4|0);
      $133 = ((($$0107121)) + 4|0);
      $134 = (($135) + -1)|0;
      $136 = ($135|0)==(0);
      if ($136) {
       break L6;
      } else {
       $$0107121 = $133;$$0108120 = $132;$135 = $134;
      }
     }
    }
   }
  } while(0);
  $137 = HEAP32[$21>>2]|0;
  $138 = (($139) + ($137)|0);
  $140 = HEAP32[$22>>2]|0;
  $141 = (($142) + ($140)|0);
  $143 = HEAP32[$14>>2]|0;
  $144 = (($143) + -1)|0;
  HEAP32[$14>>2] = $144;
  $145 = ($143|0)==(0);
  if ($145) {
   break;
  } else {
   $139 = $138;$142 = $141;$146 = $141;$147 = $138;
  }
 }
 HEAP32[$0>>2] = $138;
 HEAP32[$19>>2] = $141;
 return;
}
function _SDL_Blit_RGB888_RGB888_Modulate_Blend_Scale($0) {
 $0 = $0|0;
 var $$ = 0, $$0134169 = 0, $$0135168 = 0, $$0137 = 0, $$0139 = 0, $$0141167 = 0, $$0143173 = 0, $$0145166 = 0, $$0148172 = 0, $$0150 = 0, $$0151 = 0, $$0152 = 0, $$0154 = 0, $$1 = 0, $$1136 = 0, $$1138 = 0, $$1140 = 0, $$1144$lcssa = 0, $$1149$lcssa = 0, $$1155 = 0;
 var $$156 = 0, $$2 = 0, $$2147 = 0, $$3 = 0, $$in = 0, $$pre = 0, $$pre180 = 0, $$pre181 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $trunc = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = ((($0)) + 61|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = ((($0)) + 62|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = ((($0)) + 63|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = ((($0)) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = $15 << 16;
 $17 = ((($0)) + 28|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($16|0) / ($18|0))&-1;
 $20 = ((($0)) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = $21 << 16;
 $23 = ((($0)) + 24|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (($22|0) / ($24|0))&-1;
 $26 = (($18) + -1)|0;
 HEAP32[$17>>2] = $26;
 $27 = ($18|0)==(0);
 if ($27) {
  return;
 }
 $28 = $13&255;
 $29 = ((($0)) + 20|0);
 $30 = ((($0)) + 32|0);
 $31 = $2 & 1;
 $32 = ($31|0)==(0);
 $33 = $2 & 2;
 $34 = ($33|0)==(0);
 $$156 = $34 ? 255 : $28;
 $35 = $2 & 48;
 $36 = ($35|0)!=(0);
 $37 = ($$156|0)!=(255);
 $or$cond = $36 & $37;
 $38 = $2 & 112;
 $trunc = $38&255;
 $39 = $$156 ^ 255;
 $40 = ((($0)) + 12|0);
 $$pre = HEAP32[$29>>2]|0;
 $$0143173 = 0;$$0148172 = 0;$118 = $$pre;$123 = $26;$124 = $$pre;$48 = $24;
 while(1) {
  $41 = ($$0143173|0)>(65535);
  if ($41) {
   $42 = (($$0143173) + -65536)|0;
   $43 = $42 >>> 16;
   $44 = $43 << 16;
   $45 = (($$0148172) + 1)|0;
   $46 = (($45) + ($43))|0;
   $47 = (($42) - ($44))|0;
   $$1144$lcssa = $47;$$1149$lcssa = $46;
  } else {
   $$1144$lcssa = $$0143173;$$1149$lcssa = $$0148172;
  }
  $49 = ($48|0)==(0);
  if ($49) {
   $120 = $123;
  } else {
   $$0134169 = $124;$$0135168 = 0;$$0141167 = 65536;$$0145166 = -1;$$in = $48;
   while(1) {
    $50 = (($$in) + -1)|0;
    $51 = ($$0141167|0)>(65535);
    if ($51) {
     $52 = (($$0141167) + -65536)|0;
     $53 = $52 >>> 16;
     $54 = $53 << 16;
     $55 = (($$0145166) + 1)|0;
     $56 = (($55) + ($53))|0;
     $57 = (($52) - ($54))|0;
     $58 = HEAP32[$0>>2]|0;
     $59 = HEAP32[$40>>2]|0;
     $60 = Math_imul($59, $$1149$lcssa)|0;
     $61 = (($58) + ($60)|0);
     $62 = $56 << 2;
     $63 = (($61) + ($62)|0);
     $$1136 = $63;$$2 = $57;$$2147 = $56;
    } else {
     $$1136 = $$0135168;$$2 = $$0141167;$$2147 = $$0145166;
    }
    $64 = HEAP32[$$1136>>2]|0;
    $65 = $64 >>> 16;
    $66 = $65 & 255;
    $67 = $64 >>> 8;
    $68 = $67 & 255;
    $69 = $64 & 255;
    $70 = HEAP32[$$0134169>>2]|0;
    $71 = $70 >>> 16;
    $72 = $71 & 255;
    $73 = $70 >>> 8;
    $74 = $73 & 255;
    $75 = $70 & 255;
    if ($32) {
     $$0137 = $66;$$0139 = $68;$$0154 = $69;
    } else {
     $76 = Math_imul($69, $11)|0;
     $77 = Math_imul($68, $8)|0;
     $78 = Math_imul($66, $5)|0;
     $79 = (($78>>>0) / 255)&-1;
     $80 = (($77>>>0) / 255)&-1;
     $81 = (($76>>>0) / 255)&-1;
     $$0137 = $79;$$0139 = $80;$$0154 = $81;
    }
    if ($or$cond) {
     $82 = Math_imul($$0154, $$156)|0;
     $83 = Math_imul($$0139, $$156)|0;
     $84 = Math_imul($$0137, $$156)|0;
     $85 = (($84>>>0) / 255)&-1;
     $86 = (($83>>>0) / 255)&-1;
     $87 = (($82>>>0) / 255)&-1;
     $$1138 = $85;$$1140 = $86;$$1155 = $87;
    } else {
     $$1138 = $$0137;$$1140 = $$0139;$$1155 = $$0154;
    }
    $trunc$clear = $trunc & 127;
    switch ($trunc$clear<<24>>24) {
    case 16:  {
     $88 = Math_imul($72, $39)|0;
     $89 = (($88>>>0) / 255)&-1;
     $90 = (($$1138) + ($89))|0;
     $91 = Math_imul($74, $39)|0;
     $92 = (($91>>>0) / 255)&-1;
     $93 = (($$1140) + ($92))|0;
     $94 = Math_imul($75, $39)|0;
     $95 = (($94>>>0) / 255)&-1;
     $96 = (($$1155) + ($95))|0;
     $$0150 = $96;$$0151 = $93;$$0152 = $90;
     break;
    }
    case 32:  {
     $97 = (($$1138) + ($72))|0;
     $98 = ($97>>>0)<(255);
     $$ = $98 ? $97 : 255;
     $99 = (($$1140) + ($74))|0;
     $100 = ($99>>>0)<(255);
     $$3 = $100 ? $99 : 255;
     $101 = (($$1155) + ($75))|0;
     $102 = ($101>>>0)<(255);
     $$1 = $102 ? $101 : 255;
     $$0150 = $$1;$$0151 = $$3;$$0152 = $$;
     break;
    }
    case 64:  {
     $103 = Math_imul($$1138, $72)|0;
     $104 = (($103>>>0) / 255)&-1;
     $105 = Math_imul($$1140, $74)|0;
     $106 = (($105>>>0) / 255)&-1;
     $107 = Math_imul($$1155, $75)|0;
     $108 = (($107>>>0) / 255)&-1;
     $$0150 = $108;$$0151 = $106;$$0152 = $104;
     break;
    }
    default: {
     $$0150 = $75;$$0151 = $74;$$0152 = $72;
    }
    }
    $109 = $$0152 << 16;
    $110 = $$0151 << 8;
    $111 = $110 | $109;
    $112 = $111 | $$0150;
    HEAP32[$$0134169>>2] = $112;
    $113 = (($$2) + ($25))|0;
    $114 = ((($$0134169)) + 4|0);
    $115 = ($50|0)==(0);
    if ($115) {
     break;
    } else {
     $$0134169 = $114;$$0135168 = $$1136;$$0141167 = $113;$$0145166 = $$2147;$$in = $50;
    }
   }
   $$pre181 = HEAP32[$17>>2]|0;
   $120 = $$pre181;
  }
  $116 = HEAP32[$30>>2]|0;
  $117 = (($118) + ($116)|0);
  $119 = (($120) + -1)|0;
  HEAP32[$17>>2] = $119;
  $121 = ($120|0)==(0);
  if ($121) {
   break;
  }
  $122 = (($$1144$lcssa) + ($19))|0;
  $$pre180 = HEAP32[$23>>2]|0;
  $$0143173 = $122;$$0148172 = $$1149$lcssa;$118 = $117;$123 = $119;$124 = $117;$48 = $$pre180;
 }
 HEAP32[$29>>2] = $117;
 return;
}
function _SDL_Blit_RGB888_BGR888_Scale($0) {
 $0 = $0|0;
 var $$05982 = 0, $$06081 = 0, $$06186 = 0, $$06380 = 0, $$06579 = 0, $$06885 = 0, $$1 = 0, $$162$lcssa = 0, $$169$lcssa = 0, $$2 = 0, $$267 = 0, $$in = 0, $$pre = 0, $$pre93 = 0, $$pre94 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 << 16;
 $4 = ((($0)) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3|0) / ($5|0))&-1;
 $7 = ((($0)) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 << 16;
 $10 = ((($0)) + 24|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($9|0) / ($11|0))&-1;
 $13 = (($5) + -1)|0;
 HEAP32[$4>>2] = $13;
 $14 = ($5|0)==(0);
 if ($14) {
  return;
 }
 $15 = ((($0)) + 20|0);
 $16 = ((($0)) + 32|0);
 $17 = ((($0)) + 12|0);
 $$pre = HEAP32[$15>>2]|0;
 $$06186 = 0;$$06885 = 0;$25 = $11;$54 = $$pre;$59 = $13;$60 = $$pre;
 while(1) {
  $18 = ($$06885|0)>(65535);
  if ($18) {
   $19 = (($$06885) + -65536)|0;
   $20 = $19 >>> 16;
   $21 = $20 << 16;
   $22 = (($$06186) + 1)|0;
   $23 = (($22) + ($20))|0;
   $24 = (($19) - ($21))|0;
   $$162$lcssa = $23;$$169$lcssa = $24;
  } else {
   $$162$lcssa = $$06186;$$169$lcssa = $$06885;
  }
  $26 = ($25|0)==(0);
  if ($26) {
   $56 = $59;
  } else {
   $$05982 = $60;$$06081 = 0;$$06380 = -1;$$06579 = 65536;$$in = $25;
   while(1) {
    $27 = (($$in) + -1)|0;
    $28 = ($$06579|0)>(65535);
    if ($28) {
     $29 = (($$06579) + -65536)|0;
     $30 = $29 >>> 16;
     $31 = $30 << 16;
     $32 = (($$06380) + 1)|0;
     $33 = (($32) + ($30))|0;
     $34 = (($29) - ($31))|0;
     $35 = HEAP32[$0>>2]|0;
     $36 = HEAP32[$17>>2]|0;
     $37 = Math_imul($36, $$162$lcssa)|0;
     $38 = (($35) + ($37)|0);
     $39 = $33 << 2;
     $40 = (($38) + ($39)|0);
     $$1 = $40;$$2 = $33;$$267 = $34;
    } else {
     $$1 = $$06081;$$2 = $$06380;$$267 = $$06579;
    }
    $41 = HEAP32[$$1>>2]|0;
    $42 = $41 >>> 16;
    $43 = $42 & 255;
    $44 = $41 & 65280;
    $45 = $41 << 16;
    $46 = $45 & 16711680;
    $47 = $46 | $44;
    $48 = $47 | $43;
    HEAP32[$$05982>>2] = $48;
    $49 = (($$267) + ($12))|0;
    $50 = ((($$05982)) + 4|0);
    $51 = ($27|0)==(0);
    if ($51) {
     break;
    } else {
     $$05982 = $50;$$06081 = $$1;$$06380 = $$2;$$06579 = $49;$$in = $27;
    }
   }
   $$pre94 = HEAP32[$4>>2]|0;
   $56 = $$pre94;
  }
  $52 = HEAP32[$16>>2]|0;
  $53 = (($54) + ($52)|0);
  $55 = (($56) + -1)|0;
  HEAP32[$4>>2] = $55;
  $57 = ($56|0)==(0);
  if ($57) {
   break;
  }
  $58 = (($$169$lcssa) + ($6))|0;
  $$pre93 = HEAP32[$10>>2]|0;
  $$06186 = $$162$lcssa;$$06885 = $58;$25 = $$pre93;$54 = $53;$59 = $55;$60 = $53;
 }
 HEAP32[$15>>2] = $53;
 return;
}
function _SDL_Blit_RGB888_BGR888_Blend($0) {
 $0 = $0|0;
 var $$$us97 = 0, $$08594 = 0, $$08594$us = 0, $$08594$us95 = 0, $$08693 = 0, $$08693$us = 0, $$08693$us96 = 0, $$087 = 0, $$088 = 0, $$089 = 0, $$1$us99 = 0, $$3$us98 = 0, $$pre = 0, $$pre110 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $cond = 0, $trunc = 0, $trunc$clear = 0, $trunc$clear1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + -1)|0;
 HEAP32[$3>>2] = $5;
 $6 = ($4|0)==(0);
 if ($6) {
  return;
 }
 $7 = ((($0)) + 20|0);
 $8 = ((($0)) + 24|0);
 $9 = ((($0)) + 12|0);
 $10 = ((($0)) + 32|0);
 $11 = $2 & 112;
 $trunc = $11&255;
 $$pre = HEAP32[$0>>2]|0;
 $$pre110 = HEAP32[$7>>2]|0;
 $trunc$clear = $trunc & 127;
 $cond = ($trunc$clear<<24>>24)==(64);
 $84 = $$pre;$87 = $$pre110;$91 = $$pre110;$92 = $$pre;
 while(1) {
  $12 = HEAP32[$8>>2]|0;
  $13 = (($12) + -1)|0;
  $14 = ($12|0)==(0);
  if (!($14)) {
   $trunc$clear1 = $trunc & 127;
   switch ($trunc$clear1<<24>>24) {
   case 16:  {
    $$08594$us = $91;$$08693$us = $92;$26 = $13;
    while(1) {
     $15 = HEAP32[$$08693$us>>2]|0;
     $16 = $15 >>> 16;
     $17 = $16 & 255;
     $18 = $15 & 65280;
     $19 = $15 << 16;
     $20 = $19 & 16711680;
     $21 = $18 | $17;
     $22 = $21 | $20;
     HEAP32[$$08594$us>>2] = $22;
     $23 = ((($$08693$us)) + 4|0);
     $24 = ((($$08594$us)) + 4|0);
     $25 = (($26) + -1)|0;
     $27 = ($26|0)==(0);
     if ($27) {
      break;
     } else {
      $$08594$us = $24;$$08693$us = $23;$26 = $25;
     }
    }
    break;
   }
   case 32:  {
    $$08594$us95 = $91;$$08693$us96 = $92;$53 = $13;
    while(1) {
     $28 = HEAP32[$$08693$us96>>2]|0;
     $29 = $28 >>> 16;
     $30 = $29 & 255;
     $31 = $28 >>> 8;
     $32 = $31 & 255;
     $33 = $28 & 255;
     $34 = HEAP32[$$08594$us95>>2]|0;
     $35 = $34 >>> 16;
     $36 = $35 & 255;
     $37 = $34 >>> 8;
     $38 = $37 & 255;
     $39 = $34 & 255;
     $40 = (($30) + ($39))|0;
     $41 = ($40>>>0)<(255);
     $$$us97 = $41 ? $40 : 255;
     $42 = (($38) + ($32))|0;
     $43 = ($42>>>0)<(255);
     $$3$us98 = $43 ? $42 : 255;
     $44 = (($36) + ($33))|0;
     $45 = ($44>>>0)<(255);
     $$1$us99 = $45 ? $44 : 255;
     $46 = $$1$us99 << 16;
     $47 = $$3$us98 << 8;
     $48 = $47 | $$$us97;
     $49 = $48 | $46;
     HEAP32[$$08594$us95>>2] = $49;
     $50 = ((($$08693$us96)) + 4|0);
     $51 = ((($$08594$us95)) + 4|0);
     $52 = (($53) + -1)|0;
     $54 = ($53|0)==(0);
     if ($54) {
      break;
     } else {
      $$08594$us95 = $51;$$08693$us96 = $50;$53 = $52;
     }
    }
    break;
   }
   default: {
    $$08594 = $91;$$08693 = $92;$80 = $13;
    while(1) {
     $55 = HEAP32[$$08693>>2]|0;
     $56 = HEAP32[$$08594>>2]|0;
     $57 = $56 >>> 16;
     $58 = $57 & 255;
     $59 = $56 >>> 8;
     $60 = $59 & 255;
     $61 = $56 & 255;
     if ($cond) {
      $62 = $55 & 255;
      $63 = $55 >>> 8;
      $64 = $63 & 255;
      $65 = $55 >>> 16;
      $66 = $65 & 255;
      $67 = Math_imul($66, $61)|0;
      $68 = (($67>>>0) / 255)&-1;
      $69 = Math_imul($60, $64)|0;
      $70 = (($69>>>0) / 255)&-1;
      $71 = Math_imul($58, $62)|0;
      $72 = (($71>>>0) / 255)&-1;
      $$087 = $72;$$088 = $70;$$089 = $68;
     } else {
      $$087 = $58;$$088 = $60;$$089 = $61;
     }
     $73 = $$087 << 16;
     $74 = $$088 << 8;
     $75 = $74 | $$089;
     $76 = $75 | $73;
     HEAP32[$$08594>>2] = $76;
     $77 = ((($$08693)) + 4|0);
     $78 = ((($$08594)) + 4|0);
     $79 = (($80) + -1)|0;
     $81 = ($80|0)==(0);
     if ($81) {
      break;
     } else {
      $$08594 = $78;$$08693 = $77;$80 = $79;
     }
    }
   }
   }
  }
  $82 = HEAP32[$9>>2]|0;
  $83 = (($84) + ($82)|0);
  $85 = HEAP32[$10>>2]|0;
  $86 = (($87) + ($85)|0);
  $88 = HEAP32[$3>>2]|0;
  $89 = (($88) + -1)|0;
  HEAP32[$3>>2] = $89;
  $90 = ($88|0)==(0);
  if ($90) {
   break;
  } else {
   $84 = $83;$87 = $86;$91 = $86;$92 = $83;
  }
 }
 HEAP32[$0>>2] = $83;
 HEAP32[$7>>2] = $86;
 return;
}
function _SDL_Blit_RGB888_BGR888_Blend_Scale($0) {
 $0 = $0|0;
 var $$ = 0, $$0112142 = 0, $$0112142$us = 0, $$0113141 = 0, $$0113141$us = 0, $$0117140 = 0, $$0117140$us = 0, $$0119146 = 0, $$0121139 = 0, $$0121139$us = 0, $$0124145 = 0, $$0126 = 0, $$0127 = 0, $$0128 = 0, $$1 = 0, $$1114 = 0, $$1114$us = 0, $$1120$lcssa = 0, $$1125$lcssa = 0, $$2 = 0;
 var $$2$us = 0, $$2123 = 0, $$2123$us = 0, $$3 = 0, $$pre = 0, $$pre156 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $trunc = 0, $trunc$clear = 0, $trunc$clear1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 << 16;
 $6 = ((($0)) + 28|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5|0) / ($7|0))&-1;
 $9 = ((($0)) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10 << 16;
 $12 = ((($0)) + 24|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($11|0) / ($13|0))&-1;
 $15 = (($7) + -1)|0;
 HEAP32[$6>>2] = $15;
 $16 = ($7|0)==(0);
 if ($16) {
  return;
 }
 $17 = ((($0)) + 20|0);
 $18 = ((($0)) + 32|0);
 $19 = $2 & 112;
 $trunc = $19&255;
 $20 = ((($0)) + 12|0);
 $trunc$clear = $trunc & 127;
 $21 = ($trunc$clear<<24>>24)==(16);
 $$pre = HEAP32[$17>>2]|0;
 $$0119146 = 0;$$0124145 = 0;$106 = $$pre;$111 = $$pre;$30 = $13;
 while(1) {
  $22 = ($$0119146|0)>(65535);
  if ($22) {
   $23 = (($$0119146) + -65536)|0;
   $24 = $23 >>> 16;
   $25 = $24 << 16;
   $26 = (($$0124145) + 1)|0;
   $27 = (($26) + ($24))|0;
   $28 = (($23) - ($25))|0;
   $$1120$lcssa = $28;$$1125$lcssa = $27;
  } else {
   $$1120$lcssa = $$0119146;$$1125$lcssa = $$0124145;
  }
  $29 = (($30) + -1)|0;
  $31 = ($30|0)==(0);
  L9: do {
   if (!($31)) {
    if ($21) {
     $$0112142$us = $111;$$0113141$us = 0;$$0117140$us = 65536;$$0121139$us = -1;$56 = $29;
     while(1) {
      $32 = ($$0117140$us|0)>(65535);
      if ($32) {
       $33 = (($$0117140$us) + -65536)|0;
       $34 = $33 >>> 16;
       $35 = $34 << 16;
       $36 = (($$0121139$us) + 1)|0;
       $37 = (($36) + ($34))|0;
       $38 = (($33) - ($35))|0;
       $39 = HEAP32[$0>>2]|0;
       $40 = HEAP32[$20>>2]|0;
       $41 = Math_imul($40, $$1125$lcssa)|0;
       $42 = (($39) + ($41)|0);
       $43 = $37 << 2;
       $44 = (($42) + ($43)|0);
       $$1114$us = $44;$$2$us = $38;$$2123$us = $37;
      } else {
       $$1114$us = $$0113141$us;$$2$us = $$0117140$us;$$2123$us = $$0121139$us;
      }
      $45 = HEAP32[$$1114$us>>2]|0;
      $46 = $45 >>> 16;
      $47 = $46 & 255;
      $48 = $45 & 65280;
      $49 = $45 << 16;
      $50 = $49 & 16711680;
      $51 = $48 | $47;
      $52 = $51 | $50;
      HEAP32[$$0112142$us>>2] = $52;
      $53 = (($$2$us) + ($14))|0;
      $54 = ((($$0112142$us)) + 4|0);
      $55 = (($56) + -1)|0;
      $57 = ($56|0)==(0);
      if ($57) {
       break L9;
      } else {
       $$0112142$us = $54;$$0113141$us = $$1114$us;$$0117140$us = $53;$$0121139$us = $$2123$us;$56 = $55;
      }
     }
    } else {
     $$0112142 = $111;$$0113141 = 0;$$0117140 = 65536;$$0121139 = -1;$102 = $29;
    }
    while(1) {
     $58 = ($$0117140|0)>(65535);
     if ($58) {
      $59 = (($$0117140) + -65536)|0;
      $60 = $59 >>> 16;
      $61 = $60 << 16;
      $62 = (($$0121139) + 1)|0;
      $63 = (($62) + ($60))|0;
      $64 = (($59) - ($61))|0;
      $65 = HEAP32[$0>>2]|0;
      $66 = HEAP32[$20>>2]|0;
      $67 = Math_imul($66, $$1125$lcssa)|0;
      $68 = (($65) + ($67)|0);
      $69 = $63 << 2;
      $70 = (($68) + ($69)|0);
      $$1114 = $70;$$2 = $64;$$2123 = $63;
     } else {
      $$1114 = $$0113141;$$2 = $$0117140;$$2123 = $$0121139;
     }
     $71 = HEAP32[$$1114>>2]|0;
     $72 = $71 >>> 16;
     $73 = $72 & 255;
     $74 = $71 >>> 8;
     $75 = $74 & 255;
     $76 = $71 & 255;
     $77 = HEAP32[$$0112142>>2]|0;
     $78 = $77 >>> 16;
     $79 = $78 & 255;
     $80 = $77 >>> 8;
     $81 = $80 & 255;
     $82 = $77 & 255;
     $trunc$clear1 = $trunc & 127;
     switch ($trunc$clear1<<24>>24) {
     case 64:  {
      $89 = Math_imul($73, $82)|0;
      $90 = (($89>>>0) / 255)&-1;
      $91 = Math_imul($81, $75)|0;
      $92 = (($91>>>0) / 255)&-1;
      $93 = Math_imul($79, $76)|0;
      $94 = (($93>>>0) / 255)&-1;
      $$0126 = $94;$$0127 = $92;$$0128 = $90;
      break;
     }
     case 32:  {
      $83 = (($73) + ($82))|0;
      $84 = ($83>>>0)<(255);
      $$ = $84 ? $83 : 255;
      $85 = (($81) + ($75))|0;
      $86 = ($85>>>0)<(255);
      $$3 = $86 ? $85 : 255;
      $87 = (($79) + ($76))|0;
      $88 = ($87>>>0)<(255);
      $$1 = $88 ? $87 : 255;
      $$0126 = $$1;$$0127 = $$3;$$0128 = $$;
      break;
     }
     default: {
      $$0126 = $79;$$0127 = $81;$$0128 = $82;
     }
     }
     $95 = $$0126 << 16;
     $96 = $$0127 << 8;
     $97 = $96 | $$0128;
     $98 = $97 | $95;
     HEAP32[$$0112142>>2] = $98;
     $99 = (($$2) + ($14))|0;
     $100 = ((($$0112142)) + 4|0);
     $101 = (($102) + -1)|0;
     $103 = ($102|0)==(0);
     if ($103) {
      break L9;
     } else {
      $$0112142 = $100;$$0113141 = $$1114;$$0117140 = $99;$$0121139 = $$2123;$102 = $101;
     }
    }
   }
  } while(0);
  $104 = HEAP32[$18>>2]|0;
  $105 = (($106) + ($104)|0);
  $107 = HEAP32[$6>>2]|0;
  $108 = (($107) + -1)|0;
  HEAP32[$6>>2] = $108;
  $109 = ($107|0)==(0);
  if ($109) {
   break;
  }
  $110 = (($$1120$lcssa) + ($8))|0;
  $$pre156 = HEAP32[$12>>2]|0;
  $$0119146 = $110;$$0124145 = $$1125$lcssa;$106 = $105;$111 = $105;$30 = $$pre156;
 }
 HEAP32[$17>>2] = $105;
 return;
}
function _SDL_Blit_RGB888_BGR888_Modulate($0) {
 $0 = $0|0;
 var $$05157 = 0, $$05157$us$us = 0, $$05256 = 0, $$05256$us$us = 0, $$in = 0, $$in68 = 0, $$lcssa77$sink = 0, $$lcssa78$sink = 0, $$pre71 = 0, $$pre72 = 0, $$pre73 = 0, $$pre74 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = ((($0)) + 61|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = ((($0)) + 62|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = ((($0)) + 28|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($13) + -1)|0;
 HEAP32[$12>>2] = $14;
 $15 = ($13|0)==(0);
 if ($15) {
  return;
 }
 $16 = ((($0)) + 20|0);
 $17 = ((($0)) + 24|0);
 $18 = ((($0)) + 12|0);
 $19 = ((($0)) + 32|0);
 $20 = $2 & 1;
 $21 = ($20|0)==(0);
 $$pre72 = HEAP32[$0>>2]|0;
 $$pre73 = HEAP32[$16>>2]|0;
 if ($21) {
  $26 = $$pre72;$29 = $$pre73;$76 = $14;$77 = $$pre73;$78 = $$pre72;
  while(1) {
   $22 = HEAP32[$17>>2]|0;
   $23 = ($22|0)==(0);
   if ($23) {
    $31 = $76;
   } else {
    $$05157$us$us = $77;$$05256$us$us = $78;$$in68 = $22;
    while(1) {
     $33 = (($$in68) + -1)|0;
     $34 = HEAP32[$$05256$us$us>>2]|0;
     $35 = $34 >>> 16;
     $36 = $35 & 255;
     $37 = $34 & 65280;
     $38 = $34 << 16;
     $39 = $38 & 16711680;
     $40 = $37 | $36;
     $41 = $40 | $39;
     HEAP32[$$05157$us$us>>2] = $41;
     $42 = ((($$05256$us$us)) + 4|0);
     $43 = ((($$05157$us$us)) + 4|0);
     $44 = ($33|0)==(0);
     if ($44) {
      break;
     } else {
      $$05157$us$us = $43;$$05256$us$us = $42;$$in68 = $33;
     }
    }
    $$pre74 = HEAP32[$12>>2]|0;
    $31 = $$pre74;
   }
   $24 = HEAP32[$18>>2]|0;
   $25 = (($26) + ($24)|0);
   $27 = HEAP32[$19>>2]|0;
   $28 = (($29) + ($27)|0);
   $30 = (($31) + -1)|0;
   HEAP32[$12>>2] = $30;
   $32 = ($31|0)==(0);
   if ($32) {
    $$lcssa77$sink = $25;$$lcssa78$sink = $28;
    break;
   } else {
    $26 = $25;$29 = $28;$76 = $30;$77 = $28;$78 = $25;
   }
  }
 } else {
  $69 = $$pre72;$72 = $$pre73;$79 = $14;$80 = $$pre73;$81 = $$pre72;
  while(1) {
   $45 = HEAP32[$17>>2]|0;
   $46 = ($45|0)==(0);
   if ($46) {
    $74 = $79;
   } else {
    $$05157 = $80;$$05256 = $81;$$in = $45;
    while(1) {
     $47 = (($$in) + -1)|0;
     $48 = HEAP32[$$05256>>2]|0;
     $49 = $48 >>> 16;
     $50 = $49 & 255;
     $51 = $48 >>> 8;
     $52 = $51 & 255;
     $53 = $48 & 255;
     $54 = Math_imul($53, $11)|0;
     $55 = Math_imul($52, $8)|0;
     $56 = Math_imul($50, $5)|0;
     $57 = (($56>>>0) / 255)&-1;
     $58 = (($55>>>0) / 255)&-1;
     $59 = (($54>>>0) / 255)&-1;
     $60 = $59 << 16;
     $61 = $58 << 8;
     $62 = $61 | $57;
     $63 = $62 | $60;
     HEAP32[$$05157>>2] = $63;
     $64 = ((($$05256)) + 4|0);
     $65 = ((($$05157)) + 4|0);
     $66 = ($47|0)==(0);
     if ($66) {
      break;
     } else {
      $$05157 = $65;$$05256 = $64;$$in = $47;
     }
    }
    $$pre71 = HEAP32[$12>>2]|0;
    $74 = $$pre71;
   }
   $67 = HEAP32[$18>>2]|0;
   $68 = (($69) + ($67)|0);
   $70 = HEAP32[$19>>2]|0;
   $71 = (($72) + ($70)|0);
   $73 = (($74) + -1)|0;
   HEAP32[$12>>2] = $73;
   $75 = ($74|0)==(0);
   if ($75) {
    $$lcssa77$sink = $68;$$lcssa78$sink = $71;
    break;
   } else {
    $69 = $68;$72 = $71;$79 = $73;$80 = $71;$81 = $68;
   }
  }
 }
 HEAP32[$0>>2] = $$lcssa77$sink;
 HEAP32[$16>>2] = $$lcssa78$sink;
 return;
}
function _SDL_Blit_RGB888_BGR888_Modulate_Scale($0) {
 $0 = $0|0;
 var $$078104 = 0, $$078104$us = 0, $$079103 = 0, $$079103$us = 0, $$081102 = 0, $$081102$us = 0, $$083108 = 0, $$085101 = 0, $$085101$us = 0, $$088107 = 0, $$1 = 0, $$1$us = 0, $$184$lcssa = 0, $$189$lcssa = 0, $$2 = 0, $$2$us = 0, $$287 = 0, $$287$us = 0, $$pre = 0, $$pre118 = 0;
 var $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = ((($0)) + 61|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = ((($0)) + 62|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = ((($0)) + 8|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13 << 16;
 $15 = ((($0)) + 28|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($14|0) / ($16|0))&-1;
 $18 = ((($0)) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = $19 << 16;
 $21 = ((($0)) + 24|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($20|0) / ($22|0))&-1;
 $24 = (($16) + -1)|0;
 HEAP32[$15>>2] = $24;
 $25 = ($16|0)==(0);
 if ($25) {
  return;
 }
 $26 = ((($0)) + 20|0);
 $27 = ((($0)) + 32|0);
 $28 = $2 & 1;
 $29 = ($28|0)==(0);
 $30 = ((($0)) + 12|0);
 $$pre = HEAP32[$26>>2]|0;
 $$083108 = 0;$$088107 = 0;$103 = $$pre;$108 = $$pre;$39 = $22;
 while(1) {
  $31 = ($$083108|0)>(65535);
  if ($31) {
   $32 = (($$083108) + -65536)|0;
   $33 = $32 >>> 16;
   $34 = $33 << 16;
   $35 = (($$088107) + 1)|0;
   $36 = (($35) + ($33))|0;
   $37 = (($32) - ($34))|0;
   $$184$lcssa = $37;$$189$lcssa = $36;
  } else {
   $$184$lcssa = $$083108;$$189$lcssa = $$088107;
  }
  $38 = (($39) + -1)|0;
  $40 = ($39|0)==(0);
  if (!($40)) {
   if ($29) {
    $$078104$us = $108;$$079103$us = 0;$$081102$us = 65536;$$085101$us = -1;$65 = $38;
    while(1) {
     $41 = ($$081102$us|0)>(65535);
     if ($41) {
      $42 = (($$081102$us) + -65536)|0;
      $43 = $42 >>> 16;
      $44 = $43 << 16;
      $45 = (($$085101$us) + 1)|0;
      $46 = (($45) + ($43))|0;
      $47 = (($42) - ($44))|0;
      $48 = HEAP32[$0>>2]|0;
      $49 = HEAP32[$30>>2]|0;
      $50 = Math_imul($49, $$189$lcssa)|0;
      $51 = (($48) + ($50)|0);
      $52 = $46 << 2;
      $53 = (($51) + ($52)|0);
      $$1$us = $53;$$2$us = $47;$$287$us = $46;
     } else {
      $$1$us = $$079103$us;$$2$us = $$081102$us;$$287$us = $$085101$us;
     }
     $54 = HEAP32[$$1$us>>2]|0;
     $55 = $54 >>> 16;
     $56 = $55 & 255;
     $57 = $54 & 65280;
     $58 = $54 << 16;
     $59 = $58 & 16711680;
     $60 = $59 | $57;
     $61 = $60 | $56;
     HEAP32[$$078104$us>>2] = $61;
     $62 = (($$2$us) + ($23))|0;
     $63 = ((($$078104$us)) + 4|0);
     $64 = (($65) + -1)|0;
     $66 = ($65|0)==(0);
     if ($66) {
      break;
     } else {
      $$078104$us = $63;$$079103$us = $$1$us;$$081102$us = $62;$$085101$us = $$287$us;$65 = $64;
     }
    }
   } else {
    $$078104 = $108;$$079103 = 0;$$081102 = 65536;$$085101 = -1;$99 = $38;
    while(1) {
     $67 = ($$081102|0)>(65535);
     if ($67) {
      $68 = (($$081102) + -65536)|0;
      $69 = $68 >>> 16;
      $70 = $69 << 16;
      $71 = (($$085101) + 1)|0;
      $72 = (($71) + ($69))|0;
      $73 = (($68) - ($70))|0;
      $74 = HEAP32[$0>>2]|0;
      $75 = HEAP32[$30>>2]|0;
      $76 = Math_imul($75, $$189$lcssa)|0;
      $77 = (($74) + ($76)|0);
      $78 = $72 << 2;
      $79 = (($77) + ($78)|0);
      $$1 = $79;$$2 = $73;$$287 = $72;
     } else {
      $$1 = $$079103;$$2 = $$081102;$$287 = $$085101;
     }
     $80 = HEAP32[$$1>>2]|0;
     $81 = $80 >>> 16;
     $82 = $81 & 255;
     $83 = $80 >>> 8;
     $84 = $83 & 255;
     $85 = $80 & 255;
     $86 = Math_imul($85, $11)|0;
     $87 = Math_imul($84, $8)|0;
     $88 = Math_imul($82, $5)|0;
     $89 = (($88>>>0) / 255)&-1;
     $90 = (($87>>>0) / 255)&-1;
     $91 = (($86>>>0) / 255)&-1;
     $92 = $91 << 16;
     $93 = $90 << 8;
     $94 = $92 | $93;
     $95 = $94 | $89;
     HEAP32[$$078104>>2] = $95;
     $96 = (($$2) + ($23))|0;
     $97 = ((($$078104)) + 4|0);
     $98 = (($99) + -1)|0;
     $100 = ($99|0)==(0);
     if ($100) {
      break;
     } else {
      $$078104 = $97;$$079103 = $$1;$$081102 = $96;$$085101 = $$287;$99 = $98;
     }
    }
   }
  }
  $101 = HEAP32[$27>>2]|0;
  $102 = (($103) + ($101)|0);
  $104 = HEAP32[$15>>2]|0;
  $105 = (($104) + -1)|0;
  HEAP32[$15>>2] = $105;
  $106 = ($104|0)==(0);
  if ($106) {
   break;
  }
  $107 = (($$184$lcssa) + ($17))|0;
  $$pre118 = HEAP32[$21>>2]|0;
  $$083108 = $107;$$088107 = $$189$lcssa;$103 = $102;$108 = $102;$39 = $$pre118;
 }
 HEAP32[$26>>2] = $102;
 return;
}
function _SDL_Blit_RGB888_BGR888_Modulate_Blend($0) {
 $0 = $0|0;
 var $$ = 0, $$$us = 0, $$0107121 = 0, $$0107121$us = 0, $$0108120 = 0, $$0108120$us = 0, $$0109 = 0, $$0109$us = 0, $$0110 = 0, $$0110$us = 0, $$0111 = 0, $$0111$us = 0, $$1 = 0, $$1$us = 0, $$1114 = 0, $$1114$us = 0, $$1116 = 0, $$1116$us = 0, $$1118 = 0, $$1118$us = 0;
 var $$119 = 0, $$3 = 0, $$3$us = 0, $$pre = 0, $$pre126 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $trunc = 0, $trunc$clear = 0, $trunc$clear1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = ((($0)) + 61|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = ((($0)) + 62|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = ((($0)) + 63|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = ((($0)) + 28|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($15) + -1)|0;
 HEAP32[$14>>2] = $16;
 $17 = ($15|0)==(0);
 if ($17) {
  return;
 }
 $18 = $13&255;
 $19 = ((($0)) + 20|0);
 $20 = ((($0)) + 24|0);
 $21 = ((($0)) + 12|0);
 $22 = ((($0)) + 32|0);
 $23 = $2 & 1;
 $24 = ($23|0)==(0);
 $25 = $2 & 2;
 $26 = ($25|0)==(0);
 $$119 = $26 ? 255 : $18;
 $27 = $2 & 48;
 $28 = ($27|0)!=(0);
 $29 = ($$119|0)!=(255);
 $or$cond = $28 & $29;
 $30 = $2 & 112;
 $trunc = $30&255;
 $31 = $$119 ^ 255;
 $$pre = HEAP32[$0>>2]|0;
 $$pre126 = HEAP32[$19>>2]|0;
 $139 = $$pre;$142 = $$pre126;$146 = $$pre126;$147 = $$pre;
 while(1) {
  $32 = HEAP32[$20>>2]|0;
  $33 = (($32) + -1)|0;
  $34 = ($32|0)==(0);
  L6: do {
   if (!($34)) {
    if ($24) {
     $$0107121$us = $146;$$0108120$us = $147;$81 = $33;
     while(1) {
      $35 = HEAP32[$$0108120$us>>2]|0;
      $36 = $35 >>> 16;
      $37 = $36 & 255;
      $38 = $35 >>> 8;
      $39 = $38 & 255;
      $40 = $35 & 255;
      $41 = HEAP32[$$0107121$us>>2]|0;
      $42 = $41 >>> 16;
      $43 = $42 & 255;
      $44 = $41 >>> 8;
      $45 = $44 & 255;
      $46 = $41 & 255;
      if ($or$cond) {
       $47 = Math_imul($40, $$119)|0;
       $48 = Math_imul($39, $$119)|0;
       $49 = Math_imul($37, $$119)|0;
       $50 = (($49>>>0) / 255)&-1;
       $51 = (($48>>>0) / 255)&-1;
       $52 = (($47>>>0) / 255)&-1;
       $$1114$us = $52;$$1116$us = $51;$$1118$us = $50;
      } else {
       $$1114$us = $40;$$1116$us = $39;$$1118$us = $37;
      }
      $trunc$clear = $trunc & 127;
      switch ($trunc$clear<<24>>24) {
      case 16:  {
       $65 = Math_imul($46, $31)|0;
       $66 = (($65>>>0) / 255)&-1;
       $67 = (($$1118$us) + ($66))|0;
       $68 = Math_imul($45, $31)|0;
       $69 = (($68>>>0) / 255)&-1;
       $70 = (($$1116$us) + ($69))|0;
       $71 = Math_imul($43, $31)|0;
       $72 = (($71>>>0) / 255)&-1;
       $73 = (($$1114$us) + ($72))|0;
       $$0109$us = $73;$$0110$us = $70;$$0111$us = $67;
       break;
      }
      case 32:  {
       $59 = (($$1118$us) + ($46))|0;
       $60 = ($59>>>0)<(255);
       $$$us = $60 ? $59 : 255;
       $61 = (($$1116$us) + ($45))|0;
       $62 = ($61>>>0)<(255);
       $$3$us = $62 ? $61 : 255;
       $63 = (($$1114$us) + ($43))|0;
       $64 = ($63>>>0)<(255);
       $$1$us = $64 ? $63 : 255;
       $$0109$us = $$1$us;$$0110$us = $$3$us;$$0111$us = $$$us;
       break;
      }
      case 64:  {
       $53 = Math_imul($$1118$us, $46)|0;
       $54 = (($53>>>0) / 255)&-1;
       $55 = Math_imul($$1116$us, $45)|0;
       $56 = (($55>>>0) / 255)&-1;
       $57 = Math_imul($$1114$us, $43)|0;
       $58 = (($57>>>0) / 255)&-1;
       $$0109$us = $58;$$0110$us = $56;$$0111$us = $54;
       break;
      }
      default: {
       $$0109$us = $43;$$0110$us = $45;$$0111$us = $46;
      }
      }
      $74 = $$0109$us << 16;
      $75 = $$0110$us << 8;
      $76 = $75 | $$0111$us;
      $77 = $76 | $74;
      HEAP32[$$0107121$us>>2] = $77;
      $78 = ((($$0108120$us)) + 4|0);
      $79 = ((($$0107121$us)) + 4|0);
      $80 = (($81) + -1)|0;
      $82 = ($81|0)==(0);
      if ($82) {
       break L6;
      } else {
       $$0107121$us = $79;$$0108120$us = $78;$81 = $80;
      }
     }
    } else {
     $$0107121 = $146;$$0108120 = $147;$135 = $33;
     while(1) {
      $83 = HEAP32[$$0108120>>2]|0;
      $84 = $83 >>> 16;
      $85 = $84 & 255;
      $86 = $83 >>> 8;
      $87 = $86 & 255;
      $88 = $83 & 255;
      $89 = HEAP32[$$0107121>>2]|0;
      $90 = $89 >>> 16;
      $91 = $90 & 255;
      $92 = $89 >>> 8;
      $93 = $92 & 255;
      $94 = $89 & 255;
      $95 = Math_imul($88, $11)|0;
      $96 = Math_imul($87, $8)|0;
      $97 = Math_imul($85, $5)|0;
      $98 = (($97>>>0) / 255)&-1;
      $99 = (($96>>>0) / 255)&-1;
      $100 = (($95>>>0) / 255)&-1;
      if ($or$cond) {
       $101 = Math_imul($100, $$119)|0;
       $102 = Math_imul($99, $$119)|0;
       $103 = Math_imul($98, $$119)|0;
       $104 = (($103>>>0) / 255)&-1;
       $105 = (($102>>>0) / 255)&-1;
       $106 = (($101>>>0) / 255)&-1;
       $$1114 = $106;$$1116 = $105;$$1118 = $104;
      } else {
       $$1114 = $100;$$1116 = $99;$$1118 = $98;
      }
      $trunc$clear1 = $trunc & 127;
      switch ($trunc$clear1<<24>>24) {
      case 16:  {
       $107 = Math_imul($94, $31)|0;
       $108 = (($107>>>0) / 255)&-1;
       $109 = (($$1118) + ($108))|0;
       $110 = Math_imul($93, $31)|0;
       $111 = (($110>>>0) / 255)&-1;
       $112 = (($$1116) + ($111))|0;
       $113 = Math_imul($91, $31)|0;
       $114 = (($113>>>0) / 255)&-1;
       $115 = (($$1114) + ($114))|0;
       $$0109 = $115;$$0110 = $112;$$0111 = $109;
       break;
      }
      case 32:  {
       $116 = (($$1118) + ($94))|0;
       $117 = ($116>>>0)<(255);
       $$ = $117 ? $116 : 255;
       $118 = (($$1116) + ($93))|0;
       $119 = ($118>>>0)<(255);
       $$3 = $119 ? $118 : 255;
       $120 = (($$1114) + ($91))|0;
       $121 = ($120>>>0)<(255);
       $$1 = $121 ? $120 : 255;
       $$0109 = $$1;$$0110 = $$3;$$0111 = $$;
       break;
      }
      case 64:  {
       $122 = Math_imul($$1118, $94)|0;
       $123 = (($122>>>0) / 255)&-1;
       $124 = Math_imul($$1116, $93)|0;
       $125 = (($124>>>0) / 255)&-1;
       $126 = Math_imul($$1114, $91)|0;
       $127 = (($126>>>0) / 255)&-1;
       $$0109 = $127;$$0110 = $125;$$0111 = $123;
       break;
      }
      default: {
       $$0109 = $91;$$0110 = $93;$$0111 = $94;
      }
      }
      $128 = $$0109 << 16;
      $129 = $$0110 << 8;
      $130 = $129 | $$0111;
      $131 = $130 | $128;
      HEAP32[$$0107121>>2] = $131;
      $132 = ((($$0108120)) + 4|0);
      $133 = ((($$0107121)) + 4|0);
      $134 = (($135) + -1)|0;
      $136 = ($135|0)==(0);
      if ($136) {
       break L6;
      } else {
       $$0107121 = $133;$$0108120 = $132;$135 = $134;
      }
     }
    }
   }
  } while(0);
  $137 = HEAP32[$21>>2]|0;
  $138 = (($139) + ($137)|0);
  $140 = HEAP32[$22>>2]|0;
  $141 = (($142) + ($140)|0);
  $143 = HEAP32[$14>>2]|0;
  $144 = (($143) + -1)|0;
  HEAP32[$14>>2] = $144;
  $145 = ($143|0)==(0);
  if ($145) {
   break;
  } else {
   $139 = $138;$142 = $141;$146 = $141;$147 = $138;
  }
 }
 HEAP32[$0>>2] = $138;
 HEAP32[$19>>2] = $141;
 return;
}
function _SDL_Blit_RGB888_BGR888_Modulate_Blend_Scale($0) {
 $0 = $0|0;
 var $$ = 0, $$0134169 = 0, $$0135168 = 0, $$0137 = 0, $$0139 = 0, $$0141167 = 0, $$0143173 = 0, $$0145166 = 0, $$0148172 = 0, $$0150 = 0, $$0151 = 0, $$0152 = 0, $$0154 = 0, $$1 = 0, $$1136 = 0, $$1138 = 0, $$1140 = 0, $$1144$lcssa = 0, $$1149$lcssa = 0, $$1155 = 0;
 var $$156 = 0, $$2 = 0, $$2147 = 0, $$3 = 0, $$in = 0, $$pre = 0, $$pre180 = 0, $$pre181 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $trunc = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = ((($0)) + 61|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = ((($0)) + 62|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = ((($0)) + 63|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = ((($0)) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = $15 << 16;
 $17 = ((($0)) + 28|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($16|0) / ($18|0))&-1;
 $20 = ((($0)) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = $21 << 16;
 $23 = ((($0)) + 24|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (($22|0) / ($24|0))&-1;
 $26 = (($18) + -1)|0;
 HEAP32[$17>>2] = $26;
 $27 = ($18|0)==(0);
 if ($27) {
  return;
 }
 $28 = $13&255;
 $29 = ((($0)) + 20|0);
 $30 = ((($0)) + 32|0);
 $31 = $2 & 1;
 $32 = ($31|0)==(0);
 $33 = $2 & 2;
 $34 = ($33|0)==(0);
 $$156 = $34 ? 255 : $28;
 $35 = $2 & 48;
 $36 = ($35|0)!=(0);
 $37 = ($$156|0)!=(255);
 $or$cond = $36 & $37;
 $38 = $2 & 112;
 $trunc = $38&255;
 $39 = $$156 ^ 255;
 $40 = ((($0)) + 12|0);
 $$pre = HEAP32[$29>>2]|0;
 $$0143173 = 0;$$0148172 = 0;$118 = $$pre;$123 = $26;$124 = $$pre;$48 = $24;
 while(1) {
  $41 = ($$0143173|0)>(65535);
  if ($41) {
   $42 = (($$0143173) + -65536)|0;
   $43 = $42 >>> 16;
   $44 = $43 << 16;
   $45 = (($$0148172) + 1)|0;
   $46 = (($45) + ($43))|0;
   $47 = (($42) - ($44))|0;
   $$1144$lcssa = $47;$$1149$lcssa = $46;
  } else {
   $$1144$lcssa = $$0143173;$$1149$lcssa = $$0148172;
  }
  $49 = ($48|0)==(0);
  if ($49) {
   $120 = $123;
  } else {
   $$0134169 = $124;$$0135168 = 0;$$0141167 = 65536;$$0145166 = -1;$$in = $48;
   while(1) {
    $50 = (($$in) + -1)|0;
    $51 = ($$0141167|0)>(65535);
    if ($51) {
     $52 = (($$0141167) + -65536)|0;
     $53 = $52 >>> 16;
     $54 = $53 << 16;
     $55 = (($$0145166) + 1)|0;
     $56 = (($55) + ($53))|0;
     $57 = (($52) - ($54))|0;
     $58 = HEAP32[$0>>2]|0;
     $59 = HEAP32[$40>>2]|0;
     $60 = Math_imul($59, $$1149$lcssa)|0;
     $61 = (($58) + ($60)|0);
     $62 = $56 << 2;
     $63 = (($61) + ($62)|0);
     $$1136 = $63;$$2 = $57;$$2147 = $56;
    } else {
     $$1136 = $$0135168;$$2 = $$0141167;$$2147 = $$0145166;
    }
    $64 = HEAP32[$$1136>>2]|0;
    $65 = $64 >>> 16;
    $66 = $65 & 255;
    $67 = $64 >>> 8;
    $68 = $67 & 255;
    $69 = $64 & 255;
    $70 = HEAP32[$$0134169>>2]|0;
    $71 = $70 >>> 16;
    $72 = $71 & 255;
    $73 = $70 >>> 8;
    $74 = $73 & 255;
    $75 = $70 & 255;
    if ($32) {
     $$0137 = $66;$$0139 = $68;$$0154 = $69;
    } else {
     $76 = Math_imul($69, $11)|0;
     $77 = Math_imul($68, $8)|0;
     $78 = Math_imul($66, $5)|0;
     $79 = (($78>>>0) / 255)&-1;
     $80 = (($77>>>0) / 255)&-1;
     $81 = (($76>>>0) / 255)&-1;
     $$0137 = $79;$$0139 = $80;$$0154 = $81;
    }
    if ($or$cond) {
     $82 = Math_imul($$0154, $$156)|0;
     $83 = Math_imul($$0139, $$156)|0;
     $84 = Math_imul($$0137, $$156)|0;
     $85 = (($84>>>0) / 255)&-1;
     $86 = (($83>>>0) / 255)&-1;
     $87 = (($82>>>0) / 255)&-1;
     $$1138 = $85;$$1140 = $86;$$1155 = $87;
    } else {
     $$1138 = $$0137;$$1140 = $$0139;$$1155 = $$0154;
    }
    $trunc$clear = $trunc & 127;
    switch ($trunc$clear<<24>>24) {
    case 16:  {
     $88 = Math_imul($75, $39)|0;
     $89 = (($88>>>0) / 255)&-1;
     $90 = (($$1138) + ($89))|0;
     $91 = Math_imul($74, $39)|0;
     $92 = (($91>>>0) / 255)&-1;
     $93 = (($$1140) + ($92))|0;
     $94 = Math_imul($72, $39)|0;
     $95 = (($94>>>0) / 255)&-1;
     $96 = (($$1155) + ($95))|0;
     $$0150 = $96;$$0151 = $93;$$0152 = $90;
     break;
    }
    case 32:  {
     $97 = (($$1138) + ($75))|0;
     $98 = ($97>>>0)<(255);
     $$ = $98 ? $97 : 255;
     $99 = (($$1140) + ($74))|0;
     $100 = ($99>>>0)<(255);
     $$3 = $100 ? $99 : 255;
     $101 = (($$1155) + ($72))|0;
     $102 = ($101>>>0)<(255);
     $$1 = $102 ? $101 : 255;
     $$0150 = $$1;$$0151 = $$3;$$0152 = $$;
     break;
    }
    case 64:  {
     $103 = Math_imul($$1138, $75)|0;
     $104 = (($103>>>0) / 255)&-1;
     $105 = Math_imul($$1140, $74)|0;
     $106 = (($105>>>0) / 255)&-1;
     $107 = Math_imul($$1155, $72)|0;
     $108 = (($107>>>0) / 255)&-1;
     $$0150 = $108;$$0151 = $106;$$0152 = $104;
     break;
    }
    default: {
     $$0150 = $72;$$0151 = $74;$$0152 = $75;
    }
    }
    $109 = $$0150 << 16;
    $110 = $$0151 << 8;
    $111 = $110 | $$0152;
    $112 = $111 | $109;
    HEAP32[$$0134169>>2] = $112;
    $113 = (($$2) + ($25))|0;
    $114 = ((($$0134169)) + 4|0);
    $115 = ($50|0)==(0);
    if ($115) {
     break;
    } else {
     $$0134169 = $114;$$0135168 = $$1136;$$0141167 = $113;$$0145166 = $$2147;$$in = $50;
    }
   }
   $$pre181 = HEAP32[$17>>2]|0;
   $120 = $$pre181;
  }
  $116 = HEAP32[$30>>2]|0;
  $117 = (($118) + ($116)|0);
  $119 = (($120) + -1)|0;
  HEAP32[$17>>2] = $119;
  $121 = ($120|0)==(0);
  if ($121) {
   break;
  }
  $122 = (($$1144$lcssa) + ($19))|0;
  $$pre180 = HEAP32[$23>>2]|0;
  $$0143173 = $122;$$0148172 = $$1149$lcssa;$118 = $117;$123 = $119;$124 = $117;$48 = $$pre180;
 }
 HEAP32[$29>>2] = $117;
 return;
}
function _SDL_Blit_RGB888_ARGB8888_Scale($0) {
 $0 = $0|0;
 var $$06285 = 0, $$06384 = 0, $$06489 = 0, $$06683 = 0, $$06882 = 0, $$07188 = 0, $$1 = 0, $$165$lcssa = 0, $$172$lcssa = 0, $$2 = 0, $$270 = 0, $$in = 0, $$pre = 0, $$pre96 = 0, $$pre97 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 << 16;
 $4 = ((($0)) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3|0) / ($5|0))&-1;
 $7 = ((($0)) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 << 16;
 $10 = ((($0)) + 24|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($9|0) / ($11|0))&-1;
 $13 = (($5) + -1)|0;
 HEAP32[$4>>2] = $13;
 $14 = ($5|0)==(0);
 if ($14) {
  return;
 }
 $15 = ((($0)) + 20|0);
 $16 = ((($0)) + 32|0);
 $17 = ((($0)) + 12|0);
 $$pre = HEAP32[$15>>2]|0;
 $$06489 = 0;$$07188 = 0;$25 = $11;$48 = $$pre;$53 = $13;$54 = $$pre;
 while(1) {
  $18 = ($$07188|0)>(65535);
  if ($18) {
   $19 = (($$07188) + -65536)|0;
   $20 = $19 >>> 16;
   $21 = $20 << 16;
   $22 = (($$06489) + 1)|0;
   $23 = (($22) + ($20))|0;
   $24 = (($19) - ($21))|0;
   $$165$lcssa = $23;$$172$lcssa = $24;
  } else {
   $$165$lcssa = $$06489;$$172$lcssa = $$07188;
  }
  $26 = ($25|0)==(0);
  if ($26) {
   $50 = $53;
  } else {
   $$06285 = $54;$$06384 = 0;$$06683 = -1;$$06882 = 65536;$$in = $25;
   while(1) {
    $27 = (($$in) + -1)|0;
    $28 = ($$06882|0)>(65535);
    if ($28) {
     $29 = (($$06882) + -65536)|0;
     $30 = $29 >>> 16;
     $31 = $30 << 16;
     $32 = (($$06683) + 1)|0;
     $33 = (($32) + ($30))|0;
     $34 = (($29) - ($31))|0;
     $35 = HEAP32[$0>>2]|0;
     $36 = HEAP32[$17>>2]|0;
     $37 = Math_imul($36, $$165$lcssa)|0;
     $38 = (($35) + ($37)|0);
     $39 = $33 << 2;
     $40 = (($38) + ($39)|0);
     $$1 = $40;$$2 = $33;$$270 = $34;
    } else {
     $$1 = $$06384;$$2 = $$06683;$$270 = $$06882;
    }
    $41 = HEAP32[$$1>>2]|0;
    $42 = $41 | -16777216;
    HEAP32[$$06285>>2] = $42;
    $43 = (($$270) + ($12))|0;
    $44 = ((($$06285)) + 4|0);
    $45 = ($27|0)==(0);
    if ($45) {
     break;
    } else {
     $$06285 = $44;$$06384 = $$1;$$06683 = $$2;$$06882 = $43;$$in = $27;
    }
   }
   $$pre97 = HEAP32[$4>>2]|0;
   $50 = $$pre97;
  }
  $46 = HEAP32[$16>>2]|0;
  $47 = (($48) + ($46)|0);
  $49 = (($50) + -1)|0;
  HEAP32[$4>>2] = $49;
  $51 = ($50|0)==(0);
  if ($51) {
   break;
  }
  $52 = (($$172$lcssa) + ($6))|0;
  $$pre96 = HEAP32[$10>>2]|0;
  $$06489 = $$165$lcssa;$$07188 = $52;$25 = $$pre96;$48 = $47;$53 = $49;$54 = $47;
 }
 HEAP32[$15>>2] = $47;
 return;
}
function _SDL_Blit_RGB888_ARGB8888_Blend($0) {
 $0 = $0|0;
 var $$ = 0, $$092102 = 0, $$092102$us = 0, $$093101 = 0, $$093101$us = 0, $$095 = 0, $$096 = 0, $$097 = 0, $$1 = 0, $$3 = 0, $$pre = 0, $$pre107 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $trunc = 0, $trunc$clear = 0, $trunc$clear1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + -1)|0;
 HEAP32[$3>>2] = $5;
 $6 = ($4|0)==(0);
 if ($6) {
  return;
 }
 $7 = ((($0)) + 20|0);
 $8 = ((($0)) + 24|0);
 $9 = ((($0)) + 12|0);
 $10 = ((($0)) + 32|0);
 $11 = $2 & 112;
 $trunc = $11&255;
 $trunc$clear = $trunc & 127;
 $12 = ($trunc$clear<<24>>24)==(16);
 $$pre = HEAP32[$0>>2]|0;
 $$pre107 = HEAP32[$7>>2]|0;
 $60 = $$pre;$63 = $$pre107;$67 = $$pre107;$68 = $$pre;
 while(1) {
  $13 = HEAP32[$8>>2]|0;
  $14 = (($13) + -1)|0;
  $15 = ($13|0)==(0);
  L6: do {
   if (!($15)) {
    if ($12) {
     $$092102$us = $67;$$093101$us = $68;$21 = $14;
     while(1) {
      $16 = HEAP32[$$093101$us>>2]|0;
      $17 = $16 | -16777216;
      HEAP32[$$092102$us>>2] = $17;
      $18 = ((($$093101$us)) + 4|0);
      $19 = ((($$092102$us)) + 4|0);
      $20 = (($21) + -1)|0;
      $22 = ($21|0)==(0);
      if ($22) {
       break L6;
      } else {
       $$092102$us = $19;$$093101$us = $18;$21 = $20;
      }
     }
    } else {
     $$092102 = $67;$$093101 = $68;$56 = $14;
    }
    while(1) {
     $23 = HEAP32[$$093101>>2]|0;
     $24 = $23 >>> 16;
     $25 = $24 & 255;
     $26 = $23 >>> 8;
     $27 = $26 & 255;
     $28 = $23 & 255;
     $29 = HEAP32[$$092102>>2]|0;
     $30 = $29 >>> 16;
     $31 = $30 & 255;
     $32 = $29 >>> 8;
     $33 = $32 & 255;
     $34 = $29 & 255;
     $35 = $29 & -16777216;
     $trunc$clear1 = $trunc & 127;
     switch ($trunc$clear1<<24>>24) {
     case 64:  {
      $42 = Math_imul($31, $25)|0;
      $43 = (($42>>>0) / 255)&-1;
      $44 = Math_imul($33, $27)|0;
      $45 = (($44>>>0) / 255)&-1;
      $46 = Math_imul($34, $28)|0;
      $47 = (($46>>>0) / 255)&-1;
      $$095 = $47;$$096 = $45;$$097 = $43;
      break;
     }
     case 32:  {
      $36 = (($31) + ($25))|0;
      $37 = ($36>>>0)<(255);
      $$ = $37 ? $36 : 255;
      $38 = (($33) + ($27))|0;
      $39 = ($38>>>0)<(255);
      $$3 = $39 ? $38 : 255;
      $40 = (($34) + ($28))|0;
      $41 = ($40>>>0)<(255);
      $$1 = $41 ? $40 : 255;
      $$095 = $$1;$$096 = $$3;$$097 = $$;
      break;
     }
     default: {
      $$095 = $34;$$096 = $33;$$097 = $31;
     }
     }
     $48 = $$097 << 16;
     $49 = $$096 << 8;
     $50 = $49 | $48;
     $51 = $50 | $$095;
     $52 = $51 | $35;
     HEAP32[$$092102>>2] = $52;
     $53 = ((($$093101)) + 4|0);
     $54 = ((($$092102)) + 4|0);
     $55 = (($56) + -1)|0;
     $57 = ($56|0)==(0);
     if ($57) {
      break L6;
     } else {
      $$092102 = $54;$$093101 = $53;$56 = $55;
     }
    }
   }
  } while(0);
  $58 = HEAP32[$9>>2]|0;
  $59 = (($60) + ($58)|0);
  $61 = HEAP32[$10>>2]|0;
  $62 = (($63) + ($61)|0);
  $64 = HEAP32[$3>>2]|0;
  $65 = (($64) + -1)|0;
  HEAP32[$3>>2] = $65;
  $66 = ($64|0)==(0);
  if ($66) {
   break;
  } else {
   $60 = $59;$63 = $62;$67 = $62;$68 = $59;
  }
 }
 HEAP32[$0>>2] = $59;
 HEAP32[$7>>2] = $62;
 return;
}
function _SDL_Blit_RGB888_ARGB8888_Blend_Scale($0) {
 $0 = $0|0;
 var $$ = 0, $$0119150 = 0, $$0119150$us = 0, $$0120149 = 0, $$0120149$us = 0, $$0124148 = 0, $$0124148$us = 0, $$0126154 = 0, $$0128147 = 0, $$0128147$us = 0, $$0131153 = 0, $$0134 = 0, $$0135 = 0, $$0136 = 0, $$1 = 0, $$1121 = 0, $$1121$us = 0, $$1127$lcssa = 0, $$1132$lcssa = 0, $$2 = 0;
 var $$2$us = 0, $$2130 = 0, $$2130$us = 0, $$3 = 0, $$pre = 0, $$pre164 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $trunc = 0, $trunc$clear = 0, $trunc$clear1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 << 16;
 $6 = ((($0)) + 28|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5|0) / ($7|0))&-1;
 $9 = ((($0)) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10 << 16;
 $12 = ((($0)) + 24|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($11|0) / ($13|0))&-1;
 $15 = (($7) + -1)|0;
 HEAP32[$6>>2] = $15;
 $16 = ($7|0)==(0);
 if ($16) {
  return;
 }
 $17 = ((($0)) + 20|0);
 $18 = ((($0)) + 32|0);
 $19 = $2 & 112;
 $trunc = $19&255;
 $20 = ((($0)) + 12|0);
 $trunc$clear = $trunc & 127;
 $21 = ($trunc$clear<<24>>24)==(16);
 $$pre = HEAP32[$17>>2]|0;
 $$0126154 = 0;$$0131153 = 0;$102 = $$pre;$107 = $$pre;$30 = $13;
 while(1) {
  $22 = ($$0126154|0)>(65535);
  if ($22) {
   $23 = (($$0126154) + -65536)|0;
   $24 = $23 >>> 16;
   $25 = $24 << 16;
   $26 = (($$0131153) + 1)|0;
   $27 = (($26) + ($24))|0;
   $28 = (($23) - ($25))|0;
   $$1127$lcssa = $28;$$1132$lcssa = $27;
  } else {
   $$1127$lcssa = $$0126154;$$1132$lcssa = $$0131153;
  }
  $29 = (($30) + -1)|0;
  $31 = ($30|0)==(0);
  L9: do {
   if (!($31)) {
    if ($21) {
     $$0119150$us = $107;$$0120149$us = 0;$$0124148$us = 65536;$$0128147$us = -1;$50 = $29;
     while(1) {
      $32 = ($$0124148$us|0)>(65535);
      if ($32) {
       $33 = (($$0124148$us) + -65536)|0;
       $34 = $33 >>> 16;
       $35 = $34 << 16;
       $36 = (($$0128147$us) + 1)|0;
       $37 = (($36) + ($34))|0;
       $38 = (($33) - ($35))|0;
       $39 = HEAP32[$0>>2]|0;
       $40 = HEAP32[$20>>2]|0;
       $41 = Math_imul($40, $$1132$lcssa)|0;
       $42 = (($39) + ($41)|0);
       $43 = $37 << 2;
       $44 = (($42) + ($43)|0);
       $$1121$us = $44;$$2$us = $38;$$2130$us = $37;
      } else {
       $$1121$us = $$0120149$us;$$2$us = $$0124148$us;$$2130$us = $$0128147$us;
      }
      $45 = HEAP32[$$1121$us>>2]|0;
      $46 = $45 | -16777216;
      HEAP32[$$0119150$us>>2] = $46;
      $47 = (($$2$us) + ($14))|0;
      $48 = ((($$0119150$us)) + 4|0);
      $49 = (($50) + -1)|0;
      $51 = ($50|0)==(0);
      if ($51) {
       break L9;
      } else {
       $$0119150$us = $48;$$0120149$us = $$1121$us;$$0124148$us = $47;$$0128147$us = $$2130$us;$50 = $49;
      }
     }
    } else {
     $$0119150 = $107;$$0120149 = 0;$$0124148 = 65536;$$0128147 = -1;$98 = $29;
    }
    while(1) {
     $52 = ($$0124148|0)>(65535);
     if ($52) {
      $53 = (($$0124148) + -65536)|0;
      $54 = $53 >>> 16;
      $55 = $54 << 16;
      $56 = (($$0128147) + 1)|0;
      $57 = (($56) + ($54))|0;
      $58 = (($53) - ($55))|0;
      $59 = HEAP32[$0>>2]|0;
      $60 = HEAP32[$20>>2]|0;
      $61 = Math_imul($60, $$1132$lcssa)|0;
      $62 = (($59) + ($61)|0);
      $63 = $57 << 2;
      $64 = (($62) + ($63)|0);
      $$1121 = $64;$$2 = $58;$$2130 = $57;
     } else {
      $$1121 = $$0120149;$$2 = $$0124148;$$2130 = $$0128147;
     }
     $65 = HEAP32[$$1121>>2]|0;
     $66 = $65 >>> 16;
     $67 = $66 & 255;
     $68 = $65 >>> 8;
     $69 = $68 & 255;
     $70 = $65 & 255;
     $71 = HEAP32[$$0119150>>2]|0;
     $72 = $71 >>> 16;
     $73 = $72 & 255;
     $74 = $71 >>> 8;
     $75 = $74 & 255;
     $76 = $71 & 255;
     $77 = $71 & -16777216;
     $trunc$clear1 = $trunc & 127;
     switch ($trunc$clear1<<24>>24) {
     case 64:  {
      $84 = Math_imul($73, $67)|0;
      $85 = (($84>>>0) / 255)&-1;
      $86 = Math_imul($75, $69)|0;
      $87 = (($86>>>0) / 255)&-1;
      $88 = Math_imul($76, $70)|0;
      $89 = (($88>>>0) / 255)&-1;
      $$0134 = $89;$$0135 = $87;$$0136 = $85;
      break;
     }
     case 32:  {
      $78 = (($73) + ($67))|0;
      $79 = ($78>>>0)<(255);
      $$ = $79 ? $78 : 255;
      $80 = (($75) + ($69))|0;
      $81 = ($80>>>0)<(255);
      $$3 = $81 ? $80 : 255;
      $82 = (($76) + ($70))|0;
      $83 = ($82>>>0)<(255);
      $$1 = $83 ? $82 : 255;
      $$0134 = $$1;$$0135 = $$3;$$0136 = $$;
      break;
     }
     default: {
      $$0134 = $76;$$0135 = $75;$$0136 = $73;
     }
     }
     $90 = $$0136 << 16;
     $91 = $$0135 << 8;
     $92 = $91 | $90;
     $93 = $92 | $$0134;
     $94 = $93 | $77;
     HEAP32[$$0119150>>2] = $94;
     $95 = (($$2) + ($14))|0;
     $96 = ((($$0119150)) + 4|0);
     $97 = (($98) + -1)|0;
     $99 = ($98|0)==(0);
     if ($99) {
      break L9;
     } else {
      $$0119150 = $96;$$0120149 = $$1121;$$0124148 = $95;$$0128147 = $$2130;$98 = $97;
     }
    }
   }
  } while(0);
  $100 = HEAP32[$18>>2]|0;
  $101 = (($102) + ($100)|0);
  $103 = HEAP32[$6>>2]|0;
  $104 = (($103) + -1)|0;
  HEAP32[$6>>2] = $104;
  $105 = ($103|0)==(0);
  if ($105) {
   break;
  }
  $106 = (($$1127$lcssa) + ($8))|0;
  $$pre164 = HEAP32[$12>>2]|0;
  $$0126154 = $106;$$0131153 = $$1132$lcssa;$102 = $101;$107 = $101;$30 = $$pre164;
 }
 HEAP32[$17>>2] = $101;
 return;
}
function _SDL_Blit_RGB888_ARGB8888_Modulate($0) {
 $0 = $0|0;
 var $$06067 = 0, $$06067$us$us = 0, $$06166 = 0, $$06166$us$us = 0, $$in = 0, $$in78 = 0, $$lcssa87$sink = 0, $$lcssa88$sink = 0, $$op = 0, $$pre81 = 0, $$pre82 = 0, $$pre83 = 0, $$pre84 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = ((($0)) + 61|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = ((($0)) + 62|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = ((($0)) + 63|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = ((($0)) + 28|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($15) + -1)|0;
 HEAP32[$14>>2] = $16;
 $17 = ($15|0)==(0);
 if ($17) {
  return;
 }
 $18 = $13&255;
 $19 = ((($0)) + 20|0);
 $20 = ((($0)) + 24|0);
 $21 = ((($0)) + 12|0);
 $22 = ((($0)) + 32|0);
 $23 = $2 & 1;
 $24 = ($23|0)==(0);
 $25 = $2 & 2;
 $26 = ($25|0)==(0);
 $$op = $18 << 24;
 $27 = $26 ? -16777216 : $$op;
 $$pre82 = HEAP32[$0>>2]|0;
 $$pre83 = HEAP32[$19>>2]|0;
 if ($24) {
  $32 = $$pre82;$35 = $$pre83;$82 = $16;$83 = $$pre83;$84 = $$pre82;
  while(1) {
   $28 = HEAP32[$20>>2]|0;
   $29 = ($28|0)==(0);
   if ($29) {
    $37 = $82;
   } else {
    $$06067$us$us = $83;$$06166$us$us = $84;$$in78 = $28;
    while(1) {
     $39 = (($$in78) + -1)|0;
     $40 = HEAP32[$$06166$us$us>>2]|0;
     $41 = $40 & 16711680;
     $42 = $40 & 65280;
     $43 = $40 & 255;
     $44 = $41 | $27;
     $45 = $44 | $42;
     $46 = $45 | $43;
     HEAP32[$$06067$us$us>>2] = $46;
     $47 = ((($$06166$us$us)) + 4|0);
     $48 = ((($$06067$us$us)) + 4|0);
     $49 = ($39|0)==(0);
     if ($49) {
      break;
     } else {
      $$06067$us$us = $48;$$06166$us$us = $47;$$in78 = $39;
     }
    }
    $$pre84 = HEAP32[$14>>2]|0;
    $37 = $$pre84;
   }
   $30 = HEAP32[$21>>2]|0;
   $31 = (($32) + ($30)|0);
   $33 = HEAP32[$22>>2]|0;
   $34 = (($35) + ($33)|0);
   $36 = (($37) + -1)|0;
   HEAP32[$14>>2] = $36;
   $38 = ($37|0)==(0);
   if ($38) {
    $$lcssa87$sink = $31;$$lcssa88$sink = $34;
    break;
   } else {
    $32 = $31;$35 = $34;$82 = $36;$83 = $34;$84 = $31;
   }
  }
 } else {
  $75 = $$pre82;$78 = $$pre83;$85 = $16;$86 = $$pre83;$87 = $$pre82;
  while(1) {
   $50 = HEAP32[$20>>2]|0;
   $51 = ($50|0)==(0);
   if ($51) {
    $80 = $85;
   } else {
    $$06067 = $86;$$06166 = $87;$$in = $50;
    while(1) {
     $52 = (($$in) + -1)|0;
     $53 = HEAP32[$$06166>>2]|0;
     $54 = $53 >>> 16;
     $55 = $54 & 255;
     $56 = $53 >>> 8;
     $57 = $56 & 255;
     $58 = $53 & 255;
     $59 = Math_imul($58, $11)|0;
     $60 = Math_imul($57, $8)|0;
     $61 = Math_imul($55, $5)|0;
     $62 = (($61>>>0) / 255)&-1;
     $63 = (($60>>>0) / 255)&-1;
     $64 = (($59>>>0) / 255)&-1;
     $65 = $62 << 16;
     $66 = $65 | $27;
     $67 = $63 << 8;
     $68 = $66 | $67;
     $69 = $68 | $64;
     HEAP32[$$06067>>2] = $69;
     $70 = ((($$06166)) + 4|0);
     $71 = ((($$06067)) + 4|0);
     $72 = ($52|0)==(0);
     if ($72) {
      break;
     } else {
      $$06067 = $71;$$06166 = $70;$$in = $52;
     }
    }
    $$pre81 = HEAP32[$14>>2]|0;
    $80 = $$pre81;
   }
   $73 = HEAP32[$21>>2]|0;
   $74 = (($75) + ($73)|0);
   $76 = HEAP32[$22>>2]|0;
   $77 = (($78) + ($76)|0);
   $79 = (($80) + -1)|0;
   HEAP32[$14>>2] = $79;
   $81 = ($80|0)==(0);
   if ($81) {
    $$lcssa87$sink = $74;$$lcssa88$sink = $77;
    break;
   } else {
    $75 = $74;$78 = $77;$85 = $79;$86 = $77;$87 = $74;
   }
  }
 }
 HEAP32[$0>>2] = $$lcssa87$sink;
 HEAP32[$19>>2] = $$lcssa88$sink;
 return;
}
function _SDL_Blit_RGB888_ARGB8888_Modulate_Scale($0) {
 $0 = $0|0;
 var $$087114 = 0, $$087114$us = 0, $$088113 = 0, $$088113$us = 0, $$090112 = 0, $$090112$us = 0, $$092118 = 0, $$094111 = 0, $$094111$us = 0, $$097117 = 0, $$1 = 0, $$1$us = 0, $$193$lcssa = 0, $$198$lcssa = 0, $$2 = 0, $$2$us = 0, $$296 = 0, $$296$us = 0, $$op = 0, $$pre = 0;
 var $$pre128 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $12 = 0;
 var $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = ((($0)) + 61|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = ((($0)) + 62|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = ((($0)) + 63|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = ((($0)) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = $15 << 16;
 $17 = ((($0)) + 28|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($16|0) / ($18|0))&-1;
 $20 = ((($0)) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = $21 << 16;
 $23 = ((($0)) + 24|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (($22|0) / ($24|0))&-1;
 $26 = (($18) + -1)|0;
 HEAP32[$17>>2] = $26;
 $27 = ($18|0)==(0);
 if ($27) {
  return;
 }
 $28 = $13&255;
 $29 = ((($0)) + 20|0);
 $30 = ((($0)) + 32|0);
 $31 = $2 & 1;
 $32 = ($31|0)==(0);
 $33 = $2 & 2;
 $34 = ($33|0)==(0);
 $$op = $28 << 24;
 $35 = $34 ? -16777216 : $$op;
 $36 = ((($0)) + 12|0);
 $$pre = HEAP32[$29>>2]|0;
 $$092118 = 0;$$097117 = 0;$109 = $$pre;$114 = $$pre;$45 = $24;
 while(1) {
  $37 = ($$092118|0)>(65535);
  if ($37) {
   $38 = (($$092118) + -65536)|0;
   $39 = $38 >>> 16;
   $40 = $39 << 16;
   $41 = (($$097117) + 1)|0;
   $42 = (($41) + ($39))|0;
   $43 = (($38) - ($40))|0;
   $$193$lcssa = $43;$$198$lcssa = $42;
  } else {
   $$193$lcssa = $$092118;$$198$lcssa = $$097117;
  }
  $44 = (($45) + -1)|0;
  $46 = ($45|0)==(0);
  if (!($46)) {
   if ($32) {
    $$087114$us = $114;$$088113$us = 0;$$090112$us = 65536;$$094111$us = -1;$70 = $44;
    while(1) {
     $47 = ($$090112$us|0)>(65535);
     if ($47) {
      $48 = (($$090112$us) + -65536)|0;
      $49 = $48 >>> 16;
      $50 = $49 << 16;
      $51 = (($$094111$us) + 1)|0;
      $52 = (($51) + ($49))|0;
      $53 = (($48) - ($50))|0;
      $54 = HEAP32[$0>>2]|0;
      $55 = HEAP32[$36>>2]|0;
      $56 = Math_imul($55, $$198$lcssa)|0;
      $57 = (($54) + ($56)|0);
      $58 = $52 << 2;
      $59 = (($57) + ($58)|0);
      $$1$us = $59;$$2$us = $53;$$296$us = $52;
     } else {
      $$1$us = $$088113$us;$$2$us = $$090112$us;$$296$us = $$094111$us;
     }
     $60 = HEAP32[$$1$us>>2]|0;
     $61 = $60 & 16711680;
     $62 = $60 & 65280;
     $63 = $60 & 255;
     $64 = $62 | $35;
     $65 = $64 | $63;
     $66 = $65 | $61;
     HEAP32[$$087114$us>>2] = $66;
     $67 = (($$2$us) + ($25))|0;
     $68 = ((($$087114$us)) + 4|0);
     $69 = (($70) + -1)|0;
     $71 = ($70|0)==(0);
     if ($71) {
      break;
     } else {
      $$087114$us = $68;$$088113$us = $$1$us;$$090112$us = $67;$$094111$us = $$296$us;$70 = $69;
     }
    }
   } else {
    $$087114 = $114;$$088113 = 0;$$090112 = 65536;$$094111 = -1;$105 = $44;
    while(1) {
     $72 = ($$090112|0)>(65535);
     if ($72) {
      $73 = (($$090112) + -65536)|0;
      $74 = $73 >>> 16;
      $75 = $74 << 16;
      $76 = (($$094111) + 1)|0;
      $77 = (($76) + ($74))|0;
      $78 = (($73) - ($75))|0;
      $79 = HEAP32[$0>>2]|0;
      $80 = HEAP32[$36>>2]|0;
      $81 = Math_imul($80, $$198$lcssa)|0;
      $82 = (($79) + ($81)|0);
      $83 = $77 << 2;
      $84 = (($82) + ($83)|0);
      $$1 = $84;$$2 = $78;$$296 = $77;
     } else {
      $$1 = $$088113;$$2 = $$090112;$$296 = $$094111;
     }
     $85 = HEAP32[$$1>>2]|0;
     $86 = $85 >>> 16;
     $87 = $86 & 255;
     $88 = $85 >>> 8;
     $89 = $88 & 255;
     $90 = $85 & 255;
     $91 = Math_imul($90, $11)|0;
     $92 = Math_imul($89, $8)|0;
     $93 = Math_imul($87, $5)|0;
     $94 = (($93>>>0) / 255)&-1;
     $95 = (($92>>>0) / 255)&-1;
     $96 = (($91>>>0) / 255)&-1;
     $97 = $94 << 16;
     $98 = $95 << 8;
     $99 = $98 | $35;
     $100 = $99 | $96;
     $101 = $100 | $97;
     HEAP32[$$087114>>2] = $101;
     $102 = (($$2) + ($25))|0;
     $103 = ((($$087114)) + 4|0);
     $104 = (($105) + -1)|0;
     $106 = ($105|0)==(0);
     if ($106) {
      break;
     } else {
      $$087114 = $103;$$088113 = $$1;$$090112 = $102;$$094111 = $$296;$105 = $104;
     }
    }
   }
  }
  $107 = HEAP32[$30>>2]|0;
  $108 = (($109) + ($107)|0);
  $110 = HEAP32[$17>>2]|0;
  $111 = (($110) + -1)|0;
  HEAP32[$17>>2] = $111;
  $112 = ($110|0)==(0);
  if ($112) {
   break;
  }
  $113 = (($$193$lcssa) + ($19))|0;
  $$pre128 = HEAP32[$23>>2]|0;
  $$092118 = $113;$$097117 = $$198$lcssa;$109 = $108;$114 = $108;$45 = $$pre128;
 }
 HEAP32[$29>>2] = $108;
 return;
}
function _SDL_Blit_RGB888_ARGB8888_Modulate_Blend($0) {
 $0 = $0|0;
 var $$ = 0, $$0114129 = 0, $$0115128 = 0, $$0116 = 0, $$0117 = 0, $$0118 = 0, $$0119 = 0, $$0121 = 0, $$0123 = 0, $$0125 = 0, $$1 = 0, $$1122 = 0, $$1124 = 0, $$1126 = 0, $$127 = 0, $$3 = 0, $$in = 0, $$pre = 0, $$pre133 = 0, $$pre134 = 0;
 var $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $trunc = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = ((($0)) + 61|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = ((($0)) + 62|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = ((($0)) + 63|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = ((($0)) + 28|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($15) + -1)|0;
 HEAP32[$14>>2] = $16;
 $17 = ($15|0)==(0);
 if ($17) {
  return;
 }
 $18 = $13&255;
 $19 = ((($0)) + 20|0);
 $20 = ((($0)) + 24|0);
 $21 = ((($0)) + 12|0);
 $22 = ((($0)) + 32|0);
 $23 = $2 & 1;
 $24 = ($23|0)==(0);
 $25 = $2 & 2;
 $26 = ($25|0)==(0);
 $$127 = $26 ? 255 : $18;
 $27 = $2 & 48;
 $28 = ($27|0)!=(0);
 $29 = ($$127|0)!=(255);
 $or$cond = $28 & $29;
 $30 = $2 & 112;
 $trunc = $30&255;
 $31 = $$127 ^ 255;
 $$pre = HEAP32[$0>>2]|0;
 $$pre133 = HEAP32[$19>>2]|0;
 $102 = $16;$103 = $$pre133;$104 = $$pre;$95 = $$pre;$98 = $$pre133;
 while(1) {
  $32 = HEAP32[$20>>2]|0;
  $33 = ($32|0)==(0);
  if ($33) {
   $100 = $102;
  } else {
   $$0114129 = $103;$$0115128 = $104;$$in = $32;
   while(1) {
    $34 = (($$in) + -1)|0;
    $35 = HEAP32[$$0115128>>2]|0;
    $36 = $35 >>> 16;
    $37 = $36 & 255;
    $38 = $35 >>> 8;
    $39 = $38 & 255;
    $40 = $35 & 255;
    $41 = HEAP32[$$0114129>>2]|0;
    $42 = $41 >>> 16;
    $43 = $42 & 255;
    $44 = $41 >>> 8;
    $45 = $44 & 255;
    $46 = $41 & 255;
    $47 = $41 >>> 24;
    if ($24) {
     $$0121 = $40;$$0123 = $39;$$0125 = $37;
    } else {
     $48 = Math_imul($40, $11)|0;
     $49 = Math_imul($39, $8)|0;
     $50 = Math_imul($37, $5)|0;
     $51 = (($50>>>0) / 255)&-1;
     $52 = (($49>>>0) / 255)&-1;
     $53 = (($48>>>0) / 255)&-1;
     $$0121 = $53;$$0123 = $52;$$0125 = $51;
    }
    if ($or$cond) {
     $54 = Math_imul($$0121, $$127)|0;
     $55 = Math_imul($$0123, $$127)|0;
     $56 = Math_imul($$0125, $$127)|0;
     $57 = (($56>>>0) / 255)&-1;
     $58 = (($55>>>0) / 255)&-1;
     $59 = (($54>>>0) / 255)&-1;
     $$1122 = $59;$$1124 = $58;$$1126 = $57;
    } else {
     $$1122 = $$0121;$$1124 = $$0123;$$1126 = $$0125;
    }
    $trunc$clear = $trunc & 127;
    switch ($trunc$clear<<24>>24) {
    case 16:  {
     $60 = Math_imul($43, $31)|0;
     $61 = (($60>>>0) / 255)&-1;
     $62 = (($$1126) + ($61))|0;
     $63 = Math_imul($45, $31)|0;
     $64 = (($63>>>0) / 255)&-1;
     $65 = (($$1124) + ($64))|0;
     $66 = Math_imul($46, $31)|0;
     $67 = (($66>>>0) / 255)&-1;
     $68 = (($$1122) + ($67))|0;
     $69 = Math_imul($47, $31)|0;
     $70 = (($69>>>0) / 255)&-1;
     $71 = (($70) + ($$127))|0;
     $$0116 = $71;$$0117 = $68;$$0118 = $65;$$0119 = $62;
     break;
    }
    case 32:  {
     $72 = (($$1126) + ($43))|0;
     $73 = ($72>>>0)<(255);
     $$ = $73 ? $72 : 255;
     $74 = (($$1124) + ($45))|0;
     $75 = ($74>>>0)<(255);
     $$3 = $75 ? $74 : 255;
     $76 = (($$1122) + ($46))|0;
     $77 = ($76>>>0)<(255);
     $$1 = $77 ? $76 : 255;
     $$0116 = $47;$$0117 = $$1;$$0118 = $$3;$$0119 = $$;
     break;
    }
    case 64:  {
     $78 = Math_imul($$1126, $43)|0;
     $79 = (($78>>>0) / 255)&-1;
     $80 = Math_imul($$1124, $45)|0;
     $81 = (($80>>>0) / 255)&-1;
     $82 = Math_imul($$1122, $46)|0;
     $83 = (($82>>>0) / 255)&-1;
     $$0116 = $47;$$0117 = $83;$$0118 = $81;$$0119 = $79;
     break;
    }
    default: {
     $$0116 = $47;$$0117 = $46;$$0118 = $45;$$0119 = $43;
    }
    }
    $84 = $$0116 << 24;
    $85 = $$0119 << 16;
    $86 = $$0118 << 8;
    $87 = $86 | $85;
    $88 = $87 | $$0117;
    $89 = $88 | $84;
    HEAP32[$$0114129>>2] = $89;
    $90 = ((($$0115128)) + 4|0);
    $91 = ((($$0114129)) + 4|0);
    $92 = ($34|0)==(0);
    if ($92) {
     break;
    } else {
     $$0114129 = $91;$$0115128 = $90;$$in = $34;
    }
   }
   $$pre134 = HEAP32[$14>>2]|0;
   $100 = $$pre134;
  }
  $93 = HEAP32[$21>>2]|0;
  $94 = (($95) + ($93)|0);
  $96 = HEAP32[$22>>2]|0;
  $97 = (($98) + ($96)|0);
  $99 = (($100) + -1)|0;
  HEAP32[$14>>2] = $99;
  $101 = ($100|0)==(0);
  if ($101) {
   break;
  } else {
   $102 = $99;$103 = $97;$104 = $94;$95 = $94;$98 = $97;
  }
 }
 HEAP32[$0>>2] = $94;
 HEAP32[$19>>2] = $97;
 return;
}
function _SDL_Blit_RGB888_ARGB8888_Modulate_Blend_Scale($0) {
 $0 = $0|0;
 var $$ = 0, $$0141177 = 0, $$0142176 = 0, $$0144 = 0, $$0146 = 0, $$0148175 = 0, $$0150181 = 0, $$0152174 = 0, $$0155180 = 0, $$0157 = 0, $$0158 = 0, $$0159 = 0, $$0160 = 0, $$0162 = 0, $$1 = 0, $$1143 = 0, $$1145 = 0, $$1147 = 0, $$1151$lcssa = 0, $$1156$lcssa = 0;
 var $$1163 = 0, $$164 = 0, $$2 = 0, $$2154 = 0, $$3 = 0, $$in = 0, $$pre = 0, $$pre188 = 0, $$pre189 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0;
 var $trunc = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = ((($0)) + 61|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = ((($0)) + 62|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = ((($0)) + 63|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = ((($0)) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = $15 << 16;
 $17 = ((($0)) + 28|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($16|0) / ($18|0))&-1;
 $20 = ((($0)) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = $21 << 16;
 $23 = ((($0)) + 24|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (($22|0) / ($24|0))&-1;
 $26 = (($18) + -1)|0;
 HEAP32[$17>>2] = $26;
 $27 = ($18|0)==(0);
 if ($27) {
  return;
 }
 $28 = $13&255;
 $29 = ((($0)) + 20|0);
 $30 = ((($0)) + 32|0);
 $31 = $2 & 1;
 $32 = ($31|0)==(0);
 $33 = $2 & 2;
 $34 = ($33|0)==(0);
 $$164 = $34 ? 255 : $28;
 $35 = $2 & 48;
 $36 = ($35|0)!=(0);
 $37 = ($$164|0)!=(255);
 $or$cond = $36 & $37;
 $38 = $2 & 112;
 $trunc = $38&255;
 $39 = $$164 ^ 255;
 $40 = ((($0)) + 12|0);
 $$pre = HEAP32[$29>>2]|0;
 $$0150181 = 0;$$0155180 = 0;$124 = $$pre;$129 = $26;$130 = $$pre;$48 = $24;
 while(1) {
  $41 = ($$0150181|0)>(65535);
  if ($41) {
   $42 = (($$0150181) + -65536)|0;
   $43 = $42 >>> 16;
   $44 = $43 << 16;
   $45 = (($$0155180) + 1)|0;
   $46 = (($45) + ($43))|0;
   $47 = (($42) - ($44))|0;
   $$1151$lcssa = $47;$$1156$lcssa = $46;
  } else {
   $$1151$lcssa = $$0150181;$$1156$lcssa = $$0155180;
  }
  $49 = ($48|0)==(0);
  if ($49) {
   $126 = $129;
  } else {
   $$0141177 = $130;$$0142176 = 0;$$0148175 = 65536;$$0152174 = -1;$$in = $48;
   while(1) {
    $50 = (($$in) + -1)|0;
    $51 = ($$0148175|0)>(65535);
    if ($51) {
     $52 = (($$0148175) + -65536)|0;
     $53 = $52 >>> 16;
     $54 = $53 << 16;
     $55 = (($$0152174) + 1)|0;
     $56 = (($55) + ($53))|0;
     $57 = (($52) - ($54))|0;
     $58 = HEAP32[$0>>2]|0;
     $59 = HEAP32[$40>>2]|0;
     $60 = Math_imul($59, $$1156$lcssa)|0;
     $61 = (($58) + ($60)|0);
     $62 = $56 << 2;
     $63 = (($61) + ($62)|0);
     $$1143 = $63;$$2 = $57;$$2154 = $56;
    } else {
     $$1143 = $$0142176;$$2 = $$0148175;$$2154 = $$0152174;
    }
    $64 = HEAP32[$$1143>>2]|0;
    $65 = $64 >>> 16;
    $66 = $65 & 255;
    $67 = $64 >>> 8;
    $68 = $67 & 255;
    $69 = $64 & 255;
    $70 = HEAP32[$$0141177>>2]|0;
    $71 = $70 >>> 16;
    $72 = $71 & 255;
    $73 = $70 >>> 8;
    $74 = $73 & 255;
    $75 = $70 & 255;
    $76 = $70 >>> 24;
    if ($32) {
     $$0144 = $66;$$0146 = $68;$$0162 = $69;
    } else {
     $77 = Math_imul($69, $11)|0;
     $78 = Math_imul($68, $8)|0;
     $79 = Math_imul($66, $5)|0;
     $80 = (($79>>>0) / 255)&-1;
     $81 = (($78>>>0) / 255)&-1;
     $82 = (($77>>>0) / 255)&-1;
     $$0144 = $80;$$0146 = $81;$$0162 = $82;
    }
    if ($or$cond) {
     $83 = Math_imul($$0162, $$164)|0;
     $84 = Math_imul($$0146, $$164)|0;
     $85 = Math_imul($$0144, $$164)|0;
     $86 = (($85>>>0) / 255)&-1;
     $87 = (($84>>>0) / 255)&-1;
     $88 = (($83>>>0) / 255)&-1;
     $$1145 = $86;$$1147 = $87;$$1163 = $88;
    } else {
     $$1145 = $$0144;$$1147 = $$0146;$$1163 = $$0162;
    }
    $trunc$clear = $trunc & 127;
    switch ($trunc$clear<<24>>24) {
    case 16:  {
     $89 = Math_imul($72, $39)|0;
     $90 = (($89>>>0) / 255)&-1;
     $91 = (($$1145) + ($90))|0;
     $92 = Math_imul($74, $39)|0;
     $93 = (($92>>>0) / 255)&-1;
     $94 = (($$1147) + ($93))|0;
     $95 = Math_imul($75, $39)|0;
     $96 = (($95>>>0) / 255)&-1;
     $97 = (($$1163) + ($96))|0;
     $98 = Math_imul($76, $39)|0;
     $99 = (($98>>>0) / 255)&-1;
     $100 = (($99) + ($$164))|0;
     $$0157 = $100;$$0158 = $97;$$0159 = $94;$$0160 = $91;
     break;
    }
    case 32:  {
     $101 = (($$1145) + ($72))|0;
     $102 = ($101>>>0)<(255);
     $$ = $102 ? $101 : 255;
     $103 = (($$1147) + ($74))|0;
     $104 = ($103>>>0)<(255);
     $$3 = $104 ? $103 : 255;
     $105 = (($$1163) + ($75))|0;
     $106 = ($105>>>0)<(255);
     $$1 = $106 ? $105 : 255;
     $$0157 = $76;$$0158 = $$1;$$0159 = $$3;$$0160 = $$;
     break;
    }
    case 64:  {
     $107 = Math_imul($$1145, $72)|0;
     $108 = (($107>>>0) / 255)&-1;
     $109 = Math_imul($$1147, $74)|0;
     $110 = (($109>>>0) / 255)&-1;
     $111 = Math_imul($$1163, $75)|0;
     $112 = (($111>>>0) / 255)&-1;
     $$0157 = $76;$$0158 = $112;$$0159 = $110;$$0160 = $108;
     break;
    }
    default: {
     $$0157 = $76;$$0158 = $75;$$0159 = $74;$$0160 = $72;
    }
    }
    $113 = $$0157 << 24;
    $114 = $$0160 << 16;
    $115 = $$0159 << 8;
    $116 = $115 | $114;
    $117 = $116 | $$0158;
    $118 = $117 | $113;
    HEAP32[$$0141177>>2] = $118;
    $119 = (($$2) + ($25))|0;
    $120 = ((($$0141177)) + 4|0);
    $121 = ($50|0)==(0);
    if ($121) {
     break;
    } else {
     $$0141177 = $120;$$0142176 = $$1143;$$0148175 = $119;$$0152174 = $$2154;$$in = $50;
    }
   }
   $$pre189 = HEAP32[$17>>2]|0;
   $126 = $$pre189;
  }
  $122 = HEAP32[$30>>2]|0;
  $123 = (($124) + ($122)|0);
  $125 = (($126) + -1)|0;
  HEAP32[$17>>2] = $125;
  $127 = ($126|0)==(0);
  if ($127) {
   break;
  }
  $128 = (($$1151$lcssa) + ($19))|0;
  $$pre188 = HEAP32[$23>>2]|0;
  $$0150181 = $128;$$0155180 = $$1156$lcssa;$124 = $123;$129 = $125;$130 = $123;$48 = $$pre188;
 }
 HEAP32[$29>>2] = $123;
 return;
}
function _SDL_Blit_BGR888_RGB888_Scale($0) {
 $0 = $0|0;
 var $$05982 = 0, $$06081 = 0, $$06186 = 0, $$06380 = 0, $$06579 = 0, $$06885 = 0, $$1 = 0, $$162$lcssa = 0, $$169$lcssa = 0, $$2 = 0, $$267 = 0, $$in = 0, $$pre = 0, $$pre93 = 0, $$pre94 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 << 16;
 $4 = ((($0)) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3|0) / ($5|0))&-1;
 $7 = ((($0)) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 << 16;
 $10 = ((($0)) + 24|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($9|0) / ($11|0))&-1;
 $13 = (($5) + -1)|0;
 HEAP32[$4>>2] = $13;
 $14 = ($5|0)==(0);
 if ($14) {
  return;
 }
 $15 = ((($0)) + 20|0);
 $16 = ((($0)) + 32|0);
 $17 = ((($0)) + 12|0);
 $$pre = HEAP32[$15>>2]|0;
 $$06186 = 0;$$06885 = 0;$25 = $11;$54 = $$pre;$59 = $13;$60 = $$pre;
 while(1) {
  $18 = ($$06885|0)>(65535);
  if ($18) {
   $19 = (($$06885) + -65536)|0;
   $20 = $19 >>> 16;
   $21 = $20 << 16;
   $22 = (($$06186) + 1)|0;
   $23 = (($22) + ($20))|0;
   $24 = (($19) - ($21))|0;
   $$162$lcssa = $23;$$169$lcssa = $24;
  } else {
   $$162$lcssa = $$06186;$$169$lcssa = $$06885;
  }
  $26 = ($25|0)==(0);
  if ($26) {
   $56 = $59;
  } else {
   $$05982 = $60;$$06081 = 0;$$06380 = -1;$$06579 = 65536;$$in = $25;
   while(1) {
    $27 = (($$in) + -1)|0;
    $28 = ($$06579|0)>(65535);
    if ($28) {
     $29 = (($$06579) + -65536)|0;
     $30 = $29 >>> 16;
     $31 = $30 << 16;
     $32 = (($$06380) + 1)|0;
     $33 = (($32) + ($30))|0;
     $34 = (($29) - ($31))|0;
     $35 = HEAP32[$0>>2]|0;
     $36 = HEAP32[$17>>2]|0;
     $37 = Math_imul($36, $$162$lcssa)|0;
     $38 = (($35) + ($37)|0);
     $39 = $33 << 2;
     $40 = (($38) + ($39)|0);
     $$1 = $40;$$2 = $33;$$267 = $34;
    } else {
     $$1 = $$06081;$$2 = $$06380;$$267 = $$06579;
    }
    $41 = HEAP32[$$1>>2]|0;
    $42 = $41 >>> 16;
    $43 = $42 & 255;
    $44 = $41 & 65280;
    $45 = $41 << 16;
    $46 = $45 & 16711680;
    $47 = $46 | $44;
    $48 = $47 | $43;
    HEAP32[$$05982>>2] = $48;
    $49 = (($$267) + ($12))|0;
    $50 = ((($$05982)) + 4|0);
    $51 = ($27|0)==(0);
    if ($51) {
     break;
    } else {
     $$05982 = $50;$$06081 = $$1;$$06380 = $$2;$$06579 = $49;$$in = $27;
    }
   }
   $$pre94 = HEAP32[$4>>2]|0;
   $56 = $$pre94;
  }
  $52 = HEAP32[$16>>2]|0;
  $53 = (($54) + ($52)|0);
  $55 = (($56) + -1)|0;
  HEAP32[$4>>2] = $55;
  $57 = ($56|0)==(0);
  if ($57) {
   break;
  }
  $58 = (($$169$lcssa) + ($6))|0;
  $$pre93 = HEAP32[$10>>2]|0;
  $$06186 = $$162$lcssa;$$06885 = $58;$25 = $$pre93;$54 = $53;$59 = $55;$60 = $53;
 }
 HEAP32[$15>>2] = $53;
 return;
}
function _SDL_Blit_BGR888_RGB888_Blend($0) {
 $0 = $0|0;
 var $$$us97 = 0, $$08594 = 0, $$08594$us = 0, $$08594$us95 = 0, $$08693 = 0, $$08693$us = 0, $$08693$us96 = 0, $$087 = 0, $$088 = 0, $$089 = 0, $$1$us99 = 0, $$3$us98 = 0, $$pre = 0, $$pre110 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $cond = 0, $trunc = 0, $trunc$clear = 0, $trunc$clear1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + -1)|0;
 HEAP32[$3>>2] = $5;
 $6 = ($4|0)==(0);
 if ($6) {
  return;
 }
 $7 = ((($0)) + 20|0);
 $8 = ((($0)) + 24|0);
 $9 = ((($0)) + 12|0);
 $10 = ((($0)) + 32|0);
 $11 = $2 & 112;
 $trunc = $11&255;
 $$pre = HEAP32[$0>>2]|0;
 $$pre110 = HEAP32[$7>>2]|0;
 $trunc$clear = $trunc & 127;
 $cond = ($trunc$clear<<24>>24)==(64);
 $84 = $$pre;$87 = $$pre110;$91 = $$pre110;$92 = $$pre;
 while(1) {
  $12 = HEAP32[$8>>2]|0;
  $13 = (($12) + -1)|0;
  $14 = ($12|0)==(0);
  if (!($14)) {
   $trunc$clear1 = $trunc & 127;
   switch ($trunc$clear1<<24>>24) {
   case 16:  {
    $$08594$us = $91;$$08693$us = $92;$26 = $13;
    while(1) {
     $15 = HEAP32[$$08693$us>>2]|0;
     $16 = $15 >>> 16;
     $17 = $16 & 255;
     $18 = $15 & 65280;
     $19 = $15 << 16;
     $20 = $19 & 16711680;
     $21 = $18 | $20;
     $22 = $21 | $17;
     HEAP32[$$08594$us>>2] = $22;
     $23 = ((($$08693$us)) + 4|0);
     $24 = ((($$08594$us)) + 4|0);
     $25 = (($26) + -1)|0;
     $27 = ($26|0)==(0);
     if ($27) {
      break;
     } else {
      $$08594$us = $24;$$08693$us = $23;$26 = $25;
     }
    }
    break;
   }
   case 32:  {
    $$08594$us95 = $91;$$08693$us96 = $92;$53 = $13;
    while(1) {
     $28 = HEAP32[$$08693$us96>>2]|0;
     $29 = $28 >>> 16;
     $30 = $29 & 255;
     $31 = $28 >>> 8;
     $32 = $31 & 255;
     $33 = $28 & 255;
     $34 = HEAP32[$$08594$us95>>2]|0;
     $35 = $34 >>> 16;
     $36 = $35 & 255;
     $37 = $34 >>> 8;
     $38 = $37 & 255;
     $39 = $34 & 255;
     $40 = (($36) + ($33))|0;
     $41 = ($40>>>0)<(255);
     $$$us97 = $41 ? $40 : 255;
     $42 = (($38) + ($32))|0;
     $43 = ($42>>>0)<(255);
     $$3$us98 = $43 ? $42 : 255;
     $44 = (($30) + ($39))|0;
     $45 = ($44>>>0)<(255);
     $$1$us99 = $45 ? $44 : 255;
     $46 = $$$us97 << 16;
     $47 = $$3$us98 << 8;
     $48 = $47 | $46;
     $49 = $48 | $$1$us99;
     HEAP32[$$08594$us95>>2] = $49;
     $50 = ((($$08693$us96)) + 4|0);
     $51 = ((($$08594$us95)) + 4|0);
     $52 = (($53) + -1)|0;
     $54 = ($53|0)==(0);
     if ($54) {
      break;
     } else {
      $$08594$us95 = $51;$$08693$us96 = $50;$53 = $52;
     }
    }
    break;
   }
   default: {
    $$08594 = $91;$$08693 = $92;$80 = $13;
    while(1) {
     $55 = HEAP32[$$08693>>2]|0;
     $56 = HEAP32[$$08594>>2]|0;
     $57 = $56 >>> 16;
     $58 = $57 & 255;
     $59 = $56 >>> 8;
     $60 = $59 & 255;
     $61 = $56 & 255;
     if ($cond) {
      $62 = $55 & 255;
      $63 = $55 >>> 8;
      $64 = $63 & 255;
      $65 = $55 >>> 16;
      $66 = $65 & 255;
      $67 = Math_imul($58, $62)|0;
      $68 = (($67>>>0) / 255)&-1;
      $69 = Math_imul($60, $64)|0;
      $70 = (($69>>>0) / 255)&-1;
      $71 = Math_imul($66, $61)|0;
      $72 = (($71>>>0) / 255)&-1;
      $$087 = $72;$$088 = $70;$$089 = $68;
     } else {
      $$087 = $61;$$088 = $60;$$089 = $58;
     }
     $73 = $$089 << 16;
     $74 = $$088 << 8;
     $75 = $74 | $73;
     $76 = $75 | $$087;
     HEAP32[$$08594>>2] = $76;
     $77 = ((($$08693)) + 4|0);
     $78 = ((($$08594)) + 4|0);
     $79 = (($80) + -1)|0;
     $81 = ($80|0)==(0);
     if ($81) {
      break;
     } else {
      $$08594 = $78;$$08693 = $77;$80 = $79;
     }
    }
   }
   }
  }
  $82 = HEAP32[$9>>2]|0;
  $83 = (($84) + ($82)|0);
  $85 = HEAP32[$10>>2]|0;
  $86 = (($87) + ($85)|0);
  $88 = HEAP32[$3>>2]|0;
  $89 = (($88) + -1)|0;
  HEAP32[$3>>2] = $89;
  $90 = ($88|0)==(0);
  if ($90) {
   break;
  } else {
   $84 = $83;$87 = $86;$91 = $86;$92 = $83;
  }
 }
 HEAP32[$0>>2] = $83;
 HEAP32[$7>>2] = $86;
 return;
}
function _SDL_Blit_BGR888_RGB888_Blend_Scale($0) {
 $0 = $0|0;
 var $$ = 0, $$0112142 = 0, $$0112142$us = 0, $$0113141 = 0, $$0113141$us = 0, $$0117140 = 0, $$0117140$us = 0, $$0119146 = 0, $$0121139 = 0, $$0121139$us = 0, $$0124145 = 0, $$0126 = 0, $$0127 = 0, $$0128 = 0, $$1 = 0, $$1114 = 0, $$1114$us = 0, $$1120$lcssa = 0, $$1125$lcssa = 0, $$2 = 0;
 var $$2$us = 0, $$2123 = 0, $$2123$us = 0, $$3 = 0, $$pre = 0, $$pre156 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $trunc = 0, $trunc$clear = 0, $trunc$clear1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 << 16;
 $6 = ((($0)) + 28|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5|0) / ($7|0))&-1;
 $9 = ((($0)) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10 << 16;
 $12 = ((($0)) + 24|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($11|0) / ($13|0))&-1;
 $15 = (($7) + -1)|0;
 HEAP32[$6>>2] = $15;
 $16 = ($7|0)==(0);
 if ($16) {
  return;
 }
 $17 = ((($0)) + 20|0);
 $18 = ((($0)) + 32|0);
 $19 = $2 & 112;
 $trunc = $19&255;
 $20 = ((($0)) + 12|0);
 $trunc$clear = $trunc & 127;
 $21 = ($trunc$clear<<24>>24)==(16);
 $$pre = HEAP32[$17>>2]|0;
 $$0119146 = 0;$$0124145 = 0;$106 = $$pre;$111 = $$pre;$30 = $13;
 while(1) {
  $22 = ($$0119146|0)>(65535);
  if ($22) {
   $23 = (($$0119146) + -65536)|0;
   $24 = $23 >>> 16;
   $25 = $24 << 16;
   $26 = (($$0124145) + 1)|0;
   $27 = (($26) + ($24))|0;
   $28 = (($23) - ($25))|0;
   $$1120$lcssa = $28;$$1125$lcssa = $27;
  } else {
   $$1120$lcssa = $$0119146;$$1125$lcssa = $$0124145;
  }
  $29 = (($30) + -1)|0;
  $31 = ($30|0)==(0);
  L9: do {
   if (!($31)) {
    if ($21) {
     $$0112142$us = $111;$$0113141$us = 0;$$0117140$us = 65536;$$0121139$us = -1;$56 = $29;
     while(1) {
      $32 = ($$0117140$us|0)>(65535);
      if ($32) {
       $33 = (($$0117140$us) + -65536)|0;
       $34 = $33 >>> 16;
       $35 = $34 << 16;
       $36 = (($$0121139$us) + 1)|0;
       $37 = (($36) + ($34))|0;
       $38 = (($33) - ($35))|0;
       $39 = HEAP32[$0>>2]|0;
       $40 = HEAP32[$20>>2]|0;
       $41 = Math_imul($40, $$1125$lcssa)|0;
       $42 = (($39) + ($41)|0);
       $43 = $37 << 2;
       $44 = (($42) + ($43)|0);
       $$1114$us = $44;$$2$us = $38;$$2123$us = $37;
      } else {
       $$1114$us = $$0113141$us;$$2$us = $$0117140$us;$$2123$us = $$0121139$us;
      }
      $45 = HEAP32[$$1114$us>>2]|0;
      $46 = $45 >>> 16;
      $47 = $46 & 255;
      $48 = $45 & 65280;
      $49 = $45 << 16;
      $50 = $49 & 16711680;
      $51 = $48 | $50;
      $52 = $51 | $47;
      HEAP32[$$0112142$us>>2] = $52;
      $53 = (($$2$us) + ($14))|0;
      $54 = ((($$0112142$us)) + 4|0);
      $55 = (($56) + -1)|0;
      $57 = ($56|0)==(0);
      if ($57) {
       break L9;
      } else {
       $$0112142$us = $54;$$0113141$us = $$1114$us;$$0117140$us = $53;$$0121139$us = $$2123$us;$56 = $55;
      }
     }
    } else {
     $$0112142 = $111;$$0113141 = 0;$$0117140 = 65536;$$0121139 = -1;$102 = $29;
    }
    while(1) {
     $58 = ($$0117140|0)>(65535);
     if ($58) {
      $59 = (($$0117140) + -65536)|0;
      $60 = $59 >>> 16;
      $61 = $60 << 16;
      $62 = (($$0121139) + 1)|0;
      $63 = (($62) + ($60))|0;
      $64 = (($59) - ($61))|0;
      $65 = HEAP32[$0>>2]|0;
      $66 = HEAP32[$20>>2]|0;
      $67 = Math_imul($66, $$1125$lcssa)|0;
      $68 = (($65) + ($67)|0);
      $69 = $63 << 2;
      $70 = (($68) + ($69)|0);
      $$1114 = $70;$$2 = $64;$$2123 = $63;
     } else {
      $$1114 = $$0113141;$$2 = $$0117140;$$2123 = $$0121139;
     }
     $71 = HEAP32[$$1114>>2]|0;
     $72 = $71 >>> 16;
     $73 = $72 & 255;
     $74 = $71 >>> 8;
     $75 = $74 & 255;
     $76 = $71 & 255;
     $77 = HEAP32[$$0112142>>2]|0;
     $78 = $77 >>> 16;
     $79 = $78 & 255;
     $80 = $77 >>> 8;
     $81 = $80 & 255;
     $82 = $77 & 255;
     $trunc$clear1 = $trunc & 127;
     switch ($trunc$clear1<<24>>24) {
     case 64:  {
      $89 = Math_imul($79, $76)|0;
      $90 = (($89>>>0) / 255)&-1;
      $91 = Math_imul($81, $75)|0;
      $92 = (($91>>>0) / 255)&-1;
      $93 = Math_imul($73, $82)|0;
      $94 = (($93>>>0) / 255)&-1;
      $$0126 = $94;$$0127 = $92;$$0128 = $90;
      break;
     }
     case 32:  {
      $83 = (($79) + ($76))|0;
      $84 = ($83>>>0)<(255);
      $$ = $84 ? $83 : 255;
      $85 = (($81) + ($75))|0;
      $86 = ($85>>>0)<(255);
      $$3 = $86 ? $85 : 255;
      $87 = (($73) + ($82))|0;
      $88 = ($87>>>0)<(255);
      $$1 = $88 ? $87 : 255;
      $$0126 = $$1;$$0127 = $$3;$$0128 = $$;
      break;
     }
     default: {
      $$0126 = $82;$$0127 = $81;$$0128 = $79;
     }
     }
     $95 = $$0128 << 16;
     $96 = $$0127 << 8;
     $97 = $96 | $95;
     $98 = $97 | $$0126;
     HEAP32[$$0112142>>2] = $98;
     $99 = (($$2) + ($14))|0;
     $100 = ((($$0112142)) + 4|0);
     $101 = (($102) + -1)|0;
     $103 = ($102|0)==(0);
     if ($103) {
      break L9;
     } else {
      $$0112142 = $100;$$0113141 = $$1114;$$0117140 = $99;$$0121139 = $$2123;$102 = $101;
     }
    }
   }
  } while(0);
  $104 = HEAP32[$18>>2]|0;
  $105 = (($106) + ($104)|0);
  $107 = HEAP32[$6>>2]|0;
  $108 = (($107) + -1)|0;
  HEAP32[$6>>2] = $108;
  $109 = ($107|0)==(0);
  if ($109) {
   break;
  }
  $110 = (($$1120$lcssa) + ($8))|0;
  $$pre156 = HEAP32[$12>>2]|0;
  $$0119146 = $110;$$0124145 = $$1125$lcssa;$106 = $105;$111 = $105;$30 = $$pre156;
 }
 HEAP32[$17>>2] = $105;
 return;
}
function _SDL_Blit_BGR888_RGB888_Modulate($0) {
 $0 = $0|0;
 var $$05157 = 0, $$05157$us$us = 0, $$05256 = 0, $$05256$us$us = 0, $$in = 0, $$in68 = 0, $$lcssa77$sink = 0, $$lcssa78$sink = 0, $$pre71 = 0, $$pre72 = 0, $$pre73 = 0, $$pre74 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = ((($0)) + 61|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = ((($0)) + 62|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = ((($0)) + 28|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($13) + -1)|0;
 HEAP32[$12>>2] = $14;
 $15 = ($13|0)==(0);
 if ($15) {
  return;
 }
 $16 = ((($0)) + 20|0);
 $17 = ((($0)) + 24|0);
 $18 = ((($0)) + 12|0);
 $19 = ((($0)) + 32|0);
 $20 = $2 & 1;
 $21 = ($20|0)==(0);
 $$pre72 = HEAP32[$0>>2]|0;
 $$pre73 = HEAP32[$16>>2]|0;
 if ($21) {
  $26 = $$pre72;$29 = $$pre73;$76 = $14;$77 = $$pre73;$78 = $$pre72;
  while(1) {
   $22 = HEAP32[$17>>2]|0;
   $23 = ($22|0)==(0);
   if ($23) {
    $31 = $76;
   } else {
    $$05157$us$us = $77;$$05256$us$us = $78;$$in68 = $22;
    while(1) {
     $33 = (($$in68) + -1)|0;
     $34 = HEAP32[$$05256$us$us>>2]|0;
     $35 = $34 >>> 16;
     $36 = $35 & 255;
     $37 = $34 & 65280;
     $38 = $34 << 16;
     $39 = $38 & 16711680;
     $40 = $37 | $39;
     $41 = $40 | $36;
     HEAP32[$$05157$us$us>>2] = $41;
     $42 = ((($$05256$us$us)) + 4|0);
     $43 = ((($$05157$us$us)) + 4|0);
     $44 = ($33|0)==(0);
     if ($44) {
      break;
     } else {
      $$05157$us$us = $43;$$05256$us$us = $42;$$in68 = $33;
     }
    }
    $$pre74 = HEAP32[$12>>2]|0;
    $31 = $$pre74;
   }
   $24 = HEAP32[$18>>2]|0;
   $25 = (($26) + ($24)|0);
   $27 = HEAP32[$19>>2]|0;
   $28 = (($29) + ($27)|0);
   $30 = (($31) + -1)|0;
   HEAP32[$12>>2] = $30;
   $32 = ($31|0)==(0);
   if ($32) {
    $$lcssa77$sink = $25;$$lcssa78$sink = $28;
    break;
   } else {
    $26 = $25;$29 = $28;$76 = $30;$77 = $28;$78 = $25;
   }
  }
 } else {
  $69 = $$pre72;$72 = $$pre73;$79 = $14;$80 = $$pre73;$81 = $$pre72;
  while(1) {
   $45 = HEAP32[$17>>2]|0;
   $46 = ($45|0)==(0);
   if ($46) {
    $74 = $79;
   } else {
    $$05157 = $80;$$05256 = $81;$$in = $45;
    while(1) {
     $47 = (($$in) + -1)|0;
     $48 = HEAP32[$$05256>>2]|0;
     $49 = $48 >>> 16;
     $50 = $49 & 255;
     $51 = $48 >>> 8;
     $52 = $51 & 255;
     $53 = $48 & 255;
     $54 = Math_imul($50, $11)|0;
     $55 = Math_imul($52, $8)|0;
     $56 = Math_imul($53, $5)|0;
     $57 = (($56>>>0) / 255)&-1;
     $58 = (($55>>>0) / 255)&-1;
     $59 = (($54>>>0) / 255)&-1;
     $60 = $57 << 16;
     $61 = $58 << 8;
     $62 = $61 | $60;
     $63 = $62 | $59;
     HEAP32[$$05157>>2] = $63;
     $64 = ((($$05256)) + 4|0);
     $65 = ((($$05157)) + 4|0);
     $66 = ($47|0)==(0);
     if ($66) {
      break;
     } else {
      $$05157 = $65;$$05256 = $64;$$in = $47;
     }
    }
    $$pre71 = HEAP32[$12>>2]|0;
    $74 = $$pre71;
   }
   $67 = HEAP32[$18>>2]|0;
   $68 = (($69) + ($67)|0);
   $70 = HEAP32[$19>>2]|0;
   $71 = (($72) + ($70)|0);
   $73 = (($74) + -1)|0;
   HEAP32[$12>>2] = $73;
   $75 = ($74|0)==(0);
   if ($75) {
    $$lcssa77$sink = $68;$$lcssa78$sink = $71;
    break;
   } else {
    $69 = $68;$72 = $71;$79 = $73;$80 = $71;$81 = $68;
   }
  }
 }
 HEAP32[$0>>2] = $$lcssa77$sink;
 HEAP32[$16>>2] = $$lcssa78$sink;
 return;
}
function _SDL_Blit_BGR888_RGB888_Modulate_Scale($0) {
 $0 = $0|0;
 var $$078104 = 0, $$078104$us = 0, $$079103 = 0, $$079103$us = 0, $$081102 = 0, $$081102$us = 0, $$083108 = 0, $$085101 = 0, $$085101$us = 0, $$088107 = 0, $$1 = 0, $$1$us = 0, $$184$lcssa = 0, $$189$lcssa = 0, $$2 = 0, $$2$us = 0, $$287 = 0, $$287$us = 0, $$pre = 0, $$pre118 = 0;
 var $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = ((($0)) + 61|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = ((($0)) + 62|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = ((($0)) + 8|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13 << 16;
 $15 = ((($0)) + 28|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($14|0) / ($16|0))&-1;
 $18 = ((($0)) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = $19 << 16;
 $21 = ((($0)) + 24|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($20|0) / ($22|0))&-1;
 $24 = (($16) + -1)|0;
 HEAP32[$15>>2] = $24;
 $25 = ($16|0)==(0);
 if ($25) {
  return;
 }
 $26 = ((($0)) + 20|0);
 $27 = ((($0)) + 32|0);
 $28 = $2 & 1;
 $29 = ($28|0)==(0);
 $30 = ((($0)) + 12|0);
 $$pre = HEAP32[$26>>2]|0;
 $$083108 = 0;$$088107 = 0;$103 = $$pre;$108 = $$pre;$39 = $22;
 while(1) {
  $31 = ($$083108|0)>(65535);
  if ($31) {
   $32 = (($$083108) + -65536)|0;
   $33 = $32 >>> 16;
   $34 = $33 << 16;
   $35 = (($$088107) + 1)|0;
   $36 = (($35) + ($33))|0;
   $37 = (($32) - ($34))|0;
   $$184$lcssa = $37;$$189$lcssa = $36;
  } else {
   $$184$lcssa = $$083108;$$189$lcssa = $$088107;
  }
  $38 = (($39) + -1)|0;
  $40 = ($39|0)==(0);
  if (!($40)) {
   if ($29) {
    $$078104$us = $108;$$079103$us = 0;$$081102$us = 65536;$$085101$us = -1;$65 = $38;
    while(1) {
     $41 = ($$081102$us|0)>(65535);
     if ($41) {
      $42 = (($$081102$us) + -65536)|0;
      $43 = $42 >>> 16;
      $44 = $43 << 16;
      $45 = (($$085101$us) + 1)|0;
      $46 = (($45) + ($43))|0;
      $47 = (($42) - ($44))|0;
      $48 = HEAP32[$0>>2]|0;
      $49 = HEAP32[$30>>2]|0;
      $50 = Math_imul($49, $$189$lcssa)|0;
      $51 = (($48) + ($50)|0);
      $52 = $46 << 2;
      $53 = (($51) + ($52)|0);
      $$1$us = $53;$$2$us = $47;$$287$us = $46;
     } else {
      $$1$us = $$079103$us;$$2$us = $$081102$us;$$287$us = $$085101$us;
     }
     $54 = HEAP32[$$1$us>>2]|0;
     $55 = $54 >>> 16;
     $56 = $55 & 255;
     $57 = $54 & 65280;
     $58 = $54 << 16;
     $59 = $58 & 16711680;
     $60 = $56 | $57;
     $61 = $60 | $59;
     HEAP32[$$078104$us>>2] = $61;
     $62 = (($$2$us) + ($23))|0;
     $63 = ((($$078104$us)) + 4|0);
     $64 = (($65) + -1)|0;
     $66 = ($65|0)==(0);
     if ($66) {
      break;
     } else {
      $$078104$us = $63;$$079103$us = $$1$us;$$081102$us = $62;$$085101$us = $$287$us;$65 = $64;
     }
    }
   } else {
    $$078104 = $108;$$079103 = 0;$$081102 = 65536;$$085101 = -1;$99 = $38;
    while(1) {
     $67 = ($$081102|0)>(65535);
     if ($67) {
      $68 = (($$081102) + -65536)|0;
      $69 = $68 >>> 16;
      $70 = $69 << 16;
      $71 = (($$085101) + 1)|0;
      $72 = (($71) + ($69))|0;
      $73 = (($68) - ($70))|0;
      $74 = HEAP32[$0>>2]|0;
      $75 = HEAP32[$30>>2]|0;
      $76 = Math_imul($75, $$189$lcssa)|0;
      $77 = (($74) + ($76)|0);
      $78 = $72 << 2;
      $79 = (($77) + ($78)|0);
      $$1 = $79;$$2 = $73;$$287 = $72;
     } else {
      $$1 = $$079103;$$2 = $$081102;$$287 = $$085101;
     }
     $80 = HEAP32[$$1>>2]|0;
     $81 = $80 >>> 16;
     $82 = $81 & 255;
     $83 = $80 >>> 8;
     $84 = $83 & 255;
     $85 = $80 & 255;
     $86 = Math_imul($82, $11)|0;
     $87 = Math_imul($84, $8)|0;
     $88 = Math_imul($85, $5)|0;
     $89 = (($88>>>0) / 255)&-1;
     $90 = (($87>>>0) / 255)&-1;
     $91 = (($86>>>0) / 255)&-1;
     $92 = $89 << 16;
     $93 = $90 << 8;
     $94 = $91 | $93;
     $95 = $94 | $92;
     HEAP32[$$078104>>2] = $95;
     $96 = (($$2) + ($23))|0;
     $97 = ((($$078104)) + 4|0);
     $98 = (($99) + -1)|0;
     $100 = ($99|0)==(0);
     if ($100) {
      break;
     } else {
      $$078104 = $97;$$079103 = $$1;$$081102 = $96;$$085101 = $$287;$99 = $98;
     }
    }
   }
  }
  $101 = HEAP32[$27>>2]|0;
  $102 = (($103) + ($101)|0);
  $104 = HEAP32[$15>>2]|0;
  $105 = (($104) + -1)|0;
  HEAP32[$15>>2] = $105;
  $106 = ($104|0)==(0);
  if ($106) {
   break;
  }
  $107 = (($$184$lcssa) + ($17))|0;
  $$pre118 = HEAP32[$21>>2]|0;
  $$083108 = $107;$$088107 = $$189$lcssa;$103 = $102;$108 = $102;$39 = $$pre118;
 }
 HEAP32[$26>>2] = $102;
 return;
}
function _SDL_Blit_BGR888_RGB888_Modulate_Blend($0) {
 $0 = $0|0;
 var $$ = 0, $$$us = 0, $$0107121 = 0, $$0107121$us = 0, $$0108120 = 0, $$0108120$us = 0, $$0109 = 0, $$0109$us = 0, $$0110 = 0, $$0110$us = 0, $$0111 = 0, $$0111$us = 0, $$1 = 0, $$1$us = 0, $$1114 = 0, $$1114$us = 0, $$1116 = 0, $$1116$us = 0, $$1118 = 0, $$1118$us = 0;
 var $$119 = 0, $$3 = 0, $$3$us = 0, $$pre = 0, $$pre126 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $trunc = 0, $trunc$clear = 0, $trunc$clear1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = ((($0)) + 61|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = ((($0)) + 62|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = ((($0)) + 63|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = ((($0)) + 28|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($15) + -1)|0;
 HEAP32[$14>>2] = $16;
 $17 = ($15|0)==(0);
 if ($17) {
  return;
 }
 $18 = $13&255;
 $19 = ((($0)) + 20|0);
 $20 = ((($0)) + 24|0);
 $21 = ((($0)) + 12|0);
 $22 = ((($0)) + 32|0);
 $23 = $2 & 1;
 $24 = ($23|0)==(0);
 $25 = $2 & 2;
 $26 = ($25|0)==(0);
 $$119 = $26 ? 255 : $18;
 $27 = $2 & 48;
 $28 = ($27|0)!=(0);
 $29 = ($$119|0)!=(255);
 $or$cond = $28 & $29;
 $30 = $2 & 112;
 $trunc = $30&255;
 $31 = $$119 ^ 255;
 $$pre = HEAP32[$0>>2]|0;
 $$pre126 = HEAP32[$19>>2]|0;
 $139 = $$pre;$142 = $$pre126;$146 = $$pre126;$147 = $$pre;
 while(1) {
  $32 = HEAP32[$20>>2]|0;
  $33 = (($32) + -1)|0;
  $34 = ($32|0)==(0);
  L6: do {
   if (!($34)) {
    if ($24) {
     $$0107121$us = $146;$$0108120$us = $147;$81 = $33;
     while(1) {
      $35 = HEAP32[$$0108120$us>>2]|0;
      $36 = $35 >>> 16;
      $37 = $36 & 255;
      $38 = $35 >>> 8;
      $39 = $38 & 255;
      $40 = $35 & 255;
      $41 = HEAP32[$$0107121$us>>2]|0;
      $42 = $41 >>> 16;
      $43 = $42 & 255;
      $44 = $41 >>> 8;
      $45 = $44 & 255;
      $46 = $41 & 255;
      if ($or$cond) {
       $47 = Math_imul($37, $$119)|0;
       $48 = Math_imul($39, $$119)|0;
       $49 = Math_imul($40, $$119)|0;
       $50 = (($49>>>0) / 255)&-1;
       $51 = (($48>>>0) / 255)&-1;
       $52 = (($47>>>0) / 255)&-1;
       $$1114$us = $52;$$1116$us = $51;$$1118$us = $50;
      } else {
       $$1114$us = $37;$$1116$us = $39;$$1118$us = $40;
      }
      $trunc$clear = $trunc & 127;
      switch ($trunc$clear<<24>>24) {
      case 16:  {
       $65 = Math_imul($43, $31)|0;
       $66 = (($65>>>0) / 255)&-1;
       $67 = (($$1118$us) + ($66))|0;
       $68 = Math_imul($45, $31)|0;
       $69 = (($68>>>0) / 255)&-1;
       $70 = (($$1116$us) + ($69))|0;
       $71 = Math_imul($46, $31)|0;
       $72 = (($71>>>0) / 255)&-1;
       $73 = (($$1114$us) + ($72))|0;
       $$0109$us = $73;$$0110$us = $70;$$0111$us = $67;
       break;
      }
      case 32:  {
       $59 = (($$1118$us) + ($43))|0;
       $60 = ($59>>>0)<(255);
       $$$us = $60 ? $59 : 255;
       $61 = (($$1116$us) + ($45))|0;
       $62 = ($61>>>0)<(255);
       $$3$us = $62 ? $61 : 255;
       $63 = (($$1114$us) + ($46))|0;
       $64 = ($63>>>0)<(255);
       $$1$us = $64 ? $63 : 255;
       $$0109$us = $$1$us;$$0110$us = $$3$us;$$0111$us = $$$us;
       break;
      }
      case 64:  {
       $53 = Math_imul($$1118$us, $43)|0;
       $54 = (($53>>>0) / 255)&-1;
       $55 = Math_imul($$1116$us, $45)|0;
       $56 = (($55>>>0) / 255)&-1;
       $57 = Math_imul($$1114$us, $46)|0;
       $58 = (($57>>>0) / 255)&-1;
       $$0109$us = $58;$$0110$us = $56;$$0111$us = $54;
       break;
      }
      default: {
       $$0109$us = $46;$$0110$us = $45;$$0111$us = $43;
      }
      }
      $74 = $$0111$us << 16;
      $75 = $$0110$us << 8;
      $76 = $75 | $74;
      $77 = $76 | $$0109$us;
      HEAP32[$$0107121$us>>2] = $77;
      $78 = ((($$0108120$us)) + 4|0);
      $79 = ((($$0107121$us)) + 4|0);
      $80 = (($81) + -1)|0;
      $82 = ($81|0)==(0);
      if ($82) {
       break L6;
      } else {
       $$0107121$us = $79;$$0108120$us = $78;$81 = $80;
      }
     }
    } else {
     $$0107121 = $146;$$0108120 = $147;$135 = $33;
     while(1) {
      $83 = HEAP32[$$0108120>>2]|0;
      $84 = $83 >>> 16;
      $85 = $84 & 255;
      $86 = $83 >>> 8;
      $87 = $86 & 255;
      $88 = $83 & 255;
      $89 = HEAP32[$$0107121>>2]|0;
      $90 = $89 >>> 16;
      $91 = $90 & 255;
      $92 = $89 >>> 8;
      $93 = $92 & 255;
      $94 = $89 & 255;
      $95 = Math_imul($85, $11)|0;
      $96 = Math_imul($87, $8)|0;
      $97 = Math_imul($88, $5)|0;
      $98 = (($97>>>0) / 255)&-1;
      $99 = (($96>>>0) / 255)&-1;
      $100 = (($95>>>0) / 255)&-1;
      if ($or$cond) {
       $101 = Math_imul($100, $$119)|0;
       $102 = Math_imul($99, $$119)|0;
       $103 = Math_imul($98, $$119)|0;
       $104 = (($103>>>0) / 255)&-1;
       $105 = (($102>>>0) / 255)&-1;
       $106 = (($101>>>0) / 255)&-1;
       $$1114 = $106;$$1116 = $105;$$1118 = $104;
      } else {
       $$1114 = $100;$$1116 = $99;$$1118 = $98;
      }
      $trunc$clear1 = $trunc & 127;
      switch ($trunc$clear1<<24>>24) {
      case 16:  {
       $107 = Math_imul($91, $31)|0;
       $108 = (($107>>>0) / 255)&-1;
       $109 = (($$1118) + ($108))|0;
       $110 = Math_imul($93, $31)|0;
       $111 = (($110>>>0) / 255)&-1;
       $112 = (($$1116) + ($111))|0;
       $113 = Math_imul($94, $31)|0;
       $114 = (($113>>>0) / 255)&-1;
       $115 = (($$1114) + ($114))|0;
       $$0109 = $115;$$0110 = $112;$$0111 = $109;
       break;
      }
      case 32:  {
       $116 = (($$1118) + ($91))|0;
       $117 = ($116>>>0)<(255);
       $$ = $117 ? $116 : 255;
       $118 = (($$1116) + ($93))|0;
       $119 = ($118>>>0)<(255);
       $$3 = $119 ? $118 : 255;
       $120 = (($$1114) + ($94))|0;
       $121 = ($120>>>0)<(255);
       $$1 = $121 ? $120 : 255;
       $$0109 = $$1;$$0110 = $$3;$$0111 = $$;
       break;
      }
      case 64:  {
       $122 = Math_imul($$1118, $91)|0;
       $123 = (($122>>>0) / 255)&-1;
       $124 = Math_imul($$1116, $93)|0;
       $125 = (($124>>>0) / 255)&-1;
       $126 = Math_imul($$1114, $94)|0;
       $127 = (($126>>>0) / 255)&-1;
       $$0109 = $127;$$0110 = $125;$$0111 = $123;
       break;
      }
      default: {
       $$0109 = $94;$$0110 = $93;$$0111 = $91;
      }
      }
      $128 = $$0111 << 16;
      $129 = $$0110 << 8;
      $130 = $129 | $128;
      $131 = $130 | $$0109;
      HEAP32[$$0107121>>2] = $131;
      $132 = ((($$0108120)) + 4|0);
      $133 = ((($$0107121)) + 4|0);
      $134 = (($135) + -1)|0;
      $136 = ($135|0)==(0);
      if ($136) {
       break L6;
      } else {
       $$0107121 = $133;$$0108120 = $132;$135 = $134;
      }
     }
    }
   }
  } while(0);
  $137 = HEAP32[$21>>2]|0;
  $138 = (($139) + ($137)|0);
  $140 = HEAP32[$22>>2]|0;
  $141 = (($142) + ($140)|0);
  $143 = HEAP32[$14>>2]|0;
  $144 = (($143) + -1)|0;
  HEAP32[$14>>2] = $144;
  $145 = ($143|0)==(0);
  if ($145) {
   break;
  } else {
   $139 = $138;$142 = $141;$146 = $141;$147 = $138;
  }
 }
 HEAP32[$0>>2] = $138;
 HEAP32[$19>>2] = $141;
 return;
}
function _SDL_Blit_BGR888_RGB888_Modulate_Blend_Scale($0) {
 $0 = $0|0;
 var $$ = 0, $$0134169 = 0, $$0135168 = 0, $$0137 = 0, $$0139 = 0, $$0141167 = 0, $$0143173 = 0, $$0145166 = 0, $$0148172 = 0, $$0150 = 0, $$0151 = 0, $$0152 = 0, $$0154 = 0, $$1 = 0, $$1136 = 0, $$1138 = 0, $$1140 = 0, $$1144$lcssa = 0, $$1149$lcssa = 0, $$1155 = 0;
 var $$156 = 0, $$2 = 0, $$2147 = 0, $$3 = 0, $$in = 0, $$pre = 0, $$pre180 = 0, $$pre181 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $trunc = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = ((($0)) + 61|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = ((($0)) + 62|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = ((($0)) + 63|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = ((($0)) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = $15 << 16;
 $17 = ((($0)) + 28|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($16|0) / ($18|0))&-1;
 $20 = ((($0)) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = $21 << 16;
 $23 = ((($0)) + 24|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (($22|0) / ($24|0))&-1;
 $26 = (($18) + -1)|0;
 HEAP32[$17>>2] = $26;
 $27 = ($18|0)==(0);
 if ($27) {
  return;
 }
 $28 = $13&255;
 $29 = ((($0)) + 20|0);
 $30 = ((($0)) + 32|0);
 $31 = $2 & 1;
 $32 = ($31|0)==(0);
 $33 = $2 & 2;
 $34 = ($33|0)==(0);
 $$156 = $34 ? 255 : $28;
 $35 = $2 & 48;
 $36 = ($35|0)!=(0);
 $37 = ($$156|0)!=(255);
 $or$cond = $36 & $37;
 $38 = $2 & 112;
 $trunc = $38&255;
 $39 = $$156 ^ 255;
 $40 = ((($0)) + 12|0);
 $$pre = HEAP32[$29>>2]|0;
 $$0143173 = 0;$$0148172 = 0;$118 = $$pre;$123 = $26;$124 = $$pre;$48 = $24;
 while(1) {
  $41 = ($$0143173|0)>(65535);
  if ($41) {
   $42 = (($$0143173) + -65536)|0;
   $43 = $42 >>> 16;
   $44 = $43 << 16;
   $45 = (($$0148172) + 1)|0;
   $46 = (($45) + ($43))|0;
   $47 = (($42) - ($44))|0;
   $$1144$lcssa = $47;$$1149$lcssa = $46;
  } else {
   $$1144$lcssa = $$0143173;$$1149$lcssa = $$0148172;
  }
  $49 = ($48|0)==(0);
  if ($49) {
   $120 = $123;
  } else {
   $$0134169 = $124;$$0135168 = 0;$$0141167 = 65536;$$0145166 = -1;$$in = $48;
   while(1) {
    $50 = (($$in) + -1)|0;
    $51 = ($$0141167|0)>(65535);
    if ($51) {
     $52 = (($$0141167) + -65536)|0;
     $53 = $52 >>> 16;
     $54 = $53 << 16;
     $55 = (($$0145166) + 1)|0;
     $56 = (($55) + ($53))|0;
     $57 = (($52) - ($54))|0;
     $58 = HEAP32[$0>>2]|0;
     $59 = HEAP32[$40>>2]|0;
     $60 = Math_imul($59, $$1149$lcssa)|0;
     $61 = (($58) + ($60)|0);
     $62 = $56 << 2;
     $63 = (($61) + ($62)|0);
     $$1136 = $63;$$2 = $57;$$2147 = $56;
    } else {
     $$1136 = $$0135168;$$2 = $$0141167;$$2147 = $$0145166;
    }
    $64 = HEAP32[$$1136>>2]|0;
    $65 = $64 >>> 16;
    $66 = $65 & 255;
    $67 = $64 >>> 8;
    $68 = $67 & 255;
    $69 = $64 & 255;
    $70 = HEAP32[$$0134169>>2]|0;
    $71 = $70 >>> 16;
    $72 = $71 & 255;
    $73 = $70 >>> 8;
    $74 = $73 & 255;
    $75 = $70 & 255;
    if ($32) {
     $$0137 = $69;$$0139 = $68;$$0154 = $66;
    } else {
     $76 = Math_imul($66, $11)|0;
     $77 = Math_imul($68, $8)|0;
     $78 = Math_imul($69, $5)|0;
     $79 = (($78>>>0) / 255)&-1;
     $80 = (($77>>>0) / 255)&-1;
     $81 = (($76>>>0) / 255)&-1;
     $$0137 = $79;$$0139 = $80;$$0154 = $81;
    }
    if ($or$cond) {
     $82 = Math_imul($$0154, $$156)|0;
     $83 = Math_imul($$0139, $$156)|0;
     $84 = Math_imul($$0137, $$156)|0;
     $85 = (($84>>>0) / 255)&-1;
     $86 = (($83>>>0) / 255)&-1;
     $87 = (($82>>>0) / 255)&-1;
     $$1138 = $85;$$1140 = $86;$$1155 = $87;
    } else {
     $$1138 = $$0137;$$1140 = $$0139;$$1155 = $$0154;
    }
    $trunc$clear = $trunc & 127;
    switch ($trunc$clear<<24>>24) {
    case 16:  {
     $88 = Math_imul($72, $39)|0;
     $89 = (($88>>>0) / 255)&-1;
     $90 = (($$1138) + ($89))|0;
     $91 = Math_imul($74, $39)|0;
     $92 = (($91>>>0) / 255)&-1;
     $93 = (($$1140) + ($92))|0;
     $94 = Math_imul($75, $39)|0;
     $95 = (($94>>>0) / 255)&-1;
     $96 = (($$1155) + ($95))|0;
     $$0150 = $96;$$0151 = $93;$$0152 = $90;
     break;
    }
    case 32:  {
     $97 = (($$1138) + ($72))|0;
     $98 = ($97>>>0)<(255);
     $$ = $98 ? $97 : 255;
     $99 = (($$1140) + ($74))|0;
     $100 = ($99>>>0)<(255);
     $$3 = $100 ? $99 : 255;
     $101 = (($$1155) + ($75))|0;
     $102 = ($101>>>0)<(255);
     $$1 = $102 ? $101 : 255;
     $$0150 = $$1;$$0151 = $$3;$$0152 = $$;
     break;
    }
    case 64:  {
     $103 = Math_imul($$1138, $72)|0;
     $104 = (($103>>>0) / 255)&-1;
     $105 = Math_imul($$1140, $74)|0;
     $106 = (($105>>>0) / 255)&-1;
     $107 = Math_imul($$1155, $75)|0;
     $108 = (($107>>>0) / 255)&-1;
     $$0150 = $108;$$0151 = $106;$$0152 = $104;
     break;
    }
    default: {
     $$0150 = $75;$$0151 = $74;$$0152 = $72;
    }
    }
    $109 = $$0152 << 16;
    $110 = $$0151 << 8;
    $111 = $110 | $109;
    $112 = $111 | $$0150;
    HEAP32[$$0134169>>2] = $112;
    $113 = (($$2) + ($25))|0;
    $114 = ((($$0134169)) + 4|0);
    $115 = ($50|0)==(0);
    if ($115) {
     break;
    } else {
     $$0134169 = $114;$$0135168 = $$1136;$$0141167 = $113;$$0145166 = $$2147;$$in = $50;
    }
   }
   $$pre181 = HEAP32[$17>>2]|0;
   $120 = $$pre181;
  }
  $116 = HEAP32[$30>>2]|0;
  $117 = (($118) + ($116)|0);
  $119 = (($120) + -1)|0;
  HEAP32[$17>>2] = $119;
  $121 = ($120|0)==(0);
  if ($121) {
   break;
  }
  $122 = (($$1144$lcssa) + ($19))|0;
  $$pre180 = HEAP32[$23>>2]|0;
  $$0143173 = $122;$$0148172 = $$1149$lcssa;$118 = $117;$123 = $119;$124 = $117;$48 = $$pre180;
 }
 HEAP32[$29>>2] = $117;
 return;
}
function _SDL_Blit_BGR888_BGR888_Scale($0) {
 $0 = $0|0;
 var $$04467 = 0, $$04566 = 0, $$04671 = 0, $$04865 = 0, $$05064 = 0, $$05370 = 0, $$1 = 0, $$147$lcssa = 0, $$154$lcssa = 0, $$2 = 0, $$252 = 0, $$in = 0, $$pre = 0, $$pre78 = 0, $$pre79 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 << 16;
 $4 = ((($0)) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3|0) / ($5|0))&-1;
 $7 = ((($0)) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 << 16;
 $10 = ((($0)) + 24|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($9|0) / ($11|0))&-1;
 $13 = (($5) + -1)|0;
 HEAP32[$4>>2] = $13;
 $14 = ($5|0)==(0);
 if ($14) {
  return;
 }
 $15 = ((($0)) + 20|0);
 $16 = ((($0)) + 32|0);
 $17 = ((($0)) + 12|0);
 $$pre = HEAP32[$15>>2]|0;
 $$04671 = 0;$$05370 = 0;$25 = $11;$47 = $$pre;$52 = $13;$53 = $$pre;
 while(1) {
  $18 = ($$05370|0)>(65535);
  if ($18) {
   $19 = (($$05370) + -65536)|0;
   $20 = $19 >>> 16;
   $21 = $20 << 16;
   $22 = (($$04671) + 1)|0;
   $23 = (($22) + ($20))|0;
   $24 = (($19) - ($21))|0;
   $$147$lcssa = $23;$$154$lcssa = $24;
  } else {
   $$147$lcssa = $$04671;$$154$lcssa = $$05370;
  }
  $26 = ($25|0)==(0);
  if ($26) {
   $49 = $52;
  } else {
   $$04467 = $53;$$04566 = 0;$$04865 = -1;$$05064 = 65536;$$in = $25;
   while(1) {
    $27 = (($$in) + -1)|0;
    $28 = ($$05064|0)>(65535);
    if ($28) {
     $29 = (($$05064) + -65536)|0;
     $30 = $29 >>> 16;
     $31 = $30 << 16;
     $32 = (($$04865) + 1)|0;
     $33 = (($32) + ($30))|0;
     $34 = (($29) - ($31))|0;
     $35 = HEAP32[$0>>2]|0;
     $36 = HEAP32[$17>>2]|0;
     $37 = Math_imul($36, $$147$lcssa)|0;
     $38 = (($35) + ($37)|0);
     $39 = $33 << 2;
     $40 = (($38) + ($39)|0);
     $$1 = $40;$$2 = $33;$$252 = $34;
    } else {
     $$1 = $$04566;$$2 = $$04865;$$252 = $$05064;
    }
    $41 = HEAP32[$$1>>2]|0;
    HEAP32[$$04467>>2] = $41;
    $42 = (($$252) + ($12))|0;
    $43 = ((($$04467)) + 4|0);
    $44 = ($27|0)==(0);
    if ($44) {
     break;
    } else {
     $$04467 = $43;$$04566 = $$1;$$04865 = $$2;$$05064 = $42;$$in = $27;
    }
   }
   $$pre79 = HEAP32[$4>>2]|0;
   $49 = $$pre79;
  }
  $45 = HEAP32[$16>>2]|0;
  $46 = (($47) + ($45)|0);
  $48 = (($49) + -1)|0;
  HEAP32[$4>>2] = $48;
  $50 = ($49|0)==(0);
  if ($50) {
   break;
  }
  $51 = (($$154$lcssa) + ($6))|0;
  $$pre78 = HEAP32[$10>>2]|0;
  $$04671 = $$147$lcssa;$$05370 = $51;$25 = $$pre78;$47 = $46;$52 = $48;$53 = $46;
 }
 HEAP32[$15>>2] = $46;
 return;
}
function _SDL_Blit_BGR888_BGR888_Blend($0) {
 $0 = $0|0;
 var $$$us97 = 0, $$08594 = 0, $$08594$us = 0, $$08594$us95 = 0, $$08693 = 0, $$08693$us = 0, $$08693$us96 = 0, $$087 = 0, $$088 = 0, $$089 = 0, $$1$us99 = 0, $$3$us98 = 0, $$pre = 0, $$pre110 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $9 = 0;
 var $cond = 0, $trunc = 0, $trunc$clear = 0, $trunc$clear1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + -1)|0;
 HEAP32[$3>>2] = $5;
 $6 = ($4|0)==(0);
 if ($6) {
  return;
 }
 $7 = ((($0)) + 20|0);
 $8 = ((($0)) + 24|0);
 $9 = ((($0)) + 12|0);
 $10 = ((($0)) + 32|0);
 $11 = $2 & 112;
 $trunc = $11&255;
 $$pre = HEAP32[$0>>2]|0;
 $$pre110 = HEAP32[$7>>2]|0;
 $trunc$clear = $trunc & 127;
 $cond = ($trunc$clear<<24>>24)==(64);
 $78 = $$pre;$81 = $$pre110;$85 = $$pre110;$86 = $$pre;
 while(1) {
  $12 = HEAP32[$8>>2]|0;
  $13 = (($12) + -1)|0;
  $14 = ($12|0)==(0);
  if (!($14)) {
   $trunc$clear1 = $trunc & 127;
   switch ($trunc$clear1<<24>>24) {
   case 16:  {
    $$08594$us = $85;$$08693$us = $86;$20 = $13;
    while(1) {
     $15 = HEAP32[$$08693$us>>2]|0;
     $16 = $15 & 16777215;
     HEAP32[$$08594$us>>2] = $16;
     $17 = ((($$08693$us)) + 4|0);
     $18 = ((($$08594$us)) + 4|0);
     $19 = (($20) + -1)|0;
     $21 = ($20|0)==(0);
     if ($21) {
      break;
     } else {
      $$08594$us = $18;$$08693$us = $17;$20 = $19;
     }
    }
    break;
   }
   case 32:  {
    $$08594$us95 = $85;$$08693$us96 = $86;$47 = $13;
    while(1) {
     $22 = HEAP32[$$08693$us96>>2]|0;
     $23 = $22 >>> 16;
     $24 = $23 & 255;
     $25 = $22 >>> 8;
     $26 = $25 & 255;
     $27 = $22 & 255;
     $28 = HEAP32[$$08594$us95>>2]|0;
     $29 = $28 >>> 16;
     $30 = $29 & 255;
     $31 = $28 >>> 8;
     $32 = $31 & 255;
     $33 = $28 & 255;
     $34 = (($33) + ($27))|0;
     $35 = ($34>>>0)<(255);
     $$$us97 = $35 ? $34 : 255;
     $36 = (($32) + ($26))|0;
     $37 = ($36>>>0)<(255);
     $$3$us98 = $37 ? $36 : 255;
     $38 = (($30) + ($24))|0;
     $39 = ($38>>>0)<(255);
     $$1$us99 = $39 ? $38 : 255;
     $40 = $$1$us99 << 16;
     $41 = $$3$us98 << 8;
     $42 = $41 | $$$us97;
     $43 = $42 | $40;
     HEAP32[$$08594$us95>>2] = $43;
     $44 = ((($$08693$us96)) + 4|0);
     $45 = ((($$08594$us95)) + 4|0);
     $46 = (($47) + -1)|0;
     $48 = ($47|0)==(0);
     if ($48) {
      break;
     } else {
      $$08594$us95 = $45;$$08693$us96 = $44;$47 = $46;
     }
    }
    break;
   }
   default: {
    $$08594 = $85;$$08693 = $86;$74 = $13;
    while(1) {
     $49 = HEAP32[$$08693>>2]|0;
     $50 = HEAP32[$$08594>>2]|0;
     $51 = $50 >>> 16;
     $52 = $51 & 255;
     $53 = $50 >>> 8;
     $54 = $53 & 255;
     $55 = $50 & 255;
     if ($cond) {
      $56 = $49 & 255;
      $57 = $49 >>> 8;
      $58 = $57 & 255;
      $59 = $49 >>> 16;
      $60 = $59 & 255;
      $61 = Math_imul($55, $56)|0;
      $62 = (($61>>>0) / 255)&-1;
      $63 = Math_imul($54, $58)|0;
      $64 = (($63>>>0) / 255)&-1;
      $65 = Math_imul($52, $60)|0;
      $66 = (($65>>>0) / 255)&-1;
      $$087 = $66;$$088 = $64;$$089 = $62;
     } else {
      $$087 = $52;$$088 = $54;$$089 = $55;
     }
     $67 = $$087 << 16;
     $68 = $$088 << 8;
     $69 = $68 | $$089;
     $70 = $69 | $67;
     HEAP32[$$08594>>2] = $70;
     $71 = ((($$08693)) + 4|0);
     $72 = ((($$08594)) + 4|0);
     $73 = (($74) + -1)|0;
     $75 = ($74|0)==(0);
     if ($75) {
      break;
     } else {
      $$08594 = $72;$$08693 = $71;$74 = $73;
     }
    }
   }
   }
  }
  $76 = HEAP32[$9>>2]|0;
  $77 = (($78) + ($76)|0);
  $79 = HEAP32[$10>>2]|0;
  $80 = (($81) + ($79)|0);
  $82 = HEAP32[$3>>2]|0;
  $83 = (($82) + -1)|0;
  HEAP32[$3>>2] = $83;
  $84 = ($82|0)==(0);
  if ($84) {
   break;
  } else {
   $78 = $77;$81 = $80;$85 = $80;$86 = $77;
  }
 }
 HEAP32[$0>>2] = $77;
 HEAP32[$7>>2] = $80;
 return;
}
function _SDL_Blit_BGR888_BGR888_Blend_Scale($0) {
 $0 = $0|0;
 var $$ = 0, $$0112142 = 0, $$0112142$us = 0, $$0113141 = 0, $$0113141$us = 0, $$0117140 = 0, $$0117140$us = 0, $$0119146 = 0, $$0121139 = 0, $$0121139$us = 0, $$0124145 = 0, $$0126 = 0, $$0127 = 0, $$0128 = 0, $$1 = 0, $$1114 = 0, $$1114$us = 0, $$1120$lcssa = 0, $$1125$lcssa = 0, $$2 = 0;
 var $$2$us = 0, $$2123 = 0, $$2123$us = 0, $$3 = 0, $$pre = 0, $$pre156 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $trunc = 0, $trunc$clear = 0, $trunc$clear1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 << 16;
 $6 = ((($0)) + 28|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5|0) / ($7|0))&-1;
 $9 = ((($0)) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10 << 16;
 $12 = ((($0)) + 24|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($11|0) / ($13|0))&-1;
 $15 = (($7) + -1)|0;
 HEAP32[$6>>2] = $15;
 $16 = ($7|0)==(0);
 if ($16) {
  return;
 }
 $17 = ((($0)) + 20|0);
 $18 = ((($0)) + 32|0);
 $19 = $2 & 112;
 $trunc = $19&255;
 $20 = ((($0)) + 12|0);
 $trunc$clear = $trunc & 127;
 $21 = ($trunc$clear<<24>>24)==(16);
 $$pre = HEAP32[$17>>2]|0;
 $$0119146 = 0;$$0124145 = 0;$100 = $$pre;$105 = $$pre;$30 = $13;
 while(1) {
  $22 = ($$0119146|0)>(65535);
  if ($22) {
   $23 = (($$0119146) + -65536)|0;
   $24 = $23 >>> 16;
   $25 = $24 << 16;
   $26 = (($$0124145) + 1)|0;
   $27 = (($26) + ($24))|0;
   $28 = (($23) - ($25))|0;
   $$1120$lcssa = $28;$$1125$lcssa = $27;
  } else {
   $$1120$lcssa = $$0119146;$$1125$lcssa = $$0124145;
  }
  $29 = (($30) + -1)|0;
  $31 = ($30|0)==(0);
  L9: do {
   if (!($31)) {
    if ($21) {
     $$0112142$us = $105;$$0113141$us = 0;$$0117140$us = 65536;$$0121139$us = -1;$50 = $29;
     while(1) {
      $32 = ($$0117140$us|0)>(65535);
      if ($32) {
       $33 = (($$0117140$us) + -65536)|0;
       $34 = $33 >>> 16;
       $35 = $34 << 16;
       $36 = (($$0121139$us) + 1)|0;
       $37 = (($36) + ($34))|0;
       $38 = (($33) - ($35))|0;
       $39 = HEAP32[$0>>2]|0;
       $40 = HEAP32[$20>>2]|0;
       $41 = Math_imul($40, $$1125$lcssa)|0;
       $42 = (($39) + ($41)|0);
       $43 = $37 << 2;
       $44 = (($42) + ($43)|0);
       $$1114$us = $44;$$2$us = $38;$$2123$us = $37;
      } else {
       $$1114$us = $$0113141$us;$$2$us = $$0117140$us;$$2123$us = $$0121139$us;
      }
      $45 = HEAP32[$$1114$us>>2]|0;
      $46 = $45 & 16777215;
      HEAP32[$$0112142$us>>2] = $46;
      $47 = (($$2$us) + ($14))|0;
      $48 = ((($$0112142$us)) + 4|0);
      $49 = (($50) + -1)|0;
      $51 = ($50|0)==(0);
      if ($51) {
       break L9;
      } else {
       $$0112142$us = $48;$$0113141$us = $$1114$us;$$0117140$us = $47;$$0121139$us = $$2123$us;$50 = $49;
      }
     }
    } else {
     $$0112142 = $105;$$0113141 = 0;$$0117140 = 65536;$$0121139 = -1;$96 = $29;
    }
    while(1) {
     $52 = ($$0117140|0)>(65535);
     if ($52) {
      $53 = (($$0117140) + -65536)|0;
      $54 = $53 >>> 16;
      $55 = $54 << 16;
      $56 = (($$0121139) + 1)|0;
      $57 = (($56) + ($54))|0;
      $58 = (($53) - ($55))|0;
      $59 = HEAP32[$0>>2]|0;
      $60 = HEAP32[$20>>2]|0;
      $61 = Math_imul($60, $$1125$lcssa)|0;
      $62 = (($59) + ($61)|0);
      $63 = $57 << 2;
      $64 = (($62) + ($63)|0);
      $$1114 = $64;$$2 = $58;$$2123 = $57;
     } else {
      $$1114 = $$0113141;$$2 = $$0117140;$$2123 = $$0121139;
     }
     $65 = HEAP32[$$1114>>2]|0;
     $66 = $65 >>> 16;
     $67 = $66 & 255;
     $68 = $65 >>> 8;
     $69 = $68 & 255;
     $70 = $65 & 255;
     $71 = HEAP32[$$0112142>>2]|0;
     $72 = $71 >>> 16;
     $73 = $72 & 255;
     $74 = $71 >>> 8;
     $75 = $74 & 255;
     $76 = $71 & 255;
     $trunc$clear1 = $trunc & 127;
     switch ($trunc$clear1<<24>>24) {
     case 64:  {
      $83 = Math_imul($76, $70)|0;
      $84 = (($83>>>0) / 255)&-1;
      $85 = Math_imul($75, $69)|0;
      $86 = (($85>>>0) / 255)&-1;
      $87 = Math_imul($73, $67)|0;
      $88 = (($87>>>0) / 255)&-1;
      $$0126 = $88;$$0127 = $86;$$0128 = $84;
      break;
     }
     case 32:  {
      $77 = (($76) + ($70))|0;
      $78 = ($77>>>0)<(255);
      $$ = $78 ? $77 : 255;
      $79 = (($75) + ($69))|0;
      $80 = ($79>>>0)<(255);
      $$3 = $80 ? $79 : 255;
      $81 = (($73) + ($67))|0;
      $82 = ($81>>>0)<(255);
      $$1 = $82 ? $81 : 255;
      $$0126 = $$1;$$0127 = $$3;$$0128 = $$;
      break;
     }
     default: {
      $$0126 = $73;$$0127 = $75;$$0128 = $76;
     }
     }
     $89 = $$0126 << 16;
     $90 = $$0127 << 8;
     $91 = $90 | $$0128;
     $92 = $91 | $89;
     HEAP32[$$0112142>>2] = $92;
     $93 = (($$2) + ($14))|0;
     $94 = ((($$0112142)) + 4|0);
     $95 = (($96) + -1)|0;
     $97 = ($96|0)==(0);
     if ($97) {
      break L9;
     } else {
      $$0112142 = $94;$$0113141 = $$1114;$$0117140 = $93;$$0121139 = $$2123;$96 = $95;
     }
    }
   }
  } while(0);
  $98 = HEAP32[$18>>2]|0;
  $99 = (($100) + ($98)|0);
  $101 = HEAP32[$6>>2]|0;
  $102 = (($101) + -1)|0;
  HEAP32[$6>>2] = $102;
  $103 = ($101|0)==(0);
  if ($103) {
   break;
  }
  $104 = (($$1120$lcssa) + ($8))|0;
  $$pre156 = HEAP32[$12>>2]|0;
  $$0119146 = $104;$$0124145 = $$1125$lcssa;$100 = $99;$105 = $99;$30 = $$pre156;
 }
 HEAP32[$17>>2] = $99;
 return;
}
function _SDL_Blit_BGR888_BGR888_Modulate($0) {
 $0 = $0|0;
 var $$05157 = 0, $$05157$us$us = 0, $$05256 = 0, $$05256$us$us = 0, $$in = 0, $$in68 = 0, $$lcssa77$sink = 0, $$lcssa78$sink = 0, $$pre71 = 0, $$pre72 = 0, $$pre73 = 0, $$pre74 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = ((($0)) + 61|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = ((($0)) + 62|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = ((($0)) + 28|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($13) + -1)|0;
 HEAP32[$12>>2] = $14;
 $15 = ($13|0)==(0);
 if ($15) {
  return;
 }
 $16 = ((($0)) + 20|0);
 $17 = ((($0)) + 24|0);
 $18 = ((($0)) + 12|0);
 $19 = ((($0)) + 32|0);
 $20 = $2 & 1;
 $21 = ($20|0)==(0);
 $$pre72 = HEAP32[$0>>2]|0;
 $$pre73 = HEAP32[$16>>2]|0;
 if ($21) {
  $26 = $$pre72;$29 = $$pre73;$70 = $14;$71 = $$pre73;$72 = $$pre72;
  while(1) {
   $22 = HEAP32[$17>>2]|0;
   $23 = ($22|0)==(0);
   if ($23) {
    $31 = $70;
   } else {
    $$05157$us$us = $71;$$05256$us$us = $72;$$in68 = $22;
    while(1) {
     $33 = (($$in68) + -1)|0;
     $34 = HEAP32[$$05256$us$us>>2]|0;
     $35 = $34 & 16777215;
     HEAP32[$$05157$us$us>>2] = $35;
     $36 = ((($$05256$us$us)) + 4|0);
     $37 = ((($$05157$us$us)) + 4|0);
     $38 = ($33|0)==(0);
     if ($38) {
      break;
     } else {
      $$05157$us$us = $37;$$05256$us$us = $36;$$in68 = $33;
     }
    }
    $$pre74 = HEAP32[$12>>2]|0;
    $31 = $$pre74;
   }
   $24 = HEAP32[$18>>2]|0;
   $25 = (($26) + ($24)|0);
   $27 = HEAP32[$19>>2]|0;
   $28 = (($29) + ($27)|0);
   $30 = (($31) + -1)|0;
   HEAP32[$12>>2] = $30;
   $32 = ($31|0)==(0);
   if ($32) {
    $$lcssa77$sink = $25;$$lcssa78$sink = $28;
    break;
   } else {
    $26 = $25;$29 = $28;$70 = $30;$71 = $28;$72 = $25;
   }
  }
 } else {
  $63 = $$pre72;$66 = $$pre73;$73 = $14;$74 = $$pre73;$75 = $$pre72;
  while(1) {
   $39 = HEAP32[$17>>2]|0;
   $40 = ($39|0)==(0);
   if ($40) {
    $68 = $73;
   } else {
    $$05157 = $74;$$05256 = $75;$$in = $39;
    while(1) {
     $41 = (($$in) + -1)|0;
     $42 = HEAP32[$$05256>>2]|0;
     $43 = $42 >>> 16;
     $44 = $43 & 255;
     $45 = $42 >>> 8;
     $46 = $45 & 255;
     $47 = $42 & 255;
     $48 = Math_imul($44, $11)|0;
     $49 = Math_imul($46, $8)|0;
     $50 = Math_imul($47, $5)|0;
     $51 = (($50>>>0) / 255)&-1;
     $52 = (($49>>>0) / 255)&-1;
     $53 = (($48>>>0) / 255)&-1;
     $54 = $53 << 16;
     $55 = $52 << 8;
     $56 = $55 | $51;
     $57 = $56 | $54;
     HEAP32[$$05157>>2] = $57;
     $58 = ((($$05256)) + 4|0);
     $59 = ((($$05157)) + 4|0);
     $60 = ($41|0)==(0);
     if ($60) {
      break;
     } else {
      $$05157 = $59;$$05256 = $58;$$in = $41;
     }
    }
    $$pre71 = HEAP32[$12>>2]|0;
    $68 = $$pre71;
   }
   $61 = HEAP32[$18>>2]|0;
   $62 = (($63) + ($61)|0);
   $64 = HEAP32[$19>>2]|0;
   $65 = (($66) + ($64)|0);
   $67 = (($68) + -1)|0;
   HEAP32[$12>>2] = $67;
   $69 = ($68|0)==(0);
   if ($69) {
    $$lcssa77$sink = $62;$$lcssa78$sink = $65;
    break;
   } else {
    $63 = $62;$66 = $65;$73 = $67;$74 = $65;$75 = $62;
   }
  }
 }
 HEAP32[$0>>2] = $$lcssa77$sink;
 HEAP32[$16>>2] = $$lcssa78$sink;
 return;
}
function _SDL_Blit_BGR888_BGR888_Modulate_Scale($0) {
 $0 = $0|0;
 var $$078104 = 0, $$078104$us = 0, $$079103 = 0, $$079103$us = 0, $$081102 = 0, $$081102$us = 0, $$083108 = 0, $$085101 = 0, $$085101$us = 0, $$088107 = 0, $$1 = 0, $$1$us = 0, $$184$lcssa = 0, $$189$lcssa = 0, $$2 = 0, $$2$us = 0, $$287 = 0, $$287$us = 0, $$pre = 0, $$pre118 = 0;
 var $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = ((($0)) + 61|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = ((($0)) + 62|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = ((($0)) + 8|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13 << 16;
 $15 = ((($0)) + 28|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($14|0) / ($16|0))&-1;
 $18 = ((($0)) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = $19 << 16;
 $21 = ((($0)) + 24|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($20|0) / ($22|0))&-1;
 $24 = (($16) + -1)|0;
 HEAP32[$15>>2] = $24;
 $25 = ($16|0)==(0);
 if ($25) {
  return;
 }
 $26 = ((($0)) + 20|0);
 $27 = ((($0)) + 32|0);
 $28 = $2 & 1;
 $29 = ($28|0)==(0);
 $30 = ((($0)) + 12|0);
 $$pre = HEAP32[$26>>2]|0;
 $$083108 = 0;$$088107 = 0;$102 = $$pre;$39 = $22;$97 = $$pre;
 while(1) {
  $31 = ($$083108|0)>(65535);
  if ($31) {
   $32 = (($$083108) + -65536)|0;
   $33 = $32 >>> 16;
   $34 = $33 << 16;
   $35 = (($$088107) + 1)|0;
   $36 = (($35) + ($33))|0;
   $37 = (($32) - ($34))|0;
   $$184$lcssa = $37;$$189$lcssa = $36;
  } else {
   $$184$lcssa = $$083108;$$189$lcssa = $$088107;
  }
  $38 = (($39) + -1)|0;
  $40 = ($39|0)==(0);
  if (!($40)) {
   if ($29) {
    $$078104$us = $102;$$079103$us = 0;$$081102$us = 65536;$$085101$us = -1;$59 = $38;
    while(1) {
     $41 = ($$081102$us|0)>(65535);
     if ($41) {
      $42 = (($$081102$us) + -65536)|0;
      $43 = $42 >>> 16;
      $44 = $43 << 16;
      $45 = (($$085101$us) + 1)|0;
      $46 = (($45) + ($43))|0;
      $47 = (($42) - ($44))|0;
      $48 = HEAP32[$0>>2]|0;
      $49 = HEAP32[$30>>2]|0;
      $50 = Math_imul($49, $$189$lcssa)|0;
      $51 = (($48) + ($50)|0);
      $52 = $46 << 2;
      $53 = (($51) + ($52)|0);
      $$1$us = $53;$$2$us = $47;$$287$us = $46;
     } else {
      $$1$us = $$079103$us;$$2$us = $$081102$us;$$287$us = $$085101$us;
     }
     $54 = HEAP32[$$1$us>>2]|0;
     $55 = $54 & 16777215;
     HEAP32[$$078104$us>>2] = $55;
     $56 = (($$2$us) + ($23))|0;
     $57 = ((($$078104$us)) + 4|0);
     $58 = (($59) + -1)|0;
     $60 = ($59|0)==(0);
     if ($60) {
      break;
     } else {
      $$078104$us = $57;$$079103$us = $$1$us;$$081102$us = $56;$$085101$us = $$287$us;$59 = $58;
     }
    }
   } else {
    $$078104 = $102;$$079103 = 0;$$081102 = 65536;$$085101 = -1;$93 = $38;
    while(1) {
     $61 = ($$081102|0)>(65535);
     if ($61) {
      $62 = (($$081102) + -65536)|0;
      $63 = $62 >>> 16;
      $64 = $63 << 16;
      $65 = (($$085101) + 1)|0;
      $66 = (($65) + ($63))|0;
      $67 = (($62) - ($64))|0;
      $68 = HEAP32[$0>>2]|0;
      $69 = HEAP32[$30>>2]|0;
      $70 = Math_imul($69, $$189$lcssa)|0;
      $71 = (($68) + ($70)|0);
      $72 = $66 << 2;
      $73 = (($71) + ($72)|0);
      $$1 = $73;$$2 = $67;$$287 = $66;
     } else {
      $$1 = $$079103;$$2 = $$081102;$$287 = $$085101;
     }
     $74 = HEAP32[$$1>>2]|0;
     $75 = $74 >>> 16;
     $76 = $75 & 255;
     $77 = $74 >>> 8;
     $78 = $77 & 255;
     $79 = $74 & 255;
     $80 = Math_imul($76, $11)|0;
     $81 = Math_imul($78, $8)|0;
     $82 = Math_imul($79, $5)|0;
     $83 = (($82>>>0) / 255)&-1;
     $84 = (($81>>>0) / 255)&-1;
     $85 = (($80>>>0) / 255)&-1;
     $86 = $85 << 16;
     $87 = $84 << 8;
     $88 = $86 | $87;
     $89 = $88 | $83;
     HEAP32[$$078104>>2] = $89;
     $90 = (($$2) + ($23))|0;
     $91 = ((($$078104)) + 4|0);
     $92 = (($93) + -1)|0;
     $94 = ($93|0)==(0);
     if ($94) {
      break;
     } else {
      $$078104 = $91;$$079103 = $$1;$$081102 = $90;$$085101 = $$287;$93 = $92;
     }
    }
   }
  }
  $95 = HEAP32[$27>>2]|0;
  $96 = (($97) + ($95)|0);
  $98 = HEAP32[$15>>2]|0;
  $99 = (($98) + -1)|0;
  HEAP32[$15>>2] = $99;
  $100 = ($98|0)==(0);
  if ($100) {
   break;
  }
  $101 = (($$184$lcssa) + ($17))|0;
  $$pre118 = HEAP32[$21>>2]|0;
  $$083108 = $101;$$088107 = $$189$lcssa;$102 = $96;$39 = $$pre118;$97 = $96;
 }
 HEAP32[$26>>2] = $96;
 return;
}
function _SDL_Blit_BGR888_BGR888_Modulate_Blend($0) {
 $0 = $0|0;
 var $$ = 0, $$$us = 0, $$0107121 = 0, $$0107121$us = 0, $$0108120 = 0, $$0108120$us = 0, $$0109 = 0, $$0109$us = 0, $$0110 = 0, $$0110$us = 0, $$0111 = 0, $$0111$us = 0, $$1 = 0, $$1$us = 0, $$1114 = 0, $$1114$us = 0, $$1116 = 0, $$1116$us = 0, $$1118 = 0, $$1118$us = 0;
 var $$119 = 0, $$3 = 0, $$3$us = 0, $$pre = 0, $$pre126 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $trunc = 0, $trunc$clear = 0, $trunc$clear1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = ((($0)) + 61|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = ((($0)) + 62|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = ((($0)) + 63|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = ((($0)) + 28|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($15) + -1)|0;
 HEAP32[$14>>2] = $16;
 $17 = ($15|0)==(0);
 if ($17) {
  return;
 }
 $18 = $13&255;
 $19 = ((($0)) + 20|0);
 $20 = ((($0)) + 24|0);
 $21 = ((($0)) + 12|0);
 $22 = ((($0)) + 32|0);
 $23 = $2 & 1;
 $24 = ($23|0)==(0);
 $25 = $2 & 2;
 $26 = ($25|0)==(0);
 $$119 = $26 ? 255 : $18;
 $27 = $2 & 48;
 $28 = ($27|0)!=(0);
 $29 = ($$119|0)!=(255);
 $or$cond = $28 & $29;
 $30 = $2 & 112;
 $trunc = $30&255;
 $31 = $$119 ^ 255;
 $$pre = HEAP32[$0>>2]|0;
 $$pre126 = HEAP32[$19>>2]|0;
 $139 = $$pre;$142 = $$pre126;$146 = $$pre126;$147 = $$pre;
 while(1) {
  $32 = HEAP32[$20>>2]|0;
  $33 = (($32) + -1)|0;
  $34 = ($32|0)==(0);
  L6: do {
   if (!($34)) {
    if ($24) {
     $$0107121$us = $146;$$0108120$us = $147;$81 = $33;
     while(1) {
      $35 = HEAP32[$$0108120$us>>2]|0;
      $36 = $35 >>> 16;
      $37 = $36 & 255;
      $38 = $35 >>> 8;
      $39 = $38 & 255;
      $40 = $35 & 255;
      $41 = HEAP32[$$0107121$us>>2]|0;
      $42 = $41 >>> 16;
      $43 = $42 & 255;
      $44 = $41 >>> 8;
      $45 = $44 & 255;
      $46 = $41 & 255;
      if ($or$cond) {
       $47 = Math_imul($37, $$119)|0;
       $48 = Math_imul($39, $$119)|0;
       $49 = Math_imul($40, $$119)|0;
       $50 = (($49>>>0) / 255)&-1;
       $51 = (($48>>>0) / 255)&-1;
       $52 = (($47>>>0) / 255)&-1;
       $$1114$us = $52;$$1116$us = $51;$$1118$us = $50;
      } else {
       $$1114$us = $37;$$1116$us = $39;$$1118$us = $40;
      }
      $trunc$clear = $trunc & 127;
      switch ($trunc$clear<<24>>24) {
      case 16:  {
       $65 = Math_imul($46, $31)|0;
       $66 = (($65>>>0) / 255)&-1;
       $67 = (($$1118$us) + ($66))|0;
       $68 = Math_imul($45, $31)|0;
       $69 = (($68>>>0) / 255)&-1;
       $70 = (($$1116$us) + ($69))|0;
       $71 = Math_imul($43, $31)|0;
       $72 = (($71>>>0) / 255)&-1;
       $73 = (($$1114$us) + ($72))|0;
       $$0109$us = $73;$$0110$us = $70;$$0111$us = $67;
       break;
      }
      case 32:  {
       $59 = (($$1118$us) + ($46))|0;
       $60 = ($59>>>0)<(255);
       $$$us = $60 ? $59 : 255;
       $61 = (($$1116$us) + ($45))|0;
       $62 = ($61>>>0)<(255);
       $$3$us = $62 ? $61 : 255;
       $63 = (($$1114$us) + ($43))|0;
       $64 = ($63>>>0)<(255);
       $$1$us = $64 ? $63 : 255;
       $$0109$us = $$1$us;$$0110$us = $$3$us;$$0111$us = $$$us;
       break;
      }
      case 64:  {
       $53 = Math_imul($$1118$us, $46)|0;
       $54 = (($53>>>0) / 255)&-1;
       $55 = Math_imul($$1116$us, $45)|0;
       $56 = (($55>>>0) / 255)&-1;
       $57 = Math_imul($$1114$us, $43)|0;
       $58 = (($57>>>0) / 255)&-1;
       $$0109$us = $58;$$0110$us = $56;$$0111$us = $54;
       break;
      }
      default: {
       $$0109$us = $43;$$0110$us = $45;$$0111$us = $46;
      }
      }
      $74 = $$0109$us << 16;
      $75 = $$0110$us << 8;
      $76 = $75 | $$0111$us;
      $77 = $76 | $74;
      HEAP32[$$0107121$us>>2] = $77;
      $78 = ((($$0108120$us)) + 4|0);
      $79 = ((($$0107121$us)) + 4|0);
      $80 = (($81) + -1)|0;
      $82 = ($81|0)==(0);
      if ($82) {
       break L6;
      } else {
       $$0107121$us = $79;$$0108120$us = $78;$81 = $80;
      }
     }
    } else {
     $$0107121 = $146;$$0108120 = $147;$135 = $33;
     while(1) {
      $83 = HEAP32[$$0108120>>2]|0;
      $84 = $83 >>> 16;
      $85 = $84 & 255;
      $86 = $83 >>> 8;
      $87 = $86 & 255;
      $88 = $83 & 255;
      $89 = HEAP32[$$0107121>>2]|0;
      $90 = $89 >>> 16;
      $91 = $90 & 255;
      $92 = $89 >>> 8;
      $93 = $92 & 255;
      $94 = $89 & 255;
      $95 = Math_imul($85, $11)|0;
      $96 = Math_imul($87, $8)|0;
      $97 = Math_imul($88, $5)|0;
      $98 = (($97>>>0) / 255)&-1;
      $99 = (($96>>>0) / 255)&-1;
      $100 = (($95>>>0) / 255)&-1;
      if ($or$cond) {
       $101 = Math_imul($100, $$119)|0;
       $102 = Math_imul($99, $$119)|0;
       $103 = Math_imul($98, $$119)|0;
       $104 = (($103>>>0) / 255)&-1;
       $105 = (($102>>>0) / 255)&-1;
       $106 = (($101>>>0) / 255)&-1;
       $$1114 = $106;$$1116 = $105;$$1118 = $104;
      } else {
       $$1114 = $100;$$1116 = $99;$$1118 = $98;
      }
      $trunc$clear1 = $trunc & 127;
      switch ($trunc$clear1<<24>>24) {
      case 16:  {
       $107 = Math_imul($94, $31)|0;
       $108 = (($107>>>0) / 255)&-1;
       $109 = (($$1118) + ($108))|0;
       $110 = Math_imul($93, $31)|0;
       $111 = (($110>>>0) / 255)&-1;
       $112 = (($$1116) + ($111))|0;
       $113 = Math_imul($91, $31)|0;
       $114 = (($113>>>0) / 255)&-1;
       $115 = (($$1114) + ($114))|0;
       $$0109 = $115;$$0110 = $112;$$0111 = $109;
       break;
      }
      case 32:  {
       $116 = (($$1118) + ($94))|0;
       $117 = ($116>>>0)<(255);
       $$ = $117 ? $116 : 255;
       $118 = (($$1116) + ($93))|0;
       $119 = ($118>>>0)<(255);
       $$3 = $119 ? $118 : 255;
       $120 = (($$1114) + ($91))|0;
       $121 = ($120>>>0)<(255);
       $$1 = $121 ? $120 : 255;
       $$0109 = $$1;$$0110 = $$3;$$0111 = $$;
       break;
      }
      case 64:  {
       $122 = Math_imul($$1118, $94)|0;
       $123 = (($122>>>0) / 255)&-1;
       $124 = Math_imul($$1116, $93)|0;
       $125 = (($124>>>0) / 255)&-1;
       $126 = Math_imul($$1114, $91)|0;
       $127 = (($126>>>0) / 255)&-1;
       $$0109 = $127;$$0110 = $125;$$0111 = $123;
       break;
      }
      default: {
       $$0109 = $91;$$0110 = $93;$$0111 = $94;
      }
      }
      $128 = $$0109 << 16;
      $129 = $$0110 << 8;
      $130 = $129 | $$0111;
      $131 = $130 | $128;
      HEAP32[$$0107121>>2] = $131;
      $132 = ((($$0108120)) + 4|0);
      $133 = ((($$0107121)) + 4|0);
      $134 = (($135) + -1)|0;
      $136 = ($135|0)==(0);
      if ($136) {
       break L6;
      } else {
       $$0107121 = $133;$$0108120 = $132;$135 = $134;
      }
     }
    }
   }
  } while(0);
  $137 = HEAP32[$21>>2]|0;
  $138 = (($139) + ($137)|0);
  $140 = HEAP32[$22>>2]|0;
  $141 = (($142) + ($140)|0);
  $143 = HEAP32[$14>>2]|0;
  $144 = (($143) + -1)|0;
  HEAP32[$14>>2] = $144;
  $145 = ($143|0)==(0);
  if ($145) {
   break;
  } else {
   $139 = $138;$142 = $141;$146 = $141;$147 = $138;
  }
 }
 HEAP32[$0>>2] = $138;
 HEAP32[$19>>2] = $141;
 return;
}
function _SDL_Blit_BGR888_BGR888_Modulate_Blend_Scale($0) {
 $0 = $0|0;
 var $$ = 0, $$0134169 = 0, $$0135168 = 0, $$0137 = 0, $$0139 = 0, $$0141167 = 0, $$0143173 = 0, $$0145166 = 0, $$0148172 = 0, $$0150 = 0, $$0151 = 0, $$0152 = 0, $$0154 = 0, $$1 = 0, $$1136 = 0, $$1138 = 0, $$1140 = 0, $$1144$lcssa = 0, $$1149$lcssa = 0, $$1155 = 0;
 var $$156 = 0, $$2 = 0, $$2147 = 0, $$3 = 0, $$in = 0, $$pre = 0, $$pre180 = 0, $$pre181 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $trunc = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = ((($0)) + 61|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = ((($0)) + 62|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = ((($0)) + 63|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = ((($0)) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = $15 << 16;
 $17 = ((($0)) + 28|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($16|0) / ($18|0))&-1;
 $20 = ((($0)) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = $21 << 16;
 $23 = ((($0)) + 24|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (($22|0) / ($24|0))&-1;
 $26 = (($18) + -1)|0;
 HEAP32[$17>>2] = $26;
 $27 = ($18|0)==(0);
 if ($27) {
  return;
 }
 $28 = $13&255;
 $29 = ((($0)) + 20|0);
 $30 = ((($0)) + 32|0);
 $31 = $2 & 1;
 $32 = ($31|0)==(0);
 $33 = $2 & 2;
 $34 = ($33|0)==(0);
 $$156 = $34 ? 255 : $28;
 $35 = $2 & 48;
 $36 = ($35|0)!=(0);
 $37 = ($$156|0)!=(255);
 $or$cond = $36 & $37;
 $38 = $2 & 112;
 $trunc = $38&255;
 $39 = $$156 ^ 255;
 $40 = ((($0)) + 12|0);
 $$pre = HEAP32[$29>>2]|0;
 $$0143173 = 0;$$0148172 = 0;$118 = $$pre;$123 = $26;$124 = $$pre;$48 = $24;
 while(1) {
  $41 = ($$0143173|0)>(65535);
  if ($41) {
   $42 = (($$0143173) + -65536)|0;
   $43 = $42 >>> 16;
   $44 = $43 << 16;
   $45 = (($$0148172) + 1)|0;
   $46 = (($45) + ($43))|0;
   $47 = (($42) - ($44))|0;
   $$1144$lcssa = $47;$$1149$lcssa = $46;
  } else {
   $$1144$lcssa = $$0143173;$$1149$lcssa = $$0148172;
  }
  $49 = ($48|0)==(0);
  if ($49) {
   $120 = $123;
  } else {
   $$0134169 = $124;$$0135168 = 0;$$0141167 = 65536;$$0145166 = -1;$$in = $48;
   while(1) {
    $50 = (($$in) + -1)|0;
    $51 = ($$0141167|0)>(65535);
    if ($51) {
     $52 = (($$0141167) + -65536)|0;
     $53 = $52 >>> 16;
     $54 = $53 << 16;
     $55 = (($$0145166) + 1)|0;
     $56 = (($55) + ($53))|0;
     $57 = (($52) - ($54))|0;
     $58 = HEAP32[$0>>2]|0;
     $59 = HEAP32[$40>>2]|0;
     $60 = Math_imul($59, $$1149$lcssa)|0;
     $61 = (($58) + ($60)|0);
     $62 = $56 << 2;
     $63 = (($61) + ($62)|0);
     $$1136 = $63;$$2 = $57;$$2147 = $56;
    } else {
     $$1136 = $$0135168;$$2 = $$0141167;$$2147 = $$0145166;
    }
    $64 = HEAP32[$$1136>>2]|0;
    $65 = $64 >>> 16;
    $66 = $65 & 255;
    $67 = $64 >>> 8;
    $68 = $67 & 255;
    $69 = $64 & 255;
    $70 = HEAP32[$$0134169>>2]|0;
    $71 = $70 >>> 16;
    $72 = $71 & 255;
    $73 = $70 >>> 8;
    $74 = $73 & 255;
    $75 = $70 & 255;
    if ($32) {
     $$0137 = $69;$$0139 = $68;$$0154 = $66;
    } else {
     $76 = Math_imul($66, $11)|0;
     $77 = Math_imul($68, $8)|0;
     $78 = Math_imul($69, $5)|0;
     $79 = (($78>>>0) / 255)&-1;
     $80 = (($77>>>0) / 255)&-1;
     $81 = (($76>>>0) / 255)&-1;
     $$0137 = $79;$$0139 = $80;$$0154 = $81;
    }
    if ($or$cond) {
     $82 = Math_imul($$0154, $$156)|0;
     $83 = Math_imul($$0139, $$156)|0;
     $84 = Math_imul($$0137, $$156)|0;
     $85 = (($84>>>0) / 255)&-1;
     $86 = (($83>>>0) / 255)&-1;
     $87 = (($82>>>0) / 255)&-1;
     $$1138 = $85;$$1140 = $86;$$1155 = $87;
    } else {
     $$1138 = $$0137;$$1140 = $$0139;$$1155 = $$0154;
    }
    $trunc$clear = $trunc & 127;
    switch ($trunc$clear<<24>>24) {
    case 16:  {
     $88 = Math_imul($75, $39)|0;
     $89 = (($88>>>0) / 255)&-1;
     $90 = (($$1138) + ($89))|0;
     $91 = Math_imul($74, $39)|0;
     $92 = (($91>>>0) / 255)&-1;
     $93 = (($$1140) + ($92))|0;
     $94 = Math_imul($72, $39)|0;
     $95 = (($94>>>0) / 255)&-1;
     $96 = (($$1155) + ($95))|0;
     $$0150 = $96;$$0151 = $93;$$0152 = $90;
     break;
    }
    case 32:  {
     $97 = (($$1138) + ($75))|0;
     $98 = ($97>>>0)<(255);
     $$ = $98 ? $97 : 255;
     $99 = (($$1140) + ($74))|0;
     $100 = ($99>>>0)<(255);
     $$3 = $100 ? $99 : 255;
     $101 = (($$1155) + ($72))|0;
     $102 = ($101>>>0)<(255);
     $$1 = $102 ? $101 : 255;
     $$0150 = $$1;$$0151 = $$3;$$0152 = $$;
     break;
    }
    case 64:  {
     $103 = Math_imul($$1138, $75)|0;
     $104 = (($103>>>0) / 255)&-1;
     $105 = Math_imul($$1140, $74)|0;
     $106 = (($105>>>0) / 255)&-1;
     $107 = Math_imul($$1155, $72)|0;
     $108 = (($107>>>0) / 255)&-1;
     $$0150 = $108;$$0151 = $106;$$0152 = $104;
     break;
    }
    default: {
     $$0150 = $72;$$0151 = $74;$$0152 = $75;
    }
    }
    $109 = $$0150 << 16;
    $110 = $$0151 << 8;
    $111 = $110 | $$0152;
    $112 = $111 | $109;
    HEAP32[$$0134169>>2] = $112;
    $113 = (($$2) + ($25))|0;
    $114 = ((($$0134169)) + 4|0);
    $115 = ($50|0)==(0);
    if ($115) {
     break;
    } else {
     $$0134169 = $114;$$0135168 = $$1136;$$0141167 = $113;$$0145166 = $$2147;$$in = $50;
    }
   }
   $$pre181 = HEAP32[$17>>2]|0;
   $120 = $$pre181;
  }
  $116 = HEAP32[$30>>2]|0;
  $117 = (($118) + ($116)|0);
  $119 = (($120) + -1)|0;
  HEAP32[$17>>2] = $119;
  $121 = ($120|0)==(0);
  if ($121) {
   break;
  }
  $122 = (($$1144$lcssa) + ($19))|0;
  $$pre180 = HEAP32[$23>>2]|0;
  $$0143173 = $122;$$0148172 = $$1149$lcssa;$118 = $117;$123 = $119;$124 = $117;$48 = $$pre180;
 }
 HEAP32[$29>>2] = $117;
 return;
}
function _SDL_Blit_BGR888_ARGB8888_Scale($0) {
 $0 = $0|0;
 var $$06285 = 0, $$06384 = 0, $$06489 = 0, $$06683 = 0, $$06882 = 0, $$07188 = 0, $$1 = 0, $$165$lcssa = 0, $$172$lcssa = 0, $$2 = 0, $$270 = 0, $$in = 0, $$pre = 0, $$pre96 = 0, $$pre97 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 << 16;
 $4 = ((($0)) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3|0) / ($5|0))&-1;
 $7 = ((($0)) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 << 16;
 $10 = ((($0)) + 24|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($9|0) / ($11|0))&-1;
 $13 = (($5) + -1)|0;
 HEAP32[$4>>2] = $13;
 $14 = ($5|0)==(0);
 if ($14) {
  return;
 }
 $15 = ((($0)) + 20|0);
 $16 = ((($0)) + 32|0);
 $17 = ((($0)) + 12|0);
 $$pre = HEAP32[$15>>2]|0;
 $$06489 = 0;$$07188 = 0;$25 = $11;$54 = $$pre;$59 = $13;$60 = $$pre;
 while(1) {
  $18 = ($$07188|0)>(65535);
  if ($18) {
   $19 = (($$07188) + -65536)|0;
   $20 = $19 >>> 16;
   $21 = $20 << 16;
   $22 = (($$06489) + 1)|0;
   $23 = (($22) + ($20))|0;
   $24 = (($19) - ($21))|0;
   $$165$lcssa = $23;$$172$lcssa = $24;
  } else {
   $$165$lcssa = $$06489;$$172$lcssa = $$07188;
  }
  $26 = ($25|0)==(0);
  if ($26) {
   $56 = $59;
  } else {
   $$06285 = $60;$$06384 = 0;$$06683 = -1;$$06882 = 65536;$$in = $25;
   while(1) {
    $27 = (($$in) + -1)|0;
    $28 = ($$06882|0)>(65535);
    if ($28) {
     $29 = (($$06882) + -65536)|0;
     $30 = $29 >>> 16;
     $31 = $30 << 16;
     $32 = (($$06683) + 1)|0;
     $33 = (($32) + ($30))|0;
     $34 = (($29) - ($31))|0;
     $35 = HEAP32[$0>>2]|0;
     $36 = HEAP32[$17>>2]|0;
     $37 = Math_imul($36, $$165$lcssa)|0;
     $38 = (($35) + ($37)|0);
     $39 = $33 << 2;
     $40 = (($38) + ($39)|0);
     $$1 = $40;$$2 = $33;$$270 = $34;
    } else {
     $$1 = $$06384;$$2 = $$06683;$$270 = $$06882;
    }
    $41 = HEAP32[$$1>>2]|0;
    $42 = $41 >>> 16;
    $43 = $42 & 255;
    $44 = $41 & 65280;
    $45 = $41 << 16;
    $46 = $44 | $45;
    $47 = $46 | $43;
    $48 = $47 | -16777216;
    HEAP32[$$06285>>2] = $48;
    $49 = (($$270) + ($12))|0;
    $50 = ((($$06285)) + 4|0);
    $51 = ($27|0)==(0);
    if ($51) {
     break;
    } else {
     $$06285 = $50;$$06384 = $$1;$$06683 = $$2;$$06882 = $49;$$in = $27;
    }
   }
   $$pre97 = HEAP32[$4>>2]|0;
   $56 = $$pre97;
  }
  $52 = HEAP32[$16>>2]|0;
  $53 = (($54) + ($52)|0);
  $55 = (($56) + -1)|0;
  HEAP32[$4>>2] = $55;
  $57 = ($56|0)==(0);
  if ($57) {
   break;
  }
  $58 = (($$172$lcssa) + ($6))|0;
  $$pre96 = HEAP32[$10>>2]|0;
  $$06489 = $$165$lcssa;$$07188 = $58;$25 = $$pre96;$54 = $53;$59 = $55;$60 = $53;
 }
 HEAP32[$15>>2] = $53;
 return;
}
function _SDL_Blit_BGR888_ARGB8888_Blend($0) {
 $0 = $0|0;
 var $$ = 0, $$092102 = 0, $$092102$us = 0, $$093101 = 0, $$093101$us = 0, $$095 = 0, $$096 = 0, $$097 = 0, $$1 = 0, $$3 = 0, $$pre = 0, $$pre107 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $8 = 0, $9 = 0, $trunc = 0, $trunc$clear = 0, $trunc$clear1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + -1)|0;
 HEAP32[$3>>2] = $5;
 $6 = ($4|0)==(0);
 if ($6) {
  return;
 }
 $7 = ((($0)) + 20|0);
 $8 = ((($0)) + 24|0);
 $9 = ((($0)) + 12|0);
 $10 = ((($0)) + 32|0);
 $11 = $2 & 112;
 $trunc = $11&255;
 $trunc$clear = $trunc & 127;
 $12 = ($trunc$clear<<24>>24)==(16);
 $$pre = HEAP32[$0>>2]|0;
 $$pre107 = HEAP32[$7>>2]|0;
 $66 = $$pre;$69 = $$pre107;$73 = $$pre107;$74 = $$pre;
 while(1) {
  $13 = HEAP32[$8>>2]|0;
  $14 = (($13) + -1)|0;
  $15 = ($13|0)==(0);
  L6: do {
   if (!($15)) {
    if ($12) {
     $$092102$us = $73;$$093101$us = $74;$27 = $14;
     while(1) {
      $16 = HEAP32[$$093101$us>>2]|0;
      $17 = $16 >>> 16;
      $18 = $17 & 255;
      $19 = $16 & 65280;
      $20 = $16 << 16;
      $21 = $19 | $20;
      $22 = $21 | $18;
      $23 = $22 | -16777216;
      HEAP32[$$092102$us>>2] = $23;
      $24 = ((($$093101$us)) + 4|0);
      $25 = ((($$092102$us)) + 4|0);
      $26 = (($27) + -1)|0;
      $28 = ($27|0)==(0);
      if ($28) {
       break L6;
      } else {
       $$092102$us = $25;$$093101$us = $24;$27 = $26;
      }
     }
    } else {
     $$092102 = $73;$$093101 = $74;$62 = $14;
    }
    while(1) {
     $29 = HEAP32[$$093101>>2]|0;
     $30 = $29 >>> 16;
     $31 = $30 & 255;
     $32 = $29 >>> 8;
     $33 = $32 & 255;
     $34 = $29 & 255;
     $35 = HEAP32[$$092102>>2]|0;
     $36 = $35 >>> 16;
     $37 = $36 & 255;
     $38 = $35 >>> 8;
     $39 = $38 & 255;
     $40 = $35 & 255;
     $41 = $35 & -16777216;
     $trunc$clear1 = $trunc & 127;
     switch ($trunc$clear1<<24>>24) {
     case 64:  {
      $48 = Math_imul($37, $34)|0;
      $49 = (($48>>>0) / 255)&-1;
      $50 = Math_imul($39, $33)|0;
      $51 = (($50>>>0) / 255)&-1;
      $52 = Math_imul($31, $40)|0;
      $53 = (($52>>>0) / 255)&-1;
      $$095 = $53;$$096 = $51;$$097 = $49;
      break;
     }
     case 32:  {
      $42 = (($37) + ($34))|0;
      $43 = ($42>>>0)<(255);
      $$ = $43 ? $42 : 255;
      $44 = (($39) + ($33))|0;
      $45 = ($44>>>0)<(255);
      $$3 = $45 ? $44 : 255;
      $46 = (($31) + ($40))|0;
      $47 = ($46>>>0)<(255);
      $$1 = $47 ? $46 : 255;
      $$095 = $$1;$$096 = $$3;$$097 = $$;
      break;
     }
     default: {
      $$095 = $40;$$096 = $39;$$097 = $37;
     }
     }
     $54 = $$097 << 16;
     $55 = $$096 << 8;
     $56 = $55 | $54;
     $57 = $56 | $$095;
     $58 = $57 | $41;
     HEAP32[$$092102>>2] = $58;
     $59 = ((($$093101)) + 4|0);
     $60 = ((($$092102)) + 4|0);
     $61 = (($62) + -1)|0;
     $63 = ($62|0)==(0);
     if ($63) {
      break L6;
     } else {
      $$092102 = $60;$$093101 = $59;$62 = $61;
     }
    }
   }
  } while(0);
  $64 = HEAP32[$9>>2]|0;
  $65 = (($66) + ($64)|0);
  $67 = HEAP32[$10>>2]|0;
  $68 = (($69) + ($67)|0);
  $70 = HEAP32[$3>>2]|0;
  $71 = (($70) + -1)|0;
  HEAP32[$3>>2] = $71;
  $72 = ($70|0)==(0);
  if ($72) {
   break;
  } else {
   $66 = $65;$69 = $68;$73 = $68;$74 = $65;
  }
 }
 HEAP32[$0>>2] = $65;
 HEAP32[$7>>2] = $68;
 return;
}
function _SDL_Blit_BGR888_ARGB8888_Blend_Scale($0) {
 $0 = $0|0;
 var $$ = 0, $$0119150 = 0, $$0119150$us = 0, $$0120149 = 0, $$0120149$us = 0, $$0124148 = 0, $$0124148$us = 0, $$0126154 = 0, $$0128147 = 0, $$0128147$us = 0, $$0131153 = 0, $$0134 = 0, $$0135 = 0, $$0136 = 0, $$1 = 0, $$1121 = 0, $$1121$us = 0, $$1127$lcssa = 0, $$1132$lcssa = 0, $$2 = 0;
 var $$2$us = 0, $$2130 = 0, $$2130$us = 0, $$3 = 0, $$pre = 0, $$pre164 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $trunc = 0;
 var $trunc$clear = 0, $trunc$clear1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 << 16;
 $6 = ((($0)) + 28|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5|0) / ($7|0))&-1;
 $9 = ((($0)) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10 << 16;
 $12 = ((($0)) + 24|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($11|0) / ($13|0))&-1;
 $15 = (($7) + -1)|0;
 HEAP32[$6>>2] = $15;
 $16 = ($7|0)==(0);
 if ($16) {
  return;
 }
 $17 = ((($0)) + 20|0);
 $18 = ((($0)) + 32|0);
 $19 = $2 & 112;
 $trunc = $19&255;
 $20 = ((($0)) + 12|0);
 $trunc$clear = $trunc & 127;
 $21 = ($trunc$clear<<24>>24)==(16);
 $$pre = HEAP32[$17>>2]|0;
 $$0126154 = 0;$$0131153 = 0;$108 = $$pre;$113 = $$pre;$30 = $13;
 while(1) {
  $22 = ($$0126154|0)>(65535);
  if ($22) {
   $23 = (($$0126154) + -65536)|0;
   $24 = $23 >>> 16;
   $25 = $24 << 16;
   $26 = (($$0131153) + 1)|0;
   $27 = (($26) + ($24))|0;
   $28 = (($23) - ($25))|0;
   $$1127$lcssa = $28;$$1132$lcssa = $27;
  } else {
   $$1127$lcssa = $$0126154;$$1132$lcssa = $$0131153;
  }
  $29 = (($30) + -1)|0;
  $31 = ($30|0)==(0);
  L9: do {
   if (!($31)) {
    if ($21) {
     $$0119150$us = $113;$$0120149$us = 0;$$0124148$us = 65536;$$0128147$us = -1;$56 = $29;
     while(1) {
      $32 = ($$0124148$us|0)>(65535);
      if ($32) {
       $33 = (($$0124148$us) + -65536)|0;
       $34 = $33 >>> 16;
       $35 = $34 << 16;
       $36 = (($$0128147$us) + 1)|0;
       $37 = (($36) + ($34))|0;
       $38 = (($33) - ($35))|0;
       $39 = HEAP32[$0>>2]|0;
       $40 = HEAP32[$20>>2]|0;
       $41 = Math_imul($40, $$1132$lcssa)|0;
       $42 = (($39) + ($41)|0);
       $43 = $37 << 2;
       $44 = (($42) + ($43)|0);
       $$1121$us = $44;$$2$us = $38;$$2130$us = $37;
      } else {
       $$1121$us = $$0120149$us;$$2$us = $$0124148$us;$$2130$us = $$0128147$us;
      }
      $45 = HEAP32[$$1121$us>>2]|0;
      $46 = $45 >>> 16;
      $47 = $46 & 255;
      $48 = $45 & 65280;
      $49 = $45 << 16;
      $50 = $48 | $49;
      $51 = $50 | $47;
      $52 = $51 | -16777216;
      HEAP32[$$0119150$us>>2] = $52;
      $53 = (($$2$us) + ($14))|0;
      $54 = ((($$0119150$us)) + 4|0);
      $55 = (($56) + -1)|0;
      $57 = ($56|0)==(0);
      if ($57) {
       break L9;
      } else {
       $$0119150$us = $54;$$0120149$us = $$1121$us;$$0124148$us = $53;$$0128147$us = $$2130$us;$56 = $55;
      }
     }
    } else {
     $$0119150 = $113;$$0120149 = 0;$$0124148 = 65536;$$0128147 = -1;$104 = $29;
    }
    while(1) {
     $58 = ($$0124148|0)>(65535);
     if ($58) {
      $59 = (($$0124148) + -65536)|0;
      $60 = $59 >>> 16;
      $61 = $60 << 16;
      $62 = (($$0128147) + 1)|0;
      $63 = (($62) + ($60))|0;
      $64 = (($59) - ($61))|0;
      $65 = HEAP32[$0>>2]|0;
      $66 = HEAP32[$20>>2]|0;
      $67 = Math_imul($66, $$1132$lcssa)|0;
      $68 = (($65) + ($67)|0);
      $69 = $63 << 2;
      $70 = (($68) + ($69)|0);
      $$1121 = $70;$$2 = $64;$$2130 = $63;
     } else {
      $$1121 = $$0120149;$$2 = $$0124148;$$2130 = $$0128147;
     }
     $71 = HEAP32[$$1121>>2]|0;
     $72 = $71 >>> 16;
     $73 = $72 & 255;
     $74 = $71 >>> 8;
     $75 = $74 & 255;
     $76 = $71 & 255;
     $77 = HEAP32[$$0119150>>2]|0;
     $78 = $77 >>> 16;
     $79 = $78 & 255;
     $80 = $77 >>> 8;
     $81 = $80 & 255;
     $82 = $77 & 255;
     $83 = $77 & -16777216;
     $trunc$clear1 = $trunc & 127;
     switch ($trunc$clear1<<24>>24) {
     case 64:  {
      $90 = Math_imul($79, $76)|0;
      $91 = (($90>>>0) / 255)&-1;
      $92 = Math_imul($81, $75)|0;
      $93 = (($92>>>0) / 255)&-1;
      $94 = Math_imul($73, $82)|0;
      $95 = (($94>>>0) / 255)&-1;
      $$0134 = $95;$$0135 = $93;$$0136 = $91;
      break;
     }
     case 32:  {
      $84 = (($79) + ($76))|0;
      $85 = ($84>>>0)<(255);
      $$ = $85 ? $84 : 255;
      $86 = (($81) + ($75))|0;
      $87 = ($86>>>0)<(255);
      $$3 = $87 ? $86 : 255;
      $88 = (($73) + ($82))|0;
      $89 = ($88>>>0)<(255);
      $$1 = $89 ? $88 : 255;
      $$0134 = $$1;$$0135 = $$3;$$0136 = $$;
      break;
     }
     default: {
      $$0134 = $82;$$0135 = $81;$$0136 = $79;
     }
     }
     $96 = $$0136 << 16;
     $97 = $$0135 << 8;
     $98 = $97 | $96;
     $99 = $98 | $$0134;
     $100 = $99 | $83;
     HEAP32[$$0119150>>2] = $100;
     $101 = (($$2) + ($14))|0;
     $102 = ((($$0119150)) + 4|0);
     $103 = (($104) + -1)|0;
     $105 = ($104|0)==(0);
     if ($105) {
      break L9;
     } else {
      $$0119150 = $102;$$0120149 = $$1121;$$0124148 = $101;$$0128147 = $$2130;$104 = $103;
     }
    }
   }
  } while(0);
  $106 = HEAP32[$18>>2]|0;
  $107 = (($108) + ($106)|0);
  $109 = HEAP32[$6>>2]|0;
  $110 = (($109) + -1)|0;
  HEAP32[$6>>2] = $110;
  $111 = ($109|0)==(0);
  if ($111) {
   break;
  }
  $112 = (($$1127$lcssa) + ($8))|0;
  $$pre164 = HEAP32[$12>>2]|0;
  $$0126154 = $112;$$0131153 = $$1132$lcssa;$108 = $107;$113 = $107;$30 = $$pre164;
 }
 HEAP32[$17>>2] = $107;
 return;
}
function _SDL_Blit_BGR888_ARGB8888_Modulate($0) {
 $0 = $0|0;
 var $$06067 = 0, $$06067$us$us = 0, $$06166 = 0, $$06166$us$us = 0, $$in = 0, $$in78 = 0, $$lcssa87$sink = 0, $$lcssa88$sink = 0, $$op = 0, $$pre81 = 0, $$pre82 = 0, $$pre83 = 0, $$pre84 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = ((($0)) + 61|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = ((($0)) + 62|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = ((($0)) + 63|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = ((($0)) + 28|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($15) + -1)|0;
 HEAP32[$14>>2] = $16;
 $17 = ($15|0)==(0);
 if ($17) {
  return;
 }
 $18 = $13&255;
 $19 = ((($0)) + 20|0);
 $20 = ((($0)) + 24|0);
 $21 = ((($0)) + 12|0);
 $22 = ((($0)) + 32|0);
 $23 = $2 & 1;
 $24 = ($23|0)==(0);
 $25 = $2 & 2;
 $26 = ($25|0)==(0);
 $$op = $18 << 24;
 $27 = $26 ? -16777216 : $$op;
 $$pre82 = HEAP32[$0>>2]|0;
 $$pre83 = HEAP32[$19>>2]|0;
 if ($24) {
  $32 = $$pre82;$35 = $$pre83;$84 = $16;$85 = $$pre83;$86 = $$pre82;
  while(1) {
   $28 = HEAP32[$20>>2]|0;
   $29 = ($28|0)==(0);
   if ($29) {
    $37 = $84;
   } else {
    $$06067$us$us = $85;$$06166$us$us = $86;$$in78 = $28;
    while(1) {
     $39 = (($$in78) + -1)|0;
     $40 = HEAP32[$$06166$us$us>>2]|0;
     $41 = $40 >>> 16;
     $42 = $41 & 255;
     $43 = $40 & 65280;
     $44 = $40 << 16;
     $45 = $44 & 16711680;
     $46 = $45 | $27;
     $47 = $46 | $43;
     $48 = $47 | $42;
     HEAP32[$$06067$us$us>>2] = $48;
     $49 = ((($$06166$us$us)) + 4|0);
     $50 = ((($$06067$us$us)) + 4|0);
     $51 = ($39|0)==(0);
     if ($51) {
      break;
     } else {
      $$06067$us$us = $50;$$06166$us$us = $49;$$in78 = $39;
     }
    }
    $$pre84 = HEAP32[$14>>2]|0;
    $37 = $$pre84;
   }
   $30 = HEAP32[$21>>2]|0;
   $31 = (($32) + ($30)|0);
   $33 = HEAP32[$22>>2]|0;
   $34 = (($35) + ($33)|0);
   $36 = (($37) + -1)|0;
   HEAP32[$14>>2] = $36;
   $38 = ($37|0)==(0);
   if ($38) {
    $$lcssa87$sink = $31;$$lcssa88$sink = $34;
    break;
   } else {
    $32 = $31;$35 = $34;$84 = $36;$85 = $34;$86 = $31;
   }
  }
 } else {
  $77 = $$pre82;$80 = $$pre83;$87 = $16;$88 = $$pre83;$89 = $$pre82;
  while(1) {
   $52 = HEAP32[$20>>2]|0;
   $53 = ($52|0)==(0);
   if ($53) {
    $82 = $87;
   } else {
    $$06067 = $88;$$06166 = $89;$$in = $52;
    while(1) {
     $54 = (($$in) + -1)|0;
     $55 = HEAP32[$$06166>>2]|0;
     $56 = $55 >>> 16;
     $57 = $56 & 255;
     $58 = $55 >>> 8;
     $59 = $58 & 255;
     $60 = $55 & 255;
     $61 = Math_imul($57, $11)|0;
     $62 = Math_imul($59, $8)|0;
     $63 = Math_imul($60, $5)|0;
     $64 = (($63>>>0) / 255)&-1;
     $65 = (($62>>>0) / 255)&-1;
     $66 = (($61>>>0) / 255)&-1;
     $67 = $64 << 16;
     $68 = $67 | $27;
     $69 = $65 << 8;
     $70 = $68 | $69;
     $71 = $70 | $66;
     HEAP32[$$06067>>2] = $71;
     $72 = ((($$06166)) + 4|0);
     $73 = ((($$06067)) + 4|0);
     $74 = ($54|0)==(0);
     if ($74) {
      break;
     } else {
      $$06067 = $73;$$06166 = $72;$$in = $54;
     }
    }
    $$pre81 = HEAP32[$14>>2]|0;
    $82 = $$pre81;
   }
   $75 = HEAP32[$21>>2]|0;
   $76 = (($77) + ($75)|0);
   $78 = HEAP32[$22>>2]|0;
   $79 = (($80) + ($78)|0);
   $81 = (($82) + -1)|0;
   HEAP32[$14>>2] = $81;
   $83 = ($82|0)==(0);
   if ($83) {
    $$lcssa87$sink = $76;$$lcssa88$sink = $79;
    break;
   } else {
    $77 = $76;$80 = $79;$87 = $81;$88 = $79;$89 = $76;
   }
  }
 }
 HEAP32[$0>>2] = $$lcssa87$sink;
 HEAP32[$19>>2] = $$lcssa88$sink;
 return;
}
function _SDL_Blit_BGR888_ARGB8888_Modulate_Scale($0) {
 $0 = $0|0;
 var $$087114 = 0, $$087114$us = 0, $$088113 = 0, $$088113$us = 0, $$090112 = 0, $$090112$us = 0, $$092118 = 0, $$094111 = 0, $$094111$us = 0, $$097117 = 0, $$1 = 0, $$1$us = 0, $$193$lcssa = 0, $$198$lcssa = 0, $$2 = 0, $$2$us = 0, $$296 = 0, $$296$us = 0, $$op = 0, $$pre = 0;
 var $$pre128 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = ((($0)) + 61|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = ((($0)) + 62|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = ((($0)) + 63|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = ((($0)) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = $15 << 16;
 $17 = ((($0)) + 28|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($16|0) / ($18|0))&-1;
 $20 = ((($0)) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = $21 << 16;
 $23 = ((($0)) + 24|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (($22|0) / ($24|0))&-1;
 $26 = (($18) + -1)|0;
 HEAP32[$17>>2] = $26;
 $27 = ($18|0)==(0);
 if ($27) {
  return;
 }
 $28 = $13&255;
 $29 = ((($0)) + 20|0);
 $30 = ((($0)) + 32|0);
 $31 = $2 & 1;
 $32 = ($31|0)==(0);
 $33 = $2 & 2;
 $34 = ($33|0)==(0);
 $$op = $28 << 24;
 $35 = $34 ? -16777216 : $$op;
 $36 = ((($0)) + 12|0);
 $$pre = HEAP32[$29>>2]|0;
 $$092118 = 0;$$097117 = 0;$111 = $$pre;$116 = $$pre;$45 = $24;
 while(1) {
  $37 = ($$092118|0)>(65535);
  if ($37) {
   $38 = (($$092118) + -65536)|0;
   $39 = $38 >>> 16;
   $40 = $39 << 16;
   $41 = (($$097117) + 1)|0;
   $42 = (($41) + ($39))|0;
   $43 = (($38) - ($40))|0;
   $$193$lcssa = $43;$$198$lcssa = $42;
  } else {
   $$193$lcssa = $$092118;$$198$lcssa = $$097117;
  }
  $44 = (($45) + -1)|0;
  $46 = ($45|0)==(0);
  if (!($46)) {
   if ($32) {
    $$087114$us = $116;$$088113$us = 0;$$090112$us = 65536;$$094111$us = -1;$72 = $44;
    while(1) {
     $47 = ($$090112$us|0)>(65535);
     if ($47) {
      $48 = (($$090112$us) + -65536)|0;
      $49 = $48 >>> 16;
      $50 = $49 << 16;
      $51 = (($$094111$us) + 1)|0;
      $52 = (($51) + ($49))|0;
      $53 = (($48) - ($50))|0;
      $54 = HEAP32[$0>>2]|0;
      $55 = HEAP32[$36>>2]|0;
      $56 = Math_imul($55, $$198$lcssa)|0;
      $57 = (($54) + ($56)|0);
      $58 = $52 << 2;
      $59 = (($57) + ($58)|0);
      $$1$us = $59;$$2$us = $53;$$296$us = $52;
     } else {
      $$1$us = $$088113$us;$$2$us = $$090112$us;$$296$us = $$094111$us;
     }
     $60 = HEAP32[$$1$us>>2]|0;
     $61 = $60 >>> 16;
     $62 = $61 & 255;
     $63 = $60 & 65280;
     $64 = $60 << 16;
     $65 = $64 & 16711680;
     $66 = $63 | $35;
     $67 = $66 | $62;
     $68 = $67 | $65;
     HEAP32[$$087114$us>>2] = $68;
     $69 = (($$2$us) + ($25))|0;
     $70 = ((($$087114$us)) + 4|0);
     $71 = (($72) + -1)|0;
     $73 = ($72|0)==(0);
     if ($73) {
      break;
     } else {
      $$087114$us = $70;$$088113$us = $$1$us;$$090112$us = $69;$$094111$us = $$296$us;$72 = $71;
     }
    }
   } else {
    $$087114 = $116;$$088113 = 0;$$090112 = 65536;$$094111 = -1;$107 = $44;
    while(1) {
     $74 = ($$090112|0)>(65535);
     if ($74) {
      $75 = (($$090112) + -65536)|0;
      $76 = $75 >>> 16;
      $77 = $76 << 16;
      $78 = (($$094111) + 1)|0;
      $79 = (($78) + ($76))|0;
      $80 = (($75) - ($77))|0;
      $81 = HEAP32[$0>>2]|0;
      $82 = HEAP32[$36>>2]|0;
      $83 = Math_imul($82, $$198$lcssa)|0;
      $84 = (($81) + ($83)|0);
      $85 = $79 << 2;
      $86 = (($84) + ($85)|0);
      $$1 = $86;$$2 = $80;$$296 = $79;
     } else {
      $$1 = $$088113;$$2 = $$090112;$$296 = $$094111;
     }
     $87 = HEAP32[$$1>>2]|0;
     $88 = $87 >>> 16;
     $89 = $88 & 255;
     $90 = $87 >>> 8;
     $91 = $90 & 255;
     $92 = $87 & 255;
     $93 = Math_imul($89, $11)|0;
     $94 = Math_imul($91, $8)|0;
     $95 = Math_imul($92, $5)|0;
     $96 = (($95>>>0) / 255)&-1;
     $97 = (($94>>>0) / 255)&-1;
     $98 = (($93>>>0) / 255)&-1;
     $99 = $96 << 16;
     $100 = $97 << 8;
     $101 = $100 | $35;
     $102 = $101 | $98;
     $103 = $102 | $99;
     HEAP32[$$087114>>2] = $103;
     $104 = (($$2) + ($25))|0;
     $105 = ((($$087114)) + 4|0);
     $106 = (($107) + -1)|0;
     $108 = ($107|0)==(0);
     if ($108) {
      break;
     } else {
      $$087114 = $105;$$088113 = $$1;$$090112 = $104;$$094111 = $$296;$107 = $106;
     }
    }
   }
  }
  $109 = HEAP32[$30>>2]|0;
  $110 = (($111) + ($109)|0);
  $112 = HEAP32[$17>>2]|0;
  $113 = (($112) + -1)|0;
  HEAP32[$17>>2] = $113;
  $114 = ($112|0)==(0);
  if ($114) {
   break;
  }
  $115 = (($$193$lcssa) + ($19))|0;
  $$pre128 = HEAP32[$23>>2]|0;
  $$092118 = $115;$$097117 = $$198$lcssa;$111 = $110;$116 = $110;$45 = $$pre128;
 }
 HEAP32[$29>>2] = $110;
 return;
}
function _SDL_Blit_BGR888_ARGB8888_Modulate_Blend($0) {
 $0 = $0|0;
 var $$ = 0, $$0114129 = 0, $$0115128 = 0, $$0116 = 0, $$0117 = 0, $$0118 = 0, $$0119 = 0, $$0121 = 0, $$0123 = 0, $$0125 = 0, $$1 = 0, $$1122 = 0, $$1124 = 0, $$1126 = 0, $$127 = 0, $$3 = 0, $$in = 0, $$pre = 0, $$pre133 = 0, $$pre134 = 0;
 var $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $trunc = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = ((($0)) + 61|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = ((($0)) + 62|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = ((($0)) + 63|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = ((($0)) + 28|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($15) + -1)|0;
 HEAP32[$14>>2] = $16;
 $17 = ($15|0)==(0);
 if ($17) {
  return;
 }
 $18 = $13&255;
 $19 = ((($0)) + 20|0);
 $20 = ((($0)) + 24|0);
 $21 = ((($0)) + 12|0);
 $22 = ((($0)) + 32|0);
 $23 = $2 & 1;
 $24 = ($23|0)==(0);
 $25 = $2 & 2;
 $26 = ($25|0)==(0);
 $$127 = $26 ? 255 : $18;
 $27 = $2 & 48;
 $28 = ($27|0)!=(0);
 $29 = ($$127|0)!=(255);
 $or$cond = $28 & $29;
 $30 = $2 & 112;
 $trunc = $30&255;
 $31 = $$127 ^ 255;
 $$pre = HEAP32[$0>>2]|0;
 $$pre133 = HEAP32[$19>>2]|0;
 $102 = $16;$103 = $$pre133;$104 = $$pre;$95 = $$pre;$98 = $$pre133;
 while(1) {
  $32 = HEAP32[$20>>2]|0;
  $33 = ($32|0)==(0);
  if ($33) {
   $100 = $102;
  } else {
   $$0114129 = $103;$$0115128 = $104;$$in = $32;
   while(1) {
    $34 = (($$in) + -1)|0;
    $35 = HEAP32[$$0115128>>2]|0;
    $36 = $35 >>> 16;
    $37 = $36 & 255;
    $38 = $35 >>> 8;
    $39 = $38 & 255;
    $40 = $35 & 255;
    $41 = HEAP32[$$0114129>>2]|0;
    $42 = $41 >>> 16;
    $43 = $42 & 255;
    $44 = $41 >>> 8;
    $45 = $44 & 255;
    $46 = $41 & 255;
    $47 = $41 >>> 24;
    if ($24) {
     $$0121 = $37;$$0123 = $39;$$0125 = $40;
    } else {
     $48 = Math_imul($37, $11)|0;
     $49 = Math_imul($39, $8)|0;
     $50 = Math_imul($40, $5)|0;
     $51 = (($50>>>0) / 255)&-1;
     $52 = (($49>>>0) / 255)&-1;
     $53 = (($48>>>0) / 255)&-1;
     $$0121 = $53;$$0123 = $52;$$0125 = $51;
    }
    if ($or$cond) {
     $54 = Math_imul($$0121, $$127)|0;
     $55 = Math_imul($$0123, $$127)|0;
     $56 = Math_imul($$0125, $$127)|0;
     $57 = (($56>>>0) / 255)&-1;
     $58 = (($55>>>0) / 255)&-1;
     $59 = (($54>>>0) / 255)&-1;
     $$1122 = $59;$$1124 = $58;$$1126 = $57;
    } else {
     $$1122 = $$0121;$$1124 = $$0123;$$1126 = $$0125;
    }
    $trunc$clear = $trunc & 127;
    switch ($trunc$clear<<24>>24) {
    case 16:  {
     $60 = Math_imul($43, $31)|0;
     $61 = (($60>>>0) / 255)&-1;
     $62 = (($$1126) + ($61))|0;
     $63 = Math_imul($45, $31)|0;
     $64 = (($63>>>0) / 255)&-1;
     $65 = (($$1124) + ($64))|0;
     $66 = Math_imul($46, $31)|0;
     $67 = (($66>>>0) / 255)&-1;
     $68 = (($$1122) + ($67))|0;
     $69 = Math_imul($47, $31)|0;
     $70 = (($69>>>0) / 255)&-1;
     $71 = (($70) + ($$127))|0;
     $$0116 = $71;$$0117 = $68;$$0118 = $65;$$0119 = $62;
     break;
    }
    case 32:  {
     $72 = (($$1126) + ($43))|0;
     $73 = ($72>>>0)<(255);
     $$ = $73 ? $72 : 255;
     $74 = (($$1124) + ($45))|0;
     $75 = ($74>>>0)<(255);
     $$3 = $75 ? $74 : 255;
     $76 = (($$1122) + ($46))|0;
     $77 = ($76>>>0)<(255);
     $$1 = $77 ? $76 : 255;
     $$0116 = $47;$$0117 = $$1;$$0118 = $$3;$$0119 = $$;
     break;
    }
    case 64:  {
     $78 = Math_imul($$1126, $43)|0;
     $79 = (($78>>>0) / 255)&-1;
     $80 = Math_imul($$1124, $45)|0;
     $81 = (($80>>>0) / 255)&-1;
     $82 = Math_imul($$1122, $46)|0;
     $83 = (($82>>>0) / 255)&-1;
     $$0116 = $47;$$0117 = $83;$$0118 = $81;$$0119 = $79;
     break;
    }
    default: {
     $$0116 = $47;$$0117 = $46;$$0118 = $45;$$0119 = $43;
    }
    }
    $84 = $$0116 << 24;
    $85 = $$0119 << 16;
    $86 = $$0118 << 8;
    $87 = $86 | $85;
    $88 = $87 | $$0117;
    $89 = $88 | $84;
    HEAP32[$$0114129>>2] = $89;
    $90 = ((($$0115128)) + 4|0);
    $91 = ((($$0114129)) + 4|0);
    $92 = ($34|0)==(0);
    if ($92) {
     break;
    } else {
     $$0114129 = $91;$$0115128 = $90;$$in = $34;
    }
   }
   $$pre134 = HEAP32[$14>>2]|0;
   $100 = $$pre134;
  }
  $93 = HEAP32[$21>>2]|0;
  $94 = (($95) + ($93)|0);
  $96 = HEAP32[$22>>2]|0;
  $97 = (($98) + ($96)|0);
  $99 = (($100) + -1)|0;
  HEAP32[$14>>2] = $99;
  $101 = ($100|0)==(0);
  if ($101) {
   break;
  } else {
   $102 = $99;$103 = $97;$104 = $94;$95 = $94;$98 = $97;
  }
 }
 HEAP32[$0>>2] = $94;
 HEAP32[$19>>2] = $97;
 return;
}
function _SDL_Blit_BGR888_ARGB8888_Modulate_Blend_Scale($0) {
 $0 = $0|0;
 var $$ = 0, $$0141177 = 0, $$0142176 = 0, $$0144 = 0, $$0146 = 0, $$0148175 = 0, $$0150181 = 0, $$0152174 = 0, $$0155180 = 0, $$0157 = 0, $$0158 = 0, $$0159 = 0, $$0160 = 0, $$0162 = 0, $$1 = 0, $$1143 = 0, $$1145 = 0, $$1147 = 0, $$1151$lcssa = 0, $$1156$lcssa = 0;
 var $$1163 = 0, $$164 = 0, $$2 = 0, $$2154 = 0, $$3 = 0, $$in = 0, $$pre = 0, $$pre188 = 0, $$pre189 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0;
 var $trunc = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = ((($0)) + 61|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = ((($0)) + 62|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = ((($0)) + 63|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = ((($0)) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = $15 << 16;
 $17 = ((($0)) + 28|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($16|0) / ($18|0))&-1;
 $20 = ((($0)) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = $21 << 16;
 $23 = ((($0)) + 24|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (($22|0) / ($24|0))&-1;
 $26 = (($18) + -1)|0;
 HEAP32[$17>>2] = $26;
 $27 = ($18|0)==(0);
 if ($27) {
  return;
 }
 $28 = $13&255;
 $29 = ((($0)) + 20|0);
 $30 = ((($0)) + 32|0);
 $31 = $2 & 1;
 $32 = ($31|0)==(0);
 $33 = $2 & 2;
 $34 = ($33|0)==(0);
 $$164 = $34 ? 255 : $28;
 $35 = $2 & 48;
 $36 = ($35|0)!=(0);
 $37 = ($$164|0)!=(255);
 $or$cond = $36 & $37;
 $38 = $2 & 112;
 $trunc = $38&255;
 $39 = $$164 ^ 255;
 $40 = ((($0)) + 12|0);
 $$pre = HEAP32[$29>>2]|0;
 $$0150181 = 0;$$0155180 = 0;$124 = $$pre;$129 = $26;$130 = $$pre;$48 = $24;
 while(1) {
  $41 = ($$0150181|0)>(65535);
  if ($41) {
   $42 = (($$0150181) + -65536)|0;
   $43 = $42 >>> 16;
   $44 = $43 << 16;
   $45 = (($$0155180) + 1)|0;
   $46 = (($45) + ($43))|0;
   $47 = (($42) - ($44))|0;
   $$1151$lcssa = $47;$$1156$lcssa = $46;
  } else {
   $$1151$lcssa = $$0150181;$$1156$lcssa = $$0155180;
  }
  $49 = ($48|0)==(0);
  if ($49) {
   $126 = $129;
  } else {
   $$0141177 = $130;$$0142176 = 0;$$0148175 = 65536;$$0152174 = -1;$$in = $48;
   while(1) {
    $50 = (($$in) + -1)|0;
    $51 = ($$0148175|0)>(65535);
    if ($51) {
     $52 = (($$0148175) + -65536)|0;
     $53 = $52 >>> 16;
     $54 = $53 << 16;
     $55 = (($$0152174) + 1)|0;
     $56 = (($55) + ($53))|0;
     $57 = (($52) - ($54))|0;
     $58 = HEAP32[$0>>2]|0;
     $59 = HEAP32[$40>>2]|0;
     $60 = Math_imul($59, $$1156$lcssa)|0;
     $61 = (($58) + ($60)|0);
     $62 = $56 << 2;
     $63 = (($61) + ($62)|0);
     $$1143 = $63;$$2 = $57;$$2154 = $56;
    } else {
     $$1143 = $$0142176;$$2 = $$0148175;$$2154 = $$0152174;
    }
    $64 = HEAP32[$$1143>>2]|0;
    $65 = $64 >>> 16;
    $66 = $65 & 255;
    $67 = $64 >>> 8;
    $68 = $67 & 255;
    $69 = $64 & 255;
    $70 = HEAP32[$$0141177>>2]|0;
    $71 = $70 >>> 16;
    $72 = $71 & 255;
    $73 = $70 >>> 8;
    $74 = $73 & 255;
    $75 = $70 & 255;
    $76 = $70 >>> 24;
    if ($32) {
     $$0144 = $69;$$0146 = $68;$$0162 = $66;
    } else {
     $77 = Math_imul($66, $11)|0;
     $78 = Math_imul($68, $8)|0;
     $79 = Math_imul($69, $5)|0;
     $80 = (($79>>>0) / 255)&-1;
     $81 = (($78>>>0) / 255)&-1;
     $82 = (($77>>>0) / 255)&-1;
     $$0144 = $80;$$0146 = $81;$$0162 = $82;
    }
    if ($or$cond) {
     $83 = Math_imul($$0162, $$164)|0;
     $84 = Math_imul($$0146, $$164)|0;
     $85 = Math_imul($$0144, $$164)|0;
     $86 = (($85>>>0) / 255)&-1;
     $87 = (($84>>>0) / 255)&-1;
     $88 = (($83>>>0) / 255)&-1;
     $$1145 = $86;$$1147 = $87;$$1163 = $88;
    } else {
     $$1145 = $$0144;$$1147 = $$0146;$$1163 = $$0162;
    }
    $trunc$clear = $trunc & 127;
    switch ($trunc$clear<<24>>24) {
    case 16:  {
     $89 = Math_imul($72, $39)|0;
     $90 = (($89>>>0) / 255)&-1;
     $91 = (($$1145) + ($90))|0;
     $92 = Math_imul($74, $39)|0;
     $93 = (($92>>>0) / 255)&-1;
     $94 = (($$1147) + ($93))|0;
     $95 = Math_imul($75, $39)|0;
     $96 = (($95>>>0) / 255)&-1;
     $97 = (($$1163) + ($96))|0;
     $98 = Math_imul($76, $39)|0;
     $99 = (($98>>>0) / 255)&-1;
     $100 = (($99) + ($$164))|0;
     $$0157 = $100;$$0158 = $97;$$0159 = $94;$$0160 = $91;
     break;
    }
    case 32:  {
     $101 = (($$1145) + ($72))|0;
     $102 = ($101>>>0)<(255);
     $$ = $102 ? $101 : 255;
     $103 = (($$1147) + ($74))|0;
     $104 = ($103>>>0)<(255);
     $$3 = $104 ? $103 : 255;
     $105 = (($$1163) + ($75))|0;
     $106 = ($105>>>0)<(255);
     $$1 = $106 ? $105 : 255;
     $$0157 = $76;$$0158 = $$1;$$0159 = $$3;$$0160 = $$;
     break;
    }
    case 64:  {
     $107 = Math_imul($$1145, $72)|0;
     $108 = (($107>>>0) / 255)&-1;
     $109 = Math_imul($$1147, $74)|0;
     $110 = (($109>>>0) / 255)&-1;
     $111 = Math_imul($$1163, $75)|0;
     $112 = (($111>>>0) / 255)&-1;
     $$0157 = $76;$$0158 = $112;$$0159 = $110;$$0160 = $108;
     break;
    }
    default: {
     $$0157 = $76;$$0158 = $75;$$0159 = $74;$$0160 = $72;
    }
    }
    $113 = $$0157 << 24;
    $114 = $$0160 << 16;
    $115 = $$0159 << 8;
    $116 = $115 | $114;
    $117 = $116 | $$0158;
    $118 = $117 | $113;
    HEAP32[$$0141177>>2] = $118;
    $119 = (($$2) + ($25))|0;
    $120 = ((($$0141177)) + 4|0);
    $121 = ($50|0)==(0);
    if ($121) {
     break;
    } else {
     $$0141177 = $120;$$0142176 = $$1143;$$0148175 = $119;$$0152174 = $$2154;$$in = $50;
    }
   }
   $$pre189 = HEAP32[$17>>2]|0;
   $126 = $$pre189;
  }
  $122 = HEAP32[$30>>2]|0;
  $123 = (($124) + ($122)|0);
  $125 = (($126) + -1)|0;
  HEAP32[$17>>2] = $125;
  $127 = ($126|0)==(0);
  if ($127) {
   break;
  }
  $128 = (($$1151$lcssa) + ($19))|0;
  $$pre188 = HEAP32[$23>>2]|0;
  $$0150181 = $128;$$0155180 = $$1156$lcssa;$124 = $123;$129 = $125;$130 = $123;$48 = $$pre188;
 }
 HEAP32[$29>>2] = $123;
 return;
}
function _SDL_Blit_ARGB8888_RGB888_Scale($0) {
 $0 = $0|0;
 var $$05982 = 0, $$06081 = 0, $$06186 = 0, $$06380 = 0, $$06579 = 0, $$06885 = 0, $$1 = 0, $$162$lcssa = 0, $$169$lcssa = 0, $$2 = 0, $$267 = 0, $$in = 0, $$pre = 0, $$pre93 = 0, $$pre94 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 << 16;
 $4 = ((($0)) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3|0) / ($5|0))&-1;
 $7 = ((($0)) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 << 16;
 $10 = ((($0)) + 24|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($9|0) / ($11|0))&-1;
 $13 = (($5) + -1)|0;
 HEAP32[$4>>2] = $13;
 $14 = ($5|0)==(0);
 if ($14) {
  return;
 }
 $15 = ((($0)) + 20|0);
 $16 = ((($0)) + 32|0);
 $17 = ((($0)) + 12|0);
 $$pre = HEAP32[$15>>2]|0;
 $$06186 = 0;$$06885 = 0;$25 = $11;$48 = $$pre;$53 = $13;$54 = $$pre;
 while(1) {
  $18 = ($$06885|0)>(65535);
  if ($18) {
   $19 = (($$06885) + -65536)|0;
   $20 = $19 >>> 16;
   $21 = $20 << 16;
   $22 = (($$06186) + 1)|0;
   $23 = (($22) + ($20))|0;
   $24 = (($19) - ($21))|0;
   $$162$lcssa = $23;$$169$lcssa = $24;
  } else {
   $$162$lcssa = $$06186;$$169$lcssa = $$06885;
  }
  $26 = ($25|0)==(0);
  if ($26) {
   $50 = $53;
  } else {
   $$05982 = $54;$$06081 = 0;$$06380 = -1;$$06579 = 65536;$$in = $25;
   while(1) {
    $27 = (($$in) + -1)|0;
    $28 = ($$06579|0)>(65535);
    if ($28) {
     $29 = (($$06579) + -65536)|0;
     $30 = $29 >>> 16;
     $31 = $30 << 16;
     $32 = (($$06380) + 1)|0;
     $33 = (($32) + ($30))|0;
     $34 = (($29) - ($31))|0;
     $35 = HEAP32[$0>>2]|0;
     $36 = HEAP32[$17>>2]|0;
     $37 = Math_imul($36, $$162$lcssa)|0;
     $38 = (($35) + ($37)|0);
     $39 = $33 << 2;
     $40 = (($38) + ($39)|0);
     $$1 = $40;$$2 = $33;$$267 = $34;
    } else {
     $$1 = $$06081;$$2 = $$06380;$$267 = $$06579;
    }
    $41 = HEAP32[$$1>>2]|0;
    $42 = $41 & 16777215;
    HEAP32[$$05982>>2] = $42;
    $43 = (($$267) + ($12))|0;
    $44 = ((($$05982)) + 4|0);
    $45 = ($27|0)==(0);
    if ($45) {
     break;
    } else {
     $$05982 = $44;$$06081 = $$1;$$06380 = $$2;$$06579 = $43;$$in = $27;
    }
   }
   $$pre94 = HEAP32[$4>>2]|0;
   $50 = $$pre94;
  }
  $46 = HEAP32[$16>>2]|0;
  $47 = (($48) + ($46)|0);
  $49 = (($50) + -1)|0;
  HEAP32[$4>>2] = $49;
  $51 = ($50|0)==(0);
  if ($51) {
   break;
  }
  $52 = (($$169$lcssa) + ($6))|0;
  $$pre93 = HEAP32[$10>>2]|0;
  $$06186 = $$162$lcssa;$$06885 = $52;$25 = $$pre93;$48 = $47;$53 = $49;$54 = $47;
 }
 HEAP32[$15>>2] = $47;
 return;
}
function _SDL_Blit_ARGB8888_RGB888_Blend($0) {
 $0 = $0|0;
 var $$ = 0, $$$us = 0, $$08695 = 0, $$08695$us = 0, $$08794 = 0, $$08794$us = 0, $$088 = 0, $$088$us = 0, $$089 = 0, $$089$us = 0, $$090 = 0, $$090$us = 0, $$091$us = 0, $$092$us = 0, $$093$us = 0, $$1 = 0, $$1$us = 0, $$3 = 0, $$3$us = 0, $$pre = 0;
 var $$pre100 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $trunc = 0, $trunc$clear = 0, $trunc$clear1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + -1)|0;
 HEAP32[$3>>2] = $5;
 $6 = ($4|0)==(0);
 if ($6) {
  return;
 }
 $7 = ((($0)) + 20|0);
 $8 = ((($0)) + 24|0);
 $9 = ((($0)) + 12|0);
 $10 = ((($0)) + 32|0);
 $11 = $2 & 48;
 $12 = ($11|0)==(0);
 $13 = $2 & 112;
 $trunc = $13&255;
 $$pre = HEAP32[$0>>2]|0;
 $$pre100 = HEAP32[$7>>2]|0;
 $114 = $$pre;$117 = $$pre100;$121 = $$pre100;$122 = $$pre;
 while(1) {
  $14 = HEAP32[$8>>2]|0;
  $15 = (($14) + -1)|0;
  $16 = ($14|0)==(0);
  L6: do {
   if (!($16)) {
    if ($12) {
     $$08695 = $121;$$08794 = $122;$110 = $15;
     while(1) {
      $68 = HEAP32[$$08794>>2]|0;
      $69 = $68 >>> 16;
      $70 = $69 & 255;
      $71 = $68 >>> 8;
      $72 = $71 & 255;
      $73 = $68 & 255;
      $74 = HEAP32[$$08695>>2]|0;
      $75 = $74 >>> 16;
      $76 = $75 & 255;
      $77 = $74 >>> 8;
      $78 = $77 & 255;
      $79 = $74 & 255;
      $trunc$clear1 = $trunc & 127;
      switch ($trunc$clear1<<24>>24) {
      case 16:  {
       $80 = $68 >>> 24;
       $81 = $80 ^ 255;
       $82 = Math_imul($76, $81)|0;
       $83 = (($82>>>0) / 255)&-1;
       $84 = (($70) + ($83))|0;
       $85 = Math_imul($78, $81)|0;
       $86 = (($85>>>0) / 255)&-1;
       $87 = (($72) + ($86))|0;
       $88 = Math_imul($81, $79)|0;
       $89 = (($88>>>0) / 255)&-1;
       $90 = (($73) + ($89))|0;
       $$088 = $90;$$089 = $87;$$090 = $84;
       break;
      }
      case 32:  {
       $91 = (($70) + ($76))|0;
       $92 = ($91>>>0)<(255);
       $$ = $92 ? $91 : 255;
       $93 = (($72) + ($78))|0;
       $94 = ($93>>>0)<(255);
       $$3 = $94 ? $93 : 255;
       $95 = (($73) + ($79))|0;
       $96 = ($95>>>0)<(255);
       $$1 = $96 ? $95 : 255;
       $$088 = $$1;$$089 = $$3;$$090 = $$;
       break;
      }
      case 64:  {
       $97 = Math_imul($70, $76)|0;
       $98 = (($97>>>0) / 255)&-1;
       $99 = Math_imul($72, $78)|0;
       $100 = (($99>>>0) / 255)&-1;
       $101 = Math_imul($73, $79)|0;
       $102 = (($101>>>0) / 255)&-1;
       $$088 = $102;$$089 = $100;$$090 = $98;
       break;
      }
      default: {
       $$088 = $79;$$089 = $78;$$090 = $76;
      }
      }
      $103 = $$090 << 16;
      $104 = $$089 << 8;
      $105 = $104 | $103;
      $106 = $105 | $$088;
      HEAP32[$$08695>>2] = $106;
      $107 = ((($$08794)) + 4|0);
      $108 = ((($$08695)) + 4|0);
      $109 = (($110) + -1)|0;
      $111 = ($110|0)==(0);
      if ($111) {
       break L6;
      } else {
       $$08695 = $108;$$08794 = $107;$110 = $109;
      }
     }
    } else {
     $$08695$us = $121;$$08794$us = $122;$66 = $15;
    }
    while(1) {
     $17 = HEAP32[$$08794$us>>2]|0;
     $18 = $17 >>> 16;
     $19 = $18 & 255;
     $20 = $17 >>> 8;
     $21 = $20 & 255;
     $22 = $17 & 255;
     $23 = $17 >>> 24;
     $24 = HEAP32[$$08695$us>>2]|0;
     $25 = $24 >>> 16;
     $26 = $25 & 255;
     $27 = $24 >>> 8;
     $28 = $27 & 255;
     $29 = $24 & 255;
     $30 = ($23|0)==(255);
     if ($30) {
      $$091$us = $19;$$092$us = $22;$$093$us = $21;
     } else {
      $31 = Math_imul($22, $23)|0;
      $32 = Math_imul($21, $23)|0;
      $33 = Math_imul($19, $23)|0;
      $34 = (($33>>>0) / 255)&-1;
      $35 = (($32>>>0) / 255)&-1;
      $36 = (($31>>>0) / 255)&-1;
      $$091$us = $34;$$092$us = $36;$$093$us = $35;
     }
     $trunc$clear = $trunc & 127;
     switch ($trunc$clear<<24>>24) {
     case 16:  {
      $49 = $23 ^ 255;
      $50 = Math_imul($26, $49)|0;
      $51 = (($50>>>0) / 255)&-1;
      $52 = (($$091$us) + ($51))|0;
      $53 = Math_imul($28, $49)|0;
      $54 = (($53>>>0) / 255)&-1;
      $55 = (($$093$us) + ($54))|0;
      $56 = Math_imul($49, $29)|0;
      $57 = (($56>>>0) / 255)&-1;
      $58 = (($$092$us) + ($57))|0;
      $$088$us = $58;$$089$us = $55;$$090$us = $52;
      break;
     }
     case 32:  {
      $43 = (($$091$us) + ($26))|0;
      $44 = ($43>>>0)<(255);
      $$$us = $44 ? $43 : 255;
      $45 = (($$093$us) + ($28))|0;
      $46 = ($45>>>0)<(255);
      $$3$us = $46 ? $45 : 255;
      $47 = (($$092$us) + ($29))|0;
      $48 = ($47>>>0)<(255);
      $$1$us = $48 ? $47 : 255;
      $$088$us = $$1$us;$$089$us = $$3$us;$$090$us = $$$us;
      break;
     }
     case 64:  {
      $37 = Math_imul($$091$us, $26)|0;
      $38 = (($37>>>0) / 255)&-1;
      $39 = Math_imul($$093$us, $28)|0;
      $40 = (($39>>>0) / 255)&-1;
      $41 = Math_imul($$092$us, $29)|0;
      $42 = (($41>>>0) / 255)&-1;
      $$088$us = $42;$$089$us = $40;$$090$us = $38;
      break;
     }
     default: {
      $$088$us = $29;$$089$us = $28;$$090$us = $26;
     }
     }
     $59 = $$090$us << 16;
     $60 = $$089$us << 8;
     $61 = $60 | $59;
     $62 = $61 | $$088$us;
     HEAP32[$$08695$us>>2] = $62;
     $63 = ((($$08794$us)) + 4|0);
     $64 = ((($$08695$us)) + 4|0);
     $65 = (($66) + -1)|0;
     $67 = ($66|0)==(0);
     if ($67) {
      break L6;
     } else {
      $$08695$us = $64;$$08794$us = $63;$66 = $65;
     }
    }
   }
  } while(0);
  $112 = HEAP32[$9>>2]|0;
  $113 = (($114) + ($112)|0);
  $115 = HEAP32[$10>>2]|0;
  $116 = (($117) + ($115)|0);
  $118 = HEAP32[$3>>2]|0;
  $119 = (($118) + -1)|0;
  HEAP32[$3>>2] = $119;
  $120 = ($118|0)==(0);
  if ($120) {
   break;
  } else {
   $114 = $113;$117 = $116;$121 = $116;$122 = $113;
  }
 }
 HEAP32[$0>>2] = $113;
 HEAP32[$7>>2] = $116;
 return;
}
function _SDL_Blit_ARGB8888_RGB888_Blend_Scale($0) {
 $0 = $0|0;
 var $$ = 0, $$0113143 = 0, $$0114142 = 0, $$0116 = 0, $$0117 = 0, $$0118141 = 0, $$0120147 = 0, $$0122140 = 0, $$0125146 = 0, $$0127 = 0, $$0128 = 0, $$0129 = 0, $$0130 = 0, $$1 = 0, $$1115 = 0, $$1121$lcssa = 0, $$1126$lcssa = 0, $$2 = 0, $$2124 = 0, $$3 = 0;
 var $$in = 0, $$pre = 0, $$pre154 = 0, $$pre155 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $trunc = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 << 16;
 $6 = ((($0)) + 28|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5|0) / ($7|0))&-1;
 $9 = ((($0)) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10 << 16;
 $12 = ((($0)) + 24|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($11|0) / ($13|0))&-1;
 $15 = (($7) + -1)|0;
 HEAP32[$6>>2] = $15;
 $16 = ($7|0)==(0);
 if ($16) {
  return;
 }
 $17 = ((($0)) + 20|0);
 $18 = ((($0)) + 32|0);
 $19 = $2 & 48;
 $20 = ($19|0)!=(0);
 $21 = $2 & 112;
 $trunc = $21&255;
 $22 = ((($0)) + 12|0);
 $$pre = HEAP32[$17>>2]|0;
 $$0120147 = 0;$$0125146 = 0;$102 = $15;$103 = $$pre;$30 = $13;$97 = $$pre;
 while(1) {
  $23 = ($$0120147|0)>(65535);
  if ($23) {
   $24 = (($$0120147) + -65536)|0;
   $25 = $24 >>> 16;
   $26 = $25 << 16;
   $27 = (($$0125146) + 1)|0;
   $28 = (($27) + ($25))|0;
   $29 = (($24) - ($26))|0;
   $$1121$lcssa = $29;$$1126$lcssa = $28;
  } else {
   $$1121$lcssa = $$0120147;$$1126$lcssa = $$0125146;
  }
  $31 = ($30|0)==(0);
  if ($31) {
   $99 = $102;
  } else {
   $$0113143 = $103;$$0114142 = 0;$$0118141 = 65536;$$0122140 = -1;$$in = $30;
   while(1) {
    $32 = (($$in) + -1)|0;
    $33 = ($$0118141|0)>(65535);
    if ($33) {
     $34 = (($$0118141) + -65536)|0;
     $35 = $34 >>> 16;
     $36 = $35 << 16;
     $37 = (($$0122140) + 1)|0;
     $38 = (($37) + ($35))|0;
     $39 = (($34) - ($36))|0;
     $40 = HEAP32[$0>>2]|0;
     $41 = HEAP32[$22>>2]|0;
     $42 = Math_imul($41, $$1126$lcssa)|0;
     $43 = (($40) + ($42)|0);
     $44 = $38 << 2;
     $45 = (($43) + ($44)|0);
     $$1115 = $45;$$2 = $39;$$2124 = $38;
    } else {
     $$1115 = $$0114142;$$2 = $$0118141;$$2124 = $$0122140;
    }
    $46 = HEAP32[$$1115>>2]|0;
    $47 = $46 >>> 16;
    $48 = $47 & 255;
    $49 = $46 >>> 8;
    $50 = $49 & 255;
    $51 = $46 & 255;
    $52 = $46 >>> 24;
    $53 = HEAP32[$$0113143>>2]|0;
    $54 = $53 >>> 16;
    $55 = $54 & 255;
    $56 = $53 >>> 8;
    $57 = $56 & 255;
    $58 = $53 & 255;
    $59 = ($52|0)!=(255);
    $or$cond = $20 & $59;
    if ($or$cond) {
     $60 = Math_imul($51, $52)|0;
     $61 = Math_imul($50, $52)|0;
     $62 = Math_imul($48, $52)|0;
     $63 = (($62>>>0) / 255)&-1;
     $64 = (($61>>>0) / 255)&-1;
     $65 = (($60>>>0) / 255)&-1;
     $$0116 = $63;$$0117 = $64;$$0130 = $65;
    } else {
     $$0116 = $48;$$0117 = $50;$$0130 = $51;
    }
    $trunc$clear = $trunc & 127;
    switch ($trunc$clear<<24>>24) {
    case 16:  {
     $66 = $52 ^ 255;
     $67 = Math_imul($55, $66)|0;
     $68 = (($67>>>0) / 255)&-1;
     $69 = (($$0116) + ($68))|0;
     $70 = Math_imul($57, $66)|0;
     $71 = (($70>>>0) / 255)&-1;
     $72 = (($$0117) + ($71))|0;
     $73 = Math_imul($66, $58)|0;
     $74 = (($73>>>0) / 255)&-1;
     $75 = (($$0130) + ($74))|0;
     $$0127 = $75;$$0128 = $72;$$0129 = $69;
     break;
    }
    case 32:  {
     $76 = (($$0116) + ($55))|0;
     $77 = ($76>>>0)<(255);
     $$ = $77 ? $76 : 255;
     $78 = (($$0117) + ($57))|0;
     $79 = ($78>>>0)<(255);
     $$3 = $79 ? $78 : 255;
     $80 = (($$0130) + ($58))|0;
     $81 = ($80>>>0)<(255);
     $$1 = $81 ? $80 : 255;
     $$0127 = $$1;$$0128 = $$3;$$0129 = $$;
     break;
    }
    case 64:  {
     $82 = Math_imul($$0116, $55)|0;
     $83 = (($82>>>0) / 255)&-1;
     $84 = Math_imul($$0117, $57)|0;
     $85 = (($84>>>0) / 255)&-1;
     $86 = Math_imul($$0130, $58)|0;
     $87 = (($86>>>0) / 255)&-1;
     $$0127 = $87;$$0128 = $85;$$0129 = $83;
     break;
    }
    default: {
     $$0127 = $58;$$0128 = $57;$$0129 = $55;
    }
    }
    $88 = $$0129 << 16;
    $89 = $$0128 << 8;
    $90 = $89 | $88;
    $91 = $90 | $$0127;
    HEAP32[$$0113143>>2] = $91;
    $92 = (($$2) + ($14))|0;
    $93 = ((($$0113143)) + 4|0);
    $94 = ($32|0)==(0);
    if ($94) {
     break;
    } else {
     $$0113143 = $93;$$0114142 = $$1115;$$0118141 = $92;$$0122140 = $$2124;$$in = $32;
    }
   }
   $$pre155 = HEAP32[$6>>2]|0;
   $99 = $$pre155;
  }
  $95 = HEAP32[$18>>2]|0;
  $96 = (($97) + ($95)|0);
  $98 = (($99) + -1)|0;
  HEAP32[$6>>2] = $98;
  $100 = ($99|0)==(0);
  if ($100) {
   break;
  }
  $101 = (($$1121$lcssa) + ($8))|0;
  $$pre154 = HEAP32[$12>>2]|0;
  $$0120147 = $101;$$0125146 = $$1126$lcssa;$102 = $98;$103 = $96;$30 = $$pre154;$97 = $96;
 }
 HEAP32[$17>>2] = $96;
 return;
}
function _SDL_Blit_ARGB8888_RGB888_Modulate($0) {
 $0 = $0|0;
 var $$05157 = 0, $$05157$us$us = 0, $$05256 = 0, $$05256$us$us = 0, $$in = 0, $$in68 = 0, $$lcssa77$sink = 0, $$lcssa78$sink = 0, $$pre71 = 0, $$pre72 = 0, $$pre73 = 0, $$pre74 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = ((($0)) + 61|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = ((($0)) + 62|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = ((($0)) + 28|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($13) + -1)|0;
 HEAP32[$12>>2] = $14;
 $15 = ($13|0)==(0);
 if ($15) {
  return;
 }
 $16 = ((($0)) + 20|0);
 $17 = ((($0)) + 24|0);
 $18 = ((($0)) + 12|0);
 $19 = ((($0)) + 32|0);
 $20 = $2 & 1;
 $21 = ($20|0)==(0);
 $$pre72 = HEAP32[$0>>2]|0;
 $$pre73 = HEAP32[$16>>2]|0;
 if ($21) {
  $26 = $$pre72;$29 = $$pre73;$70 = $14;$71 = $$pre73;$72 = $$pre72;
  while(1) {
   $22 = HEAP32[$17>>2]|0;
   $23 = ($22|0)==(0);
   if ($23) {
    $31 = $70;
   } else {
    $$05157$us$us = $71;$$05256$us$us = $72;$$in68 = $22;
    while(1) {
     $33 = (($$in68) + -1)|0;
     $34 = HEAP32[$$05256$us$us>>2]|0;
     $35 = $34 & 16777215;
     HEAP32[$$05157$us$us>>2] = $35;
     $36 = ((($$05256$us$us)) + 4|0);
     $37 = ((($$05157$us$us)) + 4|0);
     $38 = ($33|0)==(0);
     if ($38) {
      break;
     } else {
      $$05157$us$us = $37;$$05256$us$us = $36;$$in68 = $33;
     }
    }
    $$pre74 = HEAP32[$12>>2]|0;
    $31 = $$pre74;
   }
   $24 = HEAP32[$18>>2]|0;
   $25 = (($26) + ($24)|0);
   $27 = HEAP32[$19>>2]|0;
   $28 = (($29) + ($27)|0);
   $30 = (($31) + -1)|0;
   HEAP32[$12>>2] = $30;
   $32 = ($31|0)==(0);
   if ($32) {
    $$lcssa77$sink = $25;$$lcssa78$sink = $28;
    break;
   } else {
    $26 = $25;$29 = $28;$70 = $30;$71 = $28;$72 = $25;
   }
  }
 } else {
  $63 = $$pre72;$66 = $$pre73;$73 = $14;$74 = $$pre73;$75 = $$pre72;
  while(1) {
   $39 = HEAP32[$17>>2]|0;
   $40 = ($39|0)==(0);
   if ($40) {
    $68 = $73;
   } else {
    $$05157 = $74;$$05256 = $75;$$in = $39;
    while(1) {
     $41 = (($$in) + -1)|0;
     $42 = HEAP32[$$05256>>2]|0;
     $43 = $42 >>> 16;
     $44 = $43 & 255;
     $45 = $42 >>> 8;
     $46 = $45 & 255;
     $47 = $42 & 255;
     $48 = Math_imul($47, $11)|0;
     $49 = Math_imul($46, $8)|0;
     $50 = Math_imul($44, $5)|0;
     $51 = (($50>>>0) / 255)&-1;
     $52 = (($49>>>0) / 255)&-1;
     $53 = (($48>>>0) / 255)&-1;
     $54 = $51 << 16;
     $55 = $52 << 8;
     $56 = $55 | $54;
     $57 = $56 | $53;
     HEAP32[$$05157>>2] = $57;
     $58 = ((($$05256)) + 4|0);
     $59 = ((($$05157)) + 4|0);
     $60 = ($41|0)==(0);
     if ($60) {
      break;
     } else {
      $$05157 = $59;$$05256 = $58;$$in = $41;
     }
    }
    $$pre71 = HEAP32[$12>>2]|0;
    $68 = $$pre71;
   }
   $61 = HEAP32[$18>>2]|0;
   $62 = (($63) + ($61)|0);
   $64 = HEAP32[$19>>2]|0;
   $65 = (($66) + ($64)|0);
   $67 = (($68) + -1)|0;
   HEAP32[$12>>2] = $67;
   $69 = ($68|0)==(0);
   if ($69) {
    $$lcssa77$sink = $62;$$lcssa78$sink = $65;
    break;
   } else {
    $63 = $62;$66 = $65;$73 = $67;$74 = $65;$75 = $62;
   }
  }
 }
 HEAP32[$0>>2] = $$lcssa77$sink;
 HEAP32[$16>>2] = $$lcssa78$sink;
 return;
}
function _SDL_Blit_ARGB8888_RGB888_Modulate_Scale($0) {
 $0 = $0|0;
 var $$078104 = 0, $$078104$us = 0, $$079103 = 0, $$079103$us = 0, $$081102 = 0, $$081102$us = 0, $$083108 = 0, $$085101 = 0, $$085101$us = 0, $$088107 = 0, $$1 = 0, $$1$us = 0, $$184$lcssa = 0, $$189$lcssa = 0, $$2 = 0, $$2$us = 0, $$287 = 0, $$287$us = 0, $$pre = 0, $$pre118 = 0;
 var $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = ((($0)) + 61|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = ((($0)) + 62|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = ((($0)) + 8|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13 << 16;
 $15 = ((($0)) + 28|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($14|0) / ($16|0))&-1;
 $18 = ((($0)) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = $19 << 16;
 $21 = ((($0)) + 24|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($20|0) / ($22|0))&-1;
 $24 = (($16) + -1)|0;
 HEAP32[$15>>2] = $24;
 $25 = ($16|0)==(0);
 if ($25) {
  return;
 }
 $26 = ((($0)) + 20|0);
 $27 = ((($0)) + 32|0);
 $28 = $2 & 1;
 $29 = ($28|0)==(0);
 $30 = ((($0)) + 12|0);
 $$pre = HEAP32[$26>>2]|0;
 $$083108 = 0;$$088107 = 0;$102 = $$pre;$39 = $22;$97 = $$pre;
 while(1) {
  $31 = ($$083108|0)>(65535);
  if ($31) {
   $32 = (($$083108) + -65536)|0;
   $33 = $32 >>> 16;
   $34 = $33 << 16;
   $35 = (($$088107) + 1)|0;
   $36 = (($35) + ($33))|0;
   $37 = (($32) - ($34))|0;
   $$184$lcssa = $37;$$189$lcssa = $36;
  } else {
   $$184$lcssa = $$083108;$$189$lcssa = $$088107;
  }
  $38 = (($39) + -1)|0;
  $40 = ($39|0)==(0);
  if (!($40)) {
   if ($29) {
    $$078104$us = $102;$$079103$us = 0;$$081102$us = 65536;$$085101$us = -1;$59 = $38;
    while(1) {
     $41 = ($$081102$us|0)>(65535);
     if ($41) {
      $42 = (($$081102$us) + -65536)|0;
      $43 = $42 >>> 16;
      $44 = $43 << 16;
      $45 = (($$085101$us) + 1)|0;
      $46 = (($45) + ($43))|0;
      $47 = (($42) - ($44))|0;
      $48 = HEAP32[$0>>2]|0;
      $49 = HEAP32[$30>>2]|0;
      $50 = Math_imul($49, $$189$lcssa)|0;
      $51 = (($48) + ($50)|0);
      $52 = $46 << 2;
      $53 = (($51) + ($52)|0);
      $$1$us = $53;$$2$us = $47;$$287$us = $46;
     } else {
      $$1$us = $$079103$us;$$2$us = $$081102$us;$$287$us = $$085101$us;
     }
     $54 = HEAP32[$$1$us>>2]|0;
     $55 = $54 & 16777215;
     HEAP32[$$078104$us>>2] = $55;
     $56 = (($$2$us) + ($23))|0;
     $57 = ((($$078104$us)) + 4|0);
     $58 = (($59) + -1)|0;
     $60 = ($59|0)==(0);
     if ($60) {
      break;
     } else {
      $$078104$us = $57;$$079103$us = $$1$us;$$081102$us = $56;$$085101$us = $$287$us;$59 = $58;
     }
    }
   } else {
    $$078104 = $102;$$079103 = 0;$$081102 = 65536;$$085101 = -1;$93 = $38;
    while(1) {
     $61 = ($$081102|0)>(65535);
     if ($61) {
      $62 = (($$081102) + -65536)|0;
      $63 = $62 >>> 16;
      $64 = $63 << 16;
      $65 = (($$085101) + 1)|0;
      $66 = (($65) + ($63))|0;
      $67 = (($62) - ($64))|0;
      $68 = HEAP32[$0>>2]|0;
      $69 = HEAP32[$30>>2]|0;
      $70 = Math_imul($69, $$189$lcssa)|0;
      $71 = (($68) + ($70)|0);
      $72 = $66 << 2;
      $73 = (($71) + ($72)|0);
      $$1 = $73;$$2 = $67;$$287 = $66;
     } else {
      $$1 = $$079103;$$2 = $$081102;$$287 = $$085101;
     }
     $74 = HEAP32[$$1>>2]|0;
     $75 = $74 >>> 16;
     $76 = $75 & 255;
     $77 = $74 >>> 8;
     $78 = $77 & 255;
     $79 = $74 & 255;
     $80 = Math_imul($79, $11)|0;
     $81 = Math_imul($78, $8)|0;
     $82 = Math_imul($76, $5)|0;
     $83 = (($82>>>0) / 255)&-1;
     $84 = (($81>>>0) / 255)&-1;
     $85 = (($80>>>0) / 255)&-1;
     $86 = $83 << 16;
     $87 = $84 << 8;
     $88 = $85 | $87;
     $89 = $88 | $86;
     HEAP32[$$078104>>2] = $89;
     $90 = (($$2) + ($23))|0;
     $91 = ((($$078104)) + 4|0);
     $92 = (($93) + -1)|0;
     $94 = ($93|0)==(0);
     if ($94) {
      break;
     } else {
      $$078104 = $91;$$079103 = $$1;$$081102 = $90;$$085101 = $$287;$93 = $92;
     }
    }
   }
  }
  $95 = HEAP32[$27>>2]|0;
  $96 = (($97) + ($95)|0);
  $98 = HEAP32[$15>>2]|0;
  $99 = (($98) + -1)|0;
  HEAP32[$15>>2] = $99;
  $100 = ($98|0)==(0);
  if ($100) {
   break;
  }
  $101 = (($$184$lcssa) + ($17))|0;
  $$pre118 = HEAP32[$21>>2]|0;
  $$083108 = $101;$$088107 = $$189$lcssa;$102 = $96;$39 = $$pre118;$97 = $96;
 }
 HEAP32[$26>>2] = $96;
 return;
}
function _SDL_Blit_ARGB8888_RGB888_Modulate_Blend($0) {
 $0 = $0|0;
 var $$ = 0, $$0108121 = 0, $$0109120 = 0, $$0110 = 0, $$0111 = 0, $$0112 = 0, $$0113 = 0, $$0114 = 0, $$0116 = 0, $$0118 = 0, $$1 = 0, $$1115 = 0, $$1117 = 0, $$1119 = 0, $$3 = 0, $$in = 0, $$pre = 0, $$pre125 = 0, $$pre126 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $or$cond = 0, $trunc = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = ((($0)) + 61|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = ((($0)) + 62|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = ((($0)) + 63|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = $13&255;
 $15 = ((($0)) + 28|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + -1)|0;
 HEAP32[$15>>2] = $17;
 $18 = ($16|0)==(0);
 if ($18) {
  return;
 }
 $19 = ((($0)) + 20|0);
 $20 = ((($0)) + 24|0);
 $21 = ((($0)) + 12|0);
 $22 = ((($0)) + 32|0);
 $23 = $2 & 1;
 $24 = ($23|0)==(0);
 $25 = $2 & 2;
 $26 = ($25|0)==(0);
 $27 = $2 & 48;
 $28 = ($27|0)!=(0);
 $29 = $2 & 112;
 $trunc = $29&255;
 $$pre = HEAP32[$0>>2]|0;
 $$pre125 = HEAP32[$19>>2]|0;
 $100 = $$pre125;$101 = $$pre;$92 = $$pre;$95 = $$pre125;$99 = $17;
 while(1) {
  $30 = HEAP32[$20>>2]|0;
  $31 = ($30|0)==(0);
  if ($31) {
   $97 = $99;
  } else {
   $$0108121 = $100;$$0109120 = $101;$$in = $30;
   while(1) {
    $32 = (($$in) + -1)|0;
    $33 = HEAP32[$$0109120>>2]|0;
    $34 = $33 >>> 16;
    $35 = $34 & 255;
    $36 = $33 >>> 8;
    $37 = $36 & 255;
    $38 = $33 & 255;
    $39 = $33 >>> 24;
    $40 = HEAP32[$$0108121>>2]|0;
    $41 = $40 >>> 16;
    $42 = $41 & 255;
    $43 = $40 >>> 8;
    $44 = $43 & 255;
    $45 = $40 & 255;
    if ($24) {
     $$0114 = $38;$$0116 = $37;$$0118 = $35;
    } else {
     $46 = Math_imul($38, $11)|0;
     $47 = Math_imul($37, $8)|0;
     $48 = Math_imul($35, $5)|0;
     $49 = (($48>>>0) / 255)&-1;
     $50 = (($47>>>0) / 255)&-1;
     $51 = (($46>>>0) / 255)&-1;
     $$0114 = $51;$$0116 = $50;$$0118 = $49;
    }
    $52 = Math_imul($39, $14)|0;
    $53 = (($52>>>0) / 255)&-1;
    $$0113 = $26 ? $39 : $53;
    $54 = ($$0113>>>0)<(255);
    $or$cond = $28 & $54;
    if ($or$cond) {
     $55 = Math_imul($$0114, $$0113)|0;
     $56 = Math_imul($$0116, $$0113)|0;
     $57 = Math_imul($$0118, $$0113)|0;
     $58 = (($57>>>0) / 255)&-1;
     $59 = (($56>>>0) / 255)&-1;
     $60 = (($55>>>0) / 255)&-1;
     $$1115 = $60;$$1117 = $59;$$1119 = $58;
    } else {
     $$1115 = $$0114;$$1117 = $$0116;$$1119 = $$0118;
    }
    $trunc$clear = $trunc & 127;
    switch ($trunc$clear<<24>>24) {
    case 16:  {
     $61 = (255 - ($$0113))|0;
     $62 = Math_imul($61, $42)|0;
     $63 = (($62>>>0) / 255)&-1;
     $64 = (($$1119) + ($63))|0;
     $65 = Math_imul($61, $44)|0;
     $66 = (($65>>>0) / 255)&-1;
     $67 = (($$1117) + ($66))|0;
     $68 = Math_imul($61, $45)|0;
     $69 = (($68>>>0) / 255)&-1;
     $70 = (($$1115) + ($69))|0;
     $$0110 = $70;$$0111 = $67;$$0112 = $64;
     break;
    }
    case 32:  {
     $71 = (($$1119) + ($42))|0;
     $72 = ($71>>>0)<(255);
     $$ = $72 ? $71 : 255;
     $73 = (($$1117) + ($44))|0;
     $74 = ($73>>>0)<(255);
     $$3 = $74 ? $73 : 255;
     $75 = (($$1115) + ($45))|0;
     $76 = ($75>>>0)<(255);
     $$1 = $76 ? $75 : 255;
     $$0110 = $$1;$$0111 = $$3;$$0112 = $$;
     break;
    }
    case 64:  {
     $77 = Math_imul($$1119, $42)|0;
     $78 = (($77>>>0) / 255)&-1;
     $79 = Math_imul($$1117, $44)|0;
     $80 = (($79>>>0) / 255)&-1;
     $81 = Math_imul($$1115, $45)|0;
     $82 = (($81>>>0) / 255)&-1;
     $$0110 = $82;$$0111 = $80;$$0112 = $78;
     break;
    }
    default: {
     $$0110 = $45;$$0111 = $44;$$0112 = $42;
    }
    }
    $83 = $$0112 << 16;
    $84 = $$0111 << 8;
    $85 = $84 | $83;
    $86 = $85 | $$0110;
    HEAP32[$$0108121>>2] = $86;
    $87 = ((($$0109120)) + 4|0);
    $88 = ((($$0108121)) + 4|0);
    $89 = ($32|0)==(0);
    if ($89) {
     break;
    } else {
     $$0108121 = $88;$$0109120 = $87;$$in = $32;
    }
   }
   $$pre126 = HEAP32[$15>>2]|0;
   $97 = $$pre126;
  }
  $90 = HEAP32[$21>>2]|0;
  $91 = (($92) + ($90)|0);
  $93 = HEAP32[$22>>2]|0;
  $94 = (($95) + ($93)|0);
  $96 = (($97) + -1)|0;
  HEAP32[$15>>2] = $96;
  $98 = ($97|0)==(0);
  if ($98) {
   break;
  } else {
   $100 = $94;$101 = $91;$92 = $91;$95 = $94;$99 = $96;
  }
 }
 HEAP32[$0>>2] = $91;
 HEAP32[$19>>2] = $94;
 return;
}
function _SDL_Blit_ARGB8888_RGB888_Modulate_Blend_Scale($0) {
 $0 = $0|0;
 var $$ = 0, $$0135169 = 0, $$0136168 = 0, $$0138 = 0, $$0140 = 0, $$0142167 = 0, $$0144173 = 0, $$0146166 = 0, $$0149172 = 0, $$0151 = 0, $$0152 = 0, $$0153 = 0, $$0154 = 0, $$0155 = 0, $$1 = 0, $$1137 = 0, $$1139 = 0, $$1141 = 0, $$1145$lcssa = 0, $$1150$lcssa = 0;
 var $$1156 = 0, $$2 = 0, $$2148 = 0, $$3 = 0, $$in = 0, $$pre = 0, $$pre180 = 0, $$pre181 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $trunc = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = ((($0)) + 61|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = ((($0)) + 62|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = ((($0)) + 63|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = $13&255;
 $15 = ((($0)) + 8|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $16 << 16;
 $18 = ((($0)) + 28|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($17|0) / ($19|0))&-1;
 $21 = ((($0)) + 4|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = $22 << 16;
 $24 = ((($0)) + 24|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($23|0) / ($25|0))&-1;
 $27 = (($19) + -1)|0;
 HEAP32[$18>>2] = $27;
 $28 = ($19|0)==(0);
 if ($28) {
  return;
 }
 $29 = ((($0)) + 20|0);
 $30 = ((($0)) + 32|0);
 $31 = $2 & 1;
 $32 = ($31|0)==(0);
 $33 = $2 & 2;
 $34 = ($33|0)==(0);
 $35 = $2 & 48;
 $36 = ($35|0)!=(0);
 $37 = $2 & 112;
 $trunc = $37&255;
 $38 = ((($0)) + 12|0);
 $$pre = HEAP32[$29>>2]|0;
 $$0144173 = 0;$$0149172 = 0;$121 = $$pre;$126 = $27;$127 = $$pre;$46 = $25;
 while(1) {
  $39 = ($$0144173|0)>(65535);
  if ($39) {
   $40 = (($$0144173) + -65536)|0;
   $41 = $40 >>> 16;
   $42 = $41 << 16;
   $43 = (($$0149172) + 1)|0;
   $44 = (($43) + ($41))|0;
   $45 = (($40) - ($42))|0;
   $$1145$lcssa = $45;$$1150$lcssa = $44;
  } else {
   $$1145$lcssa = $$0144173;$$1150$lcssa = $$0149172;
  }
  $47 = ($46|0)==(0);
  if ($47) {
   $123 = $126;
  } else {
   $$0135169 = $127;$$0136168 = 0;$$0142167 = 65536;$$0146166 = -1;$$in = $46;
   while(1) {
    $48 = (($$in) + -1)|0;
    $49 = ($$0142167|0)>(65535);
    if ($49) {
     $50 = (($$0142167) + -65536)|0;
     $51 = $50 >>> 16;
     $52 = $51 << 16;
     $53 = (($$0146166) + 1)|0;
     $54 = (($53) + ($51))|0;
     $55 = (($50) - ($52))|0;
     $56 = HEAP32[$0>>2]|0;
     $57 = HEAP32[$38>>2]|0;
     $58 = Math_imul($57, $$1150$lcssa)|0;
     $59 = (($56) + ($58)|0);
     $60 = $54 << 2;
     $61 = (($59) + ($60)|0);
     $$1137 = $61;$$2 = $55;$$2148 = $54;
    } else {
     $$1137 = $$0136168;$$2 = $$0142167;$$2148 = $$0146166;
    }
    $62 = HEAP32[$$1137>>2]|0;
    $63 = $62 >>> 16;
    $64 = $63 & 255;
    $65 = $62 >>> 8;
    $66 = $65 & 255;
    $67 = $62 & 255;
    $68 = $62 >>> 24;
    $69 = HEAP32[$$0135169>>2]|0;
    $70 = $69 >>> 16;
    $71 = $70 & 255;
    $72 = $69 >>> 8;
    $73 = $72 & 255;
    $74 = $69 & 255;
    if ($32) {
     $$0138 = $64;$$0140 = $66;$$0155 = $67;
    } else {
     $75 = Math_imul($67, $11)|0;
     $76 = Math_imul($66, $8)|0;
     $77 = Math_imul($64, $5)|0;
     $78 = (($77>>>0) / 255)&-1;
     $79 = (($76>>>0) / 255)&-1;
     $80 = (($75>>>0) / 255)&-1;
     $$0138 = $78;$$0140 = $79;$$0155 = $80;
    }
    $81 = Math_imul($68, $14)|0;
    $82 = (($81>>>0) / 255)&-1;
    $$0154 = $34 ? $68 : $82;
    $83 = ($$0154>>>0)<(255);
    $or$cond = $36 & $83;
    if ($or$cond) {
     $84 = Math_imul($$0155, $$0154)|0;
     $85 = Math_imul($$0140, $$0154)|0;
     $86 = Math_imul($$0138, $$0154)|0;
     $87 = (($86>>>0) / 255)&-1;
     $88 = (($85>>>0) / 255)&-1;
     $89 = (($84>>>0) / 255)&-1;
     $$1139 = $87;$$1141 = $88;$$1156 = $89;
    } else {
     $$1139 = $$0138;$$1141 = $$0140;$$1156 = $$0155;
    }
    $trunc$clear = $trunc & 127;
    switch ($trunc$clear<<24>>24) {
    case 16:  {
     $90 = (255 - ($$0154))|0;
     $91 = Math_imul($90, $71)|0;
     $92 = (($91>>>0) / 255)&-1;
     $93 = (($$1139) + ($92))|0;
     $94 = Math_imul($90, $73)|0;
     $95 = (($94>>>0) / 255)&-1;
     $96 = (($$1141) + ($95))|0;
     $97 = Math_imul($90, $74)|0;
     $98 = (($97>>>0) / 255)&-1;
     $99 = (($$1156) + ($98))|0;
     $$0151 = $99;$$0152 = $96;$$0153 = $93;
     break;
    }
    case 32:  {
     $100 = (($$1139) + ($71))|0;
     $101 = ($100>>>0)<(255);
     $$ = $101 ? $100 : 255;
     $102 = (($$1141) + ($73))|0;
     $103 = ($102>>>0)<(255);
     $$3 = $103 ? $102 : 255;
     $104 = (($$1156) + ($74))|0;
     $105 = ($104>>>0)<(255);
     $$1 = $105 ? $104 : 255;
     $$0151 = $$1;$$0152 = $$3;$$0153 = $$;
     break;
    }
    case 64:  {
     $106 = Math_imul($$1139, $71)|0;
     $107 = (($106>>>0) / 255)&-1;
     $108 = Math_imul($$1141, $73)|0;
     $109 = (($108>>>0) / 255)&-1;
     $110 = Math_imul($$1156, $74)|0;
     $111 = (($110>>>0) / 255)&-1;
     $$0151 = $111;$$0152 = $109;$$0153 = $107;
     break;
    }
    default: {
     $$0151 = $74;$$0152 = $73;$$0153 = $71;
    }
    }
    $112 = $$0153 << 16;
    $113 = $$0152 << 8;
    $114 = $113 | $112;
    $115 = $114 | $$0151;
    HEAP32[$$0135169>>2] = $115;
    $116 = (($$2) + ($26))|0;
    $117 = ((($$0135169)) + 4|0);
    $118 = ($48|0)==(0);
    if ($118) {
     break;
    } else {
     $$0135169 = $117;$$0136168 = $$1137;$$0142167 = $116;$$0146166 = $$2148;$$in = $48;
    }
   }
   $$pre181 = HEAP32[$18>>2]|0;
   $123 = $$pre181;
  }
  $119 = HEAP32[$30>>2]|0;
  $120 = (($121) + ($119)|0);
  $122 = (($123) + -1)|0;
  HEAP32[$18>>2] = $122;
  $124 = ($123|0)==(0);
  if ($124) {
   break;
  }
  $125 = (($$1145$lcssa) + ($20))|0;
  $$pre180 = HEAP32[$24>>2]|0;
  $$0144173 = $125;$$0149172 = $$1150$lcssa;$121 = $120;$126 = $122;$127 = $120;$46 = $$pre180;
 }
 HEAP32[$29>>2] = $120;
 return;
}
function _SDL_Blit_ARGB8888_BGR888_Scale($0) {
 $0 = $0|0;
 var $$05982 = 0, $$06081 = 0, $$06186 = 0, $$06380 = 0, $$06579 = 0, $$06885 = 0, $$1 = 0, $$162$lcssa = 0, $$169$lcssa = 0, $$2 = 0, $$267 = 0, $$in = 0, $$pre = 0, $$pre93 = 0, $$pre94 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 << 16;
 $4 = ((($0)) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3|0) / ($5|0))&-1;
 $7 = ((($0)) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 << 16;
 $10 = ((($0)) + 24|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($9|0) / ($11|0))&-1;
 $13 = (($5) + -1)|0;
 HEAP32[$4>>2] = $13;
 $14 = ($5|0)==(0);
 if ($14) {
  return;
 }
 $15 = ((($0)) + 20|0);
 $16 = ((($0)) + 32|0);
 $17 = ((($0)) + 12|0);
 $$pre = HEAP32[$15>>2]|0;
 $$06186 = 0;$$06885 = 0;$25 = $11;$54 = $$pre;$59 = $13;$60 = $$pre;
 while(1) {
  $18 = ($$06885|0)>(65535);
  if ($18) {
   $19 = (($$06885) + -65536)|0;
   $20 = $19 >>> 16;
   $21 = $20 << 16;
   $22 = (($$06186) + 1)|0;
   $23 = (($22) + ($20))|0;
   $24 = (($19) - ($21))|0;
   $$162$lcssa = $23;$$169$lcssa = $24;
  } else {
   $$162$lcssa = $$06186;$$169$lcssa = $$06885;
  }
  $26 = ($25|0)==(0);
  if ($26) {
   $56 = $59;
  } else {
   $$05982 = $60;$$06081 = 0;$$06380 = -1;$$06579 = 65536;$$in = $25;
   while(1) {
    $27 = (($$in) + -1)|0;
    $28 = ($$06579|0)>(65535);
    if ($28) {
     $29 = (($$06579) + -65536)|0;
     $30 = $29 >>> 16;
     $31 = $30 << 16;
     $32 = (($$06380) + 1)|0;
     $33 = (($32) + ($30))|0;
     $34 = (($29) - ($31))|0;
     $35 = HEAP32[$0>>2]|0;
     $36 = HEAP32[$17>>2]|0;
     $37 = Math_imul($36, $$162$lcssa)|0;
     $38 = (($35) + ($37)|0);
     $39 = $33 << 2;
     $40 = (($38) + ($39)|0);
     $$1 = $40;$$2 = $33;$$267 = $34;
    } else {
     $$1 = $$06081;$$2 = $$06380;$$267 = $$06579;
    }
    $41 = HEAP32[$$1>>2]|0;
    $42 = $41 >>> 16;
    $43 = $42 & 255;
    $44 = $41 & 65280;
    $45 = $41 << 16;
    $46 = $45 & 16711680;
    $47 = $46 | $44;
    $48 = $47 | $43;
    HEAP32[$$05982>>2] = $48;
    $49 = (($$267) + ($12))|0;
    $50 = ((($$05982)) + 4|0);
    $51 = ($27|0)==(0);
    if ($51) {
     break;
    } else {
     $$05982 = $50;$$06081 = $$1;$$06380 = $$2;$$06579 = $49;$$in = $27;
    }
   }
   $$pre94 = HEAP32[$4>>2]|0;
   $56 = $$pre94;
  }
  $52 = HEAP32[$16>>2]|0;
  $53 = (($54) + ($52)|0);
  $55 = (($56) + -1)|0;
  HEAP32[$4>>2] = $55;
  $57 = ($56|0)==(0);
  if ($57) {
   break;
  }
  $58 = (($$169$lcssa) + ($6))|0;
  $$pre93 = HEAP32[$10>>2]|0;
  $$06186 = $$162$lcssa;$$06885 = $58;$25 = $$pre93;$54 = $53;$59 = $55;$60 = $53;
 }
 HEAP32[$15>>2] = $53;
 return;
}
function _SDL_Blit_ARGB8888_BGR888_Blend($0) {
 $0 = $0|0;
 var $$ = 0, $$$us = 0, $$08695 = 0, $$08695$us = 0, $$08794 = 0, $$08794$us = 0, $$088 = 0, $$088$us = 0, $$089 = 0, $$089$us = 0, $$090 = 0, $$090$us = 0, $$091$us = 0, $$092$us = 0, $$093$us = 0, $$1 = 0, $$1$us = 0, $$3 = 0, $$3$us = 0, $$pre = 0;
 var $$pre100 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $trunc = 0, $trunc$clear = 0, $trunc$clear1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + -1)|0;
 HEAP32[$3>>2] = $5;
 $6 = ($4|0)==(0);
 if ($6) {
  return;
 }
 $7 = ((($0)) + 20|0);
 $8 = ((($0)) + 24|0);
 $9 = ((($0)) + 12|0);
 $10 = ((($0)) + 32|0);
 $11 = $2 & 48;
 $12 = ($11|0)==(0);
 $13 = $2 & 112;
 $trunc = $13&255;
 $$pre = HEAP32[$0>>2]|0;
 $$pre100 = HEAP32[$7>>2]|0;
 $114 = $$pre;$117 = $$pre100;$121 = $$pre100;$122 = $$pre;
 while(1) {
  $14 = HEAP32[$8>>2]|0;
  $15 = (($14) + -1)|0;
  $16 = ($14|0)==(0);
  L6: do {
   if (!($16)) {
    if ($12) {
     $$08695 = $121;$$08794 = $122;$110 = $15;
     while(1) {
      $68 = HEAP32[$$08794>>2]|0;
      $69 = $68 >>> 16;
      $70 = $69 & 255;
      $71 = $68 >>> 8;
      $72 = $71 & 255;
      $73 = $68 & 255;
      $74 = HEAP32[$$08695>>2]|0;
      $75 = $74 >>> 16;
      $76 = $75 & 255;
      $77 = $74 >>> 8;
      $78 = $77 & 255;
      $79 = $74 & 255;
      $trunc$clear1 = $trunc & 127;
      switch ($trunc$clear1<<24>>24) {
      case 16:  {
       $80 = $68 >>> 24;
       $81 = $80 ^ 255;
       $82 = Math_imul($81, $79)|0;
       $83 = (($82>>>0) / 255)&-1;
       $84 = (($70) + ($83))|0;
       $85 = Math_imul($78, $81)|0;
       $86 = (($85>>>0) / 255)&-1;
       $87 = (($72) + ($86))|0;
       $88 = Math_imul($76, $81)|0;
       $89 = (($88>>>0) / 255)&-1;
       $90 = (($73) + ($89))|0;
       $$088 = $90;$$089 = $87;$$090 = $84;
       break;
      }
      case 32:  {
       $91 = (($70) + ($79))|0;
       $92 = ($91>>>0)<(255);
       $$ = $92 ? $91 : 255;
       $93 = (($72) + ($78))|0;
       $94 = ($93>>>0)<(255);
       $$3 = $94 ? $93 : 255;
       $95 = (($73) + ($76))|0;
       $96 = ($95>>>0)<(255);
       $$1 = $96 ? $95 : 255;
       $$088 = $$1;$$089 = $$3;$$090 = $$;
       break;
      }
      case 64:  {
       $97 = Math_imul($70, $79)|0;
       $98 = (($97>>>0) / 255)&-1;
       $99 = Math_imul($72, $78)|0;
       $100 = (($99>>>0) / 255)&-1;
       $101 = Math_imul($73, $76)|0;
       $102 = (($101>>>0) / 255)&-1;
       $$088 = $102;$$089 = $100;$$090 = $98;
       break;
      }
      default: {
       $$088 = $76;$$089 = $78;$$090 = $79;
      }
      }
      $103 = $$088 << 16;
      $104 = $$089 << 8;
      $105 = $104 | $$090;
      $106 = $105 | $103;
      HEAP32[$$08695>>2] = $106;
      $107 = ((($$08794)) + 4|0);
      $108 = ((($$08695)) + 4|0);
      $109 = (($110) + -1)|0;
      $111 = ($110|0)==(0);
      if ($111) {
       break L6;
      } else {
       $$08695 = $108;$$08794 = $107;$110 = $109;
      }
     }
    } else {
     $$08695$us = $121;$$08794$us = $122;$66 = $15;
    }
    while(1) {
     $17 = HEAP32[$$08794$us>>2]|0;
     $18 = $17 >>> 16;
     $19 = $18 & 255;
     $20 = $17 >>> 8;
     $21 = $20 & 255;
     $22 = $17 & 255;
     $23 = $17 >>> 24;
     $24 = HEAP32[$$08695$us>>2]|0;
     $25 = $24 >>> 16;
     $26 = $25 & 255;
     $27 = $24 >>> 8;
     $28 = $27 & 255;
     $29 = $24 & 255;
     $30 = ($23|0)==(255);
     if ($30) {
      $$091$us = $19;$$092$us = $22;$$093$us = $21;
     } else {
      $31 = Math_imul($22, $23)|0;
      $32 = Math_imul($21, $23)|0;
      $33 = Math_imul($19, $23)|0;
      $34 = (($33>>>0) / 255)&-1;
      $35 = (($32>>>0) / 255)&-1;
      $36 = (($31>>>0) / 255)&-1;
      $$091$us = $34;$$092$us = $36;$$093$us = $35;
     }
     $trunc$clear = $trunc & 127;
     switch ($trunc$clear<<24>>24) {
     case 16:  {
      $49 = $23 ^ 255;
      $50 = Math_imul($49, $29)|0;
      $51 = (($50>>>0) / 255)&-1;
      $52 = (($$091$us) + ($51))|0;
      $53 = Math_imul($28, $49)|0;
      $54 = (($53>>>0) / 255)&-1;
      $55 = (($$093$us) + ($54))|0;
      $56 = Math_imul($26, $49)|0;
      $57 = (($56>>>0) / 255)&-1;
      $58 = (($$092$us) + ($57))|0;
      $$088$us = $58;$$089$us = $55;$$090$us = $52;
      break;
     }
     case 32:  {
      $43 = (($$091$us) + ($29))|0;
      $44 = ($43>>>0)<(255);
      $$$us = $44 ? $43 : 255;
      $45 = (($$093$us) + ($28))|0;
      $46 = ($45>>>0)<(255);
      $$3$us = $46 ? $45 : 255;
      $47 = (($$092$us) + ($26))|0;
      $48 = ($47>>>0)<(255);
      $$1$us = $48 ? $47 : 255;
      $$088$us = $$1$us;$$089$us = $$3$us;$$090$us = $$$us;
      break;
     }
     case 64:  {
      $37 = Math_imul($$091$us, $29)|0;
      $38 = (($37>>>0) / 255)&-1;
      $39 = Math_imul($$093$us, $28)|0;
      $40 = (($39>>>0) / 255)&-1;
      $41 = Math_imul($$092$us, $26)|0;
      $42 = (($41>>>0) / 255)&-1;
      $$088$us = $42;$$089$us = $40;$$090$us = $38;
      break;
     }
     default: {
      $$088$us = $26;$$089$us = $28;$$090$us = $29;
     }
     }
     $59 = $$088$us << 16;
     $60 = $$089$us << 8;
     $61 = $60 | $$090$us;
     $62 = $61 | $59;
     HEAP32[$$08695$us>>2] = $62;
     $63 = ((($$08794$us)) + 4|0);
     $64 = ((($$08695$us)) + 4|0);
     $65 = (($66) + -1)|0;
     $67 = ($66|0)==(0);
     if ($67) {
      break L6;
     } else {
      $$08695$us = $64;$$08794$us = $63;$66 = $65;
     }
    }
   }
  } while(0);
  $112 = HEAP32[$9>>2]|0;
  $113 = (($114) + ($112)|0);
  $115 = HEAP32[$10>>2]|0;
  $116 = (($117) + ($115)|0);
  $118 = HEAP32[$3>>2]|0;
  $119 = (($118) + -1)|0;
  HEAP32[$3>>2] = $119;
  $120 = ($118|0)==(0);
  if ($120) {
   break;
  } else {
   $114 = $113;$117 = $116;$121 = $116;$122 = $113;
  }
 }
 HEAP32[$0>>2] = $113;
 HEAP32[$7>>2] = $116;
 return;
}
function _SDL_Blit_ARGB8888_BGR888_Blend_Scale($0) {
 $0 = $0|0;
 var $$ = 0, $$0113143 = 0, $$0114142 = 0, $$0116 = 0, $$0117 = 0, $$0118141 = 0, $$0120147 = 0, $$0122140 = 0, $$0125146 = 0, $$0127 = 0, $$0128 = 0, $$0129 = 0, $$0130 = 0, $$1 = 0, $$1115 = 0, $$1121$lcssa = 0, $$1126$lcssa = 0, $$2 = 0, $$2124 = 0, $$3 = 0;
 var $$in = 0, $$pre = 0, $$pre154 = 0, $$pre155 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $trunc = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 << 16;
 $6 = ((($0)) + 28|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5|0) / ($7|0))&-1;
 $9 = ((($0)) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10 << 16;
 $12 = ((($0)) + 24|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($11|0) / ($13|0))&-1;
 $15 = (($7) + -1)|0;
 HEAP32[$6>>2] = $15;
 $16 = ($7|0)==(0);
 if ($16) {
  return;
 }
 $17 = ((($0)) + 20|0);
 $18 = ((($0)) + 32|0);
 $19 = $2 & 48;
 $20 = ($19|0)!=(0);
 $21 = $2 & 112;
 $trunc = $21&255;
 $22 = ((($0)) + 12|0);
 $$pre = HEAP32[$17>>2]|0;
 $$0120147 = 0;$$0125146 = 0;$102 = $15;$103 = $$pre;$30 = $13;$97 = $$pre;
 while(1) {
  $23 = ($$0120147|0)>(65535);
  if ($23) {
   $24 = (($$0120147) + -65536)|0;
   $25 = $24 >>> 16;
   $26 = $25 << 16;
   $27 = (($$0125146) + 1)|0;
   $28 = (($27) + ($25))|0;
   $29 = (($24) - ($26))|0;
   $$1121$lcssa = $29;$$1126$lcssa = $28;
  } else {
   $$1121$lcssa = $$0120147;$$1126$lcssa = $$0125146;
  }
  $31 = ($30|0)==(0);
  if ($31) {
   $99 = $102;
  } else {
   $$0113143 = $103;$$0114142 = 0;$$0118141 = 65536;$$0122140 = -1;$$in = $30;
   while(1) {
    $32 = (($$in) + -1)|0;
    $33 = ($$0118141|0)>(65535);
    if ($33) {
     $34 = (($$0118141) + -65536)|0;
     $35 = $34 >>> 16;
     $36 = $35 << 16;
     $37 = (($$0122140) + 1)|0;
     $38 = (($37) + ($35))|0;
     $39 = (($34) - ($36))|0;
     $40 = HEAP32[$0>>2]|0;
     $41 = HEAP32[$22>>2]|0;
     $42 = Math_imul($41, $$1126$lcssa)|0;
     $43 = (($40) + ($42)|0);
     $44 = $38 << 2;
     $45 = (($43) + ($44)|0);
     $$1115 = $45;$$2 = $39;$$2124 = $38;
    } else {
     $$1115 = $$0114142;$$2 = $$0118141;$$2124 = $$0122140;
    }
    $46 = HEAP32[$$1115>>2]|0;
    $47 = $46 >>> 16;
    $48 = $47 & 255;
    $49 = $46 >>> 8;
    $50 = $49 & 255;
    $51 = $46 & 255;
    $52 = $46 >>> 24;
    $53 = HEAP32[$$0113143>>2]|0;
    $54 = $53 >>> 16;
    $55 = $54 & 255;
    $56 = $53 >>> 8;
    $57 = $56 & 255;
    $58 = $53 & 255;
    $59 = ($52|0)!=(255);
    $or$cond = $20 & $59;
    if ($or$cond) {
     $60 = Math_imul($51, $52)|0;
     $61 = Math_imul($50, $52)|0;
     $62 = Math_imul($48, $52)|0;
     $63 = (($62>>>0) / 255)&-1;
     $64 = (($61>>>0) / 255)&-1;
     $65 = (($60>>>0) / 255)&-1;
     $$0116 = $63;$$0117 = $64;$$0130 = $65;
    } else {
     $$0116 = $48;$$0117 = $50;$$0130 = $51;
    }
    $trunc$clear = $trunc & 127;
    switch ($trunc$clear<<24>>24) {
    case 16:  {
     $66 = $52 ^ 255;
     $67 = Math_imul($66, $58)|0;
     $68 = (($67>>>0) / 255)&-1;
     $69 = (($$0116) + ($68))|0;
     $70 = Math_imul($57, $66)|0;
     $71 = (($70>>>0) / 255)&-1;
     $72 = (($$0117) + ($71))|0;
     $73 = Math_imul($55, $66)|0;
     $74 = (($73>>>0) / 255)&-1;
     $75 = (($$0130) + ($74))|0;
     $$0127 = $75;$$0128 = $72;$$0129 = $69;
     break;
    }
    case 32:  {
     $76 = (($$0116) + ($58))|0;
     $77 = ($76>>>0)<(255);
     $$ = $77 ? $76 : 255;
     $78 = (($$0117) + ($57))|0;
     $79 = ($78>>>0)<(255);
     $$3 = $79 ? $78 : 255;
     $80 = (($$0130) + ($55))|0;
     $81 = ($80>>>0)<(255);
     $$1 = $81 ? $80 : 255;
     $$0127 = $$1;$$0128 = $$3;$$0129 = $$;
     break;
    }
    case 64:  {
     $82 = Math_imul($$0116, $58)|0;
     $83 = (($82>>>0) / 255)&-1;
     $84 = Math_imul($$0117, $57)|0;
     $85 = (($84>>>0) / 255)&-1;
     $86 = Math_imul($$0130, $55)|0;
     $87 = (($86>>>0) / 255)&-1;
     $$0127 = $87;$$0128 = $85;$$0129 = $83;
     break;
    }
    default: {
     $$0127 = $55;$$0128 = $57;$$0129 = $58;
    }
    }
    $88 = $$0127 << 16;
    $89 = $$0128 << 8;
    $90 = $89 | $$0129;
    $91 = $90 | $88;
    HEAP32[$$0113143>>2] = $91;
    $92 = (($$2) + ($14))|0;
    $93 = ((($$0113143)) + 4|0);
    $94 = ($32|0)==(0);
    if ($94) {
     break;
    } else {
     $$0113143 = $93;$$0114142 = $$1115;$$0118141 = $92;$$0122140 = $$2124;$$in = $32;
    }
   }
   $$pre155 = HEAP32[$6>>2]|0;
   $99 = $$pre155;
  }
  $95 = HEAP32[$18>>2]|0;
  $96 = (($97) + ($95)|0);
  $98 = (($99) + -1)|0;
  HEAP32[$6>>2] = $98;
  $100 = ($99|0)==(0);
  if ($100) {
   break;
  }
  $101 = (($$1121$lcssa) + ($8))|0;
  $$pre154 = HEAP32[$12>>2]|0;
  $$0120147 = $101;$$0125146 = $$1126$lcssa;$102 = $98;$103 = $96;$30 = $$pre154;$97 = $96;
 }
 HEAP32[$17>>2] = $96;
 return;
}
function _SDL_Blit_ARGB8888_BGR888_Modulate($0) {
 $0 = $0|0;
 var $$05157 = 0, $$05157$us$us = 0, $$05256 = 0, $$05256$us$us = 0, $$in = 0, $$in68 = 0, $$lcssa77$sink = 0, $$lcssa78$sink = 0, $$pre71 = 0, $$pre72 = 0, $$pre73 = 0, $$pre74 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = ((($0)) + 61|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = ((($0)) + 62|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = ((($0)) + 28|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($13) + -1)|0;
 HEAP32[$12>>2] = $14;
 $15 = ($13|0)==(0);
 if ($15) {
  return;
 }
 $16 = ((($0)) + 20|0);
 $17 = ((($0)) + 24|0);
 $18 = ((($0)) + 12|0);
 $19 = ((($0)) + 32|0);
 $20 = $2 & 1;
 $21 = ($20|0)==(0);
 $$pre72 = HEAP32[$0>>2]|0;
 $$pre73 = HEAP32[$16>>2]|0;
 if ($21) {
  $26 = $$pre72;$29 = $$pre73;$76 = $14;$77 = $$pre73;$78 = $$pre72;
  while(1) {
   $22 = HEAP32[$17>>2]|0;
   $23 = ($22|0)==(0);
   if ($23) {
    $31 = $76;
   } else {
    $$05157$us$us = $77;$$05256$us$us = $78;$$in68 = $22;
    while(1) {
     $33 = (($$in68) + -1)|0;
     $34 = HEAP32[$$05256$us$us>>2]|0;
     $35 = $34 >>> 16;
     $36 = $35 & 255;
     $37 = $34 & 65280;
     $38 = $34 << 16;
     $39 = $38 & 16711680;
     $40 = $37 | $36;
     $41 = $40 | $39;
     HEAP32[$$05157$us$us>>2] = $41;
     $42 = ((($$05256$us$us)) + 4|0);
     $43 = ((($$05157$us$us)) + 4|0);
     $44 = ($33|0)==(0);
     if ($44) {
      break;
     } else {
      $$05157$us$us = $43;$$05256$us$us = $42;$$in68 = $33;
     }
    }
    $$pre74 = HEAP32[$12>>2]|0;
    $31 = $$pre74;
   }
   $24 = HEAP32[$18>>2]|0;
   $25 = (($26) + ($24)|0);
   $27 = HEAP32[$19>>2]|0;
   $28 = (($29) + ($27)|0);
   $30 = (($31) + -1)|0;
   HEAP32[$12>>2] = $30;
   $32 = ($31|0)==(0);
   if ($32) {
    $$lcssa77$sink = $25;$$lcssa78$sink = $28;
    break;
   } else {
    $26 = $25;$29 = $28;$76 = $30;$77 = $28;$78 = $25;
   }
  }
 } else {
  $69 = $$pre72;$72 = $$pre73;$79 = $14;$80 = $$pre73;$81 = $$pre72;
  while(1) {
   $45 = HEAP32[$17>>2]|0;
   $46 = ($45|0)==(0);
   if ($46) {
    $74 = $79;
   } else {
    $$05157 = $80;$$05256 = $81;$$in = $45;
    while(1) {
     $47 = (($$in) + -1)|0;
     $48 = HEAP32[$$05256>>2]|0;
     $49 = $48 >>> 16;
     $50 = $49 & 255;
     $51 = $48 >>> 8;
     $52 = $51 & 255;
     $53 = $48 & 255;
     $54 = Math_imul($53, $11)|0;
     $55 = Math_imul($52, $8)|0;
     $56 = Math_imul($50, $5)|0;
     $57 = (($56>>>0) / 255)&-1;
     $58 = (($55>>>0) / 255)&-1;
     $59 = (($54>>>0) / 255)&-1;
     $60 = $59 << 16;
     $61 = $58 << 8;
     $62 = $61 | $57;
     $63 = $62 | $60;
     HEAP32[$$05157>>2] = $63;
     $64 = ((($$05256)) + 4|0);
     $65 = ((($$05157)) + 4|0);
     $66 = ($47|0)==(0);
     if ($66) {
      break;
     } else {
      $$05157 = $65;$$05256 = $64;$$in = $47;
     }
    }
    $$pre71 = HEAP32[$12>>2]|0;
    $74 = $$pre71;
   }
   $67 = HEAP32[$18>>2]|0;
   $68 = (($69) + ($67)|0);
   $70 = HEAP32[$19>>2]|0;
   $71 = (($72) + ($70)|0);
   $73 = (($74) + -1)|0;
   HEAP32[$12>>2] = $73;
   $75 = ($74|0)==(0);
   if ($75) {
    $$lcssa77$sink = $68;$$lcssa78$sink = $71;
    break;
   } else {
    $69 = $68;$72 = $71;$79 = $73;$80 = $71;$81 = $68;
   }
  }
 }
 HEAP32[$0>>2] = $$lcssa77$sink;
 HEAP32[$16>>2] = $$lcssa78$sink;
 return;
}
function _SDL_Blit_ARGB8888_BGR888_Modulate_Scale($0) {
 $0 = $0|0;
 var $$078104 = 0, $$078104$us = 0, $$079103 = 0, $$079103$us = 0, $$081102 = 0, $$081102$us = 0, $$083108 = 0, $$085101 = 0, $$085101$us = 0, $$088107 = 0, $$1 = 0, $$1$us = 0, $$184$lcssa = 0, $$189$lcssa = 0, $$2 = 0, $$2$us = 0, $$287 = 0, $$287$us = 0, $$pre = 0, $$pre118 = 0;
 var $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = ((($0)) + 61|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = ((($0)) + 62|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = ((($0)) + 8|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13 << 16;
 $15 = ((($0)) + 28|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($14|0) / ($16|0))&-1;
 $18 = ((($0)) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = $19 << 16;
 $21 = ((($0)) + 24|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($20|0) / ($22|0))&-1;
 $24 = (($16) + -1)|0;
 HEAP32[$15>>2] = $24;
 $25 = ($16|0)==(0);
 if ($25) {
  return;
 }
 $26 = ((($0)) + 20|0);
 $27 = ((($0)) + 32|0);
 $28 = $2 & 1;
 $29 = ($28|0)==(0);
 $30 = ((($0)) + 12|0);
 $$pre = HEAP32[$26>>2]|0;
 $$083108 = 0;$$088107 = 0;$103 = $$pre;$108 = $$pre;$39 = $22;
 while(1) {
  $31 = ($$083108|0)>(65535);
  if ($31) {
   $32 = (($$083108) + -65536)|0;
   $33 = $32 >>> 16;
   $34 = $33 << 16;
   $35 = (($$088107) + 1)|0;
   $36 = (($35) + ($33))|0;
   $37 = (($32) - ($34))|0;
   $$184$lcssa = $37;$$189$lcssa = $36;
  } else {
   $$184$lcssa = $$083108;$$189$lcssa = $$088107;
  }
  $38 = (($39) + -1)|0;
  $40 = ($39|0)==(0);
  if (!($40)) {
   if ($29) {
    $$078104$us = $108;$$079103$us = 0;$$081102$us = 65536;$$085101$us = -1;$65 = $38;
    while(1) {
     $41 = ($$081102$us|0)>(65535);
     if ($41) {
      $42 = (($$081102$us) + -65536)|0;
      $43 = $42 >>> 16;
      $44 = $43 << 16;
      $45 = (($$085101$us) + 1)|0;
      $46 = (($45) + ($43))|0;
      $47 = (($42) - ($44))|0;
      $48 = HEAP32[$0>>2]|0;
      $49 = HEAP32[$30>>2]|0;
      $50 = Math_imul($49, $$189$lcssa)|0;
      $51 = (($48) + ($50)|0);
      $52 = $46 << 2;
      $53 = (($51) + ($52)|0);
      $$1$us = $53;$$2$us = $47;$$287$us = $46;
     } else {
      $$1$us = $$079103$us;$$2$us = $$081102$us;$$287$us = $$085101$us;
     }
     $54 = HEAP32[$$1$us>>2]|0;
     $55 = $54 >>> 16;
     $56 = $55 & 255;
     $57 = $54 & 65280;
     $58 = $54 << 16;
     $59 = $58 & 16711680;
     $60 = $59 | $57;
     $61 = $60 | $56;
     HEAP32[$$078104$us>>2] = $61;
     $62 = (($$2$us) + ($23))|0;
     $63 = ((($$078104$us)) + 4|0);
     $64 = (($65) + -1)|0;
     $66 = ($65|0)==(0);
     if ($66) {
      break;
     } else {
      $$078104$us = $63;$$079103$us = $$1$us;$$081102$us = $62;$$085101$us = $$287$us;$65 = $64;
     }
    }
   } else {
    $$078104 = $108;$$079103 = 0;$$081102 = 65536;$$085101 = -1;$99 = $38;
    while(1) {
     $67 = ($$081102|0)>(65535);
     if ($67) {
      $68 = (($$081102) + -65536)|0;
      $69 = $68 >>> 16;
      $70 = $69 << 16;
      $71 = (($$085101) + 1)|0;
      $72 = (($71) + ($69))|0;
      $73 = (($68) - ($70))|0;
      $74 = HEAP32[$0>>2]|0;
      $75 = HEAP32[$30>>2]|0;
      $76 = Math_imul($75, $$189$lcssa)|0;
      $77 = (($74) + ($76)|0);
      $78 = $72 << 2;
      $79 = (($77) + ($78)|0);
      $$1 = $79;$$2 = $73;$$287 = $72;
     } else {
      $$1 = $$079103;$$2 = $$081102;$$287 = $$085101;
     }
     $80 = HEAP32[$$1>>2]|0;
     $81 = $80 >>> 16;
     $82 = $81 & 255;
     $83 = $80 >>> 8;
     $84 = $83 & 255;
     $85 = $80 & 255;
     $86 = Math_imul($85, $11)|0;
     $87 = Math_imul($84, $8)|0;
     $88 = Math_imul($82, $5)|0;
     $89 = (($88>>>0) / 255)&-1;
     $90 = (($87>>>0) / 255)&-1;
     $91 = (($86>>>0) / 255)&-1;
     $92 = $91 << 16;
     $93 = $90 << 8;
     $94 = $92 | $93;
     $95 = $94 | $89;
     HEAP32[$$078104>>2] = $95;
     $96 = (($$2) + ($23))|0;
     $97 = ((($$078104)) + 4|0);
     $98 = (($99) + -1)|0;
     $100 = ($99|0)==(0);
     if ($100) {
      break;
     } else {
      $$078104 = $97;$$079103 = $$1;$$081102 = $96;$$085101 = $$287;$99 = $98;
     }
    }
   }
  }
  $101 = HEAP32[$27>>2]|0;
  $102 = (($103) + ($101)|0);
  $104 = HEAP32[$15>>2]|0;
  $105 = (($104) + -1)|0;
  HEAP32[$15>>2] = $105;
  $106 = ($104|0)==(0);
  if ($106) {
   break;
  }
  $107 = (($$184$lcssa) + ($17))|0;
  $$pre118 = HEAP32[$21>>2]|0;
  $$083108 = $107;$$088107 = $$189$lcssa;$103 = $102;$108 = $102;$39 = $$pre118;
 }
 HEAP32[$26>>2] = $102;
 return;
}
function _SDL_Blit_ARGB8888_BGR888_Modulate_Blend($0) {
 $0 = $0|0;
 var $$ = 0, $$0108121 = 0, $$0109120 = 0, $$0110 = 0, $$0111 = 0, $$0112 = 0, $$0113 = 0, $$0114 = 0, $$0116 = 0, $$0118 = 0, $$1 = 0, $$1115 = 0, $$1117 = 0, $$1119 = 0, $$3 = 0, $$in = 0, $$pre = 0, $$pre125 = 0, $$pre126 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $or$cond = 0, $trunc = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = ((($0)) + 61|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = ((($0)) + 62|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = ((($0)) + 63|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = $13&255;
 $15 = ((($0)) + 28|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + -1)|0;
 HEAP32[$15>>2] = $17;
 $18 = ($16|0)==(0);
 if ($18) {
  return;
 }
 $19 = ((($0)) + 20|0);
 $20 = ((($0)) + 24|0);
 $21 = ((($0)) + 12|0);
 $22 = ((($0)) + 32|0);
 $23 = $2 & 1;
 $24 = ($23|0)==(0);
 $25 = $2 & 2;
 $26 = ($25|0)==(0);
 $27 = $2 & 48;
 $28 = ($27|0)!=(0);
 $29 = $2 & 112;
 $trunc = $29&255;
 $$pre = HEAP32[$0>>2]|0;
 $$pre125 = HEAP32[$19>>2]|0;
 $100 = $$pre125;$101 = $$pre;$92 = $$pre;$95 = $$pre125;$99 = $17;
 while(1) {
  $30 = HEAP32[$20>>2]|0;
  $31 = ($30|0)==(0);
  if ($31) {
   $97 = $99;
  } else {
   $$0108121 = $100;$$0109120 = $101;$$in = $30;
   while(1) {
    $32 = (($$in) + -1)|0;
    $33 = HEAP32[$$0109120>>2]|0;
    $34 = $33 >>> 16;
    $35 = $34 & 255;
    $36 = $33 >>> 8;
    $37 = $36 & 255;
    $38 = $33 & 255;
    $39 = $33 >>> 24;
    $40 = HEAP32[$$0108121>>2]|0;
    $41 = $40 >>> 16;
    $42 = $41 & 255;
    $43 = $40 >>> 8;
    $44 = $43 & 255;
    $45 = $40 & 255;
    if ($24) {
     $$0114 = $38;$$0116 = $37;$$0118 = $35;
    } else {
     $46 = Math_imul($38, $11)|0;
     $47 = Math_imul($37, $8)|0;
     $48 = Math_imul($35, $5)|0;
     $49 = (($48>>>0) / 255)&-1;
     $50 = (($47>>>0) / 255)&-1;
     $51 = (($46>>>0) / 255)&-1;
     $$0114 = $51;$$0116 = $50;$$0118 = $49;
    }
    $52 = Math_imul($39, $14)|0;
    $53 = (($52>>>0) / 255)&-1;
    $$0113 = $26 ? $39 : $53;
    $54 = ($$0113>>>0)<(255);
    $or$cond = $28 & $54;
    if ($or$cond) {
     $55 = Math_imul($$0114, $$0113)|0;
     $56 = Math_imul($$0116, $$0113)|0;
     $57 = Math_imul($$0118, $$0113)|0;
     $58 = (($57>>>0) / 255)&-1;
     $59 = (($56>>>0) / 255)&-1;
     $60 = (($55>>>0) / 255)&-1;
     $$1115 = $60;$$1117 = $59;$$1119 = $58;
    } else {
     $$1115 = $$0114;$$1117 = $$0116;$$1119 = $$0118;
    }
    $trunc$clear = $trunc & 127;
    switch ($trunc$clear<<24>>24) {
    case 16:  {
     $61 = (255 - ($$0113))|0;
     $62 = Math_imul($61, $45)|0;
     $63 = (($62>>>0) / 255)&-1;
     $64 = (($$1119) + ($63))|0;
     $65 = Math_imul($61, $44)|0;
     $66 = (($65>>>0) / 255)&-1;
     $67 = (($$1117) + ($66))|0;
     $68 = Math_imul($61, $42)|0;
     $69 = (($68>>>0) / 255)&-1;
     $70 = (($$1115) + ($69))|0;
     $$0110 = $70;$$0111 = $67;$$0112 = $64;
     break;
    }
    case 32:  {
     $71 = (($$1119) + ($45))|0;
     $72 = ($71>>>0)<(255);
     $$ = $72 ? $71 : 255;
     $73 = (($$1117) + ($44))|0;
     $74 = ($73>>>0)<(255);
     $$3 = $74 ? $73 : 255;
     $75 = (($$1115) + ($42))|0;
     $76 = ($75>>>0)<(255);
     $$1 = $76 ? $75 : 255;
     $$0110 = $$1;$$0111 = $$3;$$0112 = $$;
     break;
    }
    case 64:  {
     $77 = Math_imul($$1119, $45)|0;
     $78 = (($77>>>0) / 255)&-1;
     $79 = Math_imul($$1117, $44)|0;
     $80 = (($79>>>0) / 255)&-1;
     $81 = Math_imul($$1115, $42)|0;
     $82 = (($81>>>0) / 255)&-1;
     $$0110 = $82;$$0111 = $80;$$0112 = $78;
     break;
    }
    default: {
     $$0110 = $42;$$0111 = $44;$$0112 = $45;
    }
    }
    $83 = $$0110 << 16;
    $84 = $$0111 << 8;
    $85 = $84 | $$0112;
    $86 = $85 | $83;
    HEAP32[$$0108121>>2] = $86;
    $87 = ((($$0109120)) + 4|0);
    $88 = ((($$0108121)) + 4|0);
    $89 = ($32|0)==(0);
    if ($89) {
     break;
    } else {
     $$0108121 = $88;$$0109120 = $87;$$in = $32;
    }
   }
   $$pre126 = HEAP32[$15>>2]|0;
   $97 = $$pre126;
  }
  $90 = HEAP32[$21>>2]|0;
  $91 = (($92) + ($90)|0);
  $93 = HEAP32[$22>>2]|0;
  $94 = (($95) + ($93)|0);
  $96 = (($97) + -1)|0;
  HEAP32[$15>>2] = $96;
  $98 = ($97|0)==(0);
  if ($98) {
   break;
  } else {
   $100 = $94;$101 = $91;$92 = $91;$95 = $94;$99 = $96;
  }
 }
 HEAP32[$0>>2] = $91;
 HEAP32[$19>>2] = $94;
 return;
}
function _SDL_Blit_ARGB8888_BGR888_Modulate_Blend_Scale($0) {
 $0 = $0|0;
 var $$ = 0, $$0135169 = 0, $$0136168 = 0, $$0138 = 0, $$0140 = 0, $$0142167 = 0, $$0144173 = 0, $$0146166 = 0, $$0149172 = 0, $$0151 = 0, $$0152 = 0, $$0153 = 0, $$0154 = 0, $$0155 = 0, $$1 = 0, $$1137 = 0, $$1139 = 0, $$1141 = 0, $$1145$lcssa = 0, $$1150$lcssa = 0;
 var $$1156 = 0, $$2 = 0, $$2148 = 0, $$3 = 0, $$in = 0, $$pre = 0, $$pre180 = 0, $$pre181 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $trunc = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = ((($0)) + 61|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = ((($0)) + 62|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = ((($0)) + 63|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = $13&255;
 $15 = ((($0)) + 8|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $16 << 16;
 $18 = ((($0)) + 28|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($17|0) / ($19|0))&-1;
 $21 = ((($0)) + 4|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = $22 << 16;
 $24 = ((($0)) + 24|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($23|0) / ($25|0))&-1;
 $27 = (($19) + -1)|0;
 HEAP32[$18>>2] = $27;
 $28 = ($19|0)==(0);
 if ($28) {
  return;
 }
 $29 = ((($0)) + 20|0);
 $30 = ((($0)) + 32|0);
 $31 = $2 & 1;
 $32 = ($31|0)==(0);
 $33 = $2 & 2;
 $34 = ($33|0)==(0);
 $35 = $2 & 48;
 $36 = ($35|0)!=(0);
 $37 = $2 & 112;
 $trunc = $37&255;
 $38 = ((($0)) + 12|0);
 $$pre = HEAP32[$29>>2]|0;
 $$0144173 = 0;$$0149172 = 0;$121 = $$pre;$126 = $27;$127 = $$pre;$46 = $25;
 while(1) {
  $39 = ($$0144173|0)>(65535);
  if ($39) {
   $40 = (($$0144173) + -65536)|0;
   $41 = $40 >>> 16;
   $42 = $41 << 16;
   $43 = (($$0149172) + 1)|0;
   $44 = (($43) + ($41))|0;
   $45 = (($40) - ($42))|0;
   $$1145$lcssa = $45;$$1150$lcssa = $44;
  } else {
   $$1145$lcssa = $$0144173;$$1150$lcssa = $$0149172;
  }
  $47 = ($46|0)==(0);
  if ($47) {
   $123 = $126;
  } else {
   $$0135169 = $127;$$0136168 = 0;$$0142167 = 65536;$$0146166 = -1;$$in = $46;
   while(1) {
    $48 = (($$in) + -1)|0;
    $49 = ($$0142167|0)>(65535);
    if ($49) {
     $50 = (($$0142167) + -65536)|0;
     $51 = $50 >>> 16;
     $52 = $51 << 16;
     $53 = (($$0146166) + 1)|0;
     $54 = (($53) + ($51))|0;
     $55 = (($50) - ($52))|0;
     $56 = HEAP32[$0>>2]|0;
     $57 = HEAP32[$38>>2]|0;
     $58 = Math_imul($57, $$1150$lcssa)|0;
     $59 = (($56) + ($58)|0);
     $60 = $54 << 2;
     $61 = (($59) + ($60)|0);
     $$1137 = $61;$$2 = $55;$$2148 = $54;
    } else {
     $$1137 = $$0136168;$$2 = $$0142167;$$2148 = $$0146166;
    }
    $62 = HEAP32[$$1137>>2]|0;
    $63 = $62 >>> 16;
    $64 = $63 & 255;
    $65 = $62 >>> 8;
    $66 = $65 & 255;
    $67 = $62 & 255;
    $68 = $62 >>> 24;
    $69 = HEAP32[$$0135169>>2]|0;
    $70 = $69 >>> 16;
    $71 = $70 & 255;
    $72 = $69 >>> 8;
    $73 = $72 & 255;
    $74 = $69 & 255;
    if ($32) {
     $$0138 = $64;$$0140 = $66;$$0155 = $67;
    } else {
     $75 = Math_imul($67, $11)|0;
     $76 = Math_imul($66, $8)|0;
     $77 = Math_imul($64, $5)|0;
     $78 = (($77>>>0) / 255)&-1;
     $79 = (($76>>>0) / 255)&-1;
     $80 = (($75>>>0) / 255)&-1;
     $$0138 = $78;$$0140 = $79;$$0155 = $80;
    }
    $81 = Math_imul($68, $14)|0;
    $82 = (($81>>>0) / 255)&-1;
    $$0154 = $34 ? $68 : $82;
    $83 = ($$0154>>>0)<(255);
    $or$cond = $36 & $83;
    if ($or$cond) {
     $84 = Math_imul($$0155, $$0154)|0;
     $85 = Math_imul($$0140, $$0154)|0;
     $86 = Math_imul($$0138, $$0154)|0;
     $87 = (($86>>>0) / 255)&-1;
     $88 = (($85>>>0) / 255)&-1;
     $89 = (($84>>>0) / 255)&-1;
     $$1139 = $87;$$1141 = $88;$$1156 = $89;
    } else {
     $$1139 = $$0138;$$1141 = $$0140;$$1156 = $$0155;
    }
    $trunc$clear = $trunc & 127;
    switch ($trunc$clear<<24>>24) {
    case 16:  {
     $90 = (255 - ($$0154))|0;
     $91 = Math_imul($90, $74)|0;
     $92 = (($91>>>0) / 255)&-1;
     $93 = (($$1139) + ($92))|0;
     $94 = Math_imul($90, $73)|0;
     $95 = (($94>>>0) / 255)&-1;
     $96 = (($$1141) + ($95))|0;
     $97 = Math_imul($90, $71)|0;
     $98 = (($97>>>0) / 255)&-1;
     $99 = (($$1156) + ($98))|0;
     $$0151 = $99;$$0152 = $96;$$0153 = $93;
     break;
    }
    case 32:  {
     $100 = (($$1139) + ($74))|0;
     $101 = ($100>>>0)<(255);
     $$ = $101 ? $100 : 255;
     $102 = (($$1141) + ($73))|0;
     $103 = ($102>>>0)<(255);
     $$3 = $103 ? $102 : 255;
     $104 = (($$1156) + ($71))|0;
     $105 = ($104>>>0)<(255);
     $$1 = $105 ? $104 : 255;
     $$0151 = $$1;$$0152 = $$3;$$0153 = $$;
     break;
    }
    case 64:  {
     $106 = Math_imul($$1139, $74)|0;
     $107 = (($106>>>0) / 255)&-1;
     $108 = Math_imul($$1141, $73)|0;
     $109 = (($108>>>0) / 255)&-1;
     $110 = Math_imul($$1156, $71)|0;
     $111 = (($110>>>0) / 255)&-1;
     $$0151 = $111;$$0152 = $109;$$0153 = $107;
     break;
    }
    default: {
     $$0151 = $71;$$0152 = $73;$$0153 = $74;
    }
    }
    $112 = $$0151 << 16;
    $113 = $$0152 << 8;
    $114 = $113 | $$0153;
    $115 = $114 | $112;
    HEAP32[$$0135169>>2] = $115;
    $116 = (($$2) + ($26))|0;
    $117 = ((($$0135169)) + 4|0);
    $118 = ($48|0)==(0);
    if ($118) {
     break;
    } else {
     $$0135169 = $117;$$0136168 = $$1137;$$0142167 = $116;$$0146166 = $$2148;$$in = $48;
    }
   }
   $$pre181 = HEAP32[$18>>2]|0;
   $123 = $$pre181;
  }
  $119 = HEAP32[$30>>2]|0;
  $120 = (($121) + ($119)|0);
  $122 = (($123) + -1)|0;
  HEAP32[$18>>2] = $122;
  $124 = ($123|0)==(0);
  if ($124) {
   break;
  }
  $125 = (($$1145$lcssa) + ($20))|0;
  $$pre180 = HEAP32[$24>>2]|0;
  $$0144173 = $125;$$0149172 = $$1150$lcssa;$121 = $120;$126 = $122;$127 = $120;$46 = $$pre180;
 }
 HEAP32[$29>>2] = $120;
 return;
}
function _SDL_Blit_ARGB8888_ARGB8888_Scale($0) {
 $0 = $0|0;
 var $$04467 = 0, $$04566 = 0, $$04671 = 0, $$04865 = 0, $$05064 = 0, $$05370 = 0, $$1 = 0, $$147$lcssa = 0, $$154$lcssa = 0, $$2 = 0, $$252 = 0, $$in = 0, $$pre = 0, $$pre78 = 0, $$pre79 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 << 16;
 $4 = ((($0)) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3|0) / ($5|0))&-1;
 $7 = ((($0)) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 << 16;
 $10 = ((($0)) + 24|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($9|0) / ($11|0))&-1;
 $13 = (($5) + -1)|0;
 HEAP32[$4>>2] = $13;
 $14 = ($5|0)==(0);
 if ($14) {
  return;
 }
 $15 = ((($0)) + 20|0);
 $16 = ((($0)) + 32|0);
 $17 = ((($0)) + 12|0);
 $$pre = HEAP32[$15>>2]|0;
 $$04671 = 0;$$05370 = 0;$25 = $11;$47 = $$pre;$52 = $13;$53 = $$pre;
 while(1) {
  $18 = ($$05370|0)>(65535);
  if ($18) {
   $19 = (($$05370) + -65536)|0;
   $20 = $19 >>> 16;
   $21 = $20 << 16;
   $22 = (($$04671) + 1)|0;
   $23 = (($22) + ($20))|0;
   $24 = (($19) - ($21))|0;
   $$147$lcssa = $23;$$154$lcssa = $24;
  } else {
   $$147$lcssa = $$04671;$$154$lcssa = $$05370;
  }
  $26 = ($25|0)==(0);
  if ($26) {
   $49 = $52;
  } else {
   $$04467 = $53;$$04566 = 0;$$04865 = -1;$$05064 = 65536;$$in = $25;
   while(1) {
    $27 = (($$in) + -1)|0;
    $28 = ($$05064|0)>(65535);
    if ($28) {
     $29 = (($$05064) + -65536)|0;
     $30 = $29 >>> 16;
     $31 = $30 << 16;
     $32 = (($$04865) + 1)|0;
     $33 = (($32) + ($30))|0;
     $34 = (($29) - ($31))|0;
     $35 = HEAP32[$0>>2]|0;
     $36 = HEAP32[$17>>2]|0;
     $37 = Math_imul($36, $$147$lcssa)|0;
     $38 = (($35) + ($37)|0);
     $39 = $33 << 2;
     $40 = (($38) + ($39)|0);
     $$1 = $40;$$2 = $33;$$252 = $34;
    } else {
     $$1 = $$04566;$$2 = $$04865;$$252 = $$05064;
    }
    $41 = HEAP32[$$1>>2]|0;
    HEAP32[$$04467>>2] = $41;
    $42 = (($$252) + ($12))|0;
    $43 = ((($$04467)) + 4|0);
    $44 = ($27|0)==(0);
    if ($44) {
     break;
    } else {
     $$04467 = $43;$$04566 = $$1;$$04865 = $$2;$$05064 = $42;$$in = $27;
    }
   }
   $$pre79 = HEAP32[$4>>2]|0;
   $49 = $$pre79;
  }
  $45 = HEAP32[$16>>2]|0;
  $46 = (($47) + ($45)|0);
  $48 = (($49) + -1)|0;
  HEAP32[$4>>2] = $48;
  $50 = ($49|0)==(0);
  if ($50) {
   break;
  }
  $51 = (($$154$lcssa) + ($6))|0;
  $$pre78 = HEAP32[$10>>2]|0;
  $$04671 = $$147$lcssa;$$05370 = $51;$25 = $$pre78;$47 = $46;$52 = $48;$53 = $46;
 }
 HEAP32[$15>>2] = $46;
 return;
}
function _SDL_Blit_ARGB8888_ARGB8888_Blend($0) {
 $0 = $0|0;
 var $$ = 0, $$$us = 0, $$0100$us = 0, $$0101$us = 0, $$093103 = 0, $$093103$us = 0, $$094102 = 0, $$094102$us = 0, $$095 = 0, $$095$us = 0, $$096 = 0, $$096$us = 0, $$097 = 0, $$097$us = 0, $$098 = 0, $$098$us = 0, $$099$us = 0, $$1 = 0, $$1$us = 0, $$3 = 0;
 var $$3$us = 0, $$pre = 0, $$pre108 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $trunc = 0, $trunc$clear = 0, $trunc$clear1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + -1)|0;
 HEAP32[$3>>2] = $5;
 $6 = ($4|0)==(0);
 if ($6) {
  return;
 }
 $7 = ((($0)) + 20|0);
 $8 = ((($0)) + 24|0);
 $9 = ((($0)) + 12|0);
 $10 = ((($0)) + 32|0);
 $11 = $2 & 48;
 $12 = ($11|0)==(0);
 $13 = $2 & 112;
 $trunc = $13&255;
 $$pre = HEAP32[$0>>2]|0;
 $$pre108 = HEAP32[$7>>2]|0;
 $126 = $$pre;$129 = $$pre108;$133 = $$pre108;$134 = $$pre;
 while(1) {
  $14 = HEAP32[$8>>2]|0;
  $15 = (($14) + -1)|0;
  $16 = ($14|0)==(0);
  L6: do {
   if (!($16)) {
    if ($12) {
     $$093103 = $133;$$094102 = $134;$122 = $15;
     while(1) {
      $74 = HEAP32[$$094102>>2]|0;
      $75 = $74 >>> 16;
      $76 = $75 & 255;
      $77 = $74 >>> 8;
      $78 = $77 & 255;
      $79 = $74 & 255;
      $80 = $74 >>> 24;
      $81 = HEAP32[$$093103>>2]|0;
      $82 = $81 >>> 16;
      $83 = $82 & 255;
      $84 = $81 >>> 8;
      $85 = $84 & 255;
      $86 = $81 & 255;
      $87 = $81 >>> 24;
      $trunc$clear1 = $trunc & 127;
      switch ($trunc$clear1<<24>>24) {
      case 16:  {
       $88 = $80 ^ 255;
       $89 = Math_imul($83, $88)|0;
       $90 = (($89>>>0) / 255)&-1;
       $91 = (($76) + ($90))|0;
       $92 = Math_imul($85, $88)|0;
       $93 = (($92>>>0) / 255)&-1;
       $94 = (($78) + ($93))|0;
       $95 = Math_imul($88, $86)|0;
       $96 = (($95>>>0) / 255)&-1;
       $97 = (($79) + ($96))|0;
       $98 = Math_imul($88, $87)|0;
       $99 = (($98>>>0) / 255)&-1;
       $100 = (($99) + ($80))|0;
       $$095 = $100;$$096 = $97;$$097 = $94;$$098 = $91;
       break;
      }
      case 32:  {
       $101 = (($76) + ($83))|0;
       $102 = ($101>>>0)<(255);
       $$ = $102 ? $101 : 255;
       $103 = (($78) + ($85))|0;
       $104 = ($103>>>0)<(255);
       $$3 = $104 ? $103 : 255;
       $105 = (($79) + ($86))|0;
       $106 = ($105>>>0)<(255);
       $$1 = $106 ? $105 : 255;
       $$095 = $87;$$096 = $$1;$$097 = $$3;$$098 = $$;
       break;
      }
      case 64:  {
       $107 = Math_imul($76, $83)|0;
       $108 = (($107>>>0) / 255)&-1;
       $109 = Math_imul($78, $85)|0;
       $110 = (($109>>>0) / 255)&-1;
       $111 = Math_imul($79, $86)|0;
       $112 = (($111>>>0) / 255)&-1;
       $$095 = $87;$$096 = $112;$$097 = $110;$$098 = $108;
       break;
      }
      default: {
       $$095 = $87;$$096 = $86;$$097 = $85;$$098 = $83;
      }
      }
      $113 = $$095 << 24;
      $114 = $$098 << 16;
      $115 = $$097 << 8;
      $116 = $115 | $114;
      $117 = $116 | $$096;
      $118 = $117 | $113;
      HEAP32[$$093103>>2] = $118;
      $119 = ((($$094102)) + 4|0);
      $120 = ((($$093103)) + 4|0);
      $121 = (($122) + -1)|0;
      $123 = ($122|0)==(0);
      if ($123) {
       break L6;
      } else {
       $$093103 = $120;$$094102 = $119;$122 = $121;
      }
     }
    } else {
     $$093103$us = $133;$$094102$us = $134;$72 = $15;
    }
    while(1) {
     $17 = HEAP32[$$094102$us>>2]|0;
     $18 = $17 >>> 16;
     $19 = $18 & 255;
     $20 = $17 >>> 8;
     $21 = $20 & 255;
     $22 = $17 & 255;
     $23 = $17 >>> 24;
     $24 = HEAP32[$$093103$us>>2]|0;
     $25 = $24 >>> 16;
     $26 = $25 & 255;
     $27 = $24 >>> 8;
     $28 = $27 & 255;
     $29 = $24 & 255;
     $30 = $24 >>> 24;
     $31 = ($23|0)==(255);
     if ($31) {
      $$0100$us = $22;$$0101$us = $21;$$099$us = $19;
     } else {
      $32 = Math_imul($22, $23)|0;
      $33 = Math_imul($21, $23)|0;
      $34 = Math_imul($19, $23)|0;
      $35 = (($34>>>0) / 255)&-1;
      $36 = (($33>>>0) / 255)&-1;
      $37 = (($32>>>0) / 255)&-1;
      $$0100$us = $37;$$0101$us = $36;$$099$us = $35;
     }
     $trunc$clear = $trunc & 127;
     switch ($trunc$clear<<24>>24) {
     case 16:  {
      $50 = $23 ^ 255;
      $51 = Math_imul($26, $50)|0;
      $52 = (($51>>>0) / 255)&-1;
      $53 = (($$099$us) + ($52))|0;
      $54 = Math_imul($28, $50)|0;
      $55 = (($54>>>0) / 255)&-1;
      $56 = (($$0101$us) + ($55))|0;
      $57 = Math_imul($50, $29)|0;
      $58 = (($57>>>0) / 255)&-1;
      $59 = (($$0100$us) + ($58))|0;
      $60 = Math_imul($50, $30)|0;
      $61 = (($60>>>0) / 255)&-1;
      $62 = (($61) + ($23))|0;
      $$095$us = $62;$$096$us = $59;$$097$us = $56;$$098$us = $53;
      break;
     }
     case 32:  {
      $44 = (($$099$us) + ($26))|0;
      $45 = ($44>>>0)<(255);
      $$$us = $45 ? $44 : 255;
      $46 = (($$0101$us) + ($28))|0;
      $47 = ($46>>>0)<(255);
      $$3$us = $47 ? $46 : 255;
      $48 = (($$0100$us) + ($29))|0;
      $49 = ($48>>>0)<(255);
      $$1$us = $49 ? $48 : 255;
      $$095$us = $30;$$096$us = $$1$us;$$097$us = $$3$us;$$098$us = $$$us;
      break;
     }
     case 64:  {
      $38 = Math_imul($$099$us, $26)|0;
      $39 = (($38>>>0) / 255)&-1;
      $40 = Math_imul($$0101$us, $28)|0;
      $41 = (($40>>>0) / 255)&-1;
      $42 = Math_imul($$0100$us, $29)|0;
      $43 = (($42>>>0) / 255)&-1;
      $$095$us = $30;$$096$us = $43;$$097$us = $41;$$098$us = $39;
      break;
     }
     default: {
      $$095$us = $30;$$096$us = $29;$$097$us = $28;$$098$us = $26;
     }
     }
     $63 = $$095$us << 24;
     $64 = $$098$us << 16;
     $65 = $$097$us << 8;
     $66 = $65 | $64;
     $67 = $66 | $$096$us;
     $68 = $67 | $63;
     HEAP32[$$093103$us>>2] = $68;
     $69 = ((($$094102$us)) + 4|0);
     $70 = ((($$093103$us)) + 4|0);
     $71 = (($72) + -1)|0;
     $73 = ($72|0)==(0);
     if ($73) {
      break L6;
     } else {
      $$093103$us = $70;$$094102$us = $69;$72 = $71;
     }
    }
   }
  } while(0);
  $124 = HEAP32[$9>>2]|0;
  $125 = (($126) + ($124)|0);
  $127 = HEAP32[$10>>2]|0;
  $128 = (($129) + ($127)|0);
  $130 = HEAP32[$3>>2]|0;
  $131 = (($130) + -1)|0;
  HEAP32[$3>>2] = $131;
  $132 = ($130|0)==(0);
  if ($132) {
   break;
  } else {
   $126 = $125;$129 = $128;$133 = $128;$134 = $125;
  }
 }
 HEAP32[$0>>2] = $125;
 HEAP32[$7>>2] = $128;
 return;
}
function _SDL_Blit_ARGB8888_ARGB8888_Blend_Scale($0) {
 $0 = $0|0;
 var $$ = 0, $$0120151 = 0, $$0121150 = 0, $$0123 = 0, $$0124 = 0, $$0125149 = 0, $$0127155 = 0, $$0129148 = 0, $$0132154 = 0, $$0134 = 0, $$0135 = 0, $$0136 = 0, $$0137 = 0, $$0138 = 0, $$1 = 0, $$1122 = 0, $$1128$lcssa = 0, $$1133$lcssa = 0, $$2 = 0, $$2131 = 0;
 var $$3 = 0, $$in = 0, $$pre = 0, $$pre162 = 0, $$pre163 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $trunc = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 << 16;
 $6 = ((($0)) + 28|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5|0) / ($7|0))&-1;
 $9 = ((($0)) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10 << 16;
 $12 = ((($0)) + 24|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($11|0) / ($13|0))&-1;
 $15 = (($7) + -1)|0;
 HEAP32[$6>>2] = $15;
 $16 = ($7|0)==(0);
 if ($16) {
  return;
 }
 $17 = ((($0)) + 20|0);
 $18 = ((($0)) + 32|0);
 $19 = $2 & 48;
 $20 = ($19|0)!=(0);
 $21 = $2 & 112;
 $trunc = $21&255;
 $22 = ((($0)) + 12|0);
 $$pre = HEAP32[$17>>2]|0;
 $$0127155 = 0;$$0132154 = 0;$103 = $$pre;$108 = $15;$109 = $$pre;$30 = $13;
 while(1) {
  $23 = ($$0127155|0)>(65535);
  if ($23) {
   $24 = (($$0127155) + -65536)|0;
   $25 = $24 >>> 16;
   $26 = $25 << 16;
   $27 = (($$0132154) + 1)|0;
   $28 = (($27) + ($25))|0;
   $29 = (($24) - ($26))|0;
   $$1128$lcssa = $29;$$1133$lcssa = $28;
  } else {
   $$1128$lcssa = $$0127155;$$1133$lcssa = $$0132154;
  }
  $31 = ($30|0)==(0);
  if ($31) {
   $105 = $108;
  } else {
   $$0120151 = $109;$$0121150 = 0;$$0125149 = 65536;$$0129148 = -1;$$in = $30;
   while(1) {
    $32 = (($$in) + -1)|0;
    $33 = ($$0125149|0)>(65535);
    if ($33) {
     $34 = (($$0125149) + -65536)|0;
     $35 = $34 >>> 16;
     $36 = $35 << 16;
     $37 = (($$0129148) + 1)|0;
     $38 = (($37) + ($35))|0;
     $39 = (($34) - ($36))|0;
     $40 = HEAP32[$0>>2]|0;
     $41 = HEAP32[$22>>2]|0;
     $42 = Math_imul($41, $$1133$lcssa)|0;
     $43 = (($40) + ($42)|0);
     $44 = $38 << 2;
     $45 = (($43) + ($44)|0);
     $$1122 = $45;$$2 = $39;$$2131 = $38;
    } else {
     $$1122 = $$0121150;$$2 = $$0125149;$$2131 = $$0129148;
    }
    $46 = HEAP32[$$1122>>2]|0;
    $47 = $46 >>> 16;
    $48 = $47 & 255;
    $49 = $46 >>> 8;
    $50 = $49 & 255;
    $51 = $46 & 255;
    $52 = $46 >>> 24;
    $53 = HEAP32[$$0120151>>2]|0;
    $54 = $53 >>> 16;
    $55 = $54 & 255;
    $56 = $53 >>> 8;
    $57 = $56 & 255;
    $58 = $53 & 255;
    $59 = $53 >>> 24;
    $60 = ($52|0)!=(255);
    $or$cond = $20 & $60;
    if ($or$cond) {
     $61 = Math_imul($51, $52)|0;
     $62 = Math_imul($50, $52)|0;
     $63 = Math_imul($48, $52)|0;
     $64 = (($63>>>0) / 255)&-1;
     $65 = (($62>>>0) / 255)&-1;
     $66 = (($61>>>0) / 255)&-1;
     $$0123 = $64;$$0124 = $65;$$0138 = $66;
    } else {
     $$0123 = $48;$$0124 = $50;$$0138 = $51;
    }
    $trunc$clear = $trunc & 127;
    switch ($trunc$clear<<24>>24) {
    case 16:  {
     $67 = $52 ^ 255;
     $68 = Math_imul($55, $67)|0;
     $69 = (($68>>>0) / 255)&-1;
     $70 = (($$0123) + ($69))|0;
     $71 = Math_imul($57, $67)|0;
     $72 = (($71>>>0) / 255)&-1;
     $73 = (($$0124) + ($72))|0;
     $74 = Math_imul($67, $58)|0;
     $75 = (($74>>>0) / 255)&-1;
     $76 = (($$0138) + ($75))|0;
     $77 = Math_imul($67, $59)|0;
     $78 = (($77>>>0) / 255)&-1;
     $79 = (($78) + ($52))|0;
     $$0134 = $79;$$0135 = $76;$$0136 = $73;$$0137 = $70;
     break;
    }
    case 32:  {
     $80 = (($$0123) + ($55))|0;
     $81 = ($80>>>0)<(255);
     $$ = $81 ? $80 : 255;
     $82 = (($$0124) + ($57))|0;
     $83 = ($82>>>0)<(255);
     $$3 = $83 ? $82 : 255;
     $84 = (($$0138) + ($58))|0;
     $85 = ($84>>>0)<(255);
     $$1 = $85 ? $84 : 255;
     $$0134 = $59;$$0135 = $$1;$$0136 = $$3;$$0137 = $$;
     break;
    }
    case 64:  {
     $86 = Math_imul($$0123, $55)|0;
     $87 = (($86>>>0) / 255)&-1;
     $88 = Math_imul($$0124, $57)|0;
     $89 = (($88>>>0) / 255)&-1;
     $90 = Math_imul($$0138, $58)|0;
     $91 = (($90>>>0) / 255)&-1;
     $$0134 = $59;$$0135 = $91;$$0136 = $89;$$0137 = $87;
     break;
    }
    default: {
     $$0134 = $59;$$0135 = $58;$$0136 = $57;$$0137 = $55;
    }
    }
    $92 = $$0134 << 24;
    $93 = $$0137 << 16;
    $94 = $$0136 << 8;
    $95 = $94 | $93;
    $96 = $95 | $$0135;
    $97 = $96 | $92;
    HEAP32[$$0120151>>2] = $97;
    $98 = (($$2) + ($14))|0;
    $99 = ((($$0120151)) + 4|0);
    $100 = ($32|0)==(0);
    if ($100) {
     break;
    } else {
     $$0120151 = $99;$$0121150 = $$1122;$$0125149 = $98;$$0129148 = $$2131;$$in = $32;
    }
   }
   $$pre163 = HEAP32[$6>>2]|0;
   $105 = $$pre163;
  }
  $101 = HEAP32[$18>>2]|0;
  $102 = (($103) + ($101)|0);
  $104 = (($105) + -1)|0;
  HEAP32[$6>>2] = $104;
  $106 = ($105|0)==(0);
  if ($106) {
   break;
  }
  $107 = (($$1128$lcssa) + ($8))|0;
  $$pre162 = HEAP32[$12>>2]|0;
  $$0127155 = $107;$$0132154 = $$1133$lcssa;$103 = $102;$108 = $104;$109 = $102;$30 = $$pre162;
 }
 HEAP32[$17>>2] = $102;
 return;
}
function _SDL_Blit_ARGB8888_ARGB8888_Modulate($0) {
 $0 = $0|0;
 var $$06168 = 0, $$06168$us = 0, $$06267 = 0, $$06267$us = 0, $$063 = 0, $$063$us = 0, $$pre = 0, $$pre73 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = ((($0)) + 61|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = ((($0)) + 62|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = ((($0)) + 63|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = $13&255;
 $15 = ((($0)) + 28|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + -1)|0;
 HEAP32[$15>>2] = $17;
 $18 = ($16|0)==(0);
 if ($18) {
  return;
 }
 $19 = ((($0)) + 20|0);
 $20 = ((($0)) + 24|0);
 $21 = ((($0)) + 12|0);
 $22 = ((($0)) + 32|0);
 $23 = $2 & 1;
 $24 = ($23|0)==(0);
 $25 = $2 & 2;
 $26 = ($25|0)==(0);
 $$pre = HEAP32[$0>>2]|0;
 $$pre73 = HEAP32[$19>>2]|0;
 $74 = $$pre;$77 = $$pre73;$81 = $$pre73;$82 = $$pre;
 while(1) {
  $27 = HEAP32[$20>>2]|0;
  $28 = (($27) + -1)|0;
  $29 = ($27|0)==(0);
  if (!($29)) {
   if ($24) {
    $$06168$us = $81;$$06267$us = $82;$44 = $28;
    while(1) {
     $30 = HEAP32[$$06267$us>>2]|0;
     $31 = $30 & 16711680;
     $32 = $30 & 65280;
     $33 = $30 & 255;
     $34 = $30 >>> 24;
     $35 = Math_imul($34, $14)|0;
     $36 = (($35>>>0) / 255)&-1;
     $$063$us = $26 ? $34 : $36;
     $37 = $$063$us << 24;
     $38 = $31 | $37;
     $39 = $38 | $32;
     $40 = $39 | $33;
     HEAP32[$$06168$us>>2] = $40;
     $41 = ((($$06267$us)) + 4|0);
     $42 = ((($$06168$us)) + 4|0);
     $43 = (($44) + -1)|0;
     $45 = ($44|0)==(0);
     if ($45) {
      break;
     } else {
      $$06168$us = $42;$$06267$us = $41;$44 = $43;
     }
    }
   } else {
    $$06168 = $81;$$06267 = $82;$70 = $28;
    while(1) {
     $46 = HEAP32[$$06267>>2]|0;
     $47 = $46 >>> 16;
     $48 = $47 & 255;
     $49 = $46 >>> 8;
     $50 = $49 & 255;
     $51 = $46 & 255;
     $52 = $46 >>> 24;
     $53 = Math_imul($51, $11)|0;
     $54 = Math_imul($50, $8)|0;
     $55 = Math_imul($48, $5)|0;
     $56 = (($55>>>0) / 255)&-1;
     $57 = (($54>>>0) / 255)&-1;
     $58 = (($53>>>0) / 255)&-1;
     $59 = Math_imul($52, $14)|0;
     $60 = (($59>>>0) / 255)&-1;
     $$063 = $26 ? $52 : $60;
     $61 = $$063 << 24;
     $62 = $56 << 16;
     $63 = $62 | $61;
     $64 = $57 << 8;
     $65 = $63 | $64;
     $66 = $65 | $58;
     HEAP32[$$06168>>2] = $66;
     $67 = ((($$06267)) + 4|0);
     $68 = ((($$06168)) + 4|0);
     $69 = (($70) + -1)|0;
     $71 = ($70|0)==(0);
     if ($71) {
      break;
     } else {
      $$06168 = $68;$$06267 = $67;$70 = $69;
     }
    }
   }
  }
  $72 = HEAP32[$21>>2]|0;
  $73 = (($74) + ($72)|0);
  $75 = HEAP32[$22>>2]|0;
  $76 = (($77) + ($75)|0);
  $78 = HEAP32[$15>>2]|0;
  $79 = (($78) + -1)|0;
  HEAP32[$15>>2] = $79;
  $80 = ($78|0)==(0);
  if ($80) {
   break;
  } else {
   $74 = $73;$77 = $76;$81 = $76;$82 = $73;
  }
 }
 HEAP32[$0>>2] = $73;
 HEAP32[$19>>2] = $76;
 return;
}
function _SDL_Blit_ARGB8888_ARGB8888_Modulate_Scale($0) {
 $0 = $0|0;
 var $$0100 = 0, $$0100$us = 0, $$088115 = 0, $$088115$us = 0, $$089114 = 0, $$089114$us = 0, $$091113 = 0, $$091113$us = 0, $$093119 = 0, $$095112 = 0, $$095112$us = 0, $$098118 = 0, $$1 = 0, $$1$us = 0, $$194$lcssa = 0, $$199$lcssa = 0, $$2 = 0, $$2$us = 0, $$297 = 0, $$297$us = 0;
 var $$pre = 0, $$pre129 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = ((($0)) + 61|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = ((($0)) + 62|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = ((($0)) + 63|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = $13&255;
 $15 = ((($0)) + 8|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $16 << 16;
 $18 = ((($0)) + 28|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($17|0) / ($19|0))&-1;
 $21 = ((($0)) + 4|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = $22 << 16;
 $24 = ((($0)) + 24|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($23|0) / ($25|0))&-1;
 $27 = (($19) + -1)|0;
 HEAP32[$18>>2] = $27;
 $28 = ($19|0)==(0);
 if ($28) {
  return;
 }
 $29 = ((($0)) + 20|0);
 $30 = ((($0)) + 32|0);
 $31 = $2 & 1;
 $32 = ($31|0)==(0);
 $33 = $2 & 2;
 $34 = ($33|0)==(0);
 $35 = ((($0)) + 12|0);
 $$pre = HEAP32[$29>>2]|0;
 $$093119 = 0;$$098118 = 0;$116 = $$pre;$121 = $$pre;$44 = $25;
 while(1) {
  $36 = ($$093119|0)>(65535);
  if ($36) {
   $37 = (($$093119) + -65536)|0;
   $38 = $37 >>> 16;
   $39 = $38 << 16;
   $40 = (($$098118) + 1)|0;
   $41 = (($40) + ($38))|0;
   $42 = (($37) - ($39))|0;
   $$194$lcssa = $42;$$199$lcssa = $41;
  } else {
   $$194$lcssa = $$093119;$$199$lcssa = $$098118;
  }
  $43 = (($44) + -1)|0;
  $45 = ($44|0)==(0);
  if (!($45)) {
   if ($32) {
    $$088115$us = $121;$$089114$us = 0;$$091113$us = 65536;$$095112$us = -1;$73 = $43;
    while(1) {
     $46 = ($$091113$us|0)>(65535);
     if ($46) {
      $47 = (($$091113$us) + -65536)|0;
      $48 = $47 >>> 16;
      $49 = $48 << 16;
      $50 = (($$095112$us) + 1)|0;
      $51 = (($50) + ($48))|0;
      $52 = (($47) - ($49))|0;
      $53 = HEAP32[$0>>2]|0;
      $54 = HEAP32[$35>>2]|0;
      $55 = Math_imul($54, $$199$lcssa)|0;
      $56 = (($53) + ($55)|0);
      $57 = $51 << 2;
      $58 = (($56) + ($57)|0);
      $$1$us = $58;$$2$us = $52;$$297$us = $51;
     } else {
      $$1$us = $$089114$us;$$2$us = $$091113$us;$$297$us = $$095112$us;
     }
     $59 = HEAP32[$$1$us>>2]|0;
     $60 = $59 & 16711680;
     $61 = $59 & 65280;
     $62 = $59 & 255;
     $63 = $59 >>> 24;
     $64 = Math_imul($63, $14)|0;
     $65 = (($64>>>0) / 255)&-1;
     $$0100$us = $34 ? $63 : $65;
     $66 = $$0100$us << 24;
     $67 = $61 | $66;
     $68 = $67 | $62;
     $69 = $68 | $60;
     HEAP32[$$088115$us>>2] = $69;
     $70 = (($$2$us) + ($26))|0;
     $71 = ((($$088115$us)) + 4|0);
     $72 = (($73) + -1)|0;
     $74 = ($73|0)==(0);
     if ($74) {
      break;
     } else {
      $$088115$us = $71;$$089114$us = $$1$us;$$091113$us = $70;$$095112$us = $$297$us;$73 = $72;
     }
    }
   } else {
    $$088115 = $121;$$089114 = 0;$$091113 = 65536;$$095112 = -1;$112 = $43;
    while(1) {
     $75 = ($$091113|0)>(65535);
     if ($75) {
      $76 = (($$091113) + -65536)|0;
      $77 = $76 >>> 16;
      $78 = $77 << 16;
      $79 = (($$095112) + 1)|0;
      $80 = (($79) + ($77))|0;
      $81 = (($76) - ($78))|0;
      $82 = HEAP32[$0>>2]|0;
      $83 = HEAP32[$35>>2]|0;
      $84 = Math_imul($83, $$199$lcssa)|0;
      $85 = (($82) + ($84)|0);
      $86 = $80 << 2;
      $87 = (($85) + ($86)|0);
      $$1 = $87;$$2 = $81;$$297 = $80;
     } else {
      $$1 = $$089114;$$2 = $$091113;$$297 = $$095112;
     }
     $88 = HEAP32[$$1>>2]|0;
     $89 = $88 >>> 16;
     $90 = $89 & 255;
     $91 = $88 >>> 8;
     $92 = $91 & 255;
     $93 = $88 & 255;
     $94 = $88 >>> 24;
     $95 = Math_imul($93, $11)|0;
     $96 = Math_imul($92, $8)|0;
     $97 = Math_imul($90, $5)|0;
     $98 = (($97>>>0) / 255)&-1;
     $99 = (($96>>>0) / 255)&-1;
     $100 = (($95>>>0) / 255)&-1;
     $101 = Math_imul($94, $14)|0;
     $102 = (($101>>>0) / 255)&-1;
     $$0100 = $34 ? $94 : $102;
     $103 = $$0100 << 24;
     $104 = $98 << 16;
     $105 = $99 << 8;
     $106 = $105 | $103;
     $107 = $106 | $100;
     $108 = $107 | $104;
     HEAP32[$$088115>>2] = $108;
     $109 = (($$2) + ($26))|0;
     $110 = ((($$088115)) + 4|0);
     $111 = (($112) + -1)|0;
     $113 = ($112|0)==(0);
     if ($113) {
      break;
     } else {
      $$088115 = $110;$$089114 = $$1;$$091113 = $109;$$095112 = $$297;$112 = $111;
     }
    }
   }
  }
  $114 = HEAP32[$30>>2]|0;
  $115 = (($116) + ($114)|0);
  $117 = HEAP32[$18>>2]|0;
  $118 = (($117) + -1)|0;
  HEAP32[$18>>2] = $118;
  $119 = ($117|0)==(0);
  if ($119) {
   break;
  }
  $120 = (($$194$lcssa) + ($20))|0;
  $$pre129 = HEAP32[$24>>2]|0;
  $$093119 = $120;$$098118 = $$199$lcssa;$116 = $115;$121 = $115;$44 = $$pre129;
 }
 HEAP32[$29>>2] = $115;
 return;
}
function _SDL_Blit_ARGB8888_ARGB8888_Modulate_Blend($0) {
 $0 = $0|0;
 var $$ = 0, $$0115129 = 0, $$0116128 = 0, $$0117 = 0, $$0118 = 0, $$0119 = 0, $$0120 = 0, $$0121 = 0, $$0122 = 0, $$0124 = 0, $$0126 = 0, $$1 = 0, $$1123 = 0, $$1125 = 0, $$1127 = 0, $$3 = 0, $$in = 0, $$pre = 0, $$pre133 = 0, $$pre134 = 0;
 var $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $trunc = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = ((($0)) + 61|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = ((($0)) + 62|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = ((($0)) + 63|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = $13&255;
 $15 = ((($0)) + 28|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + -1)|0;
 HEAP32[$15>>2] = $17;
 $18 = ($16|0)==(0);
 if ($18) {
  return;
 }
 $19 = ((($0)) + 20|0);
 $20 = ((($0)) + 24|0);
 $21 = ((($0)) + 12|0);
 $22 = ((($0)) + 32|0);
 $23 = $2 & 1;
 $24 = ($23|0)==(0);
 $25 = $2 & 2;
 $26 = ($25|0)==(0);
 $27 = $2 & 48;
 $28 = ($27|0)!=(0);
 $29 = $2 & 112;
 $trunc = $29&255;
 $$pre = HEAP32[$0>>2]|0;
 $$pre133 = HEAP32[$19>>2]|0;
 $101 = $$pre133;$105 = $17;$106 = $$pre133;$107 = $$pre;$98 = $$pre;
 while(1) {
  $30 = HEAP32[$20>>2]|0;
  $31 = ($30|0)==(0);
  if ($31) {
   $103 = $105;
  } else {
   $$0115129 = $106;$$0116128 = $107;$$in = $30;
   while(1) {
    $32 = (($$in) + -1)|0;
    $33 = HEAP32[$$0116128>>2]|0;
    $34 = $33 >>> 16;
    $35 = $34 & 255;
    $36 = $33 >>> 8;
    $37 = $36 & 255;
    $38 = $33 & 255;
    $39 = $33 >>> 24;
    $40 = HEAP32[$$0115129>>2]|0;
    $41 = $40 >>> 16;
    $42 = $41 & 255;
    $43 = $40 >>> 8;
    $44 = $43 & 255;
    $45 = $40 & 255;
    $46 = $40 >>> 24;
    if ($24) {
     $$0122 = $38;$$0124 = $37;$$0126 = $35;
    } else {
     $47 = Math_imul($38, $11)|0;
     $48 = Math_imul($37, $8)|0;
     $49 = Math_imul($35, $5)|0;
     $50 = (($49>>>0) / 255)&-1;
     $51 = (($48>>>0) / 255)&-1;
     $52 = (($47>>>0) / 255)&-1;
     $$0122 = $52;$$0124 = $51;$$0126 = $50;
    }
    $53 = Math_imul($39, $14)|0;
    $54 = (($53>>>0) / 255)&-1;
    $$0121 = $26 ? $39 : $54;
    $55 = ($$0121>>>0)<(255);
    $or$cond = $28 & $55;
    if ($or$cond) {
     $56 = Math_imul($$0122, $$0121)|0;
     $57 = Math_imul($$0124, $$0121)|0;
     $58 = Math_imul($$0126, $$0121)|0;
     $59 = (($58>>>0) / 255)&-1;
     $60 = (($57>>>0) / 255)&-1;
     $61 = (($56>>>0) / 255)&-1;
     $$1123 = $61;$$1125 = $60;$$1127 = $59;
    } else {
     $$1123 = $$0122;$$1125 = $$0124;$$1127 = $$0126;
    }
    $trunc$clear = $trunc & 127;
    switch ($trunc$clear<<24>>24) {
    case 16:  {
     $62 = (255 - ($$0121))|0;
     $63 = Math_imul($62, $42)|0;
     $64 = (($63>>>0) / 255)&-1;
     $65 = (($$1127) + ($64))|0;
     $66 = Math_imul($62, $44)|0;
     $67 = (($66>>>0) / 255)&-1;
     $68 = (($$1125) + ($67))|0;
     $69 = Math_imul($62, $45)|0;
     $70 = (($69>>>0) / 255)&-1;
     $71 = (($$1123) + ($70))|0;
     $72 = Math_imul($62, $46)|0;
     $73 = (($72>>>0) / 255)&-1;
     $74 = (($73) + ($$0121))|0;
     $$0117 = $74;$$0118 = $71;$$0119 = $68;$$0120 = $65;
     break;
    }
    case 32:  {
     $75 = (($$1127) + ($42))|0;
     $76 = ($75>>>0)<(255);
     $$ = $76 ? $75 : 255;
     $77 = (($$1125) + ($44))|0;
     $78 = ($77>>>0)<(255);
     $$3 = $78 ? $77 : 255;
     $79 = (($$1123) + ($45))|0;
     $80 = ($79>>>0)<(255);
     $$1 = $80 ? $79 : 255;
     $$0117 = $46;$$0118 = $$1;$$0119 = $$3;$$0120 = $$;
     break;
    }
    case 64:  {
     $81 = Math_imul($$1127, $42)|0;
     $82 = (($81>>>0) / 255)&-1;
     $83 = Math_imul($$1125, $44)|0;
     $84 = (($83>>>0) / 255)&-1;
     $85 = Math_imul($$1123, $45)|0;
     $86 = (($85>>>0) / 255)&-1;
     $$0117 = $46;$$0118 = $86;$$0119 = $84;$$0120 = $82;
     break;
    }
    default: {
     $$0117 = $46;$$0118 = $45;$$0119 = $44;$$0120 = $42;
    }
    }
    $87 = $$0117 << 24;
    $88 = $$0120 << 16;
    $89 = $$0119 << 8;
    $90 = $89 | $88;
    $91 = $90 | $$0118;
    $92 = $91 | $87;
    HEAP32[$$0115129>>2] = $92;
    $93 = ((($$0116128)) + 4|0);
    $94 = ((($$0115129)) + 4|0);
    $95 = ($32|0)==(0);
    if ($95) {
     break;
    } else {
     $$0115129 = $94;$$0116128 = $93;$$in = $32;
    }
   }
   $$pre134 = HEAP32[$15>>2]|0;
   $103 = $$pre134;
  }
  $96 = HEAP32[$21>>2]|0;
  $97 = (($98) + ($96)|0);
  $99 = HEAP32[$22>>2]|0;
  $100 = (($101) + ($99)|0);
  $102 = (($103) + -1)|0;
  HEAP32[$15>>2] = $102;
  $104 = ($103|0)==(0);
  if ($104) {
   break;
  } else {
   $101 = $100;$105 = $102;$106 = $100;$107 = $97;$98 = $97;
  }
 }
 HEAP32[$0>>2] = $97;
 HEAP32[$19>>2] = $100;
 return;
}
function _SDL_Blit_ARGB8888_ARGB8888_Modulate_Blend_Scale($0) {
 $0 = $0|0;
 var $$ = 0, $$0142177 = 0, $$0143176 = 0, $$0145 = 0, $$0147 = 0, $$0149175 = 0, $$0151181 = 0, $$0153174 = 0, $$0156180 = 0, $$0158 = 0, $$0159 = 0, $$0160 = 0, $$0161 = 0, $$0162 = 0, $$0163 = 0, $$1 = 0, $$1144 = 0, $$1146 = 0, $$1148 = 0, $$1152$lcssa = 0;
 var $$1157$lcssa = 0, $$1164 = 0, $$2 = 0, $$2155 = 0, $$3 = 0, $$in = 0, $$pre = 0, $$pre188 = 0, $$pre189 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $or$cond = 0, $trunc = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = ((($0)) + 61|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = ((($0)) + 62|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = ((($0)) + 63|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = $13&255;
 $15 = ((($0)) + 8|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $16 << 16;
 $18 = ((($0)) + 28|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($17|0) / ($19|0))&-1;
 $21 = ((($0)) + 4|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = $22 << 16;
 $24 = ((($0)) + 24|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($23|0) / ($25|0))&-1;
 $27 = (($19) + -1)|0;
 HEAP32[$18>>2] = $27;
 $28 = ($19|0)==(0);
 if ($28) {
  return;
 }
 $29 = ((($0)) + 20|0);
 $30 = ((($0)) + 32|0);
 $31 = $2 & 1;
 $32 = ($31|0)==(0);
 $33 = $2 & 2;
 $34 = ($33|0)==(0);
 $35 = $2 & 48;
 $36 = ($35|0)!=(0);
 $37 = $2 & 112;
 $trunc = $37&255;
 $38 = ((($0)) + 12|0);
 $$pre = HEAP32[$29>>2]|0;
 $$0151181 = 0;$$0156180 = 0;$127 = $$pre;$132 = $27;$133 = $$pre;$46 = $25;
 while(1) {
  $39 = ($$0151181|0)>(65535);
  if ($39) {
   $40 = (($$0151181) + -65536)|0;
   $41 = $40 >>> 16;
   $42 = $41 << 16;
   $43 = (($$0156180) + 1)|0;
   $44 = (($43) + ($41))|0;
   $45 = (($40) - ($42))|0;
   $$1152$lcssa = $45;$$1157$lcssa = $44;
  } else {
   $$1152$lcssa = $$0151181;$$1157$lcssa = $$0156180;
  }
  $47 = ($46|0)==(0);
  if ($47) {
   $129 = $132;
  } else {
   $$0142177 = $133;$$0143176 = 0;$$0149175 = 65536;$$0153174 = -1;$$in = $46;
   while(1) {
    $48 = (($$in) + -1)|0;
    $49 = ($$0149175|0)>(65535);
    if ($49) {
     $50 = (($$0149175) + -65536)|0;
     $51 = $50 >>> 16;
     $52 = $51 << 16;
     $53 = (($$0153174) + 1)|0;
     $54 = (($53) + ($51))|0;
     $55 = (($50) - ($52))|0;
     $56 = HEAP32[$0>>2]|0;
     $57 = HEAP32[$38>>2]|0;
     $58 = Math_imul($57, $$1157$lcssa)|0;
     $59 = (($56) + ($58)|0);
     $60 = $54 << 2;
     $61 = (($59) + ($60)|0);
     $$1144 = $61;$$2 = $55;$$2155 = $54;
    } else {
     $$1144 = $$0143176;$$2 = $$0149175;$$2155 = $$0153174;
    }
    $62 = HEAP32[$$1144>>2]|0;
    $63 = $62 >>> 16;
    $64 = $63 & 255;
    $65 = $62 >>> 8;
    $66 = $65 & 255;
    $67 = $62 & 255;
    $68 = $62 >>> 24;
    $69 = HEAP32[$$0142177>>2]|0;
    $70 = $69 >>> 16;
    $71 = $70 & 255;
    $72 = $69 >>> 8;
    $73 = $72 & 255;
    $74 = $69 & 255;
    $75 = $69 >>> 24;
    if ($32) {
     $$0145 = $64;$$0147 = $66;$$0163 = $67;
    } else {
     $76 = Math_imul($67, $11)|0;
     $77 = Math_imul($66, $8)|0;
     $78 = Math_imul($64, $5)|0;
     $79 = (($78>>>0) / 255)&-1;
     $80 = (($77>>>0) / 255)&-1;
     $81 = (($76>>>0) / 255)&-1;
     $$0145 = $79;$$0147 = $80;$$0163 = $81;
    }
    $82 = Math_imul($68, $14)|0;
    $83 = (($82>>>0) / 255)&-1;
    $$0162 = $34 ? $68 : $83;
    $84 = ($$0162>>>0)<(255);
    $or$cond = $36 & $84;
    if ($or$cond) {
     $85 = Math_imul($$0163, $$0162)|0;
     $86 = Math_imul($$0147, $$0162)|0;
     $87 = Math_imul($$0145, $$0162)|0;
     $88 = (($87>>>0) / 255)&-1;
     $89 = (($86>>>0) / 255)&-1;
     $90 = (($85>>>0) / 255)&-1;
     $$1146 = $88;$$1148 = $89;$$1164 = $90;
    } else {
     $$1146 = $$0145;$$1148 = $$0147;$$1164 = $$0163;
    }
    $trunc$clear = $trunc & 127;
    switch ($trunc$clear<<24>>24) {
    case 16:  {
     $91 = (255 - ($$0162))|0;
     $92 = Math_imul($91, $71)|0;
     $93 = (($92>>>0) / 255)&-1;
     $94 = (($$1146) + ($93))|0;
     $95 = Math_imul($91, $73)|0;
     $96 = (($95>>>0) / 255)&-1;
     $97 = (($$1148) + ($96))|0;
     $98 = Math_imul($91, $74)|0;
     $99 = (($98>>>0) / 255)&-1;
     $100 = (($$1164) + ($99))|0;
     $101 = Math_imul($91, $75)|0;
     $102 = (($101>>>0) / 255)&-1;
     $103 = (($102) + ($$0162))|0;
     $$0158 = $103;$$0159 = $100;$$0160 = $97;$$0161 = $94;
     break;
    }
    case 32:  {
     $104 = (($$1146) + ($71))|0;
     $105 = ($104>>>0)<(255);
     $$ = $105 ? $104 : 255;
     $106 = (($$1148) + ($73))|0;
     $107 = ($106>>>0)<(255);
     $$3 = $107 ? $106 : 255;
     $108 = (($$1164) + ($74))|0;
     $109 = ($108>>>0)<(255);
     $$1 = $109 ? $108 : 255;
     $$0158 = $75;$$0159 = $$1;$$0160 = $$3;$$0161 = $$;
     break;
    }
    case 64:  {
     $110 = Math_imul($$1146, $71)|0;
     $111 = (($110>>>0) / 255)&-1;
     $112 = Math_imul($$1148, $73)|0;
     $113 = (($112>>>0) / 255)&-1;
     $114 = Math_imul($$1164, $74)|0;
     $115 = (($114>>>0) / 255)&-1;
     $$0158 = $75;$$0159 = $115;$$0160 = $113;$$0161 = $111;
     break;
    }
    default: {
     $$0158 = $75;$$0159 = $74;$$0160 = $73;$$0161 = $71;
    }
    }
    $116 = $$0158 << 24;
    $117 = $$0161 << 16;
    $118 = $$0160 << 8;
    $119 = $118 | $117;
    $120 = $119 | $$0159;
    $121 = $120 | $116;
    HEAP32[$$0142177>>2] = $121;
    $122 = (($$2) + ($26))|0;
    $123 = ((($$0142177)) + 4|0);
    $124 = ($48|0)==(0);
    if ($124) {
     break;
    } else {
     $$0142177 = $123;$$0143176 = $$1144;$$0149175 = $122;$$0153174 = $$2155;$$in = $48;
    }
   }
   $$pre189 = HEAP32[$18>>2]|0;
   $129 = $$pre189;
  }
  $125 = HEAP32[$30>>2]|0;
  $126 = (($127) + ($125)|0);
  $128 = (($129) + -1)|0;
  HEAP32[$18>>2] = $128;
  $130 = ($129|0)==(0);
  if ($130) {
   break;
  }
  $131 = (($$1152$lcssa) + ($20))|0;
  $$pre188 = HEAP32[$24>>2]|0;
  $$0151181 = $131;$$0156180 = $$1157$lcssa;$127 = $126;$132 = $128;$133 = $126;$46 = $$pre188;
 }
 HEAP32[$29>>2] = $126;
 return;
}
function _SDL_Blit_RGBA8888_RGB888_Scale($0) {
 $0 = $0|0;
 var $$05982 = 0, $$06081 = 0, $$06186 = 0, $$06380 = 0, $$06579 = 0, $$06885 = 0, $$1 = 0, $$162$lcssa = 0, $$169$lcssa = 0, $$2 = 0, $$267 = 0, $$in = 0, $$pre = 0, $$pre93 = 0, $$pre94 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 << 16;
 $4 = ((($0)) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3|0) / ($5|0))&-1;
 $7 = ((($0)) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 << 16;
 $10 = ((($0)) + 24|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($9|0) / ($11|0))&-1;
 $13 = (($5) + -1)|0;
 HEAP32[$4>>2] = $13;
 $14 = ($5|0)==(0);
 if ($14) {
  return;
 }
 $15 = ((($0)) + 20|0);
 $16 = ((($0)) + 32|0);
 $17 = ((($0)) + 12|0);
 $$pre = HEAP32[$15>>2]|0;
 $$06186 = 0;$$06885 = 0;$25 = $11;$54 = $$pre;$59 = $13;$60 = $$pre;
 while(1) {
  $18 = ($$06885|0)>(65535);
  if ($18) {
   $19 = (($$06885) + -65536)|0;
   $20 = $19 >>> 16;
   $21 = $20 << 16;
   $22 = (($$06186) + 1)|0;
   $23 = (($22) + ($20))|0;
   $24 = (($19) - ($21))|0;
   $$162$lcssa = $23;$$169$lcssa = $24;
  } else {
   $$162$lcssa = $$06186;$$169$lcssa = $$06885;
  }
  $26 = ($25|0)==(0);
  if ($26) {
   $56 = $59;
  } else {
   $$05982 = $60;$$06081 = 0;$$06380 = -1;$$06579 = 65536;$$in = $25;
   while(1) {
    $27 = (($$in) + -1)|0;
    $28 = ($$06579|0)>(65535);
    if ($28) {
     $29 = (($$06579) + -65536)|0;
     $30 = $29 >>> 16;
     $31 = $30 << 16;
     $32 = (($$06380) + 1)|0;
     $33 = (($32) + ($30))|0;
     $34 = (($29) - ($31))|0;
     $35 = HEAP32[$0>>2]|0;
     $36 = HEAP32[$17>>2]|0;
     $37 = Math_imul($36, $$162$lcssa)|0;
     $38 = (($35) + ($37)|0);
     $39 = $33 << 2;
     $40 = (($38) + ($39)|0);
     $$1 = $40;$$2 = $33;$$267 = $34;
    } else {
     $$1 = $$06081;$$2 = $$06380;$$267 = $$06579;
    }
    $41 = HEAP32[$$1>>2]|0;
    $42 = $41 >>> 24;
    $43 = $41 >>> 8;
    $44 = $43 & 255;
    $45 = $42 << 16;
    $46 = $43 & 65280;
    $47 = $45 | $46;
    $48 = $47 | $44;
    HEAP32[$$05982>>2] = $48;
    $49 = (($$267) + ($12))|0;
    $50 = ((($$05982)) + 4|0);
    $51 = ($27|0)==(0);
    if ($51) {
     break;
    } else {
     $$05982 = $50;$$06081 = $$1;$$06380 = $$2;$$06579 = $49;$$in = $27;
    }
   }
   $$pre94 = HEAP32[$4>>2]|0;
   $56 = $$pre94;
  }
  $52 = HEAP32[$16>>2]|0;
  $53 = (($54) + ($52)|0);
  $55 = (($56) + -1)|0;
  HEAP32[$4>>2] = $55;
  $57 = ($56|0)==(0);
  if ($57) {
   break;
  }
  $58 = (($$169$lcssa) + ($6))|0;
  $$pre93 = HEAP32[$10>>2]|0;
  $$06186 = $$162$lcssa;$$06885 = $58;$25 = $$pre93;$54 = $53;$59 = $55;$60 = $53;
 }
 HEAP32[$15>>2] = $53;
 return;
}
function _SDL_Blit_RGBA8888_RGB888_Blend($0) {
 $0 = $0|0;
 var $$ = 0, $$$us = 0, $$08695 = 0, $$08695$us = 0, $$08794 = 0, $$08794$us = 0, $$088 = 0, $$088$us = 0, $$089 = 0, $$089$us = 0, $$090 = 0, $$090$us = 0, $$091$us = 0, $$092$us = 0, $$093$us = 0, $$1 = 0, $$1$us = 0, $$3 = 0, $$3$us = 0, $$pre = 0;
 var $$pre100 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $trunc = 0, $trunc$clear = 0, $trunc$clear1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + -1)|0;
 HEAP32[$3>>2] = $5;
 $6 = ($4|0)==(0);
 if ($6) {
  return;
 }
 $7 = ((($0)) + 20|0);
 $8 = ((($0)) + 24|0);
 $9 = ((($0)) + 12|0);
 $10 = ((($0)) + 32|0);
 $11 = $2 & 48;
 $12 = ($11|0)==(0);
 $13 = $2 & 112;
 $trunc = $13&255;
 $$pre = HEAP32[$0>>2]|0;
 $$pre100 = HEAP32[$7>>2]|0;
 $114 = $$pre;$117 = $$pre100;$121 = $$pre100;$122 = $$pre;
 while(1) {
  $14 = HEAP32[$8>>2]|0;
  $15 = (($14) + -1)|0;
  $16 = ($14|0)==(0);
  L6: do {
   if (!($16)) {
    if ($12) {
     $$08695 = $121;$$08794 = $122;$110 = $15;
     while(1) {
      $68 = HEAP32[$$08794>>2]|0;
      $69 = $68 >>> 24;
      $70 = $68 >>> 16;
      $71 = $70 & 255;
      $72 = $68 >>> 8;
      $73 = $72 & 255;
      $74 = HEAP32[$$08695>>2]|0;
      $75 = $74 >>> 16;
      $76 = $75 & 255;
      $77 = $74 >>> 8;
      $78 = $77 & 255;
      $79 = $74 & 255;
      $trunc$clear1 = $trunc & 127;
      switch ($trunc$clear1<<24>>24) {
      case 16:  {
       $80 = $68 & 255;
       $81 = $80 ^ 255;
       $82 = Math_imul($76, $81)|0;
       $83 = (($82>>>0) / 255)&-1;
       $84 = (($69) + ($83))|0;
       $85 = Math_imul($78, $81)|0;
       $86 = (($85>>>0) / 255)&-1;
       $87 = (($71) + ($86))|0;
       $88 = Math_imul($81, $79)|0;
       $89 = (($88>>>0) / 255)&-1;
       $90 = (($73) + ($89))|0;
       $$088 = $90;$$089 = $87;$$090 = $84;
       break;
      }
      case 32:  {
       $91 = (($69) + ($76))|0;
       $92 = ($91>>>0)<(255);
       $$ = $92 ? $91 : 255;
       $93 = (($71) + ($78))|0;
       $94 = ($93>>>0)<(255);
       $$3 = $94 ? $93 : 255;
       $95 = (($73) + ($79))|0;
       $96 = ($95>>>0)<(255);
       $$1 = $96 ? $95 : 255;
       $$088 = $$1;$$089 = $$3;$$090 = $$;
       break;
      }
      case 64:  {
       $97 = Math_imul($69, $76)|0;
       $98 = (($97>>>0) / 255)&-1;
       $99 = Math_imul($71, $78)|0;
       $100 = (($99>>>0) / 255)&-1;
       $101 = Math_imul($73, $79)|0;
       $102 = (($101>>>0) / 255)&-1;
       $$088 = $102;$$089 = $100;$$090 = $98;
       break;
      }
      default: {
       $$088 = $79;$$089 = $78;$$090 = $76;
      }
      }
      $103 = $$090 << 16;
      $104 = $$089 << 8;
      $105 = $104 | $103;
      $106 = $105 | $$088;
      HEAP32[$$08695>>2] = $106;
      $107 = ((($$08794)) + 4|0);
      $108 = ((($$08695)) + 4|0);
      $109 = (($110) + -1)|0;
      $111 = ($110|0)==(0);
      if ($111) {
       break L6;
      } else {
       $$08695 = $108;$$08794 = $107;$110 = $109;
      }
     }
    } else {
     $$08695$us = $121;$$08794$us = $122;$66 = $15;
    }
    while(1) {
     $17 = HEAP32[$$08794$us>>2]|0;
     $18 = $17 >>> 24;
     $19 = $17 >>> 16;
     $20 = $19 & 255;
     $21 = $17 >>> 8;
     $22 = $21 & 255;
     $23 = $17 & 255;
     $24 = HEAP32[$$08695$us>>2]|0;
     $25 = $24 >>> 16;
     $26 = $25 & 255;
     $27 = $24 >>> 8;
     $28 = $27 & 255;
     $29 = $24 & 255;
     $30 = ($23|0)==(255);
     if ($30) {
      $$091$us = $18;$$092$us = $22;$$093$us = $20;
     } else {
      $31 = Math_imul($22, $23)|0;
      $32 = Math_imul($20, $23)|0;
      $33 = Math_imul($18, $23)|0;
      $34 = (($33>>>0) / 255)&-1;
      $35 = (($32>>>0) / 255)&-1;
      $36 = (($31>>>0) / 255)&-1;
      $$091$us = $34;$$092$us = $36;$$093$us = $35;
     }
     $trunc$clear = $trunc & 127;
     switch ($trunc$clear<<24>>24) {
     case 16:  {
      $49 = $23 ^ 255;
      $50 = Math_imul($26, $49)|0;
      $51 = (($50>>>0) / 255)&-1;
      $52 = (($$091$us) + ($51))|0;
      $53 = Math_imul($28, $49)|0;
      $54 = (($53>>>0) / 255)&-1;
      $55 = (($$093$us) + ($54))|0;
      $56 = Math_imul($49, $29)|0;
      $57 = (($56>>>0) / 255)&-1;
      $58 = (($$092$us) + ($57))|0;
      $$088$us = $58;$$089$us = $55;$$090$us = $52;
      break;
     }
     case 32:  {
      $43 = (($$091$us) + ($26))|0;
      $44 = ($43>>>0)<(255);
      $$$us = $44 ? $43 : 255;
      $45 = (($$093$us) + ($28))|0;
      $46 = ($45>>>0)<(255);
      $$3$us = $46 ? $45 : 255;
      $47 = (($$092$us) + ($29))|0;
      $48 = ($47>>>0)<(255);
      $$1$us = $48 ? $47 : 255;
      $$088$us = $$1$us;$$089$us = $$3$us;$$090$us = $$$us;
      break;
     }
     case 64:  {
      $37 = Math_imul($$091$us, $26)|0;
      $38 = (($37>>>0) / 255)&-1;
      $39 = Math_imul($$093$us, $28)|0;
      $40 = (($39>>>0) / 255)&-1;
      $41 = Math_imul($$092$us, $29)|0;
      $42 = (($41>>>0) / 255)&-1;
      $$088$us = $42;$$089$us = $40;$$090$us = $38;
      break;
     }
     default: {
      $$088$us = $29;$$089$us = $28;$$090$us = $26;
     }
     }
     $59 = $$090$us << 16;
     $60 = $$089$us << 8;
     $61 = $60 | $59;
     $62 = $61 | $$088$us;
     HEAP32[$$08695$us>>2] = $62;
     $63 = ((($$08794$us)) + 4|0);
     $64 = ((($$08695$us)) + 4|0);
     $65 = (($66) + -1)|0;
     $67 = ($66|0)==(0);
     if ($67) {
      break L6;
     } else {
      $$08695$us = $64;$$08794$us = $63;$66 = $65;
     }
    }
   }
  } while(0);
  $112 = HEAP32[$9>>2]|0;
  $113 = (($114) + ($112)|0);
  $115 = HEAP32[$10>>2]|0;
  $116 = (($117) + ($115)|0);
  $118 = HEAP32[$3>>2]|0;
  $119 = (($118) + -1)|0;
  HEAP32[$3>>2] = $119;
  $120 = ($118|0)==(0);
  if ($120) {
   break;
  } else {
   $114 = $113;$117 = $116;$121 = $116;$122 = $113;
  }
 }
 HEAP32[$0>>2] = $113;
 HEAP32[$7>>2] = $116;
 return;
}
function _SDL_Blit_RGBA8888_RGB888_Blend_Scale($0) {
 $0 = $0|0;
 var $$ = 0, $$0113143 = 0, $$0114142 = 0, $$0116 = 0, $$0117 = 0, $$0118141 = 0, $$0120147 = 0, $$0122140 = 0, $$0125146 = 0, $$0127 = 0, $$0128 = 0, $$0129 = 0, $$0130 = 0, $$1 = 0, $$1115 = 0, $$1121$lcssa = 0, $$1126$lcssa = 0, $$2 = 0, $$2124 = 0, $$3 = 0;
 var $$in = 0, $$pre = 0, $$pre154 = 0, $$pre155 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $trunc = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 << 16;
 $6 = ((($0)) + 28|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5|0) / ($7|0))&-1;
 $9 = ((($0)) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10 << 16;
 $12 = ((($0)) + 24|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($11|0) / ($13|0))&-1;
 $15 = (($7) + -1)|0;
 HEAP32[$6>>2] = $15;
 $16 = ($7|0)==(0);
 if ($16) {
  return;
 }
 $17 = ((($0)) + 20|0);
 $18 = ((($0)) + 32|0);
 $19 = $2 & 48;
 $20 = ($19|0)!=(0);
 $21 = $2 & 112;
 $trunc = $21&255;
 $22 = ((($0)) + 12|0);
 $$pre = HEAP32[$17>>2]|0;
 $$0120147 = 0;$$0125146 = 0;$102 = $15;$103 = $$pre;$30 = $13;$97 = $$pre;
 while(1) {
  $23 = ($$0120147|0)>(65535);
  if ($23) {
   $24 = (($$0120147) + -65536)|0;
   $25 = $24 >>> 16;
   $26 = $25 << 16;
   $27 = (($$0125146) + 1)|0;
   $28 = (($27) + ($25))|0;
   $29 = (($24) - ($26))|0;
   $$1121$lcssa = $29;$$1126$lcssa = $28;
  } else {
   $$1121$lcssa = $$0120147;$$1126$lcssa = $$0125146;
  }
  $31 = ($30|0)==(0);
  if ($31) {
   $99 = $102;
  } else {
   $$0113143 = $103;$$0114142 = 0;$$0118141 = 65536;$$0122140 = -1;$$in = $30;
   while(1) {
    $32 = (($$in) + -1)|0;
    $33 = ($$0118141|0)>(65535);
    if ($33) {
     $34 = (($$0118141) + -65536)|0;
     $35 = $34 >>> 16;
     $36 = $35 << 16;
     $37 = (($$0122140) + 1)|0;
     $38 = (($37) + ($35))|0;
     $39 = (($34) - ($36))|0;
     $40 = HEAP32[$0>>2]|0;
     $41 = HEAP32[$22>>2]|0;
     $42 = Math_imul($41, $$1126$lcssa)|0;
     $43 = (($40) + ($42)|0);
     $44 = $38 << 2;
     $45 = (($43) + ($44)|0);
     $$1115 = $45;$$2 = $39;$$2124 = $38;
    } else {
     $$1115 = $$0114142;$$2 = $$0118141;$$2124 = $$0122140;
    }
    $46 = HEAP32[$$1115>>2]|0;
    $47 = $46 >>> 24;
    $48 = $46 >>> 16;
    $49 = $48 & 255;
    $50 = $46 >>> 8;
    $51 = $50 & 255;
    $52 = $46 & 255;
    $53 = HEAP32[$$0113143>>2]|0;
    $54 = $53 >>> 16;
    $55 = $54 & 255;
    $56 = $53 >>> 8;
    $57 = $56 & 255;
    $58 = $53 & 255;
    $59 = ($52|0)!=(255);
    $or$cond = $20 & $59;
    if ($or$cond) {
     $60 = Math_imul($51, $52)|0;
     $61 = Math_imul($49, $52)|0;
     $62 = Math_imul($47, $52)|0;
     $63 = (($62>>>0) / 255)&-1;
     $64 = (($61>>>0) / 255)&-1;
     $65 = (($60>>>0) / 255)&-1;
     $$0116 = $63;$$0117 = $64;$$0130 = $65;
    } else {
     $$0116 = $47;$$0117 = $49;$$0130 = $51;
    }
    $trunc$clear = $trunc & 127;
    switch ($trunc$clear<<24>>24) {
    case 16:  {
     $66 = $52 ^ 255;
     $67 = Math_imul($55, $66)|0;
     $68 = (($67>>>0) / 255)&-1;
     $69 = (($$0116) + ($68))|0;
     $70 = Math_imul($57, $66)|0;
     $71 = (($70>>>0) / 255)&-1;
     $72 = (($$0117) + ($71))|0;
     $73 = Math_imul($66, $58)|0;
     $74 = (($73>>>0) / 255)&-1;
     $75 = (($$0130) + ($74))|0;
     $$0127 = $75;$$0128 = $72;$$0129 = $69;
     break;
    }
    case 32:  {
     $76 = (($$0116) + ($55))|0;
     $77 = ($76>>>0)<(255);
     $$ = $77 ? $76 : 255;
     $78 = (($$0117) + ($57))|0;
     $79 = ($78>>>0)<(255);
     $$3 = $79 ? $78 : 255;
     $80 = (($$0130) + ($58))|0;
     $81 = ($80>>>0)<(255);
     $$1 = $81 ? $80 : 255;
     $$0127 = $$1;$$0128 = $$3;$$0129 = $$;
     break;
    }
    case 64:  {
     $82 = Math_imul($$0116, $55)|0;
     $83 = (($82>>>0) / 255)&-1;
     $84 = Math_imul($$0117, $57)|0;
     $85 = (($84>>>0) / 255)&-1;
     $86 = Math_imul($$0130, $58)|0;
     $87 = (($86>>>0) / 255)&-1;
     $$0127 = $87;$$0128 = $85;$$0129 = $83;
     break;
    }
    default: {
     $$0127 = $58;$$0128 = $57;$$0129 = $55;
    }
    }
    $88 = $$0129 << 16;
    $89 = $$0128 << 8;
    $90 = $89 | $88;
    $91 = $90 | $$0127;
    HEAP32[$$0113143>>2] = $91;
    $92 = (($$2) + ($14))|0;
    $93 = ((($$0113143)) + 4|0);
    $94 = ($32|0)==(0);
    if ($94) {
     break;
    } else {
     $$0113143 = $93;$$0114142 = $$1115;$$0118141 = $92;$$0122140 = $$2124;$$in = $32;
    }
   }
   $$pre155 = HEAP32[$6>>2]|0;
   $99 = $$pre155;
  }
  $95 = HEAP32[$18>>2]|0;
  $96 = (($97) + ($95)|0);
  $98 = (($99) + -1)|0;
  HEAP32[$6>>2] = $98;
  $100 = ($99|0)==(0);
  if ($100) {
   break;
  }
  $101 = (($$1121$lcssa) + ($8))|0;
  $$pre154 = HEAP32[$12>>2]|0;
  $$0120147 = $101;$$0125146 = $$1126$lcssa;$102 = $98;$103 = $96;$30 = $$pre154;$97 = $96;
 }
 HEAP32[$17>>2] = $96;
 return;
}
function _SDL_Blit_RGBA8888_RGB888_Modulate($0) {
 $0 = $0|0;
 var $$05157 = 0, $$05157$us$us = 0, $$05256 = 0, $$05256$us$us = 0, $$in = 0, $$in68 = 0, $$lcssa77$sink = 0, $$lcssa78$sink = 0, $$pre71 = 0, $$pre72 = 0, $$pre73 = 0, $$pre74 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = ((($0)) + 61|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = ((($0)) + 62|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = ((($0)) + 28|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($13) + -1)|0;
 HEAP32[$12>>2] = $14;
 $15 = ($13|0)==(0);
 if ($15) {
  return;
 }
 $16 = ((($0)) + 20|0);
 $17 = ((($0)) + 24|0);
 $18 = ((($0)) + 12|0);
 $19 = ((($0)) + 32|0);
 $20 = $2 & 1;
 $21 = ($20|0)==(0);
 $$pre72 = HEAP32[$0>>2]|0;
 $$pre73 = HEAP32[$16>>2]|0;
 if ($21) {
  $26 = $$pre72;$29 = $$pre73;$76 = $14;$77 = $$pre73;$78 = $$pre72;
  while(1) {
   $22 = HEAP32[$17>>2]|0;
   $23 = ($22|0)==(0);
   if ($23) {
    $31 = $76;
   } else {
    $$05157$us$us = $77;$$05256$us$us = $78;$$in68 = $22;
    while(1) {
     $33 = (($$in68) + -1)|0;
     $34 = HEAP32[$$05256$us$us>>2]|0;
     $35 = $34 >>> 24;
     $36 = $34 >>> 8;
     $37 = $36 & 255;
     $38 = $35 << 16;
     $39 = $36 & 65280;
     $40 = $39 | $38;
     $41 = $40 | $37;
     HEAP32[$$05157$us$us>>2] = $41;
     $42 = ((($$05256$us$us)) + 4|0);
     $43 = ((($$05157$us$us)) + 4|0);
     $44 = ($33|0)==(0);
     if ($44) {
      break;
     } else {
      $$05157$us$us = $43;$$05256$us$us = $42;$$in68 = $33;
     }
    }
    $$pre74 = HEAP32[$12>>2]|0;
    $31 = $$pre74;
   }
   $24 = HEAP32[$18>>2]|0;
   $25 = (($26) + ($24)|0);
   $27 = HEAP32[$19>>2]|0;
   $28 = (($29) + ($27)|0);
   $30 = (($31) + -1)|0;
   HEAP32[$12>>2] = $30;
   $32 = ($31|0)==(0);
   if ($32) {
    $$lcssa77$sink = $25;$$lcssa78$sink = $28;
    break;
   } else {
    $26 = $25;$29 = $28;$76 = $30;$77 = $28;$78 = $25;
   }
  }
 } else {
  $69 = $$pre72;$72 = $$pre73;$79 = $14;$80 = $$pre73;$81 = $$pre72;
  while(1) {
   $45 = HEAP32[$17>>2]|0;
   $46 = ($45|0)==(0);
   if ($46) {
    $74 = $79;
   } else {
    $$05157 = $80;$$05256 = $81;$$in = $45;
    while(1) {
     $47 = (($$in) + -1)|0;
     $48 = HEAP32[$$05256>>2]|0;
     $49 = $48 >>> 24;
     $50 = $48 >>> 16;
     $51 = $50 & 255;
     $52 = $48 >>> 8;
     $53 = $52 & 255;
     $54 = Math_imul($53, $11)|0;
     $55 = Math_imul($51, $8)|0;
     $56 = Math_imul($49, $5)|0;
     $57 = (($56>>>0) / 255)&-1;
     $58 = (($55>>>0) / 255)&-1;
     $59 = (($54>>>0) / 255)&-1;
     $60 = $57 << 16;
     $61 = $58 << 8;
     $62 = $61 | $60;
     $63 = $62 | $59;
     HEAP32[$$05157>>2] = $63;
     $64 = ((($$05256)) + 4|0);
     $65 = ((($$05157)) + 4|0);
     $66 = ($47|0)==(0);
     if ($66) {
      break;
     } else {
      $$05157 = $65;$$05256 = $64;$$in = $47;
     }
    }
    $$pre71 = HEAP32[$12>>2]|0;
    $74 = $$pre71;
   }
   $67 = HEAP32[$18>>2]|0;
   $68 = (($69) + ($67)|0);
   $70 = HEAP32[$19>>2]|0;
   $71 = (($72) + ($70)|0);
   $73 = (($74) + -1)|0;
   HEAP32[$12>>2] = $73;
   $75 = ($74|0)==(0);
   if ($75) {
    $$lcssa77$sink = $68;$$lcssa78$sink = $71;
    break;
   } else {
    $69 = $68;$72 = $71;$79 = $73;$80 = $71;$81 = $68;
   }
  }
 }
 HEAP32[$0>>2] = $$lcssa77$sink;
 HEAP32[$16>>2] = $$lcssa78$sink;
 return;
}
function _SDL_Blit_RGBA8888_RGB888_Modulate_Scale($0) {
 $0 = $0|0;
 var $$078104 = 0, $$078104$us = 0, $$079103 = 0, $$079103$us = 0, $$081102 = 0, $$081102$us = 0, $$083108 = 0, $$085101 = 0, $$085101$us = 0, $$088107 = 0, $$1 = 0, $$1$us = 0, $$184$lcssa = 0, $$189$lcssa = 0, $$2 = 0, $$2$us = 0, $$287 = 0, $$287$us = 0, $$pre = 0, $$pre118 = 0;
 var $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = ((($0)) + 61|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = ((($0)) + 62|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = ((($0)) + 8|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13 << 16;
 $15 = ((($0)) + 28|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($14|0) / ($16|0))&-1;
 $18 = ((($0)) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = $19 << 16;
 $21 = ((($0)) + 24|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($20|0) / ($22|0))&-1;
 $24 = (($16) + -1)|0;
 HEAP32[$15>>2] = $24;
 $25 = ($16|0)==(0);
 if ($25) {
  return;
 }
 $26 = ((($0)) + 20|0);
 $27 = ((($0)) + 32|0);
 $28 = $2 & 1;
 $29 = ($28|0)==(0);
 $30 = ((($0)) + 12|0);
 $$pre = HEAP32[$26>>2]|0;
 $$083108 = 0;$$088107 = 0;$101 = $$pre;$106 = $$pre;$39 = $22;
 while(1) {
  $31 = ($$083108|0)>(65535);
  if ($31) {
   $32 = (($$083108) + -65536)|0;
   $33 = $32 >>> 16;
   $34 = $33 << 16;
   $35 = (($$088107) + 1)|0;
   $36 = (($35) + ($33))|0;
   $37 = (($32) - ($34))|0;
   $$184$lcssa = $37;$$189$lcssa = $36;
  } else {
   $$184$lcssa = $$083108;$$189$lcssa = $$088107;
  }
  $38 = (($39) + -1)|0;
  $40 = ($39|0)==(0);
  if (!($40)) {
   if ($29) {
    $$078104$us = $106;$$079103$us = 0;$$081102$us = 65536;$$085101$us = -1;$63 = $38;
    while(1) {
     $41 = ($$081102$us|0)>(65535);
     if ($41) {
      $42 = (($$081102$us) + -65536)|0;
      $43 = $42 >>> 16;
      $44 = $43 << 16;
      $45 = (($$085101$us) + 1)|0;
      $46 = (($45) + ($43))|0;
      $47 = (($42) - ($44))|0;
      $48 = HEAP32[$0>>2]|0;
      $49 = HEAP32[$30>>2]|0;
      $50 = Math_imul($49, $$189$lcssa)|0;
      $51 = (($48) + ($50)|0);
      $52 = $46 << 2;
      $53 = (($51) + ($52)|0);
      $$1$us = $53;$$2$us = $47;$$287$us = $46;
     } else {
      $$1$us = $$079103$us;$$2$us = $$081102$us;$$287$us = $$085101$us;
     }
     $54 = HEAP32[$$1$us>>2]|0;
     $55 = $54 >>> 24;
     $56 = $54 >>> 8;
     $57 = $55 << 16;
     $58 = $56 & 65535;
     $59 = $58 | $57;
     HEAP32[$$078104$us>>2] = $59;
     $60 = (($$2$us) + ($23))|0;
     $61 = ((($$078104$us)) + 4|0);
     $62 = (($63) + -1)|0;
     $64 = ($63|0)==(0);
     if ($64) {
      break;
     } else {
      $$078104$us = $61;$$079103$us = $$1$us;$$081102$us = $60;$$085101$us = $$287$us;$63 = $62;
     }
    }
   } else {
    $$078104 = $106;$$079103 = 0;$$081102 = 65536;$$085101 = -1;$97 = $38;
    while(1) {
     $65 = ($$081102|0)>(65535);
     if ($65) {
      $66 = (($$081102) + -65536)|0;
      $67 = $66 >>> 16;
      $68 = $67 << 16;
      $69 = (($$085101) + 1)|0;
      $70 = (($69) + ($67))|0;
      $71 = (($66) - ($68))|0;
      $72 = HEAP32[$0>>2]|0;
      $73 = HEAP32[$30>>2]|0;
      $74 = Math_imul($73, $$189$lcssa)|0;
      $75 = (($72) + ($74)|0);
      $76 = $70 << 2;
      $77 = (($75) + ($76)|0);
      $$1 = $77;$$2 = $71;$$287 = $70;
     } else {
      $$1 = $$079103;$$2 = $$081102;$$287 = $$085101;
     }
     $78 = HEAP32[$$1>>2]|0;
     $79 = $78 >>> 24;
     $80 = $78 >>> 16;
     $81 = $80 & 255;
     $82 = $78 >>> 8;
     $83 = $82 & 255;
     $84 = Math_imul($83, $11)|0;
     $85 = Math_imul($81, $8)|0;
     $86 = Math_imul($79, $5)|0;
     $87 = (($86>>>0) / 255)&-1;
     $88 = (($85>>>0) / 255)&-1;
     $89 = (($84>>>0) / 255)&-1;
     $90 = $87 << 16;
     $91 = $88 << 8;
     $92 = $89 | $91;
     $93 = $92 | $90;
     HEAP32[$$078104>>2] = $93;
     $94 = (($$2) + ($23))|0;
     $95 = ((($$078104)) + 4|0);
     $96 = (($97) + -1)|0;
     $98 = ($97|0)==(0);
     if ($98) {
      break;
     } else {
      $$078104 = $95;$$079103 = $$1;$$081102 = $94;$$085101 = $$287;$97 = $96;
     }
    }
   }
  }
  $99 = HEAP32[$27>>2]|0;
  $100 = (($101) + ($99)|0);
  $102 = HEAP32[$15>>2]|0;
  $103 = (($102) + -1)|0;
  HEAP32[$15>>2] = $103;
  $104 = ($102|0)==(0);
  if ($104) {
   break;
  }
  $105 = (($$184$lcssa) + ($17))|0;
  $$pre118 = HEAP32[$21>>2]|0;
  $$083108 = $105;$$088107 = $$189$lcssa;$101 = $100;$106 = $100;$39 = $$pre118;
 }
 HEAP32[$26>>2] = $100;
 return;
}
function _SDL_Blit_RGBA8888_RGB888_Modulate_Blend($0) {
 $0 = $0|0;
 var $$ = 0, $$0108121 = 0, $$0109120 = 0, $$0110 = 0, $$0111 = 0, $$0112 = 0, $$0113 = 0, $$0114 = 0, $$0116 = 0, $$0118 = 0, $$1 = 0, $$1115 = 0, $$1117 = 0, $$1119 = 0, $$3 = 0, $$in = 0, $$pre = 0, $$pre125 = 0, $$pre126 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $or$cond = 0, $trunc = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = ((($0)) + 61|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = ((($0)) + 62|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = ((($0)) + 63|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = $13&255;
 $15 = ((($0)) + 28|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + -1)|0;
 HEAP32[$15>>2] = $17;
 $18 = ($16|0)==(0);
 if ($18) {
  return;
 }
 $19 = ((($0)) + 20|0);
 $20 = ((($0)) + 24|0);
 $21 = ((($0)) + 12|0);
 $22 = ((($0)) + 32|0);
 $23 = $2 & 1;
 $24 = ($23|0)==(0);
 $25 = $2 & 2;
 $26 = ($25|0)==(0);
 $27 = $2 & 48;
 $28 = ($27|0)!=(0);
 $29 = $2 & 112;
 $trunc = $29&255;
 $$pre = HEAP32[$0>>2]|0;
 $$pre125 = HEAP32[$19>>2]|0;
 $100 = $$pre125;$101 = $$pre;$92 = $$pre;$95 = $$pre125;$99 = $17;
 while(1) {
  $30 = HEAP32[$20>>2]|0;
  $31 = ($30|0)==(0);
  if ($31) {
   $97 = $99;
  } else {
   $$0108121 = $100;$$0109120 = $101;$$in = $30;
   while(1) {
    $32 = (($$in) + -1)|0;
    $33 = HEAP32[$$0109120>>2]|0;
    $34 = $33 >>> 24;
    $35 = $33 >>> 16;
    $36 = $35 & 255;
    $37 = $33 >>> 8;
    $38 = $37 & 255;
    $39 = $33 & 255;
    $40 = HEAP32[$$0108121>>2]|0;
    $41 = $40 >>> 16;
    $42 = $41 & 255;
    $43 = $40 >>> 8;
    $44 = $43 & 255;
    $45 = $40 & 255;
    if ($24) {
     $$0114 = $38;$$0116 = $36;$$0118 = $34;
    } else {
     $46 = Math_imul($38, $11)|0;
     $47 = Math_imul($36, $8)|0;
     $48 = Math_imul($34, $5)|0;
     $49 = (($48>>>0) / 255)&-1;
     $50 = (($47>>>0) / 255)&-1;
     $51 = (($46>>>0) / 255)&-1;
     $$0114 = $51;$$0116 = $50;$$0118 = $49;
    }
    $52 = Math_imul($39, $14)|0;
    $53 = (($52>>>0) / 255)&-1;
    $$0113 = $26 ? $39 : $53;
    $54 = ($$0113>>>0)<(255);
    $or$cond = $28 & $54;
    if ($or$cond) {
     $55 = Math_imul($$0114, $$0113)|0;
     $56 = Math_imul($$0116, $$0113)|0;
     $57 = Math_imul($$0118, $$0113)|0;
     $58 = (($57>>>0) / 255)&-1;
     $59 = (($56>>>0) / 255)&-1;
     $60 = (($55>>>0) / 255)&-1;
     $$1115 = $60;$$1117 = $59;$$1119 = $58;
    } else {
     $$1115 = $$0114;$$1117 = $$0116;$$1119 = $$0118;
    }
    $trunc$clear = $trunc & 127;
    switch ($trunc$clear<<24>>24) {
    case 16:  {
     $61 = (255 - ($$0113))|0;
     $62 = Math_imul($61, $42)|0;
     $63 = (($62>>>0) / 255)&-1;
     $64 = (($$1119) + ($63))|0;
     $65 = Math_imul($61, $44)|0;
     $66 = (($65>>>0) / 255)&-1;
     $67 = (($$1117) + ($66))|0;
     $68 = Math_imul($61, $45)|0;
     $69 = (($68>>>0) / 255)&-1;
     $70 = (($$1115) + ($69))|0;
     $$0110 = $70;$$0111 = $67;$$0112 = $64;
     break;
    }
    case 32:  {
     $71 = (($$1119) + ($42))|0;
     $72 = ($71>>>0)<(255);
     $$ = $72 ? $71 : 255;
     $73 = (($$1117) + ($44))|0;
     $74 = ($73>>>0)<(255);
     $$3 = $74 ? $73 : 255;
     $75 = (($$1115) + ($45))|0;
     $76 = ($75>>>0)<(255);
     $$1 = $76 ? $75 : 255;
     $$0110 = $$1;$$0111 = $$3;$$0112 = $$;
     break;
    }
    case 64:  {
     $77 = Math_imul($$1119, $42)|0;
     $78 = (($77>>>0) / 255)&-1;
     $79 = Math_imul($$1117, $44)|0;
     $80 = (($79>>>0) / 255)&-1;
     $81 = Math_imul($$1115, $45)|0;
     $82 = (($81>>>0) / 255)&-1;
     $$0110 = $82;$$0111 = $80;$$0112 = $78;
     break;
    }
    default: {
     $$0110 = $45;$$0111 = $44;$$0112 = $42;
    }
    }
    $83 = $$0112 << 16;
    $84 = $$0111 << 8;
    $85 = $84 | $83;
    $86 = $85 | $$0110;
    HEAP32[$$0108121>>2] = $86;
    $87 = ((($$0109120)) + 4|0);
    $88 = ((($$0108121)) + 4|0);
    $89 = ($32|0)==(0);
    if ($89) {
     break;
    } else {
     $$0108121 = $88;$$0109120 = $87;$$in = $32;
    }
   }
   $$pre126 = HEAP32[$15>>2]|0;
   $97 = $$pre126;
  }
  $90 = HEAP32[$21>>2]|0;
  $91 = (($92) + ($90)|0);
  $93 = HEAP32[$22>>2]|0;
  $94 = (($95) + ($93)|0);
  $96 = (($97) + -1)|0;
  HEAP32[$15>>2] = $96;
  $98 = ($97|0)==(0);
  if ($98) {
   break;
  } else {
   $100 = $94;$101 = $91;$92 = $91;$95 = $94;$99 = $96;
  }
 }
 HEAP32[$0>>2] = $91;
 HEAP32[$19>>2] = $94;
 return;
}
function _SDL_Blit_RGBA8888_RGB888_Modulate_Blend_Scale($0) {
 $0 = $0|0;
 var $$ = 0, $$0135169 = 0, $$0136168 = 0, $$0138 = 0, $$0140 = 0, $$0142167 = 0, $$0144173 = 0, $$0146166 = 0, $$0149172 = 0, $$0151 = 0, $$0152 = 0, $$0153 = 0, $$0154 = 0, $$0155 = 0, $$1 = 0, $$1137 = 0, $$1139 = 0, $$1141 = 0, $$1145$lcssa = 0, $$1150$lcssa = 0;
 var $$1156 = 0, $$2 = 0, $$2148 = 0, $$3 = 0, $$in = 0, $$pre = 0, $$pre180 = 0, $$pre181 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $trunc = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = ((($0)) + 61|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = ((($0)) + 62|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = ((($0)) + 63|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = $13&255;
 $15 = ((($0)) + 8|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $16 << 16;
 $18 = ((($0)) + 28|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($17|0) / ($19|0))&-1;
 $21 = ((($0)) + 4|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = $22 << 16;
 $24 = ((($0)) + 24|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($23|0) / ($25|0))&-1;
 $27 = (($19) + -1)|0;
 HEAP32[$18>>2] = $27;
 $28 = ($19|0)==(0);
 if ($28) {
  return;
 }
 $29 = ((($0)) + 20|0);
 $30 = ((($0)) + 32|0);
 $31 = $2 & 1;
 $32 = ($31|0)==(0);
 $33 = $2 & 2;
 $34 = ($33|0)==(0);
 $35 = $2 & 48;
 $36 = ($35|0)!=(0);
 $37 = $2 & 112;
 $trunc = $37&255;
 $38 = ((($0)) + 12|0);
 $$pre = HEAP32[$29>>2]|0;
 $$0144173 = 0;$$0149172 = 0;$121 = $$pre;$126 = $27;$127 = $$pre;$46 = $25;
 while(1) {
  $39 = ($$0144173|0)>(65535);
  if ($39) {
   $40 = (($$0144173) + -65536)|0;
   $41 = $40 >>> 16;
   $42 = $41 << 16;
   $43 = (($$0149172) + 1)|0;
   $44 = (($43) + ($41))|0;
   $45 = (($40) - ($42))|0;
   $$1145$lcssa = $45;$$1150$lcssa = $44;
  } else {
   $$1145$lcssa = $$0144173;$$1150$lcssa = $$0149172;
  }
  $47 = ($46|0)==(0);
  if ($47) {
   $123 = $126;
  } else {
   $$0135169 = $127;$$0136168 = 0;$$0142167 = 65536;$$0146166 = -1;$$in = $46;
   while(1) {
    $48 = (($$in) + -1)|0;
    $49 = ($$0142167|0)>(65535);
    if ($49) {
     $50 = (($$0142167) + -65536)|0;
     $51 = $50 >>> 16;
     $52 = $51 << 16;
     $53 = (($$0146166) + 1)|0;
     $54 = (($53) + ($51))|0;
     $55 = (($50) - ($52))|0;
     $56 = HEAP32[$0>>2]|0;
     $57 = HEAP32[$38>>2]|0;
     $58 = Math_imul($57, $$1150$lcssa)|0;
     $59 = (($56) + ($58)|0);
     $60 = $54 << 2;
     $61 = (($59) + ($60)|0);
     $$1137 = $61;$$2 = $55;$$2148 = $54;
    } else {
     $$1137 = $$0136168;$$2 = $$0142167;$$2148 = $$0146166;
    }
    $62 = HEAP32[$$1137>>2]|0;
    $63 = $62 >>> 24;
    $64 = $62 >>> 16;
    $65 = $64 & 255;
    $66 = $62 >>> 8;
    $67 = $66 & 255;
    $68 = $62 & 255;
    $69 = HEAP32[$$0135169>>2]|0;
    $70 = $69 >>> 16;
    $71 = $70 & 255;
    $72 = $69 >>> 8;
    $73 = $72 & 255;
    $74 = $69 & 255;
    if ($32) {
     $$0138 = $63;$$0140 = $65;$$0155 = $67;
    } else {
     $75 = Math_imul($67, $11)|0;
     $76 = Math_imul($65, $8)|0;
     $77 = Math_imul($63, $5)|0;
     $78 = (($77>>>0) / 255)&-1;
     $79 = (($76>>>0) / 255)&-1;
     $80 = (($75>>>0) / 255)&-1;
     $$0138 = $78;$$0140 = $79;$$0155 = $80;
    }
    $81 = Math_imul($68, $14)|0;
    $82 = (($81>>>0) / 255)&-1;
    $$0154 = $34 ? $68 : $82;
    $83 = ($$0154>>>0)<(255);
    $or$cond = $36 & $83;
    if ($or$cond) {
     $84 = Math_imul($$0155, $$0154)|0;
     $85 = Math_imul($$0140, $$0154)|0;
     $86 = Math_imul($$0138, $$0154)|0;
     $87 = (($86>>>0) / 255)&-1;
     $88 = (($85>>>0) / 255)&-1;
     $89 = (($84>>>0) / 255)&-1;
     $$1139 = $87;$$1141 = $88;$$1156 = $89;
    } else {
     $$1139 = $$0138;$$1141 = $$0140;$$1156 = $$0155;
    }
    $trunc$clear = $trunc & 127;
    switch ($trunc$clear<<24>>24) {
    case 16:  {
     $90 = (255 - ($$0154))|0;
     $91 = Math_imul($90, $71)|0;
     $92 = (($91>>>0) / 255)&-1;
     $93 = (($$1139) + ($92))|0;
     $94 = Math_imul($90, $73)|0;
     $95 = (($94>>>0) / 255)&-1;
     $96 = (($$1141) + ($95))|0;
     $97 = Math_imul($90, $74)|0;
     $98 = (($97>>>0) / 255)&-1;
     $99 = (($$1156) + ($98))|0;
     $$0151 = $99;$$0152 = $96;$$0153 = $93;
     break;
    }
    case 32:  {
     $100 = (($$1139) + ($71))|0;
     $101 = ($100>>>0)<(255);
     $$ = $101 ? $100 : 255;
     $102 = (($$1141) + ($73))|0;
     $103 = ($102>>>0)<(255);
     $$3 = $103 ? $102 : 255;
     $104 = (($$1156) + ($74))|0;
     $105 = ($104>>>0)<(255);
     $$1 = $105 ? $104 : 255;
     $$0151 = $$1;$$0152 = $$3;$$0153 = $$;
     break;
    }
    case 64:  {
     $106 = Math_imul($$1139, $71)|0;
     $107 = (($106>>>0) / 255)&-1;
     $108 = Math_imul($$1141, $73)|0;
     $109 = (($108>>>0) / 255)&-1;
     $110 = Math_imul($$1156, $74)|0;
     $111 = (($110>>>0) / 255)&-1;
     $$0151 = $111;$$0152 = $109;$$0153 = $107;
     break;
    }
    default: {
     $$0151 = $74;$$0152 = $73;$$0153 = $71;
    }
    }
    $112 = $$0153 << 16;
    $113 = $$0152 << 8;
    $114 = $113 | $112;
    $115 = $114 | $$0151;
    HEAP32[$$0135169>>2] = $115;
    $116 = (($$2) + ($26))|0;
    $117 = ((($$0135169)) + 4|0);
    $118 = ($48|0)==(0);
    if ($118) {
     break;
    } else {
     $$0135169 = $117;$$0136168 = $$1137;$$0142167 = $116;$$0146166 = $$2148;$$in = $48;
    }
   }
   $$pre181 = HEAP32[$18>>2]|0;
   $123 = $$pre181;
  }
  $119 = HEAP32[$30>>2]|0;
  $120 = (($121) + ($119)|0);
  $122 = (($123) + -1)|0;
  HEAP32[$18>>2] = $122;
  $124 = ($123|0)==(0);
  if ($124) {
   break;
  }
  $125 = (($$1145$lcssa) + ($20))|0;
  $$pre180 = HEAP32[$24>>2]|0;
  $$0144173 = $125;$$0149172 = $$1150$lcssa;$121 = $120;$126 = $122;$127 = $120;$46 = $$pre180;
 }
 HEAP32[$29>>2] = $120;
 return;
}
function _SDL_Blit_RGBA8888_BGR888_Scale($0) {
 $0 = $0|0;
 var $$05982 = 0, $$06081 = 0, $$06186 = 0, $$06380 = 0, $$06579 = 0, $$06885 = 0, $$1 = 0, $$162$lcssa = 0, $$169$lcssa = 0, $$2 = 0, $$267 = 0, $$in = 0, $$pre = 0, $$pre93 = 0, $$pre94 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 << 16;
 $4 = ((($0)) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3|0) / ($5|0))&-1;
 $7 = ((($0)) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 << 16;
 $10 = ((($0)) + 24|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($9|0) / ($11|0))&-1;
 $13 = (($5) + -1)|0;
 HEAP32[$4>>2] = $13;
 $14 = ($5|0)==(0);
 if ($14) {
  return;
 }
 $15 = ((($0)) + 20|0);
 $16 = ((($0)) + 32|0);
 $17 = ((($0)) + 12|0);
 $$pre = HEAP32[$15>>2]|0;
 $$06186 = 0;$$06885 = 0;$25 = $11;$54 = $$pre;$59 = $13;$60 = $$pre;
 while(1) {
  $18 = ($$06885|0)>(65535);
  if ($18) {
   $19 = (($$06885) + -65536)|0;
   $20 = $19 >>> 16;
   $21 = $20 << 16;
   $22 = (($$06186) + 1)|0;
   $23 = (($22) + ($20))|0;
   $24 = (($19) - ($21))|0;
   $$162$lcssa = $23;$$169$lcssa = $24;
  } else {
   $$162$lcssa = $$06186;$$169$lcssa = $$06885;
  }
  $26 = ($25|0)==(0);
  if ($26) {
   $56 = $59;
  } else {
   $$05982 = $60;$$06081 = 0;$$06380 = -1;$$06579 = 65536;$$in = $25;
   while(1) {
    $27 = (($$in) + -1)|0;
    $28 = ($$06579|0)>(65535);
    if ($28) {
     $29 = (($$06579) + -65536)|0;
     $30 = $29 >>> 16;
     $31 = $30 << 16;
     $32 = (($$06380) + 1)|0;
     $33 = (($32) + ($30))|0;
     $34 = (($29) - ($31))|0;
     $35 = HEAP32[$0>>2]|0;
     $36 = HEAP32[$17>>2]|0;
     $37 = Math_imul($36, $$162$lcssa)|0;
     $38 = (($35) + ($37)|0);
     $39 = $33 << 2;
     $40 = (($38) + ($39)|0);
     $$1 = $40;$$2 = $33;$$267 = $34;
    } else {
     $$1 = $$06081;$$2 = $$06380;$$267 = $$06579;
    }
    $41 = HEAP32[$$1>>2]|0;
    $42 = $41 >>> 24;
    $43 = $41 << 8;
    $44 = $43 & 16711680;
    $45 = $41 >>> 8;
    $46 = $45 & 65280;
    $47 = $46 | $42;
    $48 = $47 | $44;
    HEAP32[$$05982>>2] = $48;
    $49 = (($$267) + ($12))|0;
    $50 = ((($$05982)) + 4|0);
    $51 = ($27|0)==(0);
    if ($51) {
     break;
    } else {
     $$05982 = $50;$$06081 = $$1;$$06380 = $$2;$$06579 = $49;$$in = $27;
    }
   }
   $$pre94 = HEAP32[$4>>2]|0;
   $56 = $$pre94;
  }
  $52 = HEAP32[$16>>2]|0;
  $53 = (($54) + ($52)|0);
  $55 = (($56) + -1)|0;
  HEAP32[$4>>2] = $55;
  $57 = ($56|0)==(0);
  if ($57) {
   break;
  }
  $58 = (($$169$lcssa) + ($6))|0;
  $$pre93 = HEAP32[$10>>2]|0;
  $$06186 = $$162$lcssa;$$06885 = $58;$25 = $$pre93;$54 = $53;$59 = $55;$60 = $53;
 }
 HEAP32[$15>>2] = $53;
 return;
}
function _SDL_Blit_RGBA8888_BGR888_Blend($0) {
 $0 = $0|0;
 var $$ = 0, $$$us = 0, $$08695 = 0, $$08695$us = 0, $$08794 = 0, $$08794$us = 0, $$088 = 0, $$088$us = 0, $$089 = 0, $$089$us = 0, $$090 = 0, $$090$us = 0, $$091$us = 0, $$092$us = 0, $$093$us = 0, $$1 = 0, $$1$us = 0, $$3 = 0, $$3$us = 0, $$pre = 0;
 var $$pre100 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $trunc = 0, $trunc$clear = 0, $trunc$clear1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + -1)|0;
 HEAP32[$3>>2] = $5;
 $6 = ($4|0)==(0);
 if ($6) {
  return;
 }
 $7 = ((($0)) + 20|0);
 $8 = ((($0)) + 24|0);
 $9 = ((($0)) + 12|0);
 $10 = ((($0)) + 32|0);
 $11 = $2 & 48;
 $12 = ($11|0)==(0);
 $13 = $2 & 112;
 $trunc = $13&255;
 $$pre = HEAP32[$0>>2]|0;
 $$pre100 = HEAP32[$7>>2]|0;
 $114 = $$pre;$117 = $$pre100;$121 = $$pre100;$122 = $$pre;
 while(1) {
  $14 = HEAP32[$8>>2]|0;
  $15 = (($14) + -1)|0;
  $16 = ($14|0)==(0);
  L6: do {
   if (!($16)) {
    if ($12) {
     $$08695 = $121;$$08794 = $122;$110 = $15;
     while(1) {
      $68 = HEAP32[$$08794>>2]|0;
      $69 = $68 >>> 24;
      $70 = $68 >>> 16;
      $71 = $70 & 255;
      $72 = $68 >>> 8;
      $73 = $72 & 255;
      $74 = HEAP32[$$08695>>2]|0;
      $75 = $74 >>> 16;
      $76 = $75 & 255;
      $77 = $74 >>> 8;
      $78 = $77 & 255;
      $79 = $74 & 255;
      $trunc$clear1 = $trunc & 127;
      switch ($trunc$clear1<<24>>24) {
      case 16:  {
       $80 = $68 & 255;
       $81 = $80 ^ 255;
       $82 = Math_imul($81, $79)|0;
       $83 = (($82>>>0) / 255)&-1;
       $84 = (($69) + ($83))|0;
       $85 = Math_imul($78, $81)|0;
       $86 = (($85>>>0) / 255)&-1;
       $87 = (($71) + ($86))|0;
       $88 = Math_imul($76, $81)|0;
       $89 = (($88>>>0) / 255)&-1;
       $90 = (($73) + ($89))|0;
       $$088 = $90;$$089 = $87;$$090 = $84;
       break;
      }
      case 32:  {
       $91 = (($69) + ($79))|0;
       $92 = ($91>>>0)<(255);
       $$ = $92 ? $91 : 255;
       $93 = (($71) + ($78))|0;
       $94 = ($93>>>0)<(255);
       $$3 = $94 ? $93 : 255;
       $95 = (($73) + ($76))|0;
       $96 = ($95>>>0)<(255);
       $$1 = $96 ? $95 : 255;
       $$088 = $$1;$$089 = $$3;$$090 = $$;
       break;
      }
      case 64:  {
       $97 = Math_imul($69, $79)|0;
       $98 = (($97>>>0) / 255)&-1;
       $99 = Math_imul($71, $78)|0;
       $100 = (($99>>>0) / 255)&-1;
       $101 = Math_imul($73, $76)|0;
       $102 = (($101>>>0) / 255)&-1;
       $$088 = $102;$$089 = $100;$$090 = $98;
       break;
      }
      default: {
       $$088 = $76;$$089 = $78;$$090 = $79;
      }
      }
      $103 = $$088 << 16;
      $104 = $$089 << 8;
      $105 = $104 | $$090;
      $106 = $105 | $103;
      HEAP32[$$08695>>2] = $106;
      $107 = ((($$08794)) + 4|0);
      $108 = ((($$08695)) + 4|0);
      $109 = (($110) + -1)|0;
      $111 = ($110|0)==(0);
      if ($111) {
       break L6;
      } else {
       $$08695 = $108;$$08794 = $107;$110 = $109;
      }
     }
    } else {
     $$08695$us = $121;$$08794$us = $122;$66 = $15;
    }
    while(1) {
     $17 = HEAP32[$$08794$us>>2]|0;
     $18 = $17 >>> 24;
     $19 = $17 >>> 16;
     $20 = $19 & 255;
     $21 = $17 >>> 8;
     $22 = $21 & 255;
     $23 = $17 & 255;
     $24 = HEAP32[$$08695$us>>2]|0;
     $25 = $24 >>> 16;
     $26 = $25 & 255;
     $27 = $24 >>> 8;
     $28 = $27 & 255;
     $29 = $24 & 255;
     $30 = ($23|0)==(255);
     if ($30) {
      $$091$us = $18;$$092$us = $22;$$093$us = $20;
     } else {
      $31 = Math_imul($22, $23)|0;
      $32 = Math_imul($20, $23)|0;
      $33 = Math_imul($18, $23)|0;
      $34 = (($33>>>0) / 255)&-1;
      $35 = (($32>>>0) / 255)&-1;
      $36 = (($31>>>0) / 255)&-1;
      $$091$us = $34;$$092$us = $36;$$093$us = $35;
     }
     $trunc$clear = $trunc & 127;
     switch ($trunc$clear<<24>>24) {
     case 16:  {
      $49 = $23 ^ 255;
      $50 = Math_imul($49, $29)|0;
      $51 = (($50>>>0) / 255)&-1;
      $52 = (($$091$us) + ($51))|0;
      $53 = Math_imul($28, $49)|0;
      $54 = (($53>>>0) / 255)&-1;
      $55 = (($$093$us) + ($54))|0;
      $56 = Math_imul($26, $49)|0;
      $57 = (($56>>>0) / 255)&-1;
      $58 = (($$092$us) + ($57))|0;
      $$088$us = $58;$$089$us = $55;$$090$us = $52;
      break;
     }
     case 32:  {
      $43 = (($$091$us) + ($29))|0;
      $44 = ($43>>>0)<(255);
      $$$us = $44 ? $43 : 255;
      $45 = (($$093$us) + ($28))|0;
      $46 = ($45>>>0)<(255);
      $$3$us = $46 ? $45 : 255;
      $47 = (($$092$us) + ($26))|0;
      $48 = ($47>>>0)<(255);
      $$1$us = $48 ? $47 : 255;
      $$088$us = $$1$us;$$089$us = $$3$us;$$090$us = $$$us;
      break;
     }
     case 64:  {
      $37 = Math_imul($$091$us, $29)|0;
      $38 = (($37>>>0) / 255)&-1;
      $39 = Math_imul($$093$us, $28)|0;
      $40 = (($39>>>0) / 255)&-1;
      $41 = Math_imul($$092$us, $26)|0;
      $42 = (($41>>>0) / 255)&-1;
      $$088$us = $42;$$089$us = $40;$$090$us = $38;
      break;
     }
     default: {
      $$088$us = $26;$$089$us = $28;$$090$us = $29;
     }
     }
     $59 = $$088$us << 16;
     $60 = $$089$us << 8;
     $61 = $60 | $$090$us;
     $62 = $61 | $59;
     HEAP32[$$08695$us>>2] = $62;
     $63 = ((($$08794$us)) + 4|0);
     $64 = ((($$08695$us)) + 4|0);
     $65 = (($66) + -1)|0;
     $67 = ($66|0)==(0);
     if ($67) {
      break L6;
     } else {
      $$08695$us = $64;$$08794$us = $63;$66 = $65;
     }
    }
   }
  } while(0);
  $112 = HEAP32[$9>>2]|0;
  $113 = (($114) + ($112)|0);
  $115 = HEAP32[$10>>2]|0;
  $116 = (($117) + ($115)|0);
  $118 = HEAP32[$3>>2]|0;
  $119 = (($118) + -1)|0;
  HEAP32[$3>>2] = $119;
  $120 = ($118|0)==(0);
  if ($120) {
   break;
  } else {
   $114 = $113;$117 = $116;$121 = $116;$122 = $113;
  }
 }
 HEAP32[$0>>2] = $113;
 HEAP32[$7>>2] = $116;
 return;
}
function _SDL_Blit_RGBA8888_BGR888_Blend_Scale($0) {
 $0 = $0|0;
 var $$ = 0, $$0113143 = 0, $$0114142 = 0, $$0116 = 0, $$0117 = 0, $$0118141 = 0, $$0120147 = 0, $$0122140 = 0, $$0125146 = 0, $$0127 = 0, $$0128 = 0, $$0129 = 0, $$0130 = 0, $$1 = 0, $$1115 = 0, $$1121$lcssa = 0, $$1126$lcssa = 0, $$2 = 0, $$2124 = 0, $$3 = 0;
 var $$in = 0, $$pre = 0, $$pre154 = 0, $$pre155 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $trunc = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 << 16;
 $6 = ((($0)) + 28|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5|0) / ($7|0))&-1;
 $9 = ((($0)) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10 << 16;
 $12 = ((($0)) + 24|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($11|0) / ($13|0))&-1;
 $15 = (($7) + -1)|0;
 HEAP32[$6>>2] = $15;
 $16 = ($7|0)==(0);
 if ($16) {
  return;
 }
 $17 = ((($0)) + 20|0);
 $18 = ((($0)) + 32|0);
 $19 = $2 & 48;
 $20 = ($19|0)!=(0);
 $21 = $2 & 112;
 $trunc = $21&255;
 $22 = ((($0)) + 12|0);
 $$pre = HEAP32[$17>>2]|0;
 $$0120147 = 0;$$0125146 = 0;$102 = $15;$103 = $$pre;$30 = $13;$97 = $$pre;
 while(1) {
  $23 = ($$0120147|0)>(65535);
  if ($23) {
   $24 = (($$0120147) + -65536)|0;
   $25 = $24 >>> 16;
   $26 = $25 << 16;
   $27 = (($$0125146) + 1)|0;
   $28 = (($27) + ($25))|0;
   $29 = (($24) - ($26))|0;
   $$1121$lcssa = $29;$$1126$lcssa = $28;
  } else {
   $$1121$lcssa = $$0120147;$$1126$lcssa = $$0125146;
  }
  $31 = ($30|0)==(0);
  if ($31) {
   $99 = $102;
  } else {
   $$0113143 = $103;$$0114142 = 0;$$0118141 = 65536;$$0122140 = -1;$$in = $30;
   while(1) {
    $32 = (($$in) + -1)|0;
    $33 = ($$0118141|0)>(65535);
    if ($33) {
     $34 = (($$0118141) + -65536)|0;
     $35 = $34 >>> 16;
     $36 = $35 << 16;
     $37 = (($$0122140) + 1)|0;
     $38 = (($37) + ($35))|0;
     $39 = (($34) - ($36))|0;
     $40 = HEAP32[$0>>2]|0;
     $41 = HEAP32[$22>>2]|0;
     $42 = Math_imul($41, $$1126$lcssa)|0;
     $43 = (($40) + ($42)|0);
     $44 = $38 << 2;
     $45 = (($43) + ($44)|0);
     $$1115 = $45;$$2 = $39;$$2124 = $38;
    } else {
     $$1115 = $$0114142;$$2 = $$0118141;$$2124 = $$0122140;
    }
    $46 = HEAP32[$$1115>>2]|0;
    $47 = $46 >>> 24;
    $48 = $46 >>> 16;
    $49 = $48 & 255;
    $50 = $46 >>> 8;
    $51 = $50 & 255;
    $52 = $46 & 255;
    $53 = HEAP32[$$0113143>>2]|0;
    $54 = $53 >>> 16;
    $55 = $54 & 255;
    $56 = $53 >>> 8;
    $57 = $56 & 255;
    $58 = $53 & 255;
    $59 = ($52|0)!=(255);
    $or$cond = $20 & $59;
    if ($or$cond) {
     $60 = Math_imul($51, $52)|0;
     $61 = Math_imul($49, $52)|0;
     $62 = Math_imul($47, $52)|0;
     $63 = (($62>>>0) / 255)&-1;
     $64 = (($61>>>0) / 255)&-1;
     $65 = (($60>>>0) / 255)&-1;
     $$0116 = $63;$$0117 = $64;$$0130 = $65;
    } else {
     $$0116 = $47;$$0117 = $49;$$0130 = $51;
    }
    $trunc$clear = $trunc & 127;
    switch ($trunc$clear<<24>>24) {
    case 16:  {
     $66 = $52 ^ 255;
     $67 = Math_imul($66, $58)|0;
     $68 = (($67>>>0) / 255)&-1;
     $69 = (($$0116) + ($68))|0;
     $70 = Math_imul($57, $66)|0;
     $71 = (($70>>>0) / 255)&-1;
     $72 = (($$0117) + ($71))|0;
     $73 = Math_imul($55, $66)|0;
     $74 = (($73>>>0) / 255)&-1;
     $75 = (($$0130) + ($74))|0;
     $$0127 = $75;$$0128 = $72;$$0129 = $69;
     break;
    }
    case 32:  {
     $76 = (($$0116) + ($58))|0;
     $77 = ($76>>>0)<(255);
     $$ = $77 ? $76 : 255;
     $78 = (($$0117) + ($57))|0;
     $79 = ($78>>>0)<(255);
     $$3 = $79 ? $78 : 255;
     $80 = (($$0130) + ($55))|0;
     $81 = ($80>>>0)<(255);
     $$1 = $81 ? $80 : 255;
     $$0127 = $$1;$$0128 = $$3;$$0129 = $$;
     break;
    }
    case 64:  {
     $82 = Math_imul($$0116, $58)|0;
     $83 = (($82>>>0) / 255)&-1;
     $84 = Math_imul($$0117, $57)|0;
     $85 = (($84>>>0) / 255)&-1;
     $86 = Math_imul($$0130, $55)|0;
     $87 = (($86>>>0) / 255)&-1;
     $$0127 = $87;$$0128 = $85;$$0129 = $83;
     break;
    }
    default: {
     $$0127 = $55;$$0128 = $57;$$0129 = $58;
    }
    }
    $88 = $$0127 << 16;
    $89 = $$0128 << 8;
    $90 = $89 | $$0129;
    $91 = $90 | $88;
    HEAP32[$$0113143>>2] = $91;
    $92 = (($$2) + ($14))|0;
    $93 = ((($$0113143)) + 4|0);
    $94 = ($32|0)==(0);
    if ($94) {
     break;
    } else {
     $$0113143 = $93;$$0114142 = $$1115;$$0118141 = $92;$$0122140 = $$2124;$$in = $32;
    }
   }
   $$pre155 = HEAP32[$6>>2]|0;
   $99 = $$pre155;
  }
  $95 = HEAP32[$18>>2]|0;
  $96 = (($97) + ($95)|0);
  $98 = (($99) + -1)|0;
  HEAP32[$6>>2] = $98;
  $100 = ($99|0)==(0);
  if ($100) {
   break;
  }
  $101 = (($$1121$lcssa) + ($8))|0;
  $$pre154 = HEAP32[$12>>2]|0;
  $$0120147 = $101;$$0125146 = $$1126$lcssa;$102 = $98;$103 = $96;$30 = $$pre154;$97 = $96;
 }
 HEAP32[$17>>2] = $96;
 return;
}
function _SDL_Blit_RGBA8888_BGR888_Modulate($0) {
 $0 = $0|0;
 var $$05157 = 0, $$05157$us$us = 0, $$05256 = 0, $$05256$us$us = 0, $$in = 0, $$in68 = 0, $$lcssa77$sink = 0, $$lcssa78$sink = 0, $$pre71 = 0, $$pre72 = 0, $$pre73 = 0, $$pre74 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = ((($0)) + 61|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = ((($0)) + 62|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = ((($0)) + 28|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($13) + -1)|0;
 HEAP32[$12>>2] = $14;
 $15 = ($13|0)==(0);
 if ($15) {
  return;
 }
 $16 = ((($0)) + 20|0);
 $17 = ((($0)) + 24|0);
 $18 = ((($0)) + 12|0);
 $19 = ((($0)) + 32|0);
 $20 = $2 & 1;
 $21 = ($20|0)==(0);
 $$pre72 = HEAP32[$0>>2]|0;
 $$pre73 = HEAP32[$16>>2]|0;
 if ($21) {
  $26 = $$pre72;$29 = $$pre73;$76 = $14;$77 = $$pre73;$78 = $$pre72;
  while(1) {
   $22 = HEAP32[$17>>2]|0;
   $23 = ($22|0)==(0);
   if ($23) {
    $31 = $76;
   } else {
    $$05157$us$us = $77;$$05256$us$us = $78;$$in68 = $22;
    while(1) {
     $33 = (($$in68) + -1)|0;
     $34 = HEAP32[$$05256$us$us>>2]|0;
     $35 = $34 >>> 24;
     $36 = $34 << 8;
     $37 = $36 & 16711680;
     $38 = $34 >>> 8;
     $39 = $38 & 65280;
     $40 = $39 | $35;
     $41 = $40 | $37;
     HEAP32[$$05157$us$us>>2] = $41;
     $42 = ((($$05256$us$us)) + 4|0);
     $43 = ((($$05157$us$us)) + 4|0);
     $44 = ($33|0)==(0);
     if ($44) {
      break;
     } else {
      $$05157$us$us = $43;$$05256$us$us = $42;$$in68 = $33;
     }
    }
    $$pre74 = HEAP32[$12>>2]|0;
    $31 = $$pre74;
   }
   $24 = HEAP32[$18>>2]|0;
   $25 = (($26) + ($24)|0);
   $27 = HEAP32[$19>>2]|0;
   $28 = (($29) + ($27)|0);
   $30 = (($31) + -1)|0;
   HEAP32[$12>>2] = $30;
   $32 = ($31|0)==(0);
   if ($32) {
    $$lcssa77$sink = $25;$$lcssa78$sink = $28;
    break;
   } else {
    $26 = $25;$29 = $28;$76 = $30;$77 = $28;$78 = $25;
   }
  }
 } else {
  $69 = $$pre72;$72 = $$pre73;$79 = $14;$80 = $$pre73;$81 = $$pre72;
  while(1) {
   $45 = HEAP32[$17>>2]|0;
   $46 = ($45|0)==(0);
   if ($46) {
    $74 = $79;
   } else {
    $$05157 = $80;$$05256 = $81;$$in = $45;
    while(1) {
     $47 = (($$in) + -1)|0;
     $48 = HEAP32[$$05256>>2]|0;
     $49 = $48 >>> 24;
     $50 = $48 >>> 16;
     $51 = $50 & 255;
     $52 = $48 >>> 8;
     $53 = $52 & 255;
     $54 = Math_imul($53, $11)|0;
     $55 = Math_imul($51, $8)|0;
     $56 = Math_imul($49, $5)|0;
     $57 = (($56>>>0) / 255)&-1;
     $58 = (($55>>>0) / 255)&-1;
     $59 = (($54>>>0) / 255)&-1;
     $60 = $59 << 16;
     $61 = $58 << 8;
     $62 = $61 | $57;
     $63 = $62 | $60;
     HEAP32[$$05157>>2] = $63;
     $64 = ((($$05256)) + 4|0);
     $65 = ((($$05157)) + 4|0);
     $66 = ($47|0)==(0);
     if ($66) {
      break;
     } else {
      $$05157 = $65;$$05256 = $64;$$in = $47;
     }
    }
    $$pre71 = HEAP32[$12>>2]|0;
    $74 = $$pre71;
   }
   $67 = HEAP32[$18>>2]|0;
   $68 = (($69) + ($67)|0);
   $70 = HEAP32[$19>>2]|0;
   $71 = (($72) + ($70)|0);
   $73 = (($74) + -1)|0;
   HEAP32[$12>>2] = $73;
   $75 = ($74|0)==(0);
   if ($75) {
    $$lcssa77$sink = $68;$$lcssa78$sink = $71;
    break;
   } else {
    $69 = $68;$72 = $71;$79 = $73;$80 = $71;$81 = $68;
   }
  }
 }
 HEAP32[$0>>2] = $$lcssa77$sink;
 HEAP32[$16>>2] = $$lcssa78$sink;
 return;
}
function _SDL_Blit_RGBA8888_BGR888_Modulate_Scale($0) {
 $0 = $0|0;
 var $$078104 = 0, $$078104$us = 0, $$079103 = 0, $$079103$us = 0, $$081102 = 0, $$081102$us = 0, $$083108 = 0, $$085101 = 0, $$085101$us = 0, $$088107 = 0, $$1 = 0, $$1$us = 0, $$184$lcssa = 0, $$189$lcssa = 0, $$2 = 0, $$2$us = 0, $$287 = 0, $$287$us = 0, $$pre = 0, $$pre118 = 0;
 var $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = ((($0)) + 61|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = ((($0)) + 62|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = ((($0)) + 8|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13 << 16;
 $15 = ((($0)) + 28|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($14|0) / ($16|0))&-1;
 $18 = ((($0)) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = $19 << 16;
 $21 = ((($0)) + 24|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($20|0) / ($22|0))&-1;
 $24 = (($16) + -1)|0;
 HEAP32[$15>>2] = $24;
 $25 = ($16|0)==(0);
 if ($25) {
  return;
 }
 $26 = ((($0)) + 20|0);
 $27 = ((($0)) + 32|0);
 $28 = $2 & 1;
 $29 = ($28|0)==(0);
 $30 = ((($0)) + 12|0);
 $$pre = HEAP32[$26>>2]|0;
 $$083108 = 0;$$088107 = 0;$103 = $$pre;$108 = $$pre;$39 = $22;
 while(1) {
  $31 = ($$083108|0)>(65535);
  if ($31) {
   $32 = (($$083108) + -65536)|0;
   $33 = $32 >>> 16;
   $34 = $33 << 16;
   $35 = (($$088107) + 1)|0;
   $36 = (($35) + ($33))|0;
   $37 = (($32) - ($34))|0;
   $$184$lcssa = $37;$$189$lcssa = $36;
  } else {
   $$184$lcssa = $$083108;$$189$lcssa = $$088107;
  }
  $38 = (($39) + -1)|0;
  $40 = ($39|0)==(0);
  if (!($40)) {
   if ($29) {
    $$078104$us = $108;$$079103$us = 0;$$081102$us = 65536;$$085101$us = -1;$65 = $38;
    while(1) {
     $41 = ($$081102$us|0)>(65535);
     if ($41) {
      $42 = (($$081102$us) + -65536)|0;
      $43 = $42 >>> 16;
      $44 = $43 << 16;
      $45 = (($$085101$us) + 1)|0;
      $46 = (($45) + ($43))|0;
      $47 = (($42) - ($44))|0;
      $48 = HEAP32[$0>>2]|0;
      $49 = HEAP32[$30>>2]|0;
      $50 = Math_imul($49, $$189$lcssa)|0;
      $51 = (($48) + ($50)|0);
      $52 = $46 << 2;
      $53 = (($51) + ($52)|0);
      $$1$us = $53;$$2$us = $47;$$287$us = $46;
     } else {
      $$1$us = $$079103$us;$$2$us = $$081102$us;$$287$us = $$085101$us;
     }
     $54 = HEAP32[$$1$us>>2]|0;
     $55 = $54 >>> 24;
     $56 = $54 << 8;
     $57 = $56 & 16711680;
     $58 = $54 >>> 8;
     $59 = $58 & 65280;
     $60 = $57 | $59;
     $61 = $60 | $55;
     HEAP32[$$078104$us>>2] = $61;
     $62 = (($$2$us) + ($23))|0;
     $63 = ((($$078104$us)) + 4|0);
     $64 = (($65) + -1)|0;
     $66 = ($65|0)==(0);
     if ($66) {
      break;
     } else {
      $$078104$us = $63;$$079103$us = $$1$us;$$081102$us = $62;$$085101$us = $$287$us;$65 = $64;
     }
    }
   } else {
    $$078104 = $108;$$079103 = 0;$$081102 = 65536;$$085101 = -1;$99 = $38;
    while(1) {
     $67 = ($$081102|0)>(65535);
     if ($67) {
      $68 = (($$081102) + -65536)|0;
      $69 = $68 >>> 16;
      $70 = $69 << 16;
      $71 = (($$085101) + 1)|0;
      $72 = (($71) + ($69))|0;
      $73 = (($68) - ($70))|0;
      $74 = HEAP32[$0>>2]|0;
      $75 = HEAP32[$30>>2]|0;
      $76 = Math_imul($75, $$189$lcssa)|0;
      $77 = (($74) + ($76)|0);
      $78 = $72 << 2;
      $79 = (($77) + ($78)|0);
      $$1 = $79;$$2 = $73;$$287 = $72;
     } else {
      $$1 = $$079103;$$2 = $$081102;$$287 = $$085101;
     }
     $80 = HEAP32[$$1>>2]|0;
     $81 = $80 >>> 24;
     $82 = $80 >>> 16;
     $83 = $82 & 255;
     $84 = $80 >>> 8;
     $85 = $84 & 255;
     $86 = Math_imul($85, $11)|0;
     $87 = Math_imul($83, $8)|0;
     $88 = Math_imul($81, $5)|0;
     $89 = (($88>>>0) / 255)&-1;
     $90 = (($87>>>0) / 255)&-1;
     $91 = (($86>>>0) / 255)&-1;
     $92 = $91 << 16;
     $93 = $90 << 8;
     $94 = $92 | $93;
     $95 = $94 | $89;
     HEAP32[$$078104>>2] = $95;
     $96 = (($$2) + ($23))|0;
     $97 = ((($$078104)) + 4|0);
     $98 = (($99) + -1)|0;
     $100 = ($99|0)==(0);
     if ($100) {
      break;
     } else {
      $$078104 = $97;$$079103 = $$1;$$081102 = $96;$$085101 = $$287;$99 = $98;
     }
    }
   }
  }
  $101 = HEAP32[$27>>2]|0;
  $102 = (($103) + ($101)|0);
  $104 = HEAP32[$15>>2]|0;
  $105 = (($104) + -1)|0;
  HEAP32[$15>>2] = $105;
  $106 = ($104|0)==(0);
  if ($106) {
   break;
  }
  $107 = (($$184$lcssa) + ($17))|0;
  $$pre118 = HEAP32[$21>>2]|0;
  $$083108 = $107;$$088107 = $$189$lcssa;$103 = $102;$108 = $102;$39 = $$pre118;
 }
 HEAP32[$26>>2] = $102;
 return;
}
function _SDL_Blit_RGBA8888_BGR888_Modulate_Blend($0) {
 $0 = $0|0;
 var $$ = 0, $$0108121 = 0, $$0109120 = 0, $$0110 = 0, $$0111 = 0, $$0112 = 0, $$0113 = 0, $$0114 = 0, $$0116 = 0, $$0118 = 0, $$1 = 0, $$1115 = 0, $$1117 = 0, $$1119 = 0, $$3 = 0, $$in = 0, $$pre = 0, $$pre125 = 0, $$pre126 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $or$cond = 0, $trunc = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = ((($0)) + 61|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = ((($0)) + 62|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = ((($0)) + 63|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = $13&255;
 $15 = ((($0)) + 28|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + -1)|0;
 HEAP32[$15>>2] = $17;
 $18 = ($16|0)==(0);
 if ($18) {
  return;
 }
 $19 = ((($0)) + 20|0);
 $20 = ((($0)) + 24|0);
 $21 = ((($0)) + 12|0);
 $22 = ((($0)) + 32|0);
 $23 = $2 & 1;
 $24 = ($23|0)==(0);
 $25 = $2 & 2;
 $26 = ($25|0)==(0);
 $27 = $2 & 48;
 $28 = ($27|0)!=(0);
 $29 = $2 & 112;
 $trunc = $29&255;
 $$pre = HEAP32[$0>>2]|0;
 $$pre125 = HEAP32[$19>>2]|0;
 $100 = $$pre125;$101 = $$pre;$92 = $$pre;$95 = $$pre125;$99 = $17;
 while(1) {
  $30 = HEAP32[$20>>2]|0;
  $31 = ($30|0)==(0);
  if ($31) {
   $97 = $99;
  } else {
   $$0108121 = $100;$$0109120 = $101;$$in = $30;
   while(1) {
    $32 = (($$in) + -1)|0;
    $33 = HEAP32[$$0109120>>2]|0;
    $34 = $33 >>> 24;
    $35 = $33 >>> 16;
    $36 = $35 & 255;
    $37 = $33 >>> 8;
    $38 = $37 & 255;
    $39 = $33 & 255;
    $40 = HEAP32[$$0108121>>2]|0;
    $41 = $40 >>> 16;
    $42 = $41 & 255;
    $43 = $40 >>> 8;
    $44 = $43 & 255;
    $45 = $40 & 255;
    if ($24) {
     $$0114 = $38;$$0116 = $36;$$0118 = $34;
    } else {
     $46 = Math_imul($38, $11)|0;
     $47 = Math_imul($36, $8)|0;
     $48 = Math_imul($34, $5)|0;
     $49 = (($48>>>0) / 255)&-1;
     $50 = (($47>>>0) / 255)&-1;
     $51 = (($46>>>0) / 255)&-1;
     $$0114 = $51;$$0116 = $50;$$0118 = $49;
    }
    $52 = Math_imul($39, $14)|0;
    $53 = (($52>>>0) / 255)&-1;
    $$0113 = $26 ? $39 : $53;
    $54 = ($$0113>>>0)<(255);
    $or$cond = $28 & $54;
    if ($or$cond) {
     $55 = Math_imul($$0114, $$0113)|0;
     $56 = Math_imul($$0116, $$0113)|0;
     $57 = Math_imul($$0118, $$0113)|0;
     $58 = (($57>>>0) / 255)&-1;
     $59 = (($56>>>0) / 255)&-1;
     $60 = (($55>>>0) / 255)&-1;
     $$1115 = $60;$$1117 = $59;$$1119 = $58;
    } else {
     $$1115 = $$0114;$$1117 = $$0116;$$1119 = $$0118;
    }
    $trunc$clear = $trunc & 127;
    switch ($trunc$clear<<24>>24) {
    case 16:  {
     $61 = (255 - ($$0113))|0;
     $62 = Math_imul($61, $45)|0;
     $63 = (($62>>>0) / 255)&-1;
     $64 = (($$1119) + ($63))|0;
     $65 = Math_imul($61, $44)|0;
     $66 = (($65>>>0) / 255)&-1;
     $67 = (($$1117) + ($66))|0;
     $68 = Math_imul($61, $42)|0;
     $69 = (($68>>>0) / 255)&-1;
     $70 = (($$1115) + ($69))|0;
     $$0110 = $70;$$0111 = $67;$$0112 = $64;
     break;
    }
    case 32:  {
     $71 = (($$1119) + ($45))|0;
     $72 = ($71>>>0)<(255);
     $$ = $72 ? $71 : 255;
     $73 = (($$1117) + ($44))|0;
     $74 = ($73>>>0)<(255);
     $$3 = $74 ? $73 : 255;
     $75 = (($$1115) + ($42))|0;
     $76 = ($75>>>0)<(255);
     $$1 = $76 ? $75 : 255;
     $$0110 = $$1;$$0111 = $$3;$$0112 = $$;
     break;
    }
    case 64:  {
     $77 = Math_imul($$1119, $45)|0;
     $78 = (($77>>>0) / 255)&-1;
     $79 = Math_imul($$1117, $44)|0;
     $80 = (($79>>>0) / 255)&-1;
     $81 = Math_imul($$1115, $42)|0;
     $82 = (($81>>>0) / 255)&-1;
     $$0110 = $82;$$0111 = $80;$$0112 = $78;
     break;
    }
    default: {
     $$0110 = $42;$$0111 = $44;$$0112 = $45;
    }
    }
    $83 = $$0110 << 16;
    $84 = $$0111 << 8;
    $85 = $84 | $$0112;
    $86 = $85 | $83;
    HEAP32[$$0108121>>2] = $86;
    $87 = ((($$0109120)) + 4|0);
    $88 = ((($$0108121)) + 4|0);
    $89 = ($32|0)==(0);
    if ($89) {
     break;
    } else {
     $$0108121 = $88;$$0109120 = $87;$$in = $32;
    }
   }
   $$pre126 = HEAP32[$15>>2]|0;
   $97 = $$pre126;
  }
  $90 = HEAP32[$21>>2]|0;
  $91 = (($92) + ($90)|0);
  $93 = HEAP32[$22>>2]|0;
  $94 = (($95) + ($93)|0);
  $96 = (($97) + -1)|0;
  HEAP32[$15>>2] = $96;
  $98 = ($97|0)==(0);
  if ($98) {
   break;
  } else {
   $100 = $94;$101 = $91;$92 = $91;$95 = $94;$99 = $96;
  }
 }
 HEAP32[$0>>2] = $91;
 HEAP32[$19>>2] = $94;
 return;
}
function _SDL_Blit_RGBA8888_BGR888_Modulate_Blend_Scale($0) {
 $0 = $0|0;
 var $$ = 0, $$0135169 = 0, $$0136168 = 0, $$0138 = 0, $$0140 = 0, $$0142167 = 0, $$0144173 = 0, $$0146166 = 0, $$0149172 = 0, $$0151 = 0, $$0152 = 0, $$0153 = 0, $$0154 = 0, $$0155 = 0, $$1 = 0, $$1137 = 0, $$1139 = 0, $$1141 = 0, $$1145$lcssa = 0, $$1150$lcssa = 0;
 var $$1156 = 0, $$2 = 0, $$2148 = 0, $$3 = 0, $$in = 0, $$pre = 0, $$pre180 = 0, $$pre181 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $trunc = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = ((($0)) + 61|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = ((($0)) + 62|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = ((($0)) + 63|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = $13&255;
 $15 = ((($0)) + 8|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $16 << 16;
 $18 = ((($0)) + 28|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($17|0) / ($19|0))&-1;
 $21 = ((($0)) + 4|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = $22 << 16;
 $24 = ((($0)) + 24|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($23|0) / ($25|0))&-1;
 $27 = (($19) + -1)|0;
 HEAP32[$18>>2] = $27;
 $28 = ($19|0)==(0);
 if ($28) {
  return;
 }
 $29 = ((($0)) + 20|0);
 $30 = ((($0)) + 32|0);
 $31 = $2 & 1;
 $32 = ($31|0)==(0);
 $33 = $2 & 2;
 $34 = ($33|0)==(0);
 $35 = $2 & 48;
 $36 = ($35|0)!=(0);
 $37 = $2 & 112;
 $trunc = $37&255;
 $38 = ((($0)) + 12|0);
 $$pre = HEAP32[$29>>2]|0;
 $$0144173 = 0;$$0149172 = 0;$121 = $$pre;$126 = $27;$127 = $$pre;$46 = $25;
 while(1) {
  $39 = ($$0144173|0)>(65535);
  if ($39) {
   $40 = (($$0144173) + -65536)|0;
   $41 = $40 >>> 16;
   $42 = $41 << 16;
   $43 = (($$0149172) + 1)|0;
   $44 = (($43) + ($41))|0;
   $45 = (($40) - ($42))|0;
   $$1145$lcssa = $45;$$1150$lcssa = $44;
  } else {
   $$1145$lcssa = $$0144173;$$1150$lcssa = $$0149172;
  }
  $47 = ($46|0)==(0);
  if ($47) {
   $123 = $126;
  } else {
   $$0135169 = $127;$$0136168 = 0;$$0142167 = 65536;$$0146166 = -1;$$in = $46;
   while(1) {
    $48 = (($$in) + -1)|0;
    $49 = ($$0142167|0)>(65535);
    if ($49) {
     $50 = (($$0142167) + -65536)|0;
     $51 = $50 >>> 16;
     $52 = $51 << 16;
     $53 = (($$0146166) + 1)|0;
     $54 = (($53) + ($51))|0;
     $55 = (($50) - ($52))|0;
     $56 = HEAP32[$0>>2]|0;
     $57 = HEAP32[$38>>2]|0;
     $58 = Math_imul($57, $$1150$lcssa)|0;
     $59 = (($56) + ($58)|0);
     $60 = $54 << 2;
     $61 = (($59) + ($60)|0);
     $$1137 = $61;$$2 = $55;$$2148 = $54;
    } else {
     $$1137 = $$0136168;$$2 = $$0142167;$$2148 = $$0146166;
    }
    $62 = HEAP32[$$1137>>2]|0;
    $63 = $62 >>> 24;
    $64 = $62 >>> 16;
    $65 = $64 & 255;
    $66 = $62 >>> 8;
    $67 = $66 & 255;
    $68 = $62 & 255;
    $69 = HEAP32[$$0135169>>2]|0;
    $70 = $69 >>> 16;
    $71 = $70 & 255;
    $72 = $69 >>> 8;
    $73 = $72 & 255;
    $74 = $69 & 255;
    if ($32) {
     $$0138 = $63;$$0140 = $65;$$0155 = $67;
    } else {
     $75 = Math_imul($67, $11)|0;
     $76 = Math_imul($65, $8)|0;
     $77 = Math_imul($63, $5)|0;
     $78 = (($77>>>0) / 255)&-1;
     $79 = (($76>>>0) / 255)&-1;
     $80 = (($75>>>0) / 255)&-1;
     $$0138 = $78;$$0140 = $79;$$0155 = $80;
    }
    $81 = Math_imul($68, $14)|0;
    $82 = (($81>>>0) / 255)&-1;
    $$0154 = $34 ? $68 : $82;
    $83 = ($$0154>>>0)<(255);
    $or$cond = $36 & $83;
    if ($or$cond) {
     $84 = Math_imul($$0155, $$0154)|0;
     $85 = Math_imul($$0140, $$0154)|0;
     $86 = Math_imul($$0138, $$0154)|0;
     $87 = (($86>>>0) / 255)&-1;
     $88 = (($85>>>0) / 255)&-1;
     $89 = (($84>>>0) / 255)&-1;
     $$1139 = $87;$$1141 = $88;$$1156 = $89;
    } else {
     $$1139 = $$0138;$$1141 = $$0140;$$1156 = $$0155;
    }
    $trunc$clear = $trunc & 127;
    switch ($trunc$clear<<24>>24) {
    case 16:  {
     $90 = (255 - ($$0154))|0;
     $91 = Math_imul($90, $74)|0;
     $92 = (($91>>>0) / 255)&-1;
     $93 = (($$1139) + ($92))|0;
     $94 = Math_imul($90, $73)|0;
     $95 = (($94>>>0) / 255)&-1;
     $96 = (($$1141) + ($95))|0;
     $97 = Math_imul($90, $71)|0;
     $98 = (($97>>>0) / 255)&-1;
     $99 = (($$1156) + ($98))|0;
     $$0151 = $99;$$0152 = $96;$$0153 = $93;
     break;
    }
    case 32:  {
     $100 = (($$1139) + ($74))|0;
     $101 = ($100>>>0)<(255);
     $$ = $101 ? $100 : 255;
     $102 = (($$1141) + ($73))|0;
     $103 = ($102>>>0)<(255);
     $$3 = $103 ? $102 : 255;
     $104 = (($$1156) + ($71))|0;
     $105 = ($104>>>0)<(255);
     $$1 = $105 ? $104 : 255;
     $$0151 = $$1;$$0152 = $$3;$$0153 = $$;
     break;
    }
    case 64:  {
     $106 = Math_imul($$1139, $74)|0;
     $107 = (($106>>>0) / 255)&-1;
     $108 = Math_imul($$1141, $73)|0;
     $109 = (($108>>>0) / 255)&-1;
     $110 = Math_imul($$1156, $71)|0;
     $111 = (($110>>>0) / 255)&-1;
     $$0151 = $111;$$0152 = $109;$$0153 = $107;
     break;
    }
    default: {
     $$0151 = $71;$$0152 = $73;$$0153 = $74;
    }
    }
    $112 = $$0151 << 16;
    $113 = $$0152 << 8;
    $114 = $113 | $$0153;
    $115 = $114 | $112;
    HEAP32[$$0135169>>2] = $115;
    $116 = (($$2) + ($26))|0;
    $117 = ((($$0135169)) + 4|0);
    $118 = ($48|0)==(0);
    if ($118) {
     break;
    } else {
     $$0135169 = $117;$$0136168 = $$1137;$$0142167 = $116;$$0146166 = $$2148;$$in = $48;
    }
   }
   $$pre181 = HEAP32[$18>>2]|0;
   $123 = $$pre181;
  }
  $119 = HEAP32[$30>>2]|0;
  $120 = (($121) + ($119)|0);
  $122 = (($123) + -1)|0;
  HEAP32[$18>>2] = $122;
  $124 = ($123|0)==(0);
  if ($124) {
   break;
  }
  $125 = (($$1145$lcssa) + ($20))|0;
  $$pre180 = HEAP32[$24>>2]|0;
  $$0144173 = $125;$$0149172 = $$1150$lcssa;$121 = $120;$126 = $122;$127 = $120;$46 = $$pre180;
 }
 HEAP32[$29>>2] = $120;
 return;
}
function _SDL_Blit_RGBA8888_ARGB8888_Scale($0) {
 $0 = $0|0;
 var $$06386 = 0, $$06485 = 0, $$06590 = 0, $$06784 = 0, $$06983 = 0, $$07289 = 0, $$1 = 0, $$166$lcssa = 0, $$173$lcssa = 0, $$2 = 0, $$271 = 0, $$in = 0, $$pre = 0, $$pre97 = 0, $$pre98 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 << 16;
 $4 = ((($0)) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3|0) / ($5|0))&-1;
 $7 = ((($0)) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 << 16;
 $10 = ((($0)) + 24|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($9|0) / ($11|0))&-1;
 $13 = (($5) + -1)|0;
 HEAP32[$4>>2] = $13;
 $14 = ($5|0)==(0);
 if ($14) {
  return;
 }
 $15 = ((($0)) + 20|0);
 $16 = ((($0)) + 32|0);
 $17 = ((($0)) + 12|0);
 $$pre = HEAP32[$15>>2]|0;
 $$06590 = 0;$$07289 = 0;$25 = $11;$56 = $$pre;$61 = $13;$62 = $$pre;
 while(1) {
  $18 = ($$07289|0)>(65535);
  if ($18) {
   $19 = (($$07289) + -65536)|0;
   $20 = $19 >>> 16;
   $21 = $20 << 16;
   $22 = (($$06590) + 1)|0;
   $23 = (($22) + ($20))|0;
   $24 = (($19) - ($21))|0;
   $$166$lcssa = $23;$$173$lcssa = $24;
  } else {
   $$166$lcssa = $$06590;$$173$lcssa = $$07289;
  }
  $26 = ($25|0)==(0);
  if ($26) {
   $58 = $61;
  } else {
   $$06386 = $62;$$06485 = 0;$$06784 = -1;$$06983 = 65536;$$in = $25;
   while(1) {
    $27 = (($$in) + -1)|0;
    $28 = ($$06983|0)>(65535);
    if ($28) {
     $29 = (($$06983) + -65536)|0;
     $30 = $29 >>> 16;
     $31 = $30 << 16;
     $32 = (($$06784) + 1)|0;
     $33 = (($32) + ($30))|0;
     $34 = (($29) - ($31))|0;
     $35 = HEAP32[$0>>2]|0;
     $36 = HEAP32[$17>>2]|0;
     $37 = Math_imul($36, $$166$lcssa)|0;
     $38 = (($35) + ($37)|0);
     $39 = $33 << 2;
     $40 = (($38) + ($39)|0);
     $$1 = $40;$$2 = $33;$$271 = $34;
    } else {
     $$1 = $$06485;$$2 = $$06784;$$271 = $$06983;
    }
    $41 = HEAP32[$$1>>2]|0;
    $42 = $41 >>> 24;
    $43 = $41 >>> 8;
    $44 = $43 & 255;
    $45 = $41 << 24;
    $46 = $42 << 16;
    $47 = $46 | $45;
    $48 = $43 & 65280;
    $49 = $47 | $48;
    $50 = $49 | $44;
    HEAP32[$$06386>>2] = $50;
    $51 = (($$271) + ($12))|0;
    $52 = ((($$06386)) + 4|0);
    $53 = ($27|0)==(0);
    if ($53) {
     break;
    } else {
     $$06386 = $52;$$06485 = $$1;$$06784 = $$2;$$06983 = $51;$$in = $27;
    }
   }
   $$pre98 = HEAP32[$4>>2]|0;
   $58 = $$pre98;
  }
  $54 = HEAP32[$16>>2]|0;
  $55 = (($56) + ($54)|0);
  $57 = (($58) + -1)|0;
  HEAP32[$4>>2] = $57;
  $59 = ($58|0)==(0);
  if ($59) {
   break;
  }
  $60 = (($$173$lcssa) + ($6))|0;
  $$pre97 = HEAP32[$10>>2]|0;
  $$06590 = $$166$lcssa;$$07289 = $60;$25 = $$pre97;$56 = $55;$61 = $57;$62 = $55;
 }
 HEAP32[$15>>2] = $55;
 return;
}
function _SDL_Blit_RGBA8888_ARGB8888_Blend($0) {
 $0 = $0|0;
 var $$ = 0, $$$us = 0, $$0100$us = 0, $$0101$us = 0, $$093103 = 0, $$093103$us = 0, $$094102 = 0, $$094102$us = 0, $$095 = 0, $$095$us = 0, $$096 = 0, $$096$us = 0, $$097 = 0, $$097$us = 0, $$098 = 0, $$098$us = 0, $$099$us = 0, $$1 = 0, $$1$us = 0, $$3 = 0;
 var $$3$us = 0, $$pre = 0, $$pre108 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $trunc = 0, $trunc$clear = 0, $trunc$clear1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + -1)|0;
 HEAP32[$3>>2] = $5;
 $6 = ($4|0)==(0);
 if ($6) {
  return;
 }
 $7 = ((($0)) + 20|0);
 $8 = ((($0)) + 24|0);
 $9 = ((($0)) + 12|0);
 $10 = ((($0)) + 32|0);
 $11 = $2 & 48;
 $12 = ($11|0)==(0);
 $13 = $2 & 112;
 $trunc = $13&255;
 $$pre = HEAP32[$0>>2]|0;
 $$pre108 = HEAP32[$7>>2]|0;
 $126 = $$pre;$129 = $$pre108;$133 = $$pre108;$134 = $$pre;
 while(1) {
  $14 = HEAP32[$8>>2]|0;
  $15 = (($14) + -1)|0;
  $16 = ($14|0)==(0);
  L6: do {
   if (!($16)) {
    if ($12) {
     $$093103 = $133;$$094102 = $134;$122 = $15;
     while(1) {
      $74 = HEAP32[$$094102>>2]|0;
      $75 = $74 >>> 24;
      $76 = $74 >>> 16;
      $77 = $76 & 255;
      $78 = $74 >>> 8;
      $79 = $78 & 255;
      $80 = $74 & 255;
      $81 = HEAP32[$$093103>>2]|0;
      $82 = $81 >>> 16;
      $83 = $82 & 255;
      $84 = $81 >>> 8;
      $85 = $84 & 255;
      $86 = $81 & 255;
      $87 = $81 >>> 24;
      $trunc$clear1 = $trunc & 127;
      switch ($trunc$clear1<<24>>24) {
      case 16:  {
       $88 = $80 ^ 255;
       $89 = Math_imul($83, $88)|0;
       $90 = (($89>>>0) / 255)&-1;
       $91 = (($75) + ($90))|0;
       $92 = Math_imul($85, $88)|0;
       $93 = (($92>>>0) / 255)&-1;
       $94 = (($77) + ($93))|0;
       $95 = Math_imul($88, $86)|0;
       $96 = (($95>>>0) / 255)&-1;
       $97 = (($79) + ($96))|0;
       $98 = Math_imul($88, $87)|0;
       $99 = (($98>>>0) / 255)&-1;
       $100 = (($99) + ($80))|0;
       $$095 = $100;$$096 = $97;$$097 = $94;$$098 = $91;
       break;
      }
      case 32:  {
       $101 = (($75) + ($83))|0;
       $102 = ($101>>>0)<(255);
       $$ = $102 ? $101 : 255;
       $103 = (($77) + ($85))|0;
       $104 = ($103>>>0)<(255);
       $$3 = $104 ? $103 : 255;
       $105 = (($79) + ($86))|0;
       $106 = ($105>>>0)<(255);
       $$1 = $106 ? $105 : 255;
       $$095 = $87;$$096 = $$1;$$097 = $$3;$$098 = $$;
       break;
      }
      case 64:  {
       $107 = Math_imul($75, $83)|0;
       $108 = (($107>>>0) / 255)&-1;
       $109 = Math_imul($77, $85)|0;
       $110 = (($109>>>0) / 255)&-1;
       $111 = Math_imul($79, $86)|0;
       $112 = (($111>>>0) / 255)&-1;
       $$095 = $87;$$096 = $112;$$097 = $110;$$098 = $108;
       break;
      }
      default: {
       $$095 = $87;$$096 = $86;$$097 = $85;$$098 = $83;
      }
      }
      $113 = $$095 << 24;
      $114 = $$098 << 16;
      $115 = $$097 << 8;
      $116 = $115 | $114;
      $117 = $116 | $$096;
      $118 = $117 | $113;
      HEAP32[$$093103>>2] = $118;
      $119 = ((($$094102)) + 4|0);
      $120 = ((($$093103)) + 4|0);
      $121 = (($122) + -1)|0;
      $123 = ($122|0)==(0);
      if ($123) {
       break L6;
      } else {
       $$093103 = $120;$$094102 = $119;$122 = $121;
      }
     }
    } else {
     $$093103$us = $133;$$094102$us = $134;$72 = $15;
    }
    while(1) {
     $17 = HEAP32[$$094102$us>>2]|0;
     $18 = $17 >>> 24;
     $19 = $17 >>> 16;
     $20 = $19 & 255;
     $21 = $17 >>> 8;
     $22 = $21 & 255;
     $23 = $17 & 255;
     $24 = HEAP32[$$093103$us>>2]|0;
     $25 = $24 >>> 16;
     $26 = $25 & 255;
     $27 = $24 >>> 8;
     $28 = $27 & 255;
     $29 = $24 & 255;
     $30 = $24 >>> 24;
     $31 = ($23|0)==(255);
     if ($31) {
      $$0100$us = $22;$$0101$us = $20;$$099$us = $18;
     } else {
      $32 = Math_imul($22, $23)|0;
      $33 = Math_imul($20, $23)|0;
      $34 = Math_imul($18, $23)|0;
      $35 = (($34>>>0) / 255)&-1;
      $36 = (($33>>>0) / 255)&-1;
      $37 = (($32>>>0) / 255)&-1;
      $$0100$us = $37;$$0101$us = $36;$$099$us = $35;
     }
     $trunc$clear = $trunc & 127;
     switch ($trunc$clear<<24>>24) {
     case 16:  {
      $50 = $23 ^ 255;
      $51 = Math_imul($26, $50)|0;
      $52 = (($51>>>0) / 255)&-1;
      $53 = (($$099$us) + ($52))|0;
      $54 = Math_imul($28, $50)|0;
      $55 = (($54>>>0) / 255)&-1;
      $56 = (($$0101$us) + ($55))|0;
      $57 = Math_imul($50, $29)|0;
      $58 = (($57>>>0) / 255)&-1;
      $59 = (($$0100$us) + ($58))|0;
      $60 = Math_imul($50, $30)|0;
      $61 = (($60>>>0) / 255)&-1;
      $62 = (($61) + ($23))|0;
      $$095$us = $62;$$096$us = $59;$$097$us = $56;$$098$us = $53;
      break;
     }
     case 32:  {
      $44 = (($$099$us) + ($26))|0;
      $45 = ($44>>>0)<(255);
      $$$us = $45 ? $44 : 255;
      $46 = (($$0101$us) + ($28))|0;
      $47 = ($46>>>0)<(255);
      $$3$us = $47 ? $46 : 255;
      $48 = (($$0100$us) + ($29))|0;
      $49 = ($48>>>0)<(255);
      $$1$us = $49 ? $48 : 255;
      $$095$us = $30;$$096$us = $$1$us;$$097$us = $$3$us;$$098$us = $$$us;
      break;
     }
     case 64:  {
      $38 = Math_imul($$099$us, $26)|0;
      $39 = (($38>>>0) / 255)&-1;
      $40 = Math_imul($$0101$us, $28)|0;
      $41 = (($40>>>0) / 255)&-1;
      $42 = Math_imul($$0100$us, $29)|0;
      $43 = (($42>>>0) / 255)&-1;
      $$095$us = $30;$$096$us = $43;$$097$us = $41;$$098$us = $39;
      break;
     }
     default: {
      $$095$us = $30;$$096$us = $29;$$097$us = $28;$$098$us = $26;
     }
     }
     $63 = $$095$us << 24;
     $64 = $$098$us << 16;
     $65 = $$097$us << 8;
     $66 = $65 | $64;
     $67 = $66 | $$096$us;
     $68 = $67 | $63;
     HEAP32[$$093103$us>>2] = $68;
     $69 = ((($$094102$us)) + 4|0);
     $70 = ((($$093103$us)) + 4|0);
     $71 = (($72) + -1)|0;
     $73 = ($72|0)==(0);
     if ($73) {
      break L6;
     } else {
      $$093103$us = $70;$$094102$us = $69;$72 = $71;
     }
    }
   }
  } while(0);
  $124 = HEAP32[$9>>2]|0;
  $125 = (($126) + ($124)|0);
  $127 = HEAP32[$10>>2]|0;
  $128 = (($129) + ($127)|0);
  $130 = HEAP32[$3>>2]|0;
  $131 = (($130) + -1)|0;
  HEAP32[$3>>2] = $131;
  $132 = ($130|0)==(0);
  if ($132) {
   break;
  } else {
   $126 = $125;$129 = $128;$133 = $128;$134 = $125;
  }
 }
 HEAP32[$0>>2] = $125;
 HEAP32[$7>>2] = $128;
 return;
}
function _SDL_Blit_RGBA8888_ARGB8888_Blend_Scale($0) {
 $0 = $0|0;
 var $$ = 0, $$0120151 = 0, $$0121150 = 0, $$0123 = 0, $$0124 = 0, $$0125149 = 0, $$0127155 = 0, $$0129148 = 0, $$0132154 = 0, $$0134 = 0, $$0135 = 0, $$0136 = 0, $$0137 = 0, $$0138 = 0, $$1 = 0, $$1122 = 0, $$1128$lcssa = 0, $$1133$lcssa = 0, $$2 = 0, $$2131 = 0;
 var $$3 = 0, $$in = 0, $$pre = 0, $$pre162 = 0, $$pre163 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $trunc = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 << 16;
 $6 = ((($0)) + 28|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5|0) / ($7|0))&-1;
 $9 = ((($0)) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10 << 16;
 $12 = ((($0)) + 24|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($11|0) / ($13|0))&-1;
 $15 = (($7) + -1)|0;
 HEAP32[$6>>2] = $15;
 $16 = ($7|0)==(0);
 if ($16) {
  return;
 }
 $17 = ((($0)) + 20|0);
 $18 = ((($0)) + 32|0);
 $19 = $2 & 48;
 $20 = ($19|0)!=(0);
 $21 = $2 & 112;
 $trunc = $21&255;
 $22 = ((($0)) + 12|0);
 $$pre = HEAP32[$17>>2]|0;
 $$0127155 = 0;$$0132154 = 0;$103 = $$pre;$108 = $15;$109 = $$pre;$30 = $13;
 while(1) {
  $23 = ($$0127155|0)>(65535);
  if ($23) {
   $24 = (($$0127155) + -65536)|0;
   $25 = $24 >>> 16;
   $26 = $25 << 16;
   $27 = (($$0132154) + 1)|0;
   $28 = (($27) + ($25))|0;
   $29 = (($24) - ($26))|0;
   $$1128$lcssa = $29;$$1133$lcssa = $28;
  } else {
   $$1128$lcssa = $$0127155;$$1133$lcssa = $$0132154;
  }
  $31 = ($30|0)==(0);
  if ($31) {
   $105 = $108;
  } else {
   $$0120151 = $109;$$0121150 = 0;$$0125149 = 65536;$$0129148 = -1;$$in = $30;
   while(1) {
    $32 = (($$in) + -1)|0;
    $33 = ($$0125149|0)>(65535);
    if ($33) {
     $34 = (($$0125149) + -65536)|0;
     $35 = $34 >>> 16;
     $36 = $35 << 16;
     $37 = (($$0129148) + 1)|0;
     $38 = (($37) + ($35))|0;
     $39 = (($34) - ($36))|0;
     $40 = HEAP32[$0>>2]|0;
     $41 = HEAP32[$22>>2]|0;
     $42 = Math_imul($41, $$1133$lcssa)|0;
     $43 = (($40) + ($42)|0);
     $44 = $38 << 2;
     $45 = (($43) + ($44)|0);
     $$1122 = $45;$$2 = $39;$$2131 = $38;
    } else {
     $$1122 = $$0121150;$$2 = $$0125149;$$2131 = $$0129148;
    }
    $46 = HEAP32[$$1122>>2]|0;
    $47 = $46 >>> 24;
    $48 = $46 >>> 16;
    $49 = $48 & 255;
    $50 = $46 >>> 8;
    $51 = $50 & 255;
    $52 = $46 & 255;
    $53 = HEAP32[$$0120151>>2]|0;
    $54 = $53 >>> 16;
    $55 = $54 & 255;
    $56 = $53 >>> 8;
    $57 = $56 & 255;
    $58 = $53 & 255;
    $59 = $53 >>> 24;
    $60 = ($52|0)!=(255);
    $or$cond = $20 & $60;
    if ($or$cond) {
     $61 = Math_imul($51, $52)|0;
     $62 = Math_imul($49, $52)|0;
     $63 = Math_imul($47, $52)|0;
     $64 = (($63>>>0) / 255)&-1;
     $65 = (($62>>>0) / 255)&-1;
     $66 = (($61>>>0) / 255)&-1;
     $$0123 = $64;$$0124 = $65;$$0138 = $66;
    } else {
     $$0123 = $47;$$0124 = $49;$$0138 = $51;
    }
    $trunc$clear = $trunc & 127;
    switch ($trunc$clear<<24>>24) {
    case 16:  {
     $67 = $52 ^ 255;
     $68 = Math_imul($55, $67)|0;
     $69 = (($68>>>0) / 255)&-1;
     $70 = (($$0123) + ($69))|0;
     $71 = Math_imul($57, $67)|0;
     $72 = (($71>>>0) / 255)&-1;
     $73 = (($$0124) + ($72))|0;
     $74 = Math_imul($67, $58)|0;
     $75 = (($74>>>0) / 255)&-1;
     $76 = (($$0138) + ($75))|0;
     $77 = Math_imul($67, $59)|0;
     $78 = (($77>>>0) / 255)&-1;
     $79 = (($78) + ($52))|0;
     $$0134 = $79;$$0135 = $76;$$0136 = $73;$$0137 = $70;
     break;
    }
    case 32:  {
     $80 = (($$0123) + ($55))|0;
     $81 = ($80>>>0)<(255);
     $$ = $81 ? $80 : 255;
     $82 = (($$0124) + ($57))|0;
     $83 = ($82>>>0)<(255);
     $$3 = $83 ? $82 : 255;
     $84 = (($$0138) + ($58))|0;
     $85 = ($84>>>0)<(255);
     $$1 = $85 ? $84 : 255;
     $$0134 = $59;$$0135 = $$1;$$0136 = $$3;$$0137 = $$;
     break;
    }
    case 64:  {
     $86 = Math_imul($$0123, $55)|0;
     $87 = (($86>>>0) / 255)&-1;
     $88 = Math_imul($$0124, $57)|0;
     $89 = (($88>>>0) / 255)&-1;
     $90 = Math_imul($$0138, $58)|0;
     $91 = (($90>>>0) / 255)&-1;
     $$0134 = $59;$$0135 = $91;$$0136 = $89;$$0137 = $87;
     break;
    }
    default: {
     $$0134 = $59;$$0135 = $58;$$0136 = $57;$$0137 = $55;
    }
    }
    $92 = $$0134 << 24;
    $93 = $$0137 << 16;
    $94 = $$0136 << 8;
    $95 = $94 | $93;
    $96 = $95 | $$0135;
    $97 = $96 | $92;
    HEAP32[$$0120151>>2] = $97;
    $98 = (($$2) + ($14))|0;
    $99 = ((($$0120151)) + 4|0);
    $100 = ($32|0)==(0);
    if ($100) {
     break;
    } else {
     $$0120151 = $99;$$0121150 = $$1122;$$0125149 = $98;$$0129148 = $$2131;$$in = $32;
    }
   }
   $$pre163 = HEAP32[$6>>2]|0;
   $105 = $$pre163;
  }
  $101 = HEAP32[$18>>2]|0;
  $102 = (($103) + ($101)|0);
  $104 = (($105) + -1)|0;
  HEAP32[$6>>2] = $104;
  $106 = ($105|0)==(0);
  if ($106) {
   break;
  }
  $107 = (($$1128$lcssa) + ($8))|0;
  $$pre162 = HEAP32[$12>>2]|0;
  $$0127155 = $107;$$0132154 = $$1133$lcssa;$103 = $102;$108 = $104;$109 = $102;$30 = $$pre162;
 }
 HEAP32[$17>>2] = $102;
 return;
}
function _SDL_Blit_RGBA8888_ARGB8888_Modulate($0) {
 $0 = $0|0;
 var $$06168 = 0, $$06168$us = 0, $$06267 = 0, $$06267$us = 0, $$063 = 0, $$063$us = 0, $$pre = 0, $$pre73 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = ((($0)) + 61|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = ((($0)) + 62|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = ((($0)) + 63|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = $13&255;
 $15 = ((($0)) + 28|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + -1)|0;
 HEAP32[$15>>2] = $17;
 $18 = ($16|0)==(0);
 if ($18) {
  return;
 }
 $19 = ((($0)) + 20|0);
 $20 = ((($0)) + 24|0);
 $21 = ((($0)) + 12|0);
 $22 = ((($0)) + 32|0);
 $23 = $2 & 1;
 $24 = ($23|0)==(0);
 $25 = $2 & 2;
 $26 = ($25|0)==(0);
 $$pre = HEAP32[$0>>2]|0;
 $$pre73 = HEAP32[$19>>2]|0;
 $76 = $$pre;$79 = $$pre73;$83 = $$pre73;$84 = $$pre;
 while(1) {
  $27 = HEAP32[$20>>2]|0;
  $28 = (($27) + -1)|0;
  $29 = ($27|0)==(0);
  if (!($29)) {
   if ($24) {
    $$06168$us = $83;$$06267$us = $84;$46 = $28;
    while(1) {
     $30 = HEAP32[$$06267$us>>2]|0;
     $31 = $30 >>> 24;
     $32 = $30 >>> 8;
     $33 = $32 & 255;
     $34 = $30 & 255;
     $35 = Math_imul($34, $14)|0;
     $36 = (($35>>>0) / 255)&-1;
     $$063$us = $26 ? $30 : $36;
     $37 = $$063$us << 24;
     $38 = $31 << 16;
     $39 = $38 | $37;
     $40 = $32 & 65280;
     $41 = $39 | $40;
     $42 = $41 | $33;
     HEAP32[$$06168$us>>2] = $42;
     $43 = ((($$06267$us)) + 4|0);
     $44 = ((($$06168$us)) + 4|0);
     $45 = (($46) + -1)|0;
     $47 = ($46|0)==(0);
     if ($47) {
      break;
     } else {
      $$06168$us = $44;$$06267$us = $43;$46 = $45;
     }
    }
   } else {
    $$06168 = $83;$$06267 = $84;$72 = $28;
    while(1) {
     $48 = HEAP32[$$06267>>2]|0;
     $49 = $48 >>> 24;
     $50 = $48 >>> 16;
     $51 = $50 & 255;
     $52 = $48 >>> 8;
     $53 = $52 & 255;
     $54 = $48 & 255;
     $55 = Math_imul($53, $11)|0;
     $56 = Math_imul($51, $8)|0;
     $57 = Math_imul($49, $5)|0;
     $58 = (($57>>>0) / 255)&-1;
     $59 = (($56>>>0) / 255)&-1;
     $60 = (($55>>>0) / 255)&-1;
     $61 = Math_imul($54, $14)|0;
     $62 = (($61>>>0) / 255)&-1;
     $$063 = $26 ? $48 : $62;
     $63 = $$063 << 24;
     $64 = $58 << 16;
     $65 = $64 | $63;
     $66 = $59 << 8;
     $67 = $65 | $66;
     $68 = $67 | $60;
     HEAP32[$$06168>>2] = $68;
     $69 = ((($$06267)) + 4|0);
     $70 = ((($$06168)) + 4|0);
     $71 = (($72) + -1)|0;
     $73 = ($72|0)==(0);
     if ($73) {
      break;
     } else {
      $$06168 = $70;$$06267 = $69;$72 = $71;
     }
    }
   }
  }
  $74 = HEAP32[$21>>2]|0;
  $75 = (($76) + ($74)|0);
  $77 = HEAP32[$22>>2]|0;
  $78 = (($79) + ($77)|0);
  $80 = HEAP32[$15>>2]|0;
  $81 = (($80) + -1)|0;
  HEAP32[$15>>2] = $81;
  $82 = ($80|0)==(0);
  if ($82) {
   break;
  } else {
   $76 = $75;$79 = $78;$83 = $78;$84 = $75;
  }
 }
 HEAP32[$0>>2] = $75;
 HEAP32[$19>>2] = $78;
 return;
}
function _SDL_Blit_RGBA8888_ARGB8888_Modulate_Scale($0) {
 $0 = $0|0;
 var $$0100 = 0, $$0100$us = 0, $$088115 = 0, $$088115$us = 0, $$089114 = 0, $$089114$us = 0, $$091113 = 0, $$091113$us = 0, $$093119 = 0, $$095112 = 0, $$095112$us = 0, $$098118 = 0, $$1 = 0, $$1$us = 0, $$194$lcssa = 0, $$199$lcssa = 0, $$2 = 0, $$2$us = 0, $$297 = 0, $$297$us = 0;
 var $$pre = 0, $$pre129 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = ((($0)) + 61|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = ((($0)) + 62|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = ((($0)) + 63|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = $13&255;
 $15 = ((($0)) + 8|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $16 << 16;
 $18 = ((($0)) + 28|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($17|0) / ($19|0))&-1;
 $21 = ((($0)) + 4|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = $22 << 16;
 $24 = ((($0)) + 24|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($23|0) / ($25|0))&-1;
 $27 = (($19) + -1)|0;
 HEAP32[$18>>2] = $27;
 $28 = ($19|0)==(0);
 if ($28) {
  return;
 }
 $29 = ((($0)) + 20|0);
 $30 = ((($0)) + 32|0);
 $31 = $2 & 1;
 $32 = ($31|0)==(0);
 $33 = $2 & 2;
 $34 = ($33|0)==(0);
 $35 = ((($0)) + 12|0);
 $$pre = HEAP32[$29>>2]|0;
 $$093119 = 0;$$098118 = 0;$118 = $$pre;$123 = $$pre;$44 = $25;
 while(1) {
  $36 = ($$093119|0)>(65535);
  if ($36) {
   $37 = (($$093119) + -65536)|0;
   $38 = $37 >>> 16;
   $39 = $38 << 16;
   $40 = (($$098118) + 1)|0;
   $41 = (($40) + ($38))|0;
   $42 = (($37) - ($39))|0;
   $$194$lcssa = $42;$$199$lcssa = $41;
  } else {
   $$194$lcssa = $$093119;$$199$lcssa = $$098118;
  }
  $43 = (($44) + -1)|0;
  $45 = ($44|0)==(0);
  if (!($45)) {
   if ($32) {
    $$088115$us = $123;$$089114$us = 0;$$091113$us = 65536;$$095112$us = -1;$75 = $43;
    while(1) {
     $46 = ($$091113$us|0)>(65535);
     if ($46) {
      $47 = (($$091113$us) + -65536)|0;
      $48 = $47 >>> 16;
      $49 = $48 << 16;
      $50 = (($$095112$us) + 1)|0;
      $51 = (($50) + ($48))|0;
      $52 = (($47) - ($49))|0;
      $53 = HEAP32[$0>>2]|0;
      $54 = HEAP32[$35>>2]|0;
      $55 = Math_imul($54, $$199$lcssa)|0;
      $56 = (($53) + ($55)|0);
      $57 = $51 << 2;
      $58 = (($56) + ($57)|0);
      $$1$us = $58;$$2$us = $52;$$297$us = $51;
     } else {
      $$1$us = $$089114$us;$$2$us = $$091113$us;$$297$us = $$095112$us;
     }
     $59 = HEAP32[$$1$us>>2]|0;
     $60 = $59 >>> 24;
     $61 = $59 >>> 8;
     $62 = $61 & 255;
     $63 = $59 & 255;
     $64 = Math_imul($63, $14)|0;
     $65 = (($64>>>0) / 255)&-1;
     $$0100$us = $34 ? $59 : $65;
     $66 = $$0100$us << 24;
     $67 = $60 << 16;
     $68 = $61 & 65280;
     $69 = $68 | $66;
     $70 = $69 | $62;
     $71 = $70 | $67;
     HEAP32[$$088115$us>>2] = $71;
     $72 = (($$2$us) + ($26))|0;
     $73 = ((($$088115$us)) + 4|0);
     $74 = (($75) + -1)|0;
     $76 = ($75|0)==(0);
     if ($76) {
      break;
     } else {
      $$088115$us = $73;$$089114$us = $$1$us;$$091113$us = $72;$$095112$us = $$297$us;$75 = $74;
     }
    }
   } else {
    $$088115 = $123;$$089114 = 0;$$091113 = 65536;$$095112 = -1;$114 = $43;
    while(1) {
     $77 = ($$091113|0)>(65535);
     if ($77) {
      $78 = (($$091113) + -65536)|0;
      $79 = $78 >>> 16;
      $80 = $79 << 16;
      $81 = (($$095112) + 1)|0;
      $82 = (($81) + ($79))|0;
      $83 = (($78) - ($80))|0;
      $84 = HEAP32[$0>>2]|0;
      $85 = HEAP32[$35>>2]|0;
      $86 = Math_imul($85, $$199$lcssa)|0;
      $87 = (($84) + ($86)|0);
      $88 = $82 << 2;
      $89 = (($87) + ($88)|0);
      $$1 = $89;$$2 = $83;$$297 = $82;
     } else {
      $$1 = $$089114;$$2 = $$091113;$$297 = $$095112;
     }
     $90 = HEAP32[$$1>>2]|0;
     $91 = $90 >>> 24;
     $92 = $90 >>> 16;
     $93 = $92 & 255;
     $94 = $90 >>> 8;
     $95 = $94 & 255;
     $96 = $90 & 255;
     $97 = Math_imul($95, $11)|0;
     $98 = Math_imul($93, $8)|0;
     $99 = Math_imul($91, $5)|0;
     $100 = (($99>>>0) / 255)&-1;
     $101 = (($98>>>0) / 255)&-1;
     $102 = (($97>>>0) / 255)&-1;
     $103 = Math_imul($96, $14)|0;
     $104 = (($103>>>0) / 255)&-1;
     $$0100 = $34 ? $90 : $104;
     $105 = $$0100 << 24;
     $106 = $100 << 16;
     $107 = $101 << 8;
     $108 = $107 | $105;
     $109 = $108 | $102;
     $110 = $109 | $106;
     HEAP32[$$088115>>2] = $110;
     $111 = (($$2) + ($26))|0;
     $112 = ((($$088115)) + 4|0);
     $113 = (($114) + -1)|0;
     $115 = ($114|0)==(0);
     if ($115) {
      break;
     } else {
      $$088115 = $112;$$089114 = $$1;$$091113 = $111;$$095112 = $$297;$114 = $113;
     }
    }
   }
  }
  $116 = HEAP32[$30>>2]|0;
  $117 = (($118) + ($116)|0);
  $119 = HEAP32[$18>>2]|0;
  $120 = (($119) + -1)|0;
  HEAP32[$18>>2] = $120;
  $121 = ($119|0)==(0);
  if ($121) {
   break;
  }
  $122 = (($$194$lcssa) + ($20))|0;
  $$pre129 = HEAP32[$24>>2]|0;
  $$093119 = $122;$$098118 = $$199$lcssa;$118 = $117;$123 = $117;$44 = $$pre129;
 }
 HEAP32[$29>>2] = $117;
 return;
}
function _SDL_Blit_RGBA8888_ARGB8888_Modulate_Blend($0) {
 $0 = $0|0;
 var $$ = 0, $$0115129 = 0, $$0116128 = 0, $$0117 = 0, $$0118 = 0, $$0119 = 0, $$0120 = 0, $$0121 = 0, $$0122 = 0, $$0124 = 0, $$0126 = 0, $$1 = 0, $$1123 = 0, $$1125 = 0, $$1127 = 0, $$3 = 0, $$in = 0, $$pre = 0, $$pre133 = 0, $$pre134 = 0;
 var $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $trunc = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = ((($0)) + 61|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = ((($0)) + 62|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = ((($0)) + 63|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = $13&255;
 $15 = ((($0)) + 28|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + -1)|0;
 HEAP32[$15>>2] = $17;
 $18 = ($16|0)==(0);
 if ($18) {
  return;
 }
 $19 = ((($0)) + 20|0);
 $20 = ((($0)) + 24|0);
 $21 = ((($0)) + 12|0);
 $22 = ((($0)) + 32|0);
 $23 = $2 & 1;
 $24 = ($23|0)==(0);
 $25 = $2 & 2;
 $26 = ($25|0)==(0);
 $27 = $2 & 48;
 $28 = ($27|0)!=(0);
 $29 = $2 & 112;
 $trunc = $29&255;
 $$pre = HEAP32[$0>>2]|0;
 $$pre133 = HEAP32[$19>>2]|0;
 $101 = $$pre133;$105 = $17;$106 = $$pre133;$107 = $$pre;$98 = $$pre;
 while(1) {
  $30 = HEAP32[$20>>2]|0;
  $31 = ($30|0)==(0);
  if ($31) {
   $103 = $105;
  } else {
   $$0115129 = $106;$$0116128 = $107;$$in = $30;
   while(1) {
    $32 = (($$in) + -1)|0;
    $33 = HEAP32[$$0116128>>2]|0;
    $34 = $33 >>> 24;
    $35 = $33 >>> 16;
    $36 = $35 & 255;
    $37 = $33 >>> 8;
    $38 = $37 & 255;
    $39 = $33 & 255;
    $40 = HEAP32[$$0115129>>2]|0;
    $41 = $40 >>> 16;
    $42 = $41 & 255;
    $43 = $40 >>> 8;
    $44 = $43 & 255;
    $45 = $40 & 255;
    $46 = $40 >>> 24;
    if ($24) {
     $$0122 = $38;$$0124 = $36;$$0126 = $34;
    } else {
     $47 = Math_imul($38, $11)|0;
     $48 = Math_imul($36, $8)|0;
     $49 = Math_imul($34, $5)|0;
     $50 = (($49>>>0) / 255)&-1;
     $51 = (($48>>>0) / 255)&-1;
     $52 = (($47>>>0) / 255)&-1;
     $$0122 = $52;$$0124 = $51;$$0126 = $50;
    }
    $53 = Math_imul($39, $14)|0;
    $54 = (($53>>>0) / 255)&-1;
    $$0121 = $26 ? $39 : $54;
    $55 = ($$0121>>>0)<(255);
    $or$cond = $28 & $55;
    if ($or$cond) {
     $56 = Math_imul($$0122, $$0121)|0;
     $57 = Math_imul($$0124, $$0121)|0;
     $58 = Math_imul($$0126, $$0121)|0;
     $59 = (($58>>>0) / 255)&-1;
     $60 = (($57>>>0) / 255)&-1;
     $61 = (($56>>>0) / 255)&-1;
     $$1123 = $61;$$1125 = $60;$$1127 = $59;
    } else {
     $$1123 = $$0122;$$1125 = $$0124;$$1127 = $$0126;
    }
    $trunc$clear = $trunc & 127;
    switch ($trunc$clear<<24>>24) {
    case 16:  {
     $62 = (255 - ($$0121))|0;
     $63 = Math_imul($62, $42)|0;
     $64 = (($63>>>0) / 255)&-1;
     $65 = (($$1127) + ($64))|0;
     $66 = Math_imul($62, $44)|0;
     $67 = (($66>>>0) / 255)&-1;
     $68 = (($$1125) + ($67))|0;
     $69 = Math_imul($62, $45)|0;
     $70 = (($69>>>0) / 255)&-1;
     $71 = (($$1123) + ($70))|0;
     $72 = Math_imul($62, $46)|0;
     $73 = (($72>>>0) / 255)&-1;
     $74 = (($73) + ($$0121))|0;
     $$0117 = $74;$$0118 = $71;$$0119 = $68;$$0120 = $65;
     break;
    }
    case 32:  {
     $75 = (($$1127) + ($42))|0;
     $76 = ($75>>>0)<(255);
     $$ = $76 ? $75 : 255;
     $77 = (($$1125) + ($44))|0;
     $78 = ($77>>>0)<(255);
     $$3 = $78 ? $77 : 255;
     $79 = (($$1123) + ($45))|0;
     $80 = ($79>>>0)<(255);
     $$1 = $80 ? $79 : 255;
     $$0117 = $46;$$0118 = $$1;$$0119 = $$3;$$0120 = $$;
     break;
    }
    case 64:  {
     $81 = Math_imul($$1127, $42)|0;
     $82 = (($81>>>0) / 255)&-1;
     $83 = Math_imul($$1125, $44)|0;
     $84 = (($83>>>0) / 255)&-1;
     $85 = Math_imul($$1123, $45)|0;
     $86 = (($85>>>0) / 255)&-1;
     $$0117 = $46;$$0118 = $86;$$0119 = $84;$$0120 = $82;
     break;
    }
    default: {
     $$0117 = $46;$$0118 = $45;$$0119 = $44;$$0120 = $42;
    }
    }
    $87 = $$0117 << 24;
    $88 = $$0120 << 16;
    $89 = $$0119 << 8;
    $90 = $89 | $88;
    $91 = $90 | $$0118;
    $92 = $91 | $87;
    HEAP32[$$0115129>>2] = $92;
    $93 = ((($$0116128)) + 4|0);
    $94 = ((($$0115129)) + 4|0);
    $95 = ($32|0)==(0);
    if ($95) {
     break;
    } else {
     $$0115129 = $94;$$0116128 = $93;$$in = $32;
    }
   }
   $$pre134 = HEAP32[$15>>2]|0;
   $103 = $$pre134;
  }
  $96 = HEAP32[$21>>2]|0;
  $97 = (($98) + ($96)|0);
  $99 = HEAP32[$22>>2]|0;
  $100 = (($101) + ($99)|0);
  $102 = (($103) + -1)|0;
  HEAP32[$15>>2] = $102;
  $104 = ($103|0)==(0);
  if ($104) {
   break;
  } else {
   $101 = $100;$105 = $102;$106 = $100;$107 = $97;$98 = $97;
  }
 }
 HEAP32[$0>>2] = $97;
 HEAP32[$19>>2] = $100;
 return;
}
function _SDL_Blit_RGBA8888_ARGB8888_Modulate_Blend_Scale($0) {
 $0 = $0|0;
 var $$ = 0, $$0142177 = 0, $$0143176 = 0, $$0145 = 0, $$0147 = 0, $$0149175 = 0, $$0151181 = 0, $$0153174 = 0, $$0156180 = 0, $$0158 = 0, $$0159 = 0, $$0160 = 0, $$0161 = 0, $$0162 = 0, $$0163 = 0, $$1 = 0, $$1144 = 0, $$1146 = 0, $$1148 = 0, $$1152$lcssa = 0;
 var $$1157$lcssa = 0, $$1164 = 0, $$2 = 0, $$2155 = 0, $$3 = 0, $$in = 0, $$pre = 0, $$pre188 = 0, $$pre189 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $or$cond = 0, $trunc = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = ((($0)) + 61|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = ((($0)) + 62|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = ((($0)) + 63|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = $13&255;
 $15 = ((($0)) + 8|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $16 << 16;
 $18 = ((($0)) + 28|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($17|0) / ($19|0))&-1;
 $21 = ((($0)) + 4|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = $22 << 16;
 $24 = ((($0)) + 24|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($23|0) / ($25|0))&-1;
 $27 = (($19) + -1)|0;
 HEAP32[$18>>2] = $27;
 $28 = ($19|0)==(0);
 if ($28) {
  return;
 }
 $29 = ((($0)) + 20|0);
 $30 = ((($0)) + 32|0);
 $31 = $2 & 1;
 $32 = ($31|0)==(0);
 $33 = $2 & 2;
 $34 = ($33|0)==(0);
 $35 = $2 & 48;
 $36 = ($35|0)!=(0);
 $37 = $2 & 112;
 $trunc = $37&255;
 $38 = ((($0)) + 12|0);
 $$pre = HEAP32[$29>>2]|0;
 $$0151181 = 0;$$0156180 = 0;$127 = $$pre;$132 = $27;$133 = $$pre;$46 = $25;
 while(1) {
  $39 = ($$0151181|0)>(65535);
  if ($39) {
   $40 = (($$0151181) + -65536)|0;
   $41 = $40 >>> 16;
   $42 = $41 << 16;
   $43 = (($$0156180) + 1)|0;
   $44 = (($43) + ($41))|0;
   $45 = (($40) - ($42))|0;
   $$1152$lcssa = $45;$$1157$lcssa = $44;
  } else {
   $$1152$lcssa = $$0151181;$$1157$lcssa = $$0156180;
  }
  $47 = ($46|0)==(0);
  if ($47) {
   $129 = $132;
  } else {
   $$0142177 = $133;$$0143176 = 0;$$0149175 = 65536;$$0153174 = -1;$$in = $46;
   while(1) {
    $48 = (($$in) + -1)|0;
    $49 = ($$0149175|0)>(65535);
    if ($49) {
     $50 = (($$0149175) + -65536)|0;
     $51 = $50 >>> 16;
     $52 = $51 << 16;
     $53 = (($$0153174) + 1)|0;
     $54 = (($53) + ($51))|0;
     $55 = (($50) - ($52))|0;
     $56 = HEAP32[$0>>2]|0;
     $57 = HEAP32[$38>>2]|0;
     $58 = Math_imul($57, $$1157$lcssa)|0;
     $59 = (($56) + ($58)|0);
     $60 = $54 << 2;
     $61 = (($59) + ($60)|0);
     $$1144 = $61;$$2 = $55;$$2155 = $54;
    } else {
     $$1144 = $$0143176;$$2 = $$0149175;$$2155 = $$0153174;
    }
    $62 = HEAP32[$$1144>>2]|0;
    $63 = $62 >>> 24;
    $64 = $62 >>> 16;
    $65 = $64 & 255;
    $66 = $62 >>> 8;
    $67 = $66 & 255;
    $68 = $62 & 255;
    $69 = HEAP32[$$0142177>>2]|0;
    $70 = $69 >>> 16;
    $71 = $70 & 255;
    $72 = $69 >>> 8;
    $73 = $72 & 255;
    $74 = $69 & 255;
    $75 = $69 >>> 24;
    if ($32) {
     $$0145 = $63;$$0147 = $65;$$0163 = $67;
    } else {
     $76 = Math_imul($67, $11)|0;
     $77 = Math_imul($65, $8)|0;
     $78 = Math_imul($63, $5)|0;
     $79 = (($78>>>0) / 255)&-1;
     $80 = (($77>>>0) / 255)&-1;
     $81 = (($76>>>0) / 255)&-1;
     $$0145 = $79;$$0147 = $80;$$0163 = $81;
    }
    $82 = Math_imul($68, $14)|0;
    $83 = (($82>>>0) / 255)&-1;
    $$0162 = $34 ? $68 : $83;
    $84 = ($$0162>>>0)<(255);
    $or$cond = $36 & $84;
    if ($or$cond) {
     $85 = Math_imul($$0163, $$0162)|0;
     $86 = Math_imul($$0147, $$0162)|0;
     $87 = Math_imul($$0145, $$0162)|0;
     $88 = (($87>>>0) / 255)&-1;
     $89 = (($86>>>0) / 255)&-1;
     $90 = (($85>>>0) / 255)&-1;
     $$1146 = $88;$$1148 = $89;$$1164 = $90;
    } else {
     $$1146 = $$0145;$$1148 = $$0147;$$1164 = $$0163;
    }
    $trunc$clear = $trunc & 127;
    switch ($trunc$clear<<24>>24) {
    case 16:  {
     $91 = (255 - ($$0162))|0;
     $92 = Math_imul($91, $71)|0;
     $93 = (($92>>>0) / 255)&-1;
     $94 = (($$1146) + ($93))|0;
     $95 = Math_imul($91, $73)|0;
     $96 = (($95>>>0) / 255)&-1;
     $97 = (($$1148) + ($96))|0;
     $98 = Math_imul($91, $74)|0;
     $99 = (($98>>>0) / 255)&-1;
     $100 = (($$1164) + ($99))|0;
     $101 = Math_imul($91, $75)|0;
     $102 = (($101>>>0) / 255)&-1;
     $103 = (($102) + ($$0162))|0;
     $$0158 = $103;$$0159 = $100;$$0160 = $97;$$0161 = $94;
     break;
    }
    case 32:  {
     $104 = (($$1146) + ($71))|0;
     $105 = ($104>>>0)<(255);
     $$ = $105 ? $104 : 255;
     $106 = (($$1148) + ($73))|0;
     $107 = ($106>>>0)<(255);
     $$3 = $107 ? $106 : 255;
     $108 = (($$1164) + ($74))|0;
     $109 = ($108>>>0)<(255);
     $$1 = $109 ? $108 : 255;
     $$0158 = $75;$$0159 = $$1;$$0160 = $$3;$$0161 = $$;
     break;
    }
    case 64:  {
     $110 = Math_imul($$1146, $71)|0;
     $111 = (($110>>>0) / 255)&-1;
     $112 = Math_imul($$1148, $73)|0;
     $113 = (($112>>>0) / 255)&-1;
     $114 = Math_imul($$1164, $74)|0;
     $115 = (($114>>>0) / 255)&-1;
     $$0158 = $75;$$0159 = $115;$$0160 = $113;$$0161 = $111;
     break;
    }
    default: {
     $$0158 = $75;$$0159 = $74;$$0160 = $73;$$0161 = $71;
    }
    }
    $116 = $$0158 << 24;
    $117 = $$0161 << 16;
    $118 = $$0160 << 8;
    $119 = $118 | $117;
    $120 = $119 | $$0159;
    $121 = $120 | $116;
    HEAP32[$$0142177>>2] = $121;
    $122 = (($$2) + ($26))|0;
    $123 = ((($$0142177)) + 4|0);
    $124 = ($48|0)==(0);
    if ($124) {
     break;
    } else {
     $$0142177 = $123;$$0143176 = $$1144;$$0149175 = $122;$$0153174 = $$2155;$$in = $48;
    }
   }
   $$pre189 = HEAP32[$18>>2]|0;
   $129 = $$pre189;
  }
  $125 = HEAP32[$30>>2]|0;
  $126 = (($127) + ($125)|0);
  $128 = (($129) + -1)|0;
  HEAP32[$18>>2] = $128;
  $130 = ($129|0)==(0);
  if ($130) {
   break;
  }
  $131 = (($$1152$lcssa) + ($20))|0;
  $$pre188 = HEAP32[$24>>2]|0;
  $$0151181 = $131;$$0156180 = $$1157$lcssa;$127 = $126;$132 = $128;$133 = $126;$46 = $$pre188;
 }
 HEAP32[$29>>2] = $126;
 return;
}
function _SDL_Blit_ABGR8888_RGB888_Scale($0) {
 $0 = $0|0;
 var $$05982 = 0, $$06081 = 0, $$06186 = 0, $$06380 = 0, $$06579 = 0, $$06885 = 0, $$1 = 0, $$162$lcssa = 0, $$169$lcssa = 0, $$2 = 0, $$267 = 0, $$in = 0, $$pre = 0, $$pre93 = 0, $$pre94 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 << 16;
 $4 = ((($0)) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3|0) / ($5|0))&-1;
 $7 = ((($0)) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 << 16;
 $10 = ((($0)) + 24|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($9|0) / ($11|0))&-1;
 $13 = (($5) + -1)|0;
 HEAP32[$4>>2] = $13;
 $14 = ($5|0)==(0);
 if ($14) {
  return;
 }
 $15 = ((($0)) + 20|0);
 $16 = ((($0)) + 32|0);
 $17 = ((($0)) + 12|0);
 $$pre = HEAP32[$15>>2]|0;
 $$06186 = 0;$$06885 = 0;$25 = $11;$54 = $$pre;$59 = $13;$60 = $$pre;
 while(1) {
  $18 = ($$06885|0)>(65535);
  if ($18) {
   $19 = (($$06885) + -65536)|0;
   $20 = $19 >>> 16;
   $21 = $20 << 16;
   $22 = (($$06186) + 1)|0;
   $23 = (($22) + ($20))|0;
   $24 = (($19) - ($21))|0;
   $$162$lcssa = $23;$$169$lcssa = $24;
  } else {
   $$162$lcssa = $$06186;$$169$lcssa = $$06885;
  }
  $26 = ($25|0)==(0);
  if ($26) {
   $56 = $59;
  } else {
   $$05982 = $60;$$06081 = 0;$$06380 = -1;$$06579 = 65536;$$in = $25;
   while(1) {
    $27 = (($$in) + -1)|0;
    $28 = ($$06579|0)>(65535);
    if ($28) {
     $29 = (($$06579) + -65536)|0;
     $30 = $29 >>> 16;
     $31 = $30 << 16;
     $32 = (($$06380) + 1)|0;
     $33 = (($32) + ($30))|0;
     $34 = (($29) - ($31))|0;
     $35 = HEAP32[$0>>2]|0;
     $36 = HEAP32[$17>>2]|0;
     $37 = Math_imul($36, $$162$lcssa)|0;
     $38 = (($35) + ($37)|0);
     $39 = $33 << 2;
     $40 = (($38) + ($39)|0);
     $$1 = $40;$$2 = $33;$$267 = $34;
    } else {
     $$1 = $$06081;$$2 = $$06380;$$267 = $$06579;
    }
    $41 = HEAP32[$$1>>2]|0;
    $42 = $41 >>> 16;
    $43 = $42 & 255;
    $44 = $41 & 65280;
    $45 = $41 << 16;
    $46 = $45 & 16711680;
    $47 = $46 | $44;
    $48 = $47 | $43;
    HEAP32[$$05982>>2] = $48;
    $49 = (($$267) + ($12))|0;
    $50 = ((($$05982)) + 4|0);
    $51 = ($27|0)==(0);
    if ($51) {
     break;
    } else {
     $$05982 = $50;$$06081 = $$1;$$06380 = $$2;$$06579 = $49;$$in = $27;
    }
   }
   $$pre94 = HEAP32[$4>>2]|0;
   $56 = $$pre94;
  }
  $52 = HEAP32[$16>>2]|0;
  $53 = (($54) + ($52)|0);
  $55 = (($56) + -1)|0;
  HEAP32[$4>>2] = $55;
  $57 = ($56|0)==(0);
  if ($57) {
   break;
  }
  $58 = (($$169$lcssa) + ($6))|0;
  $$pre93 = HEAP32[$10>>2]|0;
  $$06186 = $$162$lcssa;$$06885 = $58;$25 = $$pre93;$54 = $53;$59 = $55;$60 = $53;
 }
 HEAP32[$15>>2] = $53;
 return;
}
function _SDL_Blit_ABGR8888_RGB888_Blend($0) {
 $0 = $0|0;
 var $$ = 0, $$$us = 0, $$08695 = 0, $$08695$us = 0, $$08794 = 0, $$08794$us = 0, $$088 = 0, $$088$us = 0, $$089 = 0, $$089$us = 0, $$090 = 0, $$090$us = 0, $$091$us = 0, $$092$us = 0, $$093$us = 0, $$1 = 0, $$1$us = 0, $$3 = 0, $$3$us = 0, $$pre = 0;
 var $$pre100 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $trunc = 0, $trunc$clear = 0, $trunc$clear1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + -1)|0;
 HEAP32[$3>>2] = $5;
 $6 = ($4|0)==(0);
 if ($6) {
  return;
 }
 $7 = ((($0)) + 20|0);
 $8 = ((($0)) + 24|0);
 $9 = ((($0)) + 12|0);
 $10 = ((($0)) + 32|0);
 $11 = $2 & 48;
 $12 = ($11|0)==(0);
 $13 = $2 & 112;
 $trunc = $13&255;
 $$pre = HEAP32[$0>>2]|0;
 $$pre100 = HEAP32[$7>>2]|0;
 $114 = $$pre;$117 = $$pre100;$121 = $$pre100;$122 = $$pre;
 while(1) {
  $14 = HEAP32[$8>>2]|0;
  $15 = (($14) + -1)|0;
  $16 = ($14|0)==(0);
  L6: do {
   if (!($16)) {
    if ($12) {
     $$08695 = $121;$$08794 = $122;$110 = $15;
     while(1) {
      $68 = HEAP32[$$08794>>2]|0;
      $69 = $68 >>> 16;
      $70 = $69 & 255;
      $71 = $68 >>> 8;
      $72 = $71 & 255;
      $73 = $68 & 255;
      $74 = HEAP32[$$08695>>2]|0;
      $75 = $74 >>> 16;
      $76 = $75 & 255;
      $77 = $74 >>> 8;
      $78 = $77 & 255;
      $79 = $74 & 255;
      $trunc$clear1 = $trunc & 127;
      switch ($trunc$clear1<<24>>24) {
      case 16:  {
       $80 = $68 >>> 24;
       $81 = $80 ^ 255;
       $82 = Math_imul($76, $81)|0;
       $83 = (($82>>>0) / 255)&-1;
       $84 = (($73) + ($83))|0;
       $85 = Math_imul($78, $81)|0;
       $86 = (($85>>>0) / 255)&-1;
       $87 = (($72) + ($86))|0;
       $88 = Math_imul($81, $79)|0;
       $89 = (($88>>>0) / 255)&-1;
       $90 = (($70) + ($89))|0;
       $$088 = $90;$$089 = $87;$$090 = $84;
       break;
      }
      case 32:  {
       $91 = (($73) + ($76))|0;
       $92 = ($91>>>0)<(255);
       $$ = $92 ? $91 : 255;
       $93 = (($72) + ($78))|0;
       $94 = ($93>>>0)<(255);
       $$3 = $94 ? $93 : 255;
       $95 = (($70) + ($79))|0;
       $96 = ($95>>>0)<(255);
       $$1 = $96 ? $95 : 255;
       $$088 = $$1;$$089 = $$3;$$090 = $$;
       break;
      }
      case 64:  {
       $97 = Math_imul($73, $76)|0;
       $98 = (($97>>>0) / 255)&-1;
       $99 = Math_imul($72, $78)|0;
       $100 = (($99>>>0) / 255)&-1;
       $101 = Math_imul($70, $79)|0;
       $102 = (($101>>>0) / 255)&-1;
       $$088 = $102;$$089 = $100;$$090 = $98;
       break;
      }
      default: {
       $$088 = $79;$$089 = $78;$$090 = $76;
      }
      }
      $103 = $$090 << 16;
      $104 = $$089 << 8;
      $105 = $104 | $103;
      $106 = $105 | $$088;
      HEAP32[$$08695>>2] = $106;
      $107 = ((($$08794)) + 4|0);
      $108 = ((($$08695)) + 4|0);
      $109 = (($110) + -1)|0;
      $111 = ($110|0)==(0);
      if ($111) {
       break L6;
      } else {
       $$08695 = $108;$$08794 = $107;$110 = $109;
      }
     }
    } else {
     $$08695$us = $121;$$08794$us = $122;$66 = $15;
    }
    while(1) {
     $17 = HEAP32[$$08794$us>>2]|0;
     $18 = $17 >>> 16;
     $19 = $18 & 255;
     $20 = $17 >>> 8;
     $21 = $20 & 255;
     $22 = $17 & 255;
     $23 = $17 >>> 24;
     $24 = HEAP32[$$08695$us>>2]|0;
     $25 = $24 >>> 16;
     $26 = $25 & 255;
     $27 = $24 >>> 8;
     $28 = $27 & 255;
     $29 = $24 & 255;
     $30 = ($23|0)==(255);
     if ($30) {
      $$091$us = $22;$$092$us = $19;$$093$us = $21;
     } else {
      $31 = Math_imul($19, $23)|0;
      $32 = Math_imul($21, $23)|0;
      $33 = Math_imul($22, $23)|0;
      $34 = (($33>>>0) / 255)&-1;
      $35 = (($32>>>0) / 255)&-1;
      $36 = (($31>>>0) / 255)&-1;
      $$091$us = $34;$$092$us = $36;$$093$us = $35;
     }
     $trunc$clear = $trunc & 127;
     switch ($trunc$clear<<24>>24) {
     case 16:  {
      $49 = $23 ^ 255;
      $50 = Math_imul($26, $49)|0;
      $51 = (($50>>>0) / 255)&-1;
      $52 = (($$091$us) + ($51))|0;
      $53 = Math_imul($28, $49)|0;
      $54 = (($53>>>0) / 255)&-1;
      $55 = (($$093$us) + ($54))|0;
      $56 = Math_imul($49, $29)|0;
      $57 = (($56>>>0) / 255)&-1;
      $58 = (($$092$us) + ($57))|0;
      $$088$us = $58;$$089$us = $55;$$090$us = $52;
      break;
     }
     case 32:  {
      $43 = (($$091$us) + ($26))|0;
      $44 = ($43>>>0)<(255);
      $$$us = $44 ? $43 : 255;
      $45 = (($$093$us) + ($28))|0;
      $46 = ($45>>>0)<(255);
      $$3$us = $46 ? $45 : 255;
      $47 = (($$092$us) + ($29))|0;
      $48 = ($47>>>0)<(255);
      $$1$us = $48 ? $47 : 255;
      $$088$us = $$1$us;$$089$us = $$3$us;$$090$us = $$$us;
      break;
     }
     case 64:  {
      $37 = Math_imul($$091$us, $26)|0;
      $38 = (($37>>>0) / 255)&-1;
      $39 = Math_imul($$093$us, $28)|0;
      $40 = (($39>>>0) / 255)&-1;
      $41 = Math_imul($$092$us, $29)|0;
      $42 = (($41>>>0) / 255)&-1;
      $$088$us = $42;$$089$us = $40;$$090$us = $38;
      break;
     }
     default: {
      $$088$us = $29;$$089$us = $28;$$090$us = $26;
     }
     }
     $59 = $$090$us << 16;
     $60 = $$089$us << 8;
     $61 = $60 | $59;
     $62 = $61 | $$088$us;
     HEAP32[$$08695$us>>2] = $62;
     $63 = ((($$08794$us)) + 4|0);
     $64 = ((($$08695$us)) + 4|0);
     $65 = (($66) + -1)|0;
     $67 = ($66|0)==(0);
     if ($67) {
      break L6;
     } else {
      $$08695$us = $64;$$08794$us = $63;$66 = $65;
     }
    }
   }
  } while(0);
  $112 = HEAP32[$9>>2]|0;
  $113 = (($114) + ($112)|0);
  $115 = HEAP32[$10>>2]|0;
  $116 = (($117) + ($115)|0);
  $118 = HEAP32[$3>>2]|0;
  $119 = (($118) + -1)|0;
  HEAP32[$3>>2] = $119;
  $120 = ($118|0)==(0);
  if ($120) {
   break;
  } else {
   $114 = $113;$117 = $116;$121 = $116;$122 = $113;
  }
 }
 HEAP32[$0>>2] = $113;
 HEAP32[$7>>2] = $116;
 return;
}
function _SDL_Blit_ABGR8888_RGB888_Blend_Scale($0) {
 $0 = $0|0;
 var $$ = 0, $$0113143 = 0, $$0114142 = 0, $$0116 = 0, $$0117 = 0, $$0118141 = 0, $$0120147 = 0, $$0122140 = 0, $$0125146 = 0, $$0127 = 0, $$0128 = 0, $$0129 = 0, $$0130 = 0, $$1 = 0, $$1115 = 0, $$1121$lcssa = 0, $$1126$lcssa = 0, $$2 = 0, $$2124 = 0, $$3 = 0;
 var $$in = 0, $$pre = 0, $$pre154 = 0, $$pre155 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $trunc = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 << 16;
 $6 = ((($0)) + 28|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5|0) / ($7|0))&-1;
 $9 = ((($0)) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10 << 16;
 $12 = ((($0)) + 24|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($11|0) / ($13|0))&-1;
 $15 = (($7) + -1)|0;
 HEAP32[$6>>2] = $15;
 $16 = ($7|0)==(0);
 if ($16) {
  return;
 }
 $17 = ((($0)) + 20|0);
 $18 = ((($0)) + 32|0);
 $19 = $2 & 48;
 $20 = ($19|0)!=(0);
 $21 = $2 & 112;
 $trunc = $21&255;
 $22 = ((($0)) + 12|0);
 $$pre = HEAP32[$17>>2]|0;
 $$0120147 = 0;$$0125146 = 0;$102 = $15;$103 = $$pre;$30 = $13;$97 = $$pre;
 while(1) {
  $23 = ($$0120147|0)>(65535);
  if ($23) {
   $24 = (($$0120147) + -65536)|0;
   $25 = $24 >>> 16;
   $26 = $25 << 16;
   $27 = (($$0125146) + 1)|0;
   $28 = (($27) + ($25))|0;
   $29 = (($24) - ($26))|0;
   $$1121$lcssa = $29;$$1126$lcssa = $28;
  } else {
   $$1121$lcssa = $$0120147;$$1126$lcssa = $$0125146;
  }
  $31 = ($30|0)==(0);
  if ($31) {
   $99 = $102;
  } else {
   $$0113143 = $103;$$0114142 = 0;$$0118141 = 65536;$$0122140 = -1;$$in = $30;
   while(1) {
    $32 = (($$in) + -1)|0;
    $33 = ($$0118141|0)>(65535);
    if ($33) {
     $34 = (($$0118141) + -65536)|0;
     $35 = $34 >>> 16;
     $36 = $35 << 16;
     $37 = (($$0122140) + 1)|0;
     $38 = (($37) + ($35))|0;
     $39 = (($34) - ($36))|0;
     $40 = HEAP32[$0>>2]|0;
     $41 = HEAP32[$22>>2]|0;
     $42 = Math_imul($41, $$1126$lcssa)|0;
     $43 = (($40) + ($42)|0);
     $44 = $38 << 2;
     $45 = (($43) + ($44)|0);
     $$1115 = $45;$$2 = $39;$$2124 = $38;
    } else {
     $$1115 = $$0114142;$$2 = $$0118141;$$2124 = $$0122140;
    }
    $46 = HEAP32[$$1115>>2]|0;
    $47 = $46 >>> 16;
    $48 = $47 & 255;
    $49 = $46 >>> 8;
    $50 = $49 & 255;
    $51 = $46 & 255;
    $52 = $46 >>> 24;
    $53 = HEAP32[$$0113143>>2]|0;
    $54 = $53 >>> 16;
    $55 = $54 & 255;
    $56 = $53 >>> 8;
    $57 = $56 & 255;
    $58 = $53 & 255;
    $59 = ($52|0)!=(255);
    $or$cond = $20 & $59;
    if ($or$cond) {
     $60 = Math_imul($48, $52)|0;
     $61 = Math_imul($50, $52)|0;
     $62 = Math_imul($51, $52)|0;
     $63 = (($62>>>0) / 255)&-1;
     $64 = (($61>>>0) / 255)&-1;
     $65 = (($60>>>0) / 255)&-1;
     $$0116 = $63;$$0117 = $64;$$0130 = $65;
    } else {
     $$0116 = $51;$$0117 = $50;$$0130 = $48;
    }
    $trunc$clear = $trunc & 127;
    switch ($trunc$clear<<24>>24) {
    case 16:  {
     $66 = $52 ^ 255;
     $67 = Math_imul($55, $66)|0;
     $68 = (($67>>>0) / 255)&-1;
     $69 = (($$0116) + ($68))|0;
     $70 = Math_imul($57, $66)|0;
     $71 = (($70>>>0) / 255)&-1;
     $72 = (($$0117) + ($71))|0;
     $73 = Math_imul($66, $58)|0;
     $74 = (($73>>>0) / 255)&-1;
     $75 = (($$0130) + ($74))|0;
     $$0127 = $75;$$0128 = $72;$$0129 = $69;
     break;
    }
    case 32:  {
     $76 = (($$0116) + ($55))|0;
     $77 = ($76>>>0)<(255);
     $$ = $77 ? $76 : 255;
     $78 = (($$0117) + ($57))|0;
     $79 = ($78>>>0)<(255);
     $$3 = $79 ? $78 : 255;
     $80 = (($$0130) + ($58))|0;
     $81 = ($80>>>0)<(255);
     $$1 = $81 ? $80 : 255;
     $$0127 = $$1;$$0128 = $$3;$$0129 = $$;
     break;
    }
    case 64:  {
     $82 = Math_imul($$0116, $55)|0;
     $83 = (($82>>>0) / 255)&-1;
     $84 = Math_imul($$0117, $57)|0;
     $85 = (($84>>>0) / 255)&-1;
     $86 = Math_imul($$0130, $58)|0;
     $87 = (($86>>>0) / 255)&-1;
     $$0127 = $87;$$0128 = $85;$$0129 = $83;
     break;
    }
    default: {
     $$0127 = $58;$$0128 = $57;$$0129 = $55;
    }
    }
    $88 = $$0129 << 16;
    $89 = $$0128 << 8;
    $90 = $89 | $88;
    $91 = $90 | $$0127;
    HEAP32[$$0113143>>2] = $91;
    $92 = (($$2) + ($14))|0;
    $93 = ((($$0113143)) + 4|0);
    $94 = ($32|0)==(0);
    if ($94) {
     break;
    } else {
     $$0113143 = $93;$$0114142 = $$1115;$$0118141 = $92;$$0122140 = $$2124;$$in = $32;
    }
   }
   $$pre155 = HEAP32[$6>>2]|0;
   $99 = $$pre155;
  }
  $95 = HEAP32[$18>>2]|0;
  $96 = (($97) + ($95)|0);
  $98 = (($99) + -1)|0;
  HEAP32[$6>>2] = $98;
  $100 = ($99|0)==(0);
  if ($100) {
   break;
  }
  $101 = (($$1121$lcssa) + ($8))|0;
  $$pre154 = HEAP32[$12>>2]|0;
  $$0120147 = $101;$$0125146 = $$1126$lcssa;$102 = $98;$103 = $96;$30 = $$pre154;$97 = $96;
 }
 HEAP32[$17>>2] = $96;
 return;
}
function _SDL_Blit_ABGR8888_RGB888_Modulate($0) {
 $0 = $0|0;
 var $$05157 = 0, $$05157$us$us = 0, $$05256 = 0, $$05256$us$us = 0, $$in = 0, $$in68 = 0, $$lcssa77$sink = 0, $$lcssa78$sink = 0, $$pre71 = 0, $$pre72 = 0, $$pre73 = 0, $$pre74 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = ((($0)) + 61|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = ((($0)) + 62|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = ((($0)) + 28|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($13) + -1)|0;
 HEAP32[$12>>2] = $14;
 $15 = ($13|0)==(0);
 if ($15) {
  return;
 }
 $16 = ((($0)) + 20|0);
 $17 = ((($0)) + 24|0);
 $18 = ((($0)) + 12|0);
 $19 = ((($0)) + 32|0);
 $20 = $2 & 1;
 $21 = ($20|0)==(0);
 $$pre72 = HEAP32[$0>>2]|0;
 $$pre73 = HEAP32[$16>>2]|0;
 if ($21) {
  $26 = $$pre72;$29 = $$pre73;$76 = $14;$77 = $$pre73;$78 = $$pre72;
  while(1) {
   $22 = HEAP32[$17>>2]|0;
   $23 = ($22|0)==(0);
   if ($23) {
    $31 = $76;
   } else {
    $$05157$us$us = $77;$$05256$us$us = $78;$$in68 = $22;
    while(1) {
     $33 = (($$in68) + -1)|0;
     $34 = HEAP32[$$05256$us$us>>2]|0;
     $35 = $34 >>> 16;
     $36 = $35 & 255;
     $37 = $34 & 65280;
     $38 = $34 << 16;
     $39 = $38 & 16711680;
     $40 = $37 | $39;
     $41 = $40 | $36;
     HEAP32[$$05157$us$us>>2] = $41;
     $42 = ((($$05256$us$us)) + 4|0);
     $43 = ((($$05157$us$us)) + 4|0);
     $44 = ($33|0)==(0);
     if ($44) {
      break;
     } else {
      $$05157$us$us = $43;$$05256$us$us = $42;$$in68 = $33;
     }
    }
    $$pre74 = HEAP32[$12>>2]|0;
    $31 = $$pre74;
   }
   $24 = HEAP32[$18>>2]|0;
   $25 = (($26) + ($24)|0);
   $27 = HEAP32[$19>>2]|0;
   $28 = (($29) + ($27)|0);
   $30 = (($31) + -1)|0;
   HEAP32[$12>>2] = $30;
   $32 = ($31|0)==(0);
   if ($32) {
    $$lcssa77$sink = $25;$$lcssa78$sink = $28;
    break;
   } else {
    $26 = $25;$29 = $28;$76 = $30;$77 = $28;$78 = $25;
   }
  }
 } else {
  $69 = $$pre72;$72 = $$pre73;$79 = $14;$80 = $$pre73;$81 = $$pre72;
  while(1) {
   $45 = HEAP32[$17>>2]|0;
   $46 = ($45|0)==(0);
   if ($46) {
    $74 = $79;
   } else {
    $$05157 = $80;$$05256 = $81;$$in = $45;
    while(1) {
     $47 = (($$in) + -1)|0;
     $48 = HEAP32[$$05256>>2]|0;
     $49 = $48 >>> 16;
     $50 = $49 & 255;
     $51 = $48 >>> 8;
     $52 = $51 & 255;
     $53 = $48 & 255;
     $54 = Math_imul($50, $11)|0;
     $55 = Math_imul($52, $8)|0;
     $56 = Math_imul($53, $5)|0;
     $57 = (($56>>>0) / 255)&-1;
     $58 = (($55>>>0) / 255)&-1;
     $59 = (($54>>>0) / 255)&-1;
     $60 = $57 << 16;
     $61 = $58 << 8;
     $62 = $61 | $60;
     $63 = $62 | $59;
     HEAP32[$$05157>>2] = $63;
     $64 = ((($$05256)) + 4|0);
     $65 = ((($$05157)) + 4|0);
     $66 = ($47|0)==(0);
     if ($66) {
      break;
     } else {
      $$05157 = $65;$$05256 = $64;$$in = $47;
     }
    }
    $$pre71 = HEAP32[$12>>2]|0;
    $74 = $$pre71;
   }
   $67 = HEAP32[$18>>2]|0;
   $68 = (($69) + ($67)|0);
   $70 = HEAP32[$19>>2]|0;
   $71 = (($72) + ($70)|0);
   $73 = (($74) + -1)|0;
   HEAP32[$12>>2] = $73;
   $75 = ($74|0)==(0);
   if ($75) {
    $$lcssa77$sink = $68;$$lcssa78$sink = $71;
    break;
   } else {
    $69 = $68;$72 = $71;$79 = $73;$80 = $71;$81 = $68;
   }
  }
 }
 HEAP32[$0>>2] = $$lcssa77$sink;
 HEAP32[$16>>2] = $$lcssa78$sink;
 return;
}
function _SDL_Blit_ABGR8888_RGB888_Modulate_Scale($0) {
 $0 = $0|0;
 var $$078104 = 0, $$078104$us = 0, $$079103 = 0, $$079103$us = 0, $$081102 = 0, $$081102$us = 0, $$083108 = 0, $$085101 = 0, $$085101$us = 0, $$088107 = 0, $$1 = 0, $$1$us = 0, $$184$lcssa = 0, $$189$lcssa = 0, $$2 = 0, $$2$us = 0, $$287 = 0, $$287$us = 0, $$pre = 0, $$pre118 = 0;
 var $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = ((($0)) + 61|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = ((($0)) + 62|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = ((($0)) + 8|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13 << 16;
 $15 = ((($0)) + 28|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($14|0) / ($16|0))&-1;
 $18 = ((($0)) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = $19 << 16;
 $21 = ((($0)) + 24|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($20|0) / ($22|0))&-1;
 $24 = (($16) + -1)|0;
 HEAP32[$15>>2] = $24;
 $25 = ($16|0)==(0);
 if ($25) {
  return;
 }
 $26 = ((($0)) + 20|0);
 $27 = ((($0)) + 32|0);
 $28 = $2 & 1;
 $29 = ($28|0)==(0);
 $30 = ((($0)) + 12|0);
 $$pre = HEAP32[$26>>2]|0;
 $$083108 = 0;$$088107 = 0;$103 = $$pre;$108 = $$pre;$39 = $22;
 while(1) {
  $31 = ($$083108|0)>(65535);
  if ($31) {
   $32 = (($$083108) + -65536)|0;
   $33 = $32 >>> 16;
   $34 = $33 << 16;
   $35 = (($$088107) + 1)|0;
   $36 = (($35) + ($33))|0;
   $37 = (($32) - ($34))|0;
   $$184$lcssa = $37;$$189$lcssa = $36;
  } else {
   $$184$lcssa = $$083108;$$189$lcssa = $$088107;
  }
  $38 = (($39) + -1)|0;
  $40 = ($39|0)==(0);
  if (!($40)) {
   if ($29) {
    $$078104$us = $108;$$079103$us = 0;$$081102$us = 65536;$$085101$us = -1;$65 = $38;
    while(1) {
     $41 = ($$081102$us|0)>(65535);
     if ($41) {
      $42 = (($$081102$us) + -65536)|0;
      $43 = $42 >>> 16;
      $44 = $43 << 16;
      $45 = (($$085101$us) + 1)|0;
      $46 = (($45) + ($43))|0;
      $47 = (($42) - ($44))|0;
      $48 = HEAP32[$0>>2]|0;
      $49 = HEAP32[$30>>2]|0;
      $50 = Math_imul($49, $$189$lcssa)|0;
      $51 = (($48) + ($50)|0);
      $52 = $46 << 2;
      $53 = (($51) + ($52)|0);
      $$1$us = $53;$$2$us = $47;$$287$us = $46;
     } else {
      $$1$us = $$079103$us;$$2$us = $$081102$us;$$287$us = $$085101$us;
     }
     $54 = HEAP32[$$1$us>>2]|0;
     $55 = $54 >>> 16;
     $56 = $55 & 255;
     $57 = $54 & 65280;
     $58 = $54 << 16;
     $59 = $58 & 16711680;
     $60 = $56 | $57;
     $61 = $60 | $59;
     HEAP32[$$078104$us>>2] = $61;
     $62 = (($$2$us) + ($23))|0;
     $63 = ((($$078104$us)) + 4|0);
     $64 = (($65) + -1)|0;
     $66 = ($65|0)==(0);
     if ($66) {
      break;
     } else {
      $$078104$us = $63;$$079103$us = $$1$us;$$081102$us = $62;$$085101$us = $$287$us;$65 = $64;
     }
    }
   } else {
    $$078104 = $108;$$079103 = 0;$$081102 = 65536;$$085101 = -1;$99 = $38;
    while(1) {
     $67 = ($$081102|0)>(65535);
     if ($67) {
      $68 = (($$081102) + -65536)|0;
      $69 = $68 >>> 16;
      $70 = $69 << 16;
      $71 = (($$085101) + 1)|0;
      $72 = (($71) + ($69))|0;
      $73 = (($68) - ($70))|0;
      $74 = HEAP32[$0>>2]|0;
      $75 = HEAP32[$30>>2]|0;
      $76 = Math_imul($75, $$189$lcssa)|0;
      $77 = (($74) + ($76)|0);
      $78 = $72 << 2;
      $79 = (($77) + ($78)|0);
      $$1 = $79;$$2 = $73;$$287 = $72;
     } else {
      $$1 = $$079103;$$2 = $$081102;$$287 = $$085101;
     }
     $80 = HEAP32[$$1>>2]|0;
     $81 = $80 >>> 16;
     $82 = $81 & 255;
     $83 = $80 >>> 8;
     $84 = $83 & 255;
     $85 = $80 & 255;
     $86 = Math_imul($82, $11)|0;
     $87 = Math_imul($84, $8)|0;
     $88 = Math_imul($85, $5)|0;
     $89 = (($88>>>0) / 255)&-1;
     $90 = (($87>>>0) / 255)&-1;
     $91 = (($86>>>0) / 255)&-1;
     $92 = $89 << 16;
     $93 = $90 << 8;
     $94 = $91 | $93;
     $95 = $94 | $92;
     HEAP32[$$078104>>2] = $95;
     $96 = (($$2) + ($23))|0;
     $97 = ((($$078104)) + 4|0);
     $98 = (($99) + -1)|0;
     $100 = ($99|0)==(0);
     if ($100) {
      break;
     } else {
      $$078104 = $97;$$079103 = $$1;$$081102 = $96;$$085101 = $$287;$99 = $98;
     }
    }
   }
  }
  $101 = HEAP32[$27>>2]|0;
  $102 = (($103) + ($101)|0);
  $104 = HEAP32[$15>>2]|0;
  $105 = (($104) + -1)|0;
  HEAP32[$15>>2] = $105;
  $106 = ($104|0)==(0);
  if ($106) {
   break;
  }
  $107 = (($$184$lcssa) + ($17))|0;
  $$pre118 = HEAP32[$21>>2]|0;
  $$083108 = $107;$$088107 = $$189$lcssa;$103 = $102;$108 = $102;$39 = $$pre118;
 }
 HEAP32[$26>>2] = $102;
 return;
}
function _SDL_Blit_ABGR8888_RGB888_Modulate_Blend($0) {
 $0 = $0|0;
 var $$ = 0, $$0108121 = 0, $$0109120 = 0, $$0110 = 0, $$0111 = 0, $$0112 = 0, $$0113 = 0, $$0114 = 0, $$0116 = 0, $$0118 = 0, $$1 = 0, $$1115 = 0, $$1117 = 0, $$1119 = 0, $$3 = 0, $$in = 0, $$pre = 0, $$pre125 = 0, $$pre126 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $or$cond = 0, $trunc = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = ((($0)) + 61|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = ((($0)) + 62|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = ((($0)) + 63|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = $13&255;
 $15 = ((($0)) + 28|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + -1)|0;
 HEAP32[$15>>2] = $17;
 $18 = ($16|0)==(0);
 if ($18) {
  return;
 }
 $19 = ((($0)) + 20|0);
 $20 = ((($0)) + 24|0);
 $21 = ((($0)) + 12|0);
 $22 = ((($0)) + 32|0);
 $23 = $2 & 1;
 $24 = ($23|0)==(0);
 $25 = $2 & 2;
 $26 = ($25|0)==(0);
 $27 = $2 & 48;
 $28 = ($27|0)!=(0);
 $29 = $2 & 112;
 $trunc = $29&255;
 $$pre = HEAP32[$0>>2]|0;
 $$pre125 = HEAP32[$19>>2]|0;
 $100 = $$pre125;$101 = $$pre;$92 = $$pre;$95 = $$pre125;$99 = $17;
 while(1) {
  $30 = HEAP32[$20>>2]|0;
  $31 = ($30|0)==(0);
  if ($31) {
   $97 = $99;
  } else {
   $$0108121 = $100;$$0109120 = $101;$$in = $30;
   while(1) {
    $32 = (($$in) + -1)|0;
    $33 = HEAP32[$$0109120>>2]|0;
    $34 = $33 >>> 16;
    $35 = $34 & 255;
    $36 = $33 >>> 8;
    $37 = $36 & 255;
    $38 = $33 & 255;
    $39 = $33 >>> 24;
    $40 = HEAP32[$$0108121>>2]|0;
    $41 = $40 >>> 16;
    $42 = $41 & 255;
    $43 = $40 >>> 8;
    $44 = $43 & 255;
    $45 = $40 & 255;
    if ($24) {
     $$0114 = $35;$$0116 = $37;$$0118 = $38;
    } else {
     $46 = Math_imul($35, $11)|0;
     $47 = Math_imul($37, $8)|0;
     $48 = Math_imul($38, $5)|0;
     $49 = (($48>>>0) / 255)&-1;
     $50 = (($47>>>0) / 255)&-1;
     $51 = (($46>>>0) / 255)&-1;
     $$0114 = $51;$$0116 = $50;$$0118 = $49;
    }
    $52 = Math_imul($39, $14)|0;
    $53 = (($52>>>0) / 255)&-1;
    $$0113 = $26 ? $39 : $53;
    $54 = ($$0113>>>0)<(255);
    $or$cond = $28 & $54;
    if ($or$cond) {
     $55 = Math_imul($$0114, $$0113)|0;
     $56 = Math_imul($$0116, $$0113)|0;
     $57 = Math_imul($$0118, $$0113)|0;
     $58 = (($57>>>0) / 255)&-1;
     $59 = (($56>>>0) / 255)&-1;
     $60 = (($55>>>0) / 255)&-1;
     $$1115 = $60;$$1117 = $59;$$1119 = $58;
    } else {
     $$1115 = $$0114;$$1117 = $$0116;$$1119 = $$0118;
    }
    $trunc$clear = $trunc & 127;
    switch ($trunc$clear<<24>>24) {
    case 16:  {
     $61 = (255 - ($$0113))|0;
     $62 = Math_imul($61, $42)|0;
     $63 = (($62>>>0) / 255)&-1;
     $64 = (($$1119) + ($63))|0;
     $65 = Math_imul($61, $44)|0;
     $66 = (($65>>>0) / 255)&-1;
     $67 = (($$1117) + ($66))|0;
     $68 = Math_imul($61, $45)|0;
     $69 = (($68>>>0) / 255)&-1;
     $70 = (($$1115) + ($69))|0;
     $$0110 = $70;$$0111 = $67;$$0112 = $64;
     break;
    }
    case 32:  {
     $71 = (($$1119) + ($42))|0;
     $72 = ($71>>>0)<(255);
     $$ = $72 ? $71 : 255;
     $73 = (($$1117) + ($44))|0;
     $74 = ($73>>>0)<(255);
     $$3 = $74 ? $73 : 255;
     $75 = (($$1115) + ($45))|0;
     $76 = ($75>>>0)<(255);
     $$1 = $76 ? $75 : 255;
     $$0110 = $$1;$$0111 = $$3;$$0112 = $$;
     break;
    }
    case 64:  {
     $77 = Math_imul($$1119, $42)|0;
     $78 = (($77>>>0) / 255)&-1;
     $79 = Math_imul($$1117, $44)|0;
     $80 = (($79>>>0) / 255)&-1;
     $81 = Math_imul($$1115, $45)|0;
     $82 = (($81>>>0) / 255)&-1;
     $$0110 = $82;$$0111 = $80;$$0112 = $78;
     break;
    }
    default: {
     $$0110 = $45;$$0111 = $44;$$0112 = $42;
    }
    }
    $83 = $$0112 << 16;
    $84 = $$0111 << 8;
    $85 = $84 | $83;
    $86 = $85 | $$0110;
    HEAP32[$$0108121>>2] = $86;
    $87 = ((($$0109120)) + 4|0);
    $88 = ((($$0108121)) + 4|0);
    $89 = ($32|0)==(0);
    if ($89) {
     break;
    } else {
     $$0108121 = $88;$$0109120 = $87;$$in = $32;
    }
   }
   $$pre126 = HEAP32[$15>>2]|0;
   $97 = $$pre126;
  }
  $90 = HEAP32[$21>>2]|0;
  $91 = (($92) + ($90)|0);
  $93 = HEAP32[$22>>2]|0;
  $94 = (($95) + ($93)|0);
  $96 = (($97) + -1)|0;
  HEAP32[$15>>2] = $96;
  $98 = ($97|0)==(0);
  if ($98) {
   break;
  } else {
   $100 = $94;$101 = $91;$92 = $91;$95 = $94;$99 = $96;
  }
 }
 HEAP32[$0>>2] = $91;
 HEAP32[$19>>2] = $94;
 return;
}
function _SDL_Blit_ABGR8888_RGB888_Modulate_Blend_Scale($0) {
 $0 = $0|0;
 var $$ = 0, $$0135169 = 0, $$0136168 = 0, $$0138 = 0, $$0140 = 0, $$0142167 = 0, $$0144173 = 0, $$0146166 = 0, $$0149172 = 0, $$0151 = 0, $$0152 = 0, $$0153 = 0, $$0154 = 0, $$0155 = 0, $$1 = 0, $$1137 = 0, $$1139 = 0, $$1141 = 0, $$1145$lcssa = 0, $$1150$lcssa = 0;
 var $$1156 = 0, $$2 = 0, $$2148 = 0, $$3 = 0, $$in = 0, $$pre = 0, $$pre180 = 0, $$pre181 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $trunc = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = ((($0)) + 61|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = ((($0)) + 62|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = ((($0)) + 63|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = $13&255;
 $15 = ((($0)) + 8|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $16 << 16;
 $18 = ((($0)) + 28|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($17|0) / ($19|0))&-1;
 $21 = ((($0)) + 4|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = $22 << 16;
 $24 = ((($0)) + 24|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($23|0) / ($25|0))&-1;
 $27 = (($19) + -1)|0;
 HEAP32[$18>>2] = $27;
 $28 = ($19|0)==(0);
 if ($28) {
  return;
 }
 $29 = ((($0)) + 20|0);
 $30 = ((($0)) + 32|0);
 $31 = $2 & 1;
 $32 = ($31|0)==(0);
 $33 = $2 & 2;
 $34 = ($33|0)==(0);
 $35 = $2 & 48;
 $36 = ($35|0)!=(0);
 $37 = $2 & 112;
 $trunc = $37&255;
 $38 = ((($0)) + 12|0);
 $$pre = HEAP32[$29>>2]|0;
 $$0144173 = 0;$$0149172 = 0;$121 = $$pre;$126 = $27;$127 = $$pre;$46 = $25;
 while(1) {
  $39 = ($$0144173|0)>(65535);
  if ($39) {
   $40 = (($$0144173) + -65536)|0;
   $41 = $40 >>> 16;
   $42 = $41 << 16;
   $43 = (($$0149172) + 1)|0;
   $44 = (($43) + ($41))|0;
   $45 = (($40) - ($42))|0;
   $$1145$lcssa = $45;$$1150$lcssa = $44;
  } else {
   $$1145$lcssa = $$0144173;$$1150$lcssa = $$0149172;
  }
  $47 = ($46|0)==(0);
  if ($47) {
   $123 = $126;
  } else {
   $$0135169 = $127;$$0136168 = 0;$$0142167 = 65536;$$0146166 = -1;$$in = $46;
   while(1) {
    $48 = (($$in) + -1)|0;
    $49 = ($$0142167|0)>(65535);
    if ($49) {
     $50 = (($$0142167) + -65536)|0;
     $51 = $50 >>> 16;
     $52 = $51 << 16;
     $53 = (($$0146166) + 1)|0;
     $54 = (($53) + ($51))|0;
     $55 = (($50) - ($52))|0;
     $56 = HEAP32[$0>>2]|0;
     $57 = HEAP32[$38>>2]|0;
     $58 = Math_imul($57, $$1150$lcssa)|0;
     $59 = (($56) + ($58)|0);
     $60 = $54 << 2;
     $61 = (($59) + ($60)|0);
     $$1137 = $61;$$2 = $55;$$2148 = $54;
    } else {
     $$1137 = $$0136168;$$2 = $$0142167;$$2148 = $$0146166;
    }
    $62 = HEAP32[$$1137>>2]|0;
    $63 = $62 >>> 16;
    $64 = $63 & 255;
    $65 = $62 >>> 8;
    $66 = $65 & 255;
    $67 = $62 & 255;
    $68 = $62 >>> 24;
    $69 = HEAP32[$$0135169>>2]|0;
    $70 = $69 >>> 16;
    $71 = $70 & 255;
    $72 = $69 >>> 8;
    $73 = $72 & 255;
    $74 = $69 & 255;
    if ($32) {
     $$0138 = $67;$$0140 = $66;$$0155 = $64;
    } else {
     $75 = Math_imul($64, $11)|0;
     $76 = Math_imul($66, $8)|0;
     $77 = Math_imul($67, $5)|0;
     $78 = (($77>>>0) / 255)&-1;
     $79 = (($76>>>0) / 255)&-1;
     $80 = (($75>>>0) / 255)&-1;
     $$0138 = $78;$$0140 = $79;$$0155 = $80;
    }
    $81 = Math_imul($68, $14)|0;
    $82 = (($81>>>0) / 255)&-1;
    $$0154 = $34 ? $68 : $82;
    $83 = ($$0154>>>0)<(255);
    $or$cond = $36 & $83;
    if ($or$cond) {
     $84 = Math_imul($$0155, $$0154)|0;
     $85 = Math_imul($$0140, $$0154)|0;
     $86 = Math_imul($$0138, $$0154)|0;
     $87 = (($86>>>0) / 255)&-1;
     $88 = (($85>>>0) / 255)&-1;
     $89 = (($84>>>0) / 255)&-1;
     $$1139 = $87;$$1141 = $88;$$1156 = $89;
    } else {
     $$1139 = $$0138;$$1141 = $$0140;$$1156 = $$0155;
    }
    $trunc$clear = $trunc & 127;
    switch ($trunc$clear<<24>>24) {
    case 16:  {
     $90 = (255 - ($$0154))|0;
     $91 = Math_imul($90, $71)|0;
     $92 = (($91>>>0) / 255)&-1;
     $93 = (($$1139) + ($92))|0;
     $94 = Math_imul($90, $73)|0;
     $95 = (($94>>>0) / 255)&-1;
     $96 = (($$1141) + ($95))|0;
     $97 = Math_imul($90, $74)|0;
     $98 = (($97>>>0) / 255)&-1;
     $99 = (($$1156) + ($98))|0;
     $$0151 = $99;$$0152 = $96;$$0153 = $93;
     break;
    }
    case 32:  {
     $100 = (($$1139) + ($71))|0;
     $101 = ($100>>>0)<(255);
     $$ = $101 ? $100 : 255;
     $102 = (($$1141) + ($73))|0;
     $103 = ($102>>>0)<(255);
     $$3 = $103 ? $102 : 255;
     $104 = (($$1156) + ($74))|0;
     $105 = ($104>>>0)<(255);
     $$1 = $105 ? $104 : 255;
     $$0151 = $$1;$$0152 = $$3;$$0153 = $$;
     break;
    }
    case 64:  {
     $106 = Math_imul($$1139, $71)|0;
     $107 = (($106>>>0) / 255)&-1;
     $108 = Math_imul($$1141, $73)|0;
     $109 = (($108>>>0) / 255)&-1;
     $110 = Math_imul($$1156, $74)|0;
     $111 = (($110>>>0) / 255)&-1;
     $$0151 = $111;$$0152 = $109;$$0153 = $107;
     break;
    }
    default: {
     $$0151 = $74;$$0152 = $73;$$0153 = $71;
    }
    }
    $112 = $$0153 << 16;
    $113 = $$0152 << 8;
    $114 = $113 | $112;
    $115 = $114 | $$0151;
    HEAP32[$$0135169>>2] = $115;
    $116 = (($$2) + ($26))|0;
    $117 = ((($$0135169)) + 4|0);
    $118 = ($48|0)==(0);
    if ($118) {
     break;
    } else {
     $$0135169 = $117;$$0136168 = $$1137;$$0142167 = $116;$$0146166 = $$2148;$$in = $48;
    }
   }
   $$pre181 = HEAP32[$18>>2]|0;
   $123 = $$pre181;
  }
  $119 = HEAP32[$30>>2]|0;
  $120 = (($121) + ($119)|0);
  $122 = (($123) + -1)|0;
  HEAP32[$18>>2] = $122;
  $124 = ($123|0)==(0);
  if ($124) {
   break;
  }
  $125 = (($$1145$lcssa) + ($20))|0;
  $$pre180 = HEAP32[$24>>2]|0;
  $$0144173 = $125;$$0149172 = $$1150$lcssa;$121 = $120;$126 = $122;$127 = $120;$46 = $$pre180;
 }
 HEAP32[$29>>2] = $120;
 return;
}
function _SDL_Blit_ABGR8888_BGR888_Scale($0) {
 $0 = $0|0;
 var $$05982 = 0, $$06081 = 0, $$06186 = 0, $$06380 = 0, $$06579 = 0, $$06885 = 0, $$1 = 0, $$162$lcssa = 0, $$169$lcssa = 0, $$2 = 0, $$267 = 0, $$in = 0, $$pre = 0, $$pre93 = 0, $$pre94 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 << 16;
 $4 = ((($0)) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3|0) / ($5|0))&-1;
 $7 = ((($0)) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 << 16;
 $10 = ((($0)) + 24|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($9|0) / ($11|0))&-1;
 $13 = (($5) + -1)|0;
 HEAP32[$4>>2] = $13;
 $14 = ($5|0)==(0);
 if ($14) {
  return;
 }
 $15 = ((($0)) + 20|0);
 $16 = ((($0)) + 32|0);
 $17 = ((($0)) + 12|0);
 $$pre = HEAP32[$15>>2]|0;
 $$06186 = 0;$$06885 = 0;$25 = $11;$48 = $$pre;$53 = $13;$54 = $$pre;
 while(1) {
  $18 = ($$06885|0)>(65535);
  if ($18) {
   $19 = (($$06885) + -65536)|0;
   $20 = $19 >>> 16;
   $21 = $20 << 16;
   $22 = (($$06186) + 1)|0;
   $23 = (($22) + ($20))|0;
   $24 = (($19) - ($21))|0;
   $$162$lcssa = $23;$$169$lcssa = $24;
  } else {
   $$162$lcssa = $$06186;$$169$lcssa = $$06885;
  }
  $26 = ($25|0)==(0);
  if ($26) {
   $50 = $53;
  } else {
   $$05982 = $54;$$06081 = 0;$$06380 = -1;$$06579 = 65536;$$in = $25;
   while(1) {
    $27 = (($$in) + -1)|0;
    $28 = ($$06579|0)>(65535);
    if ($28) {
     $29 = (($$06579) + -65536)|0;
     $30 = $29 >>> 16;
     $31 = $30 << 16;
     $32 = (($$06380) + 1)|0;
     $33 = (($32) + ($30))|0;
     $34 = (($29) - ($31))|0;
     $35 = HEAP32[$0>>2]|0;
     $36 = HEAP32[$17>>2]|0;
     $37 = Math_imul($36, $$162$lcssa)|0;
     $38 = (($35) + ($37)|0);
     $39 = $33 << 2;
     $40 = (($38) + ($39)|0);
     $$1 = $40;$$2 = $33;$$267 = $34;
    } else {
     $$1 = $$06081;$$2 = $$06380;$$267 = $$06579;
    }
    $41 = HEAP32[$$1>>2]|0;
    $42 = $41 & 16777215;
    HEAP32[$$05982>>2] = $42;
    $43 = (($$267) + ($12))|0;
    $44 = ((($$05982)) + 4|0);
    $45 = ($27|0)==(0);
    if ($45) {
     break;
    } else {
     $$05982 = $44;$$06081 = $$1;$$06380 = $$2;$$06579 = $43;$$in = $27;
    }
   }
   $$pre94 = HEAP32[$4>>2]|0;
   $50 = $$pre94;
  }
  $46 = HEAP32[$16>>2]|0;
  $47 = (($48) + ($46)|0);
  $49 = (($50) + -1)|0;
  HEAP32[$4>>2] = $49;
  $51 = ($50|0)==(0);
  if ($51) {
   break;
  }
  $52 = (($$169$lcssa) + ($6))|0;
  $$pre93 = HEAP32[$10>>2]|0;
  $$06186 = $$162$lcssa;$$06885 = $52;$25 = $$pre93;$48 = $47;$53 = $49;$54 = $47;
 }
 HEAP32[$15>>2] = $47;
 return;
}
function _SDL_Blit_ABGR8888_BGR888_Blend($0) {
 $0 = $0|0;
 var $$ = 0, $$$us = 0, $$08695 = 0, $$08695$us = 0, $$08794 = 0, $$08794$us = 0, $$088 = 0, $$088$us = 0, $$089 = 0, $$089$us = 0, $$090 = 0, $$090$us = 0, $$091$us = 0, $$092$us = 0, $$093$us = 0, $$1 = 0, $$1$us = 0, $$3 = 0, $$3$us = 0, $$pre = 0;
 var $$pre100 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $trunc = 0, $trunc$clear = 0, $trunc$clear1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + -1)|0;
 HEAP32[$3>>2] = $5;
 $6 = ($4|0)==(0);
 if ($6) {
  return;
 }
 $7 = ((($0)) + 20|0);
 $8 = ((($0)) + 24|0);
 $9 = ((($0)) + 12|0);
 $10 = ((($0)) + 32|0);
 $11 = $2 & 48;
 $12 = ($11|0)==(0);
 $13 = $2 & 112;
 $trunc = $13&255;
 $$pre = HEAP32[$0>>2]|0;
 $$pre100 = HEAP32[$7>>2]|0;
 $114 = $$pre;$117 = $$pre100;$121 = $$pre100;$122 = $$pre;
 while(1) {
  $14 = HEAP32[$8>>2]|0;
  $15 = (($14) + -1)|0;
  $16 = ($14|0)==(0);
  L6: do {
   if (!($16)) {
    if ($12) {
     $$08695 = $121;$$08794 = $122;$110 = $15;
     while(1) {
      $68 = HEAP32[$$08794>>2]|0;
      $69 = $68 >>> 16;
      $70 = $69 & 255;
      $71 = $68 >>> 8;
      $72 = $71 & 255;
      $73 = $68 & 255;
      $74 = HEAP32[$$08695>>2]|0;
      $75 = $74 >>> 16;
      $76 = $75 & 255;
      $77 = $74 >>> 8;
      $78 = $77 & 255;
      $79 = $74 & 255;
      $trunc$clear1 = $trunc & 127;
      switch ($trunc$clear1<<24>>24) {
      case 16:  {
       $80 = $68 >>> 24;
       $81 = $80 ^ 255;
       $82 = Math_imul($81, $79)|0;
       $83 = (($82>>>0) / 255)&-1;
       $84 = (($73) + ($83))|0;
       $85 = Math_imul($78, $81)|0;
       $86 = (($85>>>0) / 255)&-1;
       $87 = (($72) + ($86))|0;
       $88 = Math_imul($76, $81)|0;
       $89 = (($88>>>0) / 255)&-1;
       $90 = (($70) + ($89))|0;
       $$088 = $90;$$089 = $87;$$090 = $84;
       break;
      }
      case 32:  {
       $91 = (($73) + ($79))|0;
       $92 = ($91>>>0)<(255);
       $$ = $92 ? $91 : 255;
       $93 = (($72) + ($78))|0;
       $94 = ($93>>>0)<(255);
       $$3 = $94 ? $93 : 255;
       $95 = (($70) + ($76))|0;
       $96 = ($95>>>0)<(255);
       $$1 = $96 ? $95 : 255;
       $$088 = $$1;$$089 = $$3;$$090 = $$;
       break;
      }
      case 64:  {
       $97 = Math_imul($73, $79)|0;
       $98 = (($97>>>0) / 255)&-1;
       $99 = Math_imul($72, $78)|0;
       $100 = (($99>>>0) / 255)&-1;
       $101 = Math_imul($70, $76)|0;
       $102 = (($101>>>0) / 255)&-1;
       $$088 = $102;$$089 = $100;$$090 = $98;
       break;
      }
      default: {
       $$088 = $76;$$089 = $78;$$090 = $79;
      }
      }
      $103 = $$088 << 16;
      $104 = $$089 << 8;
      $105 = $104 | $$090;
      $106 = $105 | $103;
      HEAP32[$$08695>>2] = $106;
      $107 = ((($$08794)) + 4|0);
      $108 = ((($$08695)) + 4|0);
      $109 = (($110) + -1)|0;
      $111 = ($110|0)==(0);
      if ($111) {
       break L6;
      } else {
       $$08695 = $108;$$08794 = $107;$110 = $109;
      }
     }
    } else {
     $$08695$us = $121;$$08794$us = $122;$66 = $15;
    }
    while(1) {
     $17 = HEAP32[$$08794$us>>2]|0;
     $18 = $17 >>> 16;
     $19 = $18 & 255;
     $20 = $17 >>> 8;
     $21 = $20 & 255;
     $22 = $17 & 255;
     $23 = $17 >>> 24;
     $24 = HEAP32[$$08695$us>>2]|0;
     $25 = $24 >>> 16;
     $26 = $25 & 255;
     $27 = $24 >>> 8;
     $28 = $27 & 255;
     $29 = $24 & 255;
     $30 = ($23|0)==(255);
     if ($30) {
      $$091$us = $22;$$092$us = $19;$$093$us = $21;
     } else {
      $31 = Math_imul($19, $23)|0;
      $32 = Math_imul($21, $23)|0;
      $33 = Math_imul($22, $23)|0;
      $34 = (($33>>>0) / 255)&-1;
      $35 = (($32>>>0) / 255)&-1;
      $36 = (($31>>>0) / 255)&-1;
      $$091$us = $34;$$092$us = $36;$$093$us = $35;
     }
     $trunc$clear = $trunc & 127;
     switch ($trunc$clear<<24>>24) {
     case 16:  {
      $49 = $23 ^ 255;
      $50 = Math_imul($49, $29)|0;
      $51 = (($50>>>0) / 255)&-1;
      $52 = (($$091$us) + ($51))|0;
      $53 = Math_imul($28, $49)|0;
      $54 = (($53>>>0) / 255)&-1;
      $55 = (($$093$us) + ($54))|0;
      $56 = Math_imul($26, $49)|0;
      $57 = (($56>>>0) / 255)&-1;
      $58 = (($$092$us) + ($57))|0;
      $$088$us = $58;$$089$us = $55;$$090$us = $52;
      break;
     }
     case 32:  {
      $43 = (($$091$us) + ($29))|0;
      $44 = ($43>>>0)<(255);
      $$$us = $44 ? $43 : 255;
      $45 = (($$093$us) + ($28))|0;
      $46 = ($45>>>0)<(255);
      $$3$us = $46 ? $45 : 255;
      $47 = (($$092$us) + ($26))|0;
      $48 = ($47>>>0)<(255);
      $$1$us = $48 ? $47 : 255;
      $$088$us = $$1$us;$$089$us = $$3$us;$$090$us = $$$us;
      break;
     }
     case 64:  {
      $37 = Math_imul($$091$us, $29)|0;
      $38 = (($37>>>0) / 255)&-1;
      $39 = Math_imul($$093$us, $28)|0;
      $40 = (($39>>>0) / 255)&-1;
      $41 = Math_imul($$092$us, $26)|0;
      $42 = (($41>>>0) / 255)&-1;
      $$088$us = $42;$$089$us = $40;$$090$us = $38;
      break;
     }
     default: {
      $$088$us = $26;$$089$us = $28;$$090$us = $29;
     }
     }
     $59 = $$088$us << 16;
     $60 = $$089$us << 8;
     $61 = $60 | $$090$us;
     $62 = $61 | $59;
     HEAP32[$$08695$us>>2] = $62;
     $63 = ((($$08794$us)) + 4|0);
     $64 = ((($$08695$us)) + 4|0);
     $65 = (($66) + -1)|0;
     $67 = ($66|0)==(0);
     if ($67) {
      break L6;
     } else {
      $$08695$us = $64;$$08794$us = $63;$66 = $65;
     }
    }
   }
  } while(0);
  $112 = HEAP32[$9>>2]|0;
  $113 = (($114) + ($112)|0);
  $115 = HEAP32[$10>>2]|0;
  $116 = (($117) + ($115)|0);
  $118 = HEAP32[$3>>2]|0;
  $119 = (($118) + -1)|0;
  HEAP32[$3>>2] = $119;
  $120 = ($118|0)==(0);
  if ($120) {
   break;
  } else {
   $114 = $113;$117 = $116;$121 = $116;$122 = $113;
  }
 }
 HEAP32[$0>>2] = $113;
 HEAP32[$7>>2] = $116;
 return;
}
function _SDL_Blit_ABGR8888_BGR888_Blend_Scale($0) {
 $0 = $0|0;
 var $$ = 0, $$0113143 = 0, $$0114142 = 0, $$0116 = 0, $$0117 = 0, $$0118141 = 0, $$0120147 = 0, $$0122140 = 0, $$0125146 = 0, $$0127 = 0, $$0128 = 0, $$0129 = 0, $$0130 = 0, $$1 = 0, $$1115 = 0, $$1121$lcssa = 0, $$1126$lcssa = 0, $$2 = 0, $$2124 = 0, $$3 = 0;
 var $$in = 0, $$pre = 0, $$pre154 = 0, $$pre155 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $trunc = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 << 16;
 $6 = ((($0)) + 28|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5|0) / ($7|0))&-1;
 $9 = ((($0)) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10 << 16;
 $12 = ((($0)) + 24|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($11|0) / ($13|0))&-1;
 $15 = (($7) + -1)|0;
 HEAP32[$6>>2] = $15;
 $16 = ($7|0)==(0);
 if ($16) {
  return;
 }
 $17 = ((($0)) + 20|0);
 $18 = ((($0)) + 32|0);
 $19 = $2 & 48;
 $20 = ($19|0)!=(0);
 $21 = $2 & 112;
 $trunc = $21&255;
 $22 = ((($0)) + 12|0);
 $$pre = HEAP32[$17>>2]|0;
 $$0120147 = 0;$$0125146 = 0;$102 = $15;$103 = $$pre;$30 = $13;$97 = $$pre;
 while(1) {
  $23 = ($$0120147|0)>(65535);
  if ($23) {
   $24 = (($$0120147) + -65536)|0;
   $25 = $24 >>> 16;
   $26 = $25 << 16;
   $27 = (($$0125146) + 1)|0;
   $28 = (($27) + ($25))|0;
   $29 = (($24) - ($26))|0;
   $$1121$lcssa = $29;$$1126$lcssa = $28;
  } else {
   $$1121$lcssa = $$0120147;$$1126$lcssa = $$0125146;
  }
  $31 = ($30|0)==(0);
  if ($31) {
   $99 = $102;
  } else {
   $$0113143 = $103;$$0114142 = 0;$$0118141 = 65536;$$0122140 = -1;$$in = $30;
   while(1) {
    $32 = (($$in) + -1)|0;
    $33 = ($$0118141|0)>(65535);
    if ($33) {
     $34 = (($$0118141) + -65536)|0;
     $35 = $34 >>> 16;
     $36 = $35 << 16;
     $37 = (($$0122140) + 1)|0;
     $38 = (($37) + ($35))|0;
     $39 = (($34) - ($36))|0;
     $40 = HEAP32[$0>>2]|0;
     $41 = HEAP32[$22>>2]|0;
     $42 = Math_imul($41, $$1126$lcssa)|0;
     $43 = (($40) + ($42)|0);
     $44 = $38 << 2;
     $45 = (($43) + ($44)|0);
     $$1115 = $45;$$2 = $39;$$2124 = $38;
    } else {
     $$1115 = $$0114142;$$2 = $$0118141;$$2124 = $$0122140;
    }
    $46 = HEAP32[$$1115>>2]|0;
    $47 = $46 >>> 16;
    $48 = $47 & 255;
    $49 = $46 >>> 8;
    $50 = $49 & 255;
    $51 = $46 & 255;
    $52 = $46 >>> 24;
    $53 = HEAP32[$$0113143>>2]|0;
    $54 = $53 >>> 16;
    $55 = $54 & 255;
    $56 = $53 >>> 8;
    $57 = $56 & 255;
    $58 = $53 & 255;
    $59 = ($52|0)!=(255);
    $or$cond = $20 & $59;
    if ($or$cond) {
     $60 = Math_imul($48, $52)|0;
     $61 = Math_imul($50, $52)|0;
     $62 = Math_imul($51, $52)|0;
     $63 = (($62>>>0) / 255)&-1;
     $64 = (($61>>>0) / 255)&-1;
     $65 = (($60>>>0) / 255)&-1;
     $$0116 = $63;$$0117 = $64;$$0130 = $65;
    } else {
     $$0116 = $51;$$0117 = $50;$$0130 = $48;
    }
    $trunc$clear = $trunc & 127;
    switch ($trunc$clear<<24>>24) {
    case 16:  {
     $66 = $52 ^ 255;
     $67 = Math_imul($66, $58)|0;
     $68 = (($67>>>0) / 255)&-1;
     $69 = (($$0116) + ($68))|0;
     $70 = Math_imul($57, $66)|0;
     $71 = (($70>>>0) / 255)&-1;
     $72 = (($$0117) + ($71))|0;
     $73 = Math_imul($55, $66)|0;
     $74 = (($73>>>0) / 255)&-1;
     $75 = (($$0130) + ($74))|0;
     $$0127 = $75;$$0128 = $72;$$0129 = $69;
     break;
    }
    case 32:  {
     $76 = (($$0116) + ($58))|0;
     $77 = ($76>>>0)<(255);
     $$ = $77 ? $76 : 255;
     $78 = (($$0117) + ($57))|0;
     $79 = ($78>>>0)<(255);
     $$3 = $79 ? $78 : 255;
     $80 = (($$0130) + ($55))|0;
     $81 = ($80>>>0)<(255);
     $$1 = $81 ? $80 : 255;
     $$0127 = $$1;$$0128 = $$3;$$0129 = $$;
     break;
    }
    case 64:  {
     $82 = Math_imul($$0116, $58)|0;
     $83 = (($82>>>0) / 255)&-1;
     $84 = Math_imul($$0117, $57)|0;
     $85 = (($84>>>0) / 255)&-1;
     $86 = Math_imul($$0130, $55)|0;
     $87 = (($86>>>0) / 255)&-1;
     $$0127 = $87;$$0128 = $85;$$0129 = $83;
     break;
    }
    default: {
     $$0127 = $55;$$0128 = $57;$$0129 = $58;
    }
    }
    $88 = $$0127 << 16;
    $89 = $$0128 << 8;
    $90 = $89 | $$0129;
    $91 = $90 | $88;
    HEAP32[$$0113143>>2] = $91;
    $92 = (($$2) + ($14))|0;
    $93 = ((($$0113143)) + 4|0);
    $94 = ($32|0)==(0);
    if ($94) {
     break;
    } else {
     $$0113143 = $93;$$0114142 = $$1115;$$0118141 = $92;$$0122140 = $$2124;$$in = $32;
    }
   }
   $$pre155 = HEAP32[$6>>2]|0;
   $99 = $$pre155;
  }
  $95 = HEAP32[$18>>2]|0;
  $96 = (($97) + ($95)|0);
  $98 = (($99) + -1)|0;
  HEAP32[$6>>2] = $98;
  $100 = ($99|0)==(0);
  if ($100) {
   break;
  }
  $101 = (($$1121$lcssa) + ($8))|0;
  $$pre154 = HEAP32[$12>>2]|0;
  $$0120147 = $101;$$0125146 = $$1126$lcssa;$102 = $98;$103 = $96;$30 = $$pre154;$97 = $96;
 }
 HEAP32[$17>>2] = $96;
 return;
}
function _SDL_Blit_ABGR8888_BGR888_Modulate($0) {
 $0 = $0|0;
 var $$05157 = 0, $$05157$us$us = 0, $$05256 = 0, $$05256$us$us = 0, $$in = 0, $$in68 = 0, $$lcssa77$sink = 0, $$lcssa78$sink = 0, $$pre71 = 0, $$pre72 = 0, $$pre73 = 0, $$pre74 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = ((($0)) + 61|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = ((($0)) + 62|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = ((($0)) + 28|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($13) + -1)|0;
 HEAP32[$12>>2] = $14;
 $15 = ($13|0)==(0);
 if ($15) {
  return;
 }
 $16 = ((($0)) + 20|0);
 $17 = ((($0)) + 24|0);
 $18 = ((($0)) + 12|0);
 $19 = ((($0)) + 32|0);
 $20 = $2 & 1;
 $21 = ($20|0)==(0);
 $$pre72 = HEAP32[$0>>2]|0;
 $$pre73 = HEAP32[$16>>2]|0;
 if ($21) {
  $26 = $$pre72;$29 = $$pre73;$70 = $14;$71 = $$pre73;$72 = $$pre72;
  while(1) {
   $22 = HEAP32[$17>>2]|0;
   $23 = ($22|0)==(0);
   if ($23) {
    $31 = $70;
   } else {
    $$05157$us$us = $71;$$05256$us$us = $72;$$in68 = $22;
    while(1) {
     $33 = (($$in68) + -1)|0;
     $34 = HEAP32[$$05256$us$us>>2]|0;
     $35 = $34 & 16777215;
     HEAP32[$$05157$us$us>>2] = $35;
     $36 = ((($$05256$us$us)) + 4|0);
     $37 = ((($$05157$us$us)) + 4|0);
     $38 = ($33|0)==(0);
     if ($38) {
      break;
     } else {
      $$05157$us$us = $37;$$05256$us$us = $36;$$in68 = $33;
     }
    }
    $$pre74 = HEAP32[$12>>2]|0;
    $31 = $$pre74;
   }
   $24 = HEAP32[$18>>2]|0;
   $25 = (($26) + ($24)|0);
   $27 = HEAP32[$19>>2]|0;
   $28 = (($29) + ($27)|0);
   $30 = (($31) + -1)|0;
   HEAP32[$12>>2] = $30;
   $32 = ($31|0)==(0);
   if ($32) {
    $$lcssa77$sink = $25;$$lcssa78$sink = $28;
    break;
   } else {
    $26 = $25;$29 = $28;$70 = $30;$71 = $28;$72 = $25;
   }
  }
 } else {
  $63 = $$pre72;$66 = $$pre73;$73 = $14;$74 = $$pre73;$75 = $$pre72;
  while(1) {
   $39 = HEAP32[$17>>2]|0;
   $40 = ($39|0)==(0);
   if ($40) {
    $68 = $73;
   } else {
    $$05157 = $74;$$05256 = $75;$$in = $39;
    while(1) {
     $41 = (($$in) + -1)|0;
     $42 = HEAP32[$$05256>>2]|0;
     $43 = $42 >>> 16;
     $44 = $43 & 255;
     $45 = $42 >>> 8;
     $46 = $45 & 255;
     $47 = $42 & 255;
     $48 = Math_imul($44, $11)|0;
     $49 = Math_imul($46, $8)|0;
     $50 = Math_imul($47, $5)|0;
     $51 = (($50>>>0) / 255)&-1;
     $52 = (($49>>>0) / 255)&-1;
     $53 = (($48>>>0) / 255)&-1;
     $54 = $53 << 16;
     $55 = $52 << 8;
     $56 = $55 | $51;
     $57 = $56 | $54;
     HEAP32[$$05157>>2] = $57;
     $58 = ((($$05256)) + 4|0);
     $59 = ((($$05157)) + 4|0);
     $60 = ($41|0)==(0);
     if ($60) {
      break;
     } else {
      $$05157 = $59;$$05256 = $58;$$in = $41;
     }
    }
    $$pre71 = HEAP32[$12>>2]|0;
    $68 = $$pre71;
   }
   $61 = HEAP32[$18>>2]|0;
   $62 = (($63) + ($61)|0);
   $64 = HEAP32[$19>>2]|0;
   $65 = (($66) + ($64)|0);
   $67 = (($68) + -1)|0;
   HEAP32[$12>>2] = $67;
   $69 = ($68|0)==(0);
   if ($69) {
    $$lcssa77$sink = $62;$$lcssa78$sink = $65;
    break;
   } else {
    $63 = $62;$66 = $65;$73 = $67;$74 = $65;$75 = $62;
   }
  }
 }
 HEAP32[$0>>2] = $$lcssa77$sink;
 HEAP32[$16>>2] = $$lcssa78$sink;
 return;
}
function _SDL_Blit_ABGR8888_BGR888_Modulate_Scale($0) {
 $0 = $0|0;
 var $$078104 = 0, $$078104$us = 0, $$079103 = 0, $$079103$us = 0, $$081102 = 0, $$081102$us = 0, $$083108 = 0, $$085101 = 0, $$085101$us = 0, $$088107 = 0, $$1 = 0, $$1$us = 0, $$184$lcssa = 0, $$189$lcssa = 0, $$2 = 0, $$2$us = 0, $$287 = 0, $$287$us = 0, $$pre = 0, $$pre118 = 0;
 var $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = ((($0)) + 61|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = ((($0)) + 62|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = ((($0)) + 8|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13 << 16;
 $15 = ((($0)) + 28|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($14|0) / ($16|0))&-1;
 $18 = ((($0)) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = $19 << 16;
 $21 = ((($0)) + 24|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($20|0) / ($22|0))&-1;
 $24 = (($16) + -1)|0;
 HEAP32[$15>>2] = $24;
 $25 = ($16|0)==(0);
 if ($25) {
  return;
 }
 $26 = ((($0)) + 20|0);
 $27 = ((($0)) + 32|0);
 $28 = $2 & 1;
 $29 = ($28|0)==(0);
 $30 = ((($0)) + 12|0);
 $$pre = HEAP32[$26>>2]|0;
 $$083108 = 0;$$088107 = 0;$102 = $$pre;$39 = $22;$97 = $$pre;
 while(1) {
  $31 = ($$083108|0)>(65535);
  if ($31) {
   $32 = (($$083108) + -65536)|0;
   $33 = $32 >>> 16;
   $34 = $33 << 16;
   $35 = (($$088107) + 1)|0;
   $36 = (($35) + ($33))|0;
   $37 = (($32) - ($34))|0;
   $$184$lcssa = $37;$$189$lcssa = $36;
  } else {
   $$184$lcssa = $$083108;$$189$lcssa = $$088107;
  }
  $38 = (($39) + -1)|0;
  $40 = ($39|0)==(0);
  if (!($40)) {
   if ($29) {
    $$078104$us = $102;$$079103$us = 0;$$081102$us = 65536;$$085101$us = -1;$59 = $38;
    while(1) {
     $41 = ($$081102$us|0)>(65535);
     if ($41) {
      $42 = (($$081102$us) + -65536)|0;
      $43 = $42 >>> 16;
      $44 = $43 << 16;
      $45 = (($$085101$us) + 1)|0;
      $46 = (($45) + ($43))|0;
      $47 = (($42) - ($44))|0;
      $48 = HEAP32[$0>>2]|0;
      $49 = HEAP32[$30>>2]|0;
      $50 = Math_imul($49, $$189$lcssa)|0;
      $51 = (($48) + ($50)|0);
      $52 = $46 << 2;
      $53 = (($51) + ($52)|0);
      $$1$us = $53;$$2$us = $47;$$287$us = $46;
     } else {
      $$1$us = $$079103$us;$$2$us = $$081102$us;$$287$us = $$085101$us;
     }
     $54 = HEAP32[$$1$us>>2]|0;
     $55 = $54 & 16777215;
     HEAP32[$$078104$us>>2] = $55;
     $56 = (($$2$us) + ($23))|0;
     $57 = ((($$078104$us)) + 4|0);
     $58 = (($59) + -1)|0;
     $60 = ($59|0)==(0);
     if ($60) {
      break;
     } else {
      $$078104$us = $57;$$079103$us = $$1$us;$$081102$us = $56;$$085101$us = $$287$us;$59 = $58;
     }
    }
   } else {
    $$078104 = $102;$$079103 = 0;$$081102 = 65536;$$085101 = -1;$93 = $38;
    while(1) {
     $61 = ($$081102|0)>(65535);
     if ($61) {
      $62 = (($$081102) + -65536)|0;
      $63 = $62 >>> 16;
      $64 = $63 << 16;
      $65 = (($$085101) + 1)|0;
      $66 = (($65) + ($63))|0;
      $67 = (($62) - ($64))|0;
      $68 = HEAP32[$0>>2]|0;
      $69 = HEAP32[$30>>2]|0;
      $70 = Math_imul($69, $$189$lcssa)|0;
      $71 = (($68) + ($70)|0);
      $72 = $66 << 2;
      $73 = (($71) + ($72)|0);
      $$1 = $73;$$2 = $67;$$287 = $66;
     } else {
      $$1 = $$079103;$$2 = $$081102;$$287 = $$085101;
     }
     $74 = HEAP32[$$1>>2]|0;
     $75 = $74 >>> 16;
     $76 = $75 & 255;
     $77 = $74 >>> 8;
     $78 = $77 & 255;
     $79 = $74 & 255;
     $80 = Math_imul($76, $11)|0;
     $81 = Math_imul($78, $8)|0;
     $82 = Math_imul($79, $5)|0;
     $83 = (($82>>>0) / 255)&-1;
     $84 = (($81>>>0) / 255)&-1;
     $85 = (($80>>>0) / 255)&-1;
     $86 = $85 << 16;
     $87 = $84 << 8;
     $88 = $86 | $87;
     $89 = $88 | $83;
     HEAP32[$$078104>>2] = $89;
     $90 = (($$2) + ($23))|0;
     $91 = ((($$078104)) + 4|0);
     $92 = (($93) + -1)|0;
     $94 = ($93|0)==(0);
     if ($94) {
      break;
     } else {
      $$078104 = $91;$$079103 = $$1;$$081102 = $90;$$085101 = $$287;$93 = $92;
     }
    }
   }
  }
  $95 = HEAP32[$27>>2]|0;
  $96 = (($97) + ($95)|0);
  $98 = HEAP32[$15>>2]|0;
  $99 = (($98) + -1)|0;
  HEAP32[$15>>2] = $99;
  $100 = ($98|0)==(0);
  if ($100) {
   break;
  }
  $101 = (($$184$lcssa) + ($17))|0;
  $$pre118 = HEAP32[$21>>2]|0;
  $$083108 = $101;$$088107 = $$189$lcssa;$102 = $96;$39 = $$pre118;$97 = $96;
 }
 HEAP32[$26>>2] = $96;
 return;
}
function _SDL_Blit_ABGR8888_BGR888_Modulate_Blend($0) {
 $0 = $0|0;
 var $$ = 0, $$0108121 = 0, $$0109120 = 0, $$0110 = 0, $$0111 = 0, $$0112 = 0, $$0113 = 0, $$0114 = 0, $$0116 = 0, $$0118 = 0, $$1 = 0, $$1115 = 0, $$1117 = 0, $$1119 = 0, $$3 = 0, $$in = 0, $$pre = 0, $$pre125 = 0, $$pre126 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $or$cond = 0, $trunc = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = ((($0)) + 61|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = ((($0)) + 62|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = ((($0)) + 63|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = $13&255;
 $15 = ((($0)) + 28|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + -1)|0;
 HEAP32[$15>>2] = $17;
 $18 = ($16|0)==(0);
 if ($18) {
  return;
 }
 $19 = ((($0)) + 20|0);
 $20 = ((($0)) + 24|0);
 $21 = ((($0)) + 12|0);
 $22 = ((($0)) + 32|0);
 $23 = $2 & 1;
 $24 = ($23|0)==(0);
 $25 = $2 & 2;
 $26 = ($25|0)==(0);
 $27 = $2 & 48;
 $28 = ($27|0)!=(0);
 $29 = $2 & 112;
 $trunc = $29&255;
 $$pre = HEAP32[$0>>2]|0;
 $$pre125 = HEAP32[$19>>2]|0;
 $100 = $$pre125;$101 = $$pre;$92 = $$pre;$95 = $$pre125;$99 = $17;
 while(1) {
  $30 = HEAP32[$20>>2]|0;
  $31 = ($30|0)==(0);
  if ($31) {
   $97 = $99;
  } else {
   $$0108121 = $100;$$0109120 = $101;$$in = $30;
   while(1) {
    $32 = (($$in) + -1)|0;
    $33 = HEAP32[$$0109120>>2]|0;
    $34 = $33 >>> 16;
    $35 = $34 & 255;
    $36 = $33 >>> 8;
    $37 = $36 & 255;
    $38 = $33 & 255;
    $39 = $33 >>> 24;
    $40 = HEAP32[$$0108121>>2]|0;
    $41 = $40 >>> 16;
    $42 = $41 & 255;
    $43 = $40 >>> 8;
    $44 = $43 & 255;
    $45 = $40 & 255;
    if ($24) {
     $$0114 = $35;$$0116 = $37;$$0118 = $38;
    } else {
     $46 = Math_imul($35, $11)|0;
     $47 = Math_imul($37, $8)|0;
     $48 = Math_imul($38, $5)|0;
     $49 = (($48>>>0) / 255)&-1;
     $50 = (($47>>>0) / 255)&-1;
     $51 = (($46>>>0) / 255)&-1;
     $$0114 = $51;$$0116 = $50;$$0118 = $49;
    }
    $52 = Math_imul($39, $14)|0;
    $53 = (($52>>>0) / 255)&-1;
    $$0113 = $26 ? $39 : $53;
    $54 = ($$0113>>>0)<(255);
    $or$cond = $28 & $54;
    if ($or$cond) {
     $55 = Math_imul($$0114, $$0113)|0;
     $56 = Math_imul($$0116, $$0113)|0;
     $57 = Math_imul($$0118, $$0113)|0;
     $58 = (($57>>>0) / 255)&-1;
     $59 = (($56>>>0) / 255)&-1;
     $60 = (($55>>>0) / 255)&-1;
     $$1115 = $60;$$1117 = $59;$$1119 = $58;
    } else {
     $$1115 = $$0114;$$1117 = $$0116;$$1119 = $$0118;
    }
    $trunc$clear = $trunc & 127;
    switch ($trunc$clear<<24>>24) {
    case 16:  {
     $61 = (255 - ($$0113))|0;
     $62 = Math_imul($61, $45)|0;
     $63 = (($62>>>0) / 255)&-1;
     $64 = (($$1119) + ($63))|0;
     $65 = Math_imul($61, $44)|0;
     $66 = (($65>>>0) / 255)&-1;
     $67 = (($$1117) + ($66))|0;
     $68 = Math_imul($61, $42)|0;
     $69 = (($68>>>0) / 255)&-1;
     $70 = (($$1115) + ($69))|0;
     $$0110 = $70;$$0111 = $67;$$0112 = $64;
     break;
    }
    case 32:  {
     $71 = (($$1119) + ($45))|0;
     $72 = ($71>>>0)<(255);
     $$ = $72 ? $71 : 255;
     $73 = (($$1117) + ($44))|0;
     $74 = ($73>>>0)<(255);
     $$3 = $74 ? $73 : 255;
     $75 = (($$1115) + ($42))|0;
     $76 = ($75>>>0)<(255);
     $$1 = $76 ? $75 : 255;
     $$0110 = $$1;$$0111 = $$3;$$0112 = $$;
     break;
    }
    case 64:  {
     $77 = Math_imul($$1119, $45)|0;
     $78 = (($77>>>0) / 255)&-1;
     $79 = Math_imul($$1117, $44)|0;
     $80 = (($79>>>0) / 255)&-1;
     $81 = Math_imul($$1115, $42)|0;
     $82 = (($81>>>0) / 255)&-1;
     $$0110 = $82;$$0111 = $80;$$0112 = $78;
     break;
    }
    default: {
     $$0110 = $42;$$0111 = $44;$$0112 = $45;
    }
    }
    $83 = $$0110 << 16;
    $84 = $$0111 << 8;
    $85 = $84 | $$0112;
    $86 = $85 | $83;
    HEAP32[$$0108121>>2] = $86;
    $87 = ((($$0109120)) + 4|0);
    $88 = ((($$0108121)) + 4|0);
    $89 = ($32|0)==(0);
    if ($89) {
     break;
    } else {
     $$0108121 = $88;$$0109120 = $87;$$in = $32;
    }
   }
   $$pre126 = HEAP32[$15>>2]|0;
   $97 = $$pre126;
  }
  $90 = HEAP32[$21>>2]|0;
  $91 = (($92) + ($90)|0);
  $93 = HEAP32[$22>>2]|0;
  $94 = (($95) + ($93)|0);
  $96 = (($97) + -1)|0;
  HEAP32[$15>>2] = $96;
  $98 = ($97|0)==(0);
  if ($98) {
   break;
  } else {
   $100 = $94;$101 = $91;$92 = $91;$95 = $94;$99 = $96;
  }
 }
 HEAP32[$0>>2] = $91;
 HEAP32[$19>>2] = $94;
 return;
}
function _SDL_Blit_ABGR8888_BGR888_Modulate_Blend_Scale($0) {
 $0 = $0|0;
 var $$ = 0, $$0135169 = 0, $$0136168 = 0, $$0138 = 0, $$0140 = 0, $$0142167 = 0, $$0144173 = 0, $$0146166 = 0, $$0149172 = 0, $$0151 = 0, $$0152 = 0, $$0153 = 0, $$0154 = 0, $$0155 = 0, $$1 = 0, $$1137 = 0, $$1139 = 0, $$1141 = 0, $$1145$lcssa = 0, $$1150$lcssa = 0;
 var $$1156 = 0, $$2 = 0, $$2148 = 0, $$3 = 0, $$in = 0, $$pre = 0, $$pre180 = 0, $$pre181 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $trunc = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = ((($0)) + 61|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = ((($0)) + 62|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = ((($0)) + 63|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = $13&255;
 $15 = ((($0)) + 8|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $16 << 16;
 $18 = ((($0)) + 28|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($17|0) / ($19|0))&-1;
 $21 = ((($0)) + 4|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = $22 << 16;
 $24 = ((($0)) + 24|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($23|0) / ($25|0))&-1;
 $27 = (($19) + -1)|0;
 HEAP32[$18>>2] = $27;
 $28 = ($19|0)==(0);
 if ($28) {
  return;
 }
 $29 = ((($0)) + 20|0);
 $30 = ((($0)) + 32|0);
 $31 = $2 & 1;
 $32 = ($31|0)==(0);
 $33 = $2 & 2;
 $34 = ($33|0)==(0);
 $35 = $2 & 48;
 $36 = ($35|0)!=(0);
 $37 = $2 & 112;
 $trunc = $37&255;
 $38 = ((($0)) + 12|0);
 $$pre = HEAP32[$29>>2]|0;
 $$0144173 = 0;$$0149172 = 0;$121 = $$pre;$126 = $27;$127 = $$pre;$46 = $25;
 while(1) {
  $39 = ($$0144173|0)>(65535);
  if ($39) {
   $40 = (($$0144173) + -65536)|0;
   $41 = $40 >>> 16;
   $42 = $41 << 16;
   $43 = (($$0149172) + 1)|0;
   $44 = (($43) + ($41))|0;
   $45 = (($40) - ($42))|0;
   $$1145$lcssa = $45;$$1150$lcssa = $44;
  } else {
   $$1145$lcssa = $$0144173;$$1150$lcssa = $$0149172;
  }
  $47 = ($46|0)==(0);
  if ($47) {
   $123 = $126;
  } else {
   $$0135169 = $127;$$0136168 = 0;$$0142167 = 65536;$$0146166 = -1;$$in = $46;
   while(1) {
    $48 = (($$in) + -1)|0;
    $49 = ($$0142167|0)>(65535);
    if ($49) {
     $50 = (($$0142167) + -65536)|0;
     $51 = $50 >>> 16;
     $52 = $51 << 16;
     $53 = (($$0146166) + 1)|0;
     $54 = (($53) + ($51))|0;
     $55 = (($50) - ($52))|0;
     $56 = HEAP32[$0>>2]|0;
     $57 = HEAP32[$38>>2]|0;
     $58 = Math_imul($57, $$1150$lcssa)|0;
     $59 = (($56) + ($58)|0);
     $60 = $54 << 2;
     $61 = (($59) + ($60)|0);
     $$1137 = $61;$$2 = $55;$$2148 = $54;
    } else {
     $$1137 = $$0136168;$$2 = $$0142167;$$2148 = $$0146166;
    }
    $62 = HEAP32[$$1137>>2]|0;
    $63 = $62 >>> 16;
    $64 = $63 & 255;
    $65 = $62 >>> 8;
    $66 = $65 & 255;
    $67 = $62 & 255;
    $68 = $62 >>> 24;
    $69 = HEAP32[$$0135169>>2]|0;
    $70 = $69 >>> 16;
    $71 = $70 & 255;
    $72 = $69 >>> 8;
    $73 = $72 & 255;
    $74 = $69 & 255;
    if ($32) {
     $$0138 = $67;$$0140 = $66;$$0155 = $64;
    } else {
     $75 = Math_imul($64, $11)|0;
     $76 = Math_imul($66, $8)|0;
     $77 = Math_imul($67, $5)|0;
     $78 = (($77>>>0) / 255)&-1;
     $79 = (($76>>>0) / 255)&-1;
     $80 = (($75>>>0) / 255)&-1;
     $$0138 = $78;$$0140 = $79;$$0155 = $80;
    }
    $81 = Math_imul($68, $14)|0;
    $82 = (($81>>>0) / 255)&-1;
    $$0154 = $34 ? $68 : $82;
    $83 = ($$0154>>>0)<(255);
    $or$cond = $36 & $83;
    if ($or$cond) {
     $84 = Math_imul($$0155, $$0154)|0;
     $85 = Math_imul($$0140, $$0154)|0;
     $86 = Math_imul($$0138, $$0154)|0;
     $87 = (($86>>>0) / 255)&-1;
     $88 = (($85>>>0) / 255)&-1;
     $89 = (($84>>>0) / 255)&-1;
     $$1139 = $87;$$1141 = $88;$$1156 = $89;
    } else {
     $$1139 = $$0138;$$1141 = $$0140;$$1156 = $$0155;
    }
    $trunc$clear = $trunc & 127;
    switch ($trunc$clear<<24>>24) {
    case 16:  {
     $90 = (255 - ($$0154))|0;
     $91 = Math_imul($90, $74)|0;
     $92 = (($91>>>0) / 255)&-1;
     $93 = (($$1139) + ($92))|0;
     $94 = Math_imul($90, $73)|0;
     $95 = (($94>>>0) / 255)&-1;
     $96 = (($$1141) + ($95))|0;
     $97 = Math_imul($90, $71)|0;
     $98 = (($97>>>0) / 255)&-1;
     $99 = (($$1156) + ($98))|0;
     $$0151 = $99;$$0152 = $96;$$0153 = $93;
     break;
    }
    case 32:  {
     $100 = (($$1139) + ($74))|0;
     $101 = ($100>>>0)<(255);
     $$ = $101 ? $100 : 255;
     $102 = (($$1141) + ($73))|0;
     $103 = ($102>>>0)<(255);
     $$3 = $103 ? $102 : 255;
     $104 = (($$1156) + ($71))|0;
     $105 = ($104>>>0)<(255);
     $$1 = $105 ? $104 : 255;
     $$0151 = $$1;$$0152 = $$3;$$0153 = $$;
     break;
    }
    case 64:  {
     $106 = Math_imul($$1139, $74)|0;
     $107 = (($106>>>0) / 255)&-1;
     $108 = Math_imul($$1141, $73)|0;
     $109 = (($108>>>0) / 255)&-1;
     $110 = Math_imul($$1156, $71)|0;
     $111 = (($110>>>0) / 255)&-1;
     $$0151 = $111;$$0152 = $109;$$0153 = $107;
     break;
    }
    default: {
     $$0151 = $71;$$0152 = $73;$$0153 = $74;
    }
    }
    $112 = $$0151 << 16;
    $113 = $$0152 << 8;
    $114 = $113 | $$0153;
    $115 = $114 | $112;
    HEAP32[$$0135169>>2] = $115;
    $116 = (($$2) + ($26))|0;
    $117 = ((($$0135169)) + 4|0);
    $118 = ($48|0)==(0);
    if ($118) {
     break;
    } else {
     $$0135169 = $117;$$0136168 = $$1137;$$0142167 = $116;$$0146166 = $$2148;$$in = $48;
    }
   }
   $$pre181 = HEAP32[$18>>2]|0;
   $123 = $$pre181;
  }
  $119 = HEAP32[$30>>2]|0;
  $120 = (($121) + ($119)|0);
  $122 = (($123) + -1)|0;
  HEAP32[$18>>2] = $122;
  $124 = ($123|0)==(0);
  if ($124) {
   break;
  }
  $125 = (($$1145$lcssa) + ($20))|0;
  $$pre180 = HEAP32[$24>>2]|0;
  $$0144173 = $125;$$0149172 = $$1150$lcssa;$121 = $120;$126 = $122;$127 = $120;$46 = $$pre180;
 }
 HEAP32[$29>>2] = $120;
 return;
}
function _SDL_Blit_ABGR8888_ARGB8888_Scale($0) {
 $0 = $0|0;
 var $$06386 = 0, $$06485 = 0, $$06590 = 0, $$06784 = 0, $$06983 = 0, $$07289 = 0, $$1 = 0, $$166$lcssa = 0, $$173$lcssa = 0, $$2 = 0, $$271 = 0, $$in = 0, $$pre = 0, $$pre97 = 0, $$pre98 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 << 16;
 $4 = ((($0)) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3|0) / ($5|0))&-1;
 $7 = ((($0)) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 << 16;
 $10 = ((($0)) + 24|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($9|0) / ($11|0))&-1;
 $13 = (($5) + -1)|0;
 HEAP32[$4>>2] = $13;
 $14 = ($5|0)==(0);
 if ($14) {
  return;
 }
 $15 = ((($0)) + 20|0);
 $16 = ((($0)) + 32|0);
 $17 = ((($0)) + 12|0);
 $$pre = HEAP32[$15>>2]|0;
 $$06590 = 0;$$07289 = 0;$25 = $11;$54 = $$pre;$59 = $13;$60 = $$pre;
 while(1) {
  $18 = ($$07289|0)>(65535);
  if ($18) {
   $19 = (($$07289) + -65536)|0;
   $20 = $19 >>> 16;
   $21 = $20 << 16;
   $22 = (($$06590) + 1)|0;
   $23 = (($22) + ($20))|0;
   $24 = (($19) - ($21))|0;
   $$166$lcssa = $23;$$173$lcssa = $24;
  } else {
   $$166$lcssa = $$06590;$$173$lcssa = $$07289;
  }
  $26 = ($25|0)==(0);
  if ($26) {
   $56 = $59;
  } else {
   $$06386 = $60;$$06485 = 0;$$06784 = -1;$$06983 = 65536;$$in = $25;
   while(1) {
    $27 = (($$in) + -1)|0;
    $28 = ($$06983|0)>(65535);
    if ($28) {
     $29 = (($$06983) + -65536)|0;
     $30 = $29 >>> 16;
     $31 = $30 << 16;
     $32 = (($$06784) + 1)|0;
     $33 = (($32) + ($30))|0;
     $34 = (($29) - ($31))|0;
     $35 = HEAP32[$0>>2]|0;
     $36 = HEAP32[$17>>2]|0;
     $37 = Math_imul($36, $$166$lcssa)|0;
     $38 = (($35) + ($37)|0);
     $39 = $33 << 2;
     $40 = (($38) + ($39)|0);
     $$1 = $40;$$2 = $33;$$271 = $34;
    } else {
     $$1 = $$06485;$$2 = $$06784;$$271 = $$06983;
    }
    $41 = HEAP32[$$1>>2]|0;
    $42 = $41 >>> 16;
    $43 = $42 & 255;
    $44 = $41 << 16;
    $45 = $44 & 16711680;
    $46 = $41 & -16711936;
    $47 = $46 | $45;
    $48 = $47 | $43;
    HEAP32[$$06386>>2] = $48;
    $49 = (($$271) + ($12))|0;
    $50 = ((($$06386)) + 4|0);
    $51 = ($27|0)==(0);
    if ($51) {
     break;
    } else {
     $$06386 = $50;$$06485 = $$1;$$06784 = $$2;$$06983 = $49;$$in = $27;
    }
   }
   $$pre98 = HEAP32[$4>>2]|0;
   $56 = $$pre98;
  }
  $52 = HEAP32[$16>>2]|0;
  $53 = (($54) + ($52)|0);
  $55 = (($56) + -1)|0;
  HEAP32[$4>>2] = $55;
  $57 = ($56|0)==(0);
  if ($57) {
   break;
  }
  $58 = (($$173$lcssa) + ($6))|0;
  $$pre97 = HEAP32[$10>>2]|0;
  $$06590 = $$166$lcssa;$$07289 = $58;$25 = $$pre97;$54 = $53;$59 = $55;$60 = $53;
 }
 HEAP32[$15>>2] = $53;
 return;
}
function _SDL_Blit_ABGR8888_ARGB8888_Blend($0) {
 $0 = $0|0;
 var $$ = 0, $$$us = 0, $$0100$us = 0, $$0101$us = 0, $$093103 = 0, $$093103$us = 0, $$094102 = 0, $$094102$us = 0, $$095 = 0, $$095$us = 0, $$096 = 0, $$096$us = 0, $$097 = 0, $$097$us = 0, $$098 = 0, $$098$us = 0, $$099$us = 0, $$1 = 0, $$1$us = 0, $$3 = 0;
 var $$3$us = 0, $$pre = 0, $$pre108 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $trunc = 0, $trunc$clear = 0, $trunc$clear1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + -1)|0;
 HEAP32[$3>>2] = $5;
 $6 = ($4|0)==(0);
 if ($6) {
  return;
 }
 $7 = ((($0)) + 20|0);
 $8 = ((($0)) + 24|0);
 $9 = ((($0)) + 12|0);
 $10 = ((($0)) + 32|0);
 $11 = $2 & 48;
 $12 = ($11|0)==(0);
 $13 = $2 & 112;
 $trunc = $13&255;
 $$pre = HEAP32[$0>>2]|0;
 $$pre108 = HEAP32[$7>>2]|0;
 $126 = $$pre;$129 = $$pre108;$133 = $$pre108;$134 = $$pre;
 while(1) {
  $14 = HEAP32[$8>>2]|0;
  $15 = (($14) + -1)|0;
  $16 = ($14|0)==(0);
  L6: do {
   if (!($16)) {
    if ($12) {
     $$093103 = $133;$$094102 = $134;$122 = $15;
     while(1) {
      $74 = HEAP32[$$094102>>2]|0;
      $75 = $74 >>> 16;
      $76 = $75 & 255;
      $77 = $74 >>> 8;
      $78 = $77 & 255;
      $79 = $74 & 255;
      $80 = $74 >>> 24;
      $81 = HEAP32[$$093103>>2]|0;
      $82 = $81 >>> 16;
      $83 = $82 & 255;
      $84 = $81 >>> 8;
      $85 = $84 & 255;
      $86 = $81 & 255;
      $87 = $81 >>> 24;
      $trunc$clear1 = $trunc & 127;
      switch ($trunc$clear1<<24>>24) {
      case 16:  {
       $88 = $80 ^ 255;
       $89 = Math_imul($83, $88)|0;
       $90 = (($89>>>0) / 255)&-1;
       $91 = (($79) + ($90))|0;
       $92 = Math_imul($85, $88)|0;
       $93 = (($92>>>0) / 255)&-1;
       $94 = (($78) + ($93))|0;
       $95 = Math_imul($88, $86)|0;
       $96 = (($95>>>0) / 255)&-1;
       $97 = (($76) + ($96))|0;
       $98 = Math_imul($88, $87)|0;
       $99 = (($98>>>0) / 255)&-1;
       $100 = (($99) + ($80))|0;
       $$095 = $100;$$096 = $97;$$097 = $94;$$098 = $91;
       break;
      }
      case 32:  {
       $101 = (($79) + ($83))|0;
       $102 = ($101>>>0)<(255);
       $$ = $102 ? $101 : 255;
       $103 = (($78) + ($85))|0;
       $104 = ($103>>>0)<(255);
       $$3 = $104 ? $103 : 255;
       $105 = (($76) + ($86))|0;
       $106 = ($105>>>0)<(255);
       $$1 = $106 ? $105 : 255;
       $$095 = $87;$$096 = $$1;$$097 = $$3;$$098 = $$;
       break;
      }
      case 64:  {
       $107 = Math_imul($79, $83)|0;
       $108 = (($107>>>0) / 255)&-1;
       $109 = Math_imul($78, $85)|0;
       $110 = (($109>>>0) / 255)&-1;
       $111 = Math_imul($76, $86)|0;
       $112 = (($111>>>0) / 255)&-1;
       $$095 = $87;$$096 = $112;$$097 = $110;$$098 = $108;
       break;
      }
      default: {
       $$095 = $87;$$096 = $86;$$097 = $85;$$098 = $83;
      }
      }
      $113 = $$095 << 24;
      $114 = $$098 << 16;
      $115 = $$097 << 8;
      $116 = $115 | $114;
      $117 = $116 | $$096;
      $118 = $117 | $113;
      HEAP32[$$093103>>2] = $118;
      $119 = ((($$094102)) + 4|0);
      $120 = ((($$093103)) + 4|0);
      $121 = (($122) + -1)|0;
      $123 = ($122|0)==(0);
      if ($123) {
       break L6;
      } else {
       $$093103 = $120;$$094102 = $119;$122 = $121;
      }
     }
    } else {
     $$093103$us = $133;$$094102$us = $134;$72 = $15;
    }
    while(1) {
     $17 = HEAP32[$$094102$us>>2]|0;
     $18 = $17 >>> 16;
     $19 = $18 & 255;
     $20 = $17 >>> 8;
     $21 = $20 & 255;
     $22 = $17 & 255;
     $23 = $17 >>> 24;
     $24 = HEAP32[$$093103$us>>2]|0;
     $25 = $24 >>> 16;
     $26 = $25 & 255;
     $27 = $24 >>> 8;
     $28 = $27 & 255;
     $29 = $24 & 255;
     $30 = $24 >>> 24;
     $31 = ($23|0)==(255);
     if ($31) {
      $$0100$us = $19;$$0101$us = $21;$$099$us = $22;
     } else {
      $32 = Math_imul($19, $23)|0;
      $33 = Math_imul($21, $23)|0;
      $34 = Math_imul($22, $23)|0;
      $35 = (($34>>>0) / 255)&-1;
      $36 = (($33>>>0) / 255)&-1;
      $37 = (($32>>>0) / 255)&-1;
      $$0100$us = $37;$$0101$us = $36;$$099$us = $35;
     }
     $trunc$clear = $trunc & 127;
     switch ($trunc$clear<<24>>24) {
     case 16:  {
      $50 = $23 ^ 255;
      $51 = Math_imul($26, $50)|0;
      $52 = (($51>>>0) / 255)&-1;
      $53 = (($$099$us) + ($52))|0;
      $54 = Math_imul($28, $50)|0;
      $55 = (($54>>>0) / 255)&-1;
      $56 = (($$0101$us) + ($55))|0;
      $57 = Math_imul($50, $29)|0;
      $58 = (($57>>>0) / 255)&-1;
      $59 = (($$0100$us) + ($58))|0;
      $60 = Math_imul($50, $30)|0;
      $61 = (($60>>>0) / 255)&-1;
      $62 = (($61) + ($23))|0;
      $$095$us = $62;$$096$us = $59;$$097$us = $56;$$098$us = $53;
      break;
     }
     case 32:  {
      $44 = (($$099$us) + ($26))|0;
      $45 = ($44>>>0)<(255);
      $$$us = $45 ? $44 : 255;
      $46 = (($$0101$us) + ($28))|0;
      $47 = ($46>>>0)<(255);
      $$3$us = $47 ? $46 : 255;
      $48 = (($$0100$us) + ($29))|0;
      $49 = ($48>>>0)<(255);
      $$1$us = $49 ? $48 : 255;
      $$095$us = $30;$$096$us = $$1$us;$$097$us = $$3$us;$$098$us = $$$us;
      break;
     }
     case 64:  {
      $38 = Math_imul($$099$us, $26)|0;
      $39 = (($38>>>0) / 255)&-1;
      $40 = Math_imul($$0101$us, $28)|0;
      $41 = (($40>>>0) / 255)&-1;
      $42 = Math_imul($$0100$us, $29)|0;
      $43 = (($42>>>0) / 255)&-1;
      $$095$us = $30;$$096$us = $43;$$097$us = $41;$$098$us = $39;
      break;
     }
     default: {
      $$095$us = $30;$$096$us = $29;$$097$us = $28;$$098$us = $26;
     }
     }
     $63 = $$095$us << 24;
     $64 = $$098$us << 16;
     $65 = $$097$us << 8;
     $66 = $65 | $64;
     $67 = $66 | $$096$us;
     $68 = $67 | $63;
     HEAP32[$$093103$us>>2] = $68;
     $69 = ((($$094102$us)) + 4|0);
     $70 = ((($$093103$us)) + 4|0);
     $71 = (($72) + -1)|0;
     $73 = ($72|0)==(0);
     if ($73) {
      break L6;
     } else {
      $$093103$us = $70;$$094102$us = $69;$72 = $71;
     }
    }
   }
  } while(0);
  $124 = HEAP32[$9>>2]|0;
  $125 = (($126) + ($124)|0);
  $127 = HEAP32[$10>>2]|0;
  $128 = (($129) + ($127)|0);
  $130 = HEAP32[$3>>2]|0;
  $131 = (($130) + -1)|0;
  HEAP32[$3>>2] = $131;
  $132 = ($130|0)==(0);
  if ($132) {
   break;
  } else {
   $126 = $125;$129 = $128;$133 = $128;$134 = $125;
  }
 }
 HEAP32[$0>>2] = $125;
 HEAP32[$7>>2] = $128;
 return;
}
function _SDL_Blit_ABGR8888_ARGB8888_Blend_Scale($0) {
 $0 = $0|0;
 var $$ = 0, $$0120151 = 0, $$0121150 = 0, $$0123 = 0, $$0124 = 0, $$0125149 = 0, $$0127155 = 0, $$0129148 = 0, $$0132154 = 0, $$0134 = 0, $$0135 = 0, $$0136 = 0, $$0137 = 0, $$0138 = 0, $$1 = 0, $$1122 = 0, $$1128$lcssa = 0, $$1133$lcssa = 0, $$2 = 0, $$2131 = 0;
 var $$3 = 0, $$in = 0, $$pre = 0, $$pre162 = 0, $$pre163 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $trunc = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 << 16;
 $6 = ((($0)) + 28|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5|0) / ($7|0))&-1;
 $9 = ((($0)) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10 << 16;
 $12 = ((($0)) + 24|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($11|0) / ($13|0))&-1;
 $15 = (($7) + -1)|0;
 HEAP32[$6>>2] = $15;
 $16 = ($7|0)==(0);
 if ($16) {
  return;
 }
 $17 = ((($0)) + 20|0);
 $18 = ((($0)) + 32|0);
 $19 = $2 & 48;
 $20 = ($19|0)!=(0);
 $21 = $2 & 112;
 $trunc = $21&255;
 $22 = ((($0)) + 12|0);
 $$pre = HEAP32[$17>>2]|0;
 $$0127155 = 0;$$0132154 = 0;$103 = $$pre;$108 = $15;$109 = $$pre;$30 = $13;
 while(1) {
  $23 = ($$0127155|0)>(65535);
  if ($23) {
   $24 = (($$0127155) + -65536)|0;
   $25 = $24 >>> 16;
   $26 = $25 << 16;
   $27 = (($$0132154) + 1)|0;
   $28 = (($27) + ($25))|0;
   $29 = (($24) - ($26))|0;
   $$1128$lcssa = $29;$$1133$lcssa = $28;
  } else {
   $$1128$lcssa = $$0127155;$$1133$lcssa = $$0132154;
  }
  $31 = ($30|0)==(0);
  if ($31) {
   $105 = $108;
  } else {
   $$0120151 = $109;$$0121150 = 0;$$0125149 = 65536;$$0129148 = -1;$$in = $30;
   while(1) {
    $32 = (($$in) + -1)|0;
    $33 = ($$0125149|0)>(65535);
    if ($33) {
     $34 = (($$0125149) + -65536)|0;
     $35 = $34 >>> 16;
     $36 = $35 << 16;
     $37 = (($$0129148) + 1)|0;
     $38 = (($37) + ($35))|0;
     $39 = (($34) - ($36))|0;
     $40 = HEAP32[$0>>2]|0;
     $41 = HEAP32[$22>>2]|0;
     $42 = Math_imul($41, $$1133$lcssa)|0;
     $43 = (($40) + ($42)|0);
     $44 = $38 << 2;
     $45 = (($43) + ($44)|0);
     $$1122 = $45;$$2 = $39;$$2131 = $38;
    } else {
     $$1122 = $$0121150;$$2 = $$0125149;$$2131 = $$0129148;
    }
    $46 = HEAP32[$$1122>>2]|0;
    $47 = $46 >>> 16;
    $48 = $47 & 255;
    $49 = $46 >>> 8;
    $50 = $49 & 255;
    $51 = $46 & 255;
    $52 = $46 >>> 24;
    $53 = HEAP32[$$0120151>>2]|0;
    $54 = $53 >>> 16;
    $55 = $54 & 255;
    $56 = $53 >>> 8;
    $57 = $56 & 255;
    $58 = $53 & 255;
    $59 = $53 >>> 24;
    $60 = ($52|0)!=(255);
    $or$cond = $20 & $60;
    if ($or$cond) {
     $61 = Math_imul($48, $52)|0;
     $62 = Math_imul($50, $52)|0;
     $63 = Math_imul($51, $52)|0;
     $64 = (($63>>>0) / 255)&-1;
     $65 = (($62>>>0) / 255)&-1;
     $66 = (($61>>>0) / 255)&-1;
     $$0123 = $64;$$0124 = $65;$$0138 = $66;
    } else {
     $$0123 = $51;$$0124 = $50;$$0138 = $48;
    }
    $trunc$clear = $trunc & 127;
    switch ($trunc$clear<<24>>24) {
    case 16:  {
     $67 = $52 ^ 255;
     $68 = Math_imul($55, $67)|0;
     $69 = (($68>>>0) / 255)&-1;
     $70 = (($$0123) + ($69))|0;
     $71 = Math_imul($57, $67)|0;
     $72 = (($71>>>0) / 255)&-1;
     $73 = (($$0124) + ($72))|0;
     $74 = Math_imul($67, $58)|0;
     $75 = (($74>>>0) / 255)&-1;
     $76 = (($$0138) + ($75))|0;
     $77 = Math_imul($67, $59)|0;
     $78 = (($77>>>0) / 255)&-1;
     $79 = (($78) + ($52))|0;
     $$0134 = $79;$$0135 = $76;$$0136 = $73;$$0137 = $70;
     break;
    }
    case 32:  {
     $80 = (($$0123) + ($55))|0;
     $81 = ($80>>>0)<(255);
     $$ = $81 ? $80 : 255;
     $82 = (($$0124) + ($57))|0;
     $83 = ($82>>>0)<(255);
     $$3 = $83 ? $82 : 255;
     $84 = (($$0138) + ($58))|0;
     $85 = ($84>>>0)<(255);
     $$1 = $85 ? $84 : 255;
     $$0134 = $59;$$0135 = $$1;$$0136 = $$3;$$0137 = $$;
     break;
    }
    case 64:  {
     $86 = Math_imul($$0123, $55)|0;
     $87 = (($86>>>0) / 255)&-1;
     $88 = Math_imul($$0124, $57)|0;
     $89 = (($88>>>0) / 255)&-1;
     $90 = Math_imul($$0138, $58)|0;
     $91 = (($90>>>0) / 255)&-1;
     $$0134 = $59;$$0135 = $91;$$0136 = $89;$$0137 = $87;
     break;
    }
    default: {
     $$0134 = $59;$$0135 = $58;$$0136 = $57;$$0137 = $55;
    }
    }
    $92 = $$0134 << 24;
    $93 = $$0137 << 16;
    $94 = $$0136 << 8;
    $95 = $94 | $93;
    $96 = $95 | $$0135;
    $97 = $96 | $92;
    HEAP32[$$0120151>>2] = $97;
    $98 = (($$2) + ($14))|0;
    $99 = ((($$0120151)) + 4|0);
    $100 = ($32|0)==(0);
    if ($100) {
     break;
    } else {
     $$0120151 = $99;$$0121150 = $$1122;$$0125149 = $98;$$0129148 = $$2131;$$in = $32;
    }
   }
   $$pre163 = HEAP32[$6>>2]|0;
   $105 = $$pre163;
  }
  $101 = HEAP32[$18>>2]|0;
  $102 = (($103) + ($101)|0);
  $104 = (($105) + -1)|0;
  HEAP32[$6>>2] = $104;
  $106 = ($105|0)==(0);
  if ($106) {
   break;
  }
  $107 = (($$1128$lcssa) + ($8))|0;
  $$pre162 = HEAP32[$12>>2]|0;
  $$0127155 = $107;$$0132154 = $$1133$lcssa;$103 = $102;$108 = $104;$109 = $102;$30 = $$pre162;
 }
 HEAP32[$17>>2] = $102;
 return;
}
function _SDL_Blit_ABGR8888_ARGB8888_Modulate($0) {
 $0 = $0|0;
 var $$06168 = 0, $$06168$us = 0, $$06267 = 0, $$06267$us = 0, $$063 = 0, $$063$us = 0, $$pre = 0, $$pre73 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = ((($0)) + 61|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = ((($0)) + 62|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = ((($0)) + 63|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = $13&255;
 $15 = ((($0)) + 28|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + -1)|0;
 HEAP32[$15>>2] = $17;
 $18 = ($16|0)==(0);
 if ($18) {
  return;
 }
 $19 = ((($0)) + 20|0);
 $20 = ((($0)) + 24|0);
 $21 = ((($0)) + 12|0);
 $22 = ((($0)) + 32|0);
 $23 = $2 & 1;
 $24 = ($23|0)==(0);
 $25 = $2 & 2;
 $26 = ($25|0)==(0);
 $$pre = HEAP32[$0>>2]|0;
 $$pre73 = HEAP32[$19>>2]|0;
 $76 = $$pre;$79 = $$pre73;$83 = $$pre73;$84 = $$pre;
 while(1) {
  $27 = HEAP32[$20>>2]|0;
  $28 = (($27) + -1)|0;
  $29 = ($27|0)==(0);
  if (!($29)) {
   if ($24) {
    $$06168$us = $83;$$06267$us = $84;$46 = $28;
    while(1) {
     $30 = HEAP32[$$06267$us>>2]|0;
     $31 = $30 >>> 16;
     $32 = $31 & 255;
     $33 = $30 & 65280;
     $34 = $30 >>> 24;
     $35 = Math_imul($34, $14)|0;
     $36 = (($35>>>0) / 255)&-1;
     $$063$us = $26 ? $34 : $36;
     $37 = $$063$us << 24;
     $38 = $30 << 16;
     $39 = $38 & 16711680;
     $40 = $39 | $37;
     $41 = $40 | $33;
     $42 = $41 | $32;
     HEAP32[$$06168$us>>2] = $42;
     $43 = ((($$06267$us)) + 4|0);
     $44 = ((($$06168$us)) + 4|0);
     $45 = (($46) + -1)|0;
     $47 = ($46|0)==(0);
     if ($47) {
      break;
     } else {
      $$06168$us = $44;$$06267$us = $43;$46 = $45;
     }
    }
   } else {
    $$06168 = $83;$$06267 = $84;$72 = $28;
    while(1) {
     $48 = HEAP32[$$06267>>2]|0;
     $49 = $48 >>> 16;
     $50 = $49 & 255;
     $51 = $48 >>> 8;
     $52 = $51 & 255;
     $53 = $48 & 255;
     $54 = $48 >>> 24;
     $55 = Math_imul($50, $11)|0;
     $56 = Math_imul($52, $8)|0;
     $57 = Math_imul($53, $5)|0;
     $58 = (($57>>>0) / 255)&-1;
     $59 = (($56>>>0) / 255)&-1;
     $60 = (($55>>>0) / 255)&-1;
     $61 = Math_imul($54, $14)|0;
     $62 = (($61>>>0) / 255)&-1;
     $$063 = $26 ? $54 : $62;
     $63 = $$063 << 24;
     $64 = $58 << 16;
     $65 = $64 | $63;
     $66 = $59 << 8;
     $67 = $65 | $66;
     $68 = $67 | $60;
     HEAP32[$$06168>>2] = $68;
     $69 = ((($$06267)) + 4|0);
     $70 = ((($$06168)) + 4|0);
     $71 = (($72) + -1)|0;
     $73 = ($72|0)==(0);
     if ($73) {
      break;
     } else {
      $$06168 = $70;$$06267 = $69;$72 = $71;
     }
    }
   }
  }
  $74 = HEAP32[$21>>2]|0;
  $75 = (($76) + ($74)|0);
  $77 = HEAP32[$22>>2]|0;
  $78 = (($79) + ($77)|0);
  $80 = HEAP32[$15>>2]|0;
  $81 = (($80) + -1)|0;
  HEAP32[$15>>2] = $81;
  $82 = ($80|0)==(0);
  if ($82) {
   break;
  } else {
   $76 = $75;$79 = $78;$83 = $78;$84 = $75;
  }
 }
 HEAP32[$0>>2] = $75;
 HEAP32[$19>>2] = $78;
 return;
}
function _SDL_Blit_ABGR8888_ARGB8888_Modulate_Scale($0) {
 $0 = $0|0;
 var $$0100 = 0, $$0100$us = 0, $$088115 = 0, $$088115$us = 0, $$089114 = 0, $$089114$us = 0, $$091113 = 0, $$091113$us = 0, $$093119 = 0, $$095112 = 0, $$095112$us = 0, $$098118 = 0, $$1 = 0, $$1$us = 0, $$194$lcssa = 0, $$199$lcssa = 0, $$2 = 0, $$2$us = 0, $$297 = 0, $$297$us = 0;
 var $$pre = 0, $$pre129 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = ((($0)) + 61|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = ((($0)) + 62|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = ((($0)) + 63|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = $13&255;
 $15 = ((($0)) + 8|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $16 << 16;
 $18 = ((($0)) + 28|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($17|0) / ($19|0))&-1;
 $21 = ((($0)) + 4|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = $22 << 16;
 $24 = ((($0)) + 24|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($23|0) / ($25|0))&-1;
 $27 = (($19) + -1)|0;
 HEAP32[$18>>2] = $27;
 $28 = ($19|0)==(0);
 if ($28) {
  return;
 }
 $29 = ((($0)) + 20|0);
 $30 = ((($0)) + 32|0);
 $31 = $2 & 1;
 $32 = ($31|0)==(0);
 $33 = $2 & 2;
 $34 = ($33|0)==(0);
 $35 = ((($0)) + 12|0);
 $$pre = HEAP32[$29>>2]|0;
 $$093119 = 0;$$098118 = 0;$118 = $$pre;$123 = $$pre;$44 = $25;
 while(1) {
  $36 = ($$093119|0)>(65535);
  if ($36) {
   $37 = (($$093119) + -65536)|0;
   $38 = $37 >>> 16;
   $39 = $38 << 16;
   $40 = (($$098118) + 1)|0;
   $41 = (($40) + ($38))|0;
   $42 = (($37) - ($39))|0;
   $$194$lcssa = $42;$$199$lcssa = $41;
  } else {
   $$194$lcssa = $$093119;$$199$lcssa = $$098118;
  }
  $43 = (($44) + -1)|0;
  $45 = ($44|0)==(0);
  if (!($45)) {
   if ($32) {
    $$088115$us = $123;$$089114$us = 0;$$091113$us = 65536;$$095112$us = -1;$75 = $43;
    while(1) {
     $46 = ($$091113$us|0)>(65535);
     if ($46) {
      $47 = (($$091113$us) + -65536)|0;
      $48 = $47 >>> 16;
      $49 = $48 << 16;
      $50 = (($$095112$us) + 1)|0;
      $51 = (($50) + ($48))|0;
      $52 = (($47) - ($49))|0;
      $53 = HEAP32[$0>>2]|0;
      $54 = HEAP32[$35>>2]|0;
      $55 = Math_imul($54, $$199$lcssa)|0;
      $56 = (($53) + ($55)|0);
      $57 = $51 << 2;
      $58 = (($56) + ($57)|0);
      $$1$us = $58;$$2$us = $52;$$297$us = $51;
     } else {
      $$1$us = $$089114$us;$$2$us = $$091113$us;$$297$us = $$095112$us;
     }
     $59 = HEAP32[$$1$us>>2]|0;
     $60 = $59 >>> 16;
     $61 = $60 & 255;
     $62 = $59 & 65280;
     $63 = $59 >>> 24;
     $64 = Math_imul($63, $14)|0;
     $65 = (($64>>>0) / 255)&-1;
     $$0100$us = $34 ? $63 : $65;
     $66 = $$0100$us << 24;
     $67 = $59 << 16;
     $68 = $67 & 16711680;
     $69 = $62 | $66;
     $70 = $69 | $61;
     $71 = $70 | $68;
     HEAP32[$$088115$us>>2] = $71;
     $72 = (($$2$us) + ($26))|0;
     $73 = ((($$088115$us)) + 4|0);
     $74 = (($75) + -1)|0;
     $76 = ($75|0)==(0);
     if ($76) {
      break;
     } else {
      $$088115$us = $73;$$089114$us = $$1$us;$$091113$us = $72;$$095112$us = $$297$us;$75 = $74;
     }
    }
   } else {
    $$088115 = $123;$$089114 = 0;$$091113 = 65536;$$095112 = -1;$114 = $43;
    while(1) {
     $77 = ($$091113|0)>(65535);
     if ($77) {
      $78 = (($$091113) + -65536)|0;
      $79 = $78 >>> 16;
      $80 = $79 << 16;
      $81 = (($$095112) + 1)|0;
      $82 = (($81) + ($79))|0;
      $83 = (($78) - ($80))|0;
      $84 = HEAP32[$0>>2]|0;
      $85 = HEAP32[$35>>2]|0;
      $86 = Math_imul($85, $$199$lcssa)|0;
      $87 = (($84) + ($86)|0);
      $88 = $82 << 2;
      $89 = (($87) + ($88)|0);
      $$1 = $89;$$2 = $83;$$297 = $82;
     } else {
      $$1 = $$089114;$$2 = $$091113;$$297 = $$095112;
     }
     $90 = HEAP32[$$1>>2]|0;
     $91 = $90 >>> 16;
     $92 = $91 & 255;
     $93 = $90 >>> 8;
     $94 = $93 & 255;
     $95 = $90 & 255;
     $96 = $90 >>> 24;
     $97 = Math_imul($92, $11)|0;
     $98 = Math_imul($94, $8)|0;
     $99 = Math_imul($95, $5)|0;
     $100 = (($99>>>0) / 255)&-1;
     $101 = (($98>>>0) / 255)&-1;
     $102 = (($97>>>0) / 255)&-1;
     $103 = Math_imul($96, $14)|0;
     $104 = (($103>>>0) / 255)&-1;
     $$0100 = $34 ? $96 : $104;
     $105 = $$0100 << 24;
     $106 = $100 << 16;
     $107 = $101 << 8;
     $108 = $107 | $105;
     $109 = $108 | $102;
     $110 = $109 | $106;
     HEAP32[$$088115>>2] = $110;
     $111 = (($$2) + ($26))|0;
     $112 = ((($$088115)) + 4|0);
     $113 = (($114) + -1)|0;
     $115 = ($114|0)==(0);
     if ($115) {
      break;
     } else {
      $$088115 = $112;$$089114 = $$1;$$091113 = $111;$$095112 = $$297;$114 = $113;
     }
    }
   }
  }
  $116 = HEAP32[$30>>2]|0;
  $117 = (($118) + ($116)|0);
  $119 = HEAP32[$18>>2]|0;
  $120 = (($119) + -1)|0;
  HEAP32[$18>>2] = $120;
  $121 = ($119|0)==(0);
  if ($121) {
   break;
  }
  $122 = (($$194$lcssa) + ($20))|0;
  $$pre129 = HEAP32[$24>>2]|0;
  $$093119 = $122;$$098118 = $$199$lcssa;$118 = $117;$123 = $117;$44 = $$pre129;
 }
 HEAP32[$29>>2] = $117;
 return;
}
function _SDL_Blit_ABGR8888_ARGB8888_Modulate_Blend($0) {
 $0 = $0|0;
 var $$ = 0, $$0115129 = 0, $$0116128 = 0, $$0117 = 0, $$0118 = 0, $$0119 = 0, $$0120 = 0, $$0121 = 0, $$0122 = 0, $$0124 = 0, $$0126 = 0, $$1 = 0, $$1123 = 0, $$1125 = 0, $$1127 = 0, $$3 = 0, $$in = 0, $$pre = 0, $$pre133 = 0, $$pre134 = 0;
 var $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $trunc = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = ((($0)) + 61|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = ((($0)) + 62|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = ((($0)) + 63|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = $13&255;
 $15 = ((($0)) + 28|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + -1)|0;
 HEAP32[$15>>2] = $17;
 $18 = ($16|0)==(0);
 if ($18) {
  return;
 }
 $19 = ((($0)) + 20|0);
 $20 = ((($0)) + 24|0);
 $21 = ((($0)) + 12|0);
 $22 = ((($0)) + 32|0);
 $23 = $2 & 1;
 $24 = ($23|0)==(0);
 $25 = $2 & 2;
 $26 = ($25|0)==(0);
 $27 = $2 & 48;
 $28 = ($27|0)!=(0);
 $29 = $2 & 112;
 $trunc = $29&255;
 $$pre = HEAP32[$0>>2]|0;
 $$pre133 = HEAP32[$19>>2]|0;
 $101 = $$pre133;$105 = $17;$106 = $$pre133;$107 = $$pre;$98 = $$pre;
 while(1) {
  $30 = HEAP32[$20>>2]|0;
  $31 = ($30|0)==(0);
  if ($31) {
   $103 = $105;
  } else {
   $$0115129 = $106;$$0116128 = $107;$$in = $30;
   while(1) {
    $32 = (($$in) + -1)|0;
    $33 = HEAP32[$$0116128>>2]|0;
    $34 = $33 >>> 16;
    $35 = $34 & 255;
    $36 = $33 >>> 8;
    $37 = $36 & 255;
    $38 = $33 & 255;
    $39 = $33 >>> 24;
    $40 = HEAP32[$$0115129>>2]|0;
    $41 = $40 >>> 16;
    $42 = $41 & 255;
    $43 = $40 >>> 8;
    $44 = $43 & 255;
    $45 = $40 & 255;
    $46 = $40 >>> 24;
    if ($24) {
     $$0122 = $35;$$0124 = $37;$$0126 = $38;
    } else {
     $47 = Math_imul($35, $11)|0;
     $48 = Math_imul($37, $8)|0;
     $49 = Math_imul($38, $5)|0;
     $50 = (($49>>>0) / 255)&-1;
     $51 = (($48>>>0) / 255)&-1;
     $52 = (($47>>>0) / 255)&-1;
     $$0122 = $52;$$0124 = $51;$$0126 = $50;
    }
    $53 = Math_imul($39, $14)|0;
    $54 = (($53>>>0) / 255)&-1;
    $$0121 = $26 ? $39 : $54;
    $55 = ($$0121>>>0)<(255);
    $or$cond = $28 & $55;
    if ($or$cond) {
     $56 = Math_imul($$0122, $$0121)|0;
     $57 = Math_imul($$0124, $$0121)|0;
     $58 = Math_imul($$0126, $$0121)|0;
     $59 = (($58>>>0) / 255)&-1;
     $60 = (($57>>>0) / 255)&-1;
     $61 = (($56>>>0) / 255)&-1;
     $$1123 = $61;$$1125 = $60;$$1127 = $59;
    } else {
     $$1123 = $$0122;$$1125 = $$0124;$$1127 = $$0126;
    }
    $trunc$clear = $trunc & 127;
    switch ($trunc$clear<<24>>24) {
    case 16:  {
     $62 = (255 - ($$0121))|0;
     $63 = Math_imul($62, $42)|0;
     $64 = (($63>>>0) / 255)&-1;
     $65 = (($$1127) + ($64))|0;
     $66 = Math_imul($62, $44)|0;
     $67 = (($66>>>0) / 255)&-1;
     $68 = (($$1125) + ($67))|0;
     $69 = Math_imul($62, $45)|0;
     $70 = (($69>>>0) / 255)&-1;
     $71 = (($$1123) + ($70))|0;
     $72 = Math_imul($62, $46)|0;
     $73 = (($72>>>0) / 255)&-1;
     $74 = (($73) + ($$0121))|0;
     $$0117 = $74;$$0118 = $71;$$0119 = $68;$$0120 = $65;
     break;
    }
    case 32:  {
     $75 = (($$1127) + ($42))|0;
     $76 = ($75>>>0)<(255);
     $$ = $76 ? $75 : 255;
     $77 = (($$1125) + ($44))|0;
     $78 = ($77>>>0)<(255);
     $$3 = $78 ? $77 : 255;
     $79 = (($$1123) + ($45))|0;
     $80 = ($79>>>0)<(255);
     $$1 = $80 ? $79 : 255;
     $$0117 = $46;$$0118 = $$1;$$0119 = $$3;$$0120 = $$;
     break;
    }
    case 64:  {
     $81 = Math_imul($$1127, $42)|0;
     $82 = (($81>>>0) / 255)&-1;
     $83 = Math_imul($$1125, $44)|0;
     $84 = (($83>>>0) / 255)&-1;
     $85 = Math_imul($$1123, $45)|0;
     $86 = (($85>>>0) / 255)&-1;
     $$0117 = $46;$$0118 = $86;$$0119 = $84;$$0120 = $82;
     break;
    }
    default: {
     $$0117 = $46;$$0118 = $45;$$0119 = $44;$$0120 = $42;
    }
    }
    $87 = $$0117 << 24;
    $88 = $$0120 << 16;
    $89 = $$0119 << 8;
    $90 = $89 | $88;
    $91 = $90 | $$0118;
    $92 = $91 | $87;
    HEAP32[$$0115129>>2] = $92;
    $93 = ((($$0116128)) + 4|0);
    $94 = ((($$0115129)) + 4|0);
    $95 = ($32|0)==(0);
    if ($95) {
     break;
    } else {
     $$0115129 = $94;$$0116128 = $93;$$in = $32;
    }
   }
   $$pre134 = HEAP32[$15>>2]|0;
   $103 = $$pre134;
  }
  $96 = HEAP32[$21>>2]|0;
  $97 = (($98) + ($96)|0);
  $99 = HEAP32[$22>>2]|0;
  $100 = (($101) + ($99)|0);
  $102 = (($103) + -1)|0;
  HEAP32[$15>>2] = $102;
  $104 = ($103|0)==(0);
  if ($104) {
   break;
  } else {
   $101 = $100;$105 = $102;$106 = $100;$107 = $97;$98 = $97;
  }
 }
 HEAP32[$0>>2] = $97;
 HEAP32[$19>>2] = $100;
 return;
}
function _SDL_Blit_ABGR8888_ARGB8888_Modulate_Blend_Scale($0) {
 $0 = $0|0;
 var $$ = 0, $$0142177 = 0, $$0143176 = 0, $$0145 = 0, $$0147 = 0, $$0149175 = 0, $$0151181 = 0, $$0153174 = 0, $$0156180 = 0, $$0158 = 0, $$0159 = 0, $$0160 = 0, $$0161 = 0, $$0162 = 0, $$0163 = 0, $$1 = 0, $$1144 = 0, $$1146 = 0, $$1148 = 0, $$1152$lcssa = 0;
 var $$1157$lcssa = 0, $$1164 = 0, $$2 = 0, $$2155 = 0, $$3 = 0, $$in = 0, $$pre = 0, $$pre188 = 0, $$pre189 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $or$cond = 0, $trunc = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = ((($0)) + 61|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = ((($0)) + 62|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = ((($0)) + 63|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = $13&255;
 $15 = ((($0)) + 8|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $16 << 16;
 $18 = ((($0)) + 28|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($17|0) / ($19|0))&-1;
 $21 = ((($0)) + 4|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = $22 << 16;
 $24 = ((($0)) + 24|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($23|0) / ($25|0))&-1;
 $27 = (($19) + -1)|0;
 HEAP32[$18>>2] = $27;
 $28 = ($19|0)==(0);
 if ($28) {
  return;
 }
 $29 = ((($0)) + 20|0);
 $30 = ((($0)) + 32|0);
 $31 = $2 & 1;
 $32 = ($31|0)==(0);
 $33 = $2 & 2;
 $34 = ($33|0)==(0);
 $35 = $2 & 48;
 $36 = ($35|0)!=(0);
 $37 = $2 & 112;
 $trunc = $37&255;
 $38 = ((($0)) + 12|0);
 $$pre = HEAP32[$29>>2]|0;
 $$0151181 = 0;$$0156180 = 0;$127 = $$pre;$132 = $27;$133 = $$pre;$46 = $25;
 while(1) {
  $39 = ($$0151181|0)>(65535);
  if ($39) {
   $40 = (($$0151181) + -65536)|0;
   $41 = $40 >>> 16;
   $42 = $41 << 16;
   $43 = (($$0156180) + 1)|0;
   $44 = (($43) + ($41))|0;
   $45 = (($40) - ($42))|0;
   $$1152$lcssa = $45;$$1157$lcssa = $44;
  } else {
   $$1152$lcssa = $$0151181;$$1157$lcssa = $$0156180;
  }
  $47 = ($46|0)==(0);
  if ($47) {
   $129 = $132;
  } else {
   $$0142177 = $133;$$0143176 = 0;$$0149175 = 65536;$$0153174 = -1;$$in = $46;
   while(1) {
    $48 = (($$in) + -1)|0;
    $49 = ($$0149175|0)>(65535);
    if ($49) {
     $50 = (($$0149175) + -65536)|0;
     $51 = $50 >>> 16;
     $52 = $51 << 16;
     $53 = (($$0153174) + 1)|0;
     $54 = (($53) + ($51))|0;
     $55 = (($50) - ($52))|0;
     $56 = HEAP32[$0>>2]|0;
     $57 = HEAP32[$38>>2]|0;
     $58 = Math_imul($57, $$1157$lcssa)|0;
     $59 = (($56) + ($58)|0);
     $60 = $54 << 2;
     $61 = (($59) + ($60)|0);
     $$1144 = $61;$$2 = $55;$$2155 = $54;
    } else {
     $$1144 = $$0143176;$$2 = $$0149175;$$2155 = $$0153174;
    }
    $62 = HEAP32[$$1144>>2]|0;
    $63 = $62 >>> 16;
    $64 = $63 & 255;
    $65 = $62 >>> 8;
    $66 = $65 & 255;
    $67 = $62 & 255;
    $68 = $62 >>> 24;
    $69 = HEAP32[$$0142177>>2]|0;
    $70 = $69 >>> 16;
    $71 = $70 & 255;
    $72 = $69 >>> 8;
    $73 = $72 & 255;
    $74 = $69 & 255;
    $75 = $69 >>> 24;
    if ($32) {
     $$0145 = $67;$$0147 = $66;$$0163 = $64;
    } else {
     $76 = Math_imul($64, $11)|0;
     $77 = Math_imul($66, $8)|0;
     $78 = Math_imul($67, $5)|0;
     $79 = (($78>>>0) / 255)&-1;
     $80 = (($77>>>0) / 255)&-1;
     $81 = (($76>>>0) / 255)&-1;
     $$0145 = $79;$$0147 = $80;$$0163 = $81;
    }
    $82 = Math_imul($68, $14)|0;
    $83 = (($82>>>0) / 255)&-1;
    $$0162 = $34 ? $68 : $83;
    $84 = ($$0162>>>0)<(255);
    $or$cond = $36 & $84;
    if ($or$cond) {
     $85 = Math_imul($$0163, $$0162)|0;
     $86 = Math_imul($$0147, $$0162)|0;
     $87 = Math_imul($$0145, $$0162)|0;
     $88 = (($87>>>0) / 255)&-1;
     $89 = (($86>>>0) / 255)&-1;
     $90 = (($85>>>0) / 255)&-1;
     $$1146 = $88;$$1148 = $89;$$1164 = $90;
    } else {
     $$1146 = $$0145;$$1148 = $$0147;$$1164 = $$0163;
    }
    $trunc$clear = $trunc & 127;
    switch ($trunc$clear<<24>>24) {
    case 16:  {
     $91 = (255 - ($$0162))|0;
     $92 = Math_imul($91, $71)|0;
     $93 = (($92>>>0) / 255)&-1;
     $94 = (($$1146) + ($93))|0;
     $95 = Math_imul($91, $73)|0;
     $96 = (($95>>>0) / 255)&-1;
     $97 = (($$1148) + ($96))|0;
     $98 = Math_imul($91, $74)|0;
     $99 = (($98>>>0) / 255)&-1;
     $100 = (($$1164) + ($99))|0;
     $101 = Math_imul($91, $75)|0;
     $102 = (($101>>>0) / 255)&-1;
     $103 = (($102) + ($$0162))|0;
     $$0158 = $103;$$0159 = $100;$$0160 = $97;$$0161 = $94;
     break;
    }
    case 32:  {
     $104 = (($$1146) + ($71))|0;
     $105 = ($104>>>0)<(255);
     $$ = $105 ? $104 : 255;
     $106 = (($$1148) + ($73))|0;
     $107 = ($106>>>0)<(255);
     $$3 = $107 ? $106 : 255;
     $108 = (($$1164) + ($74))|0;
     $109 = ($108>>>0)<(255);
     $$1 = $109 ? $108 : 255;
     $$0158 = $75;$$0159 = $$1;$$0160 = $$3;$$0161 = $$;
     break;
    }
    case 64:  {
     $110 = Math_imul($$1146, $71)|0;
     $111 = (($110>>>0) / 255)&-1;
     $112 = Math_imul($$1148, $73)|0;
     $113 = (($112>>>0) / 255)&-1;
     $114 = Math_imul($$1164, $74)|0;
     $115 = (($114>>>0) / 255)&-1;
     $$0158 = $75;$$0159 = $115;$$0160 = $113;$$0161 = $111;
     break;
    }
    default: {
     $$0158 = $75;$$0159 = $74;$$0160 = $73;$$0161 = $71;
    }
    }
    $116 = $$0158 << 24;
    $117 = $$0161 << 16;
    $118 = $$0160 << 8;
    $119 = $118 | $117;
    $120 = $119 | $$0159;
    $121 = $120 | $116;
    HEAP32[$$0142177>>2] = $121;
    $122 = (($$2) + ($26))|0;
    $123 = ((($$0142177)) + 4|0);
    $124 = ($48|0)==(0);
    if ($124) {
     break;
    } else {
     $$0142177 = $123;$$0143176 = $$1144;$$0149175 = $122;$$0153174 = $$2155;$$in = $48;
    }
   }
   $$pre189 = HEAP32[$18>>2]|0;
   $129 = $$pre189;
  }
  $125 = HEAP32[$30>>2]|0;
  $126 = (($127) + ($125)|0);
  $128 = (($129) + -1)|0;
  HEAP32[$18>>2] = $128;
  $130 = ($129|0)==(0);
  if ($130) {
   break;
  }
  $131 = (($$1152$lcssa) + ($20))|0;
  $$pre188 = HEAP32[$24>>2]|0;
  $$0151181 = $131;$$0156180 = $$1157$lcssa;$127 = $126;$132 = $128;$133 = $126;$46 = $$pre188;
 }
 HEAP32[$29>>2] = $126;
 return;
}
function _SDL_Blit_BGRA8888_RGB888_Scale($0) {
 $0 = $0|0;
 var $$05982 = 0, $$06081 = 0, $$06186 = 0, $$06380 = 0, $$06579 = 0, $$06885 = 0, $$1 = 0, $$162$lcssa = 0, $$169$lcssa = 0, $$2 = 0, $$267 = 0, $$in = 0, $$pre = 0, $$pre93 = 0, $$pre94 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 << 16;
 $4 = ((($0)) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3|0) / ($5|0))&-1;
 $7 = ((($0)) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 << 16;
 $10 = ((($0)) + 24|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($9|0) / ($11|0))&-1;
 $13 = (($5) + -1)|0;
 HEAP32[$4>>2] = $13;
 $14 = ($5|0)==(0);
 if ($14) {
  return;
 }
 $15 = ((($0)) + 20|0);
 $16 = ((($0)) + 32|0);
 $17 = ((($0)) + 12|0);
 $$pre = HEAP32[$15>>2]|0;
 $$06186 = 0;$$06885 = 0;$25 = $11;$54 = $$pre;$59 = $13;$60 = $$pre;
 while(1) {
  $18 = ($$06885|0)>(65535);
  if ($18) {
   $19 = (($$06885) + -65536)|0;
   $20 = $19 >>> 16;
   $21 = $20 << 16;
   $22 = (($$06186) + 1)|0;
   $23 = (($22) + ($20))|0;
   $24 = (($19) - ($21))|0;
   $$162$lcssa = $23;$$169$lcssa = $24;
  } else {
   $$162$lcssa = $$06186;$$169$lcssa = $$06885;
  }
  $26 = ($25|0)==(0);
  if ($26) {
   $56 = $59;
  } else {
   $$05982 = $60;$$06081 = 0;$$06380 = -1;$$06579 = 65536;$$in = $25;
   while(1) {
    $27 = (($$in) + -1)|0;
    $28 = ($$06579|0)>(65535);
    if ($28) {
     $29 = (($$06579) + -65536)|0;
     $30 = $29 >>> 16;
     $31 = $30 << 16;
     $32 = (($$06380) + 1)|0;
     $33 = (($32) + ($30))|0;
     $34 = (($29) - ($31))|0;
     $35 = HEAP32[$0>>2]|0;
     $36 = HEAP32[$17>>2]|0;
     $37 = Math_imul($36, $$162$lcssa)|0;
     $38 = (($35) + ($37)|0);
     $39 = $33 << 2;
     $40 = (($38) + ($39)|0);
     $$1 = $40;$$2 = $33;$$267 = $34;
    } else {
     $$1 = $$06081;$$2 = $$06380;$$267 = $$06579;
    }
    $41 = HEAP32[$$1>>2]|0;
    $42 = $41 >>> 24;
    $43 = $41 << 8;
    $44 = $43 & 16711680;
    $45 = $41 >>> 8;
    $46 = $45 & 65280;
    $47 = $46 | $42;
    $48 = $47 | $44;
    HEAP32[$$05982>>2] = $48;
    $49 = (($$267) + ($12))|0;
    $50 = ((($$05982)) + 4|0);
    $51 = ($27|0)==(0);
    if ($51) {
     break;
    } else {
     $$05982 = $50;$$06081 = $$1;$$06380 = $$2;$$06579 = $49;$$in = $27;
    }
   }
   $$pre94 = HEAP32[$4>>2]|0;
   $56 = $$pre94;
  }
  $52 = HEAP32[$16>>2]|0;
  $53 = (($54) + ($52)|0);
  $55 = (($56) + -1)|0;
  HEAP32[$4>>2] = $55;
  $57 = ($56|0)==(0);
  if ($57) {
   break;
  }
  $58 = (($$169$lcssa) + ($6))|0;
  $$pre93 = HEAP32[$10>>2]|0;
  $$06186 = $$162$lcssa;$$06885 = $58;$25 = $$pre93;$54 = $53;$59 = $55;$60 = $53;
 }
 HEAP32[$15>>2] = $53;
 return;
}
function _SDL_Blit_BGRA8888_RGB888_Blend($0) {
 $0 = $0|0;
 var $$ = 0, $$$us = 0, $$08695 = 0, $$08695$us = 0, $$08794 = 0, $$08794$us = 0, $$088 = 0, $$088$us = 0, $$089 = 0, $$089$us = 0, $$090 = 0, $$090$us = 0, $$091$us = 0, $$092$us = 0, $$093$us = 0, $$1 = 0, $$1$us = 0, $$3 = 0, $$3$us = 0, $$pre = 0;
 var $$pre100 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $trunc = 0, $trunc$clear = 0, $trunc$clear1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + -1)|0;
 HEAP32[$3>>2] = $5;
 $6 = ($4|0)==(0);
 if ($6) {
  return;
 }
 $7 = ((($0)) + 20|0);
 $8 = ((($0)) + 24|0);
 $9 = ((($0)) + 12|0);
 $10 = ((($0)) + 32|0);
 $11 = $2 & 48;
 $12 = ($11|0)==(0);
 $13 = $2 & 112;
 $trunc = $13&255;
 $$pre = HEAP32[$0>>2]|0;
 $$pre100 = HEAP32[$7>>2]|0;
 $114 = $$pre;$117 = $$pre100;$121 = $$pre100;$122 = $$pre;
 while(1) {
  $14 = HEAP32[$8>>2]|0;
  $15 = (($14) + -1)|0;
  $16 = ($14|0)==(0);
  L6: do {
   if (!($16)) {
    if ($12) {
     $$08695 = $121;$$08794 = $122;$110 = $15;
     while(1) {
      $68 = HEAP32[$$08794>>2]|0;
      $69 = $68 >>> 24;
      $70 = $68 >>> 16;
      $71 = $70 & 255;
      $72 = $68 >>> 8;
      $73 = $72 & 255;
      $74 = HEAP32[$$08695>>2]|0;
      $75 = $74 >>> 16;
      $76 = $75 & 255;
      $77 = $74 >>> 8;
      $78 = $77 & 255;
      $79 = $74 & 255;
      $trunc$clear1 = $trunc & 127;
      switch ($trunc$clear1<<24>>24) {
      case 16:  {
       $80 = $68 & 255;
       $81 = $80 ^ 255;
       $82 = Math_imul($76, $81)|0;
       $83 = (($82>>>0) / 255)&-1;
       $84 = (($73) + ($83))|0;
       $85 = Math_imul($78, $81)|0;
       $86 = (($85>>>0) / 255)&-1;
       $87 = (($71) + ($86))|0;
       $88 = Math_imul($81, $79)|0;
       $89 = (($88>>>0) / 255)&-1;
       $90 = (($69) + ($89))|0;
       $$088 = $90;$$089 = $87;$$090 = $84;
       break;
      }
      case 32:  {
       $91 = (($73) + ($76))|0;
       $92 = ($91>>>0)<(255);
       $$ = $92 ? $91 : 255;
       $93 = (($71) + ($78))|0;
       $94 = ($93>>>0)<(255);
       $$3 = $94 ? $93 : 255;
       $95 = (($69) + ($79))|0;
       $96 = ($95>>>0)<(255);
       $$1 = $96 ? $95 : 255;
       $$088 = $$1;$$089 = $$3;$$090 = $$;
       break;
      }
      case 64:  {
       $97 = Math_imul($73, $76)|0;
       $98 = (($97>>>0) / 255)&-1;
       $99 = Math_imul($71, $78)|0;
       $100 = (($99>>>0) / 255)&-1;
       $101 = Math_imul($69, $79)|0;
       $102 = (($101>>>0) / 255)&-1;
       $$088 = $102;$$089 = $100;$$090 = $98;
       break;
      }
      default: {
       $$088 = $79;$$089 = $78;$$090 = $76;
      }
      }
      $103 = $$090 << 16;
      $104 = $$089 << 8;
      $105 = $104 | $103;
      $106 = $105 | $$088;
      HEAP32[$$08695>>2] = $106;
      $107 = ((($$08794)) + 4|0);
      $108 = ((($$08695)) + 4|0);
      $109 = (($110) + -1)|0;
      $111 = ($110|0)==(0);
      if ($111) {
       break L6;
      } else {
       $$08695 = $108;$$08794 = $107;$110 = $109;
      }
     }
    } else {
     $$08695$us = $121;$$08794$us = $122;$66 = $15;
    }
    while(1) {
     $17 = HEAP32[$$08794$us>>2]|0;
     $18 = $17 >>> 24;
     $19 = $17 >>> 16;
     $20 = $19 & 255;
     $21 = $17 >>> 8;
     $22 = $21 & 255;
     $23 = $17 & 255;
     $24 = HEAP32[$$08695$us>>2]|0;
     $25 = $24 >>> 16;
     $26 = $25 & 255;
     $27 = $24 >>> 8;
     $28 = $27 & 255;
     $29 = $24 & 255;
     $30 = ($23|0)==(255);
     if ($30) {
      $$091$us = $22;$$092$us = $18;$$093$us = $20;
     } else {
      $31 = Math_imul($18, $23)|0;
      $32 = Math_imul($20, $23)|0;
      $33 = Math_imul($22, $23)|0;
      $34 = (($33>>>0) / 255)&-1;
      $35 = (($32>>>0) / 255)&-1;
      $36 = (($31>>>0) / 255)&-1;
      $$091$us = $34;$$092$us = $36;$$093$us = $35;
     }
     $trunc$clear = $trunc & 127;
     switch ($trunc$clear<<24>>24) {
     case 16:  {
      $49 = $23 ^ 255;
      $50 = Math_imul($26, $49)|0;
      $51 = (($50>>>0) / 255)&-1;
      $52 = (($$091$us) + ($51))|0;
      $53 = Math_imul($28, $49)|0;
      $54 = (($53>>>0) / 255)&-1;
      $55 = (($$093$us) + ($54))|0;
      $56 = Math_imul($49, $29)|0;
      $57 = (($56>>>0) / 255)&-1;
      $58 = (($$092$us) + ($57))|0;
      $$088$us = $58;$$089$us = $55;$$090$us = $52;
      break;
     }
     case 32:  {
      $43 = (($$091$us) + ($26))|0;
      $44 = ($43>>>0)<(255);
      $$$us = $44 ? $43 : 255;
      $45 = (($$093$us) + ($28))|0;
      $46 = ($45>>>0)<(255);
      $$3$us = $46 ? $45 : 255;
      $47 = (($$092$us) + ($29))|0;
      $48 = ($47>>>0)<(255);
      $$1$us = $48 ? $47 : 255;
      $$088$us = $$1$us;$$089$us = $$3$us;$$090$us = $$$us;
      break;
     }
     case 64:  {
      $37 = Math_imul($$091$us, $26)|0;
      $38 = (($37>>>0) / 255)&-1;
      $39 = Math_imul($$093$us, $28)|0;
      $40 = (($39>>>0) / 255)&-1;
      $41 = Math_imul($$092$us, $29)|0;
      $42 = (($41>>>0) / 255)&-1;
      $$088$us = $42;$$089$us = $40;$$090$us = $38;
      break;
     }
     default: {
      $$088$us = $29;$$089$us = $28;$$090$us = $26;
     }
     }
     $59 = $$090$us << 16;
     $60 = $$089$us << 8;
     $61 = $60 | $59;
     $62 = $61 | $$088$us;
     HEAP32[$$08695$us>>2] = $62;
     $63 = ((($$08794$us)) + 4|0);
     $64 = ((($$08695$us)) + 4|0);
     $65 = (($66) + -1)|0;
     $67 = ($66|0)==(0);
     if ($67) {
      break L6;
     } else {
      $$08695$us = $64;$$08794$us = $63;$66 = $65;
     }
    }
   }
  } while(0);
  $112 = HEAP32[$9>>2]|0;
  $113 = (($114) + ($112)|0);
  $115 = HEAP32[$10>>2]|0;
  $116 = (($117) + ($115)|0);
  $118 = HEAP32[$3>>2]|0;
  $119 = (($118) + -1)|0;
  HEAP32[$3>>2] = $119;
  $120 = ($118|0)==(0);
  if ($120) {
   break;
  } else {
   $114 = $113;$117 = $116;$121 = $116;$122 = $113;
  }
 }
 HEAP32[$0>>2] = $113;
 HEAP32[$7>>2] = $116;
 return;
}
function _SDL_Blit_BGRA8888_RGB888_Blend_Scale($0) {
 $0 = $0|0;
 var $$ = 0, $$0113143 = 0, $$0114142 = 0, $$0116 = 0, $$0117 = 0, $$0118141 = 0, $$0120147 = 0, $$0122140 = 0, $$0125146 = 0, $$0127 = 0, $$0128 = 0, $$0129 = 0, $$0130 = 0, $$1 = 0, $$1115 = 0, $$1121$lcssa = 0, $$1126$lcssa = 0, $$2 = 0, $$2124 = 0, $$3 = 0;
 var $$in = 0, $$pre = 0, $$pre154 = 0, $$pre155 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $trunc = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 << 16;
 $6 = ((($0)) + 28|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5|0) / ($7|0))&-1;
 $9 = ((($0)) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10 << 16;
 $12 = ((($0)) + 24|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($11|0) / ($13|0))&-1;
 $15 = (($7) + -1)|0;
 HEAP32[$6>>2] = $15;
 $16 = ($7|0)==(0);
 if ($16) {
  return;
 }
 $17 = ((($0)) + 20|0);
 $18 = ((($0)) + 32|0);
 $19 = $2 & 48;
 $20 = ($19|0)!=(0);
 $21 = $2 & 112;
 $trunc = $21&255;
 $22 = ((($0)) + 12|0);
 $$pre = HEAP32[$17>>2]|0;
 $$0120147 = 0;$$0125146 = 0;$102 = $15;$103 = $$pre;$30 = $13;$97 = $$pre;
 while(1) {
  $23 = ($$0120147|0)>(65535);
  if ($23) {
   $24 = (($$0120147) + -65536)|0;
   $25 = $24 >>> 16;
   $26 = $25 << 16;
   $27 = (($$0125146) + 1)|0;
   $28 = (($27) + ($25))|0;
   $29 = (($24) - ($26))|0;
   $$1121$lcssa = $29;$$1126$lcssa = $28;
  } else {
   $$1121$lcssa = $$0120147;$$1126$lcssa = $$0125146;
  }
  $31 = ($30|0)==(0);
  if ($31) {
   $99 = $102;
  } else {
   $$0113143 = $103;$$0114142 = 0;$$0118141 = 65536;$$0122140 = -1;$$in = $30;
   while(1) {
    $32 = (($$in) + -1)|0;
    $33 = ($$0118141|0)>(65535);
    if ($33) {
     $34 = (($$0118141) + -65536)|0;
     $35 = $34 >>> 16;
     $36 = $35 << 16;
     $37 = (($$0122140) + 1)|0;
     $38 = (($37) + ($35))|0;
     $39 = (($34) - ($36))|0;
     $40 = HEAP32[$0>>2]|0;
     $41 = HEAP32[$22>>2]|0;
     $42 = Math_imul($41, $$1126$lcssa)|0;
     $43 = (($40) + ($42)|0);
     $44 = $38 << 2;
     $45 = (($43) + ($44)|0);
     $$1115 = $45;$$2 = $39;$$2124 = $38;
    } else {
     $$1115 = $$0114142;$$2 = $$0118141;$$2124 = $$0122140;
    }
    $46 = HEAP32[$$1115>>2]|0;
    $47 = $46 >>> 24;
    $48 = $46 >>> 16;
    $49 = $48 & 255;
    $50 = $46 >>> 8;
    $51 = $50 & 255;
    $52 = $46 & 255;
    $53 = HEAP32[$$0113143>>2]|0;
    $54 = $53 >>> 16;
    $55 = $54 & 255;
    $56 = $53 >>> 8;
    $57 = $56 & 255;
    $58 = $53 & 255;
    $59 = ($52|0)!=(255);
    $or$cond = $20 & $59;
    if ($or$cond) {
     $60 = Math_imul($47, $52)|0;
     $61 = Math_imul($49, $52)|0;
     $62 = Math_imul($51, $52)|0;
     $63 = (($62>>>0) / 255)&-1;
     $64 = (($61>>>0) / 255)&-1;
     $65 = (($60>>>0) / 255)&-1;
     $$0116 = $63;$$0117 = $64;$$0130 = $65;
    } else {
     $$0116 = $51;$$0117 = $49;$$0130 = $47;
    }
    $trunc$clear = $trunc & 127;
    switch ($trunc$clear<<24>>24) {
    case 16:  {
     $66 = $52 ^ 255;
     $67 = Math_imul($55, $66)|0;
     $68 = (($67>>>0) / 255)&-1;
     $69 = (($$0116) + ($68))|0;
     $70 = Math_imul($57, $66)|0;
     $71 = (($70>>>0) / 255)&-1;
     $72 = (($$0117) + ($71))|0;
     $73 = Math_imul($66, $58)|0;
     $74 = (($73>>>0) / 255)&-1;
     $75 = (($$0130) + ($74))|0;
     $$0127 = $75;$$0128 = $72;$$0129 = $69;
     break;
    }
    case 32:  {
     $76 = (($$0116) + ($55))|0;
     $77 = ($76>>>0)<(255);
     $$ = $77 ? $76 : 255;
     $78 = (($$0117) + ($57))|0;
     $79 = ($78>>>0)<(255);
     $$3 = $79 ? $78 : 255;
     $80 = (($$0130) + ($58))|0;
     $81 = ($80>>>0)<(255);
     $$1 = $81 ? $80 : 255;
     $$0127 = $$1;$$0128 = $$3;$$0129 = $$;
     break;
    }
    case 64:  {
     $82 = Math_imul($$0116, $55)|0;
     $83 = (($82>>>0) / 255)&-1;
     $84 = Math_imul($$0117, $57)|0;
     $85 = (($84>>>0) / 255)&-1;
     $86 = Math_imul($$0130, $58)|0;
     $87 = (($86>>>0) / 255)&-1;
     $$0127 = $87;$$0128 = $85;$$0129 = $83;
     break;
    }
    default: {
     $$0127 = $58;$$0128 = $57;$$0129 = $55;
    }
    }
    $88 = $$0129 << 16;
    $89 = $$0128 << 8;
    $90 = $89 | $88;
    $91 = $90 | $$0127;
    HEAP32[$$0113143>>2] = $91;
    $92 = (($$2) + ($14))|0;
    $93 = ((($$0113143)) + 4|0);
    $94 = ($32|0)==(0);
    if ($94) {
     break;
    } else {
     $$0113143 = $93;$$0114142 = $$1115;$$0118141 = $92;$$0122140 = $$2124;$$in = $32;
    }
   }
   $$pre155 = HEAP32[$6>>2]|0;
   $99 = $$pre155;
  }
  $95 = HEAP32[$18>>2]|0;
  $96 = (($97) + ($95)|0);
  $98 = (($99) + -1)|0;
  HEAP32[$6>>2] = $98;
  $100 = ($99|0)==(0);
  if ($100) {
   break;
  }
  $101 = (($$1121$lcssa) + ($8))|0;
  $$pre154 = HEAP32[$12>>2]|0;
  $$0120147 = $101;$$0125146 = $$1126$lcssa;$102 = $98;$103 = $96;$30 = $$pre154;$97 = $96;
 }
 HEAP32[$17>>2] = $96;
 return;
}
function _SDL_Blit_BGRA8888_RGB888_Modulate($0) {
 $0 = $0|0;
 var $$05157 = 0, $$05157$us$us = 0, $$05256 = 0, $$05256$us$us = 0, $$in = 0, $$in68 = 0, $$lcssa77$sink = 0, $$lcssa78$sink = 0, $$pre71 = 0, $$pre72 = 0, $$pre73 = 0, $$pre74 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = ((($0)) + 61|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = ((($0)) + 62|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = ((($0)) + 28|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($13) + -1)|0;
 HEAP32[$12>>2] = $14;
 $15 = ($13|0)==(0);
 if ($15) {
  return;
 }
 $16 = ((($0)) + 20|0);
 $17 = ((($0)) + 24|0);
 $18 = ((($0)) + 12|0);
 $19 = ((($0)) + 32|0);
 $20 = $2 & 1;
 $21 = ($20|0)==(0);
 $$pre72 = HEAP32[$0>>2]|0;
 $$pre73 = HEAP32[$16>>2]|0;
 if ($21) {
  $26 = $$pre72;$29 = $$pre73;$76 = $14;$77 = $$pre73;$78 = $$pre72;
  while(1) {
   $22 = HEAP32[$17>>2]|0;
   $23 = ($22|0)==(0);
   if ($23) {
    $31 = $76;
   } else {
    $$05157$us$us = $77;$$05256$us$us = $78;$$in68 = $22;
    while(1) {
     $33 = (($$in68) + -1)|0;
     $34 = HEAP32[$$05256$us$us>>2]|0;
     $35 = $34 >>> 24;
     $36 = $34 << 8;
     $37 = $36 & 16711680;
     $38 = $34 >>> 8;
     $39 = $38 & 65280;
     $40 = $39 | $37;
     $41 = $40 | $35;
     HEAP32[$$05157$us$us>>2] = $41;
     $42 = ((($$05256$us$us)) + 4|0);
     $43 = ((($$05157$us$us)) + 4|0);
     $44 = ($33|0)==(0);
     if ($44) {
      break;
     } else {
      $$05157$us$us = $43;$$05256$us$us = $42;$$in68 = $33;
     }
    }
    $$pre74 = HEAP32[$12>>2]|0;
    $31 = $$pre74;
   }
   $24 = HEAP32[$18>>2]|0;
   $25 = (($26) + ($24)|0);
   $27 = HEAP32[$19>>2]|0;
   $28 = (($29) + ($27)|0);
   $30 = (($31) + -1)|0;
   HEAP32[$12>>2] = $30;
   $32 = ($31|0)==(0);
   if ($32) {
    $$lcssa77$sink = $25;$$lcssa78$sink = $28;
    break;
   } else {
    $26 = $25;$29 = $28;$76 = $30;$77 = $28;$78 = $25;
   }
  }
 } else {
  $69 = $$pre72;$72 = $$pre73;$79 = $14;$80 = $$pre73;$81 = $$pre72;
  while(1) {
   $45 = HEAP32[$17>>2]|0;
   $46 = ($45|0)==(0);
   if ($46) {
    $74 = $79;
   } else {
    $$05157 = $80;$$05256 = $81;$$in = $45;
    while(1) {
     $47 = (($$in) + -1)|0;
     $48 = HEAP32[$$05256>>2]|0;
     $49 = $48 >>> 24;
     $50 = $48 >>> 16;
     $51 = $50 & 255;
     $52 = $48 >>> 8;
     $53 = $52 & 255;
     $54 = Math_imul($49, $11)|0;
     $55 = Math_imul($51, $8)|0;
     $56 = Math_imul($53, $5)|0;
     $57 = (($56>>>0) / 255)&-1;
     $58 = (($55>>>0) / 255)&-1;
     $59 = (($54>>>0) / 255)&-1;
     $60 = $57 << 16;
     $61 = $58 << 8;
     $62 = $61 | $60;
     $63 = $62 | $59;
     HEAP32[$$05157>>2] = $63;
     $64 = ((($$05256)) + 4|0);
     $65 = ((($$05157)) + 4|0);
     $66 = ($47|0)==(0);
     if ($66) {
      break;
     } else {
      $$05157 = $65;$$05256 = $64;$$in = $47;
     }
    }
    $$pre71 = HEAP32[$12>>2]|0;
    $74 = $$pre71;
   }
   $67 = HEAP32[$18>>2]|0;
   $68 = (($69) + ($67)|0);
   $70 = HEAP32[$19>>2]|0;
   $71 = (($72) + ($70)|0);
   $73 = (($74) + -1)|0;
   HEAP32[$12>>2] = $73;
   $75 = ($74|0)==(0);
   if ($75) {
    $$lcssa77$sink = $68;$$lcssa78$sink = $71;
    break;
   } else {
    $69 = $68;$72 = $71;$79 = $73;$80 = $71;$81 = $68;
   }
  }
 }
 HEAP32[$0>>2] = $$lcssa77$sink;
 HEAP32[$16>>2] = $$lcssa78$sink;
 return;
}
function _SDL_Blit_BGRA8888_RGB888_Modulate_Scale($0) {
 $0 = $0|0;
 var $$078104 = 0, $$078104$us = 0, $$079103 = 0, $$079103$us = 0, $$081102 = 0, $$081102$us = 0, $$083108 = 0, $$085101 = 0, $$085101$us = 0, $$088107 = 0, $$1 = 0, $$1$us = 0, $$184$lcssa = 0, $$189$lcssa = 0, $$2 = 0, $$2$us = 0, $$287 = 0, $$287$us = 0, $$pre = 0, $$pre118 = 0;
 var $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = ((($0)) + 61|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = ((($0)) + 62|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = ((($0)) + 8|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13 << 16;
 $15 = ((($0)) + 28|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($14|0) / ($16|0))&-1;
 $18 = ((($0)) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = $19 << 16;
 $21 = ((($0)) + 24|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($20|0) / ($22|0))&-1;
 $24 = (($16) + -1)|0;
 HEAP32[$15>>2] = $24;
 $25 = ($16|0)==(0);
 if ($25) {
  return;
 }
 $26 = ((($0)) + 20|0);
 $27 = ((($0)) + 32|0);
 $28 = $2 & 1;
 $29 = ($28|0)==(0);
 $30 = ((($0)) + 12|0);
 $$pre = HEAP32[$26>>2]|0;
 $$083108 = 0;$$088107 = 0;$103 = $$pre;$108 = $$pre;$39 = $22;
 while(1) {
  $31 = ($$083108|0)>(65535);
  if ($31) {
   $32 = (($$083108) + -65536)|0;
   $33 = $32 >>> 16;
   $34 = $33 << 16;
   $35 = (($$088107) + 1)|0;
   $36 = (($35) + ($33))|0;
   $37 = (($32) - ($34))|0;
   $$184$lcssa = $37;$$189$lcssa = $36;
  } else {
   $$184$lcssa = $$083108;$$189$lcssa = $$088107;
  }
  $38 = (($39) + -1)|0;
  $40 = ($39|0)==(0);
  if (!($40)) {
   if ($29) {
    $$078104$us = $108;$$079103$us = 0;$$081102$us = 65536;$$085101$us = -1;$65 = $38;
    while(1) {
     $41 = ($$081102$us|0)>(65535);
     if ($41) {
      $42 = (($$081102$us) + -65536)|0;
      $43 = $42 >>> 16;
      $44 = $43 << 16;
      $45 = (($$085101$us) + 1)|0;
      $46 = (($45) + ($43))|0;
      $47 = (($42) - ($44))|0;
      $48 = HEAP32[$0>>2]|0;
      $49 = HEAP32[$30>>2]|0;
      $50 = Math_imul($49, $$189$lcssa)|0;
      $51 = (($48) + ($50)|0);
      $52 = $46 << 2;
      $53 = (($51) + ($52)|0);
      $$1$us = $53;$$2$us = $47;$$287$us = $46;
     } else {
      $$1$us = $$079103$us;$$2$us = $$081102$us;$$287$us = $$085101$us;
     }
     $54 = HEAP32[$$1$us>>2]|0;
     $55 = $54 >>> 24;
     $56 = $54 << 8;
     $57 = $56 & 16711680;
     $58 = $54 >>> 8;
     $59 = $58 & 65280;
     $60 = $55 | $59;
     $61 = $60 | $57;
     HEAP32[$$078104$us>>2] = $61;
     $62 = (($$2$us) + ($23))|0;
     $63 = ((($$078104$us)) + 4|0);
     $64 = (($65) + -1)|0;
     $66 = ($65|0)==(0);
     if ($66) {
      break;
     } else {
      $$078104$us = $63;$$079103$us = $$1$us;$$081102$us = $62;$$085101$us = $$287$us;$65 = $64;
     }
    }
   } else {
    $$078104 = $108;$$079103 = 0;$$081102 = 65536;$$085101 = -1;$99 = $38;
    while(1) {
     $67 = ($$081102|0)>(65535);
     if ($67) {
      $68 = (($$081102) + -65536)|0;
      $69 = $68 >>> 16;
      $70 = $69 << 16;
      $71 = (($$085101) + 1)|0;
      $72 = (($71) + ($69))|0;
      $73 = (($68) - ($70))|0;
      $74 = HEAP32[$0>>2]|0;
      $75 = HEAP32[$30>>2]|0;
      $76 = Math_imul($75, $$189$lcssa)|0;
      $77 = (($74) + ($76)|0);
      $78 = $72 << 2;
      $79 = (($77) + ($78)|0);
      $$1 = $79;$$2 = $73;$$287 = $72;
     } else {
      $$1 = $$079103;$$2 = $$081102;$$287 = $$085101;
     }
     $80 = HEAP32[$$1>>2]|0;
     $81 = $80 >>> 24;
     $82 = $80 >>> 16;
     $83 = $82 & 255;
     $84 = $80 >>> 8;
     $85 = $84 & 255;
     $86 = Math_imul($81, $11)|0;
     $87 = Math_imul($83, $8)|0;
     $88 = Math_imul($85, $5)|0;
     $89 = (($88>>>0) / 255)&-1;
     $90 = (($87>>>0) / 255)&-1;
     $91 = (($86>>>0) / 255)&-1;
     $92 = $89 << 16;
     $93 = $90 << 8;
     $94 = $91 | $93;
     $95 = $94 | $92;
     HEAP32[$$078104>>2] = $95;
     $96 = (($$2) + ($23))|0;
     $97 = ((($$078104)) + 4|0);
     $98 = (($99) + -1)|0;
     $100 = ($99|0)==(0);
     if ($100) {
      break;
     } else {
      $$078104 = $97;$$079103 = $$1;$$081102 = $96;$$085101 = $$287;$99 = $98;
     }
    }
   }
  }
  $101 = HEAP32[$27>>2]|0;
  $102 = (($103) + ($101)|0);
  $104 = HEAP32[$15>>2]|0;
  $105 = (($104) + -1)|0;
  HEAP32[$15>>2] = $105;
  $106 = ($104|0)==(0);
  if ($106) {
   break;
  }
  $107 = (($$184$lcssa) + ($17))|0;
  $$pre118 = HEAP32[$21>>2]|0;
  $$083108 = $107;$$088107 = $$189$lcssa;$103 = $102;$108 = $102;$39 = $$pre118;
 }
 HEAP32[$26>>2] = $102;
 return;
}
function _SDL_Blit_BGRA8888_RGB888_Modulate_Blend($0) {
 $0 = $0|0;
 var $$ = 0, $$0108121 = 0, $$0109120 = 0, $$0110 = 0, $$0111 = 0, $$0112 = 0, $$0113 = 0, $$0114 = 0, $$0116 = 0, $$0118 = 0, $$1 = 0, $$1115 = 0, $$1117 = 0, $$1119 = 0, $$3 = 0, $$in = 0, $$pre = 0, $$pre125 = 0, $$pre126 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $or$cond = 0, $trunc = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = ((($0)) + 61|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = ((($0)) + 62|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = ((($0)) + 63|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = $13&255;
 $15 = ((($0)) + 28|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + -1)|0;
 HEAP32[$15>>2] = $17;
 $18 = ($16|0)==(0);
 if ($18) {
  return;
 }
 $19 = ((($0)) + 20|0);
 $20 = ((($0)) + 24|0);
 $21 = ((($0)) + 12|0);
 $22 = ((($0)) + 32|0);
 $23 = $2 & 1;
 $24 = ($23|0)==(0);
 $25 = $2 & 2;
 $26 = ($25|0)==(0);
 $27 = $2 & 48;
 $28 = ($27|0)!=(0);
 $29 = $2 & 112;
 $trunc = $29&255;
 $$pre = HEAP32[$0>>2]|0;
 $$pre125 = HEAP32[$19>>2]|0;
 $100 = $$pre125;$101 = $$pre;$92 = $$pre;$95 = $$pre125;$99 = $17;
 while(1) {
  $30 = HEAP32[$20>>2]|0;
  $31 = ($30|0)==(0);
  if ($31) {
   $97 = $99;
  } else {
   $$0108121 = $100;$$0109120 = $101;$$in = $30;
   while(1) {
    $32 = (($$in) + -1)|0;
    $33 = HEAP32[$$0109120>>2]|0;
    $34 = $33 >>> 24;
    $35 = $33 >>> 16;
    $36 = $35 & 255;
    $37 = $33 >>> 8;
    $38 = $37 & 255;
    $39 = $33 & 255;
    $40 = HEAP32[$$0108121>>2]|0;
    $41 = $40 >>> 16;
    $42 = $41 & 255;
    $43 = $40 >>> 8;
    $44 = $43 & 255;
    $45 = $40 & 255;
    if ($24) {
     $$0114 = $34;$$0116 = $36;$$0118 = $38;
    } else {
     $46 = Math_imul($34, $11)|0;
     $47 = Math_imul($36, $8)|0;
     $48 = Math_imul($38, $5)|0;
     $49 = (($48>>>0) / 255)&-1;
     $50 = (($47>>>0) / 255)&-1;
     $51 = (($46>>>0) / 255)&-1;
     $$0114 = $51;$$0116 = $50;$$0118 = $49;
    }
    $52 = Math_imul($39, $14)|0;
    $53 = (($52>>>0) / 255)&-1;
    $$0113 = $26 ? $39 : $53;
    $54 = ($$0113>>>0)<(255);
    $or$cond = $28 & $54;
    if ($or$cond) {
     $55 = Math_imul($$0114, $$0113)|0;
     $56 = Math_imul($$0116, $$0113)|0;
     $57 = Math_imul($$0118, $$0113)|0;
     $58 = (($57>>>0) / 255)&-1;
     $59 = (($56>>>0) / 255)&-1;
     $60 = (($55>>>0) / 255)&-1;
     $$1115 = $60;$$1117 = $59;$$1119 = $58;
    } else {
     $$1115 = $$0114;$$1117 = $$0116;$$1119 = $$0118;
    }
    $trunc$clear = $trunc & 127;
    switch ($trunc$clear<<24>>24) {
    case 16:  {
     $61 = (255 - ($$0113))|0;
     $62 = Math_imul($61, $42)|0;
     $63 = (($62>>>0) / 255)&-1;
     $64 = (($$1119) + ($63))|0;
     $65 = Math_imul($61, $44)|0;
     $66 = (($65>>>0) / 255)&-1;
     $67 = (($$1117) + ($66))|0;
     $68 = Math_imul($61, $45)|0;
     $69 = (($68>>>0) / 255)&-1;
     $70 = (($$1115) + ($69))|0;
     $$0110 = $70;$$0111 = $67;$$0112 = $64;
     break;
    }
    case 32:  {
     $71 = (($$1119) + ($42))|0;
     $72 = ($71>>>0)<(255);
     $$ = $72 ? $71 : 255;
     $73 = (($$1117) + ($44))|0;
     $74 = ($73>>>0)<(255);
     $$3 = $74 ? $73 : 255;
     $75 = (($$1115) + ($45))|0;
     $76 = ($75>>>0)<(255);
     $$1 = $76 ? $75 : 255;
     $$0110 = $$1;$$0111 = $$3;$$0112 = $$;
     break;
    }
    case 64:  {
     $77 = Math_imul($$1119, $42)|0;
     $78 = (($77>>>0) / 255)&-1;
     $79 = Math_imul($$1117, $44)|0;
     $80 = (($79>>>0) / 255)&-1;
     $81 = Math_imul($$1115, $45)|0;
     $82 = (($81>>>0) / 255)&-1;
     $$0110 = $82;$$0111 = $80;$$0112 = $78;
     break;
    }
    default: {
     $$0110 = $45;$$0111 = $44;$$0112 = $42;
    }
    }
    $83 = $$0112 << 16;
    $84 = $$0111 << 8;
    $85 = $84 | $83;
    $86 = $85 | $$0110;
    HEAP32[$$0108121>>2] = $86;
    $87 = ((($$0109120)) + 4|0);
    $88 = ((($$0108121)) + 4|0);
    $89 = ($32|0)==(0);
    if ($89) {
     break;
    } else {
     $$0108121 = $88;$$0109120 = $87;$$in = $32;
    }
   }
   $$pre126 = HEAP32[$15>>2]|0;
   $97 = $$pre126;
  }
  $90 = HEAP32[$21>>2]|0;
  $91 = (($92) + ($90)|0);
  $93 = HEAP32[$22>>2]|0;
  $94 = (($95) + ($93)|0);
  $96 = (($97) + -1)|0;
  HEAP32[$15>>2] = $96;
  $98 = ($97|0)==(0);
  if ($98) {
   break;
  } else {
   $100 = $94;$101 = $91;$92 = $91;$95 = $94;$99 = $96;
  }
 }
 HEAP32[$0>>2] = $91;
 HEAP32[$19>>2] = $94;
 return;
}
function _SDL_Blit_BGRA8888_RGB888_Modulate_Blend_Scale($0) {
 $0 = $0|0;
 var $$ = 0, $$0135169 = 0, $$0136168 = 0, $$0138 = 0, $$0140 = 0, $$0142167 = 0, $$0144173 = 0, $$0146166 = 0, $$0149172 = 0, $$0151 = 0, $$0152 = 0, $$0153 = 0, $$0154 = 0, $$0155 = 0, $$1 = 0, $$1137 = 0, $$1139 = 0, $$1141 = 0, $$1145$lcssa = 0, $$1150$lcssa = 0;
 var $$1156 = 0, $$2 = 0, $$2148 = 0, $$3 = 0, $$in = 0, $$pre = 0, $$pre180 = 0, $$pre181 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $trunc = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = ((($0)) + 61|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = ((($0)) + 62|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = ((($0)) + 63|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = $13&255;
 $15 = ((($0)) + 8|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $16 << 16;
 $18 = ((($0)) + 28|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($17|0) / ($19|0))&-1;
 $21 = ((($0)) + 4|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = $22 << 16;
 $24 = ((($0)) + 24|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($23|0) / ($25|0))&-1;
 $27 = (($19) + -1)|0;
 HEAP32[$18>>2] = $27;
 $28 = ($19|0)==(0);
 if ($28) {
  return;
 }
 $29 = ((($0)) + 20|0);
 $30 = ((($0)) + 32|0);
 $31 = $2 & 1;
 $32 = ($31|0)==(0);
 $33 = $2 & 2;
 $34 = ($33|0)==(0);
 $35 = $2 & 48;
 $36 = ($35|0)!=(0);
 $37 = $2 & 112;
 $trunc = $37&255;
 $38 = ((($0)) + 12|0);
 $$pre = HEAP32[$29>>2]|0;
 $$0144173 = 0;$$0149172 = 0;$121 = $$pre;$126 = $27;$127 = $$pre;$46 = $25;
 while(1) {
  $39 = ($$0144173|0)>(65535);
  if ($39) {
   $40 = (($$0144173) + -65536)|0;
   $41 = $40 >>> 16;
   $42 = $41 << 16;
   $43 = (($$0149172) + 1)|0;
   $44 = (($43) + ($41))|0;
   $45 = (($40) - ($42))|0;
   $$1145$lcssa = $45;$$1150$lcssa = $44;
  } else {
   $$1145$lcssa = $$0144173;$$1150$lcssa = $$0149172;
  }
  $47 = ($46|0)==(0);
  if ($47) {
   $123 = $126;
  } else {
   $$0135169 = $127;$$0136168 = 0;$$0142167 = 65536;$$0146166 = -1;$$in = $46;
   while(1) {
    $48 = (($$in) + -1)|0;
    $49 = ($$0142167|0)>(65535);
    if ($49) {
     $50 = (($$0142167) + -65536)|0;
     $51 = $50 >>> 16;
     $52 = $51 << 16;
     $53 = (($$0146166) + 1)|0;
     $54 = (($53) + ($51))|0;
     $55 = (($50) - ($52))|0;
     $56 = HEAP32[$0>>2]|0;
     $57 = HEAP32[$38>>2]|0;
     $58 = Math_imul($57, $$1150$lcssa)|0;
     $59 = (($56) + ($58)|0);
     $60 = $54 << 2;
     $61 = (($59) + ($60)|0);
     $$1137 = $61;$$2 = $55;$$2148 = $54;
    } else {
     $$1137 = $$0136168;$$2 = $$0142167;$$2148 = $$0146166;
    }
    $62 = HEAP32[$$1137>>2]|0;
    $63 = $62 >>> 24;
    $64 = $62 >>> 16;
    $65 = $64 & 255;
    $66 = $62 >>> 8;
    $67 = $66 & 255;
    $68 = $62 & 255;
    $69 = HEAP32[$$0135169>>2]|0;
    $70 = $69 >>> 16;
    $71 = $70 & 255;
    $72 = $69 >>> 8;
    $73 = $72 & 255;
    $74 = $69 & 255;
    if ($32) {
     $$0138 = $67;$$0140 = $65;$$0155 = $63;
    } else {
     $75 = Math_imul($63, $11)|0;
     $76 = Math_imul($65, $8)|0;
     $77 = Math_imul($67, $5)|0;
     $78 = (($77>>>0) / 255)&-1;
     $79 = (($76>>>0) / 255)&-1;
     $80 = (($75>>>0) / 255)&-1;
     $$0138 = $78;$$0140 = $79;$$0155 = $80;
    }
    $81 = Math_imul($68, $14)|0;
    $82 = (($81>>>0) / 255)&-1;
    $$0154 = $34 ? $68 : $82;
    $83 = ($$0154>>>0)<(255);
    $or$cond = $36 & $83;
    if ($or$cond) {
     $84 = Math_imul($$0155, $$0154)|0;
     $85 = Math_imul($$0140, $$0154)|0;
     $86 = Math_imul($$0138, $$0154)|0;
     $87 = (($86>>>0) / 255)&-1;
     $88 = (($85>>>0) / 255)&-1;
     $89 = (($84>>>0) / 255)&-1;
     $$1139 = $87;$$1141 = $88;$$1156 = $89;
    } else {
     $$1139 = $$0138;$$1141 = $$0140;$$1156 = $$0155;
    }
    $trunc$clear = $trunc & 127;
    switch ($trunc$clear<<24>>24) {
    case 16:  {
     $90 = (255 - ($$0154))|0;
     $91 = Math_imul($90, $71)|0;
     $92 = (($91>>>0) / 255)&-1;
     $93 = (($$1139) + ($92))|0;
     $94 = Math_imul($90, $73)|0;
     $95 = (($94>>>0) / 255)&-1;
     $96 = (($$1141) + ($95))|0;
     $97 = Math_imul($90, $74)|0;
     $98 = (($97>>>0) / 255)&-1;
     $99 = (($$1156) + ($98))|0;
     $$0151 = $99;$$0152 = $96;$$0153 = $93;
     break;
    }
    case 32:  {
     $100 = (($$1139) + ($71))|0;
     $101 = ($100>>>0)<(255);
     $$ = $101 ? $100 : 255;
     $102 = (($$1141) + ($73))|0;
     $103 = ($102>>>0)<(255);
     $$3 = $103 ? $102 : 255;
     $104 = (($$1156) + ($74))|0;
     $105 = ($104>>>0)<(255);
     $$1 = $105 ? $104 : 255;
     $$0151 = $$1;$$0152 = $$3;$$0153 = $$;
     break;
    }
    case 64:  {
     $106 = Math_imul($$1139, $71)|0;
     $107 = (($106>>>0) / 255)&-1;
     $108 = Math_imul($$1141, $73)|0;
     $109 = (($108>>>0) / 255)&-1;
     $110 = Math_imul($$1156, $74)|0;
     $111 = (($110>>>0) / 255)&-1;
     $$0151 = $111;$$0152 = $109;$$0153 = $107;
     break;
    }
    default: {
     $$0151 = $74;$$0152 = $73;$$0153 = $71;
    }
    }
    $112 = $$0153 << 16;
    $113 = $$0152 << 8;
    $114 = $113 | $112;
    $115 = $114 | $$0151;
    HEAP32[$$0135169>>2] = $115;
    $116 = (($$2) + ($26))|0;
    $117 = ((($$0135169)) + 4|0);
    $118 = ($48|0)==(0);
    if ($118) {
     break;
    } else {
     $$0135169 = $117;$$0136168 = $$1137;$$0142167 = $116;$$0146166 = $$2148;$$in = $48;
    }
   }
   $$pre181 = HEAP32[$18>>2]|0;
   $123 = $$pre181;
  }
  $119 = HEAP32[$30>>2]|0;
  $120 = (($121) + ($119)|0);
  $122 = (($123) + -1)|0;
  HEAP32[$18>>2] = $122;
  $124 = ($123|0)==(0);
  if ($124) {
   break;
  }
  $125 = (($$1145$lcssa) + ($20))|0;
  $$pre180 = HEAP32[$24>>2]|0;
  $$0144173 = $125;$$0149172 = $$1150$lcssa;$121 = $120;$126 = $122;$127 = $120;$46 = $$pre180;
 }
 HEAP32[$29>>2] = $120;
 return;
}
function _SDL_Blit_BGRA8888_BGR888_Scale($0) {
 $0 = $0|0;
 var $$05982 = 0, $$06081 = 0, $$06186 = 0, $$06380 = 0, $$06579 = 0, $$06885 = 0, $$1 = 0, $$162$lcssa = 0, $$169$lcssa = 0, $$2 = 0, $$267 = 0, $$in = 0, $$pre = 0, $$pre93 = 0, $$pre94 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 << 16;
 $4 = ((($0)) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3|0) / ($5|0))&-1;
 $7 = ((($0)) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 << 16;
 $10 = ((($0)) + 24|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($9|0) / ($11|0))&-1;
 $13 = (($5) + -1)|0;
 HEAP32[$4>>2] = $13;
 $14 = ($5|0)==(0);
 if ($14) {
  return;
 }
 $15 = ((($0)) + 20|0);
 $16 = ((($0)) + 32|0);
 $17 = ((($0)) + 12|0);
 $$pre = HEAP32[$15>>2]|0;
 $$06186 = 0;$$06885 = 0;$25 = $11;$54 = $$pre;$59 = $13;$60 = $$pre;
 while(1) {
  $18 = ($$06885|0)>(65535);
  if ($18) {
   $19 = (($$06885) + -65536)|0;
   $20 = $19 >>> 16;
   $21 = $20 << 16;
   $22 = (($$06186) + 1)|0;
   $23 = (($22) + ($20))|0;
   $24 = (($19) - ($21))|0;
   $$162$lcssa = $23;$$169$lcssa = $24;
  } else {
   $$162$lcssa = $$06186;$$169$lcssa = $$06885;
  }
  $26 = ($25|0)==(0);
  if ($26) {
   $56 = $59;
  } else {
   $$05982 = $60;$$06081 = 0;$$06380 = -1;$$06579 = 65536;$$in = $25;
   while(1) {
    $27 = (($$in) + -1)|0;
    $28 = ($$06579|0)>(65535);
    if ($28) {
     $29 = (($$06579) + -65536)|0;
     $30 = $29 >>> 16;
     $31 = $30 << 16;
     $32 = (($$06380) + 1)|0;
     $33 = (($32) + ($30))|0;
     $34 = (($29) - ($31))|0;
     $35 = HEAP32[$0>>2]|0;
     $36 = HEAP32[$17>>2]|0;
     $37 = Math_imul($36, $$162$lcssa)|0;
     $38 = (($35) + ($37)|0);
     $39 = $33 << 2;
     $40 = (($38) + ($39)|0);
     $$1 = $40;$$2 = $33;$$267 = $34;
    } else {
     $$1 = $$06081;$$2 = $$06380;$$267 = $$06579;
    }
    $41 = HEAP32[$$1>>2]|0;
    $42 = $41 >>> 24;
    $43 = $41 >>> 8;
    $44 = $43 & 255;
    $45 = $42 << 16;
    $46 = $43 & 65280;
    $47 = $45 | $46;
    $48 = $47 | $44;
    HEAP32[$$05982>>2] = $48;
    $49 = (($$267) + ($12))|0;
    $50 = ((($$05982)) + 4|0);
    $51 = ($27|0)==(0);
    if ($51) {
     break;
    } else {
     $$05982 = $50;$$06081 = $$1;$$06380 = $$2;$$06579 = $49;$$in = $27;
    }
   }
   $$pre94 = HEAP32[$4>>2]|0;
   $56 = $$pre94;
  }
  $52 = HEAP32[$16>>2]|0;
  $53 = (($54) + ($52)|0);
  $55 = (($56) + -1)|0;
  HEAP32[$4>>2] = $55;
  $57 = ($56|0)==(0);
  if ($57) {
   break;
  }
  $58 = (($$169$lcssa) + ($6))|0;
  $$pre93 = HEAP32[$10>>2]|0;
  $$06186 = $$162$lcssa;$$06885 = $58;$25 = $$pre93;$54 = $53;$59 = $55;$60 = $53;
 }
 HEAP32[$15>>2] = $53;
 return;
}
function _SDL_Blit_BGRA8888_BGR888_Blend($0) {
 $0 = $0|0;
 var $$ = 0, $$$us = 0, $$08695 = 0, $$08695$us = 0, $$08794 = 0, $$08794$us = 0, $$088 = 0, $$088$us = 0, $$089 = 0, $$089$us = 0, $$090 = 0, $$090$us = 0, $$091$us = 0, $$092$us = 0, $$093$us = 0, $$1 = 0, $$1$us = 0, $$3 = 0, $$3$us = 0, $$pre = 0;
 var $$pre100 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $trunc = 0, $trunc$clear = 0, $trunc$clear1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + -1)|0;
 HEAP32[$3>>2] = $5;
 $6 = ($4|0)==(0);
 if ($6) {
  return;
 }
 $7 = ((($0)) + 20|0);
 $8 = ((($0)) + 24|0);
 $9 = ((($0)) + 12|0);
 $10 = ((($0)) + 32|0);
 $11 = $2 & 48;
 $12 = ($11|0)==(0);
 $13 = $2 & 112;
 $trunc = $13&255;
 $$pre = HEAP32[$0>>2]|0;
 $$pre100 = HEAP32[$7>>2]|0;
 $114 = $$pre;$117 = $$pre100;$121 = $$pre100;$122 = $$pre;
 while(1) {
  $14 = HEAP32[$8>>2]|0;
  $15 = (($14) + -1)|0;
  $16 = ($14|0)==(0);
  L6: do {
   if (!($16)) {
    if ($12) {
     $$08695 = $121;$$08794 = $122;$110 = $15;
     while(1) {
      $68 = HEAP32[$$08794>>2]|0;
      $69 = $68 >>> 24;
      $70 = $68 >>> 16;
      $71 = $70 & 255;
      $72 = $68 >>> 8;
      $73 = $72 & 255;
      $74 = HEAP32[$$08695>>2]|0;
      $75 = $74 >>> 16;
      $76 = $75 & 255;
      $77 = $74 >>> 8;
      $78 = $77 & 255;
      $79 = $74 & 255;
      $trunc$clear1 = $trunc & 127;
      switch ($trunc$clear1<<24>>24) {
      case 16:  {
       $80 = $68 & 255;
       $81 = $80 ^ 255;
       $82 = Math_imul($81, $79)|0;
       $83 = (($82>>>0) / 255)&-1;
       $84 = (($73) + ($83))|0;
       $85 = Math_imul($78, $81)|0;
       $86 = (($85>>>0) / 255)&-1;
       $87 = (($71) + ($86))|0;
       $88 = Math_imul($76, $81)|0;
       $89 = (($88>>>0) / 255)&-1;
       $90 = (($69) + ($89))|0;
       $$088 = $90;$$089 = $87;$$090 = $84;
       break;
      }
      case 32:  {
       $91 = (($73) + ($79))|0;
       $92 = ($91>>>0)<(255);
       $$ = $92 ? $91 : 255;
       $93 = (($71) + ($78))|0;
       $94 = ($93>>>0)<(255);
       $$3 = $94 ? $93 : 255;
       $95 = (($69) + ($76))|0;
       $96 = ($95>>>0)<(255);
       $$1 = $96 ? $95 : 255;
       $$088 = $$1;$$089 = $$3;$$090 = $$;
       break;
      }
      case 64:  {
       $97 = Math_imul($73, $79)|0;
       $98 = (($97>>>0) / 255)&-1;
       $99 = Math_imul($71, $78)|0;
       $100 = (($99>>>0) / 255)&-1;
       $101 = Math_imul($69, $76)|0;
       $102 = (($101>>>0) / 255)&-1;
       $$088 = $102;$$089 = $100;$$090 = $98;
       break;
      }
      default: {
       $$088 = $76;$$089 = $78;$$090 = $79;
      }
      }
      $103 = $$088 << 16;
      $104 = $$089 << 8;
      $105 = $104 | $$090;
      $106 = $105 | $103;
      HEAP32[$$08695>>2] = $106;
      $107 = ((($$08794)) + 4|0);
      $108 = ((($$08695)) + 4|0);
      $109 = (($110) + -1)|0;
      $111 = ($110|0)==(0);
      if ($111) {
       break L6;
      } else {
       $$08695 = $108;$$08794 = $107;$110 = $109;
      }
     }
    } else {
     $$08695$us = $121;$$08794$us = $122;$66 = $15;
    }
    while(1) {
     $17 = HEAP32[$$08794$us>>2]|0;
     $18 = $17 >>> 24;
     $19 = $17 >>> 16;
     $20 = $19 & 255;
     $21 = $17 >>> 8;
     $22 = $21 & 255;
     $23 = $17 & 255;
     $24 = HEAP32[$$08695$us>>2]|0;
     $25 = $24 >>> 16;
     $26 = $25 & 255;
     $27 = $24 >>> 8;
     $28 = $27 & 255;
     $29 = $24 & 255;
     $30 = ($23|0)==(255);
     if ($30) {
      $$091$us = $22;$$092$us = $18;$$093$us = $20;
     } else {
      $31 = Math_imul($18, $23)|0;
      $32 = Math_imul($20, $23)|0;
      $33 = Math_imul($22, $23)|0;
      $34 = (($33>>>0) / 255)&-1;
      $35 = (($32>>>0) / 255)&-1;
      $36 = (($31>>>0) / 255)&-1;
      $$091$us = $34;$$092$us = $36;$$093$us = $35;
     }
     $trunc$clear = $trunc & 127;
     switch ($trunc$clear<<24>>24) {
     case 16:  {
      $49 = $23 ^ 255;
      $50 = Math_imul($49, $29)|0;
      $51 = (($50>>>0) / 255)&-1;
      $52 = (($$091$us) + ($51))|0;
      $53 = Math_imul($28, $49)|0;
      $54 = (($53>>>0) / 255)&-1;
      $55 = (($$093$us) + ($54))|0;
      $56 = Math_imul($26, $49)|0;
      $57 = (($56>>>0) / 255)&-1;
      $58 = (($$092$us) + ($57))|0;
      $$088$us = $58;$$089$us = $55;$$090$us = $52;
      break;
     }
     case 32:  {
      $43 = (($$091$us) + ($29))|0;
      $44 = ($43>>>0)<(255);
      $$$us = $44 ? $43 : 255;
      $45 = (($$093$us) + ($28))|0;
      $46 = ($45>>>0)<(255);
      $$3$us = $46 ? $45 : 255;
      $47 = (($$092$us) + ($26))|0;
      $48 = ($47>>>0)<(255);
      $$1$us = $48 ? $47 : 255;
      $$088$us = $$1$us;$$089$us = $$3$us;$$090$us = $$$us;
      break;
     }
     case 64:  {
      $37 = Math_imul($$091$us, $29)|0;
      $38 = (($37>>>0) / 255)&-1;
      $39 = Math_imul($$093$us, $28)|0;
      $40 = (($39>>>0) / 255)&-1;
      $41 = Math_imul($$092$us, $26)|0;
      $42 = (($41>>>0) / 255)&-1;
      $$088$us = $42;$$089$us = $40;$$090$us = $38;
      break;
     }
     default: {
      $$088$us = $26;$$089$us = $28;$$090$us = $29;
     }
     }
     $59 = $$088$us << 16;
     $60 = $$089$us << 8;
     $61 = $60 | $$090$us;
     $62 = $61 | $59;
     HEAP32[$$08695$us>>2] = $62;
     $63 = ((($$08794$us)) + 4|0);
     $64 = ((($$08695$us)) + 4|0);
     $65 = (($66) + -1)|0;
     $67 = ($66|0)==(0);
     if ($67) {
      break L6;
     } else {
      $$08695$us = $64;$$08794$us = $63;$66 = $65;
     }
    }
   }
  } while(0);
  $112 = HEAP32[$9>>2]|0;
  $113 = (($114) + ($112)|0);
  $115 = HEAP32[$10>>2]|0;
  $116 = (($117) + ($115)|0);
  $118 = HEAP32[$3>>2]|0;
  $119 = (($118) + -1)|0;
  HEAP32[$3>>2] = $119;
  $120 = ($118|0)==(0);
  if ($120) {
   break;
  } else {
   $114 = $113;$117 = $116;$121 = $116;$122 = $113;
  }
 }
 HEAP32[$0>>2] = $113;
 HEAP32[$7>>2] = $116;
 return;
}
function _SDL_Blit_BGRA8888_BGR888_Blend_Scale($0) {
 $0 = $0|0;
 var $$ = 0, $$0113143 = 0, $$0114142 = 0, $$0116 = 0, $$0117 = 0, $$0118141 = 0, $$0120147 = 0, $$0122140 = 0, $$0125146 = 0, $$0127 = 0, $$0128 = 0, $$0129 = 0, $$0130 = 0, $$1 = 0, $$1115 = 0, $$1121$lcssa = 0, $$1126$lcssa = 0, $$2 = 0, $$2124 = 0, $$3 = 0;
 var $$in = 0, $$pre = 0, $$pre154 = 0, $$pre155 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $trunc = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 << 16;
 $6 = ((($0)) + 28|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5|0) / ($7|0))&-1;
 $9 = ((($0)) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10 << 16;
 $12 = ((($0)) + 24|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($11|0) / ($13|0))&-1;
 $15 = (($7) + -1)|0;
 HEAP32[$6>>2] = $15;
 $16 = ($7|0)==(0);
 if ($16) {
  return;
 }
 $17 = ((($0)) + 20|0);
 $18 = ((($0)) + 32|0);
 $19 = $2 & 48;
 $20 = ($19|0)!=(0);
 $21 = $2 & 112;
 $trunc = $21&255;
 $22 = ((($0)) + 12|0);
 $$pre = HEAP32[$17>>2]|0;
 $$0120147 = 0;$$0125146 = 0;$102 = $15;$103 = $$pre;$30 = $13;$97 = $$pre;
 while(1) {
  $23 = ($$0120147|0)>(65535);
  if ($23) {
   $24 = (($$0120147) + -65536)|0;
   $25 = $24 >>> 16;
   $26 = $25 << 16;
   $27 = (($$0125146) + 1)|0;
   $28 = (($27) + ($25))|0;
   $29 = (($24) - ($26))|0;
   $$1121$lcssa = $29;$$1126$lcssa = $28;
  } else {
   $$1121$lcssa = $$0120147;$$1126$lcssa = $$0125146;
  }
  $31 = ($30|0)==(0);
  if ($31) {
   $99 = $102;
  } else {
   $$0113143 = $103;$$0114142 = 0;$$0118141 = 65536;$$0122140 = -1;$$in = $30;
   while(1) {
    $32 = (($$in) + -1)|0;
    $33 = ($$0118141|0)>(65535);
    if ($33) {
     $34 = (($$0118141) + -65536)|0;
     $35 = $34 >>> 16;
     $36 = $35 << 16;
     $37 = (($$0122140) + 1)|0;
     $38 = (($37) + ($35))|0;
     $39 = (($34) - ($36))|0;
     $40 = HEAP32[$0>>2]|0;
     $41 = HEAP32[$22>>2]|0;
     $42 = Math_imul($41, $$1126$lcssa)|0;
     $43 = (($40) + ($42)|0);
     $44 = $38 << 2;
     $45 = (($43) + ($44)|0);
     $$1115 = $45;$$2 = $39;$$2124 = $38;
    } else {
     $$1115 = $$0114142;$$2 = $$0118141;$$2124 = $$0122140;
    }
    $46 = HEAP32[$$1115>>2]|0;
    $47 = $46 >>> 24;
    $48 = $46 >>> 16;
    $49 = $48 & 255;
    $50 = $46 >>> 8;
    $51 = $50 & 255;
    $52 = $46 & 255;
    $53 = HEAP32[$$0113143>>2]|0;
    $54 = $53 >>> 16;
    $55 = $54 & 255;
    $56 = $53 >>> 8;
    $57 = $56 & 255;
    $58 = $53 & 255;
    $59 = ($52|0)!=(255);
    $or$cond = $20 & $59;
    if ($or$cond) {
     $60 = Math_imul($47, $52)|0;
     $61 = Math_imul($49, $52)|0;
     $62 = Math_imul($51, $52)|0;
     $63 = (($62>>>0) / 255)&-1;
     $64 = (($61>>>0) / 255)&-1;
     $65 = (($60>>>0) / 255)&-1;
     $$0116 = $63;$$0117 = $64;$$0130 = $65;
    } else {
     $$0116 = $51;$$0117 = $49;$$0130 = $47;
    }
    $trunc$clear = $trunc & 127;
    switch ($trunc$clear<<24>>24) {
    case 16:  {
     $66 = $52 ^ 255;
     $67 = Math_imul($66, $58)|0;
     $68 = (($67>>>0) / 255)&-1;
     $69 = (($$0116) + ($68))|0;
     $70 = Math_imul($57, $66)|0;
     $71 = (($70>>>0) / 255)&-1;
     $72 = (($$0117) + ($71))|0;
     $73 = Math_imul($55, $66)|0;
     $74 = (($73>>>0) / 255)&-1;
     $75 = (($$0130) + ($74))|0;
     $$0127 = $75;$$0128 = $72;$$0129 = $69;
     break;
    }
    case 32:  {
     $76 = (($$0116) + ($58))|0;
     $77 = ($76>>>0)<(255);
     $$ = $77 ? $76 : 255;
     $78 = (($$0117) + ($57))|0;
     $79 = ($78>>>0)<(255);
     $$3 = $79 ? $78 : 255;
     $80 = (($$0130) + ($55))|0;
     $81 = ($80>>>0)<(255);
     $$1 = $81 ? $80 : 255;
     $$0127 = $$1;$$0128 = $$3;$$0129 = $$;
     break;
    }
    case 64:  {
     $82 = Math_imul($$0116, $58)|0;
     $83 = (($82>>>0) / 255)&-1;
     $84 = Math_imul($$0117, $57)|0;
     $85 = (($84>>>0) / 255)&-1;
     $86 = Math_imul($$0130, $55)|0;
     $87 = (($86>>>0) / 255)&-1;
     $$0127 = $87;$$0128 = $85;$$0129 = $83;
     break;
    }
    default: {
     $$0127 = $55;$$0128 = $57;$$0129 = $58;
    }
    }
    $88 = $$0127 << 16;
    $89 = $$0128 << 8;
    $90 = $89 | $$0129;
    $91 = $90 | $88;
    HEAP32[$$0113143>>2] = $91;
    $92 = (($$2) + ($14))|0;
    $93 = ((($$0113143)) + 4|0);
    $94 = ($32|0)==(0);
    if ($94) {
     break;
    } else {
     $$0113143 = $93;$$0114142 = $$1115;$$0118141 = $92;$$0122140 = $$2124;$$in = $32;
    }
   }
   $$pre155 = HEAP32[$6>>2]|0;
   $99 = $$pre155;
  }
  $95 = HEAP32[$18>>2]|0;
  $96 = (($97) + ($95)|0);
  $98 = (($99) + -1)|0;
  HEAP32[$6>>2] = $98;
  $100 = ($99|0)==(0);
  if ($100) {
   break;
  }
  $101 = (($$1121$lcssa) + ($8))|0;
  $$pre154 = HEAP32[$12>>2]|0;
  $$0120147 = $101;$$0125146 = $$1126$lcssa;$102 = $98;$103 = $96;$30 = $$pre154;$97 = $96;
 }
 HEAP32[$17>>2] = $96;
 return;
}
function _SDL_Blit_BGRA8888_BGR888_Modulate($0) {
 $0 = $0|0;
 var $$05157 = 0, $$05157$us$us = 0, $$05256 = 0, $$05256$us$us = 0, $$in = 0, $$in68 = 0, $$lcssa77$sink = 0, $$lcssa78$sink = 0, $$pre71 = 0, $$pre72 = 0, $$pre73 = 0, $$pre74 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = ((($0)) + 61|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = ((($0)) + 62|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = ((($0)) + 28|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($13) + -1)|0;
 HEAP32[$12>>2] = $14;
 $15 = ($13|0)==(0);
 if ($15) {
  return;
 }
 $16 = ((($0)) + 20|0);
 $17 = ((($0)) + 24|0);
 $18 = ((($0)) + 12|0);
 $19 = ((($0)) + 32|0);
 $20 = $2 & 1;
 $21 = ($20|0)==(0);
 $$pre72 = HEAP32[$0>>2]|0;
 $$pre73 = HEAP32[$16>>2]|0;
 if ($21) {
  $26 = $$pre72;$29 = $$pre73;$74 = $14;$75 = $$pre73;$76 = $$pre72;
  while(1) {
   $22 = HEAP32[$17>>2]|0;
   $23 = ($22|0)==(0);
   if ($23) {
    $31 = $74;
   } else {
    $$05157$us$us = $75;$$05256$us$us = $76;$$in68 = $22;
    while(1) {
     $33 = (($$in68) + -1)|0;
     $34 = HEAP32[$$05256$us$us>>2]|0;
     $35 = $34 >>> 24;
     $36 = $34 >>> 8;
     $37 = $35 << 16;
     $38 = $36 & 65535;
     $39 = $38 | $37;
     HEAP32[$$05157$us$us>>2] = $39;
     $40 = ((($$05256$us$us)) + 4|0);
     $41 = ((($$05157$us$us)) + 4|0);
     $42 = ($33|0)==(0);
     if ($42) {
      break;
     } else {
      $$05157$us$us = $41;$$05256$us$us = $40;$$in68 = $33;
     }
    }
    $$pre74 = HEAP32[$12>>2]|0;
    $31 = $$pre74;
   }
   $24 = HEAP32[$18>>2]|0;
   $25 = (($26) + ($24)|0);
   $27 = HEAP32[$19>>2]|0;
   $28 = (($29) + ($27)|0);
   $30 = (($31) + -1)|0;
   HEAP32[$12>>2] = $30;
   $32 = ($31|0)==(0);
   if ($32) {
    $$lcssa77$sink = $25;$$lcssa78$sink = $28;
    break;
   } else {
    $26 = $25;$29 = $28;$74 = $30;$75 = $28;$76 = $25;
   }
  }
 } else {
  $67 = $$pre72;$70 = $$pre73;$77 = $14;$78 = $$pre73;$79 = $$pre72;
  while(1) {
   $43 = HEAP32[$17>>2]|0;
   $44 = ($43|0)==(0);
   if ($44) {
    $72 = $77;
   } else {
    $$05157 = $78;$$05256 = $79;$$in = $43;
    while(1) {
     $45 = (($$in) + -1)|0;
     $46 = HEAP32[$$05256>>2]|0;
     $47 = $46 >>> 24;
     $48 = $46 >>> 16;
     $49 = $48 & 255;
     $50 = $46 >>> 8;
     $51 = $50 & 255;
     $52 = Math_imul($47, $11)|0;
     $53 = Math_imul($49, $8)|0;
     $54 = Math_imul($51, $5)|0;
     $55 = (($54>>>0) / 255)&-1;
     $56 = (($53>>>0) / 255)&-1;
     $57 = (($52>>>0) / 255)&-1;
     $58 = $57 << 16;
     $59 = $56 << 8;
     $60 = $59 | $55;
     $61 = $60 | $58;
     HEAP32[$$05157>>2] = $61;
     $62 = ((($$05256)) + 4|0);
     $63 = ((($$05157)) + 4|0);
     $64 = ($45|0)==(0);
     if ($64) {
      break;
     } else {
      $$05157 = $63;$$05256 = $62;$$in = $45;
     }
    }
    $$pre71 = HEAP32[$12>>2]|0;
    $72 = $$pre71;
   }
   $65 = HEAP32[$18>>2]|0;
   $66 = (($67) + ($65)|0);
   $68 = HEAP32[$19>>2]|0;
   $69 = (($70) + ($68)|0);
   $71 = (($72) + -1)|0;
   HEAP32[$12>>2] = $71;
   $73 = ($72|0)==(0);
   if ($73) {
    $$lcssa77$sink = $66;$$lcssa78$sink = $69;
    break;
   } else {
    $67 = $66;$70 = $69;$77 = $71;$78 = $69;$79 = $66;
   }
  }
 }
 HEAP32[$0>>2] = $$lcssa77$sink;
 HEAP32[$16>>2] = $$lcssa78$sink;
 return;
}
function _SDL_Blit_BGRA8888_BGR888_Modulate_Scale($0) {
 $0 = $0|0;
 var $$078104 = 0, $$078104$us = 0, $$079103 = 0, $$079103$us = 0, $$081102 = 0, $$081102$us = 0, $$083108 = 0, $$085101 = 0, $$085101$us = 0, $$088107 = 0, $$1 = 0, $$1$us = 0, $$184$lcssa = 0, $$189$lcssa = 0, $$2 = 0, $$2$us = 0, $$287 = 0, $$287$us = 0, $$pre = 0, $$pre118 = 0;
 var $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = ((($0)) + 61|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = ((($0)) + 62|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = ((($0)) + 8|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13 << 16;
 $15 = ((($0)) + 28|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($14|0) / ($16|0))&-1;
 $18 = ((($0)) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = $19 << 16;
 $21 = ((($0)) + 24|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($20|0) / ($22|0))&-1;
 $24 = (($16) + -1)|0;
 HEAP32[$15>>2] = $24;
 $25 = ($16|0)==(0);
 if ($25) {
  return;
 }
 $26 = ((($0)) + 20|0);
 $27 = ((($0)) + 32|0);
 $28 = $2 & 1;
 $29 = ($28|0)==(0);
 $30 = ((($0)) + 12|0);
 $$pre = HEAP32[$26>>2]|0;
 $$083108 = 0;$$088107 = 0;$103 = $$pre;$108 = $$pre;$39 = $22;
 while(1) {
  $31 = ($$083108|0)>(65535);
  if ($31) {
   $32 = (($$083108) + -65536)|0;
   $33 = $32 >>> 16;
   $34 = $33 << 16;
   $35 = (($$088107) + 1)|0;
   $36 = (($35) + ($33))|0;
   $37 = (($32) - ($34))|0;
   $$184$lcssa = $37;$$189$lcssa = $36;
  } else {
   $$184$lcssa = $$083108;$$189$lcssa = $$088107;
  }
  $38 = (($39) + -1)|0;
  $40 = ($39|0)==(0);
  if (!($40)) {
   if ($29) {
    $$078104$us = $108;$$079103$us = 0;$$081102$us = 65536;$$085101$us = -1;$65 = $38;
    while(1) {
     $41 = ($$081102$us|0)>(65535);
     if ($41) {
      $42 = (($$081102$us) + -65536)|0;
      $43 = $42 >>> 16;
      $44 = $43 << 16;
      $45 = (($$085101$us) + 1)|0;
      $46 = (($45) + ($43))|0;
      $47 = (($42) - ($44))|0;
      $48 = HEAP32[$0>>2]|0;
      $49 = HEAP32[$30>>2]|0;
      $50 = Math_imul($49, $$189$lcssa)|0;
      $51 = (($48) + ($50)|0);
      $52 = $46 << 2;
      $53 = (($51) + ($52)|0);
      $$1$us = $53;$$2$us = $47;$$287$us = $46;
     } else {
      $$1$us = $$079103$us;$$2$us = $$081102$us;$$287$us = $$085101$us;
     }
     $54 = HEAP32[$$1$us>>2]|0;
     $55 = $54 >>> 24;
     $56 = $54 >>> 8;
     $57 = $56 & 255;
     $58 = $55 << 16;
     $59 = $56 & 65280;
     $60 = $58 | $59;
     $61 = $60 | $57;
     HEAP32[$$078104$us>>2] = $61;
     $62 = (($$2$us) + ($23))|0;
     $63 = ((($$078104$us)) + 4|0);
     $64 = (($65) + -1)|0;
     $66 = ($65|0)==(0);
     if ($66) {
      break;
     } else {
      $$078104$us = $63;$$079103$us = $$1$us;$$081102$us = $62;$$085101$us = $$287$us;$65 = $64;
     }
    }
   } else {
    $$078104 = $108;$$079103 = 0;$$081102 = 65536;$$085101 = -1;$99 = $38;
    while(1) {
     $67 = ($$081102|0)>(65535);
     if ($67) {
      $68 = (($$081102) + -65536)|0;
      $69 = $68 >>> 16;
      $70 = $69 << 16;
      $71 = (($$085101) + 1)|0;
      $72 = (($71) + ($69))|0;
      $73 = (($68) - ($70))|0;
      $74 = HEAP32[$0>>2]|0;
      $75 = HEAP32[$30>>2]|0;
      $76 = Math_imul($75, $$189$lcssa)|0;
      $77 = (($74) + ($76)|0);
      $78 = $72 << 2;
      $79 = (($77) + ($78)|0);
      $$1 = $79;$$2 = $73;$$287 = $72;
     } else {
      $$1 = $$079103;$$2 = $$081102;$$287 = $$085101;
     }
     $80 = HEAP32[$$1>>2]|0;
     $81 = $80 >>> 24;
     $82 = $80 >>> 16;
     $83 = $82 & 255;
     $84 = $80 >>> 8;
     $85 = $84 & 255;
     $86 = Math_imul($81, $11)|0;
     $87 = Math_imul($83, $8)|0;
     $88 = Math_imul($85, $5)|0;
     $89 = (($88>>>0) / 255)&-1;
     $90 = (($87>>>0) / 255)&-1;
     $91 = (($86>>>0) / 255)&-1;
     $92 = $91 << 16;
     $93 = $90 << 8;
     $94 = $92 | $93;
     $95 = $94 | $89;
     HEAP32[$$078104>>2] = $95;
     $96 = (($$2) + ($23))|0;
     $97 = ((($$078104)) + 4|0);
     $98 = (($99) + -1)|0;
     $100 = ($99|0)==(0);
     if ($100) {
      break;
     } else {
      $$078104 = $97;$$079103 = $$1;$$081102 = $96;$$085101 = $$287;$99 = $98;
     }
    }
   }
  }
  $101 = HEAP32[$27>>2]|0;
  $102 = (($103) + ($101)|0);
  $104 = HEAP32[$15>>2]|0;
  $105 = (($104) + -1)|0;
  HEAP32[$15>>2] = $105;
  $106 = ($104|0)==(0);
  if ($106) {
   break;
  }
  $107 = (($$184$lcssa) + ($17))|0;
  $$pre118 = HEAP32[$21>>2]|0;
  $$083108 = $107;$$088107 = $$189$lcssa;$103 = $102;$108 = $102;$39 = $$pre118;
 }
 HEAP32[$26>>2] = $102;
 return;
}
function _SDL_Blit_BGRA8888_BGR888_Modulate_Blend($0) {
 $0 = $0|0;
 var $$ = 0, $$0108121 = 0, $$0109120 = 0, $$0110 = 0, $$0111 = 0, $$0112 = 0, $$0113 = 0, $$0114 = 0, $$0116 = 0, $$0118 = 0, $$1 = 0, $$1115 = 0, $$1117 = 0, $$1119 = 0, $$3 = 0, $$in = 0, $$pre = 0, $$pre125 = 0, $$pre126 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $or$cond = 0, $trunc = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = ((($0)) + 61|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = ((($0)) + 62|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = ((($0)) + 63|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = $13&255;
 $15 = ((($0)) + 28|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + -1)|0;
 HEAP32[$15>>2] = $17;
 $18 = ($16|0)==(0);
 if ($18) {
  return;
 }
 $19 = ((($0)) + 20|0);
 $20 = ((($0)) + 24|0);
 $21 = ((($0)) + 12|0);
 $22 = ((($0)) + 32|0);
 $23 = $2 & 1;
 $24 = ($23|0)==(0);
 $25 = $2 & 2;
 $26 = ($25|0)==(0);
 $27 = $2 & 48;
 $28 = ($27|0)!=(0);
 $29 = $2 & 112;
 $trunc = $29&255;
 $$pre = HEAP32[$0>>2]|0;
 $$pre125 = HEAP32[$19>>2]|0;
 $100 = $$pre125;$101 = $$pre;$92 = $$pre;$95 = $$pre125;$99 = $17;
 while(1) {
  $30 = HEAP32[$20>>2]|0;
  $31 = ($30|0)==(0);
  if ($31) {
   $97 = $99;
  } else {
   $$0108121 = $100;$$0109120 = $101;$$in = $30;
   while(1) {
    $32 = (($$in) + -1)|0;
    $33 = HEAP32[$$0109120>>2]|0;
    $34 = $33 >>> 24;
    $35 = $33 >>> 16;
    $36 = $35 & 255;
    $37 = $33 >>> 8;
    $38 = $37 & 255;
    $39 = $33 & 255;
    $40 = HEAP32[$$0108121>>2]|0;
    $41 = $40 >>> 16;
    $42 = $41 & 255;
    $43 = $40 >>> 8;
    $44 = $43 & 255;
    $45 = $40 & 255;
    if ($24) {
     $$0114 = $34;$$0116 = $36;$$0118 = $38;
    } else {
     $46 = Math_imul($34, $11)|0;
     $47 = Math_imul($36, $8)|0;
     $48 = Math_imul($38, $5)|0;
     $49 = (($48>>>0) / 255)&-1;
     $50 = (($47>>>0) / 255)&-1;
     $51 = (($46>>>0) / 255)&-1;
     $$0114 = $51;$$0116 = $50;$$0118 = $49;
    }
    $52 = Math_imul($39, $14)|0;
    $53 = (($52>>>0) / 255)&-1;
    $$0113 = $26 ? $39 : $53;
    $54 = ($$0113>>>0)<(255);
    $or$cond = $28 & $54;
    if ($or$cond) {
     $55 = Math_imul($$0114, $$0113)|0;
     $56 = Math_imul($$0116, $$0113)|0;
     $57 = Math_imul($$0118, $$0113)|0;
     $58 = (($57>>>0) / 255)&-1;
     $59 = (($56>>>0) / 255)&-1;
     $60 = (($55>>>0) / 255)&-1;
     $$1115 = $60;$$1117 = $59;$$1119 = $58;
    } else {
     $$1115 = $$0114;$$1117 = $$0116;$$1119 = $$0118;
    }
    $trunc$clear = $trunc & 127;
    switch ($trunc$clear<<24>>24) {
    case 16:  {
     $61 = (255 - ($$0113))|0;
     $62 = Math_imul($61, $45)|0;
     $63 = (($62>>>0) / 255)&-1;
     $64 = (($$1119) + ($63))|0;
     $65 = Math_imul($61, $44)|0;
     $66 = (($65>>>0) / 255)&-1;
     $67 = (($$1117) + ($66))|0;
     $68 = Math_imul($61, $42)|0;
     $69 = (($68>>>0) / 255)&-1;
     $70 = (($$1115) + ($69))|0;
     $$0110 = $70;$$0111 = $67;$$0112 = $64;
     break;
    }
    case 32:  {
     $71 = (($$1119) + ($45))|0;
     $72 = ($71>>>0)<(255);
     $$ = $72 ? $71 : 255;
     $73 = (($$1117) + ($44))|0;
     $74 = ($73>>>0)<(255);
     $$3 = $74 ? $73 : 255;
     $75 = (($$1115) + ($42))|0;
     $76 = ($75>>>0)<(255);
     $$1 = $76 ? $75 : 255;
     $$0110 = $$1;$$0111 = $$3;$$0112 = $$;
     break;
    }
    case 64:  {
     $77 = Math_imul($$1119, $45)|0;
     $78 = (($77>>>0) / 255)&-1;
     $79 = Math_imul($$1117, $44)|0;
     $80 = (($79>>>0) / 255)&-1;
     $81 = Math_imul($$1115, $42)|0;
     $82 = (($81>>>0) / 255)&-1;
     $$0110 = $82;$$0111 = $80;$$0112 = $78;
     break;
    }
    default: {
     $$0110 = $42;$$0111 = $44;$$0112 = $45;
    }
    }
    $83 = $$0110 << 16;
    $84 = $$0111 << 8;
    $85 = $84 | $$0112;
    $86 = $85 | $83;
    HEAP32[$$0108121>>2] = $86;
    $87 = ((($$0109120)) + 4|0);
    $88 = ((($$0108121)) + 4|0);
    $89 = ($32|0)==(0);
    if ($89) {
     break;
    } else {
     $$0108121 = $88;$$0109120 = $87;$$in = $32;
    }
   }
   $$pre126 = HEAP32[$15>>2]|0;
   $97 = $$pre126;
  }
  $90 = HEAP32[$21>>2]|0;
  $91 = (($92) + ($90)|0);
  $93 = HEAP32[$22>>2]|0;
  $94 = (($95) + ($93)|0);
  $96 = (($97) + -1)|0;
  HEAP32[$15>>2] = $96;
  $98 = ($97|0)==(0);
  if ($98) {
   break;
  } else {
   $100 = $94;$101 = $91;$92 = $91;$95 = $94;$99 = $96;
  }
 }
 HEAP32[$0>>2] = $91;
 HEAP32[$19>>2] = $94;
 return;
}
function _SDL_Blit_BGRA8888_BGR888_Modulate_Blend_Scale($0) {
 $0 = $0|0;
 var $$ = 0, $$0135169 = 0, $$0136168 = 0, $$0138 = 0, $$0140 = 0, $$0142167 = 0, $$0144173 = 0, $$0146166 = 0, $$0149172 = 0, $$0151 = 0, $$0152 = 0, $$0153 = 0, $$0154 = 0, $$0155 = 0, $$1 = 0, $$1137 = 0, $$1139 = 0, $$1141 = 0, $$1145$lcssa = 0, $$1150$lcssa = 0;
 var $$1156 = 0, $$2 = 0, $$2148 = 0, $$3 = 0, $$in = 0, $$pre = 0, $$pre180 = 0, $$pre181 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $trunc = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = ((($0)) + 61|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = ((($0)) + 62|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = ((($0)) + 63|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = $13&255;
 $15 = ((($0)) + 8|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $16 << 16;
 $18 = ((($0)) + 28|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($17|0) / ($19|0))&-1;
 $21 = ((($0)) + 4|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = $22 << 16;
 $24 = ((($0)) + 24|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($23|0) / ($25|0))&-1;
 $27 = (($19) + -1)|0;
 HEAP32[$18>>2] = $27;
 $28 = ($19|0)==(0);
 if ($28) {
  return;
 }
 $29 = ((($0)) + 20|0);
 $30 = ((($0)) + 32|0);
 $31 = $2 & 1;
 $32 = ($31|0)==(0);
 $33 = $2 & 2;
 $34 = ($33|0)==(0);
 $35 = $2 & 48;
 $36 = ($35|0)!=(0);
 $37 = $2 & 112;
 $trunc = $37&255;
 $38 = ((($0)) + 12|0);
 $$pre = HEAP32[$29>>2]|0;
 $$0144173 = 0;$$0149172 = 0;$121 = $$pre;$126 = $27;$127 = $$pre;$46 = $25;
 while(1) {
  $39 = ($$0144173|0)>(65535);
  if ($39) {
   $40 = (($$0144173) + -65536)|0;
   $41 = $40 >>> 16;
   $42 = $41 << 16;
   $43 = (($$0149172) + 1)|0;
   $44 = (($43) + ($41))|0;
   $45 = (($40) - ($42))|0;
   $$1145$lcssa = $45;$$1150$lcssa = $44;
  } else {
   $$1145$lcssa = $$0144173;$$1150$lcssa = $$0149172;
  }
  $47 = ($46|0)==(0);
  if ($47) {
   $123 = $126;
  } else {
   $$0135169 = $127;$$0136168 = 0;$$0142167 = 65536;$$0146166 = -1;$$in = $46;
   while(1) {
    $48 = (($$in) + -1)|0;
    $49 = ($$0142167|0)>(65535);
    if ($49) {
     $50 = (($$0142167) + -65536)|0;
     $51 = $50 >>> 16;
     $52 = $51 << 16;
     $53 = (($$0146166) + 1)|0;
     $54 = (($53) + ($51))|0;
     $55 = (($50) - ($52))|0;
     $56 = HEAP32[$0>>2]|0;
     $57 = HEAP32[$38>>2]|0;
     $58 = Math_imul($57, $$1150$lcssa)|0;
     $59 = (($56) + ($58)|0);
     $60 = $54 << 2;
     $61 = (($59) + ($60)|0);
     $$1137 = $61;$$2 = $55;$$2148 = $54;
    } else {
     $$1137 = $$0136168;$$2 = $$0142167;$$2148 = $$0146166;
    }
    $62 = HEAP32[$$1137>>2]|0;
    $63 = $62 >>> 24;
    $64 = $62 >>> 16;
    $65 = $64 & 255;
    $66 = $62 >>> 8;
    $67 = $66 & 255;
    $68 = $62 & 255;
    $69 = HEAP32[$$0135169>>2]|0;
    $70 = $69 >>> 16;
    $71 = $70 & 255;
    $72 = $69 >>> 8;
    $73 = $72 & 255;
    $74 = $69 & 255;
    if ($32) {
     $$0138 = $67;$$0140 = $65;$$0155 = $63;
    } else {
     $75 = Math_imul($63, $11)|0;
     $76 = Math_imul($65, $8)|0;
     $77 = Math_imul($67, $5)|0;
     $78 = (($77>>>0) / 255)&-1;
     $79 = (($76>>>0) / 255)&-1;
     $80 = (($75>>>0) / 255)&-1;
     $$0138 = $78;$$0140 = $79;$$0155 = $80;
    }
    $81 = Math_imul($68, $14)|0;
    $82 = (($81>>>0) / 255)&-1;
    $$0154 = $34 ? $68 : $82;
    $83 = ($$0154>>>0)<(255);
    $or$cond = $36 & $83;
    if ($or$cond) {
     $84 = Math_imul($$0155, $$0154)|0;
     $85 = Math_imul($$0140, $$0154)|0;
     $86 = Math_imul($$0138, $$0154)|0;
     $87 = (($86>>>0) / 255)&-1;
     $88 = (($85>>>0) / 255)&-1;
     $89 = (($84>>>0) / 255)&-1;
     $$1139 = $87;$$1141 = $88;$$1156 = $89;
    } else {
     $$1139 = $$0138;$$1141 = $$0140;$$1156 = $$0155;
    }
    $trunc$clear = $trunc & 127;
    switch ($trunc$clear<<24>>24) {
    case 16:  {
     $90 = (255 - ($$0154))|0;
     $91 = Math_imul($90, $74)|0;
     $92 = (($91>>>0) / 255)&-1;
     $93 = (($$1139) + ($92))|0;
     $94 = Math_imul($90, $73)|0;
     $95 = (($94>>>0) / 255)&-1;
     $96 = (($$1141) + ($95))|0;
     $97 = Math_imul($90, $71)|0;
     $98 = (($97>>>0) / 255)&-1;
     $99 = (($$1156) + ($98))|0;
     $$0151 = $99;$$0152 = $96;$$0153 = $93;
     break;
    }
    case 32:  {
     $100 = (($$1139) + ($74))|0;
     $101 = ($100>>>0)<(255);
     $$ = $101 ? $100 : 255;
     $102 = (($$1141) + ($73))|0;
     $103 = ($102>>>0)<(255);
     $$3 = $103 ? $102 : 255;
     $104 = (($$1156) + ($71))|0;
     $105 = ($104>>>0)<(255);
     $$1 = $105 ? $104 : 255;
     $$0151 = $$1;$$0152 = $$3;$$0153 = $$;
     break;
    }
    case 64:  {
     $106 = Math_imul($$1139, $74)|0;
     $107 = (($106>>>0) / 255)&-1;
     $108 = Math_imul($$1141, $73)|0;
     $109 = (($108>>>0) / 255)&-1;
     $110 = Math_imul($$1156, $71)|0;
     $111 = (($110>>>0) / 255)&-1;
     $$0151 = $111;$$0152 = $109;$$0153 = $107;
     break;
    }
    default: {
     $$0151 = $71;$$0152 = $73;$$0153 = $74;
    }
    }
    $112 = $$0151 << 16;
    $113 = $$0152 << 8;
    $114 = $113 | $$0153;
    $115 = $114 | $112;
    HEAP32[$$0135169>>2] = $115;
    $116 = (($$2) + ($26))|0;
    $117 = ((($$0135169)) + 4|0);
    $118 = ($48|0)==(0);
    if ($118) {
     break;
    } else {
     $$0135169 = $117;$$0136168 = $$1137;$$0142167 = $116;$$0146166 = $$2148;$$in = $48;
    }
   }
   $$pre181 = HEAP32[$18>>2]|0;
   $123 = $$pre181;
  }
  $119 = HEAP32[$30>>2]|0;
  $120 = (($121) + ($119)|0);
  $122 = (($123) + -1)|0;
  HEAP32[$18>>2] = $122;
  $124 = ($123|0)==(0);
  if ($124) {
   break;
  }
  $125 = (($$1145$lcssa) + ($20))|0;
  $$pre180 = HEAP32[$24>>2]|0;
  $$0144173 = $125;$$0149172 = $$1150$lcssa;$121 = $120;$126 = $122;$127 = $120;$46 = $$pre180;
 }
 HEAP32[$29>>2] = $120;
 return;
}
function _SDL_Blit_BGRA8888_ARGB8888_Scale($0) {
 $0 = $0|0;
 var $$06386 = 0, $$06485 = 0, $$06590 = 0, $$06784 = 0, $$06983 = 0, $$07289 = 0, $$1 = 0, $$166$lcssa = 0, $$173$lcssa = 0, $$2 = 0, $$271 = 0, $$in = 0, $$pre = 0, $$pre97 = 0, $$pre98 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 << 16;
 $4 = ((($0)) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3|0) / ($5|0))&-1;
 $7 = ((($0)) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 << 16;
 $10 = ((($0)) + 24|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($9|0) / ($11|0))&-1;
 $13 = (($5) + -1)|0;
 HEAP32[$4>>2] = $13;
 $14 = ($5|0)==(0);
 if ($14) {
  return;
 }
 $15 = ((($0)) + 20|0);
 $16 = ((($0)) + 32|0);
 $17 = ((($0)) + 12|0);
 $$pre = HEAP32[$15>>2]|0;
 $$06590 = 0;$$07289 = 0;$25 = $11;$48 = $$pre;$53 = $13;$54 = $$pre;
 while(1) {
  $18 = ($$07289|0)>(65535);
  if ($18) {
   $19 = (($$07289) + -65536)|0;
   $20 = $19 >>> 16;
   $21 = $20 << 16;
   $22 = (($$06590) + 1)|0;
   $23 = (($22) + ($20))|0;
   $24 = (($19) - ($21))|0;
   $$166$lcssa = $23;$$173$lcssa = $24;
  } else {
   $$166$lcssa = $$06590;$$173$lcssa = $$07289;
  }
  $26 = ($25|0)==(0);
  if ($26) {
   $50 = $53;
  } else {
   $$06386 = $54;$$06485 = 0;$$06784 = -1;$$06983 = 65536;$$in = $25;
   while(1) {
    $27 = (($$in) + -1)|0;
    $28 = ($$06983|0)>(65535);
    if ($28) {
     $29 = (($$06983) + -65536)|0;
     $30 = $29 >>> 16;
     $31 = $30 << 16;
     $32 = (($$06784) + 1)|0;
     $33 = (($32) + ($30))|0;
     $34 = (($29) - ($31))|0;
     $35 = HEAP32[$0>>2]|0;
     $36 = HEAP32[$17>>2]|0;
     $37 = Math_imul($36, $$166$lcssa)|0;
     $38 = (($35) + ($37)|0);
     $39 = $33 << 2;
     $40 = (($38) + ($39)|0);
     $$1 = $40;$$2 = $33;$$271 = $34;
    } else {
     $$1 = $$06485;$$2 = $$06784;$$271 = $$06983;
    }
    $41 = HEAP32[$$1>>2]|0;
    $42 = (_llvm_bswap_i32(($41|0))|0);
    HEAP32[$$06386>>2] = $42;
    $43 = (($$271) + ($12))|0;
    $44 = ((($$06386)) + 4|0);
    $45 = ($27|0)==(0);
    if ($45) {
     break;
    } else {
     $$06386 = $44;$$06485 = $$1;$$06784 = $$2;$$06983 = $43;$$in = $27;
    }
   }
   $$pre98 = HEAP32[$4>>2]|0;
   $50 = $$pre98;
  }
  $46 = HEAP32[$16>>2]|0;
  $47 = (($48) + ($46)|0);
  $49 = (($50) + -1)|0;
  HEAP32[$4>>2] = $49;
  $51 = ($50|0)==(0);
  if ($51) {
   break;
  }
  $52 = (($$173$lcssa) + ($6))|0;
  $$pre97 = HEAP32[$10>>2]|0;
  $$06590 = $$166$lcssa;$$07289 = $52;$25 = $$pre97;$48 = $47;$53 = $49;$54 = $47;
 }
 HEAP32[$15>>2] = $47;
 return;
}
function _SDL_Blit_BGRA8888_ARGB8888_Blend($0) {
 $0 = $0|0;
 var $$ = 0, $$$us = 0, $$0100$us = 0, $$0101$us = 0, $$093103 = 0, $$093103$us = 0, $$094102 = 0, $$094102$us = 0, $$095 = 0, $$095$us = 0, $$096 = 0, $$096$us = 0, $$097 = 0, $$097$us = 0, $$098 = 0, $$098$us = 0, $$099$us = 0, $$1 = 0, $$1$us = 0, $$3 = 0;
 var $$3$us = 0, $$pre = 0, $$pre108 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $trunc = 0, $trunc$clear = 0, $trunc$clear1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + -1)|0;
 HEAP32[$3>>2] = $5;
 $6 = ($4|0)==(0);
 if ($6) {
  return;
 }
 $7 = ((($0)) + 20|0);
 $8 = ((($0)) + 24|0);
 $9 = ((($0)) + 12|0);
 $10 = ((($0)) + 32|0);
 $11 = $2 & 48;
 $12 = ($11|0)==(0);
 $13 = $2 & 112;
 $trunc = $13&255;
 $$pre = HEAP32[$0>>2]|0;
 $$pre108 = HEAP32[$7>>2]|0;
 $126 = $$pre;$129 = $$pre108;$133 = $$pre108;$134 = $$pre;
 while(1) {
  $14 = HEAP32[$8>>2]|0;
  $15 = (($14) + -1)|0;
  $16 = ($14|0)==(0);
  L6: do {
   if (!($16)) {
    if ($12) {
     $$093103 = $133;$$094102 = $134;$122 = $15;
     while(1) {
      $74 = HEAP32[$$094102>>2]|0;
      $75 = $74 >>> 24;
      $76 = $74 >>> 16;
      $77 = $76 & 255;
      $78 = $74 >>> 8;
      $79 = $78 & 255;
      $80 = $74 & 255;
      $81 = HEAP32[$$093103>>2]|0;
      $82 = $81 >>> 16;
      $83 = $82 & 255;
      $84 = $81 >>> 8;
      $85 = $84 & 255;
      $86 = $81 & 255;
      $87 = $81 >>> 24;
      $trunc$clear1 = $trunc & 127;
      switch ($trunc$clear1<<24>>24) {
      case 16:  {
       $88 = $80 ^ 255;
       $89 = Math_imul($83, $88)|0;
       $90 = (($89>>>0) / 255)&-1;
       $91 = (($79) + ($90))|0;
       $92 = Math_imul($85, $88)|0;
       $93 = (($92>>>0) / 255)&-1;
       $94 = (($77) + ($93))|0;
       $95 = Math_imul($88, $86)|0;
       $96 = (($95>>>0) / 255)&-1;
       $97 = (($75) + ($96))|0;
       $98 = Math_imul($88, $87)|0;
       $99 = (($98>>>0) / 255)&-1;
       $100 = (($99) + ($80))|0;
       $$095 = $100;$$096 = $97;$$097 = $94;$$098 = $91;
       break;
      }
      case 32:  {
       $101 = (($79) + ($83))|0;
       $102 = ($101>>>0)<(255);
       $$ = $102 ? $101 : 255;
       $103 = (($77) + ($85))|0;
       $104 = ($103>>>0)<(255);
       $$3 = $104 ? $103 : 255;
       $105 = (($75) + ($86))|0;
       $106 = ($105>>>0)<(255);
       $$1 = $106 ? $105 : 255;
       $$095 = $87;$$096 = $$1;$$097 = $$3;$$098 = $$;
       break;
      }
      case 64:  {
       $107 = Math_imul($79, $83)|0;
       $108 = (($107>>>0) / 255)&-1;
       $109 = Math_imul($77, $85)|0;
       $110 = (($109>>>0) / 255)&-1;
       $111 = Math_imul($75, $86)|0;
       $112 = (($111>>>0) / 255)&-1;
       $$095 = $87;$$096 = $112;$$097 = $110;$$098 = $108;
       break;
      }
      default: {
       $$095 = $87;$$096 = $86;$$097 = $85;$$098 = $83;
      }
      }
      $113 = $$095 << 24;
      $114 = $$098 << 16;
      $115 = $$097 << 8;
      $116 = $115 | $114;
      $117 = $116 | $$096;
      $118 = $117 | $113;
      HEAP32[$$093103>>2] = $118;
      $119 = ((($$094102)) + 4|0);
      $120 = ((($$093103)) + 4|0);
      $121 = (($122) + -1)|0;
      $123 = ($122|0)==(0);
      if ($123) {
       break L6;
      } else {
       $$093103 = $120;$$094102 = $119;$122 = $121;
      }
     }
    } else {
     $$093103$us = $133;$$094102$us = $134;$72 = $15;
    }
    while(1) {
     $17 = HEAP32[$$094102$us>>2]|0;
     $18 = $17 >>> 24;
     $19 = $17 >>> 16;
     $20 = $19 & 255;
     $21 = $17 >>> 8;
     $22 = $21 & 255;
     $23 = $17 & 255;
     $24 = HEAP32[$$093103$us>>2]|0;
     $25 = $24 >>> 16;
     $26 = $25 & 255;
     $27 = $24 >>> 8;
     $28 = $27 & 255;
     $29 = $24 & 255;
     $30 = $24 >>> 24;
     $31 = ($23|0)==(255);
     if ($31) {
      $$0100$us = $18;$$0101$us = $20;$$099$us = $22;
     } else {
      $32 = Math_imul($18, $23)|0;
      $33 = Math_imul($20, $23)|0;
      $34 = Math_imul($22, $23)|0;
      $35 = (($34>>>0) / 255)&-1;
      $36 = (($33>>>0) / 255)&-1;
      $37 = (($32>>>0) / 255)&-1;
      $$0100$us = $37;$$0101$us = $36;$$099$us = $35;
     }
     $trunc$clear = $trunc & 127;
     switch ($trunc$clear<<24>>24) {
     case 16:  {
      $50 = $23 ^ 255;
      $51 = Math_imul($26, $50)|0;
      $52 = (($51>>>0) / 255)&-1;
      $53 = (($$099$us) + ($52))|0;
      $54 = Math_imul($28, $50)|0;
      $55 = (($54>>>0) / 255)&-1;
      $56 = (($$0101$us) + ($55))|0;
      $57 = Math_imul($50, $29)|0;
      $58 = (($57>>>0) / 255)&-1;
      $59 = (($$0100$us) + ($58))|0;
      $60 = Math_imul($50, $30)|0;
      $61 = (($60>>>0) / 255)&-1;
      $62 = (($61) + ($23))|0;
      $$095$us = $62;$$096$us = $59;$$097$us = $56;$$098$us = $53;
      break;
     }
     case 32:  {
      $44 = (($$099$us) + ($26))|0;
      $45 = ($44>>>0)<(255);
      $$$us = $45 ? $44 : 255;
      $46 = (($$0101$us) + ($28))|0;
      $47 = ($46>>>0)<(255);
      $$3$us = $47 ? $46 : 255;
      $48 = (($$0100$us) + ($29))|0;
      $49 = ($48>>>0)<(255);
      $$1$us = $49 ? $48 : 255;
      $$095$us = $30;$$096$us = $$1$us;$$097$us = $$3$us;$$098$us = $$$us;
      break;
     }
     case 64:  {
      $38 = Math_imul($$099$us, $26)|0;
      $39 = (($38>>>0) / 255)&-1;
      $40 = Math_imul($$0101$us, $28)|0;
      $41 = (($40>>>0) / 255)&-1;
      $42 = Math_imul($$0100$us, $29)|0;
      $43 = (($42>>>0) / 255)&-1;
      $$095$us = $30;$$096$us = $43;$$097$us = $41;$$098$us = $39;
      break;
     }
     default: {
      $$095$us = $30;$$096$us = $29;$$097$us = $28;$$098$us = $26;
     }
     }
     $63 = $$095$us << 24;
     $64 = $$098$us << 16;
     $65 = $$097$us << 8;
     $66 = $65 | $64;
     $67 = $66 | $$096$us;
     $68 = $67 | $63;
     HEAP32[$$093103$us>>2] = $68;
     $69 = ((($$094102$us)) + 4|0);
     $70 = ((($$093103$us)) + 4|0);
     $71 = (($72) + -1)|0;
     $73 = ($72|0)==(0);
     if ($73) {
      break L6;
     } else {
      $$093103$us = $70;$$094102$us = $69;$72 = $71;
     }
    }
   }
  } while(0);
  $124 = HEAP32[$9>>2]|0;
  $125 = (($126) + ($124)|0);
  $127 = HEAP32[$10>>2]|0;
  $128 = (($129) + ($127)|0);
  $130 = HEAP32[$3>>2]|0;
  $131 = (($130) + -1)|0;
  HEAP32[$3>>2] = $131;
  $132 = ($130|0)==(0);
  if ($132) {
   break;
  } else {
   $126 = $125;$129 = $128;$133 = $128;$134 = $125;
  }
 }
 HEAP32[$0>>2] = $125;
 HEAP32[$7>>2] = $128;
 return;
}
function _SDL_Blit_BGRA8888_ARGB8888_Blend_Scale($0) {
 $0 = $0|0;
 var $$ = 0, $$0120151 = 0, $$0121150 = 0, $$0123 = 0, $$0124 = 0, $$0125149 = 0, $$0127155 = 0, $$0129148 = 0, $$0132154 = 0, $$0134 = 0, $$0135 = 0, $$0136 = 0, $$0137 = 0, $$0138 = 0, $$1 = 0, $$1122 = 0, $$1128$lcssa = 0, $$1133$lcssa = 0, $$2 = 0, $$2131 = 0;
 var $$3 = 0, $$in = 0, $$pre = 0, $$pre162 = 0, $$pre163 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $trunc = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 << 16;
 $6 = ((($0)) + 28|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5|0) / ($7|0))&-1;
 $9 = ((($0)) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10 << 16;
 $12 = ((($0)) + 24|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($11|0) / ($13|0))&-1;
 $15 = (($7) + -1)|0;
 HEAP32[$6>>2] = $15;
 $16 = ($7|0)==(0);
 if ($16) {
  return;
 }
 $17 = ((($0)) + 20|0);
 $18 = ((($0)) + 32|0);
 $19 = $2 & 48;
 $20 = ($19|0)!=(0);
 $21 = $2 & 112;
 $trunc = $21&255;
 $22 = ((($0)) + 12|0);
 $$pre = HEAP32[$17>>2]|0;
 $$0127155 = 0;$$0132154 = 0;$103 = $$pre;$108 = $15;$109 = $$pre;$30 = $13;
 while(1) {
  $23 = ($$0127155|0)>(65535);
  if ($23) {
   $24 = (($$0127155) + -65536)|0;
   $25 = $24 >>> 16;
   $26 = $25 << 16;
   $27 = (($$0132154) + 1)|0;
   $28 = (($27) + ($25))|0;
   $29 = (($24) - ($26))|0;
   $$1128$lcssa = $29;$$1133$lcssa = $28;
  } else {
   $$1128$lcssa = $$0127155;$$1133$lcssa = $$0132154;
  }
  $31 = ($30|0)==(0);
  if ($31) {
   $105 = $108;
  } else {
   $$0120151 = $109;$$0121150 = 0;$$0125149 = 65536;$$0129148 = -1;$$in = $30;
   while(1) {
    $32 = (($$in) + -1)|0;
    $33 = ($$0125149|0)>(65535);
    if ($33) {
     $34 = (($$0125149) + -65536)|0;
     $35 = $34 >>> 16;
     $36 = $35 << 16;
     $37 = (($$0129148) + 1)|0;
     $38 = (($37) + ($35))|0;
     $39 = (($34) - ($36))|0;
     $40 = HEAP32[$0>>2]|0;
     $41 = HEAP32[$22>>2]|0;
     $42 = Math_imul($41, $$1133$lcssa)|0;
     $43 = (($40) + ($42)|0);
     $44 = $38 << 2;
     $45 = (($43) + ($44)|0);
     $$1122 = $45;$$2 = $39;$$2131 = $38;
    } else {
     $$1122 = $$0121150;$$2 = $$0125149;$$2131 = $$0129148;
    }
    $46 = HEAP32[$$1122>>2]|0;
    $47 = $46 >>> 24;
    $48 = $46 >>> 16;
    $49 = $48 & 255;
    $50 = $46 >>> 8;
    $51 = $50 & 255;
    $52 = $46 & 255;
    $53 = HEAP32[$$0120151>>2]|0;
    $54 = $53 >>> 16;
    $55 = $54 & 255;
    $56 = $53 >>> 8;
    $57 = $56 & 255;
    $58 = $53 & 255;
    $59 = $53 >>> 24;
    $60 = ($52|0)!=(255);
    $or$cond = $20 & $60;
    if ($or$cond) {
     $61 = Math_imul($47, $52)|0;
     $62 = Math_imul($49, $52)|0;
     $63 = Math_imul($51, $52)|0;
     $64 = (($63>>>0) / 255)&-1;
     $65 = (($62>>>0) / 255)&-1;
     $66 = (($61>>>0) / 255)&-1;
     $$0123 = $64;$$0124 = $65;$$0138 = $66;
    } else {
     $$0123 = $51;$$0124 = $49;$$0138 = $47;
    }
    $trunc$clear = $trunc & 127;
    switch ($trunc$clear<<24>>24) {
    case 16:  {
     $67 = $52 ^ 255;
     $68 = Math_imul($55, $67)|0;
     $69 = (($68>>>0) / 255)&-1;
     $70 = (($$0123) + ($69))|0;
     $71 = Math_imul($57, $67)|0;
     $72 = (($71>>>0) / 255)&-1;
     $73 = (($$0124) + ($72))|0;
     $74 = Math_imul($67, $58)|0;
     $75 = (($74>>>0) / 255)&-1;
     $76 = (($$0138) + ($75))|0;
     $77 = Math_imul($67, $59)|0;
     $78 = (($77>>>0) / 255)&-1;
     $79 = (($78) + ($52))|0;
     $$0134 = $79;$$0135 = $76;$$0136 = $73;$$0137 = $70;
     break;
    }
    case 32:  {
     $80 = (($$0123) + ($55))|0;
     $81 = ($80>>>0)<(255);
     $$ = $81 ? $80 : 255;
     $82 = (($$0124) + ($57))|0;
     $83 = ($82>>>0)<(255);
     $$3 = $83 ? $82 : 255;
     $84 = (($$0138) + ($58))|0;
     $85 = ($84>>>0)<(255);
     $$1 = $85 ? $84 : 255;
     $$0134 = $59;$$0135 = $$1;$$0136 = $$3;$$0137 = $$;
     break;
    }
    case 64:  {
     $86 = Math_imul($$0123, $55)|0;
     $87 = (($86>>>0) / 255)&-1;
     $88 = Math_imul($$0124, $57)|0;
     $89 = (($88>>>0) / 255)&-1;
     $90 = Math_imul($$0138, $58)|0;
     $91 = (($90>>>0) / 255)&-1;
     $$0134 = $59;$$0135 = $91;$$0136 = $89;$$0137 = $87;
     break;
    }
    default: {
     $$0134 = $59;$$0135 = $58;$$0136 = $57;$$0137 = $55;
    }
    }
    $92 = $$0134 << 24;
    $93 = $$0137 << 16;
    $94 = $$0136 << 8;
    $95 = $94 | $93;
    $96 = $95 | $$0135;
    $97 = $96 | $92;
    HEAP32[$$0120151>>2] = $97;
    $98 = (($$2) + ($14))|0;
    $99 = ((($$0120151)) + 4|0);
    $100 = ($32|0)==(0);
    if ($100) {
     break;
    } else {
     $$0120151 = $99;$$0121150 = $$1122;$$0125149 = $98;$$0129148 = $$2131;$$in = $32;
    }
   }
   $$pre163 = HEAP32[$6>>2]|0;
   $105 = $$pre163;
  }
  $101 = HEAP32[$18>>2]|0;
  $102 = (($103) + ($101)|0);
  $104 = (($105) + -1)|0;
  HEAP32[$6>>2] = $104;
  $106 = ($105|0)==(0);
  if ($106) {
   break;
  }
  $107 = (($$1128$lcssa) + ($8))|0;
  $$pre162 = HEAP32[$12>>2]|0;
  $$0127155 = $107;$$0132154 = $$1133$lcssa;$103 = $102;$108 = $104;$109 = $102;$30 = $$pre162;
 }
 HEAP32[$17>>2] = $102;
 return;
}
function _SDL_Blit_BGRA8888_ARGB8888_Modulate($0) {
 $0 = $0|0;
 var $$06168 = 0, $$06168$us = 0, $$06267 = 0, $$06267$us = 0, $$063 = 0, $$063$us = 0, $$pre = 0, $$pre73 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = ((($0)) + 61|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = ((($0)) + 62|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = ((($0)) + 63|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = $13&255;
 $15 = ((($0)) + 28|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + -1)|0;
 HEAP32[$15>>2] = $17;
 $18 = ($16|0)==(0);
 if ($18) {
  return;
 }
 $19 = ((($0)) + 20|0);
 $20 = ((($0)) + 24|0);
 $21 = ((($0)) + 12|0);
 $22 = ((($0)) + 32|0);
 $23 = $2 & 1;
 $24 = ($23|0)==(0);
 $25 = $2 & 2;
 $26 = ($25|0)==(0);
 $$pre = HEAP32[$0>>2]|0;
 $$pre73 = HEAP32[$19>>2]|0;
 $76 = $$pre;$79 = $$pre73;$83 = $$pre73;$84 = $$pre;
 while(1) {
  $27 = HEAP32[$20>>2]|0;
  $28 = (($27) + -1)|0;
  $29 = ($27|0)==(0);
  if (!($29)) {
   if ($24) {
    $$06168$us = $83;$$06267$us = $84;$46 = $28;
    while(1) {
     $30 = HEAP32[$$06267$us>>2]|0;
     $31 = $30 >>> 24;
     $32 = $30 & 255;
     $33 = Math_imul($32, $14)|0;
     $34 = (($33>>>0) / 255)&-1;
     $$063$us = $26 ? $30 : $34;
     $35 = $$063$us << 24;
     $36 = $30 << 8;
     $37 = $36 & 16711680;
     $38 = $37 | $35;
     $39 = $30 >>> 8;
     $40 = $39 & 65280;
     $41 = $38 | $40;
     $42 = $41 | $31;
     HEAP32[$$06168$us>>2] = $42;
     $43 = ((($$06267$us)) + 4|0);
     $44 = ((($$06168$us)) + 4|0);
     $45 = (($46) + -1)|0;
     $47 = ($46|0)==(0);
     if ($47) {
      break;
     } else {
      $$06168$us = $44;$$06267$us = $43;$46 = $45;
     }
    }
   } else {
    $$06168 = $83;$$06267 = $84;$72 = $28;
    while(1) {
     $48 = HEAP32[$$06267>>2]|0;
     $49 = $48 >>> 24;
     $50 = $48 >>> 16;
     $51 = $50 & 255;
     $52 = $48 >>> 8;
     $53 = $52 & 255;
     $54 = $48 & 255;
     $55 = Math_imul($49, $11)|0;
     $56 = Math_imul($51, $8)|0;
     $57 = Math_imul($53, $5)|0;
     $58 = (($57>>>0) / 255)&-1;
     $59 = (($56>>>0) / 255)&-1;
     $60 = (($55>>>0) / 255)&-1;
     $61 = Math_imul($54, $14)|0;
     $62 = (($61>>>0) / 255)&-1;
     $$063 = $26 ? $48 : $62;
     $63 = $$063 << 24;
     $64 = $58 << 16;
     $65 = $64 | $63;
     $66 = $59 << 8;
     $67 = $65 | $66;
     $68 = $67 | $60;
     HEAP32[$$06168>>2] = $68;
     $69 = ((($$06267)) + 4|0);
     $70 = ((($$06168)) + 4|0);
     $71 = (($72) + -1)|0;
     $73 = ($72|0)==(0);
     if ($73) {
      break;
     } else {
      $$06168 = $70;$$06267 = $69;$72 = $71;
     }
    }
   }
  }
  $74 = HEAP32[$21>>2]|0;
  $75 = (($76) + ($74)|0);
  $77 = HEAP32[$22>>2]|0;
  $78 = (($79) + ($77)|0);
  $80 = HEAP32[$15>>2]|0;
  $81 = (($80) + -1)|0;
  HEAP32[$15>>2] = $81;
  $82 = ($80|0)==(0);
  if ($82) {
   break;
  } else {
   $76 = $75;$79 = $78;$83 = $78;$84 = $75;
  }
 }
 HEAP32[$0>>2] = $75;
 HEAP32[$19>>2] = $78;
 return;
}
function _SDL_Blit_BGRA8888_ARGB8888_Modulate_Scale($0) {
 $0 = $0|0;
 var $$0100 = 0, $$0100$us = 0, $$088115 = 0, $$088115$us = 0, $$089114 = 0, $$089114$us = 0, $$091113 = 0, $$091113$us = 0, $$093119 = 0, $$095112 = 0, $$095112$us = 0, $$098118 = 0, $$1 = 0, $$1$us = 0, $$194$lcssa = 0, $$199$lcssa = 0, $$2 = 0, $$2$us = 0, $$297 = 0, $$297$us = 0;
 var $$pre = 0, $$pre129 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = ((($0)) + 61|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = ((($0)) + 62|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = ((($0)) + 63|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = $13&255;
 $15 = ((($0)) + 8|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $16 << 16;
 $18 = ((($0)) + 28|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($17|0) / ($19|0))&-1;
 $21 = ((($0)) + 4|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = $22 << 16;
 $24 = ((($0)) + 24|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($23|0) / ($25|0))&-1;
 $27 = (($19) + -1)|0;
 HEAP32[$18>>2] = $27;
 $28 = ($19|0)==(0);
 if ($28) {
  return;
 }
 $29 = ((($0)) + 20|0);
 $30 = ((($0)) + 32|0);
 $31 = $2 & 1;
 $32 = ($31|0)==(0);
 $33 = $2 & 2;
 $34 = ($33|0)==(0);
 $35 = ((($0)) + 12|0);
 $$pre = HEAP32[$29>>2]|0;
 $$093119 = 0;$$098118 = 0;$118 = $$pre;$123 = $$pre;$44 = $25;
 while(1) {
  $36 = ($$093119|0)>(65535);
  if ($36) {
   $37 = (($$093119) + -65536)|0;
   $38 = $37 >>> 16;
   $39 = $38 << 16;
   $40 = (($$098118) + 1)|0;
   $41 = (($40) + ($38))|0;
   $42 = (($37) - ($39))|0;
   $$194$lcssa = $42;$$199$lcssa = $41;
  } else {
   $$194$lcssa = $$093119;$$199$lcssa = $$098118;
  }
  $43 = (($44) + -1)|0;
  $45 = ($44|0)==(0);
  if (!($45)) {
   if ($32) {
    $$088115$us = $123;$$089114$us = 0;$$091113$us = 65536;$$095112$us = -1;$75 = $43;
    while(1) {
     $46 = ($$091113$us|0)>(65535);
     if ($46) {
      $47 = (($$091113$us) + -65536)|0;
      $48 = $47 >>> 16;
      $49 = $48 << 16;
      $50 = (($$095112$us) + 1)|0;
      $51 = (($50) + ($48))|0;
      $52 = (($47) - ($49))|0;
      $53 = HEAP32[$0>>2]|0;
      $54 = HEAP32[$35>>2]|0;
      $55 = Math_imul($54, $$199$lcssa)|0;
      $56 = (($53) + ($55)|0);
      $57 = $51 << 2;
      $58 = (($56) + ($57)|0);
      $$1$us = $58;$$2$us = $52;$$297$us = $51;
     } else {
      $$1$us = $$089114$us;$$2$us = $$091113$us;$$297$us = $$095112$us;
     }
     $59 = HEAP32[$$1$us>>2]|0;
     $60 = $59 >>> 24;
     $61 = $59 & 255;
     $62 = Math_imul($61, $14)|0;
     $63 = (($62>>>0) / 255)&-1;
     $$0100$us = $34 ? $59 : $63;
     $64 = $$0100$us << 24;
     $65 = $59 << 8;
     $66 = $65 & 16711680;
     $67 = $59 >>> 8;
     $68 = $67 & 65280;
     $69 = $68 | $64;
     $70 = $69 | $60;
     $71 = $70 | $66;
     HEAP32[$$088115$us>>2] = $71;
     $72 = (($$2$us) + ($26))|0;
     $73 = ((($$088115$us)) + 4|0);
     $74 = (($75) + -1)|0;
     $76 = ($75|0)==(0);
     if ($76) {
      break;
     } else {
      $$088115$us = $73;$$089114$us = $$1$us;$$091113$us = $72;$$095112$us = $$297$us;$75 = $74;
     }
    }
   } else {
    $$088115 = $123;$$089114 = 0;$$091113 = 65536;$$095112 = -1;$114 = $43;
    while(1) {
     $77 = ($$091113|0)>(65535);
     if ($77) {
      $78 = (($$091113) + -65536)|0;
      $79 = $78 >>> 16;
      $80 = $79 << 16;
      $81 = (($$095112) + 1)|0;
      $82 = (($81) + ($79))|0;
      $83 = (($78) - ($80))|0;
      $84 = HEAP32[$0>>2]|0;
      $85 = HEAP32[$35>>2]|0;
      $86 = Math_imul($85, $$199$lcssa)|0;
      $87 = (($84) + ($86)|0);
      $88 = $82 << 2;
      $89 = (($87) + ($88)|0);
      $$1 = $89;$$2 = $83;$$297 = $82;
     } else {
      $$1 = $$089114;$$2 = $$091113;$$297 = $$095112;
     }
     $90 = HEAP32[$$1>>2]|0;
     $91 = $90 >>> 24;
     $92 = $90 >>> 16;
     $93 = $92 & 255;
     $94 = $90 >>> 8;
     $95 = $94 & 255;
     $96 = $90 & 255;
     $97 = Math_imul($91, $11)|0;
     $98 = Math_imul($93, $8)|0;
     $99 = Math_imul($95, $5)|0;
     $100 = (($99>>>0) / 255)&-1;
     $101 = (($98>>>0) / 255)&-1;
     $102 = (($97>>>0) / 255)&-1;
     $103 = Math_imul($96, $14)|0;
     $104 = (($103>>>0) / 255)&-1;
     $$0100 = $34 ? $90 : $104;
     $105 = $$0100 << 24;
     $106 = $100 << 16;
     $107 = $101 << 8;
     $108 = $107 | $105;
     $109 = $108 | $102;
     $110 = $109 | $106;
     HEAP32[$$088115>>2] = $110;
     $111 = (($$2) + ($26))|0;
     $112 = ((($$088115)) + 4|0);
     $113 = (($114) + -1)|0;
     $115 = ($114|0)==(0);
     if ($115) {
      break;
     } else {
      $$088115 = $112;$$089114 = $$1;$$091113 = $111;$$095112 = $$297;$114 = $113;
     }
    }
   }
  }
  $116 = HEAP32[$30>>2]|0;
  $117 = (($118) + ($116)|0);
  $119 = HEAP32[$18>>2]|0;
  $120 = (($119) + -1)|0;
  HEAP32[$18>>2] = $120;
  $121 = ($119|0)==(0);
  if ($121) {
   break;
  }
  $122 = (($$194$lcssa) + ($20))|0;
  $$pre129 = HEAP32[$24>>2]|0;
  $$093119 = $122;$$098118 = $$199$lcssa;$118 = $117;$123 = $117;$44 = $$pre129;
 }
 HEAP32[$29>>2] = $117;
 return;
}
function _SDL_Blit_BGRA8888_ARGB8888_Modulate_Blend($0) {
 $0 = $0|0;
 var $$ = 0, $$0115129 = 0, $$0116128 = 0, $$0117 = 0, $$0118 = 0, $$0119 = 0, $$0120 = 0, $$0121 = 0, $$0122 = 0, $$0124 = 0, $$0126 = 0, $$1 = 0, $$1123 = 0, $$1125 = 0, $$1127 = 0, $$3 = 0, $$in = 0, $$pre = 0, $$pre133 = 0, $$pre134 = 0;
 var $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $trunc = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = ((($0)) + 61|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = ((($0)) + 62|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = ((($0)) + 63|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = $13&255;
 $15 = ((($0)) + 28|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + -1)|0;
 HEAP32[$15>>2] = $17;
 $18 = ($16|0)==(0);
 if ($18) {
  return;
 }
 $19 = ((($0)) + 20|0);
 $20 = ((($0)) + 24|0);
 $21 = ((($0)) + 12|0);
 $22 = ((($0)) + 32|0);
 $23 = $2 & 1;
 $24 = ($23|0)==(0);
 $25 = $2 & 2;
 $26 = ($25|0)==(0);
 $27 = $2 & 48;
 $28 = ($27|0)!=(0);
 $29 = $2 & 112;
 $trunc = $29&255;
 $$pre = HEAP32[$0>>2]|0;
 $$pre133 = HEAP32[$19>>2]|0;
 $101 = $$pre133;$105 = $17;$106 = $$pre133;$107 = $$pre;$98 = $$pre;
 while(1) {
  $30 = HEAP32[$20>>2]|0;
  $31 = ($30|0)==(0);
  if ($31) {
   $103 = $105;
  } else {
   $$0115129 = $106;$$0116128 = $107;$$in = $30;
   while(1) {
    $32 = (($$in) + -1)|0;
    $33 = HEAP32[$$0116128>>2]|0;
    $34 = $33 >>> 24;
    $35 = $33 >>> 16;
    $36 = $35 & 255;
    $37 = $33 >>> 8;
    $38 = $37 & 255;
    $39 = $33 & 255;
    $40 = HEAP32[$$0115129>>2]|0;
    $41 = $40 >>> 16;
    $42 = $41 & 255;
    $43 = $40 >>> 8;
    $44 = $43 & 255;
    $45 = $40 & 255;
    $46 = $40 >>> 24;
    if ($24) {
     $$0122 = $34;$$0124 = $36;$$0126 = $38;
    } else {
     $47 = Math_imul($34, $11)|0;
     $48 = Math_imul($36, $8)|0;
     $49 = Math_imul($38, $5)|0;
     $50 = (($49>>>0) / 255)&-1;
     $51 = (($48>>>0) / 255)&-1;
     $52 = (($47>>>0) / 255)&-1;
     $$0122 = $52;$$0124 = $51;$$0126 = $50;
    }
    $53 = Math_imul($39, $14)|0;
    $54 = (($53>>>0) / 255)&-1;
    $$0121 = $26 ? $39 : $54;
    $55 = ($$0121>>>0)<(255);
    $or$cond = $28 & $55;
    if ($or$cond) {
     $56 = Math_imul($$0122, $$0121)|0;
     $57 = Math_imul($$0124, $$0121)|0;
     $58 = Math_imul($$0126, $$0121)|0;
     $59 = (($58>>>0) / 255)&-1;
     $60 = (($57>>>0) / 255)&-1;
     $61 = (($56>>>0) / 255)&-1;
     $$1123 = $61;$$1125 = $60;$$1127 = $59;
    } else {
     $$1123 = $$0122;$$1125 = $$0124;$$1127 = $$0126;
    }
    $trunc$clear = $trunc & 127;
    switch ($trunc$clear<<24>>24) {
    case 16:  {
     $62 = (255 - ($$0121))|0;
     $63 = Math_imul($62, $42)|0;
     $64 = (($63>>>0) / 255)&-1;
     $65 = (($$1127) + ($64))|0;
     $66 = Math_imul($62, $44)|0;
     $67 = (($66>>>0) / 255)&-1;
     $68 = (($$1125) + ($67))|0;
     $69 = Math_imul($62, $45)|0;
     $70 = (($69>>>0) / 255)&-1;
     $71 = (($$1123) + ($70))|0;
     $72 = Math_imul($62, $46)|0;
     $73 = (($72>>>0) / 255)&-1;
     $74 = (($73) + ($$0121))|0;
     $$0117 = $74;$$0118 = $71;$$0119 = $68;$$0120 = $65;
     break;
    }
    case 32:  {
     $75 = (($$1127) + ($42))|0;
     $76 = ($75>>>0)<(255);
     $$ = $76 ? $75 : 255;
     $77 = (($$1125) + ($44))|0;
     $78 = ($77>>>0)<(255);
     $$3 = $78 ? $77 : 255;
     $79 = (($$1123) + ($45))|0;
     $80 = ($79>>>0)<(255);
     $$1 = $80 ? $79 : 255;
     $$0117 = $46;$$0118 = $$1;$$0119 = $$3;$$0120 = $$;
     break;
    }
    case 64:  {
     $81 = Math_imul($$1127, $42)|0;
     $82 = (($81>>>0) / 255)&-1;
     $83 = Math_imul($$1125, $44)|0;
     $84 = (($83>>>0) / 255)&-1;
     $85 = Math_imul($$1123, $45)|0;
     $86 = (($85>>>0) / 255)&-1;
     $$0117 = $46;$$0118 = $86;$$0119 = $84;$$0120 = $82;
     break;
    }
    default: {
     $$0117 = $46;$$0118 = $45;$$0119 = $44;$$0120 = $42;
    }
    }
    $87 = $$0117 << 24;
    $88 = $$0120 << 16;
    $89 = $$0119 << 8;
    $90 = $89 | $88;
    $91 = $90 | $$0118;
    $92 = $91 | $87;
    HEAP32[$$0115129>>2] = $92;
    $93 = ((($$0116128)) + 4|0);
    $94 = ((($$0115129)) + 4|0);
    $95 = ($32|0)==(0);
    if ($95) {
     break;
    } else {
     $$0115129 = $94;$$0116128 = $93;$$in = $32;
    }
   }
   $$pre134 = HEAP32[$15>>2]|0;
   $103 = $$pre134;
  }
  $96 = HEAP32[$21>>2]|0;
  $97 = (($98) + ($96)|0);
  $99 = HEAP32[$22>>2]|0;
  $100 = (($101) + ($99)|0);
  $102 = (($103) + -1)|0;
  HEAP32[$15>>2] = $102;
  $104 = ($103|0)==(0);
  if ($104) {
   break;
  } else {
   $101 = $100;$105 = $102;$106 = $100;$107 = $97;$98 = $97;
  }
 }
 HEAP32[$0>>2] = $97;
 HEAP32[$19>>2] = $100;
 return;
}
function _SDL_Blit_BGRA8888_ARGB8888_Modulate_Blend_Scale($0) {
 $0 = $0|0;
 var $$ = 0, $$0142177 = 0, $$0143176 = 0, $$0145 = 0, $$0147 = 0, $$0149175 = 0, $$0151181 = 0, $$0153174 = 0, $$0156180 = 0, $$0158 = 0, $$0159 = 0, $$0160 = 0, $$0161 = 0, $$0162 = 0, $$0163 = 0, $$1 = 0, $$1144 = 0, $$1146 = 0, $$1148 = 0, $$1152$lcssa = 0;
 var $$1157$lcssa = 0, $$1164 = 0, $$2 = 0, $$2155 = 0, $$3 = 0, $$in = 0, $$pre = 0, $$pre188 = 0, $$pre189 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $or$cond = 0, $trunc = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 60|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = ((($0)) + 61|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = ((($0)) + 62|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = ((($0)) + 63|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = $13&255;
 $15 = ((($0)) + 8|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $16 << 16;
 $18 = ((($0)) + 28|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($17|0) / ($19|0))&-1;
 $21 = ((($0)) + 4|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = $22 << 16;
 $24 = ((($0)) + 24|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($23|0) / ($25|0))&-1;
 $27 = (($19) + -1)|0;
 HEAP32[$18>>2] = $27;
 $28 = ($19|0)==(0);
 if ($28) {
  return;
 }
 $29 = ((($0)) + 20|0);
 $30 = ((($0)) + 32|0);
 $31 = $2 & 1;
 $32 = ($31|0)==(0);
 $33 = $2 & 2;
 $34 = ($33|0)==(0);
 $35 = $2 & 48;
 $36 = ($35|0)!=(0);
 $37 = $2 & 112;
 $trunc = $37&255;
 $38 = ((($0)) + 12|0);
 $$pre = HEAP32[$29>>2]|0;
 $$0151181 = 0;$$0156180 = 0;$127 = $$pre;$132 = $27;$133 = $$pre;$46 = $25;
 while(1) {
  $39 = ($$0151181|0)>(65535);
  if ($39) {
   $40 = (($$0151181) + -65536)|0;
   $41 = $40 >>> 16;
   $42 = $41 << 16;
   $43 = (($$0156180) + 1)|0;
   $44 = (($43) + ($41))|0;
   $45 = (($40) - ($42))|0;
   $$1152$lcssa = $45;$$1157$lcssa = $44;
  } else {
   $$1152$lcssa = $$0151181;$$1157$lcssa = $$0156180;
  }
  $47 = ($46|0)==(0);
  if ($47) {
   $129 = $132;
  } else {
   $$0142177 = $133;$$0143176 = 0;$$0149175 = 65536;$$0153174 = -1;$$in = $46;
   while(1) {
    $48 = (($$in) + -1)|0;
    $49 = ($$0149175|0)>(65535);
    if ($49) {
     $50 = (($$0149175) + -65536)|0;
     $51 = $50 >>> 16;
     $52 = $51 << 16;
     $53 = (($$0153174) + 1)|0;
     $54 = (($53) + ($51))|0;
     $55 = (($50) - ($52))|0;
     $56 = HEAP32[$0>>2]|0;
     $57 = HEAP32[$38>>2]|0;
     $58 = Math_imul($57, $$1157$lcssa)|0;
     $59 = (($56) + ($58)|0);
     $60 = $54 << 2;
     $61 = (($59) + ($60)|0);
     $$1144 = $61;$$2 = $55;$$2155 = $54;
    } else {
     $$1144 = $$0143176;$$2 = $$0149175;$$2155 = $$0153174;
    }
    $62 = HEAP32[$$1144>>2]|0;
    $63 = $62 >>> 24;
    $64 = $62 >>> 16;
    $65 = $64 & 255;
    $66 = $62 >>> 8;
    $67 = $66 & 255;
    $68 = $62 & 255;
    $69 = HEAP32[$$0142177>>2]|0;
    $70 = $69 >>> 16;
    $71 = $70 & 255;
    $72 = $69 >>> 8;
    $73 = $72 & 255;
    $74 = $69 & 255;
    $75 = $69 >>> 24;
    if ($32) {
     $$0145 = $67;$$0147 = $65;$$0163 = $63;
    } else {
     $76 = Math_imul($63, $11)|0;
     $77 = Math_imul($65, $8)|0;
     $78 = Math_imul($67, $5)|0;
     $79 = (($78>>>0) / 255)&-1;
     $80 = (($77>>>0) / 255)&-1;
     $81 = (($76>>>0) / 255)&-1;
     $$0145 = $79;$$0147 = $80;$$0163 = $81;
    }
    $82 = Math_imul($68, $14)|0;
    $83 = (($82>>>0) / 255)&-1;
    $$0162 = $34 ? $68 : $83;
    $84 = ($$0162>>>0)<(255);
    $or$cond = $36 & $84;
    if ($or$cond) {
     $85 = Math_imul($$0163, $$0162)|0;
     $86 = Math_imul($$0147, $$0162)|0;
     $87 = Math_imul($$0145, $$0162)|0;
     $88 = (($87>>>0) / 255)&-1;
     $89 = (($86>>>0) / 255)&-1;
     $90 = (($85>>>0) / 255)&-1;
     $$1146 = $88;$$1148 = $89;$$1164 = $90;
    } else {
     $$1146 = $$0145;$$1148 = $$0147;$$1164 = $$0163;
    }
    $trunc$clear = $trunc & 127;
    switch ($trunc$clear<<24>>24) {
    case 16:  {
     $91 = (255 - ($$0162))|0;
     $92 = Math_imul($91, $71)|0;
     $93 = (($92>>>0) / 255)&-1;
     $94 = (($$1146) + ($93))|0;
     $95 = Math_imul($91, $73)|0;
     $96 = (($95>>>0) / 255)&-1;
     $97 = (($$1148) + ($96))|0;
     $98 = Math_imul($91, $74)|0;
     $99 = (($98>>>0) / 255)&-1;
     $100 = (($$1164) + ($99))|0;
     $101 = Math_imul($91, $75)|0;
     $102 = (($101>>>0) / 255)&-1;
     $103 = (($102) + ($$0162))|0;
     $$0158 = $103;$$0159 = $100;$$0160 = $97;$$0161 = $94;
     break;
    }
    case 32:  {
     $104 = (($$1146) + ($71))|0;
     $105 = ($104>>>0)<(255);
     $$ = $105 ? $104 : 255;
     $106 = (($$1148) + ($73))|0;
     $107 = ($106>>>0)<(255);
     $$3 = $107 ? $106 : 255;
     $108 = (($$1164) + ($74))|0;
     $109 = ($108>>>0)<(255);
     $$1 = $109 ? $108 : 255;
     $$0158 = $75;$$0159 = $$1;$$0160 = $$3;$$0161 = $$;
     break;
    }
    case 64:  {
     $110 = Math_imul($$1146, $71)|0;
     $111 = (($110>>>0) / 255)&-1;
     $112 = Math_imul($$1148, $73)|0;
     $113 = (($112>>>0) / 255)&-1;
     $114 = Math_imul($$1164, $74)|0;
     $115 = (($114>>>0) / 255)&-1;
     $$0158 = $75;$$0159 = $115;$$0160 = $113;$$0161 = $111;
     break;
    }
    default: {
     $$0158 = $75;$$0159 = $74;$$0160 = $73;$$0161 = $71;
    }
    }
    $116 = $$0158 << 24;
    $117 = $$0161 << 16;
    $118 = $$0160 << 8;
    $119 = $118 | $117;
    $120 = $119 | $$0159;
    $121 = $120 | $116;
    HEAP32[$$0142177>>2] = $121;
    $122 = (($$2) + ($26))|0;
    $123 = ((($$0142177)) + 4|0);
    $124 = ($48|0)==(0);
    if ($124) {
     break;
    } else {
     $$0142177 = $123;$$0143176 = $$1144;$$0149175 = $122;$$0153174 = $$2155;$$in = $48;
    }
   }
   $$pre189 = HEAP32[$18>>2]|0;
   $129 = $$pre189;
  }
  $125 = HEAP32[$30>>2]|0;
  $126 = (($127) + ($125)|0);
  $128 = (($129) + -1)|0;
  HEAP32[$18>>2] = $128;
  $130 = ($129|0)==(0);
  if ($130) {
   break;
  }
  $131 = (($$1152$lcssa) + ($20))|0;
  $$pre188 = HEAP32[$24>>2]|0;
  $$0151181 = $131;$$0156180 = $$1157$lcssa;$127 = $126;$132 = $128;$133 = $126;$46 = $$pre188;
 }
 HEAP32[$29>>2] = $126;
 return;
}
function _SDL_strlen($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (_strlen($0)|0);
 return ($1|0);
}
function _BlitNtoN($0) {
 $0 = $0|0;
 var $$09541074 = 0, $$09551073 = 0, $$0964 = 0, $$0964$shrunk = 0, $$0965 = 0, $$0965$shrunk = 0, $$0965$shrunk$ph = 0, $$0965$shrunk$ph$in = 0, $$0966 = 0, $$0966$shrunk = 0, $$0966$shrunk$ph = 0, $$0966$shrunk$ph$in = 0, $$0967 = 0, $$0975 = 0, $$0975$shrunk = 0, $$0975$shrunk$ph = 0, $$0975$shrunk$ph$in = 0, $$0976 = 0, $$0976$shrunk = 0, $$0977 = 0;
 var $$0977$shrunk = 0, $$0977$shrunk$ph = 0, $$0977$shrunk$ph$in = 0, $$0978 = 0, $$0978$shrunk = 0, $$0978$shrunk$ph = 0, $$0978$shrunk$ph$in = 0, $$0979 = 0, $$0979$shrunk = 0, $$0979$shrunk$ph = 0, $$0979$shrunk$ph$in = 0, $$0980 = 0, $$0980$shrunk = 0, $$0981 = 0, $$0981$shrunk = 0, $$0982 = 0, $$0982$shrunk = 0, $$0982$shrunk$ph = 0, $$0982$shrunk$ph$in = 0, $$0983 = 0;
 var $$0983$shrunk = 0, $$0983$shrunk$ph = 0, $$0983$shrunk$ph$in = 0, $$0984 = 0, $$0984$shrunk = 0, $$0984$shrunk$ph = 0, $$0984$shrunk$ph$in = 0, $$0985 = 0, $$0985$shrunk = 0, $$0985$shrunk$ph = 0, $$0985$shrunk$ph$in = 0, $$0986 = 0, $$0986$shrunk = 0, $$0987 = 0, $$0987$shrunk = 0, $$0988 = 0, $$0988$shrunk = 0, $$0988$shrunk$ph = 0, $$0988$shrunk$ph$in = 0, $$0989 = 0;
 var $$0989$shrunk = 0, $$0989$shrunk$ph = 0, $$0989$shrunk$ph$in = 0, $$0990 = 0, $$0990$shrunk = 0, $$0990$shrunk$ph = 0, $$0990$shrunk$ph$in = 0, $$0991 = 0, $$0991$shrunk = 0, $$0991$shrunk$ph = 0, $$0991$shrunk$ph$in = 0, $$0992 = 0, $$0992$shrunk = 0, $$0993 = 0, $$0993$shrunk = 0, $$0993$shrunk$ph = 0, $$0993$shrunk$ph$in = 0, $$0994 = 0, $$0994$shrunk = 0, $$0994$shrunk$ph = 0;
 var $$0994$shrunk$ph$in = 0, $$0995 = 0, $$0995$shrunk = 0, $$1 = 0, $$1956 = 0, $$1968 = 0, $$2 = 0, $$2957 = 0, $$2969 = 0, $$3 = 0, $$3958 = 0, $$3970 = 0, $$4 = 0, $$4959 = 0, $$4971 = 0, $$5 = 0, $$5960 = 0, $$5972 = 0, $$6 = 0, $$6961 = 0;
 var $$6973 = 0, $$7 = 0, $$7962 = 0, $$7974 = 0, $$8 = 0, $$8963 = 0, $$in = 0, $$sink = 0, $$sink1060 = 0, $$sink1062 = 0, $$sink1064 = 0, $$sink1066 = 0, $$sink1068 = 0, $$sink1070 = 0, $$sink1072 = 0, $1 = 0, $10 = 0, $100 = 0, $1000 = 0, $1001 = 0;
 var $1002 = 0, $1003 = 0, $1004 = 0, $1005 = 0, $1006 = 0, $1007 = 0, $1008 = 0, $1009 = 0, $101 = 0, $1010 = 0, $1011 = 0, $1012 = 0, $1013 = 0, $1014 = 0, $1015 = 0, $1016 = 0, $1017 = 0, $1018 = 0, $1019 = 0, $102 = 0;
 var $1020 = 0, $1021 = 0, $1022 = 0, $1023 = 0, $1024 = 0, $1025 = 0, $1026 = 0, $1027 = 0, $1028 = 0, $1029 = 0, $103 = 0, $1030 = 0, $1031 = 0, $1032 = 0, $1033 = 0, $1034 = 0, $1035 = 0, $1036 = 0, $1037 = 0, $1038 = 0;
 var $1039 = 0, $104 = 0, $1040 = 0, $1041 = 0, $1042 = 0, $1043 = 0, $1044 = 0, $1045 = 0, $1046 = 0, $1047 = 0, $1048 = 0, $1049 = 0, $105 = 0, $1050 = 0, $1051 = 0, $1052 = 0, $1053 = 0, $1054 = 0, $1055 = 0, $1056 = 0;
 var $1057 = 0, $1058 = 0, $1059 = 0, $106 = 0, $1060 = 0, $1061 = 0, $1062 = 0, $1063 = 0, $1064 = 0, $1065 = 0, $1066 = 0, $1067 = 0, $1068 = 0, $1069 = 0, $107 = 0, $1070 = 0, $1071 = 0, $1072 = 0, $1073 = 0, $1074 = 0;
 var $1075 = 0, $1076 = 0, $1077 = 0, $1078 = 0, $1079 = 0, $108 = 0, $1080 = 0, $1081 = 0, $1082 = 0, $1083 = 0, $1084 = 0, $1085 = 0, $1086 = 0, $1087 = 0, $1088 = 0, $1089 = 0, $109 = 0, $1090 = 0, $1091 = 0, $1092 = 0;
 var $1093 = 0, $1094 = 0, $1095 = 0, $1096 = 0, $1097 = 0, $1098 = 0, $1099 = 0, $11 = 0, $110 = 0, $1100 = 0, $1101 = 0, $1102 = 0, $1103 = 0, $1104 = 0, $1105 = 0, $1106 = 0, $1107 = 0, $1108 = 0, $1109 = 0, $111 = 0;
 var $1110 = 0, $1111 = 0, $1112 = 0, $1113 = 0, $1114 = 0, $1115 = 0, $1116 = 0, $1117 = 0, $1118 = 0, $1119 = 0, $112 = 0, $1120 = 0, $1121 = 0, $1122 = 0, $1123 = 0, $1124 = 0, $1125 = 0, $1126 = 0, $1127 = 0, $1128 = 0;
 var $1129 = 0, $113 = 0, $1130 = 0, $1131 = 0, $1132 = 0, $1133 = 0, $1134 = 0, $1135 = 0, $1136 = 0, $1137 = 0, $1138 = 0, $1139 = 0, $114 = 0, $1140 = 0, $1141 = 0, $1142 = 0, $1143 = 0, $1144 = 0, $1145 = 0, $1146 = 0;
 var $1147 = 0, $1148 = 0, $1149 = 0, $115 = 0, $1150 = 0, $1151 = 0, $1152 = 0, $1153 = 0, $1154 = 0, $1155 = 0, $1156 = 0, $1157 = 0, $1158 = 0, $1159 = 0, $116 = 0, $1160 = 0, $1161 = 0, $1162 = 0, $1163 = 0, $1164 = 0;
 var $1165 = 0, $1166 = 0, $1167 = 0, $1168 = 0, $1169 = 0, $117 = 0, $1170 = 0, $1171 = 0, $1172 = 0, $1173 = 0, $1174 = 0, $1175 = 0, $1176 = 0, $1177 = 0, $1178 = 0, $1179 = 0, $118 = 0, $1180 = 0, $1181 = 0, $1182 = 0;
 var $1183 = 0, $1184 = 0, $1185 = 0, $1186 = 0, $1187 = 0, $1188 = 0, $1189 = 0, $119 = 0, $1190 = 0, $1191 = 0, $1192 = 0, $1193 = 0, $1194 = 0, $1195 = 0, $1196 = 0, $1197 = 0, $1198 = 0, $1199 = 0, $12 = 0, $120 = 0;
 var $1200 = 0, $1201 = 0, $1202 = 0, $1203 = 0, $1204 = 0, $1205 = 0, $1206 = 0, $1207 = 0, $1208 = 0, $1209 = 0, $121 = 0, $1210 = 0, $1211 = 0, $1212 = 0, $1213 = 0, $1214 = 0, $1215 = 0, $1216 = 0, $1217 = 0, $1218 = 0;
 var $1219 = 0, $122 = 0, $1220 = 0, $1221 = 0, $1222 = 0, $1223 = 0, $1224 = 0, $1225 = 0, $1226 = 0, $1227 = 0, $1228 = 0, $1229 = 0, $123 = 0, $1230 = 0, $1231 = 0, $1232 = 0, $1233 = 0, $1234 = 0, $1235 = 0, $1236 = 0;
 var $1237 = 0, $1238 = 0, $1239 = 0, $124 = 0, $1240 = 0, $1241 = 0, $1242 = 0, $1243 = 0, $1244 = 0, $1245 = 0, $1246 = 0, $1247 = 0, $1248 = 0, $1249 = 0, $125 = 0, $1250 = 0, $1251 = 0, $1252 = 0, $1253 = 0, $1254 = 0;
 var $1255 = 0, $1256 = 0, $1257 = 0, $1258 = 0, $1259 = 0, $126 = 0, $1260 = 0, $1261 = 0, $1262 = 0, $1263 = 0, $1264 = 0, $1265 = 0, $1266 = 0, $1267 = 0, $1268 = 0, $1269 = 0, $127 = 0, $1270 = 0, $1271 = 0, $1272 = 0;
 var $1273 = 0, $1274 = 0, $1275 = 0, $1276 = 0, $1277 = 0, $1278 = 0, $1279 = 0, $128 = 0, $1280 = 0, $1281 = 0, $1282 = 0, $1283 = 0, $1284 = 0, $1285 = 0, $1286 = 0, $1287 = 0, $1288 = 0, $1289 = 0, $129 = 0, $1290 = 0;
 var $1291 = 0, $1292 = 0, $1293 = 0, $1294 = 0, $1295 = 0, $1296 = 0, $1297 = 0, $1298 = 0, $1299 = 0, $13 = 0, $130 = 0, $1300 = 0, $1301 = 0, $1302 = 0, $1303 = 0, $1304 = 0, $1305 = 0, $1306 = 0, $1307 = 0, $1308 = 0;
 var $1309 = 0, $131 = 0, $1310 = 0, $1311 = 0, $1312 = 0, $1313 = 0, $1314 = 0, $1315 = 0, $1316 = 0, $1317 = 0, $1318 = 0, $1319 = 0, $132 = 0, $1320 = 0, $1321 = 0, $1322 = 0, $1323 = 0, $1324 = 0, $1325 = 0, $1326 = 0;
 var $1327 = 0, $1328 = 0, $1329 = 0, $133 = 0, $1330 = 0, $1331 = 0, $1332 = 0, $1333 = 0, $1334 = 0, $1335 = 0, $1336 = 0, $1337 = 0, $1338 = 0, $1339 = 0, $134 = 0, $1340 = 0, $1341 = 0, $1342 = 0, $1343 = 0, $1344 = 0;
 var $1345 = 0, $1346 = 0, $1347 = 0, $1348 = 0, $1349 = 0, $135 = 0, $1350 = 0, $1351 = 0, $1352 = 0, $1353 = 0, $1354 = 0, $1355 = 0, $1356 = 0, $1357 = 0, $1358 = 0, $1359 = 0, $136 = 0, $1360 = 0, $1361 = 0, $1362 = 0;
 var $1363 = 0, $1364 = 0, $1365 = 0, $1366 = 0, $1367 = 0, $1368 = 0, $1369 = 0, $137 = 0, $1370 = 0, $1371 = 0, $1372 = 0, $1373 = 0, $1374 = 0, $1375 = 0, $1376 = 0, $1377 = 0, $1378 = 0, $1379 = 0, $138 = 0, $1380 = 0;
 var $1381 = 0, $1382 = 0, $1383 = 0, $1384 = 0, $1385 = 0, $1386 = 0, $1387 = 0, $1388 = 0, $1389 = 0, $139 = 0, $1390 = 0, $1391 = 0, $1392 = 0, $1393 = 0, $1394 = 0, $1395 = 0, $1396 = 0, $1397 = 0, $1398 = 0, $1399 = 0;
 var $14 = 0, $140 = 0, $1400 = 0, $1401 = 0, $1402 = 0, $1403 = 0, $1404 = 0, $1405 = 0, $1406 = 0, $1407 = 0, $1408 = 0, $1409 = 0, $141 = 0, $1410 = 0, $1411 = 0, $1412 = 0, $1413 = 0, $1414 = 0, $1415 = 0, $1416 = 0;
 var $1417 = 0, $1418 = 0, $1419 = 0, $142 = 0, $1420 = 0, $1421 = 0, $1422 = 0, $1423 = 0, $1424 = 0, $1425 = 0, $1426 = 0, $1427 = 0, $1428 = 0, $1429 = 0, $143 = 0, $1430 = 0, $1431 = 0, $1432 = 0, $1433 = 0, $1434 = 0;
 var $1435 = 0, $1436 = 0, $1437 = 0, $1438 = 0, $1439 = 0, $144 = 0, $1440 = 0, $1441 = 0, $1442 = 0, $1443 = 0, $1444 = 0, $1445 = 0, $1446 = 0, $1447 = 0, $1448 = 0, $1449 = 0, $145 = 0, $1450 = 0, $1451 = 0, $1452 = 0;
 var $1453 = 0, $1454 = 0, $1455 = 0, $1456 = 0, $1457 = 0, $1458 = 0, $1459 = 0, $146 = 0, $1460 = 0, $1461 = 0, $1462 = 0, $1463 = 0, $1464 = 0, $1465 = 0, $1466 = 0, $1467 = 0, $1468 = 0, $1469 = 0, $147 = 0, $1470 = 0;
 var $1471 = 0, $1472 = 0, $1473 = 0, $1474 = 0, $1475 = 0, $1476 = 0, $1477 = 0, $1478 = 0, $1479 = 0, $148 = 0, $1480 = 0, $1481 = 0, $1482 = 0, $1483 = 0, $1484 = 0, $1485 = 0, $1486 = 0, $1487 = 0, $1488 = 0, $1489 = 0;
 var $149 = 0, $1490 = 0, $1491 = 0, $1492 = 0, $1493 = 0, $1494 = 0, $1495 = 0, $1496 = 0, $1497 = 0, $1498 = 0, $1499 = 0, $15 = 0, $150 = 0, $1500 = 0, $1501 = 0, $1502 = 0, $1503 = 0, $1504 = 0, $1505 = 0, $1506 = 0;
 var $1507 = 0, $1508 = 0, $1509 = 0, $151 = 0, $1510 = 0, $1511 = 0, $1512 = 0, $1513 = 0, $1514 = 0, $1515 = 0, $1516 = 0, $1517 = 0, $1518 = 0, $1519 = 0, $152 = 0, $1520 = 0, $1521 = 0, $1522 = 0, $1523 = 0, $1524 = 0;
 var $1525 = 0, $1526 = 0, $1527 = 0, $1528 = 0, $1529 = 0, $153 = 0, $1530 = 0, $1531 = 0, $1532 = 0, $1533 = 0, $1534 = 0, $1535 = 0, $1536 = 0, $1537 = 0, $1538 = 0, $1539 = 0, $154 = 0, $1540 = 0, $1541 = 0, $1542 = 0;
 var $1543 = 0, $1544 = 0, $1545 = 0, $1546 = 0, $1547 = 0, $1548 = 0, $1549 = 0, $155 = 0, $1550 = 0, $1551 = 0, $1552 = 0, $1553 = 0, $1554 = 0, $1555 = 0, $1556 = 0, $1557 = 0, $1558 = 0, $1559 = 0, $156 = 0, $1560 = 0;
 var $1561 = 0, $1562 = 0, $1563 = 0, $1564 = 0, $1565 = 0, $1566 = 0, $1567 = 0, $1568 = 0, $1569 = 0, $157 = 0, $1570 = 0, $1571 = 0, $1572 = 0, $1573 = 0, $1574 = 0, $1575 = 0, $1576 = 0, $1577 = 0, $1578 = 0, $1579 = 0;
 var $158 = 0, $1580 = 0, $1581 = 0, $1582 = 0, $1583 = 0, $1584 = 0, $1585 = 0, $1586 = 0, $1587 = 0, $1588 = 0, $1589 = 0, $159 = 0, $1590 = 0, $1591 = 0, $1592 = 0, $1593 = 0, $1594 = 0, $1595 = 0, $1596 = 0, $1597 = 0;
 var $1598 = 0, $1599 = 0, $16 = 0, $160 = 0, $1600 = 0, $1601 = 0, $1602 = 0, $1603 = 0, $1604 = 0, $1605 = 0, $1606 = 0, $1607 = 0, $1608 = 0, $1609 = 0, $161 = 0, $1610 = 0, $1611 = 0, $1612 = 0, $1613 = 0, $1614 = 0;
 var $1615 = 0, $1616 = 0, $1617 = 0, $1618 = 0, $1619 = 0, $162 = 0, $1620 = 0, $1621 = 0, $1622 = 0, $1623 = 0, $1624 = 0, $1625 = 0, $1626 = 0, $1627 = 0, $1628 = 0, $1629 = 0, $163 = 0, $1630 = 0, $1631 = 0, $1632 = 0;
 var $1633 = 0, $1634 = 0, $1635 = 0, $1636 = 0, $1637 = 0, $1638 = 0, $1639 = 0, $164 = 0, $1640 = 0, $1641 = 0, $1642 = 0, $1643 = 0, $1644 = 0, $1645 = 0, $1646 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0;
 var $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0;
 var $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0;
 var $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0;
 var $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0;
 var $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0;
 var $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0;
 var $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0;
 var $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0;
 var $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0;
 var $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0;
 var $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0;
 var $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0;
 var $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0;
 var $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0;
 var $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0;
 var $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0;
 var $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0;
 var $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0;
 var $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0;
 var $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0;
 var $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0;
 var $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0;
 var $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0;
 var $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0;
 var $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0;
 var $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0;
 var $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0;
 var $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0;
 var $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0;
 var $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0;
 var $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0;
 var $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0;
 var $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0;
 var $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0;
 var $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = 0, $834 = 0, $835 = 0;
 var $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0, $850 = 0, $851 = 0, $852 = 0, $853 = 0;
 var $854 = 0, $855 = 0, $856 = 0, $857 = 0, $858 = 0, $859 = 0, $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0, $869 = 0, $87 = 0, $870 = 0, $871 = 0;
 var $872 = 0, $873 = 0, $874 = 0, $875 = 0, $876 = 0, $877 = 0, $878 = 0, $879 = 0, $88 = 0, $880 = 0, $881 = 0, $882 = 0, $883 = 0, $884 = 0, $885 = 0, $886 = 0, $887 = 0, $888 = 0, $889 = 0, $89 = 0;
 var $890 = 0, $891 = 0, $892 = 0, $893 = 0, $894 = 0, $895 = 0, $896 = 0, $897 = 0, $898 = 0, $899 = 0, $9 = 0, $90 = 0, $900 = 0, $901 = 0, $902 = 0, $903 = 0, $904 = 0, $905 = 0, $906 = 0, $907 = 0;
 var $908 = 0, $909 = 0, $91 = 0, $910 = 0, $911 = 0, $912 = 0, $913 = 0, $914 = 0, $915 = 0, $916 = 0, $917 = 0, $918 = 0, $919 = 0, $92 = 0, $920 = 0, $921 = 0, $922 = 0, $923 = 0, $924 = 0, $925 = 0;
 var $926 = 0, $927 = 0, $928 = 0, $929 = 0, $93 = 0, $930 = 0, $931 = 0, $932 = 0, $933 = 0, $934 = 0, $935 = 0, $936 = 0, $937 = 0, $938 = 0, $939 = 0, $94 = 0, $940 = 0, $941 = 0, $942 = 0, $943 = 0;
 var $944 = 0, $945 = 0, $946 = 0, $947 = 0, $948 = 0, $949 = 0, $95 = 0, $950 = 0, $951 = 0, $952 = 0, $953 = 0, $954 = 0, $955 = 0, $956 = 0, $957 = 0, $958 = 0, $959 = 0, $96 = 0, $960 = 0, $961 = 0;
 var $962 = 0, $963 = 0, $964 = 0, $965 = 0, $966 = 0, $967 = 0, $968 = 0, $969 = 0, $97 = 0, $970 = 0, $971 = 0, $972 = 0, $973 = 0, $974 = 0, $975 = 0, $976 = 0, $977 = 0, $978 = 0, $979 = 0, $98 = 0;
 var $980 = 0, $981 = 0, $982 = 0, $983 = 0, $984 = 0, $985 = 0, $986 = 0, $987 = 0, $988 = 0, $989 = 0, $99 = 0, $990 = 0, $991 = 0, $992 = 0, $993 = 0, $994 = 0, $995 = 0, $996 = 0, $997 = 0, $998 = 0;
 var $999 = 0, $div = 0, $div1012 = 0, $div1013 = 0, $div1014 = 0, $div1015 = 0, $div1016 = 0, $div1017 = 0, $div1018 = 0, $div1019 = 0, $div1020 = 0, $div1021 = 0, $div1022 = 0, $div1023 = 0, $div1024 = 0, $div1025 = 0, $div1026 = 0, $div1027 = 0, $div1028 = 0, $div1029 = 0;
 var $div1030 = 0, $div1031 = 0, $div1032 = 0, $div1033 = 0, $div1034 = 0, $div1035 = 0, $div1036 = 0, $div1037 = 0, $div1038 = 0, $div1039 = 0, $div1040 = 0, $div1041 = 0, $div1042 = 0, $div1043 = 0, $div1044 = 0, $div1045 = 0, $div1046 = 0, $div1047 = 0, $div1048 = 0, $div1049 = 0;
 var $div1050 = 0, $div1051 = 0, $div1052 = 0, $div1053 = 0, $div1054 = 0, $div1055 = 0, $div1056 = 0, $div1057 = 0, $div1058 = 0, $trunc = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$0>>2]|0;
 $6 = ((($0)) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($0)) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($0)) + 36|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($0)) + 40|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($13)) + 9|0);
 $15 = HEAP8[$14>>0]|0;
 $16 = $15&255;
 $17 = ((($0)) + 44|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ((($18)) + 9|0);
 $20 = HEAP8[$19>>0]|0;
 $21 = $20&255;
 $22 = ((($18)) + 24|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)==(0);
 if ($24) {
  $177 = 0;
 } else {
  $25 = ((($0)) + 63|0);
  $26 = HEAP8[$25>>0]|0;
  $27 = $26&255;
  $177 = $27;
 }
 $28 = ($4|0)==(0);
 if ($28) {
  return;
 }
 $29 = (($2) + 7)|0;
 $30 = (($29|0) / 8)&-1;
 $trunc = $2&255;
 $31 = ((($18)) + 28|0);
 $32 = ((($18)) + 32|0);
 $33 = ((($18)) + 29|0);
 $34 = ((($18)) + 33|0);
 $35 = ((($18)) + 30|0);
 $36 = ((($18)) + 34|0);
 $37 = ((($18)) + 31|0);
 $38 = ((($18)) + 35|0);
 $39 = ((($13)) + 28|0);
 $40 = ((($13)) + 12|0);
 $41 = ((($13)) + 32|0);
 $42 = ((($13)) + 29|0);
 $43 = ((($13)) + 16|0);
 $44 = ((($13)) + 33|0);
 $45 = ((($13)) + 30|0);
 $46 = ((($13)) + 20|0);
 $47 = ((($13)) + 34|0);
 $$09541074 = $5;$$09551073 = $9;$$in = $4;
 L7: while(1) {
  $48 = (($$in) + -1)|0;
  $trunc$clear = $trunc & 7;
  switch ($trunc$clear<<24>>24) {
  case 0:  {
   $$0967 = $30;$$1 = $$09541074;$$1956 = $$09551073;
   label = 6;
   break;
  }
  case 7:  {
   $$1968 = $30;$$2 = $$09541074;$$2957 = $$09551073;
   label = 18;
   break;
  }
  case 6:  {
   $$2969 = $30;$$3 = $$09541074;$$3958 = $$09551073;
   label = 30;
   break;
  }
  case 5:  {
   $$3970 = $30;$$4 = $$09541074;$$4959 = $$09551073;
   label = 42;
   break;
  }
  case 4:  {
   $$4971 = $30;$$5 = $$09541074;$$5960 = $$09551073;
   label = 54;
   break;
  }
  case 3:  {
   $$5972 = $30;$$6 = $$09541074;$$6961 = $$09551073;
   label = 66;
   break;
  }
  case 2:  {
   $$6973 = $30;$$7 = $$09541074;$$7962 = $$09551073;
   label = 78;
   break;
  }
  case 1:  {
   $$7974 = $30;$$8 = $$09541074;$$8963 = $$09551073;
   label = 90;
   break;
  }
  default: {
   label = 102;
   break L7;
  }
  }
  while(1) {
   if ((label|0) == 6) {
    label = 0;
    switch ($15<<24>>24) {
    case 1:  {
     $49 = HEAP8[$$1>>0]|0;
     $50 = $49&255;
     $51 = HEAP8[$39>>0]|0;
     $52 = $51&255;
     $53 = (79212 + ($52<<2)|0);
     $54 = HEAP32[$53>>2]|0;
     $55 = HEAP32[$40>>2]|0;
     $56 = $55 & $50;
     $57 = HEAP8[$41>>0]|0;
     $58 = $57&255;
     $59 = $56 >>> $58;
     $60 = (($54) + ($59)|0);
     $61 = HEAP8[$42>>0]|0;
     $62 = $61&255;
     $63 = (79212 + ($62<<2)|0);
     $64 = HEAP32[$63>>2]|0;
     $65 = HEAP32[$43>>2]|0;
     $66 = $65 & $50;
     $67 = HEAP8[$44>>0]|0;
     $68 = $67&255;
     $69 = $66 >>> $68;
     $70 = (($64) + ($69)|0);
     $71 = HEAP8[$45>>0]|0;
     $72 = $71&255;
     $73 = (79212 + ($72<<2)|0);
     $74 = HEAP32[$73>>2]|0;
     $75 = HEAP32[$46>>2]|0;
     $76 = $75 & $50;
     $77 = HEAP8[$47>>0]|0;
     $78 = $77&255;
     $79 = $76 >>> $78;
     $80 = (($74) + ($79)|0);
     $$0975$shrunk$ph$in = $60;$$0979$shrunk$ph$in = $70;$$sink = $80;
     label = 11;
     break;
    }
    case 2:  {
     $81 = HEAP16[$$1>>1]|0;
     $82 = $81&65535;
     $83 = HEAP8[$39>>0]|0;
     $84 = $83&255;
     $85 = (79212 + ($84<<2)|0);
     $86 = HEAP32[$85>>2]|0;
     $87 = HEAP32[$40>>2]|0;
     $88 = $87 & $82;
     $89 = HEAP8[$41>>0]|0;
     $90 = $89&255;
     $91 = $88 >>> $90;
     $92 = (($86) + ($91)|0);
     $93 = HEAP8[$42>>0]|0;
     $94 = $93&255;
     $95 = (79212 + ($94<<2)|0);
     $96 = HEAP32[$95>>2]|0;
     $97 = HEAP32[$43>>2]|0;
     $98 = $97 & $82;
     $99 = HEAP8[$44>>0]|0;
     $100 = $99&255;
     $101 = $98 >>> $100;
     $102 = (($96) + ($101)|0);
     $103 = HEAP8[$45>>0]|0;
     $104 = $103&255;
     $105 = (79212 + ($104<<2)|0);
     $106 = HEAP32[$105>>2]|0;
     $107 = HEAP32[$46>>2]|0;
     $108 = $107 & $82;
     $109 = HEAP8[$47>>0]|0;
     $110 = $109&255;
     $111 = $108 >>> $110;
     $112 = (($106) + ($111)|0);
     $$0975$shrunk$ph$in = $92;$$0979$shrunk$ph$in = $102;$$sink = $112;
     label = 11;
     break;
    }
    case 3:  {
     $113 = HEAP8[$41>>0]|0;
     $div1050 = ($113&255) >>> 3;
     $114 = $div1050&255;
     $115 = (($$1) + ($114)|0);
     $116 = HEAP8[$44>>0]|0;
     $div1051 = ($116&255) >>> 3;
     $117 = $div1051&255;
     $118 = (($$1) + ($117)|0);
     $119 = HEAP8[$47>>0]|0;
     $div1052 = ($119&255) >>> 3;
     $120 = $div1052&255;
     $121 = (($$1) + ($120)|0);
     $$0975$shrunk$ph$in = $115;$$0979$shrunk$ph$in = $118;$$sink = $121;
     label = 11;
     break;
    }
    case 4:  {
     $122 = HEAP32[$$1>>2]|0;
     $123 = HEAP8[$39>>0]|0;
     $124 = $123&255;
     $125 = (79212 + ($124<<2)|0);
     $126 = HEAP32[$125>>2]|0;
     $127 = HEAP32[$40>>2]|0;
     $128 = $127 & $122;
     $129 = HEAP8[$41>>0]|0;
     $130 = $129&255;
     $131 = $128 >>> $130;
     $132 = (($126) + ($131)|0);
     $133 = HEAP8[$42>>0]|0;
     $134 = $133&255;
     $135 = (79212 + ($134<<2)|0);
     $136 = HEAP32[$135>>2]|0;
     $137 = HEAP32[$43>>2]|0;
     $138 = $137 & $122;
     $139 = HEAP8[$44>>0]|0;
     $140 = $139&255;
     $141 = $138 >>> $140;
     $142 = (($136) + ($141)|0);
     $143 = HEAP8[$45>>0]|0;
     $144 = $143&255;
     $145 = (79212 + ($144<<2)|0);
     $146 = HEAP32[$145>>2]|0;
     $147 = HEAP32[$46>>2]|0;
     $148 = $147 & $122;
     $149 = HEAP8[$47>>0]|0;
     $150 = $149&255;
     $151 = $148 >>> $150;
     $152 = (($146) + ($151)|0);
     $$0975$shrunk$ph$in = $132;$$0979$shrunk$ph$in = $142;$$sink = $152;
     label = 11;
     break;
    }
    default: {
     $$0975$shrunk = 0;$$0979$shrunk = 0;$$0980$shrunk = 0;
    }
    }
    if ((label|0) == 11) {
     label = 0;
     $$0975$shrunk$ph = HEAP8[$$0975$shrunk$ph$in>>0]|0;
     $$0979$shrunk$ph = HEAP8[$$0979$shrunk$ph$in>>0]|0;
     $153 = HEAP8[$$sink>>0]|0;
     $$0975$shrunk = $$0975$shrunk$ph;$$0979$shrunk = $$0979$shrunk$ph;$$0980$shrunk = $153;
    }
    $$0975 = $$0975$shrunk&255;
    $$0979 = $$0979$shrunk&255;
    $$0980 = $$0980$shrunk&255;
    switch ($20<<24>>24) {
    case 1:  {
     $154 = HEAP8[$31>>0]|0;
     $155 = $154&255;
     $156 = $$0975 >>> $155;
     $157 = HEAP8[$32>>0]|0;
     $158 = $157&255;
     $159 = $156 << $158;
     $160 = HEAP8[$33>>0]|0;
     $161 = $160&255;
     $162 = $$0979 >>> $161;
     $163 = HEAP8[$34>>0]|0;
     $164 = $163&255;
     $165 = $162 << $164;
     $166 = $165 | $159;
     $167 = HEAP8[$35>>0]|0;
     $168 = $167&255;
     $169 = $$0980 >>> $168;
     $170 = HEAP8[$36>>0]|0;
     $171 = $170&255;
     $172 = $169 << $171;
     $173 = $166 | $172;
     $174 = HEAP8[$37>>0]|0;
     $175 = $174&255;
     $176 = $177 >>> $175;
     $178 = HEAP8[$38>>0]|0;
     $179 = $178&255;
     $180 = $176 << $179;
     $181 = $173 | $180;
     $182 = $181&255;
     HEAP8[$$1956>>0] = $182;
     break;
    }
    case 2:  {
     $183 = HEAP8[$31>>0]|0;
     $184 = $183&255;
     $185 = $$0975 >>> $184;
     $186 = HEAP8[$32>>0]|0;
     $187 = $186&255;
     $188 = $185 << $187;
     $189 = HEAP8[$33>>0]|0;
     $190 = $189&255;
     $191 = $$0979 >>> $190;
     $192 = HEAP8[$34>>0]|0;
     $193 = $192&255;
     $194 = $191 << $193;
     $195 = $194 | $188;
     $196 = HEAP8[$35>>0]|0;
     $197 = $196&255;
     $198 = $$0980 >>> $197;
     $199 = HEAP8[$36>>0]|0;
     $200 = $199&255;
     $201 = $198 << $200;
     $202 = $195 | $201;
     $203 = HEAP8[$37>>0]|0;
     $204 = $203&255;
     $205 = $177 >>> $204;
     $206 = HEAP8[$38>>0]|0;
     $207 = $206&255;
     $208 = $205 << $207;
     $209 = $202 | $208;
     $210 = $209&65535;
     HEAP16[$$1956>>1] = $210;
     break;
    }
    case 3:  {
     $211 = HEAP8[$32>>0]|0;
     $div1047 = ($211&255) >>> 3;
     $212 = $div1047&255;
     $213 = (($$1956) + ($212)|0);
     HEAP8[$213>>0] = $$0975$shrunk;
     $214 = HEAP8[$34>>0]|0;
     $div1048 = ($214&255) >>> 3;
     $215 = $div1048&255;
     $216 = (($$1956) + ($215)|0);
     HEAP8[$216>>0] = $$0979$shrunk;
     $217 = HEAP8[$36>>0]|0;
     $div1049 = ($217&255) >>> 3;
     $218 = $div1049&255;
     $219 = (($$1956) + ($218)|0);
     HEAP8[$219>>0] = $$0980$shrunk;
     break;
    }
    case 4:  {
     $220 = HEAP8[$31>>0]|0;
     $221 = $220&255;
     $222 = $$0975 >>> $221;
     $223 = HEAP8[$32>>0]|0;
     $224 = $223&255;
     $225 = $222 << $224;
     $226 = HEAP8[$33>>0]|0;
     $227 = $226&255;
     $228 = $$0979 >>> $227;
     $229 = HEAP8[$34>>0]|0;
     $230 = $229&255;
     $231 = $228 << $230;
     $232 = $231 | $225;
     $233 = HEAP8[$35>>0]|0;
     $234 = $233&255;
     $235 = $$0980 >>> $234;
     $236 = HEAP8[$36>>0]|0;
     $237 = $236&255;
     $238 = $235 << $237;
     $239 = $232 | $238;
     $240 = HEAP8[$37>>0]|0;
     $241 = $240&255;
     $242 = $177 >>> $241;
     $243 = HEAP8[$38>>0]|0;
     $244 = $243&255;
     $245 = $242 << $244;
     $246 = $239 | $245;
     HEAP32[$$1956>>2] = $246;
     break;
    }
    default: {
    }
    }
    $247 = (($$1956) + ($21)|0);
    $248 = (($$1) + ($16)|0);
    $$1968 = $$0967;$$2 = $248;$$2957 = $247;
    label = 18;
    continue;
   }
   else if ((label|0) == 18) {
    label = 0;
    switch ($15<<24>>24) {
    case 1:  {
     $249 = HEAP8[$$2>>0]|0;
     $250 = $249&255;
     $251 = HEAP8[$39>>0]|0;
     $252 = $251&255;
     $253 = (79212 + ($252<<2)|0);
     $254 = HEAP32[$253>>2]|0;
     $255 = HEAP32[$40>>2]|0;
     $256 = $255 & $250;
     $257 = HEAP8[$41>>0]|0;
     $258 = $257&255;
     $259 = $256 >>> $258;
     $260 = (($254) + ($259)|0);
     $261 = HEAP8[$42>>0]|0;
     $262 = $261&255;
     $263 = (79212 + ($262<<2)|0);
     $264 = HEAP32[$263>>2]|0;
     $265 = HEAP32[$43>>2]|0;
     $266 = $265 & $250;
     $267 = HEAP8[$44>>0]|0;
     $268 = $267&255;
     $269 = $266 >>> $268;
     $270 = (($264) + ($269)|0);
     $271 = HEAP8[$45>>0]|0;
     $272 = $271&255;
     $273 = (79212 + ($272<<2)|0);
     $274 = HEAP32[$273>>2]|0;
     $275 = HEAP32[$46>>2]|0;
     $276 = $275 & $250;
     $277 = HEAP8[$47>>0]|0;
     $278 = $277&255;
     $279 = $276 >>> $278;
     $280 = (($274) + ($279)|0);
     $$0984$shrunk$ph$in = $260;$$0985$shrunk$ph$in = $270;$$sink1060 = $280;
     label = 23;
     break;
    }
    case 2:  {
     $281 = HEAP16[$$2>>1]|0;
     $282 = $281&65535;
     $283 = HEAP8[$39>>0]|0;
     $284 = $283&255;
     $285 = (79212 + ($284<<2)|0);
     $286 = HEAP32[$285>>2]|0;
     $287 = HEAP32[$40>>2]|0;
     $288 = $287 & $282;
     $289 = HEAP8[$41>>0]|0;
     $290 = $289&255;
     $291 = $288 >>> $290;
     $292 = (($286) + ($291)|0);
     $293 = HEAP8[$42>>0]|0;
     $294 = $293&255;
     $295 = (79212 + ($294<<2)|0);
     $296 = HEAP32[$295>>2]|0;
     $297 = HEAP32[$43>>2]|0;
     $298 = $297 & $282;
     $299 = HEAP8[$44>>0]|0;
     $300 = $299&255;
     $301 = $298 >>> $300;
     $302 = (($296) + ($301)|0);
     $303 = HEAP8[$45>>0]|0;
     $304 = $303&255;
     $305 = (79212 + ($304<<2)|0);
     $306 = HEAP32[$305>>2]|0;
     $307 = HEAP32[$46>>2]|0;
     $308 = $307 & $282;
     $309 = HEAP8[$47>>0]|0;
     $310 = $309&255;
     $311 = $308 >>> $310;
     $312 = (($306) + ($311)|0);
     $$0984$shrunk$ph$in = $292;$$0985$shrunk$ph$in = $302;$$sink1060 = $312;
     label = 23;
     break;
    }
    case 3:  {
     $313 = HEAP8[$41>>0]|0;
     $div1044 = ($313&255) >>> 3;
     $314 = $div1044&255;
     $315 = (($$2) + ($314)|0);
     $316 = HEAP8[$44>>0]|0;
     $div1045 = ($316&255) >>> 3;
     $317 = $div1045&255;
     $318 = (($$2) + ($317)|0);
     $319 = HEAP8[$47>>0]|0;
     $div1046 = ($319&255) >>> 3;
     $320 = $div1046&255;
     $321 = (($$2) + ($320)|0);
     $$0984$shrunk$ph$in = $315;$$0985$shrunk$ph$in = $318;$$sink1060 = $321;
     label = 23;
     break;
    }
    case 4:  {
     $322 = HEAP32[$$2>>2]|0;
     $323 = HEAP8[$39>>0]|0;
     $324 = $323&255;
     $325 = (79212 + ($324<<2)|0);
     $326 = HEAP32[$325>>2]|0;
     $327 = HEAP32[$40>>2]|0;
     $328 = $327 & $322;
     $329 = HEAP8[$41>>0]|0;
     $330 = $329&255;
     $331 = $328 >>> $330;
     $332 = (($326) + ($331)|0);
     $333 = HEAP8[$42>>0]|0;
     $334 = $333&255;
     $335 = (79212 + ($334<<2)|0);
     $336 = HEAP32[$335>>2]|0;
     $337 = HEAP32[$43>>2]|0;
     $338 = $337 & $322;
     $339 = HEAP8[$44>>0]|0;
     $340 = $339&255;
     $341 = $338 >>> $340;
     $342 = (($336) + ($341)|0);
     $343 = HEAP8[$45>>0]|0;
     $344 = $343&255;
     $345 = (79212 + ($344<<2)|0);
     $346 = HEAP32[$345>>2]|0;
     $347 = HEAP32[$46>>2]|0;
     $348 = $347 & $322;
     $349 = HEAP8[$47>>0]|0;
     $350 = $349&255;
     $351 = $348 >>> $350;
     $352 = (($346) + ($351)|0);
     $$0984$shrunk$ph$in = $332;$$0985$shrunk$ph$in = $342;$$sink1060 = $352;
     label = 23;
     break;
    }
    default: {
     $$0984$shrunk = 0;$$0985$shrunk = 0;$$0986$shrunk = 0;
    }
    }
    if ((label|0) == 23) {
     label = 0;
     $$0984$shrunk$ph = HEAP8[$$0984$shrunk$ph$in>>0]|0;
     $$0985$shrunk$ph = HEAP8[$$0985$shrunk$ph$in>>0]|0;
     $353 = HEAP8[$$sink1060>>0]|0;
     $$0984$shrunk = $$0984$shrunk$ph;$$0985$shrunk = $$0985$shrunk$ph;$$0986$shrunk = $353;
    }
    $$0984 = $$0984$shrunk&255;
    $$0985 = $$0985$shrunk&255;
    $$0986 = $$0986$shrunk&255;
    switch ($20<<24>>24) {
    case 1:  {
     $354 = HEAP8[$31>>0]|0;
     $355 = $354&255;
     $356 = $$0984 >>> $355;
     $357 = HEAP8[$32>>0]|0;
     $358 = $357&255;
     $359 = $356 << $358;
     $360 = HEAP8[$33>>0]|0;
     $361 = $360&255;
     $362 = $$0985 >>> $361;
     $363 = HEAP8[$34>>0]|0;
     $364 = $363&255;
     $365 = $362 << $364;
     $366 = $365 | $359;
     $367 = HEAP8[$35>>0]|0;
     $368 = $367&255;
     $369 = $$0986 >>> $368;
     $370 = HEAP8[$36>>0]|0;
     $371 = $370&255;
     $372 = $369 << $371;
     $373 = $366 | $372;
     $374 = HEAP8[$37>>0]|0;
     $375 = $374&255;
     $376 = $177 >>> $375;
     $377 = HEAP8[$38>>0]|0;
     $378 = $377&255;
     $379 = $376 << $378;
     $380 = $373 | $379;
     $381 = $380&255;
     HEAP8[$$2957>>0] = $381;
     break;
    }
    case 2:  {
     $382 = HEAP8[$31>>0]|0;
     $383 = $382&255;
     $384 = $$0984 >>> $383;
     $385 = HEAP8[$32>>0]|0;
     $386 = $385&255;
     $387 = $384 << $386;
     $388 = HEAP8[$33>>0]|0;
     $389 = $388&255;
     $390 = $$0985 >>> $389;
     $391 = HEAP8[$34>>0]|0;
     $392 = $391&255;
     $393 = $390 << $392;
     $394 = $393 | $387;
     $395 = HEAP8[$35>>0]|0;
     $396 = $395&255;
     $397 = $$0986 >>> $396;
     $398 = HEAP8[$36>>0]|0;
     $399 = $398&255;
     $400 = $397 << $399;
     $401 = $394 | $400;
     $402 = HEAP8[$37>>0]|0;
     $403 = $402&255;
     $404 = $177 >>> $403;
     $405 = HEAP8[$38>>0]|0;
     $406 = $405&255;
     $407 = $404 << $406;
     $408 = $401 | $407;
     $409 = $408&65535;
     HEAP16[$$2957>>1] = $409;
     break;
    }
    case 3:  {
     $410 = HEAP8[$32>>0]|0;
     $div1041 = ($410&255) >>> 3;
     $411 = $div1041&255;
     $412 = (($$2957) + ($411)|0);
     HEAP8[$412>>0] = $$0984$shrunk;
     $413 = HEAP8[$34>>0]|0;
     $div1042 = ($413&255) >>> 3;
     $414 = $div1042&255;
     $415 = (($$2957) + ($414)|0);
     HEAP8[$415>>0] = $$0985$shrunk;
     $416 = HEAP8[$36>>0]|0;
     $div1043 = ($416&255) >>> 3;
     $417 = $div1043&255;
     $418 = (($$2957) + ($417)|0);
     HEAP8[$418>>0] = $$0986$shrunk;
     break;
    }
    case 4:  {
     $419 = HEAP8[$31>>0]|0;
     $420 = $419&255;
     $421 = $$0984 >>> $420;
     $422 = HEAP8[$32>>0]|0;
     $423 = $422&255;
     $424 = $421 << $423;
     $425 = HEAP8[$33>>0]|0;
     $426 = $425&255;
     $427 = $$0985 >>> $426;
     $428 = HEAP8[$34>>0]|0;
     $429 = $428&255;
     $430 = $427 << $429;
     $431 = $430 | $424;
     $432 = HEAP8[$35>>0]|0;
     $433 = $432&255;
     $434 = $$0986 >>> $433;
     $435 = HEAP8[$36>>0]|0;
     $436 = $435&255;
     $437 = $434 << $436;
     $438 = $431 | $437;
     $439 = HEAP8[$37>>0]|0;
     $440 = $439&255;
     $441 = $177 >>> $440;
     $442 = HEAP8[$38>>0]|0;
     $443 = $442&255;
     $444 = $441 << $443;
     $445 = $438 | $444;
     HEAP32[$$2957>>2] = $445;
     break;
    }
    default: {
    }
    }
    $446 = (($$2957) + ($21)|0);
    $447 = (($$2) + ($16)|0);
    $$2969 = $$1968;$$3 = $447;$$3958 = $446;
    label = 30;
    continue;
   }
   else if ((label|0) == 30) {
    label = 0;
    switch ($15<<24>>24) {
    case 1:  {
     $448 = HEAP8[$$3>>0]|0;
     $449 = $448&255;
     $450 = HEAP8[$39>>0]|0;
     $451 = $450&255;
     $452 = (79212 + ($451<<2)|0);
     $453 = HEAP32[$452>>2]|0;
     $454 = HEAP32[$40>>2]|0;
     $455 = $454 & $449;
     $456 = HEAP8[$41>>0]|0;
     $457 = $456&255;
     $458 = $455 >>> $457;
     $459 = (($453) + ($458)|0);
     $460 = HEAP8[$42>>0]|0;
     $461 = $460&255;
     $462 = (79212 + ($461<<2)|0);
     $463 = HEAP32[$462>>2]|0;
     $464 = HEAP32[$43>>2]|0;
     $465 = $464 & $449;
     $466 = HEAP8[$44>>0]|0;
     $467 = $466&255;
     $468 = $465 >>> $467;
     $469 = (($463) + ($468)|0);
     $470 = HEAP8[$45>>0]|0;
     $471 = $470&255;
     $472 = (79212 + ($471<<2)|0);
     $473 = HEAP32[$472>>2]|0;
     $474 = HEAP32[$46>>2]|0;
     $475 = $474 & $449;
     $476 = HEAP8[$47>>0]|0;
     $477 = $476&255;
     $478 = $475 >>> $477;
     $479 = (($473) + ($478)|0);
     $$0990$shrunk$ph$in = $459;$$0991$shrunk$ph$in = $469;$$sink1062 = $479;
     label = 35;
     break;
    }
    case 2:  {
     $480 = HEAP16[$$3>>1]|0;
     $481 = $480&65535;
     $482 = HEAP8[$39>>0]|0;
     $483 = $482&255;
     $484 = (79212 + ($483<<2)|0);
     $485 = HEAP32[$484>>2]|0;
     $486 = HEAP32[$40>>2]|0;
     $487 = $486 & $481;
     $488 = HEAP8[$41>>0]|0;
     $489 = $488&255;
     $490 = $487 >>> $489;
     $491 = (($485) + ($490)|0);
     $492 = HEAP8[$42>>0]|0;
     $493 = $492&255;
     $494 = (79212 + ($493<<2)|0);
     $495 = HEAP32[$494>>2]|0;
     $496 = HEAP32[$43>>2]|0;
     $497 = $496 & $481;
     $498 = HEAP8[$44>>0]|0;
     $499 = $498&255;
     $500 = $497 >>> $499;
     $501 = (($495) + ($500)|0);
     $502 = HEAP8[$45>>0]|0;
     $503 = $502&255;
     $504 = (79212 + ($503<<2)|0);
     $505 = HEAP32[$504>>2]|0;
     $506 = HEAP32[$46>>2]|0;
     $507 = $506 & $481;
     $508 = HEAP8[$47>>0]|0;
     $509 = $508&255;
     $510 = $507 >>> $509;
     $511 = (($505) + ($510)|0);
     $$0990$shrunk$ph$in = $491;$$0991$shrunk$ph$in = $501;$$sink1062 = $511;
     label = 35;
     break;
    }
    case 3:  {
     $512 = HEAP8[$41>>0]|0;
     $div1038 = ($512&255) >>> 3;
     $513 = $div1038&255;
     $514 = (($$3) + ($513)|0);
     $515 = HEAP8[$44>>0]|0;
     $div1039 = ($515&255) >>> 3;
     $516 = $div1039&255;
     $517 = (($$3) + ($516)|0);
     $518 = HEAP8[$47>>0]|0;
     $div1040 = ($518&255) >>> 3;
     $519 = $div1040&255;
     $520 = (($$3) + ($519)|0);
     $$0990$shrunk$ph$in = $514;$$0991$shrunk$ph$in = $517;$$sink1062 = $520;
     label = 35;
     break;
    }
    case 4:  {
     $521 = HEAP32[$$3>>2]|0;
     $522 = HEAP8[$39>>0]|0;
     $523 = $522&255;
     $524 = (79212 + ($523<<2)|0);
     $525 = HEAP32[$524>>2]|0;
     $526 = HEAP32[$40>>2]|0;
     $527 = $526 & $521;
     $528 = HEAP8[$41>>0]|0;
     $529 = $528&255;
     $530 = $527 >>> $529;
     $531 = (($525) + ($530)|0);
     $532 = HEAP8[$42>>0]|0;
     $533 = $532&255;
     $534 = (79212 + ($533<<2)|0);
     $535 = HEAP32[$534>>2]|0;
     $536 = HEAP32[$43>>2]|0;
     $537 = $536 & $521;
     $538 = HEAP8[$44>>0]|0;
     $539 = $538&255;
     $540 = $537 >>> $539;
     $541 = (($535) + ($540)|0);
     $542 = HEAP8[$45>>0]|0;
     $543 = $542&255;
     $544 = (79212 + ($543<<2)|0);
     $545 = HEAP32[$544>>2]|0;
     $546 = HEAP32[$46>>2]|0;
     $547 = $546 & $521;
     $548 = HEAP8[$47>>0]|0;
     $549 = $548&255;
     $550 = $547 >>> $549;
     $551 = (($545) + ($550)|0);
     $$0990$shrunk$ph$in = $531;$$0991$shrunk$ph$in = $541;$$sink1062 = $551;
     label = 35;
     break;
    }
    default: {
     $$0990$shrunk = 0;$$0991$shrunk = 0;$$0995$shrunk = 0;
    }
    }
    if ((label|0) == 35) {
     label = 0;
     $$0990$shrunk$ph = HEAP8[$$0990$shrunk$ph$in>>0]|0;
     $$0991$shrunk$ph = HEAP8[$$0991$shrunk$ph$in>>0]|0;
     $552 = HEAP8[$$sink1062>>0]|0;
     $$0990$shrunk = $$0990$shrunk$ph;$$0991$shrunk = $$0991$shrunk$ph;$$0995$shrunk = $552;
    }
    $$0990 = $$0990$shrunk&255;
    $$0991 = $$0991$shrunk&255;
    $$0995 = $$0995$shrunk&255;
    switch ($20<<24>>24) {
    case 1:  {
     $553 = HEAP8[$31>>0]|0;
     $554 = $553&255;
     $555 = $$0990 >>> $554;
     $556 = HEAP8[$32>>0]|0;
     $557 = $556&255;
     $558 = $555 << $557;
     $559 = HEAP8[$33>>0]|0;
     $560 = $559&255;
     $561 = $$0991 >>> $560;
     $562 = HEAP8[$34>>0]|0;
     $563 = $562&255;
     $564 = $561 << $563;
     $565 = $564 | $558;
     $566 = HEAP8[$35>>0]|0;
     $567 = $566&255;
     $568 = $$0995 >>> $567;
     $569 = HEAP8[$36>>0]|0;
     $570 = $569&255;
     $571 = $568 << $570;
     $572 = $565 | $571;
     $573 = HEAP8[$37>>0]|0;
     $574 = $573&255;
     $575 = $177 >>> $574;
     $576 = HEAP8[$38>>0]|0;
     $577 = $576&255;
     $578 = $575 << $577;
     $579 = $572 | $578;
     $580 = $579&255;
     HEAP8[$$3958>>0] = $580;
     break;
    }
    case 2:  {
     $581 = HEAP8[$31>>0]|0;
     $582 = $581&255;
     $583 = $$0990 >>> $582;
     $584 = HEAP8[$32>>0]|0;
     $585 = $584&255;
     $586 = $583 << $585;
     $587 = HEAP8[$33>>0]|0;
     $588 = $587&255;
     $589 = $$0991 >>> $588;
     $590 = HEAP8[$34>>0]|0;
     $591 = $590&255;
     $592 = $589 << $591;
     $593 = $592 | $586;
     $594 = HEAP8[$35>>0]|0;
     $595 = $594&255;
     $596 = $$0995 >>> $595;
     $597 = HEAP8[$36>>0]|0;
     $598 = $597&255;
     $599 = $596 << $598;
     $600 = $593 | $599;
     $601 = HEAP8[$37>>0]|0;
     $602 = $601&255;
     $603 = $177 >>> $602;
     $604 = HEAP8[$38>>0]|0;
     $605 = $604&255;
     $606 = $603 << $605;
     $607 = $600 | $606;
     $608 = $607&65535;
     HEAP16[$$3958>>1] = $608;
     break;
    }
    case 3:  {
     $609 = HEAP8[$32>>0]|0;
     $div1035 = ($609&255) >>> 3;
     $610 = $div1035&255;
     $611 = (($$3958) + ($610)|0);
     HEAP8[$611>>0] = $$0990$shrunk;
     $612 = HEAP8[$34>>0]|0;
     $div1036 = ($612&255) >>> 3;
     $613 = $div1036&255;
     $614 = (($$3958) + ($613)|0);
     HEAP8[$614>>0] = $$0991$shrunk;
     $615 = HEAP8[$36>>0]|0;
     $div1037 = ($615&255) >>> 3;
     $616 = $div1037&255;
     $617 = (($$3958) + ($616)|0);
     HEAP8[$617>>0] = $$0995$shrunk;
     break;
    }
    case 4:  {
     $618 = HEAP8[$31>>0]|0;
     $619 = $618&255;
     $620 = $$0990 >>> $619;
     $621 = HEAP8[$32>>0]|0;
     $622 = $621&255;
     $623 = $620 << $622;
     $624 = HEAP8[$33>>0]|0;
     $625 = $624&255;
     $626 = $$0991 >>> $625;
     $627 = HEAP8[$34>>0]|0;
     $628 = $627&255;
     $629 = $626 << $628;
     $630 = $629 | $623;
     $631 = HEAP8[$35>>0]|0;
     $632 = $631&255;
     $633 = $$0995 >>> $632;
     $634 = HEAP8[$36>>0]|0;
     $635 = $634&255;
     $636 = $633 << $635;
     $637 = $630 | $636;
     $638 = HEAP8[$37>>0]|0;
     $639 = $638&255;
     $640 = $177 >>> $639;
     $641 = HEAP8[$38>>0]|0;
     $642 = $641&255;
     $643 = $640 << $642;
     $644 = $637 | $643;
     HEAP32[$$3958>>2] = $644;
     break;
    }
    default: {
    }
    }
    $645 = (($$3958) + ($21)|0);
    $646 = (($$3) + ($16)|0);
    $$3970 = $$2969;$$4 = $646;$$4959 = $645;
    label = 42;
    continue;
   }
   else if ((label|0) == 42) {
    label = 0;
    switch ($15<<24>>24) {
    case 1:  {
     $647 = HEAP8[$$4>>0]|0;
     $648 = $647&255;
     $649 = HEAP8[$39>>0]|0;
     $650 = $649&255;
     $651 = (79212 + ($650<<2)|0);
     $652 = HEAP32[$651>>2]|0;
     $653 = HEAP32[$40>>2]|0;
     $654 = $653 & $648;
     $655 = HEAP8[$41>>0]|0;
     $656 = $655&255;
     $657 = $654 >>> $656;
     $658 = (($652) + ($657)|0);
     $659 = HEAP8[$42>>0]|0;
     $660 = $659&255;
     $661 = (79212 + ($660<<2)|0);
     $662 = HEAP32[$661>>2]|0;
     $663 = HEAP32[$43>>2]|0;
     $664 = $663 & $648;
     $665 = HEAP8[$44>>0]|0;
     $666 = $665&255;
     $667 = $664 >>> $666;
     $668 = (($662) + ($667)|0);
     $669 = HEAP8[$45>>0]|0;
     $670 = $669&255;
     $671 = (79212 + ($670<<2)|0);
     $672 = HEAP32[$671>>2]|0;
     $673 = HEAP32[$46>>2]|0;
     $674 = $673 & $648;
     $675 = HEAP8[$47>>0]|0;
     $676 = $675&255;
     $677 = $674 >>> $676;
     $678 = (($672) + ($677)|0);
     $$0993$shrunk$ph$in = $668;$$0994$shrunk$ph$in = $658;$$sink1064 = $678;
     label = 47;
     break;
    }
    case 2:  {
     $679 = HEAP16[$$4>>1]|0;
     $680 = $679&65535;
     $681 = HEAP8[$39>>0]|0;
     $682 = $681&255;
     $683 = (79212 + ($682<<2)|0);
     $684 = HEAP32[$683>>2]|0;
     $685 = HEAP32[$40>>2]|0;
     $686 = $685 & $680;
     $687 = HEAP8[$41>>0]|0;
     $688 = $687&255;
     $689 = $686 >>> $688;
     $690 = (($684) + ($689)|0);
     $691 = HEAP8[$42>>0]|0;
     $692 = $691&255;
     $693 = (79212 + ($692<<2)|0);
     $694 = HEAP32[$693>>2]|0;
     $695 = HEAP32[$43>>2]|0;
     $696 = $695 & $680;
     $697 = HEAP8[$44>>0]|0;
     $698 = $697&255;
     $699 = $696 >>> $698;
     $700 = (($694) + ($699)|0);
     $701 = HEAP8[$45>>0]|0;
     $702 = $701&255;
     $703 = (79212 + ($702<<2)|0);
     $704 = HEAP32[$703>>2]|0;
     $705 = HEAP32[$46>>2]|0;
     $706 = $705 & $680;
     $707 = HEAP8[$47>>0]|0;
     $708 = $707&255;
     $709 = $706 >>> $708;
     $710 = (($704) + ($709)|0);
     $$0993$shrunk$ph$in = $700;$$0994$shrunk$ph$in = $690;$$sink1064 = $710;
     label = 47;
     break;
    }
    case 3:  {
     $711 = HEAP8[$41>>0]|0;
     $div1032 = ($711&255) >>> 3;
     $712 = $div1032&255;
     $713 = (($$4) + ($712)|0);
     $714 = HEAP8[$44>>0]|0;
     $div1033 = ($714&255) >>> 3;
     $715 = $div1033&255;
     $716 = (($$4) + ($715)|0);
     $717 = HEAP8[$47>>0]|0;
     $div1034 = ($717&255) >>> 3;
     $718 = $div1034&255;
     $719 = (($$4) + ($718)|0);
     $$0993$shrunk$ph$in = $716;$$0994$shrunk$ph$in = $713;$$sink1064 = $719;
     label = 47;
     break;
    }
    case 4:  {
     $720 = HEAP32[$$4>>2]|0;
     $721 = HEAP8[$39>>0]|0;
     $722 = $721&255;
     $723 = (79212 + ($722<<2)|0);
     $724 = HEAP32[$723>>2]|0;
     $725 = HEAP32[$40>>2]|0;
     $726 = $725 & $720;
     $727 = HEAP8[$41>>0]|0;
     $728 = $727&255;
     $729 = $726 >>> $728;
     $730 = (($724) + ($729)|0);
     $731 = HEAP8[$42>>0]|0;
     $732 = $731&255;
     $733 = (79212 + ($732<<2)|0);
     $734 = HEAP32[$733>>2]|0;
     $735 = HEAP32[$43>>2]|0;
     $736 = $735 & $720;
     $737 = HEAP8[$44>>0]|0;
     $738 = $737&255;
     $739 = $736 >>> $738;
     $740 = (($734) + ($739)|0);
     $741 = HEAP8[$45>>0]|0;
     $742 = $741&255;
     $743 = (79212 + ($742<<2)|0);
     $744 = HEAP32[$743>>2]|0;
     $745 = HEAP32[$46>>2]|0;
     $746 = $745 & $720;
     $747 = HEAP8[$47>>0]|0;
     $748 = $747&255;
     $749 = $746 >>> $748;
     $750 = (($744) + ($749)|0);
     $$0993$shrunk$ph$in = $740;$$0994$shrunk$ph$in = $730;$$sink1064 = $750;
     label = 47;
     break;
    }
    default: {
     $$0992$shrunk = 0;$$0993$shrunk = 0;$$0994$shrunk = 0;
    }
    }
    if ((label|0) == 47) {
     label = 0;
     $$0993$shrunk$ph = HEAP8[$$0993$shrunk$ph$in>>0]|0;
     $$0994$shrunk$ph = HEAP8[$$0994$shrunk$ph$in>>0]|0;
     $751 = HEAP8[$$sink1064>>0]|0;
     $$0992$shrunk = $751;$$0993$shrunk = $$0993$shrunk$ph;$$0994$shrunk = $$0994$shrunk$ph;
    }
    $$0992 = $$0992$shrunk&255;
    $$0993 = $$0993$shrunk&255;
    $$0994 = $$0994$shrunk&255;
    switch ($20<<24>>24) {
    case 1:  {
     $752 = HEAP8[$31>>0]|0;
     $753 = $752&255;
     $754 = $$0994 >>> $753;
     $755 = HEAP8[$32>>0]|0;
     $756 = $755&255;
     $757 = $754 << $756;
     $758 = HEAP8[$33>>0]|0;
     $759 = $758&255;
     $760 = $$0993 >>> $759;
     $761 = HEAP8[$34>>0]|0;
     $762 = $761&255;
     $763 = $760 << $762;
     $764 = $763 | $757;
     $765 = HEAP8[$35>>0]|0;
     $766 = $765&255;
     $767 = $$0992 >>> $766;
     $768 = HEAP8[$36>>0]|0;
     $769 = $768&255;
     $770 = $767 << $769;
     $771 = $764 | $770;
     $772 = HEAP8[$37>>0]|0;
     $773 = $772&255;
     $774 = $177 >>> $773;
     $775 = HEAP8[$38>>0]|0;
     $776 = $775&255;
     $777 = $774 << $776;
     $778 = $771 | $777;
     $779 = $778&255;
     HEAP8[$$4959>>0] = $779;
     break;
    }
    case 2:  {
     $780 = HEAP8[$31>>0]|0;
     $781 = $780&255;
     $782 = $$0994 >>> $781;
     $783 = HEAP8[$32>>0]|0;
     $784 = $783&255;
     $785 = $782 << $784;
     $786 = HEAP8[$33>>0]|0;
     $787 = $786&255;
     $788 = $$0993 >>> $787;
     $789 = HEAP8[$34>>0]|0;
     $790 = $789&255;
     $791 = $788 << $790;
     $792 = $791 | $785;
     $793 = HEAP8[$35>>0]|0;
     $794 = $793&255;
     $795 = $$0992 >>> $794;
     $796 = HEAP8[$36>>0]|0;
     $797 = $796&255;
     $798 = $795 << $797;
     $799 = $792 | $798;
     $800 = HEAP8[$37>>0]|0;
     $801 = $800&255;
     $802 = $177 >>> $801;
     $803 = HEAP8[$38>>0]|0;
     $804 = $803&255;
     $805 = $802 << $804;
     $806 = $799 | $805;
     $807 = $806&65535;
     HEAP16[$$4959>>1] = $807;
     break;
    }
    case 3:  {
     $808 = HEAP8[$32>>0]|0;
     $div1029 = ($808&255) >>> 3;
     $809 = $div1029&255;
     $810 = (($$4959) + ($809)|0);
     HEAP8[$810>>0] = $$0994$shrunk;
     $811 = HEAP8[$34>>0]|0;
     $div1030 = ($811&255) >>> 3;
     $812 = $div1030&255;
     $813 = (($$4959) + ($812)|0);
     HEAP8[$813>>0] = $$0993$shrunk;
     $814 = HEAP8[$36>>0]|0;
     $div1031 = ($814&255) >>> 3;
     $815 = $div1031&255;
     $816 = (($$4959) + ($815)|0);
     HEAP8[$816>>0] = $$0992$shrunk;
     break;
    }
    case 4:  {
     $817 = HEAP8[$31>>0]|0;
     $818 = $817&255;
     $819 = $$0994 >>> $818;
     $820 = HEAP8[$32>>0]|0;
     $821 = $820&255;
     $822 = $819 << $821;
     $823 = HEAP8[$33>>0]|0;
     $824 = $823&255;
     $825 = $$0993 >>> $824;
     $826 = HEAP8[$34>>0]|0;
     $827 = $826&255;
     $828 = $825 << $827;
     $829 = $828 | $822;
     $830 = HEAP8[$35>>0]|0;
     $831 = $830&255;
     $832 = $$0992 >>> $831;
     $833 = HEAP8[$36>>0]|0;
     $834 = $833&255;
     $835 = $832 << $834;
     $836 = $829 | $835;
     $837 = HEAP8[$37>>0]|0;
     $838 = $837&255;
     $839 = $177 >>> $838;
     $840 = HEAP8[$38>>0]|0;
     $841 = $840&255;
     $842 = $839 << $841;
     $843 = $836 | $842;
     HEAP32[$$4959>>2] = $843;
     break;
    }
    default: {
    }
    }
    $844 = (($$4959) + ($21)|0);
    $845 = (($$4) + ($16)|0);
    $$4971 = $$3970;$$5 = $845;$$5960 = $844;
    label = 54;
    continue;
   }
   else if ((label|0) == 54) {
    label = 0;
    switch ($15<<24>>24) {
    case 1:  {
     $846 = HEAP8[$$5>>0]|0;
     $847 = $846&255;
     $848 = HEAP8[$39>>0]|0;
     $849 = $848&255;
     $850 = (79212 + ($849<<2)|0);
     $851 = HEAP32[$850>>2]|0;
     $852 = HEAP32[$40>>2]|0;
     $853 = $852 & $847;
     $854 = HEAP8[$41>>0]|0;
     $855 = $854&255;
     $856 = $853 >>> $855;
     $857 = (($851) + ($856)|0);
     $858 = HEAP8[$42>>0]|0;
     $859 = $858&255;
     $860 = (79212 + ($859<<2)|0);
     $861 = HEAP32[$860>>2]|0;
     $862 = HEAP32[$43>>2]|0;
     $863 = $862 & $847;
     $864 = HEAP8[$44>>0]|0;
     $865 = $864&255;
     $866 = $863 >>> $865;
     $867 = (($861) + ($866)|0);
     $868 = HEAP8[$45>>0]|0;
     $869 = $868&255;
     $870 = (79212 + ($869<<2)|0);
     $871 = HEAP32[$870>>2]|0;
     $872 = HEAP32[$46>>2]|0;
     $873 = $872 & $847;
     $874 = HEAP8[$47>>0]|0;
     $875 = $874&255;
     $876 = $873 >>> $875;
     $877 = (($871) + ($876)|0);
     $$0988$shrunk$ph$in = $867;$$0989$shrunk$ph$in = $857;$$sink1066 = $877;
     label = 59;
     break;
    }
    case 2:  {
     $878 = HEAP16[$$5>>1]|0;
     $879 = $878&65535;
     $880 = HEAP8[$39>>0]|0;
     $881 = $880&255;
     $882 = (79212 + ($881<<2)|0);
     $883 = HEAP32[$882>>2]|0;
     $884 = HEAP32[$40>>2]|0;
     $885 = $884 & $879;
     $886 = HEAP8[$41>>0]|0;
     $887 = $886&255;
     $888 = $885 >>> $887;
     $889 = (($883) + ($888)|0);
     $890 = HEAP8[$42>>0]|0;
     $891 = $890&255;
     $892 = (79212 + ($891<<2)|0);
     $893 = HEAP32[$892>>2]|0;
     $894 = HEAP32[$43>>2]|0;
     $895 = $894 & $879;
     $896 = HEAP8[$44>>0]|0;
     $897 = $896&255;
     $898 = $895 >>> $897;
     $899 = (($893) + ($898)|0);
     $900 = HEAP8[$45>>0]|0;
     $901 = $900&255;
     $902 = (79212 + ($901<<2)|0);
     $903 = HEAP32[$902>>2]|0;
     $904 = HEAP32[$46>>2]|0;
     $905 = $904 & $879;
     $906 = HEAP8[$47>>0]|0;
     $907 = $906&255;
     $908 = $905 >>> $907;
     $909 = (($903) + ($908)|0);
     $$0988$shrunk$ph$in = $899;$$0989$shrunk$ph$in = $889;$$sink1066 = $909;
     label = 59;
     break;
    }
    case 3:  {
     $910 = HEAP8[$41>>0]|0;
     $div1026 = ($910&255) >>> 3;
     $911 = $div1026&255;
     $912 = (($$5) + ($911)|0);
     $913 = HEAP8[$44>>0]|0;
     $div1027 = ($913&255) >>> 3;
     $914 = $div1027&255;
     $915 = (($$5) + ($914)|0);
     $916 = HEAP8[$47>>0]|0;
     $div1028 = ($916&255) >>> 3;
     $917 = $div1028&255;
     $918 = (($$5) + ($917)|0);
     $$0988$shrunk$ph$in = $915;$$0989$shrunk$ph$in = $912;$$sink1066 = $918;
     label = 59;
     break;
    }
    case 4:  {
     $919 = HEAP32[$$5>>2]|0;
     $920 = HEAP8[$39>>0]|0;
     $921 = $920&255;
     $922 = (79212 + ($921<<2)|0);
     $923 = HEAP32[$922>>2]|0;
     $924 = HEAP32[$40>>2]|0;
     $925 = $924 & $919;
     $926 = HEAP8[$41>>0]|0;
     $927 = $926&255;
     $928 = $925 >>> $927;
     $929 = (($923) + ($928)|0);
     $930 = HEAP8[$42>>0]|0;
     $931 = $930&255;
     $932 = (79212 + ($931<<2)|0);
     $933 = HEAP32[$932>>2]|0;
     $934 = HEAP32[$43>>2]|0;
     $935 = $934 & $919;
     $936 = HEAP8[$44>>0]|0;
     $937 = $936&255;
     $938 = $935 >>> $937;
     $939 = (($933) + ($938)|0);
     $940 = HEAP8[$45>>0]|0;
     $941 = $940&255;
     $942 = (79212 + ($941<<2)|0);
     $943 = HEAP32[$942>>2]|0;
     $944 = HEAP32[$46>>2]|0;
     $945 = $944 & $919;
     $946 = HEAP8[$47>>0]|0;
     $947 = $946&255;
     $948 = $945 >>> $947;
     $949 = (($943) + ($948)|0);
     $$0988$shrunk$ph$in = $939;$$0989$shrunk$ph$in = $929;$$sink1066 = $949;
     label = 59;
     break;
    }
    default: {
     $$0987$shrunk = 0;$$0988$shrunk = 0;$$0989$shrunk = 0;
    }
    }
    if ((label|0) == 59) {
     label = 0;
     $$0988$shrunk$ph = HEAP8[$$0988$shrunk$ph$in>>0]|0;
     $$0989$shrunk$ph = HEAP8[$$0989$shrunk$ph$in>>0]|0;
     $950 = HEAP8[$$sink1066>>0]|0;
     $$0987$shrunk = $950;$$0988$shrunk = $$0988$shrunk$ph;$$0989$shrunk = $$0989$shrunk$ph;
    }
    $$0987 = $$0987$shrunk&255;
    $$0988 = $$0988$shrunk&255;
    $$0989 = $$0989$shrunk&255;
    switch ($20<<24>>24) {
    case 1:  {
     $951 = HEAP8[$31>>0]|0;
     $952 = $951&255;
     $953 = $$0989 >>> $952;
     $954 = HEAP8[$32>>0]|0;
     $955 = $954&255;
     $956 = $953 << $955;
     $957 = HEAP8[$33>>0]|0;
     $958 = $957&255;
     $959 = $$0988 >>> $958;
     $960 = HEAP8[$34>>0]|0;
     $961 = $960&255;
     $962 = $959 << $961;
     $963 = $962 | $956;
     $964 = HEAP8[$35>>0]|0;
     $965 = $964&255;
     $966 = $$0987 >>> $965;
     $967 = HEAP8[$36>>0]|0;
     $968 = $967&255;
     $969 = $966 << $968;
     $970 = $963 | $969;
     $971 = HEAP8[$37>>0]|0;
     $972 = $971&255;
     $973 = $177 >>> $972;
     $974 = HEAP8[$38>>0]|0;
     $975 = $974&255;
     $976 = $973 << $975;
     $977 = $970 | $976;
     $978 = $977&255;
     HEAP8[$$5960>>0] = $978;
     break;
    }
    case 2:  {
     $979 = HEAP8[$31>>0]|0;
     $980 = $979&255;
     $981 = $$0989 >>> $980;
     $982 = HEAP8[$32>>0]|0;
     $983 = $982&255;
     $984 = $981 << $983;
     $985 = HEAP8[$33>>0]|0;
     $986 = $985&255;
     $987 = $$0988 >>> $986;
     $988 = HEAP8[$34>>0]|0;
     $989 = $988&255;
     $990 = $987 << $989;
     $991 = $990 | $984;
     $992 = HEAP8[$35>>0]|0;
     $993 = $992&255;
     $994 = $$0987 >>> $993;
     $995 = HEAP8[$36>>0]|0;
     $996 = $995&255;
     $997 = $994 << $996;
     $998 = $991 | $997;
     $999 = HEAP8[$37>>0]|0;
     $1000 = $999&255;
     $1001 = $177 >>> $1000;
     $1002 = HEAP8[$38>>0]|0;
     $1003 = $1002&255;
     $1004 = $1001 << $1003;
     $1005 = $998 | $1004;
     $1006 = $1005&65535;
     HEAP16[$$5960>>1] = $1006;
     break;
    }
    case 3:  {
     $1007 = HEAP8[$32>>0]|0;
     $div1023 = ($1007&255) >>> 3;
     $1008 = $div1023&255;
     $1009 = (($$5960) + ($1008)|0);
     HEAP8[$1009>>0] = $$0989$shrunk;
     $1010 = HEAP8[$34>>0]|0;
     $div1024 = ($1010&255) >>> 3;
     $1011 = $div1024&255;
     $1012 = (($$5960) + ($1011)|0);
     HEAP8[$1012>>0] = $$0988$shrunk;
     $1013 = HEAP8[$36>>0]|0;
     $div1025 = ($1013&255) >>> 3;
     $1014 = $div1025&255;
     $1015 = (($$5960) + ($1014)|0);
     HEAP8[$1015>>0] = $$0987$shrunk;
     break;
    }
    case 4:  {
     $1016 = HEAP8[$31>>0]|0;
     $1017 = $1016&255;
     $1018 = $$0989 >>> $1017;
     $1019 = HEAP8[$32>>0]|0;
     $1020 = $1019&255;
     $1021 = $1018 << $1020;
     $1022 = HEAP8[$33>>0]|0;
     $1023 = $1022&255;
     $1024 = $$0988 >>> $1023;
     $1025 = HEAP8[$34>>0]|0;
     $1026 = $1025&255;
     $1027 = $1024 << $1026;
     $1028 = $1027 | $1021;
     $1029 = HEAP8[$35>>0]|0;
     $1030 = $1029&255;
     $1031 = $$0987 >>> $1030;
     $1032 = HEAP8[$36>>0]|0;
     $1033 = $1032&255;
     $1034 = $1031 << $1033;
     $1035 = $1028 | $1034;
     $1036 = HEAP8[$37>>0]|0;
     $1037 = $1036&255;
     $1038 = $177 >>> $1037;
     $1039 = HEAP8[$38>>0]|0;
     $1040 = $1039&255;
     $1041 = $1038 << $1040;
     $1042 = $1035 | $1041;
     HEAP32[$$5960>>2] = $1042;
     break;
    }
    default: {
    }
    }
    $1043 = (($$5960) + ($21)|0);
    $1044 = (($$5) + ($16)|0);
    $$5972 = $$4971;$$6 = $1044;$$6961 = $1043;
    label = 66;
    continue;
   }
   else if ((label|0) == 66) {
    label = 0;
    switch ($15<<24>>24) {
    case 1:  {
     $1045 = HEAP8[$$6>>0]|0;
     $1046 = $1045&255;
     $1047 = HEAP8[$39>>0]|0;
     $1048 = $1047&255;
     $1049 = (79212 + ($1048<<2)|0);
     $1050 = HEAP32[$1049>>2]|0;
     $1051 = HEAP32[$40>>2]|0;
     $1052 = $1051 & $1046;
     $1053 = HEAP8[$41>>0]|0;
     $1054 = $1053&255;
     $1055 = $1052 >>> $1054;
     $1056 = (($1050) + ($1055)|0);
     $1057 = HEAP8[$42>>0]|0;
     $1058 = $1057&255;
     $1059 = (79212 + ($1058<<2)|0);
     $1060 = HEAP32[$1059>>2]|0;
     $1061 = HEAP32[$43>>2]|0;
     $1062 = $1061 & $1046;
     $1063 = HEAP8[$44>>0]|0;
     $1064 = $1063&255;
     $1065 = $1062 >>> $1064;
     $1066 = (($1060) + ($1065)|0);
     $1067 = HEAP8[$45>>0]|0;
     $1068 = $1067&255;
     $1069 = (79212 + ($1068<<2)|0);
     $1070 = HEAP32[$1069>>2]|0;
     $1071 = HEAP32[$46>>2]|0;
     $1072 = $1071 & $1046;
     $1073 = HEAP8[$47>>0]|0;
     $1074 = $1073&255;
     $1075 = $1072 >>> $1074;
     $1076 = (($1070) + ($1075)|0);
     $$0982$shrunk$ph$in = $1066;$$0983$shrunk$ph$in = $1056;$$sink1068 = $1076;
     label = 71;
     break;
    }
    case 2:  {
     $1077 = HEAP16[$$6>>1]|0;
     $1078 = $1077&65535;
     $1079 = HEAP8[$39>>0]|0;
     $1080 = $1079&255;
     $1081 = (79212 + ($1080<<2)|0);
     $1082 = HEAP32[$1081>>2]|0;
     $1083 = HEAP32[$40>>2]|0;
     $1084 = $1083 & $1078;
     $1085 = HEAP8[$41>>0]|0;
     $1086 = $1085&255;
     $1087 = $1084 >>> $1086;
     $1088 = (($1082) + ($1087)|0);
     $1089 = HEAP8[$42>>0]|0;
     $1090 = $1089&255;
     $1091 = (79212 + ($1090<<2)|0);
     $1092 = HEAP32[$1091>>2]|0;
     $1093 = HEAP32[$43>>2]|0;
     $1094 = $1093 & $1078;
     $1095 = HEAP8[$44>>0]|0;
     $1096 = $1095&255;
     $1097 = $1094 >>> $1096;
     $1098 = (($1092) + ($1097)|0);
     $1099 = HEAP8[$45>>0]|0;
     $1100 = $1099&255;
     $1101 = (79212 + ($1100<<2)|0);
     $1102 = HEAP32[$1101>>2]|0;
     $1103 = HEAP32[$46>>2]|0;
     $1104 = $1103 & $1078;
     $1105 = HEAP8[$47>>0]|0;
     $1106 = $1105&255;
     $1107 = $1104 >>> $1106;
     $1108 = (($1102) + ($1107)|0);
     $$0982$shrunk$ph$in = $1098;$$0983$shrunk$ph$in = $1088;$$sink1068 = $1108;
     label = 71;
     break;
    }
    case 3:  {
     $1109 = HEAP8[$41>>0]|0;
     $div1020 = ($1109&255) >>> 3;
     $1110 = $div1020&255;
     $1111 = (($$6) + ($1110)|0);
     $1112 = HEAP8[$44>>0]|0;
     $div1021 = ($1112&255) >>> 3;
     $1113 = $div1021&255;
     $1114 = (($$6) + ($1113)|0);
     $1115 = HEAP8[$47>>0]|0;
     $div1022 = ($1115&255) >>> 3;
     $1116 = $div1022&255;
     $1117 = (($$6) + ($1116)|0);
     $$0982$shrunk$ph$in = $1114;$$0983$shrunk$ph$in = $1111;$$sink1068 = $1117;
     label = 71;
     break;
    }
    case 4:  {
     $1118 = HEAP32[$$6>>2]|0;
     $1119 = HEAP8[$39>>0]|0;
     $1120 = $1119&255;
     $1121 = (79212 + ($1120<<2)|0);
     $1122 = HEAP32[$1121>>2]|0;
     $1123 = HEAP32[$40>>2]|0;
     $1124 = $1123 & $1118;
     $1125 = HEAP8[$41>>0]|0;
     $1126 = $1125&255;
     $1127 = $1124 >>> $1126;
     $1128 = (($1122) + ($1127)|0);
     $1129 = HEAP8[$42>>0]|0;
     $1130 = $1129&255;
     $1131 = (79212 + ($1130<<2)|0);
     $1132 = HEAP32[$1131>>2]|0;
     $1133 = HEAP32[$43>>2]|0;
     $1134 = $1133 & $1118;
     $1135 = HEAP8[$44>>0]|0;
     $1136 = $1135&255;
     $1137 = $1134 >>> $1136;
     $1138 = (($1132) + ($1137)|0);
     $1139 = HEAP8[$45>>0]|0;
     $1140 = $1139&255;
     $1141 = (79212 + ($1140<<2)|0);
     $1142 = HEAP32[$1141>>2]|0;
     $1143 = HEAP32[$46>>2]|0;
     $1144 = $1143 & $1118;
     $1145 = HEAP8[$47>>0]|0;
     $1146 = $1145&255;
     $1147 = $1144 >>> $1146;
     $1148 = (($1142) + ($1147)|0);
     $$0982$shrunk$ph$in = $1138;$$0983$shrunk$ph$in = $1128;$$sink1068 = $1148;
     label = 71;
     break;
    }
    default: {
     $$0981$shrunk = 0;$$0982$shrunk = 0;$$0983$shrunk = 0;
    }
    }
    if ((label|0) == 71) {
     label = 0;
     $$0982$shrunk$ph = HEAP8[$$0982$shrunk$ph$in>>0]|0;
     $$0983$shrunk$ph = HEAP8[$$0983$shrunk$ph$in>>0]|0;
     $1149 = HEAP8[$$sink1068>>0]|0;
     $$0981$shrunk = $1149;$$0982$shrunk = $$0982$shrunk$ph;$$0983$shrunk = $$0983$shrunk$ph;
    }
    $$0981 = $$0981$shrunk&255;
    $$0982 = $$0982$shrunk&255;
    $$0983 = $$0983$shrunk&255;
    switch ($20<<24>>24) {
    case 1:  {
     $1150 = HEAP8[$31>>0]|0;
     $1151 = $1150&255;
     $1152 = $$0983 >>> $1151;
     $1153 = HEAP8[$32>>0]|0;
     $1154 = $1153&255;
     $1155 = $1152 << $1154;
     $1156 = HEAP8[$33>>0]|0;
     $1157 = $1156&255;
     $1158 = $$0982 >>> $1157;
     $1159 = HEAP8[$34>>0]|0;
     $1160 = $1159&255;
     $1161 = $1158 << $1160;
     $1162 = $1161 | $1155;
     $1163 = HEAP8[$35>>0]|0;
     $1164 = $1163&255;
     $1165 = $$0981 >>> $1164;
     $1166 = HEAP8[$36>>0]|0;
     $1167 = $1166&255;
     $1168 = $1165 << $1167;
     $1169 = $1162 | $1168;
     $1170 = HEAP8[$37>>0]|0;
     $1171 = $1170&255;
     $1172 = $177 >>> $1171;
     $1173 = HEAP8[$38>>0]|0;
     $1174 = $1173&255;
     $1175 = $1172 << $1174;
     $1176 = $1169 | $1175;
     $1177 = $1176&255;
     HEAP8[$$6961>>0] = $1177;
     break;
    }
    case 2:  {
     $1178 = HEAP8[$31>>0]|0;
     $1179 = $1178&255;
     $1180 = $$0983 >>> $1179;
     $1181 = HEAP8[$32>>0]|0;
     $1182 = $1181&255;
     $1183 = $1180 << $1182;
     $1184 = HEAP8[$33>>0]|0;
     $1185 = $1184&255;
     $1186 = $$0982 >>> $1185;
     $1187 = HEAP8[$34>>0]|0;
     $1188 = $1187&255;
     $1189 = $1186 << $1188;
     $1190 = $1189 | $1183;
     $1191 = HEAP8[$35>>0]|0;
     $1192 = $1191&255;
     $1193 = $$0981 >>> $1192;
     $1194 = HEAP8[$36>>0]|0;
     $1195 = $1194&255;
     $1196 = $1193 << $1195;
     $1197 = $1190 | $1196;
     $1198 = HEAP8[$37>>0]|0;
     $1199 = $1198&255;
     $1200 = $177 >>> $1199;
     $1201 = HEAP8[$38>>0]|0;
     $1202 = $1201&255;
     $1203 = $1200 << $1202;
     $1204 = $1197 | $1203;
     $1205 = $1204&65535;
     HEAP16[$$6961>>1] = $1205;
     break;
    }
    case 3:  {
     $1206 = HEAP8[$32>>0]|0;
     $div1017 = ($1206&255) >>> 3;
     $1207 = $div1017&255;
     $1208 = (($$6961) + ($1207)|0);
     HEAP8[$1208>>0] = $$0983$shrunk;
     $1209 = HEAP8[$34>>0]|0;
     $div1018 = ($1209&255) >>> 3;
     $1210 = $div1018&255;
     $1211 = (($$6961) + ($1210)|0);
     HEAP8[$1211>>0] = $$0982$shrunk;
     $1212 = HEAP8[$36>>0]|0;
     $div1019 = ($1212&255) >>> 3;
     $1213 = $div1019&255;
     $1214 = (($$6961) + ($1213)|0);
     HEAP8[$1214>>0] = $$0981$shrunk;
     break;
    }
    case 4:  {
     $1215 = HEAP8[$31>>0]|0;
     $1216 = $1215&255;
     $1217 = $$0983 >>> $1216;
     $1218 = HEAP8[$32>>0]|0;
     $1219 = $1218&255;
     $1220 = $1217 << $1219;
     $1221 = HEAP8[$33>>0]|0;
     $1222 = $1221&255;
     $1223 = $$0982 >>> $1222;
     $1224 = HEAP8[$34>>0]|0;
     $1225 = $1224&255;
     $1226 = $1223 << $1225;
     $1227 = $1226 | $1220;
     $1228 = HEAP8[$35>>0]|0;
     $1229 = $1228&255;
     $1230 = $$0981 >>> $1229;
     $1231 = HEAP8[$36>>0]|0;
     $1232 = $1231&255;
     $1233 = $1230 << $1232;
     $1234 = $1227 | $1233;
     $1235 = HEAP8[$37>>0]|0;
     $1236 = $1235&255;
     $1237 = $177 >>> $1236;
     $1238 = HEAP8[$38>>0]|0;
     $1239 = $1238&255;
     $1240 = $1237 << $1239;
     $1241 = $1234 | $1240;
     HEAP32[$$6961>>2] = $1241;
     break;
    }
    default: {
    }
    }
    $1242 = (($$6961) + ($21)|0);
    $1243 = (($$6) + ($16)|0);
    $$6973 = $$5972;$$7 = $1243;$$7962 = $1242;
    label = 78;
    continue;
   }
   else if ((label|0) == 78) {
    label = 0;
    switch ($15<<24>>24) {
    case 1:  {
     $1244 = HEAP8[$$7>>0]|0;
     $1245 = $1244&255;
     $1246 = HEAP8[$39>>0]|0;
     $1247 = $1246&255;
     $1248 = (79212 + ($1247<<2)|0);
     $1249 = HEAP32[$1248>>2]|0;
     $1250 = HEAP32[$40>>2]|0;
     $1251 = $1250 & $1245;
     $1252 = HEAP8[$41>>0]|0;
     $1253 = $1252&255;
     $1254 = $1251 >>> $1253;
     $1255 = (($1249) + ($1254)|0);
     $1256 = HEAP8[$42>>0]|0;
     $1257 = $1256&255;
     $1258 = (79212 + ($1257<<2)|0);
     $1259 = HEAP32[$1258>>2]|0;
     $1260 = HEAP32[$43>>2]|0;
     $1261 = $1260 & $1245;
     $1262 = HEAP8[$44>>0]|0;
     $1263 = $1262&255;
     $1264 = $1261 >>> $1263;
     $1265 = (($1259) + ($1264)|0);
     $1266 = HEAP8[$45>>0]|0;
     $1267 = $1266&255;
     $1268 = (79212 + ($1267<<2)|0);
     $1269 = HEAP32[$1268>>2]|0;
     $1270 = HEAP32[$46>>2]|0;
     $1271 = $1270 & $1245;
     $1272 = HEAP8[$47>>0]|0;
     $1273 = $1272&255;
     $1274 = $1271 >>> $1273;
     $1275 = (($1269) + ($1274)|0);
     $$0977$shrunk$ph$in = $1265;$$0978$shrunk$ph$in = $1255;$$sink1070 = $1275;
     label = 83;
     break;
    }
    case 2:  {
     $1276 = HEAP16[$$7>>1]|0;
     $1277 = $1276&65535;
     $1278 = HEAP8[$39>>0]|0;
     $1279 = $1278&255;
     $1280 = (79212 + ($1279<<2)|0);
     $1281 = HEAP32[$1280>>2]|0;
     $1282 = HEAP32[$40>>2]|0;
     $1283 = $1282 & $1277;
     $1284 = HEAP8[$41>>0]|0;
     $1285 = $1284&255;
     $1286 = $1283 >>> $1285;
     $1287 = (($1281) + ($1286)|0);
     $1288 = HEAP8[$42>>0]|0;
     $1289 = $1288&255;
     $1290 = (79212 + ($1289<<2)|0);
     $1291 = HEAP32[$1290>>2]|0;
     $1292 = HEAP32[$43>>2]|0;
     $1293 = $1292 & $1277;
     $1294 = HEAP8[$44>>0]|0;
     $1295 = $1294&255;
     $1296 = $1293 >>> $1295;
     $1297 = (($1291) + ($1296)|0);
     $1298 = HEAP8[$45>>0]|0;
     $1299 = $1298&255;
     $1300 = (79212 + ($1299<<2)|0);
     $1301 = HEAP32[$1300>>2]|0;
     $1302 = HEAP32[$46>>2]|0;
     $1303 = $1302 & $1277;
     $1304 = HEAP8[$47>>0]|0;
     $1305 = $1304&255;
     $1306 = $1303 >>> $1305;
     $1307 = (($1301) + ($1306)|0);
     $$0977$shrunk$ph$in = $1297;$$0978$shrunk$ph$in = $1287;$$sink1070 = $1307;
     label = 83;
     break;
    }
    case 3:  {
     $1308 = HEAP8[$41>>0]|0;
     $div1014 = ($1308&255) >>> 3;
     $1309 = $div1014&255;
     $1310 = (($$7) + ($1309)|0);
     $1311 = HEAP8[$44>>0]|0;
     $div1015 = ($1311&255) >>> 3;
     $1312 = $div1015&255;
     $1313 = (($$7) + ($1312)|0);
     $1314 = HEAP8[$47>>0]|0;
     $div1016 = ($1314&255) >>> 3;
     $1315 = $div1016&255;
     $1316 = (($$7) + ($1315)|0);
     $$0977$shrunk$ph$in = $1313;$$0978$shrunk$ph$in = $1310;$$sink1070 = $1316;
     label = 83;
     break;
    }
    case 4:  {
     $1317 = HEAP32[$$7>>2]|0;
     $1318 = HEAP8[$39>>0]|0;
     $1319 = $1318&255;
     $1320 = (79212 + ($1319<<2)|0);
     $1321 = HEAP32[$1320>>2]|0;
     $1322 = HEAP32[$40>>2]|0;
     $1323 = $1322 & $1317;
     $1324 = HEAP8[$41>>0]|0;
     $1325 = $1324&255;
     $1326 = $1323 >>> $1325;
     $1327 = (($1321) + ($1326)|0);
     $1328 = HEAP8[$42>>0]|0;
     $1329 = $1328&255;
     $1330 = (79212 + ($1329<<2)|0);
     $1331 = HEAP32[$1330>>2]|0;
     $1332 = HEAP32[$43>>2]|0;
     $1333 = $1332 & $1317;
     $1334 = HEAP8[$44>>0]|0;
     $1335 = $1334&255;
     $1336 = $1333 >>> $1335;
     $1337 = (($1331) + ($1336)|0);
     $1338 = HEAP8[$45>>0]|0;
     $1339 = $1338&255;
     $1340 = (79212 + ($1339<<2)|0);
     $1341 = HEAP32[$1340>>2]|0;
     $1342 = HEAP32[$46>>2]|0;
     $1343 = $1342 & $1317;
     $1344 = HEAP8[$47>>0]|0;
     $1345 = $1344&255;
     $1346 = $1343 >>> $1345;
     $1347 = (($1341) + ($1346)|0);
     $$0977$shrunk$ph$in = $1337;$$0978$shrunk$ph$in = $1327;$$sink1070 = $1347;
     label = 83;
     break;
    }
    default: {
     $$0976$shrunk = 0;$$0977$shrunk = 0;$$0978$shrunk = 0;
    }
    }
    if ((label|0) == 83) {
     label = 0;
     $$0977$shrunk$ph = HEAP8[$$0977$shrunk$ph$in>>0]|0;
     $$0978$shrunk$ph = HEAP8[$$0978$shrunk$ph$in>>0]|0;
     $1348 = HEAP8[$$sink1070>>0]|0;
     $$0976$shrunk = $1348;$$0977$shrunk = $$0977$shrunk$ph;$$0978$shrunk = $$0978$shrunk$ph;
    }
    $$0976 = $$0976$shrunk&255;
    $$0977 = $$0977$shrunk&255;
    $$0978 = $$0978$shrunk&255;
    switch ($20<<24>>24) {
    case 1:  {
     $1349 = HEAP8[$31>>0]|0;
     $1350 = $1349&255;
     $1351 = $$0978 >>> $1350;
     $1352 = HEAP8[$32>>0]|0;
     $1353 = $1352&255;
     $1354 = $1351 << $1353;
     $1355 = HEAP8[$33>>0]|0;
     $1356 = $1355&255;
     $1357 = $$0977 >>> $1356;
     $1358 = HEAP8[$34>>0]|0;
     $1359 = $1358&255;
     $1360 = $1357 << $1359;
     $1361 = $1360 | $1354;
     $1362 = HEAP8[$35>>0]|0;
     $1363 = $1362&255;
     $1364 = $$0976 >>> $1363;
     $1365 = HEAP8[$36>>0]|0;
     $1366 = $1365&255;
     $1367 = $1364 << $1366;
     $1368 = $1361 | $1367;
     $1369 = HEAP8[$37>>0]|0;
     $1370 = $1369&255;
     $1371 = $177 >>> $1370;
     $1372 = HEAP8[$38>>0]|0;
     $1373 = $1372&255;
     $1374 = $1371 << $1373;
     $1375 = $1368 | $1374;
     $1376 = $1375&255;
     HEAP8[$$7962>>0] = $1376;
     break;
    }
    case 2:  {
     $1377 = HEAP8[$31>>0]|0;
     $1378 = $1377&255;
     $1379 = $$0978 >>> $1378;
     $1380 = HEAP8[$32>>0]|0;
     $1381 = $1380&255;
     $1382 = $1379 << $1381;
     $1383 = HEAP8[$33>>0]|0;
     $1384 = $1383&255;
     $1385 = $$0977 >>> $1384;
     $1386 = HEAP8[$34>>0]|0;
     $1387 = $1386&255;
     $1388 = $1385 << $1387;
     $1389 = $1388 | $1382;
     $1390 = HEAP8[$35>>0]|0;
     $1391 = $1390&255;
     $1392 = $$0976 >>> $1391;
     $1393 = HEAP8[$36>>0]|0;
     $1394 = $1393&255;
     $1395 = $1392 << $1394;
     $1396 = $1389 | $1395;
     $1397 = HEAP8[$37>>0]|0;
     $1398 = $1397&255;
     $1399 = $177 >>> $1398;
     $1400 = HEAP8[$38>>0]|0;
     $1401 = $1400&255;
     $1402 = $1399 << $1401;
     $1403 = $1396 | $1402;
     $1404 = $1403&65535;
     HEAP16[$$7962>>1] = $1404;
     break;
    }
    case 3:  {
     $1405 = HEAP8[$32>>0]|0;
     $div = ($1405&255) >>> 3;
     $1406 = $div&255;
     $1407 = (($$7962) + ($1406)|0);
     HEAP8[$1407>>0] = $$0978$shrunk;
     $1408 = HEAP8[$34>>0]|0;
     $div1012 = ($1408&255) >>> 3;
     $1409 = $div1012&255;
     $1410 = (($$7962) + ($1409)|0);
     HEAP8[$1410>>0] = $$0977$shrunk;
     $1411 = HEAP8[$36>>0]|0;
     $div1013 = ($1411&255) >>> 3;
     $1412 = $div1013&255;
     $1413 = (($$7962) + ($1412)|0);
     HEAP8[$1413>>0] = $$0976$shrunk;
     break;
    }
    case 4:  {
     $1414 = HEAP8[$31>>0]|0;
     $1415 = $1414&255;
     $1416 = $$0978 >>> $1415;
     $1417 = HEAP8[$32>>0]|0;
     $1418 = $1417&255;
     $1419 = $1416 << $1418;
     $1420 = HEAP8[$33>>0]|0;
     $1421 = $1420&255;
     $1422 = $$0977 >>> $1421;
     $1423 = HEAP8[$34>>0]|0;
     $1424 = $1423&255;
     $1425 = $1422 << $1424;
     $1426 = $1425 | $1419;
     $1427 = HEAP8[$35>>0]|0;
     $1428 = $1427&255;
     $1429 = $$0976 >>> $1428;
     $1430 = HEAP8[$36>>0]|0;
     $1431 = $1430&255;
     $1432 = $1429 << $1431;
     $1433 = $1426 | $1432;
     $1434 = HEAP8[$37>>0]|0;
     $1435 = $1434&255;
     $1436 = $177 >>> $1435;
     $1437 = HEAP8[$38>>0]|0;
     $1438 = $1437&255;
     $1439 = $1436 << $1438;
     $1440 = $1433 | $1439;
     HEAP32[$$7962>>2] = $1440;
     break;
    }
    default: {
    }
    }
    $1441 = (($$7962) + ($21)|0);
    $1442 = (($$7) + ($16)|0);
    $$7974 = $$6973;$$8 = $1442;$$8963 = $1441;
    label = 90;
    continue;
   }
   else if ((label|0) == 90) {
    label = 0;
    switch ($15<<24>>24) {
    case 1:  {
     $1443 = HEAP8[$$8>>0]|0;
     $1444 = $1443&255;
     $1445 = HEAP8[$39>>0]|0;
     $1446 = $1445&255;
     $1447 = (79212 + ($1446<<2)|0);
     $1448 = HEAP32[$1447>>2]|0;
     $1449 = HEAP32[$40>>2]|0;
     $1450 = $1449 & $1444;
     $1451 = HEAP8[$41>>0]|0;
     $1452 = $1451&255;
     $1453 = $1450 >>> $1452;
     $1454 = (($1448) + ($1453)|0);
     $1455 = HEAP8[$42>>0]|0;
     $1456 = $1455&255;
     $1457 = (79212 + ($1456<<2)|0);
     $1458 = HEAP32[$1457>>2]|0;
     $1459 = HEAP32[$43>>2]|0;
     $1460 = $1459 & $1444;
     $1461 = HEAP8[$44>>0]|0;
     $1462 = $1461&255;
     $1463 = $1460 >>> $1462;
     $1464 = (($1458) + ($1463)|0);
     $1465 = HEAP8[$45>>0]|0;
     $1466 = $1465&255;
     $1467 = (79212 + ($1466<<2)|0);
     $1468 = HEAP32[$1467>>2]|0;
     $1469 = HEAP32[$46>>2]|0;
     $1470 = $1469 & $1444;
     $1471 = HEAP8[$47>>0]|0;
     $1472 = $1471&255;
     $1473 = $1470 >>> $1472;
     $1474 = (($1468) + ($1473)|0);
     $$0965$shrunk$ph$in = $1464;$$0966$shrunk$ph$in = $1454;$$sink1072 = $1474;
     label = 95;
     break;
    }
    case 2:  {
     $1475 = HEAP16[$$8>>1]|0;
     $1476 = $1475&65535;
     $1477 = HEAP8[$39>>0]|0;
     $1478 = $1477&255;
     $1479 = (79212 + ($1478<<2)|0);
     $1480 = HEAP32[$1479>>2]|0;
     $1481 = HEAP32[$40>>2]|0;
     $1482 = $1481 & $1476;
     $1483 = HEAP8[$41>>0]|0;
     $1484 = $1483&255;
     $1485 = $1482 >>> $1484;
     $1486 = (($1480) + ($1485)|0);
     $1487 = HEAP8[$42>>0]|0;
     $1488 = $1487&255;
     $1489 = (79212 + ($1488<<2)|0);
     $1490 = HEAP32[$1489>>2]|0;
     $1491 = HEAP32[$43>>2]|0;
     $1492 = $1491 & $1476;
     $1493 = HEAP8[$44>>0]|0;
     $1494 = $1493&255;
     $1495 = $1492 >>> $1494;
     $1496 = (($1490) + ($1495)|0);
     $1497 = HEAP8[$45>>0]|0;
     $1498 = $1497&255;
     $1499 = (79212 + ($1498<<2)|0);
     $1500 = HEAP32[$1499>>2]|0;
     $1501 = HEAP32[$46>>2]|0;
     $1502 = $1501 & $1476;
     $1503 = HEAP8[$47>>0]|0;
     $1504 = $1503&255;
     $1505 = $1502 >>> $1504;
     $1506 = (($1500) + ($1505)|0);
     $$0965$shrunk$ph$in = $1496;$$0966$shrunk$ph$in = $1486;$$sink1072 = $1506;
     label = 95;
     break;
    }
    case 3:  {
     $1507 = HEAP8[$41>>0]|0;
     $div1056 = ($1507&255) >>> 3;
     $1508 = $div1056&255;
     $1509 = (($$8) + ($1508)|0);
     $1510 = HEAP8[$44>>0]|0;
     $div1057 = ($1510&255) >>> 3;
     $1511 = $div1057&255;
     $1512 = (($$8) + ($1511)|0);
     $1513 = HEAP8[$47>>0]|0;
     $div1058 = ($1513&255) >>> 3;
     $1514 = $div1058&255;
     $1515 = (($$8) + ($1514)|0);
     $$0965$shrunk$ph$in = $1512;$$0966$shrunk$ph$in = $1509;$$sink1072 = $1515;
     label = 95;
     break;
    }
    case 4:  {
     $1516 = HEAP32[$$8>>2]|0;
     $1517 = HEAP8[$39>>0]|0;
     $1518 = $1517&255;
     $1519 = (79212 + ($1518<<2)|0);
     $1520 = HEAP32[$1519>>2]|0;
     $1521 = HEAP32[$40>>2]|0;
     $1522 = $1521 & $1516;
     $1523 = HEAP8[$41>>0]|0;
     $1524 = $1523&255;
     $1525 = $1522 >>> $1524;
     $1526 = (($1520) + ($1525)|0);
     $1527 = HEAP8[$42>>0]|0;
     $1528 = $1527&255;
     $1529 = (79212 + ($1528<<2)|0);
     $1530 = HEAP32[$1529>>2]|0;
     $1531 = HEAP32[$43>>2]|0;
     $1532 = $1531 & $1516;
     $1533 = HEAP8[$44>>0]|0;
     $1534 = $1533&255;
     $1535 = $1532 >>> $1534;
     $1536 = (($1530) + ($1535)|0);
     $1537 = HEAP8[$45>>0]|0;
     $1538 = $1537&255;
     $1539 = (79212 + ($1538<<2)|0);
     $1540 = HEAP32[$1539>>2]|0;
     $1541 = HEAP32[$46>>2]|0;
     $1542 = $1541 & $1516;
     $1543 = HEAP8[$47>>0]|0;
     $1544 = $1543&255;
     $1545 = $1542 >>> $1544;
     $1546 = (($1540) + ($1545)|0);
     $$0965$shrunk$ph$in = $1536;$$0966$shrunk$ph$in = $1526;$$sink1072 = $1546;
     label = 95;
     break;
    }
    default: {
     $$0964$shrunk = 0;$$0965$shrunk = 0;$$0966$shrunk = 0;
    }
    }
    if ((label|0) == 95) {
     label = 0;
     $$0965$shrunk$ph = HEAP8[$$0965$shrunk$ph$in>>0]|0;
     $$0966$shrunk$ph = HEAP8[$$0966$shrunk$ph$in>>0]|0;
     $1547 = HEAP8[$$sink1072>>0]|0;
     $$0964$shrunk = $1547;$$0965$shrunk = $$0965$shrunk$ph;$$0966$shrunk = $$0966$shrunk$ph;
    }
    $$0964 = $$0964$shrunk&255;
    $$0965 = $$0965$shrunk&255;
    $$0966 = $$0966$shrunk&255;
    switch ($20<<24>>24) {
    case 1:  {
     $1548 = HEAP8[$31>>0]|0;
     $1549 = $1548&255;
     $1550 = $$0966 >>> $1549;
     $1551 = HEAP8[$32>>0]|0;
     $1552 = $1551&255;
     $1553 = $1550 << $1552;
     $1554 = HEAP8[$33>>0]|0;
     $1555 = $1554&255;
     $1556 = $$0965 >>> $1555;
     $1557 = HEAP8[$34>>0]|0;
     $1558 = $1557&255;
     $1559 = $1556 << $1558;
     $1560 = $1559 | $1553;
     $1561 = HEAP8[$35>>0]|0;
     $1562 = $1561&255;
     $1563 = $$0964 >>> $1562;
     $1564 = HEAP8[$36>>0]|0;
     $1565 = $1564&255;
     $1566 = $1563 << $1565;
     $1567 = $1560 | $1566;
     $1568 = HEAP8[$37>>0]|0;
     $1569 = $1568&255;
     $1570 = $177 >>> $1569;
     $1571 = HEAP8[$38>>0]|0;
     $1572 = $1571&255;
     $1573 = $1570 << $1572;
     $1574 = $1567 | $1573;
     $1575 = $1574&255;
     HEAP8[$$8963>>0] = $1575;
     break;
    }
    case 2:  {
     $1576 = HEAP8[$31>>0]|0;
     $1577 = $1576&255;
     $1578 = $$0966 >>> $1577;
     $1579 = HEAP8[$32>>0]|0;
     $1580 = $1579&255;
     $1581 = $1578 << $1580;
     $1582 = HEAP8[$33>>0]|0;
     $1583 = $1582&255;
     $1584 = $$0965 >>> $1583;
     $1585 = HEAP8[$34>>0]|0;
     $1586 = $1585&255;
     $1587 = $1584 << $1586;
     $1588 = $1587 | $1581;
     $1589 = HEAP8[$35>>0]|0;
     $1590 = $1589&255;
     $1591 = $$0964 >>> $1590;
     $1592 = HEAP8[$36>>0]|0;
     $1593 = $1592&255;
     $1594 = $1591 << $1593;
     $1595 = $1588 | $1594;
     $1596 = HEAP8[$37>>0]|0;
     $1597 = $1596&255;
     $1598 = $177 >>> $1597;
     $1599 = HEAP8[$38>>0]|0;
     $1600 = $1599&255;
     $1601 = $1598 << $1600;
     $1602 = $1595 | $1601;
     $1603 = $1602&65535;
     HEAP16[$$8963>>1] = $1603;
     break;
    }
    case 3:  {
     $1604 = HEAP8[$32>>0]|0;
     $div1053 = ($1604&255) >>> 3;
     $1605 = $div1053&255;
     $1606 = (($$8963) + ($1605)|0);
     HEAP8[$1606>>0] = $$0966$shrunk;
     $1607 = HEAP8[$34>>0]|0;
     $div1054 = ($1607&255) >>> 3;
     $1608 = $div1054&255;
     $1609 = (($$8963) + ($1608)|0);
     HEAP8[$1609>>0] = $$0965$shrunk;
     $1610 = HEAP8[$36>>0]|0;
     $div1055 = ($1610&255) >>> 3;
     $1611 = $div1055&255;
     $1612 = (($$8963) + ($1611)|0);
     HEAP8[$1612>>0] = $$0964$shrunk;
     break;
    }
    case 4:  {
     $1613 = HEAP8[$31>>0]|0;
     $1614 = $1613&255;
     $1615 = $$0966 >>> $1614;
     $1616 = HEAP8[$32>>0]|0;
     $1617 = $1616&255;
     $1618 = $1615 << $1617;
     $1619 = HEAP8[$33>>0]|0;
     $1620 = $1619&255;
     $1621 = $$0965 >>> $1620;
     $1622 = HEAP8[$34>>0]|0;
     $1623 = $1622&255;
     $1624 = $1621 << $1623;
     $1625 = $1624 | $1618;
     $1626 = HEAP8[$35>>0]|0;
     $1627 = $1626&255;
     $1628 = $$0964 >>> $1627;
     $1629 = HEAP8[$36>>0]|0;
     $1630 = $1629&255;
     $1631 = $1628 << $1630;
     $1632 = $1625 | $1631;
     $1633 = HEAP8[$37>>0]|0;
     $1634 = $1633&255;
     $1635 = $177 >>> $1634;
     $1636 = HEAP8[$38>>0]|0;
     $1637 = $1636&255;
     $1638 = $1635 << $1637;
     $1639 = $1632 | $1638;
     HEAP32[$$8963>>2] = $1639;
     break;
    }
    default: {
    }
    }
    $1640 = (($$8963) + ($21)|0);
    $1641 = (($$8) + ($16)|0);
    $1642 = (($$7974) + -1)|0;
    $1643 = ($$7974|0)>(1);
    if ($1643) {
     $$0967 = $1642;$$1 = $1641;$$1956 = $1640;
     label = 6;
     continue;
    } else {
     break;
    }
   }
  }
  $1644 = (($1641) + ($7)|0);
  $1645 = (($1640) + ($11)|0);
  $1646 = ($48|0)==(0);
  if ($1646) {
   label = 104;
   break;
  } else {
   $$09541074 = $1644;$$09551073 = $1645;$$in = $48;
  }
 }
 if ((label|0) == 102) {
  // unreachable;
 }
 else if ((label|0) == 104) {
  return;
 }
}
function _Blit4to4CopyAlpha($0) {
 $0 = $0|0;
 var $$0$us = 0, $$05977 = 0, $$05977$us = 0, $$05977$us79 = 0, $$06776 = 0, $$06776$us = 0, $$06776$us80 = 0, $$1$us86127 = 0, $$160$us = 0, $$168$us = 0, $$2 = 0, $$261$us85126 = 0, $$269$us84125 = 0, $$3 = 0, $$362 = 0, $$370 = 0, $$4 = 0, $$463 = 0, $$471 = 0, $$5 = 0;
 var $$564 = 0, $$572 = 0, $$6 = 0, $$665 = 0, $$673 = 0, $$7 = 0, $$766 = 0, $$774 = 0, $$8 = 0, $$875 = 0, $$lcssa123 = 0, $$lcssa124 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $trunc = 0, $trunc$clear = 0, $trunc$clear1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$0>>2]|0;
 $6 = ((($0)) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($0)) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($0)) + 36|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($4) + -1)|0;
 $13 = ($4|0)==(0);
 if ($13) {
  return;
 }
 $14 = (($2) + 7)|0;
 $15 = (($14|0) / 8)&-1;
 $trunc = $2&255;
 $trunc$clear = $trunc & 7;
 switch ($trunc$clear<<24>>24) {
 case 0:  {
  $$05977$us = $9;$$06776$us = $5;$46 = $12;
  while(1) {
   $$0$us = $15;$$160$us = $$05977$us;$$168$us = $$06776$us;
   while(1) {
    $17 = HEAP32[$$168$us>>2]|0;
    HEAP32[$$160$us>>2] = $17;
    $18 = ((($$160$us)) + 4|0);
    $19 = ((($$168$us)) + 4|0);
    $20 = HEAP32[$19>>2]|0;
    HEAP32[$18>>2] = $20;
    $21 = ((($$160$us)) + 8|0);
    $22 = ((($$168$us)) + 8|0);
    $23 = HEAP32[$22>>2]|0;
    HEAP32[$21>>2] = $23;
    $24 = ((($$160$us)) + 12|0);
    $25 = ((($$168$us)) + 12|0);
    $26 = HEAP32[$25>>2]|0;
    HEAP32[$24>>2] = $26;
    $27 = ((($$160$us)) + 16|0);
    $28 = ((($$168$us)) + 16|0);
    $29 = HEAP32[$28>>2]|0;
    HEAP32[$27>>2] = $29;
    $30 = ((($$160$us)) + 20|0);
    $31 = ((($$168$us)) + 20|0);
    $32 = HEAP32[$31>>2]|0;
    HEAP32[$30>>2] = $32;
    $33 = ((($$160$us)) + 24|0);
    $34 = ((($$168$us)) + 24|0);
    $35 = HEAP32[$34>>2]|0;
    HEAP32[$33>>2] = $35;
    $36 = ((($$160$us)) + 28|0);
    $37 = ((($$168$us)) + 28|0);
    $38 = HEAP32[$37>>2]|0;
    HEAP32[$36>>2] = $38;
    $39 = ((($$160$us)) + 32|0);
    $40 = ((($$168$us)) + 32|0);
    $41 = (($$0$us) + -1)|0;
    $42 = ($$0$us|0)>(1);
    if ($42) {
     $$0$us = $41;$$160$us = $39;$$168$us = $40;
    } else {
     break;
    }
   }
   $43 = (($40) + ($7)|0);
   $44 = (($39) + ($11)|0);
   $45 = (($46) + -1)|0;
   $47 = ($46|0)==(0);
   if ($47) {
    break;
   } else {
    $$05977$us = $44;$$06776$us = $43;$46 = $45;
   }
  }
  return;
  break;
 }
 case 7:  {
  $16 = ($14|0)>(15);
  $$05977$us79 = $9;$$06776$us80 = $5;$100 = $12;
  while(1) {
   $48 = HEAP32[$$06776$us80>>2]|0;
   HEAP32[$$05977$us79>>2] = $48;
   $49 = ((($$05977$us79)) + 4|0);
   $50 = ((($$06776$us80)) + 4|0);
   $51 = HEAP32[$50>>2]|0;
   HEAP32[$49>>2] = $51;
   $52 = ((($$05977$us79)) + 8|0);
   $53 = ((($$06776$us80)) + 8|0);
   $54 = HEAP32[$53>>2]|0;
   HEAP32[$52>>2] = $54;
   $55 = ((($$05977$us79)) + 12|0);
   $56 = ((($$06776$us80)) + 12|0);
   $57 = HEAP32[$56>>2]|0;
   HEAP32[$55>>2] = $57;
   $58 = ((($$05977$us79)) + 16|0);
   $59 = ((($$06776$us80)) + 16|0);
   $60 = HEAP32[$59>>2]|0;
   HEAP32[$58>>2] = $60;
   $61 = ((($$05977$us79)) + 20|0);
   $62 = ((($$06776$us80)) + 20|0);
   $63 = HEAP32[$62>>2]|0;
   HEAP32[$61>>2] = $63;
   $64 = ((($$05977$us79)) + 24|0);
   $65 = ((($$06776$us80)) + 24|0);
   $66 = HEAP32[$65>>2]|0;
   HEAP32[$64>>2] = $66;
   $67 = ((($$05977$us79)) + 28|0);
   $68 = ((($$06776$us80)) + 28|0);
   if ($16) {
    $$1$us86127 = $15;$$261$us85126 = $$05977$us79;$$269$us84125 = $$06776$us80;$71 = $68;$72 = $67;
    while(1) {
     $69 = (($$1$us86127) + -1)|0;
     $70 = HEAP32[$71>>2]|0;
     HEAP32[$72>>2] = $70;
     $73 = ((($$261$us85126)) + 32|0);
     $74 = ((($$269$us84125)) + 32|0);
     $75 = HEAP32[$74>>2]|0;
     HEAP32[$73>>2] = $75;
     $76 = ((($$261$us85126)) + 36|0);
     $77 = ((($$269$us84125)) + 36|0);
     $78 = HEAP32[$77>>2]|0;
     HEAP32[$76>>2] = $78;
     $79 = ((($$261$us85126)) + 40|0);
     $80 = ((($$269$us84125)) + 40|0);
     $81 = HEAP32[$80>>2]|0;
     HEAP32[$79>>2] = $81;
     $82 = ((($$261$us85126)) + 44|0);
     $83 = ((($$269$us84125)) + 44|0);
     $84 = HEAP32[$83>>2]|0;
     HEAP32[$82>>2] = $84;
     $85 = ((($$261$us85126)) + 48|0);
     $86 = ((($$269$us84125)) + 48|0);
     $87 = HEAP32[$86>>2]|0;
     HEAP32[$85>>2] = $87;
     $88 = ((($$261$us85126)) + 52|0);
     $89 = ((($$269$us84125)) + 52|0);
     $90 = HEAP32[$89>>2]|0;
     HEAP32[$88>>2] = $90;
     $91 = ((($$261$us85126)) + 56|0);
     $92 = ((($$269$us84125)) + 56|0);
     $93 = HEAP32[$92>>2]|0;
     HEAP32[$91>>2] = $93;
     $94 = ((($$261$us85126)) + 60|0);
     $95 = ((($$269$us84125)) + 60|0);
     $96 = ($69|0)>(1);
     if ($96) {
      $$1$us86127 = $69;$$261$us85126 = $73;$$269$us84125 = $74;$71 = $95;$72 = $94;
     } else {
      $$lcssa123 = $95;$$lcssa124 = $94;
      break;
     }
    }
   } else {
    $$lcssa123 = $68;$$lcssa124 = $67;
   }
   $97 = (($$lcssa123) + ($7)|0);
   $98 = (($$lcssa124) + ($11)|0);
   $99 = (($100) + -1)|0;
   $101 = ($100|0)==(0);
   if ($101) {
    break;
   } else {
    $$05977$us79 = $98;$$06776$us80 = $97;$100 = $99;
   }
  }
  return;
  break;
 }
 default: {
  $$05977 = $9;$$06776 = $5;$131 = $12;
  L5: while(1) {
   $trunc$clear1 = $trunc & 7;
   switch ($trunc$clear1<<24>>24) {
   case 1:  {
    $$7 = $15;$$8 = $$05977;$$875 = $$06776;
    label = 17;
    break;
   }
   case 2:  {
    $$6 = $15;$$766 = $$05977;$$774 = $$06776;
    label = 16;
    break;
   }
   case 6:  {
    $$2 = $15;$$362 = $$05977;$$370 = $$06776;
    label = 12;
    break;
   }
   case 5:  {
    $$3 = $15;$$463 = $$05977;$$471 = $$06776;
    label = 13;
    break;
   }
   case 4:  {
    $$4 = $15;$$564 = $$05977;$$572 = $$06776;
    label = 14;
    break;
   }
   case 3:  {
    $$5 = $15;$$665 = $$05977;$$673 = $$06776;
    label = 15;
    break;
   }
   default: {
    label = 18;
    break L5;
   }
   }
   while(1) {
    if ((label|0) == 12) {
     label = 0;
     $111 = HEAP32[$$370>>2]|0;
     HEAP32[$$362>>2] = $111;
     $112 = ((($$362)) + 4|0);
     $113 = ((($$370)) + 4|0);
     $$3 = $$2;$$463 = $112;$$471 = $113;
     label = 13;
     continue;
    }
    else if ((label|0) == 13) {
     label = 0;
     $114 = HEAP32[$$471>>2]|0;
     HEAP32[$$463>>2] = $114;
     $115 = ((($$463)) + 4|0);
     $116 = ((($$471)) + 4|0);
     $$4 = $$3;$$564 = $115;$$572 = $116;
     label = 14;
     continue;
    }
    else if ((label|0) == 14) {
     label = 0;
     $117 = HEAP32[$$572>>2]|0;
     HEAP32[$$564>>2] = $117;
     $118 = ((($$564)) + 4|0);
     $119 = ((($$572)) + 4|0);
     $$5 = $$4;$$665 = $118;$$673 = $119;
     label = 15;
     continue;
    }
    else if ((label|0) == 15) {
     label = 0;
     $120 = HEAP32[$$673>>2]|0;
     HEAP32[$$665>>2] = $120;
     $121 = ((($$665)) + 4|0);
     $122 = ((($$673)) + 4|0);
     $$6 = $$5;$$766 = $121;$$774 = $122;
     label = 16;
     continue;
    }
    else if ((label|0) == 16) {
     label = 0;
     $123 = HEAP32[$$774>>2]|0;
     HEAP32[$$766>>2] = $123;
     $124 = ((($$766)) + 4|0);
     $125 = ((($$774)) + 4|0);
     $$7 = $$6;$$8 = $124;$$875 = $125;
     label = 17;
     continue;
    }
    else if ((label|0) == 17) {
     label = 0;
     $126 = HEAP32[$$875>>2]|0;
     HEAP32[$$8>>2] = $126;
     $105 = ((($$8)) + 4|0);
     $104 = ((($$875)) + 4|0);
     $127 = ($$7|0)>(1);
     if (!($127)) {
      break;
     }
     $102 = (($$7) + -1)|0;
     $103 = HEAP32[$104>>2]|0;
     HEAP32[$105>>2] = $103;
     $106 = ((($$8)) + 8|0);
     $107 = ((($$875)) + 8|0);
     $108 = HEAP32[$107>>2]|0;
     HEAP32[$106>>2] = $108;
     $109 = ((($$8)) + 12|0);
     $110 = ((($$875)) + 12|0);
     $$2 = $102;$$362 = $109;$$370 = $110;
     label = 12;
     continue;
    }
   }
   $128 = (($104) + ($7)|0);
   $129 = (($105) + ($11)|0);
   $130 = (($131) + -1)|0;
   $132 = ($131|0)==(0);
   if ($132) {
    label = 20;
    break;
   } else {
    $$05977 = $129;$$06776 = $128;$131 = $130;
   }
  }
  if ((label|0) == 18) {
   // unreachable;
  }
  else if ((label|0) == 20) {
   return;
  }
 }
 }
}
function _BlitNtoNCopyAlpha($0) {
 $0 = $0|0;
 var $$0166184 = 0, $$0167183 = 0, $$0169 = 0, $$0169$shrunk = 0, $$0170 = 0, $$0170$shrunk = 0, $$0171 = 0, $$0171$shrunk = 0, $$0172 = 0, $$0172$shrunk = 0, $$0173179 = 0, $$1$lcssa = 0, $$1168$lcssa = 0, $$1168180 = 0, $$1181 = 0, $$in = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0;
 var $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0;
 var $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0;
 var $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0;
 var $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0;
 var $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0;
 var $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0;
 var $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0;
 var $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0;
 var $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0;
 var $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0;
 var $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $div = 0, $div174 = 0, $div175 = 0, $div176 = 0, $div177 = 0, $div178 = 0, $scevgep = 0, $scevgep187 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($0)) + 36|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($0)) + 40|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ((($10)) + 9|0);
 $12 = HEAP8[$11>>0]|0;
 $13 = $12&255;
 $14 = ((($0)) + 44|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ((($15)) + 9|0);
 $17 = HEAP8[$16>>0]|0;
 $18 = $17&255;
 $19 = ($4|0)==(0);
 if ($19) {
  return;
 }
 $20 = ((($0)) + 20|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = HEAP32[$0>>2]|0;
 $23 = ($2|0)==(0);
 $24 = ((($15)) + 28|0);
 $25 = ((($15)) + 32|0);
 $26 = ((($15)) + 29|0);
 $27 = ((($15)) + 33|0);
 $28 = ((($15)) + 30|0);
 $29 = ((($15)) + 34|0);
 $30 = ((($15)) + 31|0);
 $31 = ((($15)) + 35|0);
 $32 = ((($10)) + 28|0);
 $33 = ((($10)) + 12|0);
 $34 = ((($10)) + 32|0);
 $35 = ((($10)) + 29|0);
 $36 = ((($10)) + 16|0);
 $37 = ((($10)) + 33|0);
 $38 = ((($10)) + 30|0);
 $39 = ((($10)) + 20|0);
 $40 = ((($10)) + 34|0);
 $41 = ((($10)) + 31|0);
 $42 = ((($10)) + 24|0);
 $43 = ((($10)) + 35|0);
 $44 = Math_imul($2, $18)|0;
 $45 = Math_imul($2, $13)|0;
 $$0166184 = $22;$$0167183 = $21;$$in = $4;
 while(1) {
  $46 = (($$in) + -1)|0;
  if ($23) {
   $$1$lcssa = $$0166184;$$1168$lcssa = $$0167183;
  } else {
   $scevgep = (($$0167183) + ($44)|0);
   $$0173179 = $2;$$1168180 = $$0167183;$$1181 = $$0166184;
   while(1) {
    switch ($12<<24>>24) {
    case 1:  {
     $47 = HEAP8[$$1181>>0]|0;
     $48 = $47&255;
     $49 = HEAP8[$32>>0]|0;
     $50 = $49&255;
     $51 = (79212 + ($50<<2)|0);
     $52 = HEAP32[$51>>2]|0;
     $53 = HEAP32[$33>>2]|0;
     $54 = $53 & $48;
     $55 = HEAP8[$34>>0]|0;
     $56 = $55&255;
     $57 = $54 >>> $56;
     $58 = (($52) + ($57)|0);
     $59 = HEAP8[$58>>0]|0;
     $60 = HEAP8[$35>>0]|0;
     $61 = $60&255;
     $62 = (79212 + ($61<<2)|0);
     $63 = HEAP32[$62>>2]|0;
     $64 = HEAP32[$36>>2]|0;
     $65 = $64 & $48;
     $66 = HEAP8[$37>>0]|0;
     $67 = $66&255;
     $68 = $65 >>> $67;
     $69 = (($63) + ($68)|0);
     $70 = HEAP8[$69>>0]|0;
     $71 = HEAP8[$38>>0]|0;
     $72 = $71&255;
     $73 = (79212 + ($72<<2)|0);
     $74 = HEAP32[$73>>2]|0;
     $75 = HEAP32[$39>>2]|0;
     $76 = $75 & $48;
     $77 = HEAP8[$40>>0]|0;
     $78 = $77&255;
     $79 = $76 >>> $78;
     $80 = (($74) + ($79)|0);
     $81 = HEAP8[$80>>0]|0;
     $82 = HEAP8[$41>>0]|0;
     $83 = $82&255;
     $84 = (79212 + ($83<<2)|0);
     $85 = HEAP32[$84>>2]|0;
     $86 = HEAP32[$42>>2]|0;
     $87 = $86 & $48;
     $88 = HEAP8[$43>>0]|0;
     $89 = $88&255;
     $90 = $87 >>> $89;
     $91 = (($85) + ($90)|0);
     $92 = HEAP8[$91>>0]|0;
     $$0169$shrunk = $92;$$0170$shrunk = $81;$$0171$shrunk = $70;$$0172$shrunk = $59;
     break;
    }
    case 2:  {
     $93 = HEAP16[$$1181>>1]|0;
     $94 = $93&65535;
     $95 = HEAP8[$32>>0]|0;
     $96 = $95&255;
     $97 = (79212 + ($96<<2)|0);
     $98 = HEAP32[$97>>2]|0;
     $99 = HEAP32[$33>>2]|0;
     $100 = $99 & $94;
     $101 = HEAP8[$34>>0]|0;
     $102 = $101&255;
     $103 = $100 >>> $102;
     $104 = (($98) + ($103)|0);
     $105 = HEAP8[$104>>0]|0;
     $106 = HEAP8[$35>>0]|0;
     $107 = $106&255;
     $108 = (79212 + ($107<<2)|0);
     $109 = HEAP32[$108>>2]|0;
     $110 = HEAP32[$36>>2]|0;
     $111 = $110 & $94;
     $112 = HEAP8[$37>>0]|0;
     $113 = $112&255;
     $114 = $111 >>> $113;
     $115 = (($109) + ($114)|0);
     $116 = HEAP8[$115>>0]|0;
     $117 = HEAP8[$38>>0]|0;
     $118 = $117&255;
     $119 = (79212 + ($118<<2)|0);
     $120 = HEAP32[$119>>2]|0;
     $121 = HEAP32[$39>>2]|0;
     $122 = $121 & $94;
     $123 = HEAP8[$40>>0]|0;
     $124 = $123&255;
     $125 = $122 >>> $124;
     $126 = (($120) + ($125)|0);
     $127 = HEAP8[$126>>0]|0;
     $128 = HEAP8[$41>>0]|0;
     $129 = $128&255;
     $130 = (79212 + ($129<<2)|0);
     $131 = HEAP32[$130>>2]|0;
     $132 = HEAP32[$42>>2]|0;
     $133 = $132 & $94;
     $134 = HEAP8[$43>>0]|0;
     $135 = $134&255;
     $136 = $133 >>> $135;
     $137 = (($131) + ($136)|0);
     $138 = HEAP8[$137>>0]|0;
     $$0169$shrunk = $138;$$0170$shrunk = $127;$$0171$shrunk = $116;$$0172$shrunk = $105;
     break;
    }
    case 3:  {
     $139 = HEAP8[$34>>0]|0;
     $div176 = ($139&255) >>> 3;
     $140 = $div176&255;
     $141 = (($$1181) + ($140)|0);
     $142 = HEAP8[$141>>0]|0;
     $143 = HEAP8[$37>>0]|0;
     $div177 = ($143&255) >>> 3;
     $144 = $div177&255;
     $145 = (($$1181) + ($144)|0);
     $146 = HEAP8[$145>>0]|0;
     $147 = HEAP8[$40>>0]|0;
     $div178 = ($147&255) >>> 3;
     $148 = $div178&255;
     $149 = (($$1181) + ($148)|0);
     $150 = HEAP8[$149>>0]|0;
     $$0169$shrunk = -1;$$0170$shrunk = $150;$$0171$shrunk = $146;$$0172$shrunk = $142;
     break;
    }
    case 4:  {
     $151 = HEAP32[$$1181>>2]|0;
     $152 = HEAP8[$32>>0]|0;
     $153 = $152&255;
     $154 = (79212 + ($153<<2)|0);
     $155 = HEAP32[$154>>2]|0;
     $156 = HEAP32[$33>>2]|0;
     $157 = $156 & $151;
     $158 = HEAP8[$34>>0]|0;
     $159 = $158&255;
     $160 = $157 >>> $159;
     $161 = (($155) + ($160)|0);
     $162 = HEAP8[$161>>0]|0;
     $163 = HEAP8[$35>>0]|0;
     $164 = $163&255;
     $165 = (79212 + ($164<<2)|0);
     $166 = HEAP32[$165>>2]|0;
     $167 = HEAP32[$36>>2]|0;
     $168 = $167 & $151;
     $169 = HEAP8[$37>>0]|0;
     $170 = $169&255;
     $171 = $168 >>> $170;
     $172 = (($166) + ($171)|0);
     $173 = HEAP8[$172>>0]|0;
     $174 = HEAP8[$38>>0]|0;
     $175 = $174&255;
     $176 = (79212 + ($175<<2)|0);
     $177 = HEAP32[$176>>2]|0;
     $178 = HEAP32[$39>>2]|0;
     $179 = $178 & $151;
     $180 = HEAP8[$40>>0]|0;
     $181 = $180&255;
     $182 = $179 >>> $181;
     $183 = (($177) + ($182)|0);
     $184 = HEAP8[$183>>0]|0;
     $185 = HEAP8[$41>>0]|0;
     $186 = $185&255;
     $187 = (79212 + ($186<<2)|0);
     $188 = HEAP32[$187>>2]|0;
     $189 = HEAP32[$42>>2]|0;
     $190 = $189 & $151;
     $191 = HEAP8[$43>>0]|0;
     $192 = $191&255;
     $193 = $190 >>> $192;
     $194 = (($188) + ($193)|0);
     $195 = HEAP8[$194>>0]|0;
     $$0169$shrunk = $195;$$0170$shrunk = $184;$$0171$shrunk = $173;$$0172$shrunk = $162;
     break;
    }
    default: {
     $$0169$shrunk = 0;$$0170$shrunk = 0;$$0171$shrunk = 0;$$0172$shrunk = 0;
    }
    }
    $$0169 = $$0169$shrunk&255;
    $$0170 = $$0170$shrunk&255;
    $$0171 = $$0171$shrunk&255;
    $$0172 = $$0172$shrunk&255;
    switch ($17<<24>>24) {
    case 1:  {
     $196 = HEAP8[$24>>0]|0;
     $197 = $196&255;
     $198 = $$0172 >>> $197;
     $199 = HEAP8[$25>>0]|0;
     $200 = $199&255;
     $201 = $198 << $200;
     $202 = HEAP8[$26>>0]|0;
     $203 = $202&255;
     $204 = $$0171 >>> $203;
     $205 = HEAP8[$27>>0]|0;
     $206 = $205&255;
     $207 = $204 << $206;
     $208 = $207 | $201;
     $209 = HEAP8[$28>>0]|0;
     $210 = $209&255;
     $211 = $$0170 >>> $210;
     $212 = HEAP8[$29>>0]|0;
     $213 = $212&255;
     $214 = $211 << $213;
     $215 = $208 | $214;
     $216 = HEAP8[$30>>0]|0;
     $217 = $216&255;
     $218 = $$0169 >>> $217;
     $219 = HEAP8[$31>>0]|0;
     $220 = $219&255;
     $221 = $218 << $220;
     $222 = $215 | $221;
     $223 = $222&255;
     HEAP8[$$1168180>>0] = $223;
     break;
    }
    case 2:  {
     $224 = HEAP8[$24>>0]|0;
     $225 = $224&255;
     $226 = $$0172 >>> $225;
     $227 = HEAP8[$25>>0]|0;
     $228 = $227&255;
     $229 = $226 << $228;
     $230 = HEAP8[$26>>0]|0;
     $231 = $230&255;
     $232 = $$0171 >>> $231;
     $233 = HEAP8[$27>>0]|0;
     $234 = $233&255;
     $235 = $232 << $234;
     $236 = $235 | $229;
     $237 = HEAP8[$28>>0]|0;
     $238 = $237&255;
     $239 = $$0170 >>> $238;
     $240 = HEAP8[$29>>0]|0;
     $241 = $240&255;
     $242 = $239 << $241;
     $243 = $236 | $242;
     $244 = HEAP8[$30>>0]|0;
     $245 = $244&255;
     $246 = $$0169 >>> $245;
     $247 = HEAP8[$31>>0]|0;
     $248 = $247&255;
     $249 = $246 << $248;
     $250 = $243 | $249;
     $251 = $250&65535;
     HEAP16[$$1168180>>1] = $251;
     break;
    }
    case 3:  {
     $252 = HEAP8[$25>>0]|0;
     $div = ($252&255) >>> 3;
     $253 = $div&255;
     $254 = (($$1168180) + ($253)|0);
     HEAP8[$254>>0] = $$0172$shrunk;
     $255 = HEAP8[$27>>0]|0;
     $div174 = ($255&255) >>> 3;
     $256 = $div174&255;
     $257 = (($$1168180) + ($256)|0);
     HEAP8[$257>>0] = $$0171$shrunk;
     $258 = HEAP8[$29>>0]|0;
     $div175 = ($258&255) >>> 3;
     $259 = $div175&255;
     $260 = (($$1168180) + ($259)|0);
     HEAP8[$260>>0] = $$0170$shrunk;
     break;
    }
    case 4:  {
     $261 = HEAP8[$24>>0]|0;
     $262 = $261&255;
     $263 = $$0172 >>> $262;
     $264 = HEAP8[$25>>0]|0;
     $265 = $264&255;
     $266 = $263 << $265;
     $267 = HEAP8[$26>>0]|0;
     $268 = $267&255;
     $269 = $$0171 >>> $268;
     $270 = HEAP8[$27>>0]|0;
     $271 = $270&255;
     $272 = $269 << $271;
     $273 = $272 | $266;
     $274 = HEAP8[$28>>0]|0;
     $275 = $274&255;
     $276 = $$0170 >>> $275;
     $277 = HEAP8[$29>>0]|0;
     $278 = $277&255;
     $279 = $276 << $278;
     $280 = $273 | $279;
     $281 = HEAP8[$30>>0]|0;
     $282 = $281&255;
     $283 = $$0169 >>> $282;
     $284 = HEAP8[$31>>0]|0;
     $285 = $284&255;
     $286 = $283 << $285;
     $287 = $280 | $286;
     HEAP32[$$1168180>>2] = $287;
     break;
    }
    default: {
    }
    }
    $288 = (($$1168180) + ($18)|0);
    $289 = (($$1181) + ($13)|0);
    $290 = (($$0173179) + -1)|0;
    $291 = ($290|0)==(0);
    if ($291) {
     break;
    } else {
     $$0173179 = $290;$$1168180 = $288;$$1181 = $289;
    }
   }
   $scevgep187 = (($$0166184) + ($45)|0);
   $$1$lcssa = $scevgep187;$$1168$lcssa = $scevgep;
  }
  $292 = (($$1$lcssa) + ($6)|0);
  $293 = (($$1168$lcssa) + ($8)|0);
  $294 = ($46|0)==(0);
  if ($294) {
   break;
  } else {
   $$0166184 = $292;$$0167183 = $293;$$in = $46;
  }
 }
 return;
}
function _BlitNtoNKey($0) {
 $0 = $0|0;
 var $$0794860 = 0, $$0795859 = 0, $$0804 = 0, $$0812 = 0, $$0813 = 0, $$0814 = 0, $$0815 = 0, $$0816 = 0, $$0817 = 0, $$0818 = 0, $$0819 = 0, $$1 = 0, $$1796 = 0, $$1805 = 0, $$2 = 0, $$2797 = 0, $$2806 = 0, $$3 = 0, $$3798 = 0, $$3807 = 0;
 var $$4 = 0, $$4799 = 0, $$4808 = 0, $$5 = 0, $$5800 = 0, $$5809 = 0, $$6 = 0, $$6801 = 0, $$6810 = 0, $$7 = 0, $$7802 = 0, $$7811 = 0, $$8 = 0, $$8803 = 0, $$in = 0, $1 = 0, $10 = 0, $100 = 0, $1000 = 0, $1001 = 0;
 var $1002 = 0, $1003 = 0, $1004 = 0, $1005 = 0, $1006 = 0, $1007 = 0, $1008 = 0, $1009 = 0, $101 = 0, $1010 = 0, $1011 = 0, $1012 = 0, $1013 = 0, $1014 = 0, $1015 = 0, $1016 = 0, $1017 = 0, $1018 = 0, $1019 = 0, $102 = 0;
 var $1020 = 0, $1021 = 0, $1022 = 0, $1023 = 0, $1024 = 0, $1025 = 0, $1026 = 0, $1027 = 0, $1028 = 0, $1029 = 0, $103 = 0, $1030 = 0, $1031 = 0, $1032 = 0, $1033 = 0, $1034 = 0, $1035 = 0, $1036 = 0, $1037 = 0, $1038 = 0;
 var $1039 = 0, $104 = 0, $1040 = 0, $1041 = 0, $1042 = 0, $1043 = 0, $1044 = 0, $1045 = 0, $1046 = 0, $1047 = 0, $1048 = 0, $1049 = 0, $105 = 0, $1050 = 0, $1051 = 0, $1052 = 0, $1053 = 0, $1054 = 0, $1055 = 0, $1056 = 0;
 var $1057 = 0, $1058 = 0, $1059 = 0, $106 = 0, $1060 = 0, $1061 = 0, $1062 = 0, $1063 = 0, $1064 = 0, $1065 = 0, $1066 = 0, $1067 = 0, $1068 = 0, $1069 = 0, $107 = 0, $1070 = 0, $1071 = 0, $1072 = 0, $1073 = 0, $1074 = 0;
 var $1075 = 0, $1076 = 0, $1077 = 0, $1078 = 0, $1079 = 0, $108 = 0, $1080 = 0, $1081 = 0, $1082 = 0, $1083 = 0, $1084 = 0, $1085 = 0, $1086 = 0, $1087 = 0, $1088 = 0, $1089 = 0, $109 = 0, $1090 = 0, $1091 = 0, $1092 = 0;
 var $1093 = 0, $1094 = 0, $1095 = 0, $1096 = 0, $1097 = 0, $1098 = 0, $1099 = 0, $11 = 0, $110 = 0, $1100 = 0, $1101 = 0, $1102 = 0, $1103 = 0, $1104 = 0, $1105 = 0, $1106 = 0, $1107 = 0, $1108 = 0, $1109 = 0, $111 = 0;
 var $1110 = 0, $1111 = 0, $1112 = 0, $1113 = 0, $1114 = 0, $1115 = 0, $1116 = 0, $1117 = 0, $1118 = 0, $1119 = 0, $112 = 0, $1120 = 0, $1121 = 0, $1122 = 0, $1123 = 0, $1124 = 0, $1125 = 0, $1126 = 0, $1127 = 0, $1128 = 0;
 var $1129 = 0, $113 = 0, $1130 = 0, $1131 = 0, $1132 = 0, $1133 = 0, $1134 = 0, $1135 = 0, $1136 = 0, $1137 = 0, $1138 = 0, $1139 = 0, $114 = 0, $1140 = 0, $1141 = 0, $1142 = 0, $1143 = 0, $1144 = 0, $1145 = 0, $1146 = 0;
 var $1147 = 0, $1148 = 0, $1149 = 0, $115 = 0, $1150 = 0, $1151 = 0, $1152 = 0, $1153 = 0, $1154 = 0, $1155 = 0, $1156 = 0, $1157 = 0, $1158 = 0, $1159 = 0, $116 = 0, $1160 = 0, $1161 = 0, $1162 = 0, $1163 = 0, $1164 = 0;
 var $1165 = 0, $1166 = 0, $1167 = 0, $1168 = 0, $1169 = 0, $117 = 0, $1170 = 0, $1171 = 0, $1172 = 0, $1173 = 0, $1174 = 0, $1175 = 0, $1176 = 0, $1177 = 0, $1178 = 0, $1179 = 0, $118 = 0, $1180 = 0, $1181 = 0, $1182 = 0;
 var $1183 = 0, $1184 = 0, $1185 = 0, $1186 = 0, $1187 = 0, $1188 = 0, $1189 = 0, $119 = 0, $1190 = 0, $1191 = 0, $1192 = 0, $1193 = 0, $1194 = 0, $1195 = 0, $1196 = 0, $1197 = 0, $1198 = 0, $1199 = 0, $12 = 0, $120 = 0;
 var $1200 = 0, $1201 = 0, $1202 = 0, $1203 = 0, $1204 = 0, $1205 = 0, $1206 = 0, $1207 = 0, $1208 = 0, $1209 = 0, $121 = 0, $1210 = 0, $1211 = 0, $1212 = 0, $1213 = 0, $1214 = 0, $1215 = 0, $1216 = 0, $1217 = 0, $1218 = 0;
 var $1219 = 0, $122 = 0, $1220 = 0, $1221 = 0, $1222 = 0, $1223 = 0, $1224 = 0, $1225 = 0, $1226 = 0, $1227 = 0, $1228 = 0, $1229 = 0, $123 = 0, $1230 = 0, $1231 = 0, $1232 = 0, $1233 = 0, $1234 = 0, $1235 = 0, $1236 = 0;
 var $1237 = 0, $1238 = 0, $1239 = 0, $124 = 0, $1240 = 0, $1241 = 0, $1242 = 0, $1243 = 0, $1244 = 0, $1245 = 0, $1246 = 0, $1247 = 0, $1248 = 0, $1249 = 0, $125 = 0, $1250 = 0, $1251 = 0, $1252 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0;
 var $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0;
 var $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0;
 var $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0;
 var $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0;
 var $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0;
 var $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0;
 var $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0;
 var $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0;
 var $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0;
 var $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0;
 var $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0;
 var $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0;
 var $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0;
 var $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0;
 var $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0;
 var $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0;
 var $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0;
 var $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0;
 var $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0;
 var $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0;
 var $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0;
 var $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0;
 var $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0;
 var $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0;
 var $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0;
 var $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0;
 var $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0;
 var $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0;
 var $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0;
 var $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0;
 var $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0;
 var $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0;
 var $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0;
 var $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0;
 var $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0;
 var $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0;
 var $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0;
 var $830 = 0, $831 = 0, $832 = 0, $833 = 0, $834 = 0, $835 = 0, $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0;
 var $849 = 0, $85 = 0, $850 = 0, $851 = 0, $852 = 0, $853 = 0, $854 = 0, $855 = 0, $856 = 0, $857 = 0, $858 = 0, $859 = 0, $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0;
 var $867 = 0, $868 = 0, $869 = 0, $87 = 0, $870 = 0, $871 = 0, $872 = 0, $873 = 0, $874 = 0, $875 = 0, $876 = 0, $877 = 0, $878 = 0, $879 = 0, $88 = 0, $880 = 0, $881 = 0, $882 = 0, $883 = 0, $884 = 0;
 var $885 = 0, $886 = 0, $887 = 0, $888 = 0, $889 = 0, $89 = 0, $890 = 0, $891 = 0, $892 = 0, $893 = 0, $894 = 0, $895 = 0, $896 = 0, $897 = 0, $898 = 0, $899 = 0, $9 = 0, $90 = 0, $900 = 0, $901 = 0;
 var $902 = 0, $903 = 0, $904 = 0, $905 = 0, $906 = 0, $907 = 0, $908 = 0, $909 = 0, $91 = 0, $910 = 0, $911 = 0, $912 = 0, $913 = 0, $914 = 0, $915 = 0, $916 = 0, $917 = 0, $918 = 0, $919 = 0, $92 = 0;
 var $920 = 0, $921 = 0, $922 = 0, $923 = 0, $924 = 0, $925 = 0, $926 = 0, $927 = 0, $928 = 0, $929 = 0, $93 = 0, $930 = 0, $931 = 0, $932 = 0, $933 = 0, $934 = 0, $935 = 0, $936 = 0, $937 = 0, $938 = 0;
 var $939 = 0, $94 = 0, $940 = 0, $941 = 0, $942 = 0, $943 = 0, $944 = 0, $945 = 0, $946 = 0, $947 = 0, $948 = 0, $949 = 0, $95 = 0, $950 = 0, $951 = 0, $952 = 0, $953 = 0, $954 = 0, $955 = 0, $956 = 0;
 var $957 = 0, $958 = 0, $959 = 0, $96 = 0, $960 = 0, $961 = 0, $962 = 0, $963 = 0, $964 = 0, $965 = 0, $966 = 0, $967 = 0, $968 = 0, $969 = 0, $97 = 0, $970 = 0, $971 = 0, $972 = 0, $973 = 0, $974 = 0;
 var $975 = 0, $976 = 0, $977 = 0, $978 = 0, $979 = 0, $98 = 0, $980 = 0, $981 = 0, $982 = 0, $983 = 0, $984 = 0, $985 = 0, $986 = 0, $987 = 0, $988 = 0, $989 = 0, $99 = 0, $990 = 0, $991 = 0, $992 = 0;
 var $993 = 0, $994 = 0, $995 = 0, $996 = 0, $997 = 0, $998 = 0, $999 = 0, $div = 0, $div829 = 0, $div830 = 0, $div832 = 0, $div833 = 0, $div834 = 0, $div836 = 0, $div837 = 0, $div838 = 0, $div840 = 0, $div841 = 0, $div842 = 0, $div844 = 0;
 var $div845 = 0, $div846 = 0, $div848 = 0, $div849 = 0, $div850 = 0, $div852 = 0, $div853 = 0, $div854 = 0, $div856 = 0, $div857 = 0, $div858 = 0, $trunc = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$0>>2]|0;
 $6 = ((($0)) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($0)) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($0)) + 36|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($0)) + 56|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($0)) + 40|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ((($0)) + 44|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ((($15)) + 9|0);
 $19 = HEAP8[$18>>0]|0;
 $20 = $19&255;
 $21 = ((($17)) + 9|0);
 $22 = HEAP8[$21>>0]|0;
 $23 = $22&255;
 $24 = ((($17)) + 24|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)==(0);
 if ($26) {
  $133 = 0;
 } else {
  $27 = ((($0)) + 63|0);
  $28 = HEAP8[$27>>0]|0;
  $29 = $28&255;
  $133 = $29;
 }
 $30 = ((($15)) + 24|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = $31 ^ -1;
 $33 = $13 & $32;
 $34 = ($4|0)==(0);
 if ($34) {
  return;
 }
 $35 = (($2) + 7)|0;
 $36 = (($35|0) / 8)&-1;
 $trunc = $2&255;
 $37 = ((($15)) + 28|0);
 $38 = ((($15)) + 12|0);
 $39 = ((($15)) + 32|0);
 $40 = ((($15)) + 29|0);
 $41 = ((($15)) + 16|0);
 $42 = ((($15)) + 33|0);
 $43 = ((($15)) + 30|0);
 $44 = ((($15)) + 20|0);
 $45 = ((($15)) + 34|0);
 $46 = ((($17)) + 28|0);
 $47 = ((($17)) + 32|0);
 $48 = ((($17)) + 29|0);
 $49 = ((($17)) + 33|0);
 $50 = ((($17)) + 30|0);
 $51 = ((($17)) + 34|0);
 $52 = ((($17)) + 31|0);
 $53 = ((($17)) + 35|0);
 $$0794860 = $5;$$0795859 = $9;$$in = $4;
 L7: while(1) {
  $54 = (($$in) + -1)|0;
  $trunc$clear = $trunc & 7;
  switch ($trunc$clear<<24>>24) {
  case 0:  {
   $$0804 = $36;$$1 = $$0794860;$$1796 = $$0795859;
   label = 6;
   break;
  }
  case 7:  {
   $$1805 = $36;$$2 = $$0794860;$$2797 = $$0795859;
   label = 18;
   break;
  }
  case 6:  {
   $$2806 = $36;$$3 = $$0794860;$$3798 = $$0795859;
   label = 30;
   break;
  }
  case 5:  {
   $$3807 = $36;$$4 = $$0794860;$$4799 = $$0795859;
   label = 42;
   break;
  }
  case 4:  {
   $$4808 = $36;$$5 = $$0794860;$$5800 = $$0795859;
   label = 54;
   break;
  }
  case 3:  {
   $$5809 = $36;$$6 = $$0794860;$$6801 = $$0795859;
   label = 66;
   break;
  }
  case 2:  {
   $$6810 = $36;$$7 = $$0794860;$$7802 = $$0795859;
   label = 78;
   break;
  }
  case 1:  {
   $$7811 = $36;$$8 = $$0794860;$$8803 = $$0795859;
   label = 90;
   break;
  }
  default: {
   label = 102;
   break L7;
  }
  }
  while(1) {
   if ((label|0) == 6) {
    label = 0;
    switch ($19<<24>>24) {
    case 1:  {
     $55 = HEAP8[$$1>>0]|0;
     $56 = $55&255;
     $$0812 = $56;
     break;
    }
    case 2:  {
     $57 = HEAP16[$$1>>1]|0;
     $58 = $57&65535;
     $$0812 = $58;
     break;
    }
    case 3:  {
     $59 = HEAP8[$$1>>0]|0;
     $60 = $59&255;
     $61 = ((($$1)) + 1|0);
     $62 = HEAP8[$61>>0]|0;
     $63 = $62&255;
     $64 = $63 << 8;
     $65 = $64 | $60;
     $66 = ((($$1)) + 2|0);
     $67 = HEAP8[$66>>0]|0;
     $68 = $67&255;
     $69 = $68 << 16;
     $70 = $65 | $69;
     $$0812 = $70;
     break;
    }
    case 4:  {
     $71 = HEAP32[$$1>>2]|0;
     $$0812 = $71;
     break;
    }
    default: {
     $$0812 = 0;
    }
    }
    $72 = $$0812 & $32;
    $73 = ($72|0)==($33|0);
    L18: do {
     if (!($73)) {
      $74 = HEAP8[$37>>0]|0;
      $75 = $74&255;
      $76 = (79212 + ($75<<2)|0);
      $77 = HEAP32[$76>>2]|0;
      $78 = HEAP32[$38>>2]|0;
      $79 = $78 & $$0812;
      $80 = HEAP8[$39>>0]|0;
      $81 = $80&255;
      $82 = $79 >>> $81;
      $83 = (($77) + ($82)|0);
      $84 = HEAP8[$83>>0]|0;
      $85 = $84&255;
      $86 = HEAP8[$40>>0]|0;
      $87 = $86&255;
      $88 = (79212 + ($87<<2)|0);
      $89 = HEAP32[$88>>2]|0;
      $90 = HEAP32[$41>>2]|0;
      $91 = $90 & $$0812;
      $92 = HEAP8[$42>>0]|0;
      $93 = $92&255;
      $94 = $91 >>> $93;
      $95 = (($89) + ($94)|0);
      $96 = HEAP8[$95>>0]|0;
      $97 = $96&255;
      $98 = HEAP8[$43>>0]|0;
      $99 = $98&255;
      $100 = (79212 + ($99<<2)|0);
      $101 = HEAP32[$100>>2]|0;
      $102 = HEAP32[$44>>2]|0;
      $103 = $102 & $$0812;
      $104 = HEAP8[$45>>0]|0;
      $105 = $104&255;
      $106 = $103 >>> $105;
      $107 = (($101) + ($106)|0);
      $108 = HEAP8[$107>>0]|0;
      $109 = $108&255;
      switch ($22<<24>>24) {
      case 1:  {
       $110 = HEAP8[$46>>0]|0;
       $111 = $110&255;
       $112 = $85 >>> $111;
       $113 = HEAP8[$47>>0]|0;
       $114 = $113&255;
       $115 = $112 << $114;
       $116 = HEAP8[$48>>0]|0;
       $117 = $116&255;
       $118 = $97 >>> $117;
       $119 = HEAP8[$49>>0]|0;
       $120 = $119&255;
       $121 = $118 << $120;
       $122 = $121 | $115;
       $123 = HEAP8[$50>>0]|0;
       $124 = $123&255;
       $125 = $109 >>> $124;
       $126 = HEAP8[$51>>0]|0;
       $127 = $126&255;
       $128 = $125 << $127;
       $129 = $122 | $128;
       $130 = HEAP8[$52>>0]|0;
       $131 = $130&255;
       $132 = $133 >>> $131;
       $134 = HEAP8[$53>>0]|0;
       $135 = $134&255;
       $136 = $132 << $135;
       $137 = $129 | $136;
       $138 = $137&255;
       HEAP8[$$1796>>0] = $138;
       break L18;
       break;
      }
      case 2:  {
       $139 = HEAP8[$46>>0]|0;
       $140 = $139&255;
       $141 = $85 >>> $140;
       $142 = HEAP8[$47>>0]|0;
       $143 = $142&255;
       $144 = $141 << $143;
       $145 = HEAP8[$48>>0]|0;
       $146 = $145&255;
       $147 = $97 >>> $146;
       $148 = HEAP8[$49>>0]|0;
       $149 = $148&255;
       $150 = $147 << $149;
       $151 = $150 | $144;
       $152 = HEAP8[$50>>0]|0;
       $153 = $152&255;
       $154 = $109 >>> $153;
       $155 = HEAP8[$51>>0]|0;
       $156 = $155&255;
       $157 = $154 << $156;
       $158 = $151 | $157;
       $159 = HEAP8[$52>>0]|0;
       $160 = $159&255;
       $161 = $133 >>> $160;
       $162 = HEAP8[$53>>0]|0;
       $163 = $162&255;
       $164 = $161 << $163;
       $165 = $158 | $164;
       $166 = $165&65535;
       HEAP16[$$1796>>1] = $166;
       break L18;
       break;
      }
      case 3:  {
       $167 = HEAP8[$47>>0]|0;
       $div852 = ($167&255) >>> 3;
       $168 = $div852&255;
       $169 = (($$1796) + ($168)|0);
       HEAP8[$169>>0] = $84;
       $170 = HEAP8[$49>>0]|0;
       $div853 = ($170&255) >>> 3;
       $171 = $div853&255;
       $172 = (($$1796) + ($171)|0);
       HEAP8[$172>>0] = $96;
       $173 = HEAP8[$51>>0]|0;
       $div854 = ($173&255) >>> 3;
       $174 = $div854&255;
       $175 = (($$1796) + ($174)|0);
       HEAP8[$175>>0] = $108;
       break L18;
       break;
      }
      case 4:  {
       $176 = HEAP8[$46>>0]|0;
       $177 = $176&255;
       $178 = $85 >>> $177;
       $179 = HEAP8[$47>>0]|0;
       $180 = $179&255;
       $181 = $178 << $180;
       $182 = HEAP8[$48>>0]|0;
       $183 = $182&255;
       $184 = $97 >>> $183;
       $185 = HEAP8[$49>>0]|0;
       $186 = $185&255;
       $187 = $184 << $186;
       $188 = $187 | $181;
       $189 = HEAP8[$50>>0]|0;
       $190 = $189&255;
       $191 = $109 >>> $190;
       $192 = HEAP8[$51>>0]|0;
       $193 = $192&255;
       $194 = $191 << $193;
       $195 = $188 | $194;
       $196 = HEAP8[$52>>0]|0;
       $197 = $196&255;
       $198 = $133 >>> $197;
       $199 = HEAP8[$53>>0]|0;
       $200 = $199&255;
       $201 = $198 << $200;
       $202 = $195 | $201;
       HEAP32[$$1796>>2] = $202;
       break L18;
       break;
      }
      default: {
       break L18;
      }
      }
     }
    } while(0);
    $203 = (($$1796) + ($23)|0);
    $204 = (($$1) + ($20)|0);
    $$1805 = $$0804;$$2 = $204;$$2797 = $203;
    label = 18;
    continue;
   }
   else if ((label|0) == 18) {
    label = 0;
    switch ($19<<24>>24) {
    case 1:  {
     $205 = HEAP8[$$2>>0]|0;
     $206 = $205&255;
     $$0813 = $206;
     break;
    }
    case 2:  {
     $207 = HEAP16[$$2>>1]|0;
     $208 = $207&65535;
     $$0813 = $208;
     break;
    }
    case 3:  {
     $209 = HEAP8[$$2>>0]|0;
     $210 = $209&255;
     $211 = ((($$2)) + 1|0);
     $212 = HEAP8[$211>>0]|0;
     $213 = $212&255;
     $214 = $213 << 8;
     $215 = $214 | $210;
     $216 = ((($$2)) + 2|0);
     $217 = HEAP8[$216>>0]|0;
     $218 = $217&255;
     $219 = $218 << 16;
     $220 = $215 | $219;
     $$0813 = $220;
     break;
    }
    case 4:  {
     $221 = HEAP32[$$2>>2]|0;
     $$0813 = $221;
     break;
    }
    default: {
     $$0813 = 0;
    }
    }
    $222 = $$0813 & $32;
    $223 = ($222|0)==($33|0);
    L33: do {
     if (!($223)) {
      $224 = HEAP8[$37>>0]|0;
      $225 = $224&255;
      $226 = (79212 + ($225<<2)|0);
      $227 = HEAP32[$226>>2]|0;
      $228 = HEAP32[$38>>2]|0;
      $229 = $228 & $$0813;
      $230 = HEAP8[$39>>0]|0;
      $231 = $230&255;
      $232 = $229 >>> $231;
      $233 = (($227) + ($232)|0);
      $234 = HEAP8[$233>>0]|0;
      $235 = $234&255;
      $236 = HEAP8[$40>>0]|0;
      $237 = $236&255;
      $238 = (79212 + ($237<<2)|0);
      $239 = HEAP32[$238>>2]|0;
      $240 = HEAP32[$41>>2]|0;
      $241 = $240 & $$0813;
      $242 = HEAP8[$42>>0]|0;
      $243 = $242&255;
      $244 = $241 >>> $243;
      $245 = (($239) + ($244)|0);
      $246 = HEAP8[$245>>0]|0;
      $247 = $246&255;
      $248 = HEAP8[$43>>0]|0;
      $249 = $248&255;
      $250 = (79212 + ($249<<2)|0);
      $251 = HEAP32[$250>>2]|0;
      $252 = HEAP32[$44>>2]|0;
      $253 = $252 & $$0813;
      $254 = HEAP8[$45>>0]|0;
      $255 = $254&255;
      $256 = $253 >>> $255;
      $257 = (($251) + ($256)|0);
      $258 = HEAP8[$257>>0]|0;
      $259 = $258&255;
      switch ($22<<24>>24) {
      case 1:  {
       $260 = HEAP8[$46>>0]|0;
       $261 = $260&255;
       $262 = $235 >>> $261;
       $263 = HEAP8[$47>>0]|0;
       $264 = $263&255;
       $265 = $262 << $264;
       $266 = HEAP8[$48>>0]|0;
       $267 = $266&255;
       $268 = $247 >>> $267;
       $269 = HEAP8[$49>>0]|0;
       $270 = $269&255;
       $271 = $268 << $270;
       $272 = $271 | $265;
       $273 = HEAP8[$50>>0]|0;
       $274 = $273&255;
       $275 = $259 >>> $274;
       $276 = HEAP8[$51>>0]|0;
       $277 = $276&255;
       $278 = $275 << $277;
       $279 = $272 | $278;
       $280 = HEAP8[$52>>0]|0;
       $281 = $280&255;
       $282 = $133 >>> $281;
       $283 = HEAP8[$53>>0]|0;
       $284 = $283&255;
       $285 = $282 << $284;
       $286 = $279 | $285;
       $287 = $286&255;
       HEAP8[$$2797>>0] = $287;
       break L33;
       break;
      }
      case 2:  {
       $288 = HEAP8[$46>>0]|0;
       $289 = $288&255;
       $290 = $235 >>> $289;
       $291 = HEAP8[$47>>0]|0;
       $292 = $291&255;
       $293 = $290 << $292;
       $294 = HEAP8[$48>>0]|0;
       $295 = $294&255;
       $296 = $247 >>> $295;
       $297 = HEAP8[$49>>0]|0;
       $298 = $297&255;
       $299 = $296 << $298;
       $300 = $299 | $293;
       $301 = HEAP8[$50>>0]|0;
       $302 = $301&255;
       $303 = $259 >>> $302;
       $304 = HEAP8[$51>>0]|0;
       $305 = $304&255;
       $306 = $303 << $305;
       $307 = $300 | $306;
       $308 = HEAP8[$52>>0]|0;
       $309 = $308&255;
       $310 = $133 >>> $309;
       $311 = HEAP8[$53>>0]|0;
       $312 = $311&255;
       $313 = $310 << $312;
       $314 = $307 | $313;
       $315 = $314&65535;
       HEAP16[$$2797>>1] = $315;
       break L33;
       break;
      }
      case 3:  {
       $316 = HEAP8[$47>>0]|0;
       $div848 = ($316&255) >>> 3;
       $317 = $div848&255;
       $318 = (($$2797) + ($317)|0);
       HEAP8[$318>>0] = $234;
       $319 = HEAP8[$49>>0]|0;
       $div849 = ($319&255) >>> 3;
       $320 = $div849&255;
       $321 = (($$2797) + ($320)|0);
       HEAP8[$321>>0] = $246;
       $322 = HEAP8[$51>>0]|0;
       $div850 = ($322&255) >>> 3;
       $323 = $div850&255;
       $324 = (($$2797) + ($323)|0);
       HEAP8[$324>>0] = $258;
       break L33;
       break;
      }
      case 4:  {
       $325 = HEAP8[$46>>0]|0;
       $326 = $325&255;
       $327 = $235 >>> $326;
       $328 = HEAP8[$47>>0]|0;
       $329 = $328&255;
       $330 = $327 << $329;
       $331 = HEAP8[$48>>0]|0;
       $332 = $331&255;
       $333 = $247 >>> $332;
       $334 = HEAP8[$49>>0]|0;
       $335 = $334&255;
       $336 = $333 << $335;
       $337 = $336 | $330;
       $338 = HEAP8[$50>>0]|0;
       $339 = $338&255;
       $340 = $259 >>> $339;
       $341 = HEAP8[$51>>0]|0;
       $342 = $341&255;
       $343 = $340 << $342;
       $344 = $337 | $343;
       $345 = HEAP8[$52>>0]|0;
       $346 = $345&255;
       $347 = $133 >>> $346;
       $348 = HEAP8[$53>>0]|0;
       $349 = $348&255;
       $350 = $347 << $349;
       $351 = $344 | $350;
       HEAP32[$$2797>>2] = $351;
       break L33;
       break;
      }
      default: {
       break L33;
      }
      }
     }
    } while(0);
    $352 = (($$2797) + ($23)|0);
    $353 = (($$2) + ($20)|0);
    $$2806 = $$1805;$$3 = $353;$$3798 = $352;
    label = 30;
    continue;
   }
   else if ((label|0) == 30) {
    label = 0;
    switch ($19<<24>>24) {
    case 1:  {
     $354 = HEAP8[$$3>>0]|0;
     $355 = $354&255;
     $$0815 = $355;
     break;
    }
    case 2:  {
     $356 = HEAP16[$$3>>1]|0;
     $357 = $356&65535;
     $$0815 = $357;
     break;
    }
    case 3:  {
     $358 = HEAP8[$$3>>0]|0;
     $359 = $358&255;
     $360 = ((($$3)) + 1|0);
     $361 = HEAP8[$360>>0]|0;
     $362 = $361&255;
     $363 = $362 << 8;
     $364 = $363 | $359;
     $365 = ((($$3)) + 2|0);
     $366 = HEAP8[$365>>0]|0;
     $367 = $366&255;
     $368 = $367 << 16;
     $369 = $364 | $368;
     $$0815 = $369;
     break;
    }
    case 4:  {
     $370 = HEAP32[$$3>>2]|0;
     $$0815 = $370;
     break;
    }
    default: {
     $$0815 = 0;
    }
    }
    $371 = $$0815 & $32;
    $372 = ($371|0)==($33|0);
    L48: do {
     if (!($372)) {
      $373 = HEAP8[$37>>0]|0;
      $374 = $373&255;
      $375 = (79212 + ($374<<2)|0);
      $376 = HEAP32[$375>>2]|0;
      $377 = HEAP32[$38>>2]|0;
      $378 = $377 & $$0815;
      $379 = HEAP8[$39>>0]|0;
      $380 = $379&255;
      $381 = $378 >>> $380;
      $382 = (($376) + ($381)|0);
      $383 = HEAP8[$382>>0]|0;
      $384 = $383&255;
      $385 = HEAP8[$40>>0]|0;
      $386 = $385&255;
      $387 = (79212 + ($386<<2)|0);
      $388 = HEAP32[$387>>2]|0;
      $389 = HEAP32[$41>>2]|0;
      $390 = $389 & $$0815;
      $391 = HEAP8[$42>>0]|0;
      $392 = $391&255;
      $393 = $390 >>> $392;
      $394 = (($388) + ($393)|0);
      $395 = HEAP8[$394>>0]|0;
      $396 = $395&255;
      $397 = HEAP8[$43>>0]|0;
      $398 = $397&255;
      $399 = (79212 + ($398<<2)|0);
      $400 = HEAP32[$399>>2]|0;
      $401 = HEAP32[$44>>2]|0;
      $402 = $401 & $$0815;
      $403 = HEAP8[$45>>0]|0;
      $404 = $403&255;
      $405 = $402 >>> $404;
      $406 = (($400) + ($405)|0);
      $407 = HEAP8[$406>>0]|0;
      $408 = $407&255;
      switch ($22<<24>>24) {
      case 1:  {
       $409 = HEAP8[$46>>0]|0;
       $410 = $409&255;
       $411 = $384 >>> $410;
       $412 = HEAP8[$47>>0]|0;
       $413 = $412&255;
       $414 = $411 << $413;
       $415 = HEAP8[$48>>0]|0;
       $416 = $415&255;
       $417 = $396 >>> $416;
       $418 = HEAP8[$49>>0]|0;
       $419 = $418&255;
       $420 = $417 << $419;
       $421 = $420 | $414;
       $422 = HEAP8[$50>>0]|0;
       $423 = $422&255;
       $424 = $408 >>> $423;
       $425 = HEAP8[$51>>0]|0;
       $426 = $425&255;
       $427 = $424 << $426;
       $428 = $421 | $427;
       $429 = HEAP8[$52>>0]|0;
       $430 = $429&255;
       $431 = $133 >>> $430;
       $432 = HEAP8[$53>>0]|0;
       $433 = $432&255;
       $434 = $431 << $433;
       $435 = $428 | $434;
       $436 = $435&255;
       HEAP8[$$3798>>0] = $436;
       break L48;
       break;
      }
      case 2:  {
       $437 = HEAP8[$46>>0]|0;
       $438 = $437&255;
       $439 = $384 >>> $438;
       $440 = HEAP8[$47>>0]|0;
       $441 = $440&255;
       $442 = $439 << $441;
       $443 = HEAP8[$48>>0]|0;
       $444 = $443&255;
       $445 = $396 >>> $444;
       $446 = HEAP8[$49>>0]|0;
       $447 = $446&255;
       $448 = $445 << $447;
       $449 = $448 | $442;
       $450 = HEAP8[$50>>0]|0;
       $451 = $450&255;
       $452 = $408 >>> $451;
       $453 = HEAP8[$51>>0]|0;
       $454 = $453&255;
       $455 = $452 << $454;
       $456 = $449 | $455;
       $457 = HEAP8[$52>>0]|0;
       $458 = $457&255;
       $459 = $133 >>> $458;
       $460 = HEAP8[$53>>0]|0;
       $461 = $460&255;
       $462 = $459 << $461;
       $463 = $456 | $462;
       $464 = $463&65535;
       HEAP16[$$3798>>1] = $464;
       break L48;
       break;
      }
      case 3:  {
       $465 = HEAP8[$47>>0]|0;
       $div844 = ($465&255) >>> 3;
       $466 = $div844&255;
       $467 = (($$3798) + ($466)|0);
       HEAP8[$467>>0] = $383;
       $468 = HEAP8[$49>>0]|0;
       $div845 = ($468&255) >>> 3;
       $469 = $div845&255;
       $470 = (($$3798) + ($469)|0);
       HEAP8[$470>>0] = $395;
       $471 = HEAP8[$51>>0]|0;
       $div846 = ($471&255) >>> 3;
       $472 = $div846&255;
       $473 = (($$3798) + ($472)|0);
       HEAP8[$473>>0] = $407;
       break L48;
       break;
      }
      case 4:  {
       $474 = HEAP8[$46>>0]|0;
       $475 = $474&255;
       $476 = $384 >>> $475;
       $477 = HEAP8[$47>>0]|0;
       $478 = $477&255;
       $479 = $476 << $478;
       $480 = HEAP8[$48>>0]|0;
       $481 = $480&255;
       $482 = $396 >>> $481;
       $483 = HEAP8[$49>>0]|0;
       $484 = $483&255;
       $485 = $482 << $484;
       $486 = $485 | $479;
       $487 = HEAP8[$50>>0]|0;
       $488 = $487&255;
       $489 = $408 >>> $488;
       $490 = HEAP8[$51>>0]|0;
       $491 = $490&255;
       $492 = $489 << $491;
       $493 = $486 | $492;
       $494 = HEAP8[$52>>0]|0;
       $495 = $494&255;
       $496 = $133 >>> $495;
       $497 = HEAP8[$53>>0]|0;
       $498 = $497&255;
       $499 = $496 << $498;
       $500 = $493 | $499;
       HEAP32[$$3798>>2] = $500;
       break L48;
       break;
      }
      default: {
       break L48;
      }
      }
     }
    } while(0);
    $501 = (($$3798) + ($23)|0);
    $502 = (($$3) + ($20)|0);
    $$3807 = $$2806;$$4 = $502;$$4799 = $501;
    label = 42;
    continue;
   }
   else if ((label|0) == 42) {
    label = 0;
    switch ($19<<24>>24) {
    case 1:  {
     $503 = HEAP8[$$4>>0]|0;
     $504 = $503&255;
     $$0816 = $504;
     break;
    }
    case 2:  {
     $505 = HEAP16[$$4>>1]|0;
     $506 = $505&65535;
     $$0816 = $506;
     break;
    }
    case 3:  {
     $507 = HEAP8[$$4>>0]|0;
     $508 = $507&255;
     $509 = ((($$4)) + 1|0);
     $510 = HEAP8[$509>>0]|0;
     $511 = $510&255;
     $512 = $511 << 8;
     $513 = $512 | $508;
     $514 = ((($$4)) + 2|0);
     $515 = HEAP8[$514>>0]|0;
     $516 = $515&255;
     $517 = $516 << 16;
     $518 = $513 | $517;
     $$0816 = $518;
     break;
    }
    case 4:  {
     $519 = HEAP32[$$4>>2]|0;
     $$0816 = $519;
     break;
    }
    default: {
     $$0816 = 0;
    }
    }
    $520 = $$0816 & $32;
    $521 = ($520|0)==($33|0);
    L63: do {
     if (!($521)) {
      $522 = HEAP8[$37>>0]|0;
      $523 = $522&255;
      $524 = (79212 + ($523<<2)|0);
      $525 = HEAP32[$524>>2]|0;
      $526 = HEAP32[$38>>2]|0;
      $527 = $526 & $$0816;
      $528 = HEAP8[$39>>0]|0;
      $529 = $528&255;
      $530 = $527 >>> $529;
      $531 = (($525) + ($530)|0);
      $532 = HEAP8[$531>>0]|0;
      $533 = $532&255;
      $534 = HEAP8[$40>>0]|0;
      $535 = $534&255;
      $536 = (79212 + ($535<<2)|0);
      $537 = HEAP32[$536>>2]|0;
      $538 = HEAP32[$41>>2]|0;
      $539 = $538 & $$0816;
      $540 = HEAP8[$42>>0]|0;
      $541 = $540&255;
      $542 = $539 >>> $541;
      $543 = (($537) + ($542)|0);
      $544 = HEAP8[$543>>0]|0;
      $545 = $544&255;
      $546 = HEAP8[$43>>0]|0;
      $547 = $546&255;
      $548 = (79212 + ($547<<2)|0);
      $549 = HEAP32[$548>>2]|0;
      $550 = HEAP32[$44>>2]|0;
      $551 = $550 & $$0816;
      $552 = HEAP8[$45>>0]|0;
      $553 = $552&255;
      $554 = $551 >>> $553;
      $555 = (($549) + ($554)|0);
      $556 = HEAP8[$555>>0]|0;
      $557 = $556&255;
      switch ($22<<24>>24) {
      case 1:  {
       $558 = HEAP8[$46>>0]|0;
       $559 = $558&255;
       $560 = $533 >>> $559;
       $561 = HEAP8[$47>>0]|0;
       $562 = $561&255;
       $563 = $560 << $562;
       $564 = HEAP8[$48>>0]|0;
       $565 = $564&255;
       $566 = $545 >>> $565;
       $567 = HEAP8[$49>>0]|0;
       $568 = $567&255;
       $569 = $566 << $568;
       $570 = $569 | $563;
       $571 = HEAP8[$50>>0]|0;
       $572 = $571&255;
       $573 = $557 >>> $572;
       $574 = HEAP8[$51>>0]|0;
       $575 = $574&255;
       $576 = $573 << $575;
       $577 = $570 | $576;
       $578 = HEAP8[$52>>0]|0;
       $579 = $578&255;
       $580 = $133 >>> $579;
       $581 = HEAP8[$53>>0]|0;
       $582 = $581&255;
       $583 = $580 << $582;
       $584 = $577 | $583;
       $585 = $584&255;
       HEAP8[$$4799>>0] = $585;
       break L63;
       break;
      }
      case 2:  {
       $586 = HEAP8[$46>>0]|0;
       $587 = $586&255;
       $588 = $533 >>> $587;
       $589 = HEAP8[$47>>0]|0;
       $590 = $589&255;
       $591 = $588 << $590;
       $592 = HEAP8[$48>>0]|0;
       $593 = $592&255;
       $594 = $545 >>> $593;
       $595 = HEAP8[$49>>0]|0;
       $596 = $595&255;
       $597 = $594 << $596;
       $598 = $597 | $591;
       $599 = HEAP8[$50>>0]|0;
       $600 = $599&255;
       $601 = $557 >>> $600;
       $602 = HEAP8[$51>>0]|0;
       $603 = $602&255;
       $604 = $601 << $603;
       $605 = $598 | $604;
       $606 = HEAP8[$52>>0]|0;
       $607 = $606&255;
       $608 = $133 >>> $607;
       $609 = HEAP8[$53>>0]|0;
       $610 = $609&255;
       $611 = $608 << $610;
       $612 = $605 | $611;
       $613 = $612&65535;
       HEAP16[$$4799>>1] = $613;
       break L63;
       break;
      }
      case 3:  {
       $614 = HEAP8[$47>>0]|0;
       $div840 = ($614&255) >>> 3;
       $615 = $div840&255;
       $616 = (($$4799) + ($615)|0);
       HEAP8[$616>>0] = $532;
       $617 = HEAP8[$49>>0]|0;
       $div841 = ($617&255) >>> 3;
       $618 = $div841&255;
       $619 = (($$4799) + ($618)|0);
       HEAP8[$619>>0] = $544;
       $620 = HEAP8[$51>>0]|0;
       $div842 = ($620&255) >>> 3;
       $621 = $div842&255;
       $622 = (($$4799) + ($621)|0);
       HEAP8[$622>>0] = $556;
       break L63;
       break;
      }
      case 4:  {
       $623 = HEAP8[$46>>0]|0;
       $624 = $623&255;
       $625 = $533 >>> $624;
       $626 = HEAP8[$47>>0]|0;
       $627 = $626&255;
       $628 = $625 << $627;
       $629 = HEAP8[$48>>0]|0;
       $630 = $629&255;
       $631 = $545 >>> $630;
       $632 = HEAP8[$49>>0]|0;
       $633 = $632&255;
       $634 = $631 << $633;
       $635 = $634 | $628;
       $636 = HEAP8[$50>>0]|0;
       $637 = $636&255;
       $638 = $557 >>> $637;
       $639 = HEAP8[$51>>0]|0;
       $640 = $639&255;
       $641 = $638 << $640;
       $642 = $635 | $641;
       $643 = HEAP8[$52>>0]|0;
       $644 = $643&255;
       $645 = $133 >>> $644;
       $646 = HEAP8[$53>>0]|0;
       $647 = $646&255;
       $648 = $645 << $647;
       $649 = $642 | $648;
       HEAP32[$$4799>>2] = $649;
       break L63;
       break;
      }
      default: {
       break L63;
      }
      }
     }
    } while(0);
    $650 = (($$4799) + ($23)|0);
    $651 = (($$4) + ($20)|0);
    $$4808 = $$3807;$$5 = $651;$$5800 = $650;
    label = 54;
    continue;
   }
   else if ((label|0) == 54) {
    label = 0;
    switch ($19<<24>>24) {
    case 1:  {
     $652 = HEAP8[$$5>>0]|0;
     $653 = $652&255;
     $$0817 = $653;
     break;
    }
    case 2:  {
     $654 = HEAP16[$$5>>1]|0;
     $655 = $654&65535;
     $$0817 = $655;
     break;
    }
    case 3:  {
     $656 = HEAP8[$$5>>0]|0;
     $657 = $656&255;
     $658 = ((($$5)) + 1|0);
     $659 = HEAP8[$658>>0]|0;
     $660 = $659&255;
     $661 = $660 << 8;
     $662 = $661 | $657;
     $663 = ((($$5)) + 2|0);
     $664 = HEAP8[$663>>0]|0;
     $665 = $664&255;
     $666 = $665 << 16;
     $667 = $662 | $666;
     $$0817 = $667;
     break;
    }
    case 4:  {
     $668 = HEAP32[$$5>>2]|0;
     $$0817 = $668;
     break;
    }
    default: {
     $$0817 = 0;
    }
    }
    $669 = $$0817 & $32;
    $670 = ($669|0)==($33|0);
    L78: do {
     if (!($670)) {
      $671 = HEAP8[$37>>0]|0;
      $672 = $671&255;
      $673 = (79212 + ($672<<2)|0);
      $674 = HEAP32[$673>>2]|0;
      $675 = HEAP32[$38>>2]|0;
      $676 = $675 & $$0817;
      $677 = HEAP8[$39>>0]|0;
      $678 = $677&255;
      $679 = $676 >>> $678;
      $680 = (($674) + ($679)|0);
      $681 = HEAP8[$680>>0]|0;
      $682 = $681&255;
      $683 = HEAP8[$40>>0]|0;
      $684 = $683&255;
      $685 = (79212 + ($684<<2)|0);
      $686 = HEAP32[$685>>2]|0;
      $687 = HEAP32[$41>>2]|0;
      $688 = $687 & $$0817;
      $689 = HEAP8[$42>>0]|0;
      $690 = $689&255;
      $691 = $688 >>> $690;
      $692 = (($686) + ($691)|0);
      $693 = HEAP8[$692>>0]|0;
      $694 = $693&255;
      $695 = HEAP8[$43>>0]|0;
      $696 = $695&255;
      $697 = (79212 + ($696<<2)|0);
      $698 = HEAP32[$697>>2]|0;
      $699 = HEAP32[$44>>2]|0;
      $700 = $699 & $$0817;
      $701 = HEAP8[$45>>0]|0;
      $702 = $701&255;
      $703 = $700 >>> $702;
      $704 = (($698) + ($703)|0);
      $705 = HEAP8[$704>>0]|0;
      $706 = $705&255;
      switch ($22<<24>>24) {
      case 1:  {
       $707 = HEAP8[$46>>0]|0;
       $708 = $707&255;
       $709 = $682 >>> $708;
       $710 = HEAP8[$47>>0]|0;
       $711 = $710&255;
       $712 = $709 << $711;
       $713 = HEAP8[$48>>0]|0;
       $714 = $713&255;
       $715 = $694 >>> $714;
       $716 = HEAP8[$49>>0]|0;
       $717 = $716&255;
       $718 = $715 << $717;
       $719 = $718 | $712;
       $720 = HEAP8[$50>>0]|0;
       $721 = $720&255;
       $722 = $706 >>> $721;
       $723 = HEAP8[$51>>0]|0;
       $724 = $723&255;
       $725 = $722 << $724;
       $726 = $719 | $725;
       $727 = HEAP8[$52>>0]|0;
       $728 = $727&255;
       $729 = $133 >>> $728;
       $730 = HEAP8[$53>>0]|0;
       $731 = $730&255;
       $732 = $729 << $731;
       $733 = $726 | $732;
       $734 = $733&255;
       HEAP8[$$5800>>0] = $734;
       break L78;
       break;
      }
      case 2:  {
       $735 = HEAP8[$46>>0]|0;
       $736 = $735&255;
       $737 = $682 >>> $736;
       $738 = HEAP8[$47>>0]|0;
       $739 = $738&255;
       $740 = $737 << $739;
       $741 = HEAP8[$48>>0]|0;
       $742 = $741&255;
       $743 = $694 >>> $742;
       $744 = HEAP8[$49>>0]|0;
       $745 = $744&255;
       $746 = $743 << $745;
       $747 = $746 | $740;
       $748 = HEAP8[$50>>0]|0;
       $749 = $748&255;
       $750 = $706 >>> $749;
       $751 = HEAP8[$51>>0]|0;
       $752 = $751&255;
       $753 = $750 << $752;
       $754 = $747 | $753;
       $755 = HEAP8[$52>>0]|0;
       $756 = $755&255;
       $757 = $133 >>> $756;
       $758 = HEAP8[$53>>0]|0;
       $759 = $758&255;
       $760 = $757 << $759;
       $761 = $754 | $760;
       $762 = $761&65535;
       HEAP16[$$5800>>1] = $762;
       break L78;
       break;
      }
      case 3:  {
       $763 = HEAP8[$47>>0]|0;
       $div836 = ($763&255) >>> 3;
       $764 = $div836&255;
       $765 = (($$5800) + ($764)|0);
       HEAP8[$765>>0] = $681;
       $766 = HEAP8[$49>>0]|0;
       $div837 = ($766&255) >>> 3;
       $767 = $div837&255;
       $768 = (($$5800) + ($767)|0);
       HEAP8[$768>>0] = $693;
       $769 = HEAP8[$51>>0]|0;
       $div838 = ($769&255) >>> 3;
       $770 = $div838&255;
       $771 = (($$5800) + ($770)|0);
       HEAP8[$771>>0] = $705;
       break L78;
       break;
      }
      case 4:  {
       $772 = HEAP8[$46>>0]|0;
       $773 = $772&255;
       $774 = $682 >>> $773;
       $775 = HEAP8[$47>>0]|0;
       $776 = $775&255;
       $777 = $774 << $776;
       $778 = HEAP8[$48>>0]|0;
       $779 = $778&255;
       $780 = $694 >>> $779;
       $781 = HEAP8[$49>>0]|0;
       $782 = $781&255;
       $783 = $780 << $782;
       $784 = $783 | $777;
       $785 = HEAP8[$50>>0]|0;
       $786 = $785&255;
       $787 = $706 >>> $786;
       $788 = HEAP8[$51>>0]|0;
       $789 = $788&255;
       $790 = $787 << $789;
       $791 = $784 | $790;
       $792 = HEAP8[$52>>0]|0;
       $793 = $792&255;
       $794 = $133 >>> $793;
       $795 = HEAP8[$53>>0]|0;
       $796 = $795&255;
       $797 = $794 << $796;
       $798 = $791 | $797;
       HEAP32[$$5800>>2] = $798;
       break L78;
       break;
      }
      default: {
       break L78;
      }
      }
     }
    } while(0);
    $799 = (($$5800) + ($23)|0);
    $800 = (($$5) + ($20)|0);
    $$5809 = $$4808;$$6 = $800;$$6801 = $799;
    label = 66;
    continue;
   }
   else if ((label|0) == 66) {
    label = 0;
    switch ($19<<24>>24) {
    case 1:  {
     $801 = HEAP8[$$6>>0]|0;
     $802 = $801&255;
     $$0818 = $802;
     break;
    }
    case 2:  {
     $803 = HEAP16[$$6>>1]|0;
     $804 = $803&65535;
     $$0818 = $804;
     break;
    }
    case 3:  {
     $805 = HEAP8[$$6>>0]|0;
     $806 = $805&255;
     $807 = ((($$6)) + 1|0);
     $808 = HEAP8[$807>>0]|0;
     $809 = $808&255;
     $810 = $809 << 8;
     $811 = $810 | $806;
     $812 = ((($$6)) + 2|0);
     $813 = HEAP8[$812>>0]|0;
     $814 = $813&255;
     $815 = $814 << 16;
     $816 = $811 | $815;
     $$0818 = $816;
     break;
    }
    case 4:  {
     $817 = HEAP32[$$6>>2]|0;
     $$0818 = $817;
     break;
    }
    default: {
     $$0818 = 0;
    }
    }
    $818 = $$0818 & $32;
    $819 = ($818|0)==($33|0);
    L93: do {
     if (!($819)) {
      $820 = HEAP8[$37>>0]|0;
      $821 = $820&255;
      $822 = (79212 + ($821<<2)|0);
      $823 = HEAP32[$822>>2]|0;
      $824 = HEAP32[$38>>2]|0;
      $825 = $824 & $$0818;
      $826 = HEAP8[$39>>0]|0;
      $827 = $826&255;
      $828 = $825 >>> $827;
      $829 = (($823) + ($828)|0);
      $830 = HEAP8[$829>>0]|0;
      $831 = $830&255;
      $832 = HEAP8[$40>>0]|0;
      $833 = $832&255;
      $834 = (79212 + ($833<<2)|0);
      $835 = HEAP32[$834>>2]|0;
      $836 = HEAP32[$41>>2]|0;
      $837 = $836 & $$0818;
      $838 = HEAP8[$42>>0]|0;
      $839 = $838&255;
      $840 = $837 >>> $839;
      $841 = (($835) + ($840)|0);
      $842 = HEAP8[$841>>0]|0;
      $843 = $842&255;
      $844 = HEAP8[$43>>0]|0;
      $845 = $844&255;
      $846 = (79212 + ($845<<2)|0);
      $847 = HEAP32[$846>>2]|0;
      $848 = HEAP32[$44>>2]|0;
      $849 = $848 & $$0818;
      $850 = HEAP8[$45>>0]|0;
      $851 = $850&255;
      $852 = $849 >>> $851;
      $853 = (($847) + ($852)|0);
      $854 = HEAP8[$853>>0]|0;
      $855 = $854&255;
      switch ($22<<24>>24) {
      case 1:  {
       $856 = HEAP8[$46>>0]|0;
       $857 = $856&255;
       $858 = $831 >>> $857;
       $859 = HEAP8[$47>>0]|0;
       $860 = $859&255;
       $861 = $858 << $860;
       $862 = HEAP8[$48>>0]|0;
       $863 = $862&255;
       $864 = $843 >>> $863;
       $865 = HEAP8[$49>>0]|0;
       $866 = $865&255;
       $867 = $864 << $866;
       $868 = $867 | $861;
       $869 = HEAP8[$50>>0]|0;
       $870 = $869&255;
       $871 = $855 >>> $870;
       $872 = HEAP8[$51>>0]|0;
       $873 = $872&255;
       $874 = $871 << $873;
       $875 = $868 | $874;
       $876 = HEAP8[$52>>0]|0;
       $877 = $876&255;
       $878 = $133 >>> $877;
       $879 = HEAP8[$53>>0]|0;
       $880 = $879&255;
       $881 = $878 << $880;
       $882 = $875 | $881;
       $883 = $882&255;
       HEAP8[$$6801>>0] = $883;
       break L93;
       break;
      }
      case 2:  {
       $884 = HEAP8[$46>>0]|0;
       $885 = $884&255;
       $886 = $831 >>> $885;
       $887 = HEAP8[$47>>0]|0;
       $888 = $887&255;
       $889 = $886 << $888;
       $890 = HEAP8[$48>>0]|0;
       $891 = $890&255;
       $892 = $843 >>> $891;
       $893 = HEAP8[$49>>0]|0;
       $894 = $893&255;
       $895 = $892 << $894;
       $896 = $895 | $889;
       $897 = HEAP8[$50>>0]|0;
       $898 = $897&255;
       $899 = $855 >>> $898;
       $900 = HEAP8[$51>>0]|0;
       $901 = $900&255;
       $902 = $899 << $901;
       $903 = $896 | $902;
       $904 = HEAP8[$52>>0]|0;
       $905 = $904&255;
       $906 = $133 >>> $905;
       $907 = HEAP8[$53>>0]|0;
       $908 = $907&255;
       $909 = $906 << $908;
       $910 = $903 | $909;
       $911 = $910&65535;
       HEAP16[$$6801>>1] = $911;
       break L93;
       break;
      }
      case 3:  {
       $912 = HEAP8[$47>>0]|0;
       $div832 = ($912&255) >>> 3;
       $913 = $div832&255;
       $914 = (($$6801) + ($913)|0);
       HEAP8[$914>>0] = $830;
       $915 = HEAP8[$49>>0]|0;
       $div833 = ($915&255) >>> 3;
       $916 = $div833&255;
       $917 = (($$6801) + ($916)|0);
       HEAP8[$917>>0] = $842;
       $918 = HEAP8[$51>>0]|0;
       $div834 = ($918&255) >>> 3;
       $919 = $div834&255;
       $920 = (($$6801) + ($919)|0);
       HEAP8[$920>>0] = $854;
       break L93;
       break;
      }
      case 4:  {
       $921 = HEAP8[$46>>0]|0;
       $922 = $921&255;
       $923 = $831 >>> $922;
       $924 = HEAP8[$47>>0]|0;
       $925 = $924&255;
       $926 = $923 << $925;
       $927 = HEAP8[$48>>0]|0;
       $928 = $927&255;
       $929 = $843 >>> $928;
       $930 = HEAP8[$49>>0]|0;
       $931 = $930&255;
       $932 = $929 << $931;
       $933 = $932 | $926;
       $934 = HEAP8[$50>>0]|0;
       $935 = $934&255;
       $936 = $855 >>> $935;
       $937 = HEAP8[$51>>0]|0;
       $938 = $937&255;
       $939 = $936 << $938;
       $940 = $933 | $939;
       $941 = HEAP8[$52>>0]|0;
       $942 = $941&255;
       $943 = $133 >>> $942;
       $944 = HEAP8[$53>>0]|0;
       $945 = $944&255;
       $946 = $943 << $945;
       $947 = $940 | $946;
       HEAP32[$$6801>>2] = $947;
       break L93;
       break;
      }
      default: {
       break L93;
      }
      }
     }
    } while(0);
    $948 = (($$6801) + ($23)|0);
    $949 = (($$6) + ($20)|0);
    $$6810 = $$5809;$$7 = $949;$$7802 = $948;
    label = 78;
    continue;
   }
   else if ((label|0) == 78) {
    label = 0;
    switch ($19<<24>>24) {
    case 1:  {
     $950 = HEAP8[$$7>>0]|0;
     $951 = $950&255;
     $$0819 = $951;
     break;
    }
    case 2:  {
     $952 = HEAP16[$$7>>1]|0;
     $953 = $952&65535;
     $$0819 = $953;
     break;
    }
    case 3:  {
     $954 = HEAP8[$$7>>0]|0;
     $955 = $954&255;
     $956 = ((($$7)) + 1|0);
     $957 = HEAP8[$956>>0]|0;
     $958 = $957&255;
     $959 = $958 << 8;
     $960 = $959 | $955;
     $961 = ((($$7)) + 2|0);
     $962 = HEAP8[$961>>0]|0;
     $963 = $962&255;
     $964 = $963 << 16;
     $965 = $960 | $964;
     $$0819 = $965;
     break;
    }
    case 4:  {
     $966 = HEAP32[$$7>>2]|0;
     $$0819 = $966;
     break;
    }
    default: {
     $$0819 = 0;
    }
    }
    $967 = $$0819 & $32;
    $968 = ($967|0)==($33|0);
    L108: do {
     if (!($968)) {
      $969 = HEAP8[$37>>0]|0;
      $970 = $969&255;
      $971 = (79212 + ($970<<2)|0);
      $972 = HEAP32[$971>>2]|0;
      $973 = HEAP32[$38>>2]|0;
      $974 = $973 & $$0819;
      $975 = HEAP8[$39>>0]|0;
      $976 = $975&255;
      $977 = $974 >>> $976;
      $978 = (($972) + ($977)|0);
      $979 = HEAP8[$978>>0]|0;
      $980 = $979&255;
      $981 = HEAP8[$40>>0]|0;
      $982 = $981&255;
      $983 = (79212 + ($982<<2)|0);
      $984 = HEAP32[$983>>2]|0;
      $985 = HEAP32[$41>>2]|0;
      $986 = $985 & $$0819;
      $987 = HEAP8[$42>>0]|0;
      $988 = $987&255;
      $989 = $986 >>> $988;
      $990 = (($984) + ($989)|0);
      $991 = HEAP8[$990>>0]|0;
      $992 = $991&255;
      $993 = HEAP8[$43>>0]|0;
      $994 = $993&255;
      $995 = (79212 + ($994<<2)|0);
      $996 = HEAP32[$995>>2]|0;
      $997 = HEAP32[$44>>2]|0;
      $998 = $997 & $$0819;
      $999 = HEAP8[$45>>0]|0;
      $1000 = $999&255;
      $1001 = $998 >>> $1000;
      $1002 = (($996) + ($1001)|0);
      $1003 = HEAP8[$1002>>0]|0;
      $1004 = $1003&255;
      switch ($22<<24>>24) {
      case 1:  {
       $1005 = HEAP8[$46>>0]|0;
       $1006 = $1005&255;
       $1007 = $980 >>> $1006;
       $1008 = HEAP8[$47>>0]|0;
       $1009 = $1008&255;
       $1010 = $1007 << $1009;
       $1011 = HEAP8[$48>>0]|0;
       $1012 = $1011&255;
       $1013 = $992 >>> $1012;
       $1014 = HEAP8[$49>>0]|0;
       $1015 = $1014&255;
       $1016 = $1013 << $1015;
       $1017 = $1016 | $1010;
       $1018 = HEAP8[$50>>0]|0;
       $1019 = $1018&255;
       $1020 = $1004 >>> $1019;
       $1021 = HEAP8[$51>>0]|0;
       $1022 = $1021&255;
       $1023 = $1020 << $1022;
       $1024 = $1017 | $1023;
       $1025 = HEAP8[$52>>0]|0;
       $1026 = $1025&255;
       $1027 = $133 >>> $1026;
       $1028 = HEAP8[$53>>0]|0;
       $1029 = $1028&255;
       $1030 = $1027 << $1029;
       $1031 = $1024 | $1030;
       $1032 = $1031&255;
       HEAP8[$$7802>>0] = $1032;
       break L108;
       break;
      }
      case 2:  {
       $1033 = HEAP8[$46>>0]|0;
       $1034 = $1033&255;
       $1035 = $980 >>> $1034;
       $1036 = HEAP8[$47>>0]|0;
       $1037 = $1036&255;
       $1038 = $1035 << $1037;
       $1039 = HEAP8[$48>>0]|0;
       $1040 = $1039&255;
       $1041 = $992 >>> $1040;
       $1042 = HEAP8[$49>>0]|0;
       $1043 = $1042&255;
       $1044 = $1041 << $1043;
       $1045 = $1044 | $1038;
       $1046 = HEAP8[$50>>0]|0;
       $1047 = $1046&255;
       $1048 = $1004 >>> $1047;
       $1049 = HEAP8[$51>>0]|0;
       $1050 = $1049&255;
       $1051 = $1048 << $1050;
       $1052 = $1045 | $1051;
       $1053 = HEAP8[$52>>0]|0;
       $1054 = $1053&255;
       $1055 = $133 >>> $1054;
       $1056 = HEAP8[$53>>0]|0;
       $1057 = $1056&255;
       $1058 = $1055 << $1057;
       $1059 = $1052 | $1058;
       $1060 = $1059&65535;
       HEAP16[$$7802>>1] = $1060;
       break L108;
       break;
      }
      case 3:  {
       $1061 = HEAP8[$47>>0]|0;
       $div = ($1061&255) >>> 3;
       $1062 = $div&255;
       $1063 = (($$7802) + ($1062)|0);
       HEAP8[$1063>>0] = $979;
       $1064 = HEAP8[$49>>0]|0;
       $div829 = ($1064&255) >>> 3;
       $1065 = $div829&255;
       $1066 = (($$7802) + ($1065)|0);
       HEAP8[$1066>>0] = $991;
       $1067 = HEAP8[$51>>0]|0;
       $div830 = ($1067&255) >>> 3;
       $1068 = $div830&255;
       $1069 = (($$7802) + ($1068)|0);
       HEAP8[$1069>>0] = $1003;
       break L108;
       break;
      }
      case 4:  {
       $1070 = HEAP8[$46>>0]|0;
       $1071 = $1070&255;
       $1072 = $980 >>> $1071;
       $1073 = HEAP8[$47>>0]|0;
       $1074 = $1073&255;
       $1075 = $1072 << $1074;
       $1076 = HEAP8[$48>>0]|0;
       $1077 = $1076&255;
       $1078 = $992 >>> $1077;
       $1079 = HEAP8[$49>>0]|0;
       $1080 = $1079&255;
       $1081 = $1078 << $1080;
       $1082 = $1081 | $1075;
       $1083 = HEAP8[$50>>0]|0;
       $1084 = $1083&255;
       $1085 = $1004 >>> $1084;
       $1086 = HEAP8[$51>>0]|0;
       $1087 = $1086&255;
       $1088 = $1085 << $1087;
       $1089 = $1082 | $1088;
       $1090 = HEAP8[$52>>0]|0;
       $1091 = $1090&255;
       $1092 = $133 >>> $1091;
       $1093 = HEAP8[$53>>0]|0;
       $1094 = $1093&255;
       $1095 = $1092 << $1094;
       $1096 = $1089 | $1095;
       HEAP32[$$7802>>2] = $1096;
       break L108;
       break;
      }
      default: {
       break L108;
      }
      }
     }
    } while(0);
    $1097 = (($$7802) + ($23)|0);
    $1098 = (($$7) + ($20)|0);
    $$7811 = $$6810;$$8 = $1098;$$8803 = $1097;
    label = 90;
    continue;
   }
   else if ((label|0) == 90) {
    label = 0;
    switch ($19<<24>>24) {
    case 1:  {
     $1099 = HEAP8[$$8>>0]|0;
     $1100 = $1099&255;
     $$0814 = $1100;
     break;
    }
    case 2:  {
     $1101 = HEAP16[$$8>>1]|0;
     $1102 = $1101&65535;
     $$0814 = $1102;
     break;
    }
    case 3:  {
     $1103 = HEAP8[$$8>>0]|0;
     $1104 = $1103&255;
     $1105 = ((($$8)) + 1|0);
     $1106 = HEAP8[$1105>>0]|0;
     $1107 = $1106&255;
     $1108 = $1107 << 8;
     $1109 = $1108 | $1104;
     $1110 = ((($$8)) + 2|0);
     $1111 = HEAP8[$1110>>0]|0;
     $1112 = $1111&255;
     $1113 = $1112 << 16;
     $1114 = $1109 | $1113;
     $$0814 = $1114;
     break;
    }
    case 4:  {
     $1115 = HEAP32[$$8>>2]|0;
     $$0814 = $1115;
     break;
    }
    default: {
     $$0814 = 0;
    }
    }
    $1116 = $$0814 & $32;
    $1117 = ($1116|0)==($33|0);
    L123: do {
     if (!($1117)) {
      $1118 = HEAP8[$37>>0]|0;
      $1119 = $1118&255;
      $1120 = (79212 + ($1119<<2)|0);
      $1121 = HEAP32[$1120>>2]|0;
      $1122 = HEAP32[$38>>2]|0;
      $1123 = $1122 & $$0814;
      $1124 = HEAP8[$39>>0]|0;
      $1125 = $1124&255;
      $1126 = $1123 >>> $1125;
      $1127 = (($1121) + ($1126)|0);
      $1128 = HEAP8[$1127>>0]|0;
      $1129 = $1128&255;
      $1130 = HEAP8[$40>>0]|0;
      $1131 = $1130&255;
      $1132 = (79212 + ($1131<<2)|0);
      $1133 = HEAP32[$1132>>2]|0;
      $1134 = HEAP32[$41>>2]|0;
      $1135 = $1134 & $$0814;
      $1136 = HEAP8[$42>>0]|0;
      $1137 = $1136&255;
      $1138 = $1135 >>> $1137;
      $1139 = (($1133) + ($1138)|0);
      $1140 = HEAP8[$1139>>0]|0;
      $1141 = $1140&255;
      $1142 = HEAP8[$43>>0]|0;
      $1143 = $1142&255;
      $1144 = (79212 + ($1143<<2)|0);
      $1145 = HEAP32[$1144>>2]|0;
      $1146 = HEAP32[$44>>2]|0;
      $1147 = $1146 & $$0814;
      $1148 = HEAP8[$45>>0]|0;
      $1149 = $1148&255;
      $1150 = $1147 >>> $1149;
      $1151 = (($1145) + ($1150)|0);
      $1152 = HEAP8[$1151>>0]|0;
      $1153 = $1152&255;
      switch ($22<<24>>24) {
      case 1:  {
       $1154 = HEAP8[$46>>0]|0;
       $1155 = $1154&255;
       $1156 = $1129 >>> $1155;
       $1157 = HEAP8[$47>>0]|0;
       $1158 = $1157&255;
       $1159 = $1156 << $1158;
       $1160 = HEAP8[$48>>0]|0;
       $1161 = $1160&255;
       $1162 = $1141 >>> $1161;
       $1163 = HEAP8[$49>>0]|0;
       $1164 = $1163&255;
       $1165 = $1162 << $1164;
       $1166 = $1165 | $1159;
       $1167 = HEAP8[$50>>0]|0;
       $1168 = $1167&255;
       $1169 = $1153 >>> $1168;
       $1170 = HEAP8[$51>>0]|0;
       $1171 = $1170&255;
       $1172 = $1169 << $1171;
       $1173 = $1166 | $1172;
       $1174 = HEAP8[$52>>0]|0;
       $1175 = $1174&255;
       $1176 = $133 >>> $1175;
       $1177 = HEAP8[$53>>0]|0;
       $1178 = $1177&255;
       $1179 = $1176 << $1178;
       $1180 = $1173 | $1179;
       $1181 = $1180&255;
       HEAP8[$$8803>>0] = $1181;
       break L123;
       break;
      }
      case 2:  {
       $1182 = HEAP8[$46>>0]|0;
       $1183 = $1182&255;
       $1184 = $1129 >>> $1183;
       $1185 = HEAP8[$47>>0]|0;
       $1186 = $1185&255;
       $1187 = $1184 << $1186;
       $1188 = HEAP8[$48>>0]|0;
       $1189 = $1188&255;
       $1190 = $1141 >>> $1189;
       $1191 = HEAP8[$49>>0]|0;
       $1192 = $1191&255;
       $1193 = $1190 << $1192;
       $1194 = $1193 | $1187;
       $1195 = HEAP8[$50>>0]|0;
       $1196 = $1195&255;
       $1197 = $1153 >>> $1196;
       $1198 = HEAP8[$51>>0]|0;
       $1199 = $1198&255;
       $1200 = $1197 << $1199;
       $1201 = $1194 | $1200;
       $1202 = HEAP8[$52>>0]|0;
       $1203 = $1202&255;
       $1204 = $133 >>> $1203;
       $1205 = HEAP8[$53>>0]|0;
       $1206 = $1205&255;
       $1207 = $1204 << $1206;
       $1208 = $1201 | $1207;
       $1209 = $1208&65535;
       HEAP16[$$8803>>1] = $1209;
       break L123;
       break;
      }
      case 3:  {
       $1210 = HEAP8[$47>>0]|0;
       $div856 = ($1210&255) >>> 3;
       $1211 = $div856&255;
       $1212 = (($$8803) + ($1211)|0);
       HEAP8[$1212>>0] = $1128;
       $1213 = HEAP8[$49>>0]|0;
       $div857 = ($1213&255) >>> 3;
       $1214 = $div857&255;
       $1215 = (($$8803) + ($1214)|0);
       HEAP8[$1215>>0] = $1140;
       $1216 = HEAP8[$51>>0]|0;
       $div858 = ($1216&255) >>> 3;
       $1217 = $div858&255;
       $1218 = (($$8803) + ($1217)|0);
       HEAP8[$1218>>0] = $1152;
       break L123;
       break;
      }
      case 4:  {
       $1219 = HEAP8[$46>>0]|0;
       $1220 = $1219&255;
       $1221 = $1129 >>> $1220;
       $1222 = HEAP8[$47>>0]|0;
       $1223 = $1222&255;
       $1224 = $1221 << $1223;
       $1225 = HEAP8[$48>>0]|0;
       $1226 = $1225&255;
       $1227 = $1141 >>> $1226;
       $1228 = HEAP8[$49>>0]|0;
       $1229 = $1228&255;
       $1230 = $1227 << $1229;
       $1231 = $1230 | $1224;
       $1232 = HEAP8[$50>>0]|0;
       $1233 = $1232&255;
       $1234 = $1153 >>> $1233;
       $1235 = HEAP8[$51>>0]|0;
       $1236 = $1235&255;
       $1237 = $1234 << $1236;
       $1238 = $1231 | $1237;
       $1239 = HEAP8[$52>>0]|0;
       $1240 = $1239&255;
       $1241 = $133 >>> $1240;
       $1242 = HEAP8[$53>>0]|0;
       $1243 = $1242&255;
       $1244 = $1241 << $1243;
       $1245 = $1238 | $1244;
       HEAP32[$$8803>>2] = $1245;
       break L123;
       break;
      }
      default: {
       break L123;
      }
      }
     }
    } while(0);
    $1246 = (($$8803) + ($23)|0);
    $1247 = (($$8) + ($20)|0);
    $1248 = (($$7811) + -1)|0;
    $1249 = ($$7811|0)>(1);
    if ($1249) {
     $$0804 = $1248;$$1 = $1247;$$1796 = $1246;
     label = 6;
     continue;
    } else {
     break;
    }
   }
  }
  $1250 = (($1247) + ($7)|0);
  $1251 = (($1246) + ($11)|0);
  $1252 = ($54|0)==(0);
  if ($1252) {
   label = 104;
   break;
  } else {
   $$0794860 = $1250;$$0795859 = $1251;$$in = $54;
  }
 }
 if ((label|0) == 102) {
  // unreachable;
 }
 else if ((label|0) == 104) {
  return;
 }
}
function _BlitNto1($0) {
 $0 = $0|0;
 var $$0 = 0, $$0910 = 0, $$0920 = 0, $$0920$shrunk = 0, $$0928 = 0, $$0928$shrunk = 0, $$0928$shrunk$ph = 0, $$0928$shrunk$ph$in = 0, $$0944$shrunk = 0, $$0944$shrunk$ph = 0, $$0944$shrunk$ph$in = 0, $$09601091 = 0, $$09761090 = 0, $$1 = 0, $$10 = 0, $$10$shrunk = 0, $$10938 = 0, $$10938$shrunk = 0, $$10938$shrunk$ph = 0, $$10938$shrunk$ph$in = 0;
 var $$10954$shrunk = 0, $$10954$shrunk$ph = 0, $$10954$shrunk$ph$in = 0, $$10970 = 0, $$10986 = 0, $$11 = 0, $$11$shrunk = 0, $$11939 = 0, $$11939$shrunk = 0, $$11939$shrunk$ph = 0, $$11939$shrunk$ph$in = 0, $$11955$shrunk = 0, $$11955$shrunk$ph = 0, $$11955$shrunk$ph$in = 0, $$11971 = 0, $$11987 = 0, $$12 = 0, $$12$shrunk = 0, $$12940 = 0, $$12940$shrunk = 0;
 var $$12940$shrunk$ph = 0, $$12940$shrunk$ph$in = 0, $$12956$shrunk = 0, $$12956$shrunk$ph = 0, $$12956$shrunk$ph$in = 0, $$12972 = 0, $$12988 = 0, $$13 = 0, $$13$shrunk = 0, $$13941 = 0, $$13941$shrunk = 0, $$13941$shrunk$ph = 0, $$13941$shrunk$ph$in = 0, $$13957$shrunk = 0, $$13957$shrunk$ph = 0, $$13957$shrunk$ph$in = 0, $$13973 = 0, $$13989 = 0, $$14 = 0, $$14$shrunk = 0;
 var $$14942 = 0, $$14942$shrunk = 0, $$14942$shrunk$ph = 0, $$14942$shrunk$ph$in = 0, $$14958$shrunk = 0, $$14958$shrunk$ph = 0, $$14958$shrunk$ph$in = 0, $$14974 = 0, $$14990 = 0, $$15 = 0, $$15$shrunk = 0, $$15943 = 0, $$15943$shrunk = 0, $$15943$shrunk$ph = 0, $$15943$shrunk$ph$in = 0, $$15959$shrunk = 0, $$15959$shrunk$ph = 0, $$15959$shrunk$ph$in = 0, $$15975 = 0, $$15991 = 0;
 var $$16 = 0, $$16992 = 0, $$17 = 0, $$17993 = 0, $$1911 = 0, $$1921 = 0, $$1921$shrunk = 0, $$1929 = 0, $$1929$shrunk = 0, $$1929$shrunk$ph = 0, $$1929$shrunk$ph$in = 0, $$1945$shrunk = 0, $$1945$shrunk$ph = 0, $$1945$shrunk$ph$in = 0, $$1961 = 0, $$1977 = 0, $$2 = 0, $$2912 = 0, $$2922 = 0, $$2922$shrunk = 0;
 var $$2930 = 0, $$2930$shrunk = 0, $$2930$shrunk$ph = 0, $$2930$shrunk$ph$in = 0, $$2946$shrunk = 0, $$2946$shrunk$ph = 0, $$2946$shrunk$ph$in = 0, $$2962 = 0, $$2978 = 0, $$3 = 0, $$3913 = 0, $$3923 = 0, $$3923$shrunk = 0, $$3931 = 0, $$3931$shrunk = 0, $$3931$shrunk$ph = 0, $$3931$shrunk$ph$in = 0, $$3947$shrunk = 0, $$3947$shrunk$ph = 0, $$3947$shrunk$ph$in = 0;
 var $$3963 = 0, $$3979 = 0, $$4 = 0, $$4914 = 0, $$4924 = 0, $$4924$shrunk = 0, $$4932 = 0, $$4932$shrunk = 0, $$4932$shrunk$ph = 0, $$4932$shrunk$ph$in = 0, $$4948$shrunk = 0, $$4948$shrunk$ph = 0, $$4948$shrunk$ph$in = 0, $$4964 = 0, $$4980 = 0, $$5 = 0, $$5915 = 0, $$5925 = 0, $$5925$shrunk = 0, $$5933 = 0;
 var $$5933$shrunk = 0, $$5933$shrunk$ph = 0, $$5933$shrunk$ph$in = 0, $$5949$shrunk = 0, $$5949$shrunk$ph = 0, $$5949$shrunk$ph$in = 0, $$5965 = 0, $$5981 = 0, $$6 = 0, $$6916 = 0, $$6926 = 0, $$6926$shrunk = 0, $$6934 = 0, $$6934$shrunk = 0, $$6934$shrunk$ph = 0, $$6934$shrunk$ph$in = 0, $$6950$shrunk = 0, $$6950$shrunk$ph = 0, $$6950$shrunk$ph$in = 0, $$6966 = 0;
 var $$6982 = 0, $$7 = 0, $$7917 = 0, $$7927 = 0, $$7927$shrunk = 0, $$7935 = 0, $$7935$shrunk = 0, $$7935$shrunk$ph = 0, $$7935$shrunk$ph$in = 0, $$7951$shrunk = 0, $$7951$shrunk$ph = 0, $$7951$shrunk$ph$in = 0, $$7967 = 0, $$7983 = 0, $$8 = 0, $$8$shrunk = 0, $$8936 = 0, $$8936$shrunk = 0, $$8936$shrunk$ph = 0, $$8936$shrunk$ph$in = 0;
 var $$8952$shrunk = 0, $$8952$shrunk$ph = 0, $$8952$shrunk$ph$in = 0, $$8968 = 0, $$8984 = 0, $$9 = 0, $$9$shrunk = 0, $$9937 = 0, $$9937$shrunk = 0, $$9937$shrunk$ph = 0, $$9937$shrunk$ph$in = 0, $$9953$shrunk = 0, $$9953$shrunk$ph = 0, $$9953$shrunk$ph$in = 0, $$99691093 = 0, $$99851092 = 0, $$sink = 0, $$sink1059 = 0, $$sink1061 = 0, $$sink1063 = 0;
 var $$sink1065 = 0, $$sink1067 = 0, $$sink1069 = 0, $$sink1071 = 0, $$sink1073 = 0, $$sink1075 = 0, $$sink1077 = 0, $$sink1079 = 0, $$sink1081 = 0, $$sink1083 = 0, $$sink1085 = 0, $$sink1087 = 0, $1 = 0, $10 = 0, $100 = 0, $1000 = 0, $1001 = 0, $1002 = 0, $1003 = 0, $1004 = 0;
 var $1005 = 0, $1006 = 0, $1007 = 0, $1008 = 0, $1009 = 0, $101 = 0, $1010 = 0, $1011 = 0, $1012 = 0, $1013 = 0, $1014 = 0, $1015 = 0, $1016 = 0, $1017 = 0, $1018 = 0, $1019 = 0, $102 = 0, $1020 = 0, $1021 = 0, $1022 = 0;
 var $1023 = 0, $1024 = 0, $1025 = 0, $1026 = 0, $1027 = 0, $1028 = 0, $1029 = 0, $103 = 0, $1030 = 0, $1031 = 0, $1032 = 0, $1033 = 0, $1034 = 0, $1035 = 0, $1036 = 0, $1037 = 0, $1038 = 0, $1039 = 0, $104 = 0, $1040 = 0;
 var $1041 = 0, $1042 = 0, $1043 = 0, $1044 = 0, $1045 = 0, $1046 = 0, $1047 = 0, $1048 = 0, $1049 = 0, $105 = 0, $1050 = 0, $1051 = 0, $1052 = 0, $1053 = 0, $1054 = 0, $1055 = 0, $1056 = 0, $1057 = 0, $1058 = 0, $1059 = 0;
 var $106 = 0, $1060 = 0, $1061 = 0, $1062 = 0, $1063 = 0, $1064 = 0, $1065 = 0, $1066 = 0, $1067 = 0, $1068 = 0, $1069 = 0, $107 = 0, $1070 = 0, $1071 = 0, $1072 = 0, $1073 = 0, $1074 = 0, $1075 = 0, $1076 = 0, $1077 = 0;
 var $1078 = 0, $1079 = 0, $108 = 0, $1080 = 0, $1081 = 0, $1082 = 0, $1083 = 0, $1084 = 0, $1085 = 0, $1086 = 0, $1087 = 0, $1088 = 0, $1089 = 0, $109 = 0, $1090 = 0, $1091 = 0, $1092 = 0, $1093 = 0, $1094 = 0, $1095 = 0;
 var $1096 = 0, $1097 = 0, $1098 = 0, $1099 = 0, $11 = 0, $110 = 0, $1100 = 0, $1101 = 0, $1102 = 0, $1103 = 0, $1104 = 0, $1105 = 0, $1106 = 0, $1107 = 0, $1108 = 0, $1109 = 0, $111 = 0, $1110 = 0, $1111 = 0, $1112 = 0;
 var $1113 = 0, $1114 = 0, $1115 = 0, $1116 = 0, $1117 = 0, $1118 = 0, $1119 = 0, $112 = 0, $1120 = 0, $1121 = 0, $1122 = 0, $1123 = 0, $1124 = 0, $1125 = 0, $1126 = 0, $1127 = 0, $1128 = 0, $1129 = 0, $113 = 0, $1130 = 0;
 var $1131 = 0, $1132 = 0, $1133 = 0, $1134 = 0, $1135 = 0, $1136 = 0, $1137 = 0, $1138 = 0, $1139 = 0, $114 = 0, $1140 = 0, $1141 = 0, $1142 = 0, $1143 = 0, $1144 = 0, $1145 = 0, $1146 = 0, $1147 = 0, $1148 = 0, $1149 = 0;
 var $115 = 0, $1150 = 0, $1151 = 0, $1152 = 0, $1153 = 0, $1154 = 0, $1155 = 0, $1156 = 0, $1157 = 0, $1158 = 0, $1159 = 0, $116 = 0, $1160 = 0, $1161 = 0, $1162 = 0, $1163 = 0, $1164 = 0, $1165 = 0, $1166 = 0, $1167 = 0;
 var $1168 = 0, $1169 = 0, $117 = 0, $1170 = 0, $1171 = 0, $1172 = 0, $1173 = 0, $1174 = 0, $1175 = 0, $1176 = 0, $1177 = 0, $1178 = 0, $1179 = 0, $118 = 0, $1180 = 0, $1181 = 0, $1182 = 0, $1183 = 0, $1184 = 0, $1185 = 0;
 var $1186 = 0, $1187 = 0, $1188 = 0, $1189 = 0, $119 = 0, $1190 = 0, $1191 = 0, $1192 = 0, $1193 = 0, $1194 = 0, $1195 = 0, $1196 = 0, $1197 = 0, $1198 = 0, $1199 = 0, $12 = 0, $120 = 0, $1200 = 0, $1201 = 0, $1202 = 0;
 var $1203 = 0, $1204 = 0, $1205 = 0, $1206 = 0, $1207 = 0, $1208 = 0, $1209 = 0, $121 = 0, $1210 = 0, $1211 = 0, $1212 = 0, $1213 = 0, $1214 = 0, $1215 = 0, $1216 = 0, $1217 = 0, $1218 = 0, $1219 = 0, $122 = 0, $1220 = 0;
 var $1221 = 0, $1222 = 0, $1223 = 0, $1224 = 0, $1225 = 0, $1226 = 0, $1227 = 0, $1228 = 0, $1229 = 0, $123 = 0, $1230 = 0, $1231 = 0, $1232 = 0, $1233 = 0, $1234 = 0, $1235 = 0, $1236 = 0, $1237 = 0, $1238 = 0, $1239 = 0;
 var $124 = 0, $1240 = 0, $1241 = 0, $1242 = 0, $1243 = 0, $1244 = 0, $1245 = 0, $1246 = 0, $1247 = 0, $1248 = 0, $1249 = 0, $125 = 0, $1250 = 0, $1251 = 0, $1252 = 0, $1253 = 0, $1254 = 0, $1255 = 0, $1256 = 0, $1257 = 0;
 var $1258 = 0, $1259 = 0, $126 = 0, $1260 = 0, $1261 = 0, $1262 = 0, $1263 = 0, $1264 = 0, $1265 = 0, $1266 = 0, $1267 = 0, $1268 = 0, $1269 = 0, $127 = 0, $1270 = 0, $1271 = 0, $1272 = 0, $1273 = 0, $1274 = 0, $1275 = 0;
 var $1276 = 0, $1277 = 0, $1278 = 0, $1279 = 0, $128 = 0, $1280 = 0, $1281 = 0, $1282 = 0, $1283 = 0, $1284 = 0, $1285 = 0, $1286 = 0, $1287 = 0, $1288 = 0, $1289 = 0, $129 = 0, $1290 = 0, $1291 = 0, $1292 = 0, $1293 = 0;
 var $1294 = 0, $1295 = 0, $1296 = 0, $1297 = 0, $1298 = 0, $1299 = 0, $13 = 0, $130 = 0, $1300 = 0, $1301 = 0, $1302 = 0, $1303 = 0, $1304 = 0, $1305 = 0, $1306 = 0, $1307 = 0, $1308 = 0, $1309 = 0, $131 = 0, $1310 = 0;
 var $1311 = 0, $1312 = 0, $1313 = 0, $1314 = 0, $1315 = 0, $1316 = 0, $1317 = 0, $1318 = 0, $1319 = 0, $132 = 0, $1320 = 0, $1321 = 0, $1322 = 0, $1323 = 0, $1324 = 0, $1325 = 0, $1326 = 0, $1327 = 0, $1328 = 0, $1329 = 0;
 var $133 = 0, $1330 = 0, $1331 = 0, $1332 = 0, $1333 = 0, $1334 = 0, $1335 = 0, $1336 = 0, $1337 = 0, $1338 = 0, $1339 = 0, $134 = 0, $1340 = 0, $1341 = 0, $1342 = 0, $1343 = 0, $1344 = 0, $1345 = 0, $1346 = 0, $1347 = 0;
 var $1348 = 0, $1349 = 0, $135 = 0, $1350 = 0, $1351 = 0, $1352 = 0, $1353 = 0, $1354 = 0, $1355 = 0, $1356 = 0, $1357 = 0, $1358 = 0, $1359 = 0, $136 = 0, $1360 = 0, $1361 = 0, $1362 = 0, $1363 = 0, $1364 = 0, $1365 = 0;
 var $1366 = 0, $1367 = 0, $1368 = 0, $1369 = 0, $137 = 0, $1370 = 0, $1371 = 0, $1372 = 0, $1373 = 0, $1374 = 0, $1375 = 0, $1376 = 0, $1377 = 0, $1378 = 0, $1379 = 0, $138 = 0, $1380 = 0, $1381 = 0, $1382 = 0, $1383 = 0;
 var $1384 = 0, $1385 = 0, $1386 = 0, $1387 = 0, $1388 = 0, $1389 = 0, $139 = 0, $1390 = 0, $1391 = 0, $1392 = 0, $1393 = 0, $1394 = 0, $1395 = 0, $1396 = 0, $1397 = 0, $1398 = 0, $1399 = 0, $14 = 0, $140 = 0, $1400 = 0;
 var $1401 = 0, $1402 = 0, $1403 = 0, $1404 = 0, $1405 = 0, $1406 = 0, $1407 = 0, $1408 = 0, $1409 = 0, $141 = 0, $1410 = 0, $1411 = 0, $1412 = 0, $1413 = 0, $1414 = 0, $1415 = 0, $1416 = 0, $1417 = 0, $1418 = 0, $1419 = 0;
 var $142 = 0, $1420 = 0, $1421 = 0, $1422 = 0, $1423 = 0, $1424 = 0, $1425 = 0, $1426 = 0, $1427 = 0, $1428 = 0, $1429 = 0, $143 = 0, $1430 = 0, $1431 = 0, $1432 = 0, $1433 = 0, $1434 = 0, $1435 = 0, $1436 = 0, $1437 = 0;
 var $1438 = 0, $1439 = 0, $144 = 0, $1440 = 0, $1441 = 0, $1442 = 0, $1443 = 0, $1444 = 0, $1445 = 0, $1446 = 0, $1447 = 0, $1448 = 0, $1449 = 0, $145 = 0, $1450 = 0, $1451 = 0, $1452 = 0, $1453 = 0, $1454 = 0, $1455 = 0;
 var $1456 = 0, $1457 = 0, $1458 = 0, $1459 = 0, $146 = 0, $1460 = 0, $1461 = 0, $1462 = 0, $1463 = 0, $1464 = 0, $1465 = 0, $1466 = 0, $1467 = 0, $1468 = 0, $1469 = 0, $147 = 0, $1470 = 0, $1471 = 0, $1472 = 0, $1473 = 0;
 var $1474 = 0, $1475 = 0, $1476 = 0, $1477 = 0, $1478 = 0, $1479 = 0, $148 = 0, $1480 = 0, $1481 = 0, $1482 = 0, $1483 = 0, $1484 = 0, $1485 = 0, $1486 = 0, $1487 = 0, $1488 = 0, $1489 = 0, $149 = 0, $1490 = 0, $1491 = 0;
 var $1492 = 0, $1493 = 0, $1494 = 0, $1495 = 0, $1496 = 0, $1497 = 0, $1498 = 0, $1499 = 0, $15 = 0, $150 = 0, $1500 = 0, $1501 = 0, $1502 = 0, $1503 = 0, $1504 = 0, $1505 = 0, $1506 = 0, $1507 = 0, $1508 = 0, $1509 = 0;
 var $151 = 0, $1510 = 0, $1511 = 0, $1512 = 0, $1513 = 0, $1514 = 0, $1515 = 0, $1516 = 0, $1517 = 0, $1518 = 0, $1519 = 0, $152 = 0, $1520 = 0, $1521 = 0, $1522 = 0, $1523 = 0, $1524 = 0, $1525 = 0, $1526 = 0, $1527 = 0;
 var $1528 = 0, $1529 = 0, $153 = 0, $1530 = 0, $1531 = 0, $1532 = 0, $1533 = 0, $1534 = 0, $1535 = 0, $1536 = 0, $1537 = 0, $1538 = 0, $1539 = 0, $154 = 0, $1540 = 0, $1541 = 0, $1542 = 0, $1543 = 0, $1544 = 0, $1545 = 0;
 var $1546 = 0, $1547 = 0, $1548 = 0, $1549 = 0, $155 = 0, $1550 = 0, $1551 = 0, $1552 = 0, $1553 = 0, $1554 = 0, $1555 = 0, $1556 = 0, $1557 = 0, $1558 = 0, $1559 = 0, $156 = 0, $1560 = 0, $1561 = 0, $1562 = 0, $1563 = 0;
 var $1564 = 0, $1565 = 0, $1566 = 0, $1567 = 0, $1568 = 0, $1569 = 0, $157 = 0, $1570 = 0, $1571 = 0, $1572 = 0, $1573 = 0, $1574 = 0, $1575 = 0, $1576 = 0, $1577 = 0, $1578 = 0, $1579 = 0, $158 = 0, $1580 = 0, $1581 = 0;
 var $1582 = 0, $1583 = 0, $1584 = 0, $1585 = 0, $1586 = 0, $1587 = 0, $1588 = 0, $1589 = 0, $159 = 0, $1590 = 0, $1591 = 0, $1592 = 0, $1593 = 0, $1594 = 0, $1595 = 0, $1596 = 0, $1597 = 0, $1598 = 0, $1599 = 0, $16 = 0;
 var $160 = 0, $1600 = 0, $1601 = 0, $1602 = 0, $1603 = 0, $1604 = 0, $1605 = 0, $1606 = 0, $1607 = 0, $1608 = 0, $1609 = 0, $161 = 0, $1610 = 0, $1611 = 0, $1612 = 0, $1613 = 0, $1614 = 0, $1615 = 0, $1616 = 0, $1617 = 0;
 var $1618 = 0, $1619 = 0, $162 = 0, $1620 = 0, $1621 = 0, $1622 = 0, $1623 = 0, $1624 = 0, $1625 = 0, $1626 = 0, $1627 = 0, $1628 = 0, $1629 = 0, $163 = 0, $1630 = 0, $1631 = 0, $1632 = 0, $1633 = 0, $1634 = 0, $1635 = 0;
 var $1636 = 0, $1637 = 0, $1638 = 0, $1639 = 0, $164 = 0, $1640 = 0, $1641 = 0, $1642 = 0, $1643 = 0, $1644 = 0, $1645 = 0, $1646 = 0, $1647 = 0, $1648 = 0, $1649 = 0, $165 = 0, $1650 = 0, $1651 = 0, $1652 = 0, $1653 = 0;
 var $1654 = 0, $1655 = 0, $1656 = 0, $1657 = 0, $1658 = 0, $1659 = 0, $166 = 0, $1660 = 0, $1661 = 0, $1662 = 0, $1663 = 0, $1664 = 0, $1665 = 0, $1666 = 0, $1667 = 0, $1668 = 0, $1669 = 0, $167 = 0, $1670 = 0, $1671 = 0;
 var $1672 = 0, $1673 = 0, $1674 = 0, $1675 = 0, $1676 = 0, $1677 = 0, $1678 = 0, $1679 = 0, $168 = 0, $1680 = 0, $1681 = 0, $1682 = 0, $1683 = 0, $1684 = 0, $1685 = 0, $1686 = 0, $1687 = 0, $1688 = 0, $1689 = 0, $169 = 0;
 var $1690 = 0, $1691 = 0, $1692 = 0, $1693 = 0, $1694 = 0, $1695 = 0, $1696 = 0, $1697 = 0, $1698 = 0, $1699 = 0, $17 = 0, $170 = 0, $1700 = 0, $1701 = 0, $1702 = 0, $1703 = 0, $1704 = 0, $1705 = 0, $1706 = 0, $1707 = 0;
 var $1708 = 0, $1709 = 0, $171 = 0, $1710 = 0, $1711 = 0, $1712 = 0, $1713 = 0, $1714 = 0, $1715 = 0, $1716 = 0, $1717 = 0, $1718 = 0, $1719 = 0, $172 = 0, $1720 = 0, $1721 = 0, $1722 = 0, $1723 = 0, $1724 = 0, $1725 = 0;
 var $1726 = 0, $1727 = 0, $1728 = 0, $1729 = 0, $173 = 0, $1730 = 0, $1731 = 0, $1732 = 0, $1733 = 0, $1734 = 0, $1735 = 0, $1736 = 0, $1737 = 0, $1738 = 0, $1739 = 0, $174 = 0, $1740 = 0, $1741 = 0, $1742 = 0, $1743 = 0;
 var $1744 = 0, $1745 = 0, $1746 = 0, $1747 = 0, $1748 = 0, $1749 = 0, $175 = 0, $1750 = 0, $1751 = 0, $1752 = 0, $1753 = 0, $1754 = 0, $1755 = 0, $1756 = 0, $1757 = 0, $1758 = 0, $1759 = 0, $176 = 0, $1760 = 0, $1761 = 0;
 var $1762 = 0, $1763 = 0, $1764 = 0, $1765 = 0, $1766 = 0, $1767 = 0, $1768 = 0, $1769 = 0, $177 = 0, $1770 = 0, $1771 = 0, $1772 = 0, $1773 = 0, $1774 = 0, $1775 = 0, $1776 = 0, $1777 = 0, $1778 = 0, $1779 = 0, $178 = 0;
 var $1780 = 0, $1781 = 0, $1782 = 0, $1783 = 0, $1784 = 0, $1785 = 0, $1786 = 0, $1787 = 0, $1788 = 0, $1789 = 0, $179 = 0, $1790 = 0, $1791 = 0, $1792 = 0, $1793 = 0, $1794 = 0, $1795 = 0, $1796 = 0, $1797 = 0, $1798 = 0;
 var $1799 = 0, $18 = 0, $180 = 0, $1800 = 0, $1801 = 0, $1802 = 0, $1803 = 0, $1804 = 0, $1805 = 0, $1806 = 0, $1807 = 0, $1808 = 0, $1809 = 0, $181 = 0, $1810 = 0, $1811 = 0, $1812 = 0, $1813 = 0, $1814 = 0, $1815 = 0;
 var $1816 = 0, $1817 = 0, $1818 = 0, $1819 = 0, $182 = 0, $1820 = 0, $1821 = 0, $1822 = 0, $1823 = 0, $1824 = 0, $1825 = 0, $1826 = 0, $1827 = 0, $1828 = 0, $1829 = 0, $183 = 0, $1830 = 0, $1831 = 0, $1832 = 0, $1833 = 0;
 var $1834 = 0, $1835 = 0, $1836 = 0, $1837 = 0, $1838 = 0, $1839 = 0, $184 = 0, $1840 = 0, $1841 = 0, $1842 = 0, $1843 = 0, $1844 = 0, $1845 = 0, $1846 = 0, $1847 = 0, $1848 = 0, $1849 = 0, $185 = 0, $1850 = 0, $1851 = 0;
 var $1852 = 0, $1853 = 0, $1854 = 0, $1855 = 0, $1856 = 0, $1857 = 0, $1858 = 0, $1859 = 0, $186 = 0, $1860 = 0, $1861 = 0, $1862 = 0, $1863 = 0, $1864 = 0, $1865 = 0, $1866 = 0, $1867 = 0, $1868 = 0, $1869 = 0, $187 = 0;
 var $1870 = 0, $1871 = 0, $1872 = 0, $1873 = 0, $1874 = 0, $1875 = 0, $1876 = 0, $1877 = 0, $1878 = 0, $1879 = 0, $188 = 0, $1880 = 0, $1881 = 0, $1882 = 0, $1883 = 0, $1884 = 0, $1885 = 0, $1886 = 0, $1887 = 0, $1888 = 0;
 var $1889 = 0, $189 = 0, $1890 = 0, $1891 = 0, $1892 = 0, $1893 = 0, $1894 = 0, $1895 = 0, $1896 = 0, $1897 = 0, $1898 = 0, $1899 = 0, $19 = 0, $190 = 0, $1900 = 0, $1901 = 0, $1902 = 0, $1903 = 0, $1904 = 0, $1905 = 0;
 var $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0;
 var $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0;
 var $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0;
 var $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0;
 var $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0;
 var $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0;
 var $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0;
 var $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0;
 var $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0;
 var $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0;
 var $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0;
 var $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0;
 var $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0;
 var $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0;
 var $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0;
 var $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0;
 var $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0;
 var $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0;
 var $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0;
 var $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0;
 var $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0;
 var $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0;
 var $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0;
 var $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0;
 var $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0;
 var $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0;
 var $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0;
 var $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0;
 var $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0;
 var $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0;
 var $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0;
 var $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0;
 var $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0;
 var $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0;
 var $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0;
 var $821 = 0, $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = 0, $834 = 0, $835 = 0, $836 = 0, $837 = 0, $838 = 0, $839 = 0;
 var $84 = 0, $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0, $850 = 0, $851 = 0, $852 = 0, $853 = 0, $854 = 0, $855 = 0, $856 = 0, $857 = 0;
 var $858 = 0, $859 = 0, $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0, $869 = 0, $87 = 0, $870 = 0, $871 = 0, $872 = 0, $873 = 0, $874 = 0, $875 = 0;
 var $876 = 0, $877 = 0, $878 = 0, $879 = 0, $88 = 0, $880 = 0, $881 = 0, $882 = 0, $883 = 0, $884 = 0, $885 = 0, $886 = 0, $887 = 0, $888 = 0, $889 = 0, $89 = 0, $890 = 0, $891 = 0, $892 = 0, $893 = 0;
 var $894 = 0, $895 = 0, $896 = 0, $897 = 0, $898 = 0, $899 = 0, $9 = 0, $90 = 0, $900 = 0, $901 = 0, $902 = 0, $903 = 0, $904 = 0, $905 = 0, $906 = 0, $907 = 0, $908 = 0, $909 = 0, $91 = 0, $910 = 0;
 var $911 = 0, $912 = 0, $913 = 0, $914 = 0, $915 = 0, $916 = 0, $917 = 0, $918 = 0, $919 = 0, $92 = 0, $920 = 0, $921 = 0, $922 = 0, $923 = 0, $924 = 0, $925 = 0, $926 = 0, $927 = 0, $928 = 0, $929 = 0;
 var $93 = 0, $930 = 0, $931 = 0, $932 = 0, $933 = 0, $934 = 0, $935 = 0, $936 = 0, $937 = 0, $938 = 0, $939 = 0, $94 = 0, $940 = 0, $941 = 0, $942 = 0, $943 = 0, $944 = 0, $945 = 0, $946 = 0, $947 = 0;
 var $948 = 0, $949 = 0, $95 = 0, $950 = 0, $951 = 0, $952 = 0, $953 = 0, $954 = 0, $955 = 0, $956 = 0, $957 = 0, $958 = 0, $959 = 0, $96 = 0, $960 = 0, $961 = 0, $962 = 0, $963 = 0, $964 = 0, $965 = 0;
 var $966 = 0, $967 = 0, $968 = 0, $969 = 0, $97 = 0, $970 = 0, $971 = 0, $972 = 0, $973 = 0, $974 = 0, $975 = 0, $976 = 0, $977 = 0, $978 = 0, $979 = 0, $98 = 0, $980 = 0, $981 = 0, $982 = 0, $983 = 0;
 var $984 = 0, $985 = 0, $986 = 0, $987 = 0, $988 = 0, $989 = 0, $99 = 0, $990 = 0, $991 = 0, $992 = 0, $993 = 0, $994 = 0, $995 = 0, $996 = 0, $997 = 0, $998 = 0, $999 = 0, $div = 0, $div1002 = 0, $div1003 = 0;
 var $div1004 = 0, $div1005 = 0, $div1006 = 0, $div1007 = 0, $div1008 = 0, $div1009 = 0, $div1010 = 0, $div1011 = 0, $div1012 = 0, $div1013 = 0, $div1014 = 0, $div1015 = 0, $div1016 = 0, $div1017 = 0, $div1018 = 0, $div1019 = 0, $div1020 = 0, $div1021 = 0, $div1022 = 0, $div1023 = 0;
 var $div1024 = 0, $div1034 = 0, $div1035 = 0, $div1036 = 0, $div1037 = 0, $div1038 = 0, $div1039 = 0, $div1040 = 0, $div1041 = 0, $div1042 = 0, $div1043 = 0, $div1044 = 0, $div1045 = 0, $div1046 = 0, $div1047 = 0, $div1048 = 0, $div1049 = 0, $div1050 = 0, $div1051 = 0, $div1052 = 0;
 var $div1053 = 0, $div1054 = 0, $div1055 = 0, $div1056 = 0, $div1057 = 0, $trunc = 0, $trunc$clear = 0, $trunc1025 = 0, $trunc1025$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$0>>2]|0;
 $6 = ((($0)) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($0)) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($0)) + 36|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($0)) + 48|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($0)) + 40|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ((($15)) + 9|0);
 $17 = HEAP8[$16>>0]|0;
 $18 = $17&255;
 $19 = ($13|0)==(0|0);
 $20 = (($4) + -1)|0;
 $21 = ($4|0)==(0);
 if ($19) {
  if ($21) {
   return;
  }
  $33 = (($2) + 7)|0;
  $34 = (($33|0) / 8)&-1;
  $trunc1025 = $2&255;
  $35 = ((($15)) + 28|0);
  $36 = ((($15)) + 12|0);
  $37 = ((($15)) + 32|0);
  $38 = ((($15)) + 29|0);
  $39 = ((($15)) + 16|0);
  $40 = ((($15)) + 33|0);
  $41 = ((($15)) + 30|0);
  $42 = ((($15)) + 20|0);
  $43 = ((($15)) + 34|0);
  $$09601091 = $5;$$09761090 = $9;$969 = $20;
  L6: while(1) {
   $trunc1025$clear = $trunc1025 & 7;
   switch ($trunc1025$clear<<24>>24) {
   case 0:  {
    $$0910 = $34;$$1961 = $$09601091;$$1977 = $$09761090;
    label = 7;
    break;
   }
   case 7:  {
    $$1911 = $34;$$2962 = $$09601091;$$2978 = $$09761090;
    label = 14;
    break;
   }
   case 6:  {
    $$2912 = $34;$$3963 = $$09601091;$$3979 = $$09761090;
    label = 21;
    break;
   }
   case 5:  {
    $$3913 = $34;$$4964 = $$09601091;$$4980 = $$09761090;
    label = 28;
    break;
   }
   case 4:  {
    $$4914 = $34;$$5965 = $$09601091;$$5981 = $$09761090;
    label = 35;
    break;
   }
   case 3:  {
    $$5915 = $34;$$6966 = $$09601091;$$6982 = $$09761090;
    label = 42;
    break;
   }
   case 2:  {
    $$6916 = $34;$$7967 = $$09601091;$$7983 = $$09761090;
    label = 49;
    break;
   }
   case 1:  {
    $$7917 = $34;$$8968 = $$09601091;$$8984 = $$09761090;
    label = 56;
    break;
   }
   default: {
    label = 63;
    break L6;
   }
   }
   while(1) {
    if ((label|0) == 7) {
     label = 0;
     switch ($17<<24>>24) {
     case 1:  {
      $44 = HEAP8[$$1961>>0]|0;
      $45 = $44&255;
      $46 = HEAP8[$35>>0]|0;
      $47 = $46&255;
      $48 = (79212 + ($47<<2)|0);
      $49 = HEAP32[$48>>2]|0;
      $50 = HEAP32[$36>>2]|0;
      $51 = $50 & $45;
      $52 = HEAP8[$37>>0]|0;
      $53 = $52&255;
      $54 = $51 >>> $53;
      $55 = (($49) + ($54)|0);
      $56 = HEAP8[$38>>0]|0;
      $57 = $56&255;
      $58 = (79212 + ($57<<2)|0);
      $59 = HEAP32[$58>>2]|0;
      $60 = HEAP32[$39>>2]|0;
      $61 = $60 & $45;
      $62 = HEAP8[$40>>0]|0;
      $63 = $62&255;
      $64 = $61 >>> $63;
      $65 = (($59) + ($64)|0);
      $66 = HEAP8[$41>>0]|0;
      $67 = $66&255;
      $68 = (79212 + ($67<<2)|0);
      $69 = HEAP32[$68>>2]|0;
      $70 = HEAP32[$42>>2]|0;
      $71 = $70 & $45;
      $72 = HEAP8[$43>>0]|0;
      $73 = $72&255;
      $74 = $71 >>> $73;
      $75 = (($69) + ($74)|0);
      $$0928$shrunk$ph$in = $65;$$0944$shrunk$ph$in = $55;$$sink = $75;
      label = 12;
      break;
     }
     case 2:  {
      $76 = HEAP16[$$1961>>1]|0;
      $77 = $76&65535;
      $78 = HEAP8[$35>>0]|0;
      $79 = $78&255;
      $80 = (79212 + ($79<<2)|0);
      $81 = HEAP32[$80>>2]|0;
      $82 = HEAP32[$36>>2]|0;
      $83 = $82 & $77;
      $84 = HEAP8[$37>>0]|0;
      $85 = $84&255;
      $86 = $83 >>> $85;
      $87 = (($81) + ($86)|0);
      $88 = HEAP8[$38>>0]|0;
      $89 = $88&255;
      $90 = (79212 + ($89<<2)|0);
      $91 = HEAP32[$90>>2]|0;
      $92 = HEAP32[$39>>2]|0;
      $93 = $92 & $77;
      $94 = HEAP8[$40>>0]|0;
      $95 = $94&255;
      $96 = $93 >>> $95;
      $97 = (($91) + ($96)|0);
      $98 = HEAP8[$41>>0]|0;
      $99 = $98&255;
      $100 = (79212 + ($99<<2)|0);
      $101 = HEAP32[$100>>2]|0;
      $102 = HEAP32[$42>>2]|0;
      $103 = $102 & $77;
      $104 = HEAP8[$43>>0]|0;
      $105 = $104&255;
      $106 = $103 >>> $105;
      $107 = (($101) + ($106)|0);
      $$0928$shrunk$ph$in = $97;$$0944$shrunk$ph$in = $87;$$sink = $107;
      label = 12;
      break;
     }
     case 3:  {
      $108 = HEAP8[$37>>0]|0;
      $div1052 = ($108&255) >>> 3;
      $109 = $div1052&255;
      $110 = (($$1961) + ($109)|0);
      $111 = HEAP8[$40>>0]|0;
      $div1053 = ($111&255) >>> 3;
      $112 = $div1053&255;
      $113 = (($$1961) + ($112)|0);
      $114 = HEAP8[$43>>0]|0;
      $div1054 = ($114&255) >>> 3;
      $115 = $div1054&255;
      $116 = (($$1961) + ($115)|0);
      $$0928$shrunk$ph$in = $113;$$0944$shrunk$ph$in = $110;$$sink = $116;
      label = 12;
      break;
     }
     case 4:  {
      $117 = HEAP32[$$1961>>2]|0;
      $118 = HEAP8[$35>>0]|0;
      $119 = $118&255;
      $120 = (79212 + ($119<<2)|0);
      $121 = HEAP32[$120>>2]|0;
      $122 = HEAP32[$36>>2]|0;
      $123 = $122 & $117;
      $124 = HEAP8[$37>>0]|0;
      $125 = $124&255;
      $126 = $123 >>> $125;
      $127 = (($121) + ($126)|0);
      $128 = HEAP8[$38>>0]|0;
      $129 = $128&255;
      $130 = (79212 + ($129<<2)|0);
      $131 = HEAP32[$130>>2]|0;
      $132 = HEAP32[$39>>2]|0;
      $133 = $132 & $117;
      $134 = HEAP8[$40>>0]|0;
      $135 = $134&255;
      $136 = $133 >>> $135;
      $137 = (($131) + ($136)|0);
      $138 = HEAP8[$41>>0]|0;
      $139 = $138&255;
      $140 = (79212 + ($139<<2)|0);
      $141 = HEAP32[$140>>2]|0;
      $142 = HEAP32[$42>>2]|0;
      $143 = $142 & $117;
      $144 = HEAP8[$43>>0]|0;
      $145 = $144&255;
      $146 = $143 >>> $145;
      $147 = (($141) + ($146)|0);
      $$0928$shrunk$ph$in = $137;$$0944$shrunk$ph$in = $127;$$sink = $147;
      label = 12;
      break;
     }
     default: {
      $$0920$shrunk = 0;$$0928$shrunk = 0;$$0944$shrunk = 0;
     }
     }
     if ((label|0) == 12) {
      label = 0;
      $$0928$shrunk$ph = HEAP8[$$0928$shrunk$ph$in>>0]|0;
      $$0944$shrunk$ph = HEAP8[$$0944$shrunk$ph$in>>0]|0;
      $148 = HEAP8[$$sink>>0]|0;
      $$0920$shrunk = $148;$$0928$shrunk = $$0928$shrunk$ph;$$0944$shrunk = $$0944$shrunk$ph;
     }
     $$0920 = $$0920$shrunk&255;
     $$0928 = $$0928$shrunk&255;
     $149 = $$0944$shrunk & -32;
     $150 = $149&255;
     $151 = $$0928 >>> 5;
     $152 = $151 << 2;
     $153 = $152 | $150;
     $154 = $$0920 >>> 6;
     $155 = $153 | $154;
     $156 = $155&255;
     HEAP8[$$1977>>0] = $156;
     $157 = ((($$1977)) + 1|0);
     $158 = (($$1961) + ($18)|0);
     $$1911 = $$0910;$$2962 = $158;$$2978 = $157;
     label = 14;
     continue;
    }
    else if ((label|0) == 14) {
     label = 0;
     switch ($17<<24>>24) {
     case 1:  {
      $159 = HEAP8[$$2962>>0]|0;
      $160 = $159&255;
      $161 = HEAP8[$35>>0]|0;
      $162 = $161&255;
      $163 = (79212 + ($162<<2)|0);
      $164 = HEAP32[$163>>2]|0;
      $165 = HEAP32[$36>>2]|0;
      $166 = $165 & $160;
      $167 = HEAP8[$37>>0]|0;
      $168 = $167&255;
      $169 = $166 >>> $168;
      $170 = (($164) + ($169)|0);
      $171 = HEAP8[$38>>0]|0;
      $172 = $171&255;
      $173 = (79212 + ($172<<2)|0);
      $174 = HEAP32[$173>>2]|0;
      $175 = HEAP32[$39>>2]|0;
      $176 = $175 & $160;
      $177 = HEAP8[$40>>0]|0;
      $178 = $177&255;
      $179 = $176 >>> $178;
      $180 = (($174) + ($179)|0);
      $181 = HEAP8[$41>>0]|0;
      $182 = $181&255;
      $183 = (79212 + ($182<<2)|0);
      $184 = HEAP32[$183>>2]|0;
      $185 = HEAP32[$42>>2]|0;
      $186 = $185 & $160;
      $187 = HEAP8[$43>>0]|0;
      $188 = $187&255;
      $189 = $186 >>> $188;
      $190 = (($184) + ($189)|0);
      $$1929$shrunk$ph$in = $180;$$1945$shrunk$ph$in = $170;$$sink1059 = $190;
      label = 19;
      break;
     }
     case 2:  {
      $191 = HEAP16[$$2962>>1]|0;
      $192 = $191&65535;
      $193 = HEAP8[$35>>0]|0;
      $194 = $193&255;
      $195 = (79212 + ($194<<2)|0);
      $196 = HEAP32[$195>>2]|0;
      $197 = HEAP32[$36>>2]|0;
      $198 = $197 & $192;
      $199 = HEAP8[$37>>0]|0;
      $200 = $199&255;
      $201 = $198 >>> $200;
      $202 = (($196) + ($201)|0);
      $203 = HEAP8[$38>>0]|0;
      $204 = $203&255;
      $205 = (79212 + ($204<<2)|0);
      $206 = HEAP32[$205>>2]|0;
      $207 = HEAP32[$39>>2]|0;
      $208 = $207 & $192;
      $209 = HEAP8[$40>>0]|0;
      $210 = $209&255;
      $211 = $208 >>> $210;
      $212 = (($206) + ($211)|0);
      $213 = HEAP8[$41>>0]|0;
      $214 = $213&255;
      $215 = (79212 + ($214<<2)|0);
      $216 = HEAP32[$215>>2]|0;
      $217 = HEAP32[$42>>2]|0;
      $218 = $217 & $192;
      $219 = HEAP8[$43>>0]|0;
      $220 = $219&255;
      $221 = $218 >>> $220;
      $222 = (($216) + ($221)|0);
      $$1929$shrunk$ph$in = $212;$$1945$shrunk$ph$in = $202;$$sink1059 = $222;
      label = 19;
      break;
     }
     case 3:  {
      $223 = HEAP8[$37>>0]|0;
      $div1049 = ($223&255) >>> 3;
      $224 = $div1049&255;
      $225 = (($$2962) + ($224)|0);
      $226 = HEAP8[$40>>0]|0;
      $div1050 = ($226&255) >>> 3;
      $227 = $div1050&255;
      $228 = (($$2962) + ($227)|0);
      $229 = HEAP8[$43>>0]|0;
      $div1051 = ($229&255) >>> 3;
      $230 = $div1051&255;
      $231 = (($$2962) + ($230)|0);
      $$1929$shrunk$ph$in = $228;$$1945$shrunk$ph$in = $225;$$sink1059 = $231;
      label = 19;
      break;
     }
     case 4:  {
      $232 = HEAP32[$$2962>>2]|0;
      $233 = HEAP8[$35>>0]|0;
      $234 = $233&255;
      $235 = (79212 + ($234<<2)|0);
      $236 = HEAP32[$235>>2]|0;
      $237 = HEAP32[$36>>2]|0;
      $238 = $237 & $232;
      $239 = HEAP8[$37>>0]|0;
      $240 = $239&255;
      $241 = $238 >>> $240;
      $242 = (($236) + ($241)|0);
      $243 = HEAP8[$38>>0]|0;
      $244 = $243&255;
      $245 = (79212 + ($244<<2)|0);
      $246 = HEAP32[$245>>2]|0;
      $247 = HEAP32[$39>>2]|0;
      $248 = $247 & $232;
      $249 = HEAP8[$40>>0]|0;
      $250 = $249&255;
      $251 = $248 >>> $250;
      $252 = (($246) + ($251)|0);
      $253 = HEAP8[$41>>0]|0;
      $254 = $253&255;
      $255 = (79212 + ($254<<2)|0);
      $256 = HEAP32[$255>>2]|0;
      $257 = HEAP32[$42>>2]|0;
      $258 = $257 & $232;
      $259 = HEAP8[$43>>0]|0;
      $260 = $259&255;
      $261 = $258 >>> $260;
      $262 = (($256) + ($261)|0);
      $$1929$shrunk$ph$in = $252;$$1945$shrunk$ph$in = $242;$$sink1059 = $262;
      label = 19;
      break;
     }
     default: {
      $$1921$shrunk = 0;$$1929$shrunk = 0;$$1945$shrunk = 0;
     }
     }
     if ((label|0) == 19) {
      label = 0;
      $$1929$shrunk$ph = HEAP8[$$1929$shrunk$ph$in>>0]|0;
      $$1945$shrunk$ph = HEAP8[$$1945$shrunk$ph$in>>0]|0;
      $263 = HEAP8[$$sink1059>>0]|0;
      $$1921$shrunk = $263;$$1929$shrunk = $$1929$shrunk$ph;$$1945$shrunk = $$1945$shrunk$ph;
     }
     $$1921 = $$1921$shrunk&255;
     $$1929 = $$1929$shrunk&255;
     $264 = $$1945$shrunk & -32;
     $265 = $264&255;
     $266 = $$1929 >>> 5;
     $267 = $266 << 2;
     $268 = $267 | $265;
     $269 = $$1921 >>> 6;
     $270 = $268 | $269;
     $271 = $270&255;
     HEAP8[$$2978>>0] = $271;
     $272 = ((($$2978)) + 1|0);
     $273 = (($$2962) + ($18)|0);
     $$2912 = $$1911;$$3963 = $273;$$3979 = $272;
     label = 21;
     continue;
    }
    else if ((label|0) == 21) {
     label = 0;
     switch ($17<<24>>24) {
     case 1:  {
      $274 = HEAP8[$$3963>>0]|0;
      $275 = $274&255;
      $276 = HEAP8[$35>>0]|0;
      $277 = $276&255;
      $278 = (79212 + ($277<<2)|0);
      $279 = HEAP32[$278>>2]|0;
      $280 = HEAP32[$36>>2]|0;
      $281 = $280 & $275;
      $282 = HEAP8[$37>>0]|0;
      $283 = $282&255;
      $284 = $281 >>> $283;
      $285 = (($279) + ($284)|0);
      $286 = HEAP8[$38>>0]|0;
      $287 = $286&255;
      $288 = (79212 + ($287<<2)|0);
      $289 = HEAP32[$288>>2]|0;
      $290 = HEAP32[$39>>2]|0;
      $291 = $290 & $275;
      $292 = HEAP8[$40>>0]|0;
      $293 = $292&255;
      $294 = $291 >>> $293;
      $295 = (($289) + ($294)|0);
      $296 = HEAP8[$41>>0]|0;
      $297 = $296&255;
      $298 = (79212 + ($297<<2)|0);
      $299 = HEAP32[$298>>2]|0;
      $300 = HEAP32[$42>>2]|0;
      $301 = $300 & $275;
      $302 = HEAP8[$43>>0]|0;
      $303 = $302&255;
      $304 = $301 >>> $303;
      $305 = (($299) + ($304)|0);
      $$2930$shrunk$ph$in = $295;$$2946$shrunk$ph$in = $285;$$sink1061 = $305;
      label = 26;
      break;
     }
     case 2:  {
      $306 = HEAP16[$$3963>>1]|0;
      $307 = $306&65535;
      $308 = HEAP8[$35>>0]|0;
      $309 = $308&255;
      $310 = (79212 + ($309<<2)|0);
      $311 = HEAP32[$310>>2]|0;
      $312 = HEAP32[$36>>2]|0;
      $313 = $312 & $307;
      $314 = HEAP8[$37>>0]|0;
      $315 = $314&255;
      $316 = $313 >>> $315;
      $317 = (($311) + ($316)|0);
      $318 = HEAP8[$38>>0]|0;
      $319 = $318&255;
      $320 = (79212 + ($319<<2)|0);
      $321 = HEAP32[$320>>2]|0;
      $322 = HEAP32[$39>>2]|0;
      $323 = $322 & $307;
      $324 = HEAP8[$40>>0]|0;
      $325 = $324&255;
      $326 = $323 >>> $325;
      $327 = (($321) + ($326)|0);
      $328 = HEAP8[$41>>0]|0;
      $329 = $328&255;
      $330 = (79212 + ($329<<2)|0);
      $331 = HEAP32[$330>>2]|0;
      $332 = HEAP32[$42>>2]|0;
      $333 = $332 & $307;
      $334 = HEAP8[$43>>0]|0;
      $335 = $334&255;
      $336 = $333 >>> $335;
      $337 = (($331) + ($336)|0);
      $$2930$shrunk$ph$in = $327;$$2946$shrunk$ph$in = $317;$$sink1061 = $337;
      label = 26;
      break;
     }
     case 3:  {
      $338 = HEAP8[$37>>0]|0;
      $div1046 = ($338&255) >>> 3;
      $339 = $div1046&255;
      $340 = (($$3963) + ($339)|0);
      $341 = HEAP8[$40>>0]|0;
      $div1047 = ($341&255) >>> 3;
      $342 = $div1047&255;
      $343 = (($$3963) + ($342)|0);
      $344 = HEAP8[$43>>0]|0;
      $div1048 = ($344&255) >>> 3;
      $345 = $div1048&255;
      $346 = (($$3963) + ($345)|0);
      $$2930$shrunk$ph$in = $343;$$2946$shrunk$ph$in = $340;$$sink1061 = $346;
      label = 26;
      break;
     }
     case 4:  {
      $347 = HEAP32[$$3963>>2]|0;
      $348 = HEAP8[$35>>0]|0;
      $349 = $348&255;
      $350 = (79212 + ($349<<2)|0);
      $351 = HEAP32[$350>>2]|0;
      $352 = HEAP32[$36>>2]|0;
      $353 = $352 & $347;
      $354 = HEAP8[$37>>0]|0;
      $355 = $354&255;
      $356 = $353 >>> $355;
      $357 = (($351) + ($356)|0);
      $358 = HEAP8[$38>>0]|0;
      $359 = $358&255;
      $360 = (79212 + ($359<<2)|0);
      $361 = HEAP32[$360>>2]|0;
      $362 = HEAP32[$39>>2]|0;
      $363 = $362 & $347;
      $364 = HEAP8[$40>>0]|0;
      $365 = $364&255;
      $366 = $363 >>> $365;
      $367 = (($361) + ($366)|0);
      $368 = HEAP8[$41>>0]|0;
      $369 = $368&255;
      $370 = (79212 + ($369<<2)|0);
      $371 = HEAP32[$370>>2]|0;
      $372 = HEAP32[$42>>2]|0;
      $373 = $372 & $347;
      $374 = HEAP8[$43>>0]|0;
      $375 = $374&255;
      $376 = $373 >>> $375;
      $377 = (($371) + ($376)|0);
      $$2930$shrunk$ph$in = $367;$$2946$shrunk$ph$in = $357;$$sink1061 = $377;
      label = 26;
      break;
     }
     default: {
      $$2922$shrunk = 0;$$2930$shrunk = 0;$$2946$shrunk = 0;
     }
     }
     if ((label|0) == 26) {
      label = 0;
      $$2930$shrunk$ph = HEAP8[$$2930$shrunk$ph$in>>0]|0;
      $$2946$shrunk$ph = HEAP8[$$2946$shrunk$ph$in>>0]|0;
      $378 = HEAP8[$$sink1061>>0]|0;
      $$2922$shrunk = $378;$$2930$shrunk = $$2930$shrunk$ph;$$2946$shrunk = $$2946$shrunk$ph;
     }
     $$2922 = $$2922$shrunk&255;
     $$2930 = $$2930$shrunk&255;
     $379 = $$2946$shrunk & -32;
     $380 = $379&255;
     $381 = $$2930 >>> 5;
     $382 = $381 << 2;
     $383 = $382 | $380;
     $384 = $$2922 >>> 6;
     $385 = $383 | $384;
     $386 = $385&255;
     HEAP8[$$3979>>0] = $386;
     $387 = ((($$3979)) + 1|0);
     $388 = (($$3963) + ($18)|0);
     $$3913 = $$2912;$$4964 = $388;$$4980 = $387;
     label = 28;
     continue;
    }
    else if ((label|0) == 28) {
     label = 0;
     switch ($17<<24>>24) {
     case 1:  {
      $389 = HEAP8[$$4964>>0]|0;
      $390 = $389&255;
      $391 = HEAP8[$35>>0]|0;
      $392 = $391&255;
      $393 = (79212 + ($392<<2)|0);
      $394 = HEAP32[$393>>2]|0;
      $395 = HEAP32[$36>>2]|0;
      $396 = $395 & $390;
      $397 = HEAP8[$37>>0]|0;
      $398 = $397&255;
      $399 = $396 >>> $398;
      $400 = (($394) + ($399)|0);
      $401 = HEAP8[$38>>0]|0;
      $402 = $401&255;
      $403 = (79212 + ($402<<2)|0);
      $404 = HEAP32[$403>>2]|0;
      $405 = HEAP32[$39>>2]|0;
      $406 = $405 & $390;
      $407 = HEAP8[$40>>0]|0;
      $408 = $407&255;
      $409 = $406 >>> $408;
      $410 = (($404) + ($409)|0);
      $411 = HEAP8[$41>>0]|0;
      $412 = $411&255;
      $413 = (79212 + ($412<<2)|0);
      $414 = HEAP32[$413>>2]|0;
      $415 = HEAP32[$42>>2]|0;
      $416 = $415 & $390;
      $417 = HEAP8[$43>>0]|0;
      $418 = $417&255;
      $419 = $416 >>> $418;
      $420 = (($414) + ($419)|0);
      $$3931$shrunk$ph$in = $410;$$3947$shrunk$ph$in = $400;$$sink1063 = $420;
      label = 33;
      break;
     }
     case 2:  {
      $421 = HEAP16[$$4964>>1]|0;
      $422 = $421&65535;
      $423 = HEAP8[$35>>0]|0;
      $424 = $423&255;
      $425 = (79212 + ($424<<2)|0);
      $426 = HEAP32[$425>>2]|0;
      $427 = HEAP32[$36>>2]|0;
      $428 = $427 & $422;
      $429 = HEAP8[$37>>0]|0;
      $430 = $429&255;
      $431 = $428 >>> $430;
      $432 = (($426) + ($431)|0);
      $433 = HEAP8[$38>>0]|0;
      $434 = $433&255;
      $435 = (79212 + ($434<<2)|0);
      $436 = HEAP32[$435>>2]|0;
      $437 = HEAP32[$39>>2]|0;
      $438 = $437 & $422;
      $439 = HEAP8[$40>>0]|0;
      $440 = $439&255;
      $441 = $438 >>> $440;
      $442 = (($436) + ($441)|0);
      $443 = HEAP8[$41>>0]|0;
      $444 = $443&255;
      $445 = (79212 + ($444<<2)|0);
      $446 = HEAP32[$445>>2]|0;
      $447 = HEAP32[$42>>2]|0;
      $448 = $447 & $422;
      $449 = HEAP8[$43>>0]|0;
      $450 = $449&255;
      $451 = $448 >>> $450;
      $452 = (($446) + ($451)|0);
      $$3931$shrunk$ph$in = $442;$$3947$shrunk$ph$in = $432;$$sink1063 = $452;
      label = 33;
      break;
     }
     case 3:  {
      $453 = HEAP8[$37>>0]|0;
      $div1043 = ($453&255) >>> 3;
      $454 = $div1043&255;
      $455 = (($$4964) + ($454)|0);
      $456 = HEAP8[$40>>0]|0;
      $div1044 = ($456&255) >>> 3;
      $457 = $div1044&255;
      $458 = (($$4964) + ($457)|0);
      $459 = HEAP8[$43>>0]|0;
      $div1045 = ($459&255) >>> 3;
      $460 = $div1045&255;
      $461 = (($$4964) + ($460)|0);
      $$3931$shrunk$ph$in = $458;$$3947$shrunk$ph$in = $455;$$sink1063 = $461;
      label = 33;
      break;
     }
     case 4:  {
      $462 = HEAP32[$$4964>>2]|0;
      $463 = HEAP8[$35>>0]|0;
      $464 = $463&255;
      $465 = (79212 + ($464<<2)|0);
      $466 = HEAP32[$465>>2]|0;
      $467 = HEAP32[$36>>2]|0;
      $468 = $467 & $462;
      $469 = HEAP8[$37>>0]|0;
      $470 = $469&255;
      $471 = $468 >>> $470;
      $472 = (($466) + ($471)|0);
      $473 = HEAP8[$38>>0]|0;
      $474 = $473&255;
      $475 = (79212 + ($474<<2)|0);
      $476 = HEAP32[$475>>2]|0;
      $477 = HEAP32[$39>>2]|0;
      $478 = $477 & $462;
      $479 = HEAP8[$40>>0]|0;
      $480 = $479&255;
      $481 = $478 >>> $480;
      $482 = (($476) + ($481)|0);
      $483 = HEAP8[$41>>0]|0;
      $484 = $483&255;
      $485 = (79212 + ($484<<2)|0);
      $486 = HEAP32[$485>>2]|0;
      $487 = HEAP32[$42>>2]|0;
      $488 = $487 & $462;
      $489 = HEAP8[$43>>0]|0;
      $490 = $489&255;
      $491 = $488 >>> $490;
      $492 = (($486) + ($491)|0);
      $$3931$shrunk$ph$in = $482;$$3947$shrunk$ph$in = $472;$$sink1063 = $492;
      label = 33;
      break;
     }
     default: {
      $$3923$shrunk = 0;$$3931$shrunk = 0;$$3947$shrunk = 0;
     }
     }
     if ((label|0) == 33) {
      label = 0;
      $$3931$shrunk$ph = HEAP8[$$3931$shrunk$ph$in>>0]|0;
      $$3947$shrunk$ph = HEAP8[$$3947$shrunk$ph$in>>0]|0;
      $493 = HEAP8[$$sink1063>>0]|0;
      $$3923$shrunk = $493;$$3931$shrunk = $$3931$shrunk$ph;$$3947$shrunk = $$3947$shrunk$ph;
     }
     $$3923 = $$3923$shrunk&255;
     $$3931 = $$3931$shrunk&255;
     $494 = $$3947$shrunk & -32;
     $495 = $494&255;
     $496 = $$3931 >>> 5;
     $497 = $496 << 2;
     $498 = $497 | $495;
     $499 = $$3923 >>> 6;
     $500 = $498 | $499;
     $501 = $500&255;
     HEAP8[$$4980>>0] = $501;
     $502 = ((($$4980)) + 1|0);
     $503 = (($$4964) + ($18)|0);
     $$4914 = $$3913;$$5965 = $503;$$5981 = $502;
     label = 35;
     continue;
    }
    else if ((label|0) == 35) {
     label = 0;
     switch ($17<<24>>24) {
     case 1:  {
      $504 = HEAP8[$$5965>>0]|0;
      $505 = $504&255;
      $506 = HEAP8[$35>>0]|0;
      $507 = $506&255;
      $508 = (79212 + ($507<<2)|0);
      $509 = HEAP32[$508>>2]|0;
      $510 = HEAP32[$36>>2]|0;
      $511 = $510 & $505;
      $512 = HEAP8[$37>>0]|0;
      $513 = $512&255;
      $514 = $511 >>> $513;
      $515 = (($509) + ($514)|0);
      $516 = HEAP8[$38>>0]|0;
      $517 = $516&255;
      $518 = (79212 + ($517<<2)|0);
      $519 = HEAP32[$518>>2]|0;
      $520 = HEAP32[$39>>2]|0;
      $521 = $520 & $505;
      $522 = HEAP8[$40>>0]|0;
      $523 = $522&255;
      $524 = $521 >>> $523;
      $525 = (($519) + ($524)|0);
      $526 = HEAP8[$41>>0]|0;
      $527 = $526&255;
      $528 = (79212 + ($527<<2)|0);
      $529 = HEAP32[$528>>2]|0;
      $530 = HEAP32[$42>>2]|0;
      $531 = $530 & $505;
      $532 = HEAP8[$43>>0]|0;
      $533 = $532&255;
      $534 = $531 >>> $533;
      $535 = (($529) + ($534)|0);
      $$4932$shrunk$ph$in = $525;$$4948$shrunk$ph$in = $515;$$sink1065 = $535;
      label = 40;
      break;
     }
     case 2:  {
      $536 = HEAP16[$$5965>>1]|0;
      $537 = $536&65535;
      $538 = HEAP8[$35>>0]|0;
      $539 = $538&255;
      $540 = (79212 + ($539<<2)|0);
      $541 = HEAP32[$540>>2]|0;
      $542 = HEAP32[$36>>2]|0;
      $543 = $542 & $537;
      $544 = HEAP8[$37>>0]|0;
      $545 = $544&255;
      $546 = $543 >>> $545;
      $547 = (($541) + ($546)|0);
      $548 = HEAP8[$38>>0]|0;
      $549 = $548&255;
      $550 = (79212 + ($549<<2)|0);
      $551 = HEAP32[$550>>2]|0;
      $552 = HEAP32[$39>>2]|0;
      $553 = $552 & $537;
      $554 = HEAP8[$40>>0]|0;
      $555 = $554&255;
      $556 = $553 >>> $555;
      $557 = (($551) + ($556)|0);
      $558 = HEAP8[$41>>0]|0;
      $559 = $558&255;
      $560 = (79212 + ($559<<2)|0);
      $561 = HEAP32[$560>>2]|0;
      $562 = HEAP32[$42>>2]|0;
      $563 = $562 & $537;
      $564 = HEAP8[$43>>0]|0;
      $565 = $564&255;
      $566 = $563 >>> $565;
      $567 = (($561) + ($566)|0);
      $$4932$shrunk$ph$in = $557;$$4948$shrunk$ph$in = $547;$$sink1065 = $567;
      label = 40;
      break;
     }
     case 3:  {
      $568 = HEAP8[$37>>0]|0;
      $div1040 = ($568&255) >>> 3;
      $569 = $div1040&255;
      $570 = (($$5965) + ($569)|0);
      $571 = HEAP8[$40>>0]|0;
      $div1041 = ($571&255) >>> 3;
      $572 = $div1041&255;
      $573 = (($$5965) + ($572)|0);
      $574 = HEAP8[$43>>0]|0;
      $div1042 = ($574&255) >>> 3;
      $575 = $div1042&255;
      $576 = (($$5965) + ($575)|0);
      $$4932$shrunk$ph$in = $573;$$4948$shrunk$ph$in = $570;$$sink1065 = $576;
      label = 40;
      break;
     }
     case 4:  {
      $577 = HEAP32[$$5965>>2]|0;
      $578 = HEAP8[$35>>0]|0;
      $579 = $578&255;
      $580 = (79212 + ($579<<2)|0);
      $581 = HEAP32[$580>>2]|0;
      $582 = HEAP32[$36>>2]|0;
      $583 = $582 & $577;
      $584 = HEAP8[$37>>0]|0;
      $585 = $584&255;
      $586 = $583 >>> $585;
      $587 = (($581) + ($586)|0);
      $588 = HEAP8[$38>>0]|0;
      $589 = $588&255;
      $590 = (79212 + ($589<<2)|0);
      $591 = HEAP32[$590>>2]|0;
      $592 = HEAP32[$39>>2]|0;
      $593 = $592 & $577;
      $594 = HEAP8[$40>>0]|0;
      $595 = $594&255;
      $596 = $593 >>> $595;
      $597 = (($591) + ($596)|0);
      $598 = HEAP8[$41>>0]|0;
      $599 = $598&255;
      $600 = (79212 + ($599<<2)|0);
      $601 = HEAP32[$600>>2]|0;
      $602 = HEAP32[$42>>2]|0;
      $603 = $602 & $577;
      $604 = HEAP8[$43>>0]|0;
      $605 = $604&255;
      $606 = $603 >>> $605;
      $607 = (($601) + ($606)|0);
      $$4932$shrunk$ph$in = $597;$$4948$shrunk$ph$in = $587;$$sink1065 = $607;
      label = 40;
      break;
     }
     default: {
      $$4924$shrunk = 0;$$4932$shrunk = 0;$$4948$shrunk = 0;
     }
     }
     if ((label|0) == 40) {
      label = 0;
      $$4932$shrunk$ph = HEAP8[$$4932$shrunk$ph$in>>0]|0;
      $$4948$shrunk$ph = HEAP8[$$4948$shrunk$ph$in>>0]|0;
      $608 = HEAP8[$$sink1065>>0]|0;
      $$4924$shrunk = $608;$$4932$shrunk = $$4932$shrunk$ph;$$4948$shrunk = $$4948$shrunk$ph;
     }
     $$4924 = $$4924$shrunk&255;
     $$4932 = $$4932$shrunk&255;
     $609 = $$4948$shrunk & -32;
     $610 = $609&255;
     $611 = $$4932 >>> 5;
     $612 = $611 << 2;
     $613 = $612 | $610;
     $614 = $$4924 >>> 6;
     $615 = $613 | $614;
     $616 = $615&255;
     HEAP8[$$5981>>0] = $616;
     $617 = ((($$5981)) + 1|0);
     $618 = (($$5965) + ($18)|0);
     $$5915 = $$4914;$$6966 = $618;$$6982 = $617;
     label = 42;
     continue;
    }
    else if ((label|0) == 42) {
     label = 0;
     switch ($17<<24>>24) {
     case 1:  {
      $619 = HEAP8[$$6966>>0]|0;
      $620 = $619&255;
      $621 = HEAP8[$35>>0]|0;
      $622 = $621&255;
      $623 = (79212 + ($622<<2)|0);
      $624 = HEAP32[$623>>2]|0;
      $625 = HEAP32[$36>>2]|0;
      $626 = $625 & $620;
      $627 = HEAP8[$37>>0]|0;
      $628 = $627&255;
      $629 = $626 >>> $628;
      $630 = (($624) + ($629)|0);
      $631 = HEAP8[$38>>0]|0;
      $632 = $631&255;
      $633 = (79212 + ($632<<2)|0);
      $634 = HEAP32[$633>>2]|0;
      $635 = HEAP32[$39>>2]|0;
      $636 = $635 & $620;
      $637 = HEAP8[$40>>0]|0;
      $638 = $637&255;
      $639 = $636 >>> $638;
      $640 = (($634) + ($639)|0);
      $641 = HEAP8[$41>>0]|0;
      $642 = $641&255;
      $643 = (79212 + ($642<<2)|0);
      $644 = HEAP32[$643>>2]|0;
      $645 = HEAP32[$42>>2]|0;
      $646 = $645 & $620;
      $647 = HEAP8[$43>>0]|0;
      $648 = $647&255;
      $649 = $646 >>> $648;
      $650 = (($644) + ($649)|0);
      $$5933$shrunk$ph$in = $640;$$5949$shrunk$ph$in = $630;$$sink1067 = $650;
      label = 47;
      break;
     }
     case 2:  {
      $651 = HEAP16[$$6966>>1]|0;
      $652 = $651&65535;
      $653 = HEAP8[$35>>0]|0;
      $654 = $653&255;
      $655 = (79212 + ($654<<2)|0);
      $656 = HEAP32[$655>>2]|0;
      $657 = HEAP32[$36>>2]|0;
      $658 = $657 & $652;
      $659 = HEAP8[$37>>0]|0;
      $660 = $659&255;
      $661 = $658 >>> $660;
      $662 = (($656) + ($661)|0);
      $663 = HEAP8[$38>>0]|0;
      $664 = $663&255;
      $665 = (79212 + ($664<<2)|0);
      $666 = HEAP32[$665>>2]|0;
      $667 = HEAP32[$39>>2]|0;
      $668 = $667 & $652;
      $669 = HEAP8[$40>>0]|0;
      $670 = $669&255;
      $671 = $668 >>> $670;
      $672 = (($666) + ($671)|0);
      $673 = HEAP8[$41>>0]|0;
      $674 = $673&255;
      $675 = (79212 + ($674<<2)|0);
      $676 = HEAP32[$675>>2]|0;
      $677 = HEAP32[$42>>2]|0;
      $678 = $677 & $652;
      $679 = HEAP8[$43>>0]|0;
      $680 = $679&255;
      $681 = $678 >>> $680;
      $682 = (($676) + ($681)|0);
      $$5933$shrunk$ph$in = $672;$$5949$shrunk$ph$in = $662;$$sink1067 = $682;
      label = 47;
      break;
     }
     case 3:  {
      $683 = HEAP8[$37>>0]|0;
      $div1037 = ($683&255) >>> 3;
      $684 = $div1037&255;
      $685 = (($$6966) + ($684)|0);
      $686 = HEAP8[$40>>0]|0;
      $div1038 = ($686&255) >>> 3;
      $687 = $div1038&255;
      $688 = (($$6966) + ($687)|0);
      $689 = HEAP8[$43>>0]|0;
      $div1039 = ($689&255) >>> 3;
      $690 = $div1039&255;
      $691 = (($$6966) + ($690)|0);
      $$5933$shrunk$ph$in = $688;$$5949$shrunk$ph$in = $685;$$sink1067 = $691;
      label = 47;
      break;
     }
     case 4:  {
      $692 = HEAP32[$$6966>>2]|0;
      $693 = HEAP8[$35>>0]|0;
      $694 = $693&255;
      $695 = (79212 + ($694<<2)|0);
      $696 = HEAP32[$695>>2]|0;
      $697 = HEAP32[$36>>2]|0;
      $698 = $697 & $692;
      $699 = HEAP8[$37>>0]|0;
      $700 = $699&255;
      $701 = $698 >>> $700;
      $702 = (($696) + ($701)|0);
      $703 = HEAP8[$38>>0]|0;
      $704 = $703&255;
      $705 = (79212 + ($704<<2)|0);
      $706 = HEAP32[$705>>2]|0;
      $707 = HEAP32[$39>>2]|0;
      $708 = $707 & $692;
      $709 = HEAP8[$40>>0]|0;
      $710 = $709&255;
      $711 = $708 >>> $710;
      $712 = (($706) + ($711)|0);
      $713 = HEAP8[$41>>0]|0;
      $714 = $713&255;
      $715 = (79212 + ($714<<2)|0);
      $716 = HEAP32[$715>>2]|0;
      $717 = HEAP32[$42>>2]|0;
      $718 = $717 & $692;
      $719 = HEAP8[$43>>0]|0;
      $720 = $719&255;
      $721 = $718 >>> $720;
      $722 = (($716) + ($721)|0);
      $$5933$shrunk$ph$in = $712;$$5949$shrunk$ph$in = $702;$$sink1067 = $722;
      label = 47;
      break;
     }
     default: {
      $$5925$shrunk = 0;$$5933$shrunk = 0;$$5949$shrunk = 0;
     }
     }
     if ((label|0) == 47) {
      label = 0;
      $$5933$shrunk$ph = HEAP8[$$5933$shrunk$ph$in>>0]|0;
      $$5949$shrunk$ph = HEAP8[$$5949$shrunk$ph$in>>0]|0;
      $723 = HEAP8[$$sink1067>>0]|0;
      $$5925$shrunk = $723;$$5933$shrunk = $$5933$shrunk$ph;$$5949$shrunk = $$5949$shrunk$ph;
     }
     $$5925 = $$5925$shrunk&255;
     $$5933 = $$5933$shrunk&255;
     $724 = $$5949$shrunk & -32;
     $725 = $724&255;
     $726 = $$5933 >>> 5;
     $727 = $726 << 2;
     $728 = $727 | $725;
     $729 = $$5925 >>> 6;
     $730 = $728 | $729;
     $731 = $730&255;
     HEAP8[$$6982>>0] = $731;
     $732 = ((($$6982)) + 1|0);
     $733 = (($$6966) + ($18)|0);
     $$6916 = $$5915;$$7967 = $733;$$7983 = $732;
     label = 49;
     continue;
    }
    else if ((label|0) == 49) {
     label = 0;
     switch ($17<<24>>24) {
     case 1:  {
      $734 = HEAP8[$$7967>>0]|0;
      $735 = $734&255;
      $736 = HEAP8[$35>>0]|0;
      $737 = $736&255;
      $738 = (79212 + ($737<<2)|0);
      $739 = HEAP32[$738>>2]|0;
      $740 = HEAP32[$36>>2]|0;
      $741 = $740 & $735;
      $742 = HEAP8[$37>>0]|0;
      $743 = $742&255;
      $744 = $741 >>> $743;
      $745 = (($739) + ($744)|0);
      $746 = HEAP8[$38>>0]|0;
      $747 = $746&255;
      $748 = (79212 + ($747<<2)|0);
      $749 = HEAP32[$748>>2]|0;
      $750 = HEAP32[$39>>2]|0;
      $751 = $750 & $735;
      $752 = HEAP8[$40>>0]|0;
      $753 = $752&255;
      $754 = $751 >>> $753;
      $755 = (($749) + ($754)|0);
      $756 = HEAP8[$41>>0]|0;
      $757 = $756&255;
      $758 = (79212 + ($757<<2)|0);
      $759 = HEAP32[$758>>2]|0;
      $760 = HEAP32[$42>>2]|0;
      $761 = $760 & $735;
      $762 = HEAP8[$43>>0]|0;
      $763 = $762&255;
      $764 = $761 >>> $763;
      $765 = (($759) + ($764)|0);
      $$6934$shrunk$ph$in = $755;$$6950$shrunk$ph$in = $745;$$sink1069 = $765;
      label = 54;
      break;
     }
     case 2:  {
      $766 = HEAP16[$$7967>>1]|0;
      $767 = $766&65535;
      $768 = HEAP8[$35>>0]|0;
      $769 = $768&255;
      $770 = (79212 + ($769<<2)|0);
      $771 = HEAP32[$770>>2]|0;
      $772 = HEAP32[$36>>2]|0;
      $773 = $772 & $767;
      $774 = HEAP8[$37>>0]|0;
      $775 = $774&255;
      $776 = $773 >>> $775;
      $777 = (($771) + ($776)|0);
      $778 = HEAP8[$38>>0]|0;
      $779 = $778&255;
      $780 = (79212 + ($779<<2)|0);
      $781 = HEAP32[$780>>2]|0;
      $782 = HEAP32[$39>>2]|0;
      $783 = $782 & $767;
      $784 = HEAP8[$40>>0]|0;
      $785 = $784&255;
      $786 = $783 >>> $785;
      $787 = (($781) + ($786)|0);
      $788 = HEAP8[$41>>0]|0;
      $789 = $788&255;
      $790 = (79212 + ($789<<2)|0);
      $791 = HEAP32[$790>>2]|0;
      $792 = HEAP32[$42>>2]|0;
      $793 = $792 & $767;
      $794 = HEAP8[$43>>0]|0;
      $795 = $794&255;
      $796 = $793 >>> $795;
      $797 = (($791) + ($796)|0);
      $$6934$shrunk$ph$in = $787;$$6950$shrunk$ph$in = $777;$$sink1069 = $797;
      label = 54;
      break;
     }
     case 3:  {
      $798 = HEAP8[$37>>0]|0;
      $div1034 = ($798&255) >>> 3;
      $799 = $div1034&255;
      $800 = (($$7967) + ($799)|0);
      $801 = HEAP8[$40>>0]|0;
      $div1035 = ($801&255) >>> 3;
      $802 = $div1035&255;
      $803 = (($$7967) + ($802)|0);
      $804 = HEAP8[$43>>0]|0;
      $div1036 = ($804&255) >>> 3;
      $805 = $div1036&255;
      $806 = (($$7967) + ($805)|0);
      $$6934$shrunk$ph$in = $803;$$6950$shrunk$ph$in = $800;$$sink1069 = $806;
      label = 54;
      break;
     }
     case 4:  {
      $807 = HEAP32[$$7967>>2]|0;
      $808 = HEAP8[$35>>0]|0;
      $809 = $808&255;
      $810 = (79212 + ($809<<2)|0);
      $811 = HEAP32[$810>>2]|0;
      $812 = HEAP32[$36>>2]|0;
      $813 = $812 & $807;
      $814 = HEAP8[$37>>0]|0;
      $815 = $814&255;
      $816 = $813 >>> $815;
      $817 = (($811) + ($816)|0);
      $818 = HEAP8[$38>>0]|0;
      $819 = $818&255;
      $820 = (79212 + ($819<<2)|0);
      $821 = HEAP32[$820>>2]|0;
      $822 = HEAP32[$39>>2]|0;
      $823 = $822 & $807;
      $824 = HEAP8[$40>>0]|0;
      $825 = $824&255;
      $826 = $823 >>> $825;
      $827 = (($821) + ($826)|0);
      $828 = HEAP8[$41>>0]|0;
      $829 = $828&255;
      $830 = (79212 + ($829<<2)|0);
      $831 = HEAP32[$830>>2]|0;
      $832 = HEAP32[$42>>2]|0;
      $833 = $832 & $807;
      $834 = HEAP8[$43>>0]|0;
      $835 = $834&255;
      $836 = $833 >>> $835;
      $837 = (($831) + ($836)|0);
      $$6934$shrunk$ph$in = $827;$$6950$shrunk$ph$in = $817;$$sink1069 = $837;
      label = 54;
      break;
     }
     default: {
      $$6926$shrunk = 0;$$6934$shrunk = 0;$$6950$shrunk = 0;
     }
     }
     if ((label|0) == 54) {
      label = 0;
      $$6934$shrunk$ph = HEAP8[$$6934$shrunk$ph$in>>0]|0;
      $$6950$shrunk$ph = HEAP8[$$6950$shrunk$ph$in>>0]|0;
      $838 = HEAP8[$$sink1069>>0]|0;
      $$6926$shrunk = $838;$$6934$shrunk = $$6934$shrunk$ph;$$6950$shrunk = $$6950$shrunk$ph;
     }
     $$6926 = $$6926$shrunk&255;
     $$6934 = $$6934$shrunk&255;
     $839 = $$6950$shrunk & -32;
     $840 = $839&255;
     $841 = $$6934 >>> 5;
     $842 = $841 << 2;
     $843 = $842 | $840;
     $844 = $$6926 >>> 6;
     $845 = $843 | $844;
     $846 = $845&255;
     HEAP8[$$7983>>0] = $846;
     $847 = ((($$7983)) + 1|0);
     $848 = (($$7967) + ($18)|0);
     $$7917 = $$6916;$$8968 = $848;$$8984 = $847;
     label = 56;
     continue;
    }
    else if ((label|0) == 56) {
     label = 0;
     switch ($17<<24>>24) {
     case 1:  {
      $849 = HEAP8[$$8968>>0]|0;
      $850 = $849&255;
      $851 = HEAP8[$35>>0]|0;
      $852 = $851&255;
      $853 = (79212 + ($852<<2)|0);
      $854 = HEAP32[$853>>2]|0;
      $855 = HEAP32[$36>>2]|0;
      $856 = $855 & $850;
      $857 = HEAP8[$37>>0]|0;
      $858 = $857&255;
      $859 = $856 >>> $858;
      $860 = (($854) + ($859)|0);
      $861 = HEAP8[$38>>0]|0;
      $862 = $861&255;
      $863 = (79212 + ($862<<2)|0);
      $864 = HEAP32[$863>>2]|0;
      $865 = HEAP32[$39>>2]|0;
      $866 = $865 & $850;
      $867 = HEAP8[$40>>0]|0;
      $868 = $867&255;
      $869 = $866 >>> $868;
      $870 = (($864) + ($869)|0);
      $871 = HEAP8[$41>>0]|0;
      $872 = $871&255;
      $873 = (79212 + ($872<<2)|0);
      $874 = HEAP32[$873>>2]|0;
      $875 = HEAP32[$42>>2]|0;
      $876 = $875 & $850;
      $877 = HEAP8[$43>>0]|0;
      $878 = $877&255;
      $879 = $876 >>> $878;
      $880 = (($874) + ($879)|0);
      $$7935$shrunk$ph$in = $870;$$7951$shrunk$ph$in = $860;$$sink1071 = $880;
      label = 61;
      break;
     }
     case 2:  {
      $881 = HEAP16[$$8968>>1]|0;
      $882 = $881&65535;
      $883 = HEAP8[$35>>0]|0;
      $884 = $883&255;
      $885 = (79212 + ($884<<2)|0);
      $886 = HEAP32[$885>>2]|0;
      $887 = HEAP32[$36>>2]|0;
      $888 = $887 & $882;
      $889 = HEAP8[$37>>0]|0;
      $890 = $889&255;
      $891 = $888 >>> $890;
      $892 = (($886) + ($891)|0);
      $893 = HEAP8[$38>>0]|0;
      $894 = $893&255;
      $895 = (79212 + ($894<<2)|0);
      $896 = HEAP32[$895>>2]|0;
      $897 = HEAP32[$39>>2]|0;
      $898 = $897 & $882;
      $899 = HEAP8[$40>>0]|0;
      $900 = $899&255;
      $901 = $898 >>> $900;
      $902 = (($896) + ($901)|0);
      $903 = HEAP8[$41>>0]|0;
      $904 = $903&255;
      $905 = (79212 + ($904<<2)|0);
      $906 = HEAP32[$905>>2]|0;
      $907 = HEAP32[$42>>2]|0;
      $908 = $907 & $882;
      $909 = HEAP8[$43>>0]|0;
      $910 = $909&255;
      $911 = $908 >>> $910;
      $912 = (($906) + ($911)|0);
      $$7935$shrunk$ph$in = $902;$$7951$shrunk$ph$in = $892;$$sink1071 = $912;
      label = 61;
      break;
     }
     case 3:  {
      $913 = HEAP8[$37>>0]|0;
      $div1055 = ($913&255) >>> 3;
      $914 = $div1055&255;
      $915 = (($$8968) + ($914)|0);
      $916 = HEAP8[$40>>0]|0;
      $div1056 = ($916&255) >>> 3;
      $917 = $div1056&255;
      $918 = (($$8968) + ($917)|0);
      $919 = HEAP8[$43>>0]|0;
      $div1057 = ($919&255) >>> 3;
      $920 = $div1057&255;
      $921 = (($$8968) + ($920)|0);
      $$7935$shrunk$ph$in = $918;$$7951$shrunk$ph$in = $915;$$sink1071 = $921;
      label = 61;
      break;
     }
     case 4:  {
      $922 = HEAP32[$$8968>>2]|0;
      $923 = HEAP8[$35>>0]|0;
      $924 = $923&255;
      $925 = (79212 + ($924<<2)|0);
      $926 = HEAP32[$925>>2]|0;
      $927 = HEAP32[$36>>2]|0;
      $928 = $927 & $922;
      $929 = HEAP8[$37>>0]|0;
      $930 = $929&255;
      $931 = $928 >>> $930;
      $932 = (($926) + ($931)|0);
      $933 = HEAP8[$38>>0]|0;
      $934 = $933&255;
      $935 = (79212 + ($934<<2)|0);
      $936 = HEAP32[$935>>2]|0;
      $937 = HEAP32[$39>>2]|0;
      $938 = $937 & $922;
      $939 = HEAP8[$40>>0]|0;
      $940 = $939&255;
      $941 = $938 >>> $940;
      $942 = (($936) + ($941)|0);
      $943 = HEAP8[$41>>0]|0;
      $944 = $943&255;
      $945 = (79212 + ($944<<2)|0);
      $946 = HEAP32[$945>>2]|0;
      $947 = HEAP32[$42>>2]|0;
      $948 = $947 & $922;
      $949 = HEAP8[$43>>0]|0;
      $950 = $949&255;
      $951 = $948 >>> $950;
      $952 = (($946) + ($951)|0);
      $$7935$shrunk$ph$in = $942;$$7951$shrunk$ph$in = $932;$$sink1071 = $952;
      label = 61;
      break;
     }
     default: {
      $$7927$shrunk = 0;$$7935$shrunk = 0;$$7951$shrunk = 0;
     }
     }
     if ((label|0) == 61) {
      label = 0;
      $$7935$shrunk$ph = HEAP8[$$7935$shrunk$ph$in>>0]|0;
      $$7951$shrunk$ph = HEAP8[$$7951$shrunk$ph$in>>0]|0;
      $953 = HEAP8[$$sink1071>>0]|0;
      $$7927$shrunk = $953;$$7935$shrunk = $$7935$shrunk$ph;$$7951$shrunk = $$7951$shrunk$ph;
     }
     $$7927 = $$7927$shrunk&255;
     $$7935 = $$7935$shrunk&255;
     $954 = $$7951$shrunk & -32;
     $955 = $954&255;
     $956 = $$7935 >>> 5;
     $957 = $956 << 2;
     $958 = $957 | $955;
     $959 = $$7927 >>> 6;
     $960 = $958 | $959;
     $961 = $960&255;
     HEAP8[$$8984>>0] = $961;
     $962 = ((($$8984)) + 1|0);
     $963 = (($$8968) + ($18)|0);
     $964 = (($$7917) + -1)|0;
     $965 = ($$7917|0)>(1);
     if ($965) {
      $$0910 = $964;$$1961 = $963;$$1977 = $962;
      label = 7;
      continue;
     } else {
      break;
     }
    }
   }
   $966 = (($963) + ($7)|0);
   $967 = (($962) + ($11)|0);
   $968 = (($969) + -1)|0;
   $970 = ($969|0)==(0);
   if ($970) {
    label = 124;
    break;
   } else {
    $$09601091 = $966;$$09761090 = $967;$969 = $968;
   }
  }
  if ((label|0) == 63) {
   // unreachable;
  }
  else if ((label|0) == 124) {
   return;
  }
 } else {
  if ($21) {
   return;
  }
  $22 = (($2) + 7)|0;
  $23 = (($22|0) / 8)&-1;
  $trunc = $2&255;
  $24 = ((($15)) + 28|0);
  $25 = ((($15)) + 12|0);
  $26 = ((($15)) + 32|0);
  $27 = ((($15)) + 29|0);
  $28 = ((($15)) + 16|0);
  $29 = ((($15)) + 33|0);
  $30 = ((($15)) + 30|0);
  $31 = ((($15)) + 20|0);
  $32 = ((($15)) + 34|0);
  $$99691093 = $5;$$99851092 = $9;$1904 = $20;
  L90: while(1) {
   $trunc$clear = $trunc & 7;
   switch ($trunc$clear<<24>>24) {
   case 0:  {
    $$0 = $23;$$10970 = $$99691093;$$10986 = $$99851092;
    label = 66;
    break;
   }
   case 7:  {
    $$1 = $23;$$11971 = $$99691093;$$11987 = $$99851092;
    label = 73;
    break;
   }
   case 6:  {
    $$12972 = $$99691093;$$12988 = $$99851092;$$2 = $23;
    label = 80;
    break;
   }
   case 5:  {
    $$13973 = $$99691093;$$13989 = $$99851092;$$3 = $23;
    label = 87;
    break;
   }
   case 4:  {
    $$14974 = $$99691093;$$14990 = $$99851092;$$4 = $23;
    label = 94;
    break;
   }
   case 3:  {
    $$15975 = $$99691093;$$15991 = $$99851092;$$5 = $23;
    label = 101;
    break;
   }
   case 2:  {
    $$16 = $$99691093;$$16992 = $$99851092;$$6 = $23;
    label = 108;
    break;
   }
   case 1:  {
    $$17 = $$99691093;$$17993 = $$99851092;$$7 = $23;
    label = 115;
    break;
   }
   default: {
    label = 122;
    break L90;
   }
   }
   while(1) {
    if ((label|0) == 66) {
     label = 0;
     switch ($17<<24>>24) {
     case 1:  {
      $971 = HEAP8[$$10970>>0]|0;
      $972 = $971&255;
      $973 = HEAP8[$24>>0]|0;
      $974 = $973&255;
      $975 = (79212 + ($974<<2)|0);
      $976 = HEAP32[$975>>2]|0;
      $977 = HEAP32[$25>>2]|0;
      $978 = $977 & $972;
      $979 = HEAP8[$26>>0]|0;
      $980 = $979&255;
      $981 = $978 >>> $980;
      $982 = (($976) + ($981)|0);
      $983 = HEAP8[$27>>0]|0;
      $984 = $983&255;
      $985 = (79212 + ($984<<2)|0);
      $986 = HEAP32[$985>>2]|0;
      $987 = HEAP32[$28>>2]|0;
      $988 = $987 & $972;
      $989 = HEAP8[$29>>0]|0;
      $990 = $989&255;
      $991 = $988 >>> $990;
      $992 = (($986) + ($991)|0);
      $993 = HEAP8[$30>>0]|0;
      $994 = $993&255;
      $995 = (79212 + ($994<<2)|0);
      $996 = HEAP32[$995>>2]|0;
      $997 = HEAP32[$31>>2]|0;
      $998 = $997 & $972;
      $999 = HEAP8[$32>>0]|0;
      $1000 = $999&255;
      $1001 = $998 >>> $1000;
      $1002 = (($996) + ($1001)|0);
      $$8936$shrunk$ph$in = $992;$$8952$shrunk$ph$in = $982;$$sink1073 = $1002;
      label = 71;
      break;
     }
     case 2:  {
      $1003 = HEAP16[$$10970>>1]|0;
      $1004 = $1003&65535;
      $1005 = HEAP8[$24>>0]|0;
      $1006 = $1005&255;
      $1007 = (79212 + ($1006<<2)|0);
      $1008 = HEAP32[$1007>>2]|0;
      $1009 = HEAP32[$25>>2]|0;
      $1010 = $1009 & $1004;
      $1011 = HEAP8[$26>>0]|0;
      $1012 = $1011&255;
      $1013 = $1010 >>> $1012;
      $1014 = (($1008) + ($1013)|0);
      $1015 = HEAP8[$27>>0]|0;
      $1016 = $1015&255;
      $1017 = (79212 + ($1016<<2)|0);
      $1018 = HEAP32[$1017>>2]|0;
      $1019 = HEAP32[$28>>2]|0;
      $1020 = $1019 & $1004;
      $1021 = HEAP8[$29>>0]|0;
      $1022 = $1021&255;
      $1023 = $1020 >>> $1022;
      $1024 = (($1018) + ($1023)|0);
      $1025 = HEAP8[$30>>0]|0;
      $1026 = $1025&255;
      $1027 = (79212 + ($1026<<2)|0);
      $1028 = HEAP32[$1027>>2]|0;
      $1029 = HEAP32[$31>>2]|0;
      $1030 = $1029 & $1004;
      $1031 = HEAP8[$32>>0]|0;
      $1032 = $1031&255;
      $1033 = $1030 >>> $1032;
      $1034 = (($1028) + ($1033)|0);
      $$8936$shrunk$ph$in = $1024;$$8952$shrunk$ph$in = $1014;$$sink1073 = $1034;
      label = 71;
      break;
     }
     case 3:  {
      $1035 = HEAP8[$26>>0]|0;
      $div1019 = ($1035&255) >>> 3;
      $1036 = $div1019&255;
      $1037 = (($$10970) + ($1036)|0);
      $1038 = HEAP8[$29>>0]|0;
      $div1020 = ($1038&255) >>> 3;
      $1039 = $div1020&255;
      $1040 = (($$10970) + ($1039)|0);
      $1041 = HEAP8[$32>>0]|0;
      $div1021 = ($1041&255) >>> 3;
      $1042 = $div1021&255;
      $1043 = (($$10970) + ($1042)|0);
      $$8936$shrunk$ph$in = $1040;$$8952$shrunk$ph$in = $1037;$$sink1073 = $1043;
      label = 71;
      break;
     }
     case 4:  {
      $1044 = HEAP32[$$10970>>2]|0;
      $1045 = HEAP8[$24>>0]|0;
      $1046 = $1045&255;
      $1047 = (79212 + ($1046<<2)|0);
      $1048 = HEAP32[$1047>>2]|0;
      $1049 = HEAP32[$25>>2]|0;
      $1050 = $1049 & $1044;
      $1051 = HEAP8[$26>>0]|0;
      $1052 = $1051&255;
      $1053 = $1050 >>> $1052;
      $1054 = (($1048) + ($1053)|0);
      $1055 = HEAP8[$27>>0]|0;
      $1056 = $1055&255;
      $1057 = (79212 + ($1056<<2)|0);
      $1058 = HEAP32[$1057>>2]|0;
      $1059 = HEAP32[$28>>2]|0;
      $1060 = $1059 & $1044;
      $1061 = HEAP8[$29>>0]|0;
      $1062 = $1061&255;
      $1063 = $1060 >>> $1062;
      $1064 = (($1058) + ($1063)|0);
      $1065 = HEAP8[$30>>0]|0;
      $1066 = $1065&255;
      $1067 = (79212 + ($1066<<2)|0);
      $1068 = HEAP32[$1067>>2]|0;
      $1069 = HEAP32[$31>>2]|0;
      $1070 = $1069 & $1044;
      $1071 = HEAP8[$32>>0]|0;
      $1072 = $1071&255;
      $1073 = $1070 >>> $1072;
      $1074 = (($1068) + ($1073)|0);
      $$8936$shrunk$ph$in = $1064;$$8952$shrunk$ph$in = $1054;$$sink1073 = $1074;
      label = 71;
      break;
     }
     default: {
      $$8$shrunk = 0;$$8936$shrunk = 0;$$8952$shrunk = 0;
     }
     }
     if ((label|0) == 71) {
      label = 0;
      $$8936$shrunk$ph = HEAP8[$$8936$shrunk$ph$in>>0]|0;
      $$8952$shrunk$ph = HEAP8[$$8952$shrunk$ph$in>>0]|0;
      $1075 = HEAP8[$$sink1073>>0]|0;
      $$8$shrunk = $1075;$$8936$shrunk = $$8936$shrunk$ph;$$8952$shrunk = $$8952$shrunk$ph;
     }
     $$8 = $$8$shrunk&255;
     $$8936 = $$8936$shrunk&255;
     $1076 = $$8952$shrunk & -32;
     $1077 = $1076&255;
     $1078 = $$8936 >>> 5;
     $1079 = $1078 << 2;
     $1080 = $1079 | $1077;
     $1081 = $$8 >>> 6;
     $1082 = $1080 | $1081;
     $1083 = (($13) + ($1082)|0);
     $1084 = HEAP8[$1083>>0]|0;
     HEAP8[$$10986>>0] = $1084;
     $1085 = ((($$10986)) + 1|0);
     $1086 = (($$10970) + ($18)|0);
     $$1 = $$0;$$11971 = $1086;$$11987 = $1085;
     label = 73;
     continue;
    }
    else if ((label|0) == 73) {
     label = 0;
     switch ($17<<24>>24) {
     case 1:  {
      $1087 = HEAP8[$$11971>>0]|0;
      $1088 = $1087&255;
      $1089 = HEAP8[$24>>0]|0;
      $1090 = $1089&255;
      $1091 = (79212 + ($1090<<2)|0);
      $1092 = HEAP32[$1091>>2]|0;
      $1093 = HEAP32[$25>>2]|0;
      $1094 = $1093 & $1088;
      $1095 = HEAP8[$26>>0]|0;
      $1096 = $1095&255;
      $1097 = $1094 >>> $1096;
      $1098 = (($1092) + ($1097)|0);
      $1099 = HEAP8[$27>>0]|0;
      $1100 = $1099&255;
      $1101 = (79212 + ($1100<<2)|0);
      $1102 = HEAP32[$1101>>2]|0;
      $1103 = HEAP32[$28>>2]|0;
      $1104 = $1103 & $1088;
      $1105 = HEAP8[$29>>0]|0;
      $1106 = $1105&255;
      $1107 = $1104 >>> $1106;
      $1108 = (($1102) + ($1107)|0);
      $1109 = HEAP8[$30>>0]|0;
      $1110 = $1109&255;
      $1111 = (79212 + ($1110<<2)|0);
      $1112 = HEAP32[$1111>>2]|0;
      $1113 = HEAP32[$31>>2]|0;
      $1114 = $1113 & $1088;
      $1115 = HEAP8[$32>>0]|0;
      $1116 = $1115&255;
      $1117 = $1114 >>> $1116;
      $1118 = (($1112) + ($1117)|0);
      $$9937$shrunk$ph$in = $1108;$$9953$shrunk$ph$in = $1098;$$sink1075 = $1118;
      label = 78;
      break;
     }
     case 2:  {
      $1119 = HEAP16[$$11971>>1]|0;
      $1120 = $1119&65535;
      $1121 = HEAP8[$24>>0]|0;
      $1122 = $1121&255;
      $1123 = (79212 + ($1122<<2)|0);
      $1124 = HEAP32[$1123>>2]|0;
      $1125 = HEAP32[$25>>2]|0;
      $1126 = $1125 & $1120;
      $1127 = HEAP8[$26>>0]|0;
      $1128 = $1127&255;
      $1129 = $1126 >>> $1128;
      $1130 = (($1124) + ($1129)|0);
      $1131 = HEAP8[$27>>0]|0;
      $1132 = $1131&255;
      $1133 = (79212 + ($1132<<2)|0);
      $1134 = HEAP32[$1133>>2]|0;
      $1135 = HEAP32[$28>>2]|0;
      $1136 = $1135 & $1120;
      $1137 = HEAP8[$29>>0]|0;
      $1138 = $1137&255;
      $1139 = $1136 >>> $1138;
      $1140 = (($1134) + ($1139)|0);
      $1141 = HEAP8[$30>>0]|0;
      $1142 = $1141&255;
      $1143 = (79212 + ($1142<<2)|0);
      $1144 = HEAP32[$1143>>2]|0;
      $1145 = HEAP32[$31>>2]|0;
      $1146 = $1145 & $1120;
      $1147 = HEAP8[$32>>0]|0;
      $1148 = $1147&255;
      $1149 = $1146 >>> $1148;
      $1150 = (($1144) + ($1149)|0);
      $$9937$shrunk$ph$in = $1140;$$9953$shrunk$ph$in = $1130;$$sink1075 = $1150;
      label = 78;
      break;
     }
     case 3:  {
      $1151 = HEAP8[$26>>0]|0;
      $div1016 = ($1151&255) >>> 3;
      $1152 = $div1016&255;
      $1153 = (($$11971) + ($1152)|0);
      $1154 = HEAP8[$29>>0]|0;
      $div1017 = ($1154&255) >>> 3;
      $1155 = $div1017&255;
      $1156 = (($$11971) + ($1155)|0);
      $1157 = HEAP8[$32>>0]|0;
      $div1018 = ($1157&255) >>> 3;
      $1158 = $div1018&255;
      $1159 = (($$11971) + ($1158)|0);
      $$9937$shrunk$ph$in = $1156;$$9953$shrunk$ph$in = $1153;$$sink1075 = $1159;
      label = 78;
      break;
     }
     case 4:  {
      $1160 = HEAP32[$$11971>>2]|0;
      $1161 = HEAP8[$24>>0]|0;
      $1162 = $1161&255;
      $1163 = (79212 + ($1162<<2)|0);
      $1164 = HEAP32[$1163>>2]|0;
      $1165 = HEAP32[$25>>2]|0;
      $1166 = $1165 & $1160;
      $1167 = HEAP8[$26>>0]|0;
      $1168 = $1167&255;
      $1169 = $1166 >>> $1168;
      $1170 = (($1164) + ($1169)|0);
      $1171 = HEAP8[$27>>0]|0;
      $1172 = $1171&255;
      $1173 = (79212 + ($1172<<2)|0);
      $1174 = HEAP32[$1173>>2]|0;
      $1175 = HEAP32[$28>>2]|0;
      $1176 = $1175 & $1160;
      $1177 = HEAP8[$29>>0]|0;
      $1178 = $1177&255;
      $1179 = $1176 >>> $1178;
      $1180 = (($1174) + ($1179)|0);
      $1181 = HEAP8[$30>>0]|0;
      $1182 = $1181&255;
      $1183 = (79212 + ($1182<<2)|0);
      $1184 = HEAP32[$1183>>2]|0;
      $1185 = HEAP32[$31>>2]|0;
      $1186 = $1185 & $1160;
      $1187 = HEAP8[$32>>0]|0;
      $1188 = $1187&255;
      $1189 = $1186 >>> $1188;
      $1190 = (($1184) + ($1189)|0);
      $$9937$shrunk$ph$in = $1180;$$9953$shrunk$ph$in = $1170;$$sink1075 = $1190;
      label = 78;
      break;
     }
     default: {
      $$9$shrunk = 0;$$9937$shrunk = 0;$$9953$shrunk = 0;
     }
     }
     if ((label|0) == 78) {
      label = 0;
      $$9937$shrunk$ph = HEAP8[$$9937$shrunk$ph$in>>0]|0;
      $$9953$shrunk$ph = HEAP8[$$9953$shrunk$ph$in>>0]|0;
      $1191 = HEAP8[$$sink1075>>0]|0;
      $$9$shrunk = $1191;$$9937$shrunk = $$9937$shrunk$ph;$$9953$shrunk = $$9953$shrunk$ph;
     }
     $$9 = $$9$shrunk&255;
     $$9937 = $$9937$shrunk&255;
     $1192 = $$9953$shrunk & -32;
     $1193 = $1192&255;
     $1194 = $$9937 >>> 5;
     $1195 = $1194 << 2;
     $1196 = $1195 | $1193;
     $1197 = $$9 >>> 6;
     $1198 = $1196 | $1197;
     $1199 = (($13) + ($1198)|0);
     $1200 = HEAP8[$1199>>0]|0;
     HEAP8[$$11987>>0] = $1200;
     $1201 = ((($$11987)) + 1|0);
     $1202 = (($$11971) + ($18)|0);
     $$12972 = $1202;$$12988 = $1201;$$2 = $$1;
     label = 80;
     continue;
    }
    else if ((label|0) == 80) {
     label = 0;
     switch ($17<<24>>24) {
     case 1:  {
      $1203 = HEAP8[$$12972>>0]|0;
      $1204 = $1203&255;
      $1205 = HEAP8[$24>>0]|0;
      $1206 = $1205&255;
      $1207 = (79212 + ($1206<<2)|0);
      $1208 = HEAP32[$1207>>2]|0;
      $1209 = HEAP32[$25>>2]|0;
      $1210 = $1209 & $1204;
      $1211 = HEAP8[$26>>0]|0;
      $1212 = $1211&255;
      $1213 = $1210 >>> $1212;
      $1214 = (($1208) + ($1213)|0);
      $1215 = HEAP8[$27>>0]|0;
      $1216 = $1215&255;
      $1217 = (79212 + ($1216<<2)|0);
      $1218 = HEAP32[$1217>>2]|0;
      $1219 = HEAP32[$28>>2]|0;
      $1220 = $1219 & $1204;
      $1221 = HEAP8[$29>>0]|0;
      $1222 = $1221&255;
      $1223 = $1220 >>> $1222;
      $1224 = (($1218) + ($1223)|0);
      $1225 = HEAP8[$30>>0]|0;
      $1226 = $1225&255;
      $1227 = (79212 + ($1226<<2)|0);
      $1228 = HEAP32[$1227>>2]|0;
      $1229 = HEAP32[$31>>2]|0;
      $1230 = $1229 & $1204;
      $1231 = HEAP8[$32>>0]|0;
      $1232 = $1231&255;
      $1233 = $1230 >>> $1232;
      $1234 = (($1228) + ($1233)|0);
      $$10938$shrunk$ph$in = $1224;$$10954$shrunk$ph$in = $1214;$$sink1077 = $1234;
      label = 85;
      break;
     }
     case 2:  {
      $1235 = HEAP16[$$12972>>1]|0;
      $1236 = $1235&65535;
      $1237 = HEAP8[$24>>0]|0;
      $1238 = $1237&255;
      $1239 = (79212 + ($1238<<2)|0);
      $1240 = HEAP32[$1239>>2]|0;
      $1241 = HEAP32[$25>>2]|0;
      $1242 = $1241 & $1236;
      $1243 = HEAP8[$26>>0]|0;
      $1244 = $1243&255;
      $1245 = $1242 >>> $1244;
      $1246 = (($1240) + ($1245)|0);
      $1247 = HEAP8[$27>>0]|0;
      $1248 = $1247&255;
      $1249 = (79212 + ($1248<<2)|0);
      $1250 = HEAP32[$1249>>2]|0;
      $1251 = HEAP32[$28>>2]|0;
      $1252 = $1251 & $1236;
      $1253 = HEAP8[$29>>0]|0;
      $1254 = $1253&255;
      $1255 = $1252 >>> $1254;
      $1256 = (($1250) + ($1255)|0);
      $1257 = HEAP8[$30>>0]|0;
      $1258 = $1257&255;
      $1259 = (79212 + ($1258<<2)|0);
      $1260 = HEAP32[$1259>>2]|0;
      $1261 = HEAP32[$31>>2]|0;
      $1262 = $1261 & $1236;
      $1263 = HEAP8[$32>>0]|0;
      $1264 = $1263&255;
      $1265 = $1262 >>> $1264;
      $1266 = (($1260) + ($1265)|0);
      $$10938$shrunk$ph$in = $1256;$$10954$shrunk$ph$in = $1246;$$sink1077 = $1266;
      label = 85;
      break;
     }
     case 3:  {
      $1267 = HEAP8[$26>>0]|0;
      $div1013 = ($1267&255) >>> 3;
      $1268 = $div1013&255;
      $1269 = (($$12972) + ($1268)|0);
      $1270 = HEAP8[$29>>0]|0;
      $div1014 = ($1270&255) >>> 3;
      $1271 = $div1014&255;
      $1272 = (($$12972) + ($1271)|0);
      $1273 = HEAP8[$32>>0]|0;
      $div1015 = ($1273&255) >>> 3;
      $1274 = $div1015&255;
      $1275 = (($$12972) + ($1274)|0);
      $$10938$shrunk$ph$in = $1272;$$10954$shrunk$ph$in = $1269;$$sink1077 = $1275;
      label = 85;
      break;
     }
     case 4:  {
      $1276 = HEAP32[$$12972>>2]|0;
      $1277 = HEAP8[$24>>0]|0;
      $1278 = $1277&255;
      $1279 = (79212 + ($1278<<2)|0);
      $1280 = HEAP32[$1279>>2]|0;
      $1281 = HEAP32[$25>>2]|0;
      $1282 = $1281 & $1276;
      $1283 = HEAP8[$26>>0]|0;
      $1284 = $1283&255;
      $1285 = $1282 >>> $1284;
      $1286 = (($1280) + ($1285)|0);
      $1287 = HEAP8[$27>>0]|0;
      $1288 = $1287&255;
      $1289 = (79212 + ($1288<<2)|0);
      $1290 = HEAP32[$1289>>2]|0;
      $1291 = HEAP32[$28>>2]|0;
      $1292 = $1291 & $1276;
      $1293 = HEAP8[$29>>0]|0;
      $1294 = $1293&255;
      $1295 = $1292 >>> $1294;
      $1296 = (($1290) + ($1295)|0);
      $1297 = HEAP8[$30>>0]|0;
      $1298 = $1297&255;
      $1299 = (79212 + ($1298<<2)|0);
      $1300 = HEAP32[$1299>>2]|0;
      $1301 = HEAP32[$31>>2]|0;
      $1302 = $1301 & $1276;
      $1303 = HEAP8[$32>>0]|0;
      $1304 = $1303&255;
      $1305 = $1302 >>> $1304;
      $1306 = (($1300) + ($1305)|0);
      $$10938$shrunk$ph$in = $1296;$$10954$shrunk$ph$in = $1286;$$sink1077 = $1306;
      label = 85;
      break;
     }
     default: {
      $$10$shrunk = 0;$$10938$shrunk = 0;$$10954$shrunk = 0;
     }
     }
     if ((label|0) == 85) {
      label = 0;
      $$10938$shrunk$ph = HEAP8[$$10938$shrunk$ph$in>>0]|0;
      $$10954$shrunk$ph = HEAP8[$$10954$shrunk$ph$in>>0]|0;
      $1307 = HEAP8[$$sink1077>>0]|0;
      $$10$shrunk = $1307;$$10938$shrunk = $$10938$shrunk$ph;$$10954$shrunk = $$10954$shrunk$ph;
     }
     $$10 = $$10$shrunk&255;
     $$10938 = $$10938$shrunk&255;
     $1308 = $$10954$shrunk & -32;
     $1309 = $1308&255;
     $1310 = $$10938 >>> 5;
     $1311 = $1310 << 2;
     $1312 = $1311 | $1309;
     $1313 = $$10 >>> 6;
     $1314 = $1312 | $1313;
     $1315 = (($13) + ($1314)|0);
     $1316 = HEAP8[$1315>>0]|0;
     HEAP8[$$12988>>0] = $1316;
     $1317 = ((($$12988)) + 1|0);
     $1318 = (($$12972) + ($18)|0);
     $$13973 = $1318;$$13989 = $1317;$$3 = $$2;
     label = 87;
     continue;
    }
    else if ((label|0) == 87) {
     label = 0;
     switch ($17<<24>>24) {
     case 1:  {
      $1319 = HEAP8[$$13973>>0]|0;
      $1320 = $1319&255;
      $1321 = HEAP8[$24>>0]|0;
      $1322 = $1321&255;
      $1323 = (79212 + ($1322<<2)|0);
      $1324 = HEAP32[$1323>>2]|0;
      $1325 = HEAP32[$25>>2]|0;
      $1326 = $1325 & $1320;
      $1327 = HEAP8[$26>>0]|0;
      $1328 = $1327&255;
      $1329 = $1326 >>> $1328;
      $1330 = (($1324) + ($1329)|0);
      $1331 = HEAP8[$27>>0]|0;
      $1332 = $1331&255;
      $1333 = (79212 + ($1332<<2)|0);
      $1334 = HEAP32[$1333>>2]|0;
      $1335 = HEAP32[$28>>2]|0;
      $1336 = $1335 & $1320;
      $1337 = HEAP8[$29>>0]|0;
      $1338 = $1337&255;
      $1339 = $1336 >>> $1338;
      $1340 = (($1334) + ($1339)|0);
      $1341 = HEAP8[$30>>0]|0;
      $1342 = $1341&255;
      $1343 = (79212 + ($1342<<2)|0);
      $1344 = HEAP32[$1343>>2]|0;
      $1345 = HEAP32[$31>>2]|0;
      $1346 = $1345 & $1320;
      $1347 = HEAP8[$32>>0]|0;
      $1348 = $1347&255;
      $1349 = $1346 >>> $1348;
      $1350 = (($1344) + ($1349)|0);
      $$11939$shrunk$ph$in = $1340;$$11955$shrunk$ph$in = $1330;$$sink1079 = $1350;
      label = 92;
      break;
     }
     case 2:  {
      $1351 = HEAP16[$$13973>>1]|0;
      $1352 = $1351&65535;
      $1353 = HEAP8[$24>>0]|0;
      $1354 = $1353&255;
      $1355 = (79212 + ($1354<<2)|0);
      $1356 = HEAP32[$1355>>2]|0;
      $1357 = HEAP32[$25>>2]|0;
      $1358 = $1357 & $1352;
      $1359 = HEAP8[$26>>0]|0;
      $1360 = $1359&255;
      $1361 = $1358 >>> $1360;
      $1362 = (($1356) + ($1361)|0);
      $1363 = HEAP8[$27>>0]|0;
      $1364 = $1363&255;
      $1365 = (79212 + ($1364<<2)|0);
      $1366 = HEAP32[$1365>>2]|0;
      $1367 = HEAP32[$28>>2]|0;
      $1368 = $1367 & $1352;
      $1369 = HEAP8[$29>>0]|0;
      $1370 = $1369&255;
      $1371 = $1368 >>> $1370;
      $1372 = (($1366) + ($1371)|0);
      $1373 = HEAP8[$30>>0]|0;
      $1374 = $1373&255;
      $1375 = (79212 + ($1374<<2)|0);
      $1376 = HEAP32[$1375>>2]|0;
      $1377 = HEAP32[$31>>2]|0;
      $1378 = $1377 & $1352;
      $1379 = HEAP8[$32>>0]|0;
      $1380 = $1379&255;
      $1381 = $1378 >>> $1380;
      $1382 = (($1376) + ($1381)|0);
      $$11939$shrunk$ph$in = $1372;$$11955$shrunk$ph$in = $1362;$$sink1079 = $1382;
      label = 92;
      break;
     }
     case 3:  {
      $1383 = HEAP8[$26>>0]|0;
      $div1010 = ($1383&255) >>> 3;
      $1384 = $div1010&255;
      $1385 = (($$13973) + ($1384)|0);
      $1386 = HEAP8[$29>>0]|0;
      $div1011 = ($1386&255) >>> 3;
      $1387 = $div1011&255;
      $1388 = (($$13973) + ($1387)|0);
      $1389 = HEAP8[$32>>0]|0;
      $div1012 = ($1389&255) >>> 3;
      $1390 = $div1012&255;
      $1391 = (($$13973) + ($1390)|0);
      $$11939$shrunk$ph$in = $1388;$$11955$shrunk$ph$in = $1385;$$sink1079 = $1391;
      label = 92;
      break;
     }
     case 4:  {
      $1392 = HEAP32[$$13973>>2]|0;
      $1393 = HEAP8[$24>>0]|0;
      $1394 = $1393&255;
      $1395 = (79212 + ($1394<<2)|0);
      $1396 = HEAP32[$1395>>2]|0;
      $1397 = HEAP32[$25>>2]|0;
      $1398 = $1397 & $1392;
      $1399 = HEAP8[$26>>0]|0;
      $1400 = $1399&255;
      $1401 = $1398 >>> $1400;
      $1402 = (($1396) + ($1401)|0);
      $1403 = HEAP8[$27>>0]|0;
      $1404 = $1403&255;
      $1405 = (79212 + ($1404<<2)|0);
      $1406 = HEAP32[$1405>>2]|0;
      $1407 = HEAP32[$28>>2]|0;
      $1408 = $1407 & $1392;
      $1409 = HEAP8[$29>>0]|0;
      $1410 = $1409&255;
      $1411 = $1408 >>> $1410;
      $1412 = (($1406) + ($1411)|0);
      $1413 = HEAP8[$30>>0]|0;
      $1414 = $1413&255;
      $1415 = (79212 + ($1414<<2)|0);
      $1416 = HEAP32[$1415>>2]|0;
      $1417 = HEAP32[$31>>2]|0;
      $1418 = $1417 & $1392;
      $1419 = HEAP8[$32>>0]|0;
      $1420 = $1419&255;
      $1421 = $1418 >>> $1420;
      $1422 = (($1416) + ($1421)|0);
      $$11939$shrunk$ph$in = $1412;$$11955$shrunk$ph$in = $1402;$$sink1079 = $1422;
      label = 92;
      break;
     }
     default: {
      $$11$shrunk = 0;$$11939$shrunk = 0;$$11955$shrunk = 0;
     }
     }
     if ((label|0) == 92) {
      label = 0;
      $$11939$shrunk$ph = HEAP8[$$11939$shrunk$ph$in>>0]|0;
      $$11955$shrunk$ph = HEAP8[$$11955$shrunk$ph$in>>0]|0;
      $1423 = HEAP8[$$sink1079>>0]|0;
      $$11$shrunk = $1423;$$11939$shrunk = $$11939$shrunk$ph;$$11955$shrunk = $$11955$shrunk$ph;
     }
     $$11 = $$11$shrunk&255;
     $$11939 = $$11939$shrunk&255;
     $1424 = $$11955$shrunk & -32;
     $1425 = $1424&255;
     $1426 = $$11939 >>> 5;
     $1427 = $1426 << 2;
     $1428 = $1427 | $1425;
     $1429 = $$11 >>> 6;
     $1430 = $1428 | $1429;
     $1431 = (($13) + ($1430)|0);
     $1432 = HEAP8[$1431>>0]|0;
     HEAP8[$$13989>>0] = $1432;
     $1433 = ((($$13989)) + 1|0);
     $1434 = (($$13973) + ($18)|0);
     $$14974 = $1434;$$14990 = $1433;$$4 = $$3;
     label = 94;
     continue;
    }
    else if ((label|0) == 94) {
     label = 0;
     switch ($17<<24>>24) {
     case 1:  {
      $1435 = HEAP8[$$14974>>0]|0;
      $1436 = $1435&255;
      $1437 = HEAP8[$24>>0]|0;
      $1438 = $1437&255;
      $1439 = (79212 + ($1438<<2)|0);
      $1440 = HEAP32[$1439>>2]|0;
      $1441 = HEAP32[$25>>2]|0;
      $1442 = $1441 & $1436;
      $1443 = HEAP8[$26>>0]|0;
      $1444 = $1443&255;
      $1445 = $1442 >>> $1444;
      $1446 = (($1440) + ($1445)|0);
      $1447 = HEAP8[$27>>0]|0;
      $1448 = $1447&255;
      $1449 = (79212 + ($1448<<2)|0);
      $1450 = HEAP32[$1449>>2]|0;
      $1451 = HEAP32[$28>>2]|0;
      $1452 = $1451 & $1436;
      $1453 = HEAP8[$29>>0]|0;
      $1454 = $1453&255;
      $1455 = $1452 >>> $1454;
      $1456 = (($1450) + ($1455)|0);
      $1457 = HEAP8[$30>>0]|0;
      $1458 = $1457&255;
      $1459 = (79212 + ($1458<<2)|0);
      $1460 = HEAP32[$1459>>2]|0;
      $1461 = HEAP32[$31>>2]|0;
      $1462 = $1461 & $1436;
      $1463 = HEAP8[$32>>0]|0;
      $1464 = $1463&255;
      $1465 = $1462 >>> $1464;
      $1466 = (($1460) + ($1465)|0);
      $$12940$shrunk$ph$in = $1456;$$12956$shrunk$ph$in = $1446;$$sink1081 = $1466;
      label = 99;
      break;
     }
     case 2:  {
      $1467 = HEAP16[$$14974>>1]|0;
      $1468 = $1467&65535;
      $1469 = HEAP8[$24>>0]|0;
      $1470 = $1469&255;
      $1471 = (79212 + ($1470<<2)|0);
      $1472 = HEAP32[$1471>>2]|0;
      $1473 = HEAP32[$25>>2]|0;
      $1474 = $1473 & $1468;
      $1475 = HEAP8[$26>>0]|0;
      $1476 = $1475&255;
      $1477 = $1474 >>> $1476;
      $1478 = (($1472) + ($1477)|0);
      $1479 = HEAP8[$27>>0]|0;
      $1480 = $1479&255;
      $1481 = (79212 + ($1480<<2)|0);
      $1482 = HEAP32[$1481>>2]|0;
      $1483 = HEAP32[$28>>2]|0;
      $1484 = $1483 & $1468;
      $1485 = HEAP8[$29>>0]|0;
      $1486 = $1485&255;
      $1487 = $1484 >>> $1486;
      $1488 = (($1482) + ($1487)|0);
      $1489 = HEAP8[$30>>0]|0;
      $1490 = $1489&255;
      $1491 = (79212 + ($1490<<2)|0);
      $1492 = HEAP32[$1491>>2]|0;
      $1493 = HEAP32[$31>>2]|0;
      $1494 = $1493 & $1468;
      $1495 = HEAP8[$32>>0]|0;
      $1496 = $1495&255;
      $1497 = $1494 >>> $1496;
      $1498 = (($1492) + ($1497)|0);
      $$12940$shrunk$ph$in = $1488;$$12956$shrunk$ph$in = $1478;$$sink1081 = $1498;
      label = 99;
      break;
     }
     case 3:  {
      $1499 = HEAP8[$26>>0]|0;
      $div1007 = ($1499&255) >>> 3;
      $1500 = $div1007&255;
      $1501 = (($$14974) + ($1500)|0);
      $1502 = HEAP8[$29>>0]|0;
      $div1008 = ($1502&255) >>> 3;
      $1503 = $div1008&255;
      $1504 = (($$14974) + ($1503)|0);
      $1505 = HEAP8[$32>>0]|0;
      $div1009 = ($1505&255) >>> 3;
      $1506 = $div1009&255;
      $1507 = (($$14974) + ($1506)|0);
      $$12940$shrunk$ph$in = $1504;$$12956$shrunk$ph$in = $1501;$$sink1081 = $1507;
      label = 99;
      break;
     }
     case 4:  {
      $1508 = HEAP32[$$14974>>2]|0;
      $1509 = HEAP8[$24>>0]|0;
      $1510 = $1509&255;
      $1511 = (79212 + ($1510<<2)|0);
      $1512 = HEAP32[$1511>>2]|0;
      $1513 = HEAP32[$25>>2]|0;
      $1514 = $1513 & $1508;
      $1515 = HEAP8[$26>>0]|0;
      $1516 = $1515&255;
      $1517 = $1514 >>> $1516;
      $1518 = (($1512) + ($1517)|0);
      $1519 = HEAP8[$27>>0]|0;
      $1520 = $1519&255;
      $1521 = (79212 + ($1520<<2)|0);
      $1522 = HEAP32[$1521>>2]|0;
      $1523 = HEAP32[$28>>2]|0;
      $1524 = $1523 & $1508;
      $1525 = HEAP8[$29>>0]|0;
      $1526 = $1525&255;
      $1527 = $1524 >>> $1526;
      $1528 = (($1522) + ($1527)|0);
      $1529 = HEAP8[$30>>0]|0;
      $1530 = $1529&255;
      $1531 = (79212 + ($1530<<2)|0);
      $1532 = HEAP32[$1531>>2]|0;
      $1533 = HEAP32[$31>>2]|0;
      $1534 = $1533 & $1508;
      $1535 = HEAP8[$32>>0]|0;
      $1536 = $1535&255;
      $1537 = $1534 >>> $1536;
      $1538 = (($1532) + ($1537)|0);
      $$12940$shrunk$ph$in = $1528;$$12956$shrunk$ph$in = $1518;$$sink1081 = $1538;
      label = 99;
      break;
     }
     default: {
      $$12$shrunk = 0;$$12940$shrunk = 0;$$12956$shrunk = 0;
     }
     }
     if ((label|0) == 99) {
      label = 0;
      $$12940$shrunk$ph = HEAP8[$$12940$shrunk$ph$in>>0]|0;
      $$12956$shrunk$ph = HEAP8[$$12956$shrunk$ph$in>>0]|0;
      $1539 = HEAP8[$$sink1081>>0]|0;
      $$12$shrunk = $1539;$$12940$shrunk = $$12940$shrunk$ph;$$12956$shrunk = $$12956$shrunk$ph;
     }
     $$12 = $$12$shrunk&255;
     $$12940 = $$12940$shrunk&255;
     $1540 = $$12956$shrunk & -32;
     $1541 = $1540&255;
     $1542 = $$12940 >>> 5;
     $1543 = $1542 << 2;
     $1544 = $1543 | $1541;
     $1545 = $$12 >>> 6;
     $1546 = $1544 | $1545;
     $1547 = (($13) + ($1546)|0);
     $1548 = HEAP8[$1547>>0]|0;
     HEAP8[$$14990>>0] = $1548;
     $1549 = ((($$14990)) + 1|0);
     $1550 = (($$14974) + ($18)|0);
     $$15975 = $1550;$$15991 = $1549;$$5 = $$4;
     label = 101;
     continue;
    }
    else if ((label|0) == 101) {
     label = 0;
     switch ($17<<24>>24) {
     case 1:  {
      $1551 = HEAP8[$$15975>>0]|0;
      $1552 = $1551&255;
      $1553 = HEAP8[$24>>0]|0;
      $1554 = $1553&255;
      $1555 = (79212 + ($1554<<2)|0);
      $1556 = HEAP32[$1555>>2]|0;
      $1557 = HEAP32[$25>>2]|0;
      $1558 = $1557 & $1552;
      $1559 = HEAP8[$26>>0]|0;
      $1560 = $1559&255;
      $1561 = $1558 >>> $1560;
      $1562 = (($1556) + ($1561)|0);
      $1563 = HEAP8[$27>>0]|0;
      $1564 = $1563&255;
      $1565 = (79212 + ($1564<<2)|0);
      $1566 = HEAP32[$1565>>2]|0;
      $1567 = HEAP32[$28>>2]|0;
      $1568 = $1567 & $1552;
      $1569 = HEAP8[$29>>0]|0;
      $1570 = $1569&255;
      $1571 = $1568 >>> $1570;
      $1572 = (($1566) + ($1571)|0);
      $1573 = HEAP8[$30>>0]|0;
      $1574 = $1573&255;
      $1575 = (79212 + ($1574<<2)|0);
      $1576 = HEAP32[$1575>>2]|0;
      $1577 = HEAP32[$31>>2]|0;
      $1578 = $1577 & $1552;
      $1579 = HEAP8[$32>>0]|0;
      $1580 = $1579&255;
      $1581 = $1578 >>> $1580;
      $1582 = (($1576) + ($1581)|0);
      $$13941$shrunk$ph$in = $1572;$$13957$shrunk$ph$in = $1562;$$sink1083 = $1582;
      label = 106;
      break;
     }
     case 2:  {
      $1583 = HEAP16[$$15975>>1]|0;
      $1584 = $1583&65535;
      $1585 = HEAP8[$24>>0]|0;
      $1586 = $1585&255;
      $1587 = (79212 + ($1586<<2)|0);
      $1588 = HEAP32[$1587>>2]|0;
      $1589 = HEAP32[$25>>2]|0;
      $1590 = $1589 & $1584;
      $1591 = HEAP8[$26>>0]|0;
      $1592 = $1591&255;
      $1593 = $1590 >>> $1592;
      $1594 = (($1588) + ($1593)|0);
      $1595 = HEAP8[$27>>0]|0;
      $1596 = $1595&255;
      $1597 = (79212 + ($1596<<2)|0);
      $1598 = HEAP32[$1597>>2]|0;
      $1599 = HEAP32[$28>>2]|0;
      $1600 = $1599 & $1584;
      $1601 = HEAP8[$29>>0]|0;
      $1602 = $1601&255;
      $1603 = $1600 >>> $1602;
      $1604 = (($1598) + ($1603)|0);
      $1605 = HEAP8[$30>>0]|0;
      $1606 = $1605&255;
      $1607 = (79212 + ($1606<<2)|0);
      $1608 = HEAP32[$1607>>2]|0;
      $1609 = HEAP32[$31>>2]|0;
      $1610 = $1609 & $1584;
      $1611 = HEAP8[$32>>0]|0;
      $1612 = $1611&255;
      $1613 = $1610 >>> $1612;
      $1614 = (($1608) + ($1613)|0);
      $$13941$shrunk$ph$in = $1604;$$13957$shrunk$ph$in = $1594;$$sink1083 = $1614;
      label = 106;
      break;
     }
     case 3:  {
      $1615 = HEAP8[$26>>0]|0;
      $div1004 = ($1615&255) >>> 3;
      $1616 = $div1004&255;
      $1617 = (($$15975) + ($1616)|0);
      $1618 = HEAP8[$29>>0]|0;
      $div1005 = ($1618&255) >>> 3;
      $1619 = $div1005&255;
      $1620 = (($$15975) + ($1619)|0);
      $1621 = HEAP8[$32>>0]|0;
      $div1006 = ($1621&255) >>> 3;
      $1622 = $div1006&255;
      $1623 = (($$15975) + ($1622)|0);
      $$13941$shrunk$ph$in = $1620;$$13957$shrunk$ph$in = $1617;$$sink1083 = $1623;
      label = 106;
      break;
     }
     case 4:  {
      $1624 = HEAP32[$$15975>>2]|0;
      $1625 = HEAP8[$24>>0]|0;
      $1626 = $1625&255;
      $1627 = (79212 + ($1626<<2)|0);
      $1628 = HEAP32[$1627>>2]|0;
      $1629 = HEAP32[$25>>2]|0;
      $1630 = $1629 & $1624;
      $1631 = HEAP8[$26>>0]|0;
      $1632 = $1631&255;
      $1633 = $1630 >>> $1632;
      $1634 = (($1628) + ($1633)|0);
      $1635 = HEAP8[$27>>0]|0;
      $1636 = $1635&255;
      $1637 = (79212 + ($1636<<2)|0);
      $1638 = HEAP32[$1637>>2]|0;
      $1639 = HEAP32[$28>>2]|0;
      $1640 = $1639 & $1624;
      $1641 = HEAP8[$29>>0]|0;
      $1642 = $1641&255;
      $1643 = $1640 >>> $1642;
      $1644 = (($1638) + ($1643)|0);
      $1645 = HEAP8[$30>>0]|0;
      $1646 = $1645&255;
      $1647 = (79212 + ($1646<<2)|0);
      $1648 = HEAP32[$1647>>2]|0;
      $1649 = HEAP32[$31>>2]|0;
      $1650 = $1649 & $1624;
      $1651 = HEAP8[$32>>0]|0;
      $1652 = $1651&255;
      $1653 = $1650 >>> $1652;
      $1654 = (($1648) + ($1653)|0);
      $$13941$shrunk$ph$in = $1644;$$13957$shrunk$ph$in = $1634;$$sink1083 = $1654;
      label = 106;
      break;
     }
     default: {
      $$13$shrunk = 0;$$13941$shrunk = 0;$$13957$shrunk = 0;
     }
     }
     if ((label|0) == 106) {
      label = 0;
      $$13941$shrunk$ph = HEAP8[$$13941$shrunk$ph$in>>0]|0;
      $$13957$shrunk$ph = HEAP8[$$13957$shrunk$ph$in>>0]|0;
      $1655 = HEAP8[$$sink1083>>0]|0;
      $$13$shrunk = $1655;$$13941$shrunk = $$13941$shrunk$ph;$$13957$shrunk = $$13957$shrunk$ph;
     }
     $$13 = $$13$shrunk&255;
     $$13941 = $$13941$shrunk&255;
     $1656 = $$13957$shrunk & -32;
     $1657 = $1656&255;
     $1658 = $$13941 >>> 5;
     $1659 = $1658 << 2;
     $1660 = $1659 | $1657;
     $1661 = $$13 >>> 6;
     $1662 = $1660 | $1661;
     $1663 = (($13) + ($1662)|0);
     $1664 = HEAP8[$1663>>0]|0;
     HEAP8[$$15991>>0] = $1664;
     $1665 = ((($$15991)) + 1|0);
     $1666 = (($$15975) + ($18)|0);
     $$16 = $1666;$$16992 = $1665;$$6 = $$5;
     label = 108;
     continue;
    }
    else if ((label|0) == 108) {
     label = 0;
     switch ($17<<24>>24) {
     case 1:  {
      $1667 = HEAP8[$$16>>0]|0;
      $1668 = $1667&255;
      $1669 = HEAP8[$24>>0]|0;
      $1670 = $1669&255;
      $1671 = (79212 + ($1670<<2)|0);
      $1672 = HEAP32[$1671>>2]|0;
      $1673 = HEAP32[$25>>2]|0;
      $1674 = $1673 & $1668;
      $1675 = HEAP8[$26>>0]|0;
      $1676 = $1675&255;
      $1677 = $1674 >>> $1676;
      $1678 = (($1672) + ($1677)|0);
      $1679 = HEAP8[$27>>0]|0;
      $1680 = $1679&255;
      $1681 = (79212 + ($1680<<2)|0);
      $1682 = HEAP32[$1681>>2]|0;
      $1683 = HEAP32[$28>>2]|0;
      $1684 = $1683 & $1668;
      $1685 = HEAP8[$29>>0]|0;
      $1686 = $1685&255;
      $1687 = $1684 >>> $1686;
      $1688 = (($1682) + ($1687)|0);
      $1689 = HEAP8[$30>>0]|0;
      $1690 = $1689&255;
      $1691 = (79212 + ($1690<<2)|0);
      $1692 = HEAP32[$1691>>2]|0;
      $1693 = HEAP32[$31>>2]|0;
      $1694 = $1693 & $1668;
      $1695 = HEAP8[$32>>0]|0;
      $1696 = $1695&255;
      $1697 = $1694 >>> $1696;
      $1698 = (($1692) + ($1697)|0);
      $$14942$shrunk$ph$in = $1688;$$14958$shrunk$ph$in = $1678;$$sink1085 = $1698;
      label = 113;
      break;
     }
     case 2:  {
      $1699 = HEAP16[$$16>>1]|0;
      $1700 = $1699&65535;
      $1701 = HEAP8[$24>>0]|0;
      $1702 = $1701&255;
      $1703 = (79212 + ($1702<<2)|0);
      $1704 = HEAP32[$1703>>2]|0;
      $1705 = HEAP32[$25>>2]|0;
      $1706 = $1705 & $1700;
      $1707 = HEAP8[$26>>0]|0;
      $1708 = $1707&255;
      $1709 = $1706 >>> $1708;
      $1710 = (($1704) + ($1709)|0);
      $1711 = HEAP8[$27>>0]|0;
      $1712 = $1711&255;
      $1713 = (79212 + ($1712<<2)|0);
      $1714 = HEAP32[$1713>>2]|0;
      $1715 = HEAP32[$28>>2]|0;
      $1716 = $1715 & $1700;
      $1717 = HEAP8[$29>>0]|0;
      $1718 = $1717&255;
      $1719 = $1716 >>> $1718;
      $1720 = (($1714) + ($1719)|0);
      $1721 = HEAP8[$30>>0]|0;
      $1722 = $1721&255;
      $1723 = (79212 + ($1722<<2)|0);
      $1724 = HEAP32[$1723>>2]|0;
      $1725 = HEAP32[$31>>2]|0;
      $1726 = $1725 & $1700;
      $1727 = HEAP8[$32>>0]|0;
      $1728 = $1727&255;
      $1729 = $1726 >>> $1728;
      $1730 = (($1724) + ($1729)|0);
      $$14942$shrunk$ph$in = $1720;$$14958$shrunk$ph$in = $1710;$$sink1085 = $1730;
      label = 113;
      break;
     }
     case 3:  {
      $1731 = HEAP8[$26>>0]|0;
      $div = ($1731&255) >>> 3;
      $1732 = $div&255;
      $1733 = (($$16) + ($1732)|0);
      $1734 = HEAP8[$29>>0]|0;
      $div1002 = ($1734&255) >>> 3;
      $1735 = $div1002&255;
      $1736 = (($$16) + ($1735)|0);
      $1737 = HEAP8[$32>>0]|0;
      $div1003 = ($1737&255) >>> 3;
      $1738 = $div1003&255;
      $1739 = (($$16) + ($1738)|0);
      $$14942$shrunk$ph$in = $1736;$$14958$shrunk$ph$in = $1733;$$sink1085 = $1739;
      label = 113;
      break;
     }
     case 4:  {
      $1740 = HEAP32[$$16>>2]|0;
      $1741 = HEAP8[$24>>0]|0;
      $1742 = $1741&255;
      $1743 = (79212 + ($1742<<2)|0);
      $1744 = HEAP32[$1743>>2]|0;
      $1745 = HEAP32[$25>>2]|0;
      $1746 = $1745 & $1740;
      $1747 = HEAP8[$26>>0]|0;
      $1748 = $1747&255;
      $1749 = $1746 >>> $1748;
      $1750 = (($1744) + ($1749)|0);
      $1751 = HEAP8[$27>>0]|0;
      $1752 = $1751&255;
      $1753 = (79212 + ($1752<<2)|0);
      $1754 = HEAP32[$1753>>2]|0;
      $1755 = HEAP32[$28>>2]|0;
      $1756 = $1755 & $1740;
      $1757 = HEAP8[$29>>0]|0;
      $1758 = $1757&255;
      $1759 = $1756 >>> $1758;
      $1760 = (($1754) + ($1759)|0);
      $1761 = HEAP8[$30>>0]|0;
      $1762 = $1761&255;
      $1763 = (79212 + ($1762<<2)|0);
      $1764 = HEAP32[$1763>>2]|0;
      $1765 = HEAP32[$31>>2]|0;
      $1766 = $1765 & $1740;
      $1767 = HEAP8[$32>>0]|0;
      $1768 = $1767&255;
      $1769 = $1766 >>> $1768;
      $1770 = (($1764) + ($1769)|0);
      $$14942$shrunk$ph$in = $1760;$$14958$shrunk$ph$in = $1750;$$sink1085 = $1770;
      label = 113;
      break;
     }
     default: {
      $$14$shrunk = 0;$$14942$shrunk = 0;$$14958$shrunk = 0;
     }
     }
     if ((label|0) == 113) {
      label = 0;
      $$14942$shrunk$ph = HEAP8[$$14942$shrunk$ph$in>>0]|0;
      $$14958$shrunk$ph = HEAP8[$$14958$shrunk$ph$in>>0]|0;
      $1771 = HEAP8[$$sink1085>>0]|0;
      $$14$shrunk = $1771;$$14942$shrunk = $$14942$shrunk$ph;$$14958$shrunk = $$14958$shrunk$ph;
     }
     $$14 = $$14$shrunk&255;
     $$14942 = $$14942$shrunk&255;
     $1772 = $$14958$shrunk & -32;
     $1773 = $1772&255;
     $1774 = $$14942 >>> 5;
     $1775 = $1774 << 2;
     $1776 = $1775 | $1773;
     $1777 = $$14 >>> 6;
     $1778 = $1776 | $1777;
     $1779 = (($13) + ($1778)|0);
     $1780 = HEAP8[$1779>>0]|0;
     HEAP8[$$16992>>0] = $1780;
     $1781 = ((($$16992)) + 1|0);
     $1782 = (($$16) + ($18)|0);
     $$17 = $1782;$$17993 = $1781;$$7 = $$6;
     label = 115;
     continue;
    }
    else if ((label|0) == 115) {
     label = 0;
     switch ($17<<24>>24) {
     case 1:  {
      $1783 = HEAP8[$$17>>0]|0;
      $1784 = $1783&255;
      $1785 = HEAP8[$24>>0]|0;
      $1786 = $1785&255;
      $1787 = (79212 + ($1786<<2)|0);
      $1788 = HEAP32[$1787>>2]|0;
      $1789 = HEAP32[$25>>2]|0;
      $1790 = $1789 & $1784;
      $1791 = HEAP8[$26>>0]|0;
      $1792 = $1791&255;
      $1793 = $1790 >>> $1792;
      $1794 = (($1788) + ($1793)|0);
      $1795 = HEAP8[$27>>0]|0;
      $1796 = $1795&255;
      $1797 = (79212 + ($1796<<2)|0);
      $1798 = HEAP32[$1797>>2]|0;
      $1799 = HEAP32[$28>>2]|0;
      $1800 = $1799 & $1784;
      $1801 = HEAP8[$29>>0]|0;
      $1802 = $1801&255;
      $1803 = $1800 >>> $1802;
      $1804 = (($1798) + ($1803)|0);
      $1805 = HEAP8[$30>>0]|0;
      $1806 = $1805&255;
      $1807 = (79212 + ($1806<<2)|0);
      $1808 = HEAP32[$1807>>2]|0;
      $1809 = HEAP32[$31>>2]|0;
      $1810 = $1809 & $1784;
      $1811 = HEAP8[$32>>0]|0;
      $1812 = $1811&255;
      $1813 = $1810 >>> $1812;
      $1814 = (($1808) + ($1813)|0);
      $$15943$shrunk$ph$in = $1804;$$15959$shrunk$ph$in = $1794;$$sink1087 = $1814;
      label = 120;
      break;
     }
     case 2:  {
      $1815 = HEAP16[$$17>>1]|0;
      $1816 = $1815&65535;
      $1817 = HEAP8[$24>>0]|0;
      $1818 = $1817&255;
      $1819 = (79212 + ($1818<<2)|0);
      $1820 = HEAP32[$1819>>2]|0;
      $1821 = HEAP32[$25>>2]|0;
      $1822 = $1821 & $1816;
      $1823 = HEAP8[$26>>0]|0;
      $1824 = $1823&255;
      $1825 = $1822 >>> $1824;
      $1826 = (($1820) + ($1825)|0);
      $1827 = HEAP8[$27>>0]|0;
      $1828 = $1827&255;
      $1829 = (79212 + ($1828<<2)|0);
      $1830 = HEAP32[$1829>>2]|0;
      $1831 = HEAP32[$28>>2]|0;
      $1832 = $1831 & $1816;
      $1833 = HEAP8[$29>>0]|0;
      $1834 = $1833&255;
      $1835 = $1832 >>> $1834;
      $1836 = (($1830) + ($1835)|0);
      $1837 = HEAP8[$30>>0]|0;
      $1838 = $1837&255;
      $1839 = (79212 + ($1838<<2)|0);
      $1840 = HEAP32[$1839>>2]|0;
      $1841 = HEAP32[$31>>2]|0;
      $1842 = $1841 & $1816;
      $1843 = HEAP8[$32>>0]|0;
      $1844 = $1843&255;
      $1845 = $1842 >>> $1844;
      $1846 = (($1840) + ($1845)|0);
      $$15943$shrunk$ph$in = $1836;$$15959$shrunk$ph$in = $1826;$$sink1087 = $1846;
      label = 120;
      break;
     }
     case 3:  {
      $1847 = HEAP8[$26>>0]|0;
      $div1022 = ($1847&255) >>> 3;
      $1848 = $div1022&255;
      $1849 = (($$17) + ($1848)|0);
      $1850 = HEAP8[$29>>0]|0;
      $div1023 = ($1850&255) >>> 3;
      $1851 = $div1023&255;
      $1852 = (($$17) + ($1851)|0);
      $1853 = HEAP8[$32>>0]|0;
      $div1024 = ($1853&255) >>> 3;
      $1854 = $div1024&255;
      $1855 = (($$17) + ($1854)|0);
      $$15943$shrunk$ph$in = $1852;$$15959$shrunk$ph$in = $1849;$$sink1087 = $1855;
      label = 120;
      break;
     }
     case 4:  {
      $1856 = HEAP32[$$17>>2]|0;
      $1857 = HEAP8[$24>>0]|0;
      $1858 = $1857&255;
      $1859 = (79212 + ($1858<<2)|0);
      $1860 = HEAP32[$1859>>2]|0;
      $1861 = HEAP32[$25>>2]|0;
      $1862 = $1861 & $1856;
      $1863 = HEAP8[$26>>0]|0;
      $1864 = $1863&255;
      $1865 = $1862 >>> $1864;
      $1866 = (($1860) + ($1865)|0);
      $1867 = HEAP8[$27>>0]|0;
      $1868 = $1867&255;
      $1869 = (79212 + ($1868<<2)|0);
      $1870 = HEAP32[$1869>>2]|0;
      $1871 = HEAP32[$28>>2]|0;
      $1872 = $1871 & $1856;
      $1873 = HEAP8[$29>>0]|0;
      $1874 = $1873&255;
      $1875 = $1872 >>> $1874;
      $1876 = (($1870) + ($1875)|0);
      $1877 = HEAP8[$30>>0]|0;
      $1878 = $1877&255;
      $1879 = (79212 + ($1878<<2)|0);
      $1880 = HEAP32[$1879>>2]|0;
      $1881 = HEAP32[$31>>2]|0;
      $1882 = $1881 & $1856;
      $1883 = HEAP8[$32>>0]|0;
      $1884 = $1883&255;
      $1885 = $1882 >>> $1884;
      $1886 = (($1880) + ($1885)|0);
      $$15943$shrunk$ph$in = $1876;$$15959$shrunk$ph$in = $1866;$$sink1087 = $1886;
      label = 120;
      break;
     }
     default: {
      $$15$shrunk = 0;$$15943$shrunk = 0;$$15959$shrunk = 0;
     }
     }
     if ((label|0) == 120) {
      label = 0;
      $$15943$shrunk$ph = HEAP8[$$15943$shrunk$ph$in>>0]|0;
      $$15959$shrunk$ph = HEAP8[$$15959$shrunk$ph$in>>0]|0;
      $1887 = HEAP8[$$sink1087>>0]|0;
      $$15$shrunk = $1887;$$15943$shrunk = $$15943$shrunk$ph;$$15959$shrunk = $$15959$shrunk$ph;
     }
     $$15 = $$15$shrunk&255;
     $$15943 = $$15943$shrunk&255;
     $1888 = $$15959$shrunk & -32;
     $1889 = $1888&255;
     $1890 = $$15943 >>> 5;
     $1891 = $1890 << 2;
     $1892 = $1891 | $1889;
     $1893 = $$15 >>> 6;
     $1894 = $1892 | $1893;
     $1895 = (($13) + ($1894)|0);
     $1896 = HEAP8[$1895>>0]|0;
     HEAP8[$$17993>>0] = $1896;
     $1897 = ((($$17993)) + 1|0);
     $1898 = (($$17) + ($18)|0);
     $1899 = (($$7) + -1)|0;
     $1900 = ($$7|0)>(1);
     if ($1900) {
      $$0 = $1899;$$10970 = $1898;$$10986 = $1897;
      label = 66;
      continue;
     } else {
      break;
     }
    }
   }
   $1901 = (($1898) + ($7)|0);
   $1902 = (($1897) + ($11)|0);
   $1903 = (($1904) + -1)|0;
   $1905 = ($1904|0)==(0);
   if ($1905) {
    label = 124;
    break;
   } else {
    $$99691093 = $1901;$$99851092 = $1902;$1904 = $1903;
   }
  }
  if ((label|0) == 122) {
   // unreachable;
  }
  else if ((label|0) == 124) {
   return;
  }
 }
}
function _Blit_RGB888_index8($0) {
 $0 = $0|0;
 var $$0 = 0, $$0130 = 0, $$0140162 = 0, $$0148161 = 0, $$1 = 0, $$10 = 0, $$11 = 0, $$1131 = 0, $$1141164 = 0, $$1149 = 0, $$12 = 0, $$13 = 0, $$14 = 0, $$15 = 0, $$16 = 0, $$17 = 0, $$2 = 0, $$2132 = 0, $$2142 = 0, $$2150 = 0;
 var $$3 = 0, $$3133 = 0, $$3143 = 0, $$3151 = 0, $$4 = 0, $$4134 = 0, $$4144 = 0, $$4152 = 0, $$5 = 0, $$5135 = 0, $$5145 = 0, $$5153 = 0, $$6 = 0, $$6136 = 0, $$6146 = 0, $$6154 = 0, $$7 = 0, $$7137 = 0, $$7147 = 0, $$7155 = 0;
 var $$8 = 0, $$8156 = 0, $$9 = 0, $$9157163 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0;
 var $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0;
 var $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0;
 var $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $trunc = 0, $trunc$clear = 0, $trunc158 = 0, $trunc158$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$0>>2]|0;
 $6 = ((($0)) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7|0) / 4)&-1;
 $9 = ((($0)) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ((($0)) + 36|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ((($0)) + 48|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(0|0);
 $16 = (($4) + -1)|0;
 $17 = ($4|0)==(0);
 if ($15) {
  if ($17) {
   return;
  }
  $20 = (($2) + 7)|0;
  $21 = (($20|0) / 8)&-1;
  $trunc158 = $2&255;
  $$0140162 = $5;$$0148161 = $10;$115 = $16;
  L6: while(1) {
   $trunc158$clear = $trunc158 & 7;
   switch ($trunc158$clear<<24>>24) {
   case 0:  {
    $$0130 = $21;$$1149 = $$0148161;
    label = 7;
    break;
   }
   case 7:  {
    $$1131 = $21;$$2150 = $$0148161;
    label = 8;
    break;
   }
   case 6:  {
    $$2132 = $21;$$3151 = $$0148161;
    label = 9;
    break;
   }
   case 5:  {
    $$3133 = $21;$$4152 = $$0148161;
    label = 10;
    break;
   }
   case 4:  {
    $$4134 = $21;$$5153 = $$0148161;
    label = 11;
    break;
   }
   case 3:  {
    $$5135 = $21;$$6154 = $$0148161;
    label = 12;
    break;
   }
   case 2:  {
    $$6136 = $21;$$7155 = $$0148161;
    label = 13;
    break;
   }
   case 1:  {
    $$7137 = $21;$$8156 = $$0148161;
    label = 14;
    break;
   }
   default: {
    label = 15;
    break L6;
   }
   }
   while(1) {
    if ((label|0) == 7) {
     label = 0;
     $22 = HEAP32[$$0140162>>2]|0;
     $23 = $22 >>> 16;
     $24 = $23 & 224;
     $25 = $22 >>> 11;
     $26 = $25 & 28;
     $27 = $24 | $26;
     $28 = $22 >>> 6;
     $29 = $28 & 3;
     $30 = $27 | $29;
     $31 = $30&255;
     $32 = ((($$1149)) + 1|0);
     HEAP8[$$1149>>0] = $31;
     $$1131 = $$0130;$$2150 = $32;
     label = 8;
     continue;
    }
    else if ((label|0) == 8) {
     label = 0;
     $33 = HEAP32[$$0140162>>2]|0;
     $34 = $33 >>> 16;
     $35 = $34 & 224;
     $36 = $33 >>> 11;
     $37 = $36 & 28;
     $38 = $35 | $37;
     $39 = $33 >>> 6;
     $40 = $39 & 3;
     $41 = $38 | $40;
     $42 = $41&255;
     $43 = ((($$2150)) + 1|0);
     HEAP8[$$2150>>0] = $42;
     $$2132 = $$1131;$$3151 = $43;
     label = 9;
     continue;
    }
    else if ((label|0) == 9) {
     label = 0;
     $44 = HEAP32[$$0140162>>2]|0;
     $45 = $44 >>> 16;
     $46 = $45 & 224;
     $47 = $44 >>> 11;
     $48 = $47 & 28;
     $49 = $46 | $48;
     $50 = $44 >>> 6;
     $51 = $50 & 3;
     $52 = $49 | $51;
     $53 = $52&255;
     $54 = ((($$3151)) + 1|0);
     HEAP8[$$3151>>0] = $53;
     $$3133 = $$2132;$$4152 = $54;
     label = 10;
     continue;
    }
    else if ((label|0) == 10) {
     label = 0;
     $55 = HEAP32[$$0140162>>2]|0;
     $56 = $55 >>> 16;
     $57 = $56 & 224;
     $58 = $55 >>> 11;
     $59 = $58 & 28;
     $60 = $57 | $59;
     $61 = $55 >>> 6;
     $62 = $61 & 3;
     $63 = $60 | $62;
     $64 = $63&255;
     $65 = ((($$4152)) + 1|0);
     HEAP8[$$4152>>0] = $64;
     $$4134 = $$3133;$$5153 = $65;
     label = 11;
     continue;
    }
    else if ((label|0) == 11) {
     label = 0;
     $66 = HEAP32[$$0140162>>2]|0;
     $67 = $66 >>> 16;
     $68 = $67 & 224;
     $69 = $66 >>> 11;
     $70 = $69 & 28;
     $71 = $68 | $70;
     $72 = $66 >>> 6;
     $73 = $72 & 3;
     $74 = $71 | $73;
     $75 = $74&255;
     $76 = ((($$5153)) + 1|0);
     HEAP8[$$5153>>0] = $75;
     $$5135 = $$4134;$$6154 = $76;
     label = 12;
     continue;
    }
    else if ((label|0) == 12) {
     label = 0;
     $77 = HEAP32[$$0140162>>2]|0;
     $78 = $77 >>> 16;
     $79 = $78 & 224;
     $80 = $77 >>> 11;
     $81 = $80 & 28;
     $82 = $79 | $81;
     $83 = $77 >>> 6;
     $84 = $83 & 3;
     $85 = $82 | $84;
     $86 = $85&255;
     $87 = ((($$6154)) + 1|0);
     HEAP8[$$6154>>0] = $86;
     $$6136 = $$5135;$$7155 = $87;
     label = 13;
     continue;
    }
    else if ((label|0) == 13) {
     label = 0;
     $88 = HEAP32[$$0140162>>2]|0;
     $89 = $88 >>> 16;
     $90 = $89 & 224;
     $91 = $88 >>> 11;
     $92 = $91 & 28;
     $93 = $90 | $92;
     $94 = $88 >>> 6;
     $95 = $94 & 3;
     $96 = $93 | $95;
     $97 = $96&255;
     $98 = ((($$7155)) + 1|0);
     HEAP8[$$7155>>0] = $97;
     $$7137 = $$6136;$$8156 = $98;
     label = 14;
     continue;
    }
    else if ((label|0) == 14) {
     label = 0;
     $99 = HEAP32[$$0140162>>2]|0;
     $100 = $99 >>> 16;
     $101 = $100 & 224;
     $102 = $99 >>> 11;
     $103 = $102 & 28;
     $104 = $101 | $103;
     $105 = $99 >>> 6;
     $106 = $105 & 3;
     $107 = $104 | $106;
     $108 = $107&255;
     $109 = ((($$8156)) + 1|0);
     HEAP8[$$8156>>0] = $108;
     $110 = (($$7137) + -1)|0;
     $111 = ($$7137|0)>(1);
     if ($111) {
      $$0130 = $110;$$1149 = $109;
      label = 7;
      continue;
     } else {
      break;
     }
    }
   }
   $112 = (($$0140162) + ($8<<2)|0);
   $113 = (($109) + ($12)|0);
   $114 = (($115) + -1)|0;
   $116 = ($115|0)==(0);
   if ($116) {
    label = 28;
    break;
   } else {
    $$0140162 = $112;$$0148161 = $113;$115 = $114;
   }
  }
  if ((label|0) == 15) {
   // unreachable;
  }
  else if ((label|0) == 28) {
   return;
  }
 } else {
  if ($17) {
   return;
  }
  $18 = (($2) + 7)|0;
  $19 = (($18|0) / 8)&-1;
  $trunc = $2&255;
  $$1141164 = $5;$$9157163 = $10;$226 = $16;
  L26: while(1) {
   $trunc$clear = $trunc & 7;
   switch ($trunc$clear<<24>>24) {
   case 0:  {
    $$0 = $19;$$10 = $$9157163;$$2142 = $$1141164;
    label = 18;
    break;
   }
   case 7:  {
    $$1 = $19;$$11 = $$9157163;$$3143 = $$1141164;
    label = 19;
    break;
   }
   case 6:  {
    $$12 = $$9157163;$$2 = $19;$$4144 = $$1141164;
    label = 20;
    break;
   }
   case 5:  {
    $$13 = $$9157163;$$3 = $19;$$5145 = $$1141164;
    label = 21;
    break;
   }
   case 4:  {
    $$14 = $$9157163;$$4 = $19;$$6146 = $$1141164;
    label = 22;
    break;
   }
   case 3:  {
    $$15 = $$9157163;$$5 = $19;$$7147 = $$1141164;
    label = 23;
    break;
   }
   case 2:  {
    $$16 = $$9157163;$$6 = $19;$$8 = $$1141164;
    label = 24;
    break;
   }
   case 1:  {
    $$17 = $$9157163;$$7 = $19;$$9 = $$1141164;
    label = 25;
    break;
   }
   default: {
    label = 26;
    break L26;
   }
   }
   while(1) {
    if ((label|0) == 18) {
     label = 0;
     $117 = HEAP32[$$2142>>2]|0;
     $118 = $117 >>> 16;
     $119 = $118 & 224;
     $120 = $117 >>> 11;
     $121 = $120 & 28;
     $122 = $119 | $121;
     $123 = $117 >>> 6;
     $124 = $123 & 3;
     $125 = $122 | $124;
     $126 = (($14) + ($125)|0);
     $127 = HEAP8[$126>>0]|0;
     $128 = ((($$10)) + 1|0);
     HEAP8[$$10>>0] = $127;
     $129 = ((($$2142)) + 4|0);
     $$1 = $$0;$$11 = $128;$$3143 = $129;
     label = 19;
     continue;
    }
    else if ((label|0) == 19) {
     label = 0;
     $130 = HEAP32[$$3143>>2]|0;
     $131 = $130 >>> 16;
     $132 = $131 & 224;
     $133 = $130 >>> 11;
     $134 = $133 & 28;
     $135 = $132 | $134;
     $136 = $130 >>> 6;
     $137 = $136 & 3;
     $138 = $135 | $137;
     $139 = (($14) + ($138)|0);
     $140 = HEAP8[$139>>0]|0;
     $141 = ((($$11)) + 1|0);
     HEAP8[$$11>>0] = $140;
     $142 = ((($$3143)) + 4|0);
     $$12 = $141;$$2 = $$1;$$4144 = $142;
     label = 20;
     continue;
    }
    else if ((label|0) == 20) {
     label = 0;
     $143 = HEAP32[$$4144>>2]|0;
     $144 = $143 >>> 16;
     $145 = $144 & 224;
     $146 = $143 >>> 11;
     $147 = $146 & 28;
     $148 = $145 | $147;
     $149 = $143 >>> 6;
     $150 = $149 & 3;
     $151 = $148 | $150;
     $152 = (($14) + ($151)|0);
     $153 = HEAP8[$152>>0]|0;
     $154 = ((($$12)) + 1|0);
     HEAP8[$$12>>0] = $153;
     $155 = ((($$4144)) + 4|0);
     $$13 = $154;$$3 = $$2;$$5145 = $155;
     label = 21;
     continue;
    }
    else if ((label|0) == 21) {
     label = 0;
     $156 = HEAP32[$$5145>>2]|0;
     $157 = $156 >>> 16;
     $158 = $157 & 224;
     $159 = $156 >>> 11;
     $160 = $159 & 28;
     $161 = $158 | $160;
     $162 = $156 >>> 6;
     $163 = $162 & 3;
     $164 = $161 | $163;
     $165 = (($14) + ($164)|0);
     $166 = HEAP8[$165>>0]|0;
     $167 = ((($$13)) + 1|0);
     HEAP8[$$13>>0] = $166;
     $168 = ((($$5145)) + 4|0);
     $$14 = $167;$$4 = $$3;$$6146 = $168;
     label = 22;
     continue;
    }
    else if ((label|0) == 22) {
     label = 0;
     $169 = HEAP32[$$6146>>2]|0;
     $170 = $169 >>> 16;
     $171 = $170 & 224;
     $172 = $169 >>> 11;
     $173 = $172 & 28;
     $174 = $171 | $173;
     $175 = $169 >>> 6;
     $176 = $175 & 3;
     $177 = $174 | $176;
     $178 = (($14) + ($177)|0);
     $179 = HEAP8[$178>>0]|0;
     $180 = ((($$14)) + 1|0);
     HEAP8[$$14>>0] = $179;
     $181 = ((($$6146)) + 4|0);
     $$15 = $180;$$5 = $$4;$$7147 = $181;
     label = 23;
     continue;
    }
    else if ((label|0) == 23) {
     label = 0;
     $182 = HEAP32[$$7147>>2]|0;
     $183 = $182 >>> 16;
     $184 = $183 & 224;
     $185 = $182 >>> 11;
     $186 = $185 & 28;
     $187 = $184 | $186;
     $188 = $182 >>> 6;
     $189 = $188 & 3;
     $190 = $187 | $189;
     $191 = (($14) + ($190)|0);
     $192 = HEAP8[$191>>0]|0;
     $193 = ((($$15)) + 1|0);
     HEAP8[$$15>>0] = $192;
     $194 = ((($$7147)) + 4|0);
     $$16 = $193;$$6 = $$5;$$8 = $194;
     label = 24;
     continue;
    }
    else if ((label|0) == 24) {
     label = 0;
     $195 = HEAP32[$$8>>2]|0;
     $196 = $195 >>> 16;
     $197 = $196 & 224;
     $198 = $195 >>> 11;
     $199 = $198 & 28;
     $200 = $197 | $199;
     $201 = $195 >>> 6;
     $202 = $201 & 3;
     $203 = $200 | $202;
     $204 = (($14) + ($203)|0);
     $205 = HEAP8[$204>>0]|0;
     $206 = ((($$16)) + 1|0);
     HEAP8[$$16>>0] = $205;
     $207 = ((($$8)) + 4|0);
     $$17 = $206;$$7 = $$6;$$9 = $207;
     label = 25;
     continue;
    }
    else if ((label|0) == 25) {
     label = 0;
     $208 = HEAP32[$$9>>2]|0;
     $209 = $208 >>> 16;
     $210 = $209 & 224;
     $211 = $208 >>> 11;
     $212 = $211 & 28;
     $213 = $210 | $212;
     $214 = $208 >>> 6;
     $215 = $214 & 3;
     $216 = $213 | $215;
     $217 = (($14) + ($216)|0);
     $218 = HEAP8[$217>>0]|0;
     $219 = ((($$17)) + 1|0);
     HEAP8[$$17>>0] = $218;
     $220 = ((($$9)) + 4|0);
     $221 = (($$7) + -1)|0;
     $222 = ($$7|0)>(1);
     if ($222) {
      $$0 = $221;$$10 = $219;$$2142 = $220;
      label = 18;
      continue;
     } else {
      break;
     }
    }
   }
   $223 = (($220) + ($8<<2)|0);
   $224 = (($219) + ($12)|0);
   $225 = (($226) + -1)|0;
   $227 = ($226|0)==(0);
   if ($227) {
    label = 28;
    break;
   } else {
    $$1141164 = $223;$$9157163 = $224;$226 = $225;
   }
  }
  if ((label|0) == 26) {
   // unreachable;
  }
  else if ((label|0) == 28) {
   return;
  }
 }
}
function _Blit_RGB101010_index8($0) {
 $0 = $0|0;
 var $$0 = 0, $$0130 = 0, $$0140162 = 0, $$0148161 = 0, $$1 = 0, $$10 = 0, $$11 = 0, $$1131 = 0, $$1141164 = 0, $$1149 = 0, $$12 = 0, $$13 = 0, $$14 = 0, $$15 = 0, $$16 = 0, $$17 = 0, $$2 = 0, $$2132 = 0, $$2142 = 0, $$2150 = 0;
 var $$3 = 0, $$3133 = 0, $$3143 = 0, $$3151 = 0, $$4 = 0, $$4134 = 0, $$4144 = 0, $$4152 = 0, $$5 = 0, $$5135 = 0, $$5145 = 0, $$5153 = 0, $$6 = 0, $$6136 = 0, $$6146 = 0, $$6154 = 0, $$7 = 0, $$7137 = 0, $$7147 = 0, $$7155 = 0;
 var $$8 = 0, $$8156 = 0, $$9 = 0, $$9157163 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0;
 var $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0;
 var $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0;
 var $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $trunc = 0, $trunc$clear = 0, $trunc158 = 0, $trunc158$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$0>>2]|0;
 $6 = ((($0)) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7|0) / 4)&-1;
 $9 = ((($0)) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ((($0)) + 36|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ((($0)) + 48|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(0|0);
 $16 = (($4) + -1)|0;
 $17 = ($4|0)==(0);
 if ($15) {
  if ($17) {
   return;
  }
  $20 = (($2) + 7)|0;
  $21 = (($20|0) / 8)&-1;
  $trunc158 = $2&255;
  $$0140162 = $5;$$0148161 = $10;$115 = $16;
  L6: while(1) {
   $trunc158$clear = $trunc158 & 7;
   switch ($trunc158$clear<<24>>24) {
   case 0:  {
    $$0130 = $21;$$1149 = $$0148161;
    label = 7;
    break;
   }
   case 7:  {
    $$1131 = $21;$$2150 = $$0148161;
    label = 8;
    break;
   }
   case 6:  {
    $$2132 = $21;$$3151 = $$0148161;
    label = 9;
    break;
   }
   case 5:  {
    $$3133 = $21;$$4152 = $$0148161;
    label = 10;
    break;
   }
   case 4:  {
    $$4134 = $21;$$5153 = $$0148161;
    label = 11;
    break;
   }
   case 3:  {
    $$5135 = $21;$$6154 = $$0148161;
    label = 12;
    break;
   }
   case 2:  {
    $$6136 = $21;$$7155 = $$0148161;
    label = 13;
    break;
   }
   case 1:  {
    $$7137 = $21;$$8156 = $$0148161;
    label = 14;
    break;
   }
   default: {
    label = 15;
    break L6;
   }
   }
   while(1) {
    if ((label|0) == 7) {
     label = 0;
     $22 = HEAP32[$$0140162>>2]|0;
     $23 = $22 >>> 22;
     $24 = $23 & 224;
     $25 = $22 >>> 15;
     $26 = $25 & 28;
     $27 = $24 | $26;
     $28 = $22 >>> 8;
     $29 = $28 & 3;
     $30 = $27 | $29;
     $31 = $30&255;
     $32 = ((($$1149)) + 1|0);
     HEAP8[$$1149>>0] = $31;
     $$1131 = $$0130;$$2150 = $32;
     label = 8;
     continue;
    }
    else if ((label|0) == 8) {
     label = 0;
     $33 = HEAP32[$$0140162>>2]|0;
     $34 = $33 >>> 22;
     $35 = $34 & 224;
     $36 = $33 >>> 15;
     $37 = $36 & 28;
     $38 = $35 | $37;
     $39 = $33 >>> 8;
     $40 = $39 & 3;
     $41 = $38 | $40;
     $42 = $41&255;
     $43 = ((($$2150)) + 1|0);
     HEAP8[$$2150>>0] = $42;
     $$2132 = $$1131;$$3151 = $43;
     label = 9;
     continue;
    }
    else if ((label|0) == 9) {
     label = 0;
     $44 = HEAP32[$$0140162>>2]|0;
     $45 = $44 >>> 22;
     $46 = $45 & 224;
     $47 = $44 >>> 15;
     $48 = $47 & 28;
     $49 = $46 | $48;
     $50 = $44 >>> 8;
     $51 = $50 & 3;
     $52 = $49 | $51;
     $53 = $52&255;
     $54 = ((($$3151)) + 1|0);
     HEAP8[$$3151>>0] = $53;
     $$3133 = $$2132;$$4152 = $54;
     label = 10;
     continue;
    }
    else if ((label|0) == 10) {
     label = 0;
     $55 = HEAP32[$$0140162>>2]|0;
     $56 = $55 >>> 22;
     $57 = $56 & 224;
     $58 = $55 >>> 15;
     $59 = $58 & 28;
     $60 = $57 | $59;
     $61 = $55 >>> 8;
     $62 = $61 & 3;
     $63 = $60 | $62;
     $64 = $63&255;
     $65 = ((($$4152)) + 1|0);
     HEAP8[$$4152>>0] = $64;
     $$4134 = $$3133;$$5153 = $65;
     label = 11;
     continue;
    }
    else if ((label|0) == 11) {
     label = 0;
     $66 = HEAP32[$$0140162>>2]|0;
     $67 = $66 >>> 22;
     $68 = $67 & 224;
     $69 = $66 >>> 15;
     $70 = $69 & 28;
     $71 = $68 | $70;
     $72 = $66 >>> 8;
     $73 = $72 & 3;
     $74 = $71 | $73;
     $75 = $74&255;
     $76 = ((($$5153)) + 1|0);
     HEAP8[$$5153>>0] = $75;
     $$5135 = $$4134;$$6154 = $76;
     label = 12;
     continue;
    }
    else if ((label|0) == 12) {
     label = 0;
     $77 = HEAP32[$$0140162>>2]|0;
     $78 = $77 >>> 22;
     $79 = $78 & 224;
     $80 = $77 >>> 15;
     $81 = $80 & 28;
     $82 = $79 | $81;
     $83 = $77 >>> 8;
     $84 = $83 & 3;
     $85 = $82 | $84;
     $86 = $85&255;
     $87 = ((($$6154)) + 1|0);
     HEAP8[$$6154>>0] = $86;
     $$6136 = $$5135;$$7155 = $87;
     label = 13;
     continue;
    }
    else if ((label|0) == 13) {
     label = 0;
     $88 = HEAP32[$$0140162>>2]|0;
     $89 = $88 >>> 22;
     $90 = $89 & 224;
     $91 = $88 >>> 15;
     $92 = $91 & 28;
     $93 = $90 | $92;
     $94 = $88 >>> 8;
     $95 = $94 & 3;
     $96 = $93 | $95;
     $97 = $96&255;
     $98 = ((($$7155)) + 1|0);
     HEAP8[$$7155>>0] = $97;
     $$7137 = $$6136;$$8156 = $98;
     label = 14;
     continue;
    }
    else if ((label|0) == 14) {
     label = 0;
     $99 = HEAP32[$$0140162>>2]|0;
     $100 = $99 >>> 22;
     $101 = $100 & 224;
     $102 = $99 >>> 15;
     $103 = $102 & 28;
     $104 = $101 | $103;
     $105 = $99 >>> 8;
     $106 = $105 & 3;
     $107 = $104 | $106;
     $108 = $107&255;
     $109 = ((($$8156)) + 1|0);
     HEAP8[$$8156>>0] = $108;
     $110 = (($$7137) + -1)|0;
     $111 = ($$7137|0)>(1);
     if ($111) {
      $$0130 = $110;$$1149 = $109;
      label = 7;
      continue;
     } else {
      break;
     }
    }
   }
   $112 = (($$0140162) + ($8<<2)|0);
   $113 = (($109) + ($12)|0);
   $114 = (($115) + -1)|0;
   $116 = ($115|0)==(0);
   if ($116) {
    label = 28;
    break;
   } else {
    $$0140162 = $112;$$0148161 = $113;$115 = $114;
   }
  }
  if ((label|0) == 15) {
   // unreachable;
  }
  else if ((label|0) == 28) {
   return;
  }
 } else {
  if ($17) {
   return;
  }
  $18 = (($2) + 7)|0;
  $19 = (($18|0) / 8)&-1;
  $trunc = $2&255;
  $$1141164 = $5;$$9157163 = $10;$226 = $16;
  L26: while(1) {
   $trunc$clear = $trunc & 7;
   switch ($trunc$clear<<24>>24) {
   case 0:  {
    $$0 = $19;$$10 = $$9157163;$$2142 = $$1141164;
    label = 18;
    break;
   }
   case 7:  {
    $$1 = $19;$$11 = $$9157163;$$3143 = $$1141164;
    label = 19;
    break;
   }
   case 6:  {
    $$12 = $$9157163;$$2 = $19;$$4144 = $$1141164;
    label = 20;
    break;
   }
   case 5:  {
    $$13 = $$9157163;$$3 = $19;$$5145 = $$1141164;
    label = 21;
    break;
   }
   case 4:  {
    $$14 = $$9157163;$$4 = $19;$$6146 = $$1141164;
    label = 22;
    break;
   }
   case 3:  {
    $$15 = $$9157163;$$5 = $19;$$7147 = $$1141164;
    label = 23;
    break;
   }
   case 2:  {
    $$16 = $$9157163;$$6 = $19;$$8 = $$1141164;
    label = 24;
    break;
   }
   case 1:  {
    $$17 = $$9157163;$$7 = $19;$$9 = $$1141164;
    label = 25;
    break;
   }
   default: {
    label = 26;
    break L26;
   }
   }
   while(1) {
    if ((label|0) == 18) {
     label = 0;
     $117 = HEAP32[$$2142>>2]|0;
     $118 = $117 >>> 22;
     $119 = $118 & 224;
     $120 = $117 >>> 15;
     $121 = $120 & 28;
     $122 = $119 | $121;
     $123 = $117 >>> 8;
     $124 = $123 & 3;
     $125 = $122 | $124;
     $126 = (($14) + ($125)|0);
     $127 = HEAP8[$126>>0]|0;
     $128 = ((($$10)) + 1|0);
     HEAP8[$$10>>0] = $127;
     $129 = ((($$2142)) + 4|0);
     $$1 = $$0;$$11 = $128;$$3143 = $129;
     label = 19;
     continue;
    }
    else if ((label|0) == 19) {
     label = 0;
     $130 = HEAP32[$$3143>>2]|0;
     $131 = $130 >>> 22;
     $132 = $131 & 224;
     $133 = $130 >>> 15;
     $134 = $133 & 28;
     $135 = $132 | $134;
     $136 = $130 >>> 8;
     $137 = $136 & 3;
     $138 = $135 | $137;
     $139 = (($14) + ($138)|0);
     $140 = HEAP8[$139>>0]|0;
     $141 = ((($$11)) + 1|0);
     HEAP8[$$11>>0] = $140;
     $142 = ((($$3143)) + 4|0);
     $$12 = $141;$$2 = $$1;$$4144 = $142;
     label = 20;
     continue;
    }
    else if ((label|0) == 20) {
     label = 0;
     $143 = HEAP32[$$4144>>2]|0;
     $144 = $143 >>> 22;
     $145 = $144 & 224;
     $146 = $143 >>> 15;
     $147 = $146 & 28;
     $148 = $145 | $147;
     $149 = $143 >>> 8;
     $150 = $149 & 3;
     $151 = $148 | $150;
     $152 = (($14) + ($151)|0);
     $153 = HEAP8[$152>>0]|0;
     $154 = ((($$12)) + 1|0);
     HEAP8[$$12>>0] = $153;
     $155 = ((($$4144)) + 4|0);
     $$13 = $154;$$3 = $$2;$$5145 = $155;
     label = 21;
     continue;
    }
    else if ((label|0) == 21) {
     label = 0;
     $156 = HEAP32[$$5145>>2]|0;
     $157 = $156 >>> 22;
     $158 = $157 & 224;
     $159 = $156 >>> 15;
     $160 = $159 & 28;
     $161 = $158 | $160;
     $162 = $156 >>> 8;
     $163 = $162 & 3;
     $164 = $161 | $163;
     $165 = (($14) + ($164)|0);
     $166 = HEAP8[$165>>0]|0;
     $167 = ((($$13)) + 1|0);
     HEAP8[$$13>>0] = $166;
     $168 = ((($$5145)) + 4|0);
     $$14 = $167;$$4 = $$3;$$6146 = $168;
     label = 22;
     continue;
    }
    else if ((label|0) == 22) {
     label = 0;
     $169 = HEAP32[$$6146>>2]|0;
     $170 = $169 >>> 22;
     $171 = $170 & 224;
     $172 = $169 >>> 15;
     $173 = $172 & 28;
     $174 = $171 | $173;
     $175 = $169 >>> 8;
     $176 = $175 & 3;
     $177 = $174 | $176;
     $178 = (($14) + ($177)|0);
     $179 = HEAP8[$178>>0]|0;
     $180 = ((($$14)) + 1|0);
     HEAP8[$$14>>0] = $179;
     $181 = ((($$6146)) + 4|0);
     $$15 = $180;$$5 = $$4;$$7147 = $181;
     label = 23;
     continue;
    }
    else if ((label|0) == 23) {
     label = 0;
     $182 = HEAP32[$$7147>>2]|0;
     $183 = $182 >>> 22;
     $184 = $183 & 224;
     $185 = $182 >>> 15;
     $186 = $185 & 28;
     $187 = $184 | $186;
     $188 = $182 >>> 8;
     $189 = $188 & 3;
     $190 = $187 | $189;
     $191 = (($14) + ($190)|0);
     $192 = HEAP8[$191>>0]|0;
     $193 = ((($$15)) + 1|0);
     HEAP8[$$15>>0] = $192;
     $194 = ((($$7147)) + 4|0);
     $$16 = $193;$$6 = $$5;$$8 = $194;
     label = 24;
     continue;
    }
    else if ((label|0) == 24) {
     label = 0;
     $195 = HEAP32[$$8>>2]|0;
     $196 = $195 >>> 22;
     $197 = $196 & 224;
     $198 = $195 >>> 15;
     $199 = $198 & 28;
     $200 = $197 | $199;
     $201 = $195 >>> 8;
     $202 = $201 & 3;
     $203 = $200 | $202;
     $204 = (($14) + ($203)|0);
     $205 = HEAP8[$204>>0]|0;
     $206 = ((($$16)) + 1|0);
     HEAP8[$$16>>0] = $205;
     $207 = ((($$8)) + 4|0);
     $$17 = $206;$$7 = $$6;$$9 = $207;
     label = 25;
     continue;
    }
    else if ((label|0) == 25) {
     label = 0;
     $208 = HEAP32[$$9>>2]|0;
     $209 = $208 >>> 22;
     $210 = $209 & 224;
     $211 = $208 >>> 15;
     $212 = $211 & 28;
     $213 = $210 | $212;
     $214 = $208 >>> 8;
     $215 = $214 & 3;
     $216 = $213 | $215;
     $217 = (($14) + ($216)|0);
     $218 = HEAP8[$217>>0]|0;
     $219 = ((($$17)) + 1|0);
     HEAP8[$$17>>0] = $218;
     $220 = ((($$9)) + 4|0);
     $221 = (($$7) + -1)|0;
     $222 = ($$7|0)>(1);
     if ($222) {
      $$0 = $221;$$10 = $219;$$2142 = $220;
      label = 18;
      continue;
     } else {
      break;
     }
    }
   }
   $223 = (($220) + ($8<<2)|0);
   $224 = (($219) + ($12)|0);
   $225 = (($226) + -1)|0;
   $227 = ($226|0)==(0);
   if ($227) {
    label = 28;
    break;
   } else {
    $$1141164 = $223;$$9157163 = $224;$226 = $225;
   }
  }
  if ((label|0) == 26) {
   // unreachable;
  }
  else if ((label|0) == 28) {
   return;
  }
 }
}
function _Blit2101010toN($0) {
 $0 = $0|0;
 var $$0554604 = 0, $$0555603 = 0, $$0564 = 0, $$1 = 0, $$1556 = 0, $$1565 = 0, $$2 = 0, $$2557 = 0, $$2566 = 0, $$3 = 0, $$3558 = 0, $$3567 = 0, $$4 = 0, $$4559 = 0, $$4568 = 0, $$5 = 0, $$5560 = 0, $$5569 = 0, $$6 = 0, $$6561 = 0;
 var $$6570 = 0, $$7 = 0, $$7562 = 0, $$7571 = 0, $$8 = 0, $$8563 = 0, $$in = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0;
 var $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0;
 var $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0;
 var $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0;
 var $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0;
 var $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0;
 var $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0;
 var $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0;
 var $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0;
 var $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0;
 var $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0;
 var $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0;
 var $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0;
 var $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0;
 var $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0;
 var $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0;
 var $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0;
 var $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0;
 var $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0;
 var $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0;
 var $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0;
 var $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0;
 var $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0;
 var $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0;
 var $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0;
 var $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0;
 var $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0;
 var $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0;
 var $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0;
 var $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0;
 var $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0;
 var $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0;
 var $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0;
 var $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0;
 var $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0;
 var $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0;
 var $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0;
 var $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0;
 var $831 = 0, $832 = 0, $833 = 0, $834 = 0, $835 = 0, $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0;
 var $85 = 0, $850 = 0, $851 = 0, $852 = 0, $853 = 0, $854 = 0, $855 = 0, $856 = 0, $857 = 0, $858 = 0, $859 = 0, $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0;
 var $868 = 0, $869 = 0, $87 = 0, $870 = 0, $871 = 0, $872 = 0, $873 = 0, $874 = 0, $875 = 0, $876 = 0, $877 = 0, $878 = 0, $879 = 0, $88 = 0, $880 = 0, $881 = 0, $882 = 0, $883 = 0, $884 = 0, $885 = 0;
 var $886 = 0, $887 = 0, $888 = 0, $889 = 0, $89 = 0, $890 = 0, $891 = 0, $892 = 0, $893 = 0, $894 = 0, $895 = 0, $896 = 0, $897 = 0, $898 = 0, $899 = 0, $9 = 0, $90 = 0, $900 = 0, $901 = 0, $902 = 0;
 var $903 = 0, $904 = 0, $905 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $div = 0, $div580 = 0, $div581 = 0, $div582 = 0, $div583 = 0, $div584 = 0, $div585 = 0, $div586 = 0;
 var $div587 = 0, $div588 = 0, $div589 = 0, $div590 = 0, $div591 = 0, $div592 = 0, $div593 = 0, $div594 = 0, $div595 = 0, $div596 = 0, $div597 = 0, $div598 = 0, $div599 = 0, $div600 = 0, $div601 = 0, $div602 = 0, $trunc = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($0)) + 36|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($0)) + 44|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ((($10)) + 9|0);
 $12 = HEAP8[$11>>0]|0;
 $13 = $12&255;
 $14 = ($4|0)==(0);
 if ($14) {
  return;
 }
 $15 = ((($0)) + 20|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = HEAP32[$0>>2]|0;
 $18 = (($2) + 7)|0;
 $19 = (($18|0) / 8)&-1;
 $trunc = $2&255;
 $20 = ((($10)) + 28|0);
 $21 = ((($10)) + 32|0);
 $22 = ((($10)) + 29|0);
 $23 = ((($10)) + 33|0);
 $24 = ((($10)) + 30|0);
 $25 = ((($10)) + 34|0);
 $26 = ((($10)) + 31|0);
 $27 = ((($10)) + 35|0);
 $$0554604 = $17;$$0555603 = $16;$$in = $4;
 L4: while(1) {
  $28 = (($$in) + -1)|0;
  $trunc$clear = $trunc & 7;
  switch ($trunc$clear<<24>>24) {
  case 0:  {
   $$0564 = $19;$$1 = $$0554604;$$1556 = $$0555603;
   label = 4;
   break;
  }
  case 7:  {
   $$1565 = $19;$$2 = $$0554604;$$2557 = $$0555603;
   label = 10;
   break;
  }
  case 6:  {
   $$2566 = $19;$$3 = $$0554604;$$3558 = $$0555603;
   label = 16;
   break;
  }
  case 5:  {
   $$3567 = $19;$$4 = $$0554604;$$4559 = $$0555603;
   label = 22;
   break;
  }
  case 4:  {
   $$4568 = $19;$$5 = $$0554604;$$5560 = $$0555603;
   label = 28;
   break;
  }
  case 3:  {
   $$5569 = $19;$$6 = $$0554604;$$6561 = $$0555603;
   label = 34;
   break;
  }
  case 2:  {
   $$6570 = $19;$$7 = $$0554604;$$7562 = $$0555603;
   label = 40;
   break;
  }
  case 1:  {
   $$7571 = $19;$$8 = $$0554604;$$8563 = $$0555603;
   label = 46;
   break;
  }
  default: {
   label = 52;
   break L4;
  }
  }
  while(1) {
   if ((label|0) == 4) {
    label = 0;
    $29 = HEAP32[$$1>>2]|0;
    $30 = $29 >>> 22;
    $31 = $30 & 255;
    $32 = $29 >>> 12;
    $33 = $32 & 255;
    $34 = $29 >>> 2;
    $35 = $34 & 255;
    $36 = HEAP32[(79236)>>2]|0;
    $37 = $29 >>> 30;
    $38 = (($36) + ($37)|0);
    $39 = HEAP8[$38>>0]|0;
    $40 = $39&255;
    switch ($12<<24>>24) {
    case 1:  {
     $41 = HEAP8[$20>>0]|0;
     $42 = $41&255;
     $43 = $31 >>> $42;
     $44 = HEAP8[$21>>0]|0;
     $45 = $44&255;
     $46 = $43 << $45;
     $47 = HEAP8[$22>>0]|0;
     $48 = $47&255;
     $49 = $33 >>> $48;
     $50 = HEAP8[$23>>0]|0;
     $51 = $50&255;
     $52 = $49 << $51;
     $53 = $52 | $46;
     $54 = HEAP8[$24>>0]|0;
     $55 = $54&255;
     $56 = $35 >>> $55;
     $57 = HEAP8[$25>>0]|0;
     $58 = $57&255;
     $59 = $56 << $58;
     $60 = $53 | $59;
     $61 = HEAP8[$26>>0]|0;
     $62 = $61&255;
     $63 = $40 >>> $62;
     $64 = HEAP8[$27>>0]|0;
     $65 = $64&255;
     $66 = $63 << $65;
     $67 = $60 | $66;
     $68 = $67&255;
     HEAP8[$$1556>>0] = $68;
     break;
    }
    case 2:  {
     $69 = HEAP8[$20>>0]|0;
     $70 = $69&255;
     $71 = $31 >>> $70;
     $72 = HEAP8[$21>>0]|0;
     $73 = $72&255;
     $74 = $71 << $73;
     $75 = HEAP8[$22>>0]|0;
     $76 = $75&255;
     $77 = $33 >>> $76;
     $78 = HEAP8[$23>>0]|0;
     $79 = $78&255;
     $80 = $77 << $79;
     $81 = $80 | $74;
     $82 = HEAP8[$24>>0]|0;
     $83 = $82&255;
     $84 = $35 >>> $83;
     $85 = HEAP8[$25>>0]|0;
     $86 = $85&255;
     $87 = $84 << $86;
     $88 = $81 | $87;
     $89 = HEAP8[$26>>0]|0;
     $90 = $89&255;
     $91 = $40 >>> $90;
     $92 = HEAP8[$27>>0]|0;
     $93 = $92&255;
     $94 = $91 << $93;
     $95 = $88 | $94;
     $96 = $95&65535;
     HEAP16[$$1556>>1] = $96;
     break;
    }
    case 3:  {
     $97 = $30&255;
     $98 = HEAP8[$21>>0]|0;
     $div597 = ($98&255) >>> 3;
     $99 = $div597&255;
     $100 = (($$1556) + ($99)|0);
     HEAP8[$100>>0] = $97;
     $101 = $32&255;
     $102 = HEAP8[$23>>0]|0;
     $div598 = ($102&255) >>> 3;
     $103 = $div598&255;
     $104 = (($$1556) + ($103)|0);
     HEAP8[$104>>0] = $101;
     $105 = $34&255;
     $106 = HEAP8[$25>>0]|0;
     $div599 = ($106&255) >>> 3;
     $107 = $div599&255;
     $108 = (($$1556) + ($107)|0);
     HEAP8[$108>>0] = $105;
     break;
    }
    case 4:  {
     $109 = HEAP8[$20>>0]|0;
     $110 = $109&255;
     $111 = $31 >>> $110;
     $112 = HEAP8[$21>>0]|0;
     $113 = $112&255;
     $114 = $111 << $113;
     $115 = HEAP8[$22>>0]|0;
     $116 = $115&255;
     $117 = $33 >>> $116;
     $118 = HEAP8[$23>>0]|0;
     $119 = $118&255;
     $120 = $117 << $119;
     $121 = $120 | $114;
     $122 = HEAP8[$24>>0]|0;
     $123 = $122&255;
     $124 = $35 >>> $123;
     $125 = HEAP8[$25>>0]|0;
     $126 = $125&255;
     $127 = $124 << $126;
     $128 = $121 | $127;
     $129 = HEAP8[$26>>0]|0;
     $130 = $129&255;
     $131 = $40 >>> $130;
     $132 = HEAP8[$27>>0]|0;
     $133 = $132&255;
     $134 = $131 << $133;
     $135 = $128 | $134;
     HEAP32[$$1556>>2] = $135;
     break;
    }
    default: {
    }
    }
    $136 = (($$1556) + ($13)|0);
    $137 = ((($$1)) + 4|0);
    $$1565 = $$0564;$$2 = $137;$$2557 = $136;
    label = 10;
    continue;
   }
   else if ((label|0) == 10) {
    label = 0;
    $138 = HEAP32[$$2>>2]|0;
    $139 = $138 >>> 22;
    $140 = $139 & 255;
    $141 = $138 >>> 12;
    $142 = $141 & 255;
    $143 = $138 >>> 2;
    $144 = $143 & 255;
    $145 = HEAP32[(79236)>>2]|0;
    $146 = $138 >>> 30;
    $147 = (($145) + ($146)|0);
    $148 = HEAP8[$147>>0]|0;
    $149 = $148&255;
    switch ($12<<24>>24) {
    case 1:  {
     $150 = HEAP8[$20>>0]|0;
     $151 = $150&255;
     $152 = $140 >>> $151;
     $153 = HEAP8[$21>>0]|0;
     $154 = $153&255;
     $155 = $152 << $154;
     $156 = HEAP8[$22>>0]|0;
     $157 = $156&255;
     $158 = $142 >>> $157;
     $159 = HEAP8[$23>>0]|0;
     $160 = $159&255;
     $161 = $158 << $160;
     $162 = $161 | $155;
     $163 = HEAP8[$24>>0]|0;
     $164 = $163&255;
     $165 = $144 >>> $164;
     $166 = HEAP8[$25>>0]|0;
     $167 = $166&255;
     $168 = $165 << $167;
     $169 = $162 | $168;
     $170 = HEAP8[$26>>0]|0;
     $171 = $170&255;
     $172 = $149 >>> $171;
     $173 = HEAP8[$27>>0]|0;
     $174 = $173&255;
     $175 = $172 << $174;
     $176 = $169 | $175;
     $177 = $176&255;
     HEAP8[$$2557>>0] = $177;
     break;
    }
    case 2:  {
     $178 = HEAP8[$20>>0]|0;
     $179 = $178&255;
     $180 = $140 >>> $179;
     $181 = HEAP8[$21>>0]|0;
     $182 = $181&255;
     $183 = $180 << $182;
     $184 = HEAP8[$22>>0]|0;
     $185 = $184&255;
     $186 = $142 >>> $185;
     $187 = HEAP8[$23>>0]|0;
     $188 = $187&255;
     $189 = $186 << $188;
     $190 = $189 | $183;
     $191 = HEAP8[$24>>0]|0;
     $192 = $191&255;
     $193 = $144 >>> $192;
     $194 = HEAP8[$25>>0]|0;
     $195 = $194&255;
     $196 = $193 << $195;
     $197 = $190 | $196;
     $198 = HEAP8[$26>>0]|0;
     $199 = $198&255;
     $200 = $149 >>> $199;
     $201 = HEAP8[$27>>0]|0;
     $202 = $201&255;
     $203 = $200 << $202;
     $204 = $197 | $203;
     $205 = $204&65535;
     HEAP16[$$2557>>1] = $205;
     break;
    }
    case 3:  {
     $206 = $139&255;
     $207 = HEAP8[$21>>0]|0;
     $div594 = ($207&255) >>> 3;
     $208 = $div594&255;
     $209 = (($$2557) + ($208)|0);
     HEAP8[$209>>0] = $206;
     $210 = $141&255;
     $211 = HEAP8[$23>>0]|0;
     $div595 = ($211&255) >>> 3;
     $212 = $div595&255;
     $213 = (($$2557) + ($212)|0);
     HEAP8[$213>>0] = $210;
     $214 = $143&255;
     $215 = HEAP8[$25>>0]|0;
     $div596 = ($215&255) >>> 3;
     $216 = $div596&255;
     $217 = (($$2557) + ($216)|0);
     HEAP8[$217>>0] = $214;
     break;
    }
    case 4:  {
     $218 = HEAP8[$20>>0]|0;
     $219 = $218&255;
     $220 = $140 >>> $219;
     $221 = HEAP8[$21>>0]|0;
     $222 = $221&255;
     $223 = $220 << $222;
     $224 = HEAP8[$22>>0]|0;
     $225 = $224&255;
     $226 = $142 >>> $225;
     $227 = HEAP8[$23>>0]|0;
     $228 = $227&255;
     $229 = $226 << $228;
     $230 = $229 | $223;
     $231 = HEAP8[$24>>0]|0;
     $232 = $231&255;
     $233 = $144 >>> $232;
     $234 = HEAP8[$25>>0]|0;
     $235 = $234&255;
     $236 = $233 << $235;
     $237 = $230 | $236;
     $238 = HEAP8[$26>>0]|0;
     $239 = $238&255;
     $240 = $149 >>> $239;
     $241 = HEAP8[$27>>0]|0;
     $242 = $241&255;
     $243 = $240 << $242;
     $244 = $237 | $243;
     HEAP32[$$2557>>2] = $244;
     break;
    }
    default: {
    }
    }
    $245 = (($$2557) + ($13)|0);
    $246 = ((($$2)) + 4|0);
    $$2566 = $$1565;$$3 = $246;$$3558 = $245;
    label = 16;
    continue;
   }
   else if ((label|0) == 16) {
    label = 0;
    $247 = HEAP32[$$3>>2]|0;
    $248 = $247 >>> 22;
    $249 = $248 & 255;
    $250 = $247 >>> 12;
    $251 = $250 & 255;
    $252 = $247 >>> 2;
    $253 = $252 & 255;
    $254 = HEAP32[(79236)>>2]|0;
    $255 = $247 >>> 30;
    $256 = (($254) + ($255)|0);
    $257 = HEAP8[$256>>0]|0;
    $258 = $257&255;
    switch ($12<<24>>24) {
    case 1:  {
     $259 = HEAP8[$20>>0]|0;
     $260 = $259&255;
     $261 = $249 >>> $260;
     $262 = HEAP8[$21>>0]|0;
     $263 = $262&255;
     $264 = $261 << $263;
     $265 = HEAP8[$22>>0]|0;
     $266 = $265&255;
     $267 = $251 >>> $266;
     $268 = HEAP8[$23>>0]|0;
     $269 = $268&255;
     $270 = $267 << $269;
     $271 = $270 | $264;
     $272 = HEAP8[$24>>0]|0;
     $273 = $272&255;
     $274 = $253 >>> $273;
     $275 = HEAP8[$25>>0]|0;
     $276 = $275&255;
     $277 = $274 << $276;
     $278 = $271 | $277;
     $279 = HEAP8[$26>>0]|0;
     $280 = $279&255;
     $281 = $258 >>> $280;
     $282 = HEAP8[$27>>0]|0;
     $283 = $282&255;
     $284 = $281 << $283;
     $285 = $278 | $284;
     $286 = $285&255;
     HEAP8[$$3558>>0] = $286;
     break;
    }
    case 2:  {
     $287 = HEAP8[$20>>0]|0;
     $288 = $287&255;
     $289 = $249 >>> $288;
     $290 = HEAP8[$21>>0]|0;
     $291 = $290&255;
     $292 = $289 << $291;
     $293 = HEAP8[$22>>0]|0;
     $294 = $293&255;
     $295 = $251 >>> $294;
     $296 = HEAP8[$23>>0]|0;
     $297 = $296&255;
     $298 = $295 << $297;
     $299 = $298 | $292;
     $300 = HEAP8[$24>>0]|0;
     $301 = $300&255;
     $302 = $253 >>> $301;
     $303 = HEAP8[$25>>0]|0;
     $304 = $303&255;
     $305 = $302 << $304;
     $306 = $299 | $305;
     $307 = HEAP8[$26>>0]|0;
     $308 = $307&255;
     $309 = $258 >>> $308;
     $310 = HEAP8[$27>>0]|0;
     $311 = $310&255;
     $312 = $309 << $311;
     $313 = $306 | $312;
     $314 = $313&65535;
     HEAP16[$$3558>>1] = $314;
     break;
    }
    case 3:  {
     $315 = $248&255;
     $316 = HEAP8[$21>>0]|0;
     $div591 = ($316&255) >>> 3;
     $317 = $div591&255;
     $318 = (($$3558) + ($317)|0);
     HEAP8[$318>>0] = $315;
     $319 = $250&255;
     $320 = HEAP8[$23>>0]|0;
     $div592 = ($320&255) >>> 3;
     $321 = $div592&255;
     $322 = (($$3558) + ($321)|0);
     HEAP8[$322>>0] = $319;
     $323 = $252&255;
     $324 = HEAP8[$25>>0]|0;
     $div593 = ($324&255) >>> 3;
     $325 = $div593&255;
     $326 = (($$3558) + ($325)|0);
     HEAP8[$326>>0] = $323;
     break;
    }
    case 4:  {
     $327 = HEAP8[$20>>0]|0;
     $328 = $327&255;
     $329 = $249 >>> $328;
     $330 = HEAP8[$21>>0]|0;
     $331 = $330&255;
     $332 = $329 << $331;
     $333 = HEAP8[$22>>0]|0;
     $334 = $333&255;
     $335 = $251 >>> $334;
     $336 = HEAP8[$23>>0]|0;
     $337 = $336&255;
     $338 = $335 << $337;
     $339 = $338 | $332;
     $340 = HEAP8[$24>>0]|0;
     $341 = $340&255;
     $342 = $253 >>> $341;
     $343 = HEAP8[$25>>0]|0;
     $344 = $343&255;
     $345 = $342 << $344;
     $346 = $339 | $345;
     $347 = HEAP8[$26>>0]|0;
     $348 = $347&255;
     $349 = $258 >>> $348;
     $350 = HEAP8[$27>>0]|0;
     $351 = $350&255;
     $352 = $349 << $351;
     $353 = $346 | $352;
     HEAP32[$$3558>>2] = $353;
     break;
    }
    default: {
    }
    }
    $354 = (($$3558) + ($13)|0);
    $355 = ((($$3)) + 4|0);
    $$3567 = $$2566;$$4 = $355;$$4559 = $354;
    label = 22;
    continue;
   }
   else if ((label|0) == 22) {
    label = 0;
    $356 = HEAP32[$$4>>2]|0;
    $357 = $356 >>> 22;
    $358 = $357 & 255;
    $359 = $356 >>> 12;
    $360 = $359 & 255;
    $361 = $356 >>> 2;
    $362 = $361 & 255;
    $363 = HEAP32[(79236)>>2]|0;
    $364 = $356 >>> 30;
    $365 = (($363) + ($364)|0);
    $366 = HEAP8[$365>>0]|0;
    $367 = $366&255;
    switch ($12<<24>>24) {
    case 1:  {
     $368 = HEAP8[$20>>0]|0;
     $369 = $368&255;
     $370 = $358 >>> $369;
     $371 = HEAP8[$21>>0]|0;
     $372 = $371&255;
     $373 = $370 << $372;
     $374 = HEAP8[$22>>0]|0;
     $375 = $374&255;
     $376 = $360 >>> $375;
     $377 = HEAP8[$23>>0]|0;
     $378 = $377&255;
     $379 = $376 << $378;
     $380 = $379 | $373;
     $381 = HEAP8[$24>>0]|0;
     $382 = $381&255;
     $383 = $362 >>> $382;
     $384 = HEAP8[$25>>0]|0;
     $385 = $384&255;
     $386 = $383 << $385;
     $387 = $380 | $386;
     $388 = HEAP8[$26>>0]|0;
     $389 = $388&255;
     $390 = $367 >>> $389;
     $391 = HEAP8[$27>>0]|0;
     $392 = $391&255;
     $393 = $390 << $392;
     $394 = $387 | $393;
     $395 = $394&255;
     HEAP8[$$4559>>0] = $395;
     break;
    }
    case 2:  {
     $396 = HEAP8[$20>>0]|0;
     $397 = $396&255;
     $398 = $358 >>> $397;
     $399 = HEAP8[$21>>0]|0;
     $400 = $399&255;
     $401 = $398 << $400;
     $402 = HEAP8[$22>>0]|0;
     $403 = $402&255;
     $404 = $360 >>> $403;
     $405 = HEAP8[$23>>0]|0;
     $406 = $405&255;
     $407 = $404 << $406;
     $408 = $407 | $401;
     $409 = HEAP8[$24>>0]|0;
     $410 = $409&255;
     $411 = $362 >>> $410;
     $412 = HEAP8[$25>>0]|0;
     $413 = $412&255;
     $414 = $411 << $413;
     $415 = $408 | $414;
     $416 = HEAP8[$26>>0]|0;
     $417 = $416&255;
     $418 = $367 >>> $417;
     $419 = HEAP8[$27>>0]|0;
     $420 = $419&255;
     $421 = $418 << $420;
     $422 = $415 | $421;
     $423 = $422&65535;
     HEAP16[$$4559>>1] = $423;
     break;
    }
    case 3:  {
     $424 = $357&255;
     $425 = HEAP8[$21>>0]|0;
     $div588 = ($425&255) >>> 3;
     $426 = $div588&255;
     $427 = (($$4559) + ($426)|0);
     HEAP8[$427>>0] = $424;
     $428 = $359&255;
     $429 = HEAP8[$23>>0]|0;
     $div589 = ($429&255) >>> 3;
     $430 = $div589&255;
     $431 = (($$4559) + ($430)|0);
     HEAP8[$431>>0] = $428;
     $432 = $361&255;
     $433 = HEAP8[$25>>0]|0;
     $div590 = ($433&255) >>> 3;
     $434 = $div590&255;
     $435 = (($$4559) + ($434)|0);
     HEAP8[$435>>0] = $432;
     break;
    }
    case 4:  {
     $436 = HEAP8[$20>>0]|0;
     $437 = $436&255;
     $438 = $358 >>> $437;
     $439 = HEAP8[$21>>0]|0;
     $440 = $439&255;
     $441 = $438 << $440;
     $442 = HEAP8[$22>>0]|0;
     $443 = $442&255;
     $444 = $360 >>> $443;
     $445 = HEAP8[$23>>0]|0;
     $446 = $445&255;
     $447 = $444 << $446;
     $448 = $447 | $441;
     $449 = HEAP8[$24>>0]|0;
     $450 = $449&255;
     $451 = $362 >>> $450;
     $452 = HEAP8[$25>>0]|0;
     $453 = $452&255;
     $454 = $451 << $453;
     $455 = $448 | $454;
     $456 = HEAP8[$26>>0]|0;
     $457 = $456&255;
     $458 = $367 >>> $457;
     $459 = HEAP8[$27>>0]|0;
     $460 = $459&255;
     $461 = $458 << $460;
     $462 = $455 | $461;
     HEAP32[$$4559>>2] = $462;
     break;
    }
    default: {
    }
    }
    $463 = (($$4559) + ($13)|0);
    $464 = ((($$4)) + 4|0);
    $$4568 = $$3567;$$5 = $464;$$5560 = $463;
    label = 28;
    continue;
   }
   else if ((label|0) == 28) {
    label = 0;
    $465 = HEAP32[$$5>>2]|0;
    $466 = $465 >>> 22;
    $467 = $466 & 255;
    $468 = $465 >>> 12;
    $469 = $468 & 255;
    $470 = $465 >>> 2;
    $471 = $470 & 255;
    $472 = HEAP32[(79236)>>2]|0;
    $473 = $465 >>> 30;
    $474 = (($472) + ($473)|0);
    $475 = HEAP8[$474>>0]|0;
    $476 = $475&255;
    switch ($12<<24>>24) {
    case 1:  {
     $477 = HEAP8[$20>>0]|0;
     $478 = $477&255;
     $479 = $467 >>> $478;
     $480 = HEAP8[$21>>0]|0;
     $481 = $480&255;
     $482 = $479 << $481;
     $483 = HEAP8[$22>>0]|0;
     $484 = $483&255;
     $485 = $469 >>> $484;
     $486 = HEAP8[$23>>0]|0;
     $487 = $486&255;
     $488 = $485 << $487;
     $489 = $488 | $482;
     $490 = HEAP8[$24>>0]|0;
     $491 = $490&255;
     $492 = $471 >>> $491;
     $493 = HEAP8[$25>>0]|0;
     $494 = $493&255;
     $495 = $492 << $494;
     $496 = $489 | $495;
     $497 = HEAP8[$26>>0]|0;
     $498 = $497&255;
     $499 = $476 >>> $498;
     $500 = HEAP8[$27>>0]|0;
     $501 = $500&255;
     $502 = $499 << $501;
     $503 = $496 | $502;
     $504 = $503&255;
     HEAP8[$$5560>>0] = $504;
     break;
    }
    case 2:  {
     $505 = HEAP8[$20>>0]|0;
     $506 = $505&255;
     $507 = $467 >>> $506;
     $508 = HEAP8[$21>>0]|0;
     $509 = $508&255;
     $510 = $507 << $509;
     $511 = HEAP8[$22>>0]|0;
     $512 = $511&255;
     $513 = $469 >>> $512;
     $514 = HEAP8[$23>>0]|0;
     $515 = $514&255;
     $516 = $513 << $515;
     $517 = $516 | $510;
     $518 = HEAP8[$24>>0]|0;
     $519 = $518&255;
     $520 = $471 >>> $519;
     $521 = HEAP8[$25>>0]|0;
     $522 = $521&255;
     $523 = $520 << $522;
     $524 = $517 | $523;
     $525 = HEAP8[$26>>0]|0;
     $526 = $525&255;
     $527 = $476 >>> $526;
     $528 = HEAP8[$27>>0]|0;
     $529 = $528&255;
     $530 = $527 << $529;
     $531 = $524 | $530;
     $532 = $531&65535;
     HEAP16[$$5560>>1] = $532;
     break;
    }
    case 3:  {
     $533 = $466&255;
     $534 = HEAP8[$21>>0]|0;
     $div585 = ($534&255) >>> 3;
     $535 = $div585&255;
     $536 = (($$5560) + ($535)|0);
     HEAP8[$536>>0] = $533;
     $537 = $468&255;
     $538 = HEAP8[$23>>0]|0;
     $div586 = ($538&255) >>> 3;
     $539 = $div586&255;
     $540 = (($$5560) + ($539)|0);
     HEAP8[$540>>0] = $537;
     $541 = $470&255;
     $542 = HEAP8[$25>>0]|0;
     $div587 = ($542&255) >>> 3;
     $543 = $div587&255;
     $544 = (($$5560) + ($543)|0);
     HEAP8[$544>>0] = $541;
     break;
    }
    case 4:  {
     $545 = HEAP8[$20>>0]|0;
     $546 = $545&255;
     $547 = $467 >>> $546;
     $548 = HEAP8[$21>>0]|0;
     $549 = $548&255;
     $550 = $547 << $549;
     $551 = HEAP8[$22>>0]|0;
     $552 = $551&255;
     $553 = $469 >>> $552;
     $554 = HEAP8[$23>>0]|0;
     $555 = $554&255;
     $556 = $553 << $555;
     $557 = $556 | $550;
     $558 = HEAP8[$24>>0]|0;
     $559 = $558&255;
     $560 = $471 >>> $559;
     $561 = HEAP8[$25>>0]|0;
     $562 = $561&255;
     $563 = $560 << $562;
     $564 = $557 | $563;
     $565 = HEAP8[$26>>0]|0;
     $566 = $565&255;
     $567 = $476 >>> $566;
     $568 = HEAP8[$27>>0]|0;
     $569 = $568&255;
     $570 = $567 << $569;
     $571 = $564 | $570;
     HEAP32[$$5560>>2] = $571;
     break;
    }
    default: {
    }
    }
    $572 = (($$5560) + ($13)|0);
    $573 = ((($$5)) + 4|0);
    $$5569 = $$4568;$$6 = $573;$$6561 = $572;
    label = 34;
    continue;
   }
   else if ((label|0) == 34) {
    label = 0;
    $574 = HEAP32[$$6>>2]|0;
    $575 = $574 >>> 22;
    $576 = $575 & 255;
    $577 = $574 >>> 12;
    $578 = $577 & 255;
    $579 = $574 >>> 2;
    $580 = $579 & 255;
    $581 = HEAP32[(79236)>>2]|0;
    $582 = $574 >>> 30;
    $583 = (($581) + ($582)|0);
    $584 = HEAP8[$583>>0]|0;
    $585 = $584&255;
    switch ($12<<24>>24) {
    case 1:  {
     $586 = HEAP8[$20>>0]|0;
     $587 = $586&255;
     $588 = $576 >>> $587;
     $589 = HEAP8[$21>>0]|0;
     $590 = $589&255;
     $591 = $588 << $590;
     $592 = HEAP8[$22>>0]|0;
     $593 = $592&255;
     $594 = $578 >>> $593;
     $595 = HEAP8[$23>>0]|0;
     $596 = $595&255;
     $597 = $594 << $596;
     $598 = $597 | $591;
     $599 = HEAP8[$24>>0]|0;
     $600 = $599&255;
     $601 = $580 >>> $600;
     $602 = HEAP8[$25>>0]|0;
     $603 = $602&255;
     $604 = $601 << $603;
     $605 = $598 | $604;
     $606 = HEAP8[$26>>0]|0;
     $607 = $606&255;
     $608 = $585 >>> $607;
     $609 = HEAP8[$27>>0]|0;
     $610 = $609&255;
     $611 = $608 << $610;
     $612 = $605 | $611;
     $613 = $612&255;
     HEAP8[$$6561>>0] = $613;
     break;
    }
    case 2:  {
     $614 = HEAP8[$20>>0]|0;
     $615 = $614&255;
     $616 = $576 >>> $615;
     $617 = HEAP8[$21>>0]|0;
     $618 = $617&255;
     $619 = $616 << $618;
     $620 = HEAP8[$22>>0]|0;
     $621 = $620&255;
     $622 = $578 >>> $621;
     $623 = HEAP8[$23>>0]|0;
     $624 = $623&255;
     $625 = $622 << $624;
     $626 = $625 | $619;
     $627 = HEAP8[$24>>0]|0;
     $628 = $627&255;
     $629 = $580 >>> $628;
     $630 = HEAP8[$25>>0]|0;
     $631 = $630&255;
     $632 = $629 << $631;
     $633 = $626 | $632;
     $634 = HEAP8[$26>>0]|0;
     $635 = $634&255;
     $636 = $585 >>> $635;
     $637 = HEAP8[$27>>0]|0;
     $638 = $637&255;
     $639 = $636 << $638;
     $640 = $633 | $639;
     $641 = $640&65535;
     HEAP16[$$6561>>1] = $641;
     break;
    }
    case 3:  {
     $642 = $575&255;
     $643 = HEAP8[$21>>0]|0;
     $div582 = ($643&255) >>> 3;
     $644 = $div582&255;
     $645 = (($$6561) + ($644)|0);
     HEAP8[$645>>0] = $642;
     $646 = $577&255;
     $647 = HEAP8[$23>>0]|0;
     $div583 = ($647&255) >>> 3;
     $648 = $div583&255;
     $649 = (($$6561) + ($648)|0);
     HEAP8[$649>>0] = $646;
     $650 = $579&255;
     $651 = HEAP8[$25>>0]|0;
     $div584 = ($651&255) >>> 3;
     $652 = $div584&255;
     $653 = (($$6561) + ($652)|0);
     HEAP8[$653>>0] = $650;
     break;
    }
    case 4:  {
     $654 = HEAP8[$20>>0]|0;
     $655 = $654&255;
     $656 = $576 >>> $655;
     $657 = HEAP8[$21>>0]|0;
     $658 = $657&255;
     $659 = $656 << $658;
     $660 = HEAP8[$22>>0]|0;
     $661 = $660&255;
     $662 = $578 >>> $661;
     $663 = HEAP8[$23>>0]|0;
     $664 = $663&255;
     $665 = $662 << $664;
     $666 = $665 | $659;
     $667 = HEAP8[$24>>0]|0;
     $668 = $667&255;
     $669 = $580 >>> $668;
     $670 = HEAP8[$25>>0]|0;
     $671 = $670&255;
     $672 = $669 << $671;
     $673 = $666 | $672;
     $674 = HEAP8[$26>>0]|0;
     $675 = $674&255;
     $676 = $585 >>> $675;
     $677 = HEAP8[$27>>0]|0;
     $678 = $677&255;
     $679 = $676 << $678;
     $680 = $673 | $679;
     HEAP32[$$6561>>2] = $680;
     break;
    }
    default: {
    }
    }
    $681 = (($$6561) + ($13)|0);
    $682 = ((($$6)) + 4|0);
    $$6570 = $$5569;$$7 = $682;$$7562 = $681;
    label = 40;
    continue;
   }
   else if ((label|0) == 40) {
    label = 0;
    $683 = HEAP32[$$7>>2]|0;
    $684 = $683 >>> 22;
    $685 = $684 & 255;
    $686 = $683 >>> 12;
    $687 = $686 & 255;
    $688 = $683 >>> 2;
    $689 = $688 & 255;
    $690 = HEAP32[(79236)>>2]|0;
    $691 = $683 >>> 30;
    $692 = (($690) + ($691)|0);
    $693 = HEAP8[$692>>0]|0;
    $694 = $693&255;
    switch ($12<<24>>24) {
    case 1:  {
     $695 = HEAP8[$20>>0]|0;
     $696 = $695&255;
     $697 = $685 >>> $696;
     $698 = HEAP8[$21>>0]|0;
     $699 = $698&255;
     $700 = $697 << $699;
     $701 = HEAP8[$22>>0]|0;
     $702 = $701&255;
     $703 = $687 >>> $702;
     $704 = HEAP8[$23>>0]|0;
     $705 = $704&255;
     $706 = $703 << $705;
     $707 = $706 | $700;
     $708 = HEAP8[$24>>0]|0;
     $709 = $708&255;
     $710 = $689 >>> $709;
     $711 = HEAP8[$25>>0]|0;
     $712 = $711&255;
     $713 = $710 << $712;
     $714 = $707 | $713;
     $715 = HEAP8[$26>>0]|0;
     $716 = $715&255;
     $717 = $694 >>> $716;
     $718 = HEAP8[$27>>0]|0;
     $719 = $718&255;
     $720 = $717 << $719;
     $721 = $714 | $720;
     $722 = $721&255;
     HEAP8[$$7562>>0] = $722;
     break;
    }
    case 2:  {
     $723 = HEAP8[$20>>0]|0;
     $724 = $723&255;
     $725 = $685 >>> $724;
     $726 = HEAP8[$21>>0]|0;
     $727 = $726&255;
     $728 = $725 << $727;
     $729 = HEAP8[$22>>0]|0;
     $730 = $729&255;
     $731 = $687 >>> $730;
     $732 = HEAP8[$23>>0]|0;
     $733 = $732&255;
     $734 = $731 << $733;
     $735 = $734 | $728;
     $736 = HEAP8[$24>>0]|0;
     $737 = $736&255;
     $738 = $689 >>> $737;
     $739 = HEAP8[$25>>0]|0;
     $740 = $739&255;
     $741 = $738 << $740;
     $742 = $735 | $741;
     $743 = HEAP8[$26>>0]|0;
     $744 = $743&255;
     $745 = $694 >>> $744;
     $746 = HEAP8[$27>>0]|0;
     $747 = $746&255;
     $748 = $745 << $747;
     $749 = $742 | $748;
     $750 = $749&65535;
     HEAP16[$$7562>>1] = $750;
     break;
    }
    case 3:  {
     $751 = $684&255;
     $752 = HEAP8[$21>>0]|0;
     $div = ($752&255) >>> 3;
     $753 = $div&255;
     $754 = (($$7562) + ($753)|0);
     HEAP8[$754>>0] = $751;
     $755 = $686&255;
     $756 = HEAP8[$23>>0]|0;
     $div580 = ($756&255) >>> 3;
     $757 = $div580&255;
     $758 = (($$7562) + ($757)|0);
     HEAP8[$758>>0] = $755;
     $759 = $688&255;
     $760 = HEAP8[$25>>0]|0;
     $div581 = ($760&255) >>> 3;
     $761 = $div581&255;
     $762 = (($$7562) + ($761)|0);
     HEAP8[$762>>0] = $759;
     break;
    }
    case 4:  {
     $763 = HEAP8[$20>>0]|0;
     $764 = $763&255;
     $765 = $685 >>> $764;
     $766 = HEAP8[$21>>0]|0;
     $767 = $766&255;
     $768 = $765 << $767;
     $769 = HEAP8[$22>>0]|0;
     $770 = $769&255;
     $771 = $687 >>> $770;
     $772 = HEAP8[$23>>0]|0;
     $773 = $772&255;
     $774 = $771 << $773;
     $775 = $774 | $768;
     $776 = HEAP8[$24>>0]|0;
     $777 = $776&255;
     $778 = $689 >>> $777;
     $779 = HEAP8[$25>>0]|0;
     $780 = $779&255;
     $781 = $778 << $780;
     $782 = $775 | $781;
     $783 = HEAP8[$26>>0]|0;
     $784 = $783&255;
     $785 = $694 >>> $784;
     $786 = HEAP8[$27>>0]|0;
     $787 = $786&255;
     $788 = $785 << $787;
     $789 = $782 | $788;
     HEAP32[$$7562>>2] = $789;
     break;
    }
    default: {
    }
    }
    $790 = (($$7562) + ($13)|0);
    $791 = ((($$7)) + 4|0);
    $$7571 = $$6570;$$8 = $791;$$8563 = $790;
    label = 46;
    continue;
   }
   else if ((label|0) == 46) {
    label = 0;
    $792 = HEAP32[$$8>>2]|0;
    $793 = $792 >>> 22;
    $794 = $793 & 255;
    $795 = $792 >>> 12;
    $796 = $795 & 255;
    $797 = $792 >>> 2;
    $798 = $797 & 255;
    $799 = HEAP32[(79236)>>2]|0;
    $800 = $792 >>> 30;
    $801 = (($799) + ($800)|0);
    $802 = HEAP8[$801>>0]|0;
    $803 = $802&255;
    switch ($12<<24>>24) {
    case 1:  {
     $804 = HEAP8[$20>>0]|0;
     $805 = $804&255;
     $806 = $794 >>> $805;
     $807 = HEAP8[$21>>0]|0;
     $808 = $807&255;
     $809 = $806 << $808;
     $810 = HEAP8[$22>>0]|0;
     $811 = $810&255;
     $812 = $796 >>> $811;
     $813 = HEAP8[$23>>0]|0;
     $814 = $813&255;
     $815 = $812 << $814;
     $816 = $815 | $809;
     $817 = HEAP8[$24>>0]|0;
     $818 = $817&255;
     $819 = $798 >>> $818;
     $820 = HEAP8[$25>>0]|0;
     $821 = $820&255;
     $822 = $819 << $821;
     $823 = $816 | $822;
     $824 = HEAP8[$26>>0]|0;
     $825 = $824&255;
     $826 = $803 >>> $825;
     $827 = HEAP8[$27>>0]|0;
     $828 = $827&255;
     $829 = $826 << $828;
     $830 = $823 | $829;
     $831 = $830&255;
     HEAP8[$$8563>>0] = $831;
     break;
    }
    case 2:  {
     $832 = HEAP8[$20>>0]|0;
     $833 = $832&255;
     $834 = $794 >>> $833;
     $835 = HEAP8[$21>>0]|0;
     $836 = $835&255;
     $837 = $834 << $836;
     $838 = HEAP8[$22>>0]|0;
     $839 = $838&255;
     $840 = $796 >>> $839;
     $841 = HEAP8[$23>>0]|0;
     $842 = $841&255;
     $843 = $840 << $842;
     $844 = $843 | $837;
     $845 = HEAP8[$24>>0]|0;
     $846 = $845&255;
     $847 = $798 >>> $846;
     $848 = HEAP8[$25>>0]|0;
     $849 = $848&255;
     $850 = $847 << $849;
     $851 = $844 | $850;
     $852 = HEAP8[$26>>0]|0;
     $853 = $852&255;
     $854 = $803 >>> $853;
     $855 = HEAP8[$27>>0]|0;
     $856 = $855&255;
     $857 = $854 << $856;
     $858 = $851 | $857;
     $859 = $858&65535;
     HEAP16[$$8563>>1] = $859;
     break;
    }
    case 3:  {
     $860 = $793&255;
     $861 = HEAP8[$21>>0]|0;
     $div600 = ($861&255) >>> 3;
     $862 = $div600&255;
     $863 = (($$8563) + ($862)|0);
     HEAP8[$863>>0] = $860;
     $864 = $795&255;
     $865 = HEAP8[$23>>0]|0;
     $div601 = ($865&255) >>> 3;
     $866 = $div601&255;
     $867 = (($$8563) + ($866)|0);
     HEAP8[$867>>0] = $864;
     $868 = $797&255;
     $869 = HEAP8[$25>>0]|0;
     $div602 = ($869&255) >>> 3;
     $870 = $div602&255;
     $871 = (($$8563) + ($870)|0);
     HEAP8[$871>>0] = $868;
     break;
    }
    case 4:  {
     $872 = HEAP8[$20>>0]|0;
     $873 = $872&255;
     $874 = $794 >>> $873;
     $875 = HEAP8[$21>>0]|0;
     $876 = $875&255;
     $877 = $874 << $876;
     $878 = HEAP8[$22>>0]|0;
     $879 = $878&255;
     $880 = $796 >>> $879;
     $881 = HEAP8[$23>>0]|0;
     $882 = $881&255;
     $883 = $880 << $882;
     $884 = $883 | $877;
     $885 = HEAP8[$24>>0]|0;
     $886 = $885&255;
     $887 = $798 >>> $886;
     $888 = HEAP8[$25>>0]|0;
     $889 = $888&255;
     $890 = $887 << $889;
     $891 = $884 | $890;
     $892 = HEAP8[$26>>0]|0;
     $893 = $892&255;
     $894 = $803 >>> $893;
     $895 = HEAP8[$27>>0]|0;
     $896 = $895&255;
     $897 = $894 << $896;
     $898 = $891 | $897;
     HEAP32[$$8563>>2] = $898;
     break;
    }
    default: {
    }
    }
    $899 = (($$8563) + ($13)|0);
    $900 = ((($$8)) + 4|0);
    $901 = (($$7571) + -1)|0;
    $902 = ($$7571|0)>(1);
    if ($902) {
     $$0564 = $901;$$1 = $900;$$1556 = $899;
     label = 4;
     continue;
    } else {
     break;
    }
   }
  }
  $903 = (($900) + ($6)|0);
  $904 = (($899) + ($8)|0);
  $905 = ($28|0)==(0);
  if ($905) {
   label = 54;
   break;
  } else {
   $$0554604 = $903;$$0555603 = $904;$$in = $28;
  }
 }
 if ((label|0) == 52) {
  // unreachable;
 }
 else if ((label|0) == 54) {
  return;
 }
}
function _BlitNto2101010($0) {
 $0 = $0|0;
 var $$ = 0, $$0 = 0, $$0634$shrunk = 0, $$0634$shrunk728 = 0, $$0642 = 0, $$0642$shrunk = 0, $$0642$shrunk$in = 0, $$0642$shrunk727 = 0, $$0642729 = 0, $$0650 = 0, $$0650$shrunk = 0, $$0650$shrunk$in = 0, $$0650$shrunk726 = 0, $$0650730 = 0, $$0658 = 0, $$0658$shrunk = 0, $$0658$shrunk$in = 0, $$0667802 = 0, $$0675801 = 0, $$1 = 0;
 var $$1635$shrunk = 0, $$1635$shrunk737 = 0, $$1643 = 0, $$1643$shrunk = 0, $$1643$shrunk$in = 0, $$1643$shrunk736 = 0, $$1643738 = 0, $$1651 = 0, $$1651$shrunk = 0, $$1651$shrunk$in = 0, $$1651$shrunk735 = 0, $$1651739 = 0, $$1659 = 0, $$1659$shrunk = 0, $$1659$shrunk$in = 0, $$1668 = 0, $$1676 = 0, $$2 = 0, $$2636$shrunk = 0, $$2636$shrunk746 = 0;
 var $$2644 = 0, $$2644$shrunk = 0, $$2644$shrunk$in = 0, $$2644$shrunk745 = 0, $$2644747 = 0, $$2652 = 0, $$2652$shrunk = 0, $$2652$shrunk$in = 0, $$2652$shrunk744 = 0, $$2652748 = 0, $$2660 = 0, $$2660$shrunk = 0, $$2660$shrunk$in = 0, $$2669 = 0, $$2677 = 0, $$3 = 0, $$3637$shrunk = 0, $$3637$shrunk755 = 0, $$3645 = 0, $$3645$shrunk = 0;
 var $$3645$shrunk$in = 0, $$3645$shrunk754 = 0, $$3645756 = 0, $$3653 = 0, $$3653$shrunk = 0, $$3653$shrunk$in = 0, $$3653$shrunk753 = 0, $$3653757 = 0, $$3661 = 0, $$3661$shrunk = 0, $$3661$shrunk$in = 0, $$3670 = 0, $$3678 = 0, $$4 = 0, $$4638$shrunk = 0, $$4638$shrunk764 = 0, $$4646 = 0, $$4646$shrunk = 0, $$4646$shrunk$in = 0, $$4646$shrunk763 = 0;
 var $$4646765 = 0, $$4654 = 0, $$4654$shrunk = 0, $$4654$shrunk$in = 0, $$4654$shrunk762 = 0, $$4654766 = 0, $$4662 = 0, $$4662$shrunk = 0, $$4662$shrunk$in = 0, $$4671 = 0, $$4679 = 0, $$5 = 0, $$5639$shrunk = 0, $$5639$shrunk773 = 0, $$5647 = 0, $$5647$shrunk = 0, $$5647$shrunk$in = 0, $$5647$shrunk772 = 0, $$5647774 = 0, $$5655 = 0;
 var $$5655$shrunk = 0, $$5655$shrunk$in = 0, $$5655$shrunk771 = 0, $$5655775 = 0, $$5663 = 0, $$5663$shrunk = 0, $$5663$shrunk$in = 0, $$5672 = 0, $$5680 = 0, $$6 = 0, $$6640$shrunk = 0, $$6640$shrunk782 = 0, $$6648 = 0, $$6648$shrunk = 0, $$6648$shrunk$in = 0, $$6648$shrunk781 = 0, $$6648783 = 0, $$6656 = 0, $$6656$shrunk = 0, $$6656$shrunk$in = 0;
 var $$6656$shrunk780 = 0, $$6656784 = 0, $$6664 = 0, $$6664$shrunk = 0, $$6664$shrunk$in = 0, $$6673 = 0, $$6681 = 0, $$7 = 0, $$7641$shrunk = 0, $$7641$shrunk791 = 0, $$7649 = 0, $$7649$shrunk = 0, $$7649$shrunk$in = 0, $$7649$shrunk790 = 0, $$7649792 = 0, $$7657 = 0, $$7657$shrunk = 0, $$7657$shrunk$in = 0, $$7657$shrunk789 = 0, $$7657793 = 0;
 var $$7665 = 0, $$7665$shrunk = 0, $$7665$shrunk$in = 0, $$7674 = 0, $$7682 = 0, $$794 = 0, $$795 = 0, $$796 = 0, $$797 = 0, $$798 = 0, $$799 = 0, $$8 = 0, $$800 = 0, $$8683 = 0, $$in = 0, $1 = 0, $10 = 0, $100 = 0, $1000 = 0, $1001 = 0;
 var $1002 = 0, $1003 = 0, $1004 = 0, $1005 = 0, $1006 = 0, $1007 = 0, $1008 = 0, $1009 = 0, $101 = 0, $1010 = 0, $1011 = 0, $1012 = 0, $1013 = 0, $1014 = 0, $1015 = 0, $1016 = 0, $1017 = 0, $1018 = 0, $1019 = 0, $102 = 0;
 var $1020 = 0, $1021 = 0, $1022 = 0, $1023 = 0, $1024 = 0, $1025 = 0, $1026 = 0, $1027 = 0, $1028 = 0, $1029 = 0, $103 = 0, $1030 = 0, $1031 = 0, $1032 = 0, $1033 = 0, $1034 = 0, $1035 = 0, $1036 = 0, $1037 = 0, $1038 = 0;
 var $1039 = 0, $104 = 0, $1040 = 0, $1041 = 0, $1042 = 0, $1043 = 0, $1044 = 0, $1045 = 0, $1046 = 0, $1047 = 0, $1048 = 0, $1049 = 0, $105 = 0, $1050 = 0, $1051 = 0, $1052 = 0, $1053 = 0, $1054 = 0, $1055 = 0, $1056 = 0;
 var $1057 = 0, $1058 = 0, $1059 = 0, $106 = 0, $1060 = 0, $1061 = 0, $1062 = 0, $1063 = 0, $1064 = 0, $1065 = 0, $1066 = 0, $1067 = 0, $1068 = 0, $1069 = 0, $107 = 0, $1070 = 0, $1071 = 0, $1072 = 0, $1073 = 0, $1074 = 0;
 var $1075 = 0, $1076 = 0, $1077 = 0, $1078 = 0, $1079 = 0, $108 = 0, $1080 = 0, $1081 = 0, $1082 = 0, $1083 = 0, $1084 = 0, $1085 = 0, $1086 = 0, $1087 = 0, $1088 = 0, $1089 = 0, $109 = 0, $1090 = 0, $1091 = 0, $1092 = 0;
 var $1093 = 0, $1094 = 0, $1095 = 0, $1096 = 0, $1097 = 0, $1098 = 0, $1099 = 0, $11 = 0, $110 = 0, $1100 = 0, $1101 = 0, $1102 = 0, $1103 = 0, $1104 = 0, $1105 = 0, $1106 = 0, $1107 = 0, $1108 = 0, $1109 = 0, $111 = 0;
 var $1110 = 0, $1111 = 0, $1112 = 0, $1113 = 0, $1114 = 0, $1115 = 0, $1116 = 0, $1117 = 0, $1118 = 0, $1119 = 0, $112 = 0, $1120 = 0, $1121 = 0, $1122 = 0, $1123 = 0, $1124 = 0, $1125 = 0, $1126 = 0, $1127 = 0, $1128 = 0;
 var $1129 = 0, $113 = 0, $1130 = 0, $1131 = 0, $1132 = 0, $1133 = 0, $1134 = 0, $1135 = 0, $1136 = 0, $1137 = 0, $1138 = 0, $1139 = 0, $114 = 0, $1140 = 0, $1141 = 0, $1142 = 0, $1143 = 0, $1144 = 0, $1145 = 0, $1146 = 0;
 var $1147 = 0, $1148 = 0, $1149 = 0, $115 = 0, $1150 = 0, $1151 = 0, $1152 = 0, $1153 = 0, $1154 = 0, $1155 = 0, $1156 = 0, $1157 = 0, $1158 = 0, $1159 = 0, $116 = 0, $1160 = 0, $1161 = 0, $1162 = 0, $1163 = 0, $1164 = 0;
 var $1165 = 0, $1166 = 0, $1167 = 0, $1168 = 0, $1169 = 0, $117 = 0, $1170 = 0, $1171 = 0, $1172 = 0, $1173 = 0, $1174 = 0, $1175 = 0, $1176 = 0, $1177 = 0, $1178 = 0, $1179 = 0, $118 = 0, $1180 = 0, $1181 = 0, $1182 = 0;
 var $1183 = 0, $1184 = 0, $1185 = 0, $1186 = 0, $1187 = 0, $1188 = 0, $1189 = 0, $119 = 0, $1190 = 0, $1191 = 0, $1192 = 0, $1193 = 0, $1194 = 0, $1195 = 0, $1196 = 0, $1197 = 0, $1198 = 0, $1199 = 0, $12 = 0, $120 = 0;
 var $1200 = 0, $1201 = 0, $1202 = 0, $1203 = 0, $1204 = 0, $1205 = 0, $1206 = 0, $1207 = 0, $1208 = 0, $1209 = 0, $121 = 0, $1210 = 0, $1211 = 0, $1212 = 0, $1213 = 0, $1214 = 0, $1215 = 0, $1216 = 0, $1217 = 0, $1218 = 0;
 var $1219 = 0, $122 = 0, $1220 = 0, $1221 = 0, $1222 = 0, $1223 = 0, $1224 = 0, $1225 = 0, $1226 = 0, $1227 = 0, $1228 = 0, $1229 = 0, $123 = 0, $1230 = 0, $1231 = 0, $1232 = 0, $1233 = 0, $1234 = 0, $1235 = 0, $1236 = 0;
 var $1237 = 0, $1238 = 0, $1239 = 0, $124 = 0, $1240 = 0, $1241 = 0, $1242 = 0, $1243 = 0, $1244 = 0, $1245 = 0, $1246 = 0, $1247 = 0, $1248 = 0, $1249 = 0, $125 = 0, $1250 = 0, $1251 = 0, $1252 = 0, $1253 = 0, $1254 = 0;
 var $1255 = 0, $1256 = 0, $1257 = 0, $1258 = 0, $1259 = 0, $126 = 0, $1260 = 0, $1261 = 0, $1262 = 0, $1263 = 0, $1264 = 0, $1265 = 0, $1266 = 0, $1267 = 0, $1268 = 0, $1269 = 0, $127 = 0, $1270 = 0, $1271 = 0, $1272 = 0;
 var $1273 = 0, $1274 = 0, $1275 = 0, $1276 = 0, $1277 = 0, $1278 = 0, $1279 = 0, $128 = 0, $1280 = 0, $1281 = 0, $1282 = 0, $1283 = 0, $1284 = 0, $1285 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0;
 var $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0;
 var $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0;
 var $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0;
 var $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0;
 var $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0;
 var $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0;
 var $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0;
 var $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0;
 var $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0;
 var $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0;
 var $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0;
 var $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0;
 var $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0;
 var $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0;
 var $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0;
 var $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0;
 var $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0;
 var $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0;
 var $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0;
 var $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0;
 var $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0;
 var $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0;
 var $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0;
 var $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0;
 var $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0;
 var $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0;
 var $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0;
 var $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0;
 var $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0;
 var $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0;
 var $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0;
 var $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = 0;
 var $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0;
 var $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = 0, $834 = 0, $835 = 0, $836 = 0;
 var $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0, $850 = 0, $851 = 0, $852 = 0, $853 = 0, $854 = 0;
 var $855 = 0, $856 = 0, $857 = 0, $858 = 0, $859 = 0, $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0, $869 = 0, $87 = 0, $870 = 0, $871 = 0, $872 = 0;
 var $873 = 0, $874 = 0, $875 = 0, $876 = 0, $877 = 0, $878 = 0, $879 = 0, $88 = 0, $880 = 0, $881 = 0, $882 = 0, $883 = 0, $884 = 0, $885 = 0, $886 = 0, $887 = 0, $888 = 0, $889 = 0, $89 = 0, $890 = 0;
 var $891 = 0, $892 = 0, $893 = 0, $894 = 0, $895 = 0, $896 = 0, $897 = 0, $898 = 0, $899 = 0, $9 = 0, $90 = 0, $900 = 0, $901 = 0, $902 = 0, $903 = 0, $904 = 0, $905 = 0, $906 = 0, $907 = 0, $908 = 0;
 var $909 = 0, $91 = 0, $910 = 0, $911 = 0, $912 = 0, $913 = 0, $914 = 0, $915 = 0, $916 = 0, $917 = 0, $918 = 0, $919 = 0, $92 = 0, $920 = 0, $921 = 0, $922 = 0, $923 = 0, $924 = 0, $925 = 0, $926 = 0;
 var $927 = 0, $928 = 0, $929 = 0, $93 = 0, $930 = 0, $931 = 0, $932 = 0, $933 = 0, $934 = 0, $935 = 0, $936 = 0, $937 = 0, $938 = 0, $939 = 0, $94 = 0, $940 = 0, $941 = 0, $942 = 0, $943 = 0, $944 = 0;
 var $945 = 0, $946 = 0, $947 = 0, $948 = 0, $949 = 0, $95 = 0, $950 = 0, $951 = 0, $952 = 0, $953 = 0, $954 = 0, $955 = 0, $956 = 0, $957 = 0, $958 = 0, $959 = 0, $96 = 0, $960 = 0, $961 = 0, $962 = 0;
 var $963 = 0, $964 = 0, $965 = 0, $966 = 0, $967 = 0, $968 = 0, $969 = 0, $97 = 0, $970 = 0, $971 = 0, $972 = 0, $973 = 0, $974 = 0, $975 = 0, $976 = 0, $977 = 0, $978 = 0, $979 = 0, $98 = 0, $980 = 0;
 var $981 = 0, $982 = 0, $983 = 0, $984 = 0, $985 = 0, $986 = 0, $987 = 0, $988 = 0, $989 = 0, $99 = 0, $990 = 0, $991 = 0, $992 = 0, $993 = 0, $994 = 0, $995 = 0, $996 = 0, $997 = 0, $998 = 0, $999 = 0;
 var $div = 0, $div686 = 0, $div688 = 0, $div690 = 0, $div692 = 0, $div694 = 0, $div696 = 0, $div698 = 0, $div699 = 0, $div700 = 0, $div701 = 0, $div702 = 0, $div703 = 0, $div704 = 0, $div705 = 0, $div706 = 0, $div707 = 0, $div708 = 0, $div709 = 0, $div710 = 0;
 var $div711 = 0, $div712 = 0, $div713 = 0, $div714 = 0, $div715 = 0, $div716 = 0, $div717 = 0, $div718 = 0, $div719 = 0, $div720 = 0, $div721 = 0, $div722 = 0, $trunc = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($0)) + 36|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($0)) + 40|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ((($10)) + 9|0);
 $12 = HEAP8[$11>>0]|0;
 $13 = $12&255;
 $14 = ($4|0)==(0);
 if ($14) {
  return;
 }
 $15 = ((($0)) + 20|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = HEAP32[$0>>2]|0;
 $18 = (($2) + 7)|0;
 $19 = (($18|0) / 8)&-1;
 $trunc = $2&255;
 $20 = ((($10)) + 28|0);
 $21 = ((($10)) + 12|0);
 $22 = ((($10)) + 32|0);
 $23 = ((($10)) + 29|0);
 $24 = ((($10)) + 16|0);
 $25 = ((($10)) + 33|0);
 $26 = ((($10)) + 30|0);
 $27 = ((($10)) + 20|0);
 $28 = ((($10)) + 34|0);
 $29 = ((($10)) + 31|0);
 $30 = ((($10)) + 24|0);
 $31 = ((($10)) + 35|0);
 $$0667802 = $17;$$0675801 = $16;$$in = $4;
 L4: while(1) {
  $32 = (($$in) + -1)|0;
  $trunc$clear = $trunc & 7;
  switch ($trunc$clear<<24>>24) {
  case 0:  {
   $$0 = $19;$$1668 = $$0667802;$$1676 = $$0675801;
   label = 4;
   break;
  }
  case 7:  {
   $$1 = $19;$$2669 = $$0667802;$$2677 = $$0675801;
   label = 11;
   break;
  }
  case 6:  {
   $$2 = $19;$$3670 = $$0667802;$$3678 = $$0675801;
   label = 18;
   break;
  }
  case 5:  {
   $$3 = $19;$$4671 = $$0667802;$$4679 = $$0675801;
   label = 25;
   break;
  }
  case 4:  {
   $$4 = $19;$$5672 = $$0667802;$$5680 = $$0675801;
   label = 32;
   break;
  }
  case 3:  {
   $$5 = $19;$$6673 = $$0667802;$$6681 = $$0675801;
   label = 39;
   break;
  }
  case 2:  {
   $$6 = $19;$$7674 = $$0667802;$$7682 = $$0675801;
   label = 46;
   break;
  }
  case 1:  {
   $$7 = $19;$$8 = $$0667802;$$8683 = $$0675801;
   label = 53;
   break;
  }
  default: {
   label = 60;
   break L4;
  }
  }
  while(1) {
   if ((label|0) == 4) {
    label = 0;
    switch ($12<<24>>24) {
    case 1:  {
     $33 = HEAP8[$$1668>>0]|0;
     $34 = $33&255;
     $35 = HEAP8[$20>>0]|0;
     $36 = $35&255;
     $37 = (79212 + ($36<<2)|0);
     $38 = HEAP32[$37>>2]|0;
     $39 = HEAP32[$21>>2]|0;
     $40 = $39 & $34;
     $41 = HEAP8[$22>>0]|0;
     $42 = $41&255;
     $43 = $40 >>> $42;
     $44 = (($38) + ($43)|0);
     $45 = HEAP8[$23>>0]|0;
     $46 = $45&255;
     $47 = (79212 + ($46<<2)|0);
     $48 = HEAP32[$47>>2]|0;
     $49 = HEAP32[$24>>2]|0;
     $50 = $49 & $34;
     $51 = HEAP8[$25>>0]|0;
     $52 = $51&255;
     $53 = $50 >>> $52;
     $54 = (($48) + ($53)|0);
     $55 = HEAP8[$26>>0]|0;
     $56 = $55&255;
     $57 = (79212 + ($56<<2)|0);
     $58 = HEAP32[$57>>2]|0;
     $59 = HEAP32[$27>>2]|0;
     $60 = $59 & $34;
     $61 = HEAP8[$28>>0]|0;
     $62 = $61&255;
     $63 = $60 >>> $62;
     $64 = (($58) + ($63)|0);
     $65 = HEAP8[$29>>0]|0;
     $66 = $65&255;
     $67 = (79212 + ($66<<2)|0);
     $68 = HEAP32[$67>>2]|0;
     $69 = HEAP32[$30>>2]|0;
     $70 = $69 & $34;
     $71 = HEAP8[$31>>0]|0;
     $72 = $71&255;
     $73 = $70 >>> $72;
     $74 = (($68) + ($73)|0);
     $75 = HEAP8[$74>>0]|0;
     $$0634$shrunk = $75;$$0642$shrunk$in = $64;$$0650$shrunk$in = $54;$$0658$shrunk$in = $44;
     label = 9;
     break;
    }
    case 2:  {
     $76 = HEAP16[$$1668>>1]|0;
     $77 = $76&65535;
     $78 = HEAP8[$20>>0]|0;
     $79 = $78&255;
     $80 = (79212 + ($79<<2)|0);
     $81 = HEAP32[$80>>2]|0;
     $82 = HEAP32[$21>>2]|0;
     $83 = $82 & $77;
     $84 = HEAP8[$22>>0]|0;
     $85 = $84&255;
     $86 = $83 >>> $85;
     $87 = (($81) + ($86)|0);
     $88 = HEAP8[$23>>0]|0;
     $89 = $88&255;
     $90 = (79212 + ($89<<2)|0);
     $91 = HEAP32[$90>>2]|0;
     $92 = HEAP32[$24>>2]|0;
     $93 = $92 & $77;
     $94 = HEAP8[$25>>0]|0;
     $95 = $94&255;
     $96 = $93 >>> $95;
     $97 = (($91) + ($96)|0);
     $98 = HEAP8[$26>>0]|0;
     $99 = $98&255;
     $100 = (79212 + ($99<<2)|0);
     $101 = HEAP32[$100>>2]|0;
     $102 = HEAP32[$27>>2]|0;
     $103 = $102 & $77;
     $104 = HEAP8[$28>>0]|0;
     $105 = $104&255;
     $106 = $103 >>> $105;
     $107 = (($101) + ($106)|0);
     $108 = HEAP8[$29>>0]|0;
     $109 = $108&255;
     $110 = (79212 + ($109<<2)|0);
     $111 = HEAP32[$110>>2]|0;
     $112 = HEAP32[$30>>2]|0;
     $113 = $112 & $77;
     $114 = HEAP8[$31>>0]|0;
     $115 = $114&255;
     $116 = $113 >>> $115;
     $117 = (($111) + ($116)|0);
     $118 = HEAP8[$117>>0]|0;
     $$0634$shrunk = $118;$$0642$shrunk$in = $107;$$0650$shrunk$in = $97;$$0658$shrunk$in = $87;
     label = 9;
     break;
    }
    case 3:  {
     $119 = HEAP8[$22>>0]|0;
     $div717 = ($119&255) >>> 3;
     $120 = $div717&255;
     $121 = (($$1668) + ($120)|0);
     $122 = HEAP8[$25>>0]|0;
     $div718 = ($122&255) >>> 3;
     $123 = $div718&255;
     $124 = (($$1668) + ($123)|0);
     $125 = HEAP8[$28>>0]|0;
     $div719 = ($125&255) >>> 3;
     $126 = $div719&255;
     $127 = (($$1668) + ($126)|0);
     $$0634$shrunk = -1;$$0642$shrunk$in = $127;$$0650$shrunk$in = $124;$$0658$shrunk$in = $121;
     label = 9;
     break;
    }
    case 4:  {
     $128 = HEAP32[$$1668>>2]|0;
     $129 = HEAP8[$20>>0]|0;
     $130 = $129&255;
     $131 = (79212 + ($130<<2)|0);
     $132 = HEAP32[$131>>2]|0;
     $133 = HEAP32[$21>>2]|0;
     $134 = $133 & $128;
     $135 = HEAP8[$22>>0]|0;
     $136 = $135&255;
     $137 = $134 >>> $136;
     $138 = (($132) + ($137)|0);
     $139 = HEAP8[$23>>0]|0;
     $140 = $139&255;
     $141 = (79212 + ($140<<2)|0);
     $142 = HEAP32[$141>>2]|0;
     $143 = HEAP32[$24>>2]|0;
     $144 = $143 & $128;
     $145 = HEAP8[$25>>0]|0;
     $146 = $145&255;
     $147 = $144 >>> $146;
     $148 = (($142) + ($147)|0);
     $149 = HEAP8[$26>>0]|0;
     $150 = $149&255;
     $151 = (79212 + ($150<<2)|0);
     $152 = HEAP32[$151>>2]|0;
     $153 = HEAP32[$27>>2]|0;
     $154 = $153 & $128;
     $155 = HEAP8[$28>>0]|0;
     $156 = $155&255;
     $157 = $154 >>> $156;
     $158 = (($152) + ($157)|0);
     $159 = HEAP8[$29>>0]|0;
     $160 = $159&255;
     $161 = (79212 + ($160<<2)|0);
     $162 = HEAP32[$161>>2]|0;
     $163 = HEAP32[$30>>2]|0;
     $164 = $163 & $128;
     $165 = HEAP8[$31>>0]|0;
     $166 = $165&255;
     $167 = $164 >>> $166;
     $168 = (($162) + ($167)|0);
     $169 = HEAP8[$168>>0]|0;
     $$0634$shrunk = $169;$$0642$shrunk$in = $158;$$0650$shrunk$in = $148;$$0658$shrunk$in = $138;
     label = 9;
     break;
    }
    default: {
     $$0634$shrunk728 = 0;$$0642$shrunk727 = 0;$$0642729 = 0;$$0650$shrunk726 = 0;$$0650730 = 0;$184 = 0;
    }
    }
    if ((label|0) == 9) {
     label = 0;
     $$0642$shrunk = HEAP8[$$0642$shrunk$in>>0]|0;
     $$0650$shrunk = HEAP8[$$0650$shrunk$in>>0]|0;
     $$0658$shrunk = HEAP8[$$0658$shrunk$in>>0]|0;
     $$0642 = $$0642$shrunk&255;
     $$0650 = $$0650$shrunk&255;
     $170 = ($$0658$shrunk<<24>>24)==(0);
     $$0658 = $$0658$shrunk&255;
     $171 = $$0658 << 22;
     $172 = $171 | 3145728;
     $$ = $170 ? 0 : $172;
     $$0634$shrunk728 = $$0634$shrunk;$$0642$shrunk727 = $$0642$shrunk;$$0642729 = $$0642;$$0650$shrunk726 = $$0650$shrunk;$$0650730 = $$0650;$184 = $$;
    }
    $173 = ($$0650$shrunk726<<24>>24)==(0);
    $174 = $$0650730 << 12;
    $175 = $174 | 3072;
    $176 = $173 ? 0 : $175;
    $177 = ($$0642$shrunk727<<24>>24)==(0);
    $178 = $$0642729 << 2;
    $179 = $178 | 3;
    $180 = $177 ? 0 : $179;
    $div686 = (($$0634$shrunk728&255) / 85)&-1;
    $181 = $div686&255;
    $182 = $181 << 30;
    $183 = $182 | $184;
    $185 = $183 | $180;
    $186 = $185 | $176;
    HEAP32[$$1676>>2] = $186;
    $187 = ((($$1676)) + 4|0);
    $188 = (($$1668) + ($13)|0);
    $$1 = $$0;$$2669 = $188;$$2677 = $187;
    label = 11;
    continue;
   }
   else if ((label|0) == 11) {
    label = 0;
    switch ($12<<24>>24) {
    case 1:  {
     $189 = HEAP8[$$2669>>0]|0;
     $190 = $189&255;
     $191 = HEAP8[$20>>0]|0;
     $192 = $191&255;
     $193 = (79212 + ($192<<2)|0);
     $194 = HEAP32[$193>>2]|0;
     $195 = HEAP32[$21>>2]|0;
     $196 = $195 & $190;
     $197 = HEAP8[$22>>0]|0;
     $198 = $197&255;
     $199 = $196 >>> $198;
     $200 = (($194) + ($199)|0);
     $201 = HEAP8[$23>>0]|0;
     $202 = $201&255;
     $203 = (79212 + ($202<<2)|0);
     $204 = HEAP32[$203>>2]|0;
     $205 = HEAP32[$24>>2]|0;
     $206 = $205 & $190;
     $207 = HEAP8[$25>>0]|0;
     $208 = $207&255;
     $209 = $206 >>> $208;
     $210 = (($204) + ($209)|0);
     $211 = HEAP8[$26>>0]|0;
     $212 = $211&255;
     $213 = (79212 + ($212<<2)|0);
     $214 = HEAP32[$213>>2]|0;
     $215 = HEAP32[$27>>2]|0;
     $216 = $215 & $190;
     $217 = HEAP8[$28>>0]|0;
     $218 = $217&255;
     $219 = $216 >>> $218;
     $220 = (($214) + ($219)|0);
     $221 = HEAP8[$29>>0]|0;
     $222 = $221&255;
     $223 = (79212 + ($222<<2)|0);
     $224 = HEAP32[$223>>2]|0;
     $225 = HEAP32[$30>>2]|0;
     $226 = $225 & $190;
     $227 = HEAP8[$31>>0]|0;
     $228 = $227&255;
     $229 = $226 >>> $228;
     $230 = (($224) + ($229)|0);
     $231 = HEAP8[$230>>0]|0;
     $$1635$shrunk = $231;$$1643$shrunk$in = $220;$$1651$shrunk$in = $210;$$1659$shrunk$in = $200;
     label = 16;
     break;
    }
    case 2:  {
     $232 = HEAP16[$$2669>>1]|0;
     $233 = $232&65535;
     $234 = HEAP8[$20>>0]|0;
     $235 = $234&255;
     $236 = (79212 + ($235<<2)|0);
     $237 = HEAP32[$236>>2]|0;
     $238 = HEAP32[$21>>2]|0;
     $239 = $238 & $233;
     $240 = HEAP8[$22>>0]|0;
     $241 = $240&255;
     $242 = $239 >>> $241;
     $243 = (($237) + ($242)|0);
     $244 = HEAP8[$23>>0]|0;
     $245 = $244&255;
     $246 = (79212 + ($245<<2)|0);
     $247 = HEAP32[$246>>2]|0;
     $248 = HEAP32[$24>>2]|0;
     $249 = $248 & $233;
     $250 = HEAP8[$25>>0]|0;
     $251 = $250&255;
     $252 = $249 >>> $251;
     $253 = (($247) + ($252)|0);
     $254 = HEAP8[$26>>0]|0;
     $255 = $254&255;
     $256 = (79212 + ($255<<2)|0);
     $257 = HEAP32[$256>>2]|0;
     $258 = HEAP32[$27>>2]|0;
     $259 = $258 & $233;
     $260 = HEAP8[$28>>0]|0;
     $261 = $260&255;
     $262 = $259 >>> $261;
     $263 = (($257) + ($262)|0);
     $264 = HEAP8[$29>>0]|0;
     $265 = $264&255;
     $266 = (79212 + ($265<<2)|0);
     $267 = HEAP32[$266>>2]|0;
     $268 = HEAP32[$30>>2]|0;
     $269 = $268 & $233;
     $270 = HEAP8[$31>>0]|0;
     $271 = $270&255;
     $272 = $269 >>> $271;
     $273 = (($267) + ($272)|0);
     $274 = HEAP8[$273>>0]|0;
     $$1635$shrunk = $274;$$1643$shrunk$in = $263;$$1651$shrunk$in = $253;$$1659$shrunk$in = $243;
     label = 16;
     break;
    }
    case 3:  {
     $275 = HEAP8[$22>>0]|0;
     $div714 = ($275&255) >>> 3;
     $276 = $div714&255;
     $277 = (($$2669) + ($276)|0);
     $278 = HEAP8[$25>>0]|0;
     $div715 = ($278&255) >>> 3;
     $279 = $div715&255;
     $280 = (($$2669) + ($279)|0);
     $281 = HEAP8[$28>>0]|0;
     $div716 = ($281&255) >>> 3;
     $282 = $div716&255;
     $283 = (($$2669) + ($282)|0);
     $$1635$shrunk = -1;$$1643$shrunk$in = $283;$$1651$shrunk$in = $280;$$1659$shrunk$in = $277;
     label = 16;
     break;
    }
    case 4:  {
     $284 = HEAP32[$$2669>>2]|0;
     $285 = HEAP8[$20>>0]|0;
     $286 = $285&255;
     $287 = (79212 + ($286<<2)|0);
     $288 = HEAP32[$287>>2]|0;
     $289 = HEAP32[$21>>2]|0;
     $290 = $289 & $284;
     $291 = HEAP8[$22>>0]|0;
     $292 = $291&255;
     $293 = $290 >>> $292;
     $294 = (($288) + ($293)|0);
     $295 = HEAP8[$23>>0]|0;
     $296 = $295&255;
     $297 = (79212 + ($296<<2)|0);
     $298 = HEAP32[$297>>2]|0;
     $299 = HEAP32[$24>>2]|0;
     $300 = $299 & $284;
     $301 = HEAP8[$25>>0]|0;
     $302 = $301&255;
     $303 = $300 >>> $302;
     $304 = (($298) + ($303)|0);
     $305 = HEAP8[$26>>0]|0;
     $306 = $305&255;
     $307 = (79212 + ($306<<2)|0);
     $308 = HEAP32[$307>>2]|0;
     $309 = HEAP32[$27>>2]|0;
     $310 = $309 & $284;
     $311 = HEAP8[$28>>0]|0;
     $312 = $311&255;
     $313 = $310 >>> $312;
     $314 = (($308) + ($313)|0);
     $315 = HEAP8[$29>>0]|0;
     $316 = $315&255;
     $317 = (79212 + ($316<<2)|0);
     $318 = HEAP32[$317>>2]|0;
     $319 = HEAP32[$30>>2]|0;
     $320 = $319 & $284;
     $321 = HEAP8[$31>>0]|0;
     $322 = $321&255;
     $323 = $320 >>> $322;
     $324 = (($318) + ($323)|0);
     $325 = HEAP8[$324>>0]|0;
     $$1635$shrunk = $325;$$1643$shrunk$in = $314;$$1651$shrunk$in = $304;$$1659$shrunk$in = $294;
     label = 16;
     break;
    }
    default: {
     $$1635$shrunk737 = 0;$$1643$shrunk736 = 0;$$1643738 = 0;$$1651$shrunk735 = 0;$$1651739 = 0;$340 = 0;
    }
    }
    if ((label|0) == 16) {
     label = 0;
     $$1643$shrunk = HEAP8[$$1643$shrunk$in>>0]|0;
     $$1651$shrunk = HEAP8[$$1651$shrunk$in>>0]|0;
     $$1659$shrunk = HEAP8[$$1659$shrunk$in>>0]|0;
     $$1643 = $$1643$shrunk&255;
     $$1651 = $$1651$shrunk&255;
     $326 = ($$1659$shrunk<<24>>24)==(0);
     $$1659 = $$1659$shrunk&255;
     $327 = $$1659 << 22;
     $328 = $327 | 3145728;
     $$794 = $326 ? 0 : $328;
     $$1635$shrunk737 = $$1635$shrunk;$$1643$shrunk736 = $$1643$shrunk;$$1643738 = $$1643;$$1651$shrunk735 = $$1651$shrunk;$$1651739 = $$1651;$340 = $$794;
    }
    $329 = ($$1651$shrunk735<<24>>24)==(0);
    $330 = $$1651739 << 12;
    $331 = $330 | 3072;
    $332 = $329 ? 0 : $331;
    $333 = ($$1643$shrunk736<<24>>24)==(0);
    $334 = $$1643738 << 2;
    $335 = $334 | 3;
    $336 = $333 ? 0 : $335;
    $div688 = (($$1635$shrunk737&255) / 85)&-1;
    $337 = $div688&255;
    $338 = $337 << 30;
    $339 = $338 | $340;
    $341 = $339 | $336;
    $342 = $341 | $332;
    HEAP32[$$2677>>2] = $342;
    $343 = ((($$2677)) + 4|0);
    $344 = (($$2669) + ($13)|0);
    $$2 = $$1;$$3670 = $344;$$3678 = $343;
    label = 18;
    continue;
   }
   else if ((label|0) == 18) {
    label = 0;
    switch ($12<<24>>24) {
    case 1:  {
     $345 = HEAP8[$$3670>>0]|0;
     $346 = $345&255;
     $347 = HEAP8[$20>>0]|0;
     $348 = $347&255;
     $349 = (79212 + ($348<<2)|0);
     $350 = HEAP32[$349>>2]|0;
     $351 = HEAP32[$21>>2]|0;
     $352 = $351 & $346;
     $353 = HEAP8[$22>>0]|0;
     $354 = $353&255;
     $355 = $352 >>> $354;
     $356 = (($350) + ($355)|0);
     $357 = HEAP8[$23>>0]|0;
     $358 = $357&255;
     $359 = (79212 + ($358<<2)|0);
     $360 = HEAP32[$359>>2]|0;
     $361 = HEAP32[$24>>2]|0;
     $362 = $361 & $346;
     $363 = HEAP8[$25>>0]|0;
     $364 = $363&255;
     $365 = $362 >>> $364;
     $366 = (($360) + ($365)|0);
     $367 = HEAP8[$26>>0]|0;
     $368 = $367&255;
     $369 = (79212 + ($368<<2)|0);
     $370 = HEAP32[$369>>2]|0;
     $371 = HEAP32[$27>>2]|0;
     $372 = $371 & $346;
     $373 = HEAP8[$28>>0]|0;
     $374 = $373&255;
     $375 = $372 >>> $374;
     $376 = (($370) + ($375)|0);
     $377 = HEAP8[$29>>0]|0;
     $378 = $377&255;
     $379 = (79212 + ($378<<2)|0);
     $380 = HEAP32[$379>>2]|0;
     $381 = HEAP32[$30>>2]|0;
     $382 = $381 & $346;
     $383 = HEAP8[$31>>0]|0;
     $384 = $383&255;
     $385 = $382 >>> $384;
     $386 = (($380) + ($385)|0);
     $387 = HEAP8[$386>>0]|0;
     $$2636$shrunk = $387;$$2644$shrunk$in = $376;$$2652$shrunk$in = $366;$$2660$shrunk$in = $356;
     label = 23;
     break;
    }
    case 2:  {
     $388 = HEAP16[$$3670>>1]|0;
     $389 = $388&65535;
     $390 = HEAP8[$20>>0]|0;
     $391 = $390&255;
     $392 = (79212 + ($391<<2)|0);
     $393 = HEAP32[$392>>2]|0;
     $394 = HEAP32[$21>>2]|0;
     $395 = $394 & $389;
     $396 = HEAP8[$22>>0]|0;
     $397 = $396&255;
     $398 = $395 >>> $397;
     $399 = (($393) + ($398)|0);
     $400 = HEAP8[$23>>0]|0;
     $401 = $400&255;
     $402 = (79212 + ($401<<2)|0);
     $403 = HEAP32[$402>>2]|0;
     $404 = HEAP32[$24>>2]|0;
     $405 = $404 & $389;
     $406 = HEAP8[$25>>0]|0;
     $407 = $406&255;
     $408 = $405 >>> $407;
     $409 = (($403) + ($408)|0);
     $410 = HEAP8[$26>>0]|0;
     $411 = $410&255;
     $412 = (79212 + ($411<<2)|0);
     $413 = HEAP32[$412>>2]|0;
     $414 = HEAP32[$27>>2]|0;
     $415 = $414 & $389;
     $416 = HEAP8[$28>>0]|0;
     $417 = $416&255;
     $418 = $415 >>> $417;
     $419 = (($413) + ($418)|0);
     $420 = HEAP8[$29>>0]|0;
     $421 = $420&255;
     $422 = (79212 + ($421<<2)|0);
     $423 = HEAP32[$422>>2]|0;
     $424 = HEAP32[$30>>2]|0;
     $425 = $424 & $389;
     $426 = HEAP8[$31>>0]|0;
     $427 = $426&255;
     $428 = $425 >>> $427;
     $429 = (($423) + ($428)|0);
     $430 = HEAP8[$429>>0]|0;
     $$2636$shrunk = $430;$$2644$shrunk$in = $419;$$2652$shrunk$in = $409;$$2660$shrunk$in = $399;
     label = 23;
     break;
    }
    case 3:  {
     $431 = HEAP8[$22>>0]|0;
     $div711 = ($431&255) >>> 3;
     $432 = $div711&255;
     $433 = (($$3670) + ($432)|0);
     $434 = HEAP8[$25>>0]|0;
     $div712 = ($434&255) >>> 3;
     $435 = $div712&255;
     $436 = (($$3670) + ($435)|0);
     $437 = HEAP8[$28>>0]|0;
     $div713 = ($437&255) >>> 3;
     $438 = $div713&255;
     $439 = (($$3670) + ($438)|0);
     $$2636$shrunk = -1;$$2644$shrunk$in = $439;$$2652$shrunk$in = $436;$$2660$shrunk$in = $433;
     label = 23;
     break;
    }
    case 4:  {
     $440 = HEAP32[$$3670>>2]|0;
     $441 = HEAP8[$20>>0]|0;
     $442 = $441&255;
     $443 = (79212 + ($442<<2)|0);
     $444 = HEAP32[$443>>2]|0;
     $445 = HEAP32[$21>>2]|0;
     $446 = $445 & $440;
     $447 = HEAP8[$22>>0]|0;
     $448 = $447&255;
     $449 = $446 >>> $448;
     $450 = (($444) + ($449)|0);
     $451 = HEAP8[$23>>0]|0;
     $452 = $451&255;
     $453 = (79212 + ($452<<2)|0);
     $454 = HEAP32[$453>>2]|0;
     $455 = HEAP32[$24>>2]|0;
     $456 = $455 & $440;
     $457 = HEAP8[$25>>0]|0;
     $458 = $457&255;
     $459 = $456 >>> $458;
     $460 = (($454) + ($459)|0);
     $461 = HEAP8[$26>>0]|0;
     $462 = $461&255;
     $463 = (79212 + ($462<<2)|0);
     $464 = HEAP32[$463>>2]|0;
     $465 = HEAP32[$27>>2]|0;
     $466 = $465 & $440;
     $467 = HEAP8[$28>>0]|0;
     $468 = $467&255;
     $469 = $466 >>> $468;
     $470 = (($464) + ($469)|0);
     $471 = HEAP8[$29>>0]|0;
     $472 = $471&255;
     $473 = (79212 + ($472<<2)|0);
     $474 = HEAP32[$473>>2]|0;
     $475 = HEAP32[$30>>2]|0;
     $476 = $475 & $440;
     $477 = HEAP8[$31>>0]|0;
     $478 = $477&255;
     $479 = $476 >>> $478;
     $480 = (($474) + ($479)|0);
     $481 = HEAP8[$480>>0]|0;
     $$2636$shrunk = $481;$$2644$shrunk$in = $470;$$2652$shrunk$in = $460;$$2660$shrunk$in = $450;
     label = 23;
     break;
    }
    default: {
     $$2636$shrunk746 = 0;$$2644$shrunk745 = 0;$$2644747 = 0;$$2652$shrunk744 = 0;$$2652748 = 0;$496 = 0;
    }
    }
    if ((label|0) == 23) {
     label = 0;
     $$2644$shrunk = HEAP8[$$2644$shrunk$in>>0]|0;
     $$2652$shrunk = HEAP8[$$2652$shrunk$in>>0]|0;
     $$2660$shrunk = HEAP8[$$2660$shrunk$in>>0]|0;
     $$2644 = $$2644$shrunk&255;
     $$2652 = $$2652$shrunk&255;
     $482 = ($$2660$shrunk<<24>>24)==(0);
     $$2660 = $$2660$shrunk&255;
     $483 = $$2660 << 22;
     $484 = $483 | 3145728;
     $$795 = $482 ? 0 : $484;
     $$2636$shrunk746 = $$2636$shrunk;$$2644$shrunk745 = $$2644$shrunk;$$2644747 = $$2644;$$2652$shrunk744 = $$2652$shrunk;$$2652748 = $$2652;$496 = $$795;
    }
    $485 = ($$2652$shrunk744<<24>>24)==(0);
    $486 = $$2652748 << 12;
    $487 = $486 | 3072;
    $488 = $485 ? 0 : $487;
    $489 = ($$2644$shrunk745<<24>>24)==(0);
    $490 = $$2644747 << 2;
    $491 = $490 | 3;
    $492 = $489 ? 0 : $491;
    $div690 = (($$2636$shrunk746&255) / 85)&-1;
    $493 = $div690&255;
    $494 = $493 << 30;
    $495 = $494 | $496;
    $497 = $495 | $492;
    $498 = $497 | $488;
    HEAP32[$$3678>>2] = $498;
    $499 = ((($$3678)) + 4|0);
    $500 = (($$3670) + ($13)|0);
    $$3 = $$2;$$4671 = $500;$$4679 = $499;
    label = 25;
    continue;
   }
   else if ((label|0) == 25) {
    label = 0;
    switch ($12<<24>>24) {
    case 1:  {
     $501 = HEAP8[$$4671>>0]|0;
     $502 = $501&255;
     $503 = HEAP8[$20>>0]|0;
     $504 = $503&255;
     $505 = (79212 + ($504<<2)|0);
     $506 = HEAP32[$505>>2]|0;
     $507 = HEAP32[$21>>2]|0;
     $508 = $507 & $502;
     $509 = HEAP8[$22>>0]|0;
     $510 = $509&255;
     $511 = $508 >>> $510;
     $512 = (($506) + ($511)|0);
     $513 = HEAP8[$23>>0]|0;
     $514 = $513&255;
     $515 = (79212 + ($514<<2)|0);
     $516 = HEAP32[$515>>2]|0;
     $517 = HEAP32[$24>>2]|0;
     $518 = $517 & $502;
     $519 = HEAP8[$25>>0]|0;
     $520 = $519&255;
     $521 = $518 >>> $520;
     $522 = (($516) + ($521)|0);
     $523 = HEAP8[$26>>0]|0;
     $524 = $523&255;
     $525 = (79212 + ($524<<2)|0);
     $526 = HEAP32[$525>>2]|0;
     $527 = HEAP32[$27>>2]|0;
     $528 = $527 & $502;
     $529 = HEAP8[$28>>0]|0;
     $530 = $529&255;
     $531 = $528 >>> $530;
     $532 = (($526) + ($531)|0);
     $533 = HEAP8[$29>>0]|0;
     $534 = $533&255;
     $535 = (79212 + ($534<<2)|0);
     $536 = HEAP32[$535>>2]|0;
     $537 = HEAP32[$30>>2]|0;
     $538 = $537 & $502;
     $539 = HEAP8[$31>>0]|0;
     $540 = $539&255;
     $541 = $538 >>> $540;
     $542 = (($536) + ($541)|0);
     $543 = HEAP8[$542>>0]|0;
     $$3637$shrunk = $543;$$3645$shrunk$in = $532;$$3653$shrunk$in = $522;$$3661$shrunk$in = $512;
     label = 30;
     break;
    }
    case 2:  {
     $544 = HEAP16[$$4671>>1]|0;
     $545 = $544&65535;
     $546 = HEAP8[$20>>0]|0;
     $547 = $546&255;
     $548 = (79212 + ($547<<2)|0);
     $549 = HEAP32[$548>>2]|0;
     $550 = HEAP32[$21>>2]|0;
     $551 = $550 & $545;
     $552 = HEAP8[$22>>0]|0;
     $553 = $552&255;
     $554 = $551 >>> $553;
     $555 = (($549) + ($554)|0);
     $556 = HEAP8[$23>>0]|0;
     $557 = $556&255;
     $558 = (79212 + ($557<<2)|0);
     $559 = HEAP32[$558>>2]|0;
     $560 = HEAP32[$24>>2]|0;
     $561 = $560 & $545;
     $562 = HEAP8[$25>>0]|0;
     $563 = $562&255;
     $564 = $561 >>> $563;
     $565 = (($559) + ($564)|0);
     $566 = HEAP8[$26>>0]|0;
     $567 = $566&255;
     $568 = (79212 + ($567<<2)|0);
     $569 = HEAP32[$568>>2]|0;
     $570 = HEAP32[$27>>2]|0;
     $571 = $570 & $545;
     $572 = HEAP8[$28>>0]|0;
     $573 = $572&255;
     $574 = $571 >>> $573;
     $575 = (($569) + ($574)|0);
     $576 = HEAP8[$29>>0]|0;
     $577 = $576&255;
     $578 = (79212 + ($577<<2)|0);
     $579 = HEAP32[$578>>2]|0;
     $580 = HEAP32[$30>>2]|0;
     $581 = $580 & $545;
     $582 = HEAP8[$31>>0]|0;
     $583 = $582&255;
     $584 = $581 >>> $583;
     $585 = (($579) + ($584)|0);
     $586 = HEAP8[$585>>0]|0;
     $$3637$shrunk = $586;$$3645$shrunk$in = $575;$$3653$shrunk$in = $565;$$3661$shrunk$in = $555;
     label = 30;
     break;
    }
    case 3:  {
     $587 = HEAP8[$22>>0]|0;
     $div708 = ($587&255) >>> 3;
     $588 = $div708&255;
     $589 = (($$4671) + ($588)|0);
     $590 = HEAP8[$25>>0]|0;
     $div709 = ($590&255) >>> 3;
     $591 = $div709&255;
     $592 = (($$4671) + ($591)|0);
     $593 = HEAP8[$28>>0]|0;
     $div710 = ($593&255) >>> 3;
     $594 = $div710&255;
     $595 = (($$4671) + ($594)|0);
     $$3637$shrunk = -1;$$3645$shrunk$in = $595;$$3653$shrunk$in = $592;$$3661$shrunk$in = $589;
     label = 30;
     break;
    }
    case 4:  {
     $596 = HEAP32[$$4671>>2]|0;
     $597 = HEAP8[$20>>0]|0;
     $598 = $597&255;
     $599 = (79212 + ($598<<2)|0);
     $600 = HEAP32[$599>>2]|0;
     $601 = HEAP32[$21>>2]|0;
     $602 = $601 & $596;
     $603 = HEAP8[$22>>0]|0;
     $604 = $603&255;
     $605 = $602 >>> $604;
     $606 = (($600) + ($605)|0);
     $607 = HEAP8[$23>>0]|0;
     $608 = $607&255;
     $609 = (79212 + ($608<<2)|0);
     $610 = HEAP32[$609>>2]|0;
     $611 = HEAP32[$24>>2]|0;
     $612 = $611 & $596;
     $613 = HEAP8[$25>>0]|0;
     $614 = $613&255;
     $615 = $612 >>> $614;
     $616 = (($610) + ($615)|0);
     $617 = HEAP8[$26>>0]|0;
     $618 = $617&255;
     $619 = (79212 + ($618<<2)|0);
     $620 = HEAP32[$619>>2]|0;
     $621 = HEAP32[$27>>2]|0;
     $622 = $621 & $596;
     $623 = HEAP8[$28>>0]|0;
     $624 = $623&255;
     $625 = $622 >>> $624;
     $626 = (($620) + ($625)|0);
     $627 = HEAP8[$29>>0]|0;
     $628 = $627&255;
     $629 = (79212 + ($628<<2)|0);
     $630 = HEAP32[$629>>2]|0;
     $631 = HEAP32[$30>>2]|0;
     $632 = $631 & $596;
     $633 = HEAP8[$31>>0]|0;
     $634 = $633&255;
     $635 = $632 >>> $634;
     $636 = (($630) + ($635)|0);
     $637 = HEAP8[$636>>0]|0;
     $$3637$shrunk = $637;$$3645$shrunk$in = $626;$$3653$shrunk$in = $616;$$3661$shrunk$in = $606;
     label = 30;
     break;
    }
    default: {
     $$3637$shrunk755 = 0;$$3645$shrunk754 = 0;$$3645756 = 0;$$3653$shrunk753 = 0;$$3653757 = 0;$652 = 0;
    }
    }
    if ((label|0) == 30) {
     label = 0;
     $$3645$shrunk = HEAP8[$$3645$shrunk$in>>0]|0;
     $$3653$shrunk = HEAP8[$$3653$shrunk$in>>0]|0;
     $$3661$shrunk = HEAP8[$$3661$shrunk$in>>0]|0;
     $$3645 = $$3645$shrunk&255;
     $$3653 = $$3653$shrunk&255;
     $638 = ($$3661$shrunk<<24>>24)==(0);
     $$3661 = $$3661$shrunk&255;
     $639 = $$3661 << 22;
     $640 = $639 | 3145728;
     $$796 = $638 ? 0 : $640;
     $$3637$shrunk755 = $$3637$shrunk;$$3645$shrunk754 = $$3645$shrunk;$$3645756 = $$3645;$$3653$shrunk753 = $$3653$shrunk;$$3653757 = $$3653;$652 = $$796;
    }
    $641 = ($$3653$shrunk753<<24>>24)==(0);
    $642 = $$3653757 << 12;
    $643 = $642 | 3072;
    $644 = $641 ? 0 : $643;
    $645 = ($$3645$shrunk754<<24>>24)==(0);
    $646 = $$3645756 << 2;
    $647 = $646 | 3;
    $648 = $645 ? 0 : $647;
    $div692 = (($$3637$shrunk755&255) / 85)&-1;
    $649 = $div692&255;
    $650 = $649 << 30;
    $651 = $650 | $652;
    $653 = $651 | $648;
    $654 = $653 | $644;
    HEAP32[$$4679>>2] = $654;
    $655 = ((($$4679)) + 4|0);
    $656 = (($$4671) + ($13)|0);
    $$4 = $$3;$$5672 = $656;$$5680 = $655;
    label = 32;
    continue;
   }
   else if ((label|0) == 32) {
    label = 0;
    switch ($12<<24>>24) {
    case 1:  {
     $657 = HEAP8[$$5672>>0]|0;
     $658 = $657&255;
     $659 = HEAP8[$20>>0]|0;
     $660 = $659&255;
     $661 = (79212 + ($660<<2)|0);
     $662 = HEAP32[$661>>2]|0;
     $663 = HEAP32[$21>>2]|0;
     $664 = $663 & $658;
     $665 = HEAP8[$22>>0]|0;
     $666 = $665&255;
     $667 = $664 >>> $666;
     $668 = (($662) + ($667)|0);
     $669 = HEAP8[$23>>0]|0;
     $670 = $669&255;
     $671 = (79212 + ($670<<2)|0);
     $672 = HEAP32[$671>>2]|0;
     $673 = HEAP32[$24>>2]|0;
     $674 = $673 & $658;
     $675 = HEAP8[$25>>0]|0;
     $676 = $675&255;
     $677 = $674 >>> $676;
     $678 = (($672) + ($677)|0);
     $679 = HEAP8[$26>>0]|0;
     $680 = $679&255;
     $681 = (79212 + ($680<<2)|0);
     $682 = HEAP32[$681>>2]|0;
     $683 = HEAP32[$27>>2]|0;
     $684 = $683 & $658;
     $685 = HEAP8[$28>>0]|0;
     $686 = $685&255;
     $687 = $684 >>> $686;
     $688 = (($682) + ($687)|0);
     $689 = HEAP8[$29>>0]|0;
     $690 = $689&255;
     $691 = (79212 + ($690<<2)|0);
     $692 = HEAP32[$691>>2]|0;
     $693 = HEAP32[$30>>2]|0;
     $694 = $693 & $658;
     $695 = HEAP8[$31>>0]|0;
     $696 = $695&255;
     $697 = $694 >>> $696;
     $698 = (($692) + ($697)|0);
     $699 = HEAP8[$698>>0]|0;
     $$4638$shrunk = $699;$$4646$shrunk$in = $688;$$4654$shrunk$in = $678;$$4662$shrunk$in = $668;
     label = 37;
     break;
    }
    case 2:  {
     $700 = HEAP16[$$5672>>1]|0;
     $701 = $700&65535;
     $702 = HEAP8[$20>>0]|0;
     $703 = $702&255;
     $704 = (79212 + ($703<<2)|0);
     $705 = HEAP32[$704>>2]|0;
     $706 = HEAP32[$21>>2]|0;
     $707 = $706 & $701;
     $708 = HEAP8[$22>>0]|0;
     $709 = $708&255;
     $710 = $707 >>> $709;
     $711 = (($705) + ($710)|0);
     $712 = HEAP8[$23>>0]|0;
     $713 = $712&255;
     $714 = (79212 + ($713<<2)|0);
     $715 = HEAP32[$714>>2]|0;
     $716 = HEAP32[$24>>2]|0;
     $717 = $716 & $701;
     $718 = HEAP8[$25>>0]|0;
     $719 = $718&255;
     $720 = $717 >>> $719;
     $721 = (($715) + ($720)|0);
     $722 = HEAP8[$26>>0]|0;
     $723 = $722&255;
     $724 = (79212 + ($723<<2)|0);
     $725 = HEAP32[$724>>2]|0;
     $726 = HEAP32[$27>>2]|0;
     $727 = $726 & $701;
     $728 = HEAP8[$28>>0]|0;
     $729 = $728&255;
     $730 = $727 >>> $729;
     $731 = (($725) + ($730)|0);
     $732 = HEAP8[$29>>0]|0;
     $733 = $732&255;
     $734 = (79212 + ($733<<2)|0);
     $735 = HEAP32[$734>>2]|0;
     $736 = HEAP32[$30>>2]|0;
     $737 = $736 & $701;
     $738 = HEAP8[$31>>0]|0;
     $739 = $738&255;
     $740 = $737 >>> $739;
     $741 = (($735) + ($740)|0);
     $742 = HEAP8[$741>>0]|0;
     $$4638$shrunk = $742;$$4646$shrunk$in = $731;$$4654$shrunk$in = $721;$$4662$shrunk$in = $711;
     label = 37;
     break;
    }
    case 3:  {
     $743 = HEAP8[$22>>0]|0;
     $div705 = ($743&255) >>> 3;
     $744 = $div705&255;
     $745 = (($$5672) + ($744)|0);
     $746 = HEAP8[$25>>0]|0;
     $div706 = ($746&255) >>> 3;
     $747 = $div706&255;
     $748 = (($$5672) + ($747)|0);
     $749 = HEAP8[$28>>0]|0;
     $div707 = ($749&255) >>> 3;
     $750 = $div707&255;
     $751 = (($$5672) + ($750)|0);
     $$4638$shrunk = -1;$$4646$shrunk$in = $751;$$4654$shrunk$in = $748;$$4662$shrunk$in = $745;
     label = 37;
     break;
    }
    case 4:  {
     $752 = HEAP32[$$5672>>2]|0;
     $753 = HEAP8[$20>>0]|0;
     $754 = $753&255;
     $755 = (79212 + ($754<<2)|0);
     $756 = HEAP32[$755>>2]|0;
     $757 = HEAP32[$21>>2]|0;
     $758 = $757 & $752;
     $759 = HEAP8[$22>>0]|0;
     $760 = $759&255;
     $761 = $758 >>> $760;
     $762 = (($756) + ($761)|0);
     $763 = HEAP8[$23>>0]|0;
     $764 = $763&255;
     $765 = (79212 + ($764<<2)|0);
     $766 = HEAP32[$765>>2]|0;
     $767 = HEAP32[$24>>2]|0;
     $768 = $767 & $752;
     $769 = HEAP8[$25>>0]|0;
     $770 = $769&255;
     $771 = $768 >>> $770;
     $772 = (($766) + ($771)|0);
     $773 = HEAP8[$26>>0]|0;
     $774 = $773&255;
     $775 = (79212 + ($774<<2)|0);
     $776 = HEAP32[$775>>2]|0;
     $777 = HEAP32[$27>>2]|0;
     $778 = $777 & $752;
     $779 = HEAP8[$28>>0]|0;
     $780 = $779&255;
     $781 = $778 >>> $780;
     $782 = (($776) + ($781)|0);
     $783 = HEAP8[$29>>0]|0;
     $784 = $783&255;
     $785 = (79212 + ($784<<2)|0);
     $786 = HEAP32[$785>>2]|0;
     $787 = HEAP32[$30>>2]|0;
     $788 = $787 & $752;
     $789 = HEAP8[$31>>0]|0;
     $790 = $789&255;
     $791 = $788 >>> $790;
     $792 = (($786) + ($791)|0);
     $793 = HEAP8[$792>>0]|0;
     $$4638$shrunk = $793;$$4646$shrunk$in = $782;$$4654$shrunk$in = $772;$$4662$shrunk$in = $762;
     label = 37;
     break;
    }
    default: {
     $$4638$shrunk764 = 0;$$4646$shrunk763 = 0;$$4646765 = 0;$$4654$shrunk762 = 0;$$4654766 = 0;$808 = 0;
    }
    }
    if ((label|0) == 37) {
     label = 0;
     $$4646$shrunk = HEAP8[$$4646$shrunk$in>>0]|0;
     $$4654$shrunk = HEAP8[$$4654$shrunk$in>>0]|0;
     $$4662$shrunk = HEAP8[$$4662$shrunk$in>>0]|0;
     $$4646 = $$4646$shrunk&255;
     $$4654 = $$4654$shrunk&255;
     $794 = ($$4662$shrunk<<24>>24)==(0);
     $$4662 = $$4662$shrunk&255;
     $795 = $$4662 << 22;
     $796 = $795 | 3145728;
     $$797 = $794 ? 0 : $796;
     $$4638$shrunk764 = $$4638$shrunk;$$4646$shrunk763 = $$4646$shrunk;$$4646765 = $$4646;$$4654$shrunk762 = $$4654$shrunk;$$4654766 = $$4654;$808 = $$797;
    }
    $797 = ($$4654$shrunk762<<24>>24)==(0);
    $798 = $$4654766 << 12;
    $799 = $798 | 3072;
    $800 = $797 ? 0 : $799;
    $801 = ($$4646$shrunk763<<24>>24)==(0);
    $802 = $$4646765 << 2;
    $803 = $802 | 3;
    $804 = $801 ? 0 : $803;
    $div694 = (($$4638$shrunk764&255) / 85)&-1;
    $805 = $div694&255;
    $806 = $805 << 30;
    $807 = $806 | $808;
    $809 = $807 | $804;
    $810 = $809 | $800;
    HEAP32[$$5680>>2] = $810;
    $811 = ((($$5680)) + 4|0);
    $812 = (($$5672) + ($13)|0);
    $$5 = $$4;$$6673 = $812;$$6681 = $811;
    label = 39;
    continue;
   }
   else if ((label|0) == 39) {
    label = 0;
    switch ($12<<24>>24) {
    case 1:  {
     $813 = HEAP8[$$6673>>0]|0;
     $814 = $813&255;
     $815 = HEAP8[$20>>0]|0;
     $816 = $815&255;
     $817 = (79212 + ($816<<2)|0);
     $818 = HEAP32[$817>>2]|0;
     $819 = HEAP32[$21>>2]|0;
     $820 = $819 & $814;
     $821 = HEAP8[$22>>0]|0;
     $822 = $821&255;
     $823 = $820 >>> $822;
     $824 = (($818) + ($823)|0);
     $825 = HEAP8[$23>>0]|0;
     $826 = $825&255;
     $827 = (79212 + ($826<<2)|0);
     $828 = HEAP32[$827>>2]|0;
     $829 = HEAP32[$24>>2]|0;
     $830 = $829 & $814;
     $831 = HEAP8[$25>>0]|0;
     $832 = $831&255;
     $833 = $830 >>> $832;
     $834 = (($828) + ($833)|0);
     $835 = HEAP8[$26>>0]|0;
     $836 = $835&255;
     $837 = (79212 + ($836<<2)|0);
     $838 = HEAP32[$837>>2]|0;
     $839 = HEAP32[$27>>2]|0;
     $840 = $839 & $814;
     $841 = HEAP8[$28>>0]|0;
     $842 = $841&255;
     $843 = $840 >>> $842;
     $844 = (($838) + ($843)|0);
     $845 = HEAP8[$29>>0]|0;
     $846 = $845&255;
     $847 = (79212 + ($846<<2)|0);
     $848 = HEAP32[$847>>2]|0;
     $849 = HEAP32[$30>>2]|0;
     $850 = $849 & $814;
     $851 = HEAP8[$31>>0]|0;
     $852 = $851&255;
     $853 = $850 >>> $852;
     $854 = (($848) + ($853)|0);
     $855 = HEAP8[$854>>0]|0;
     $$5639$shrunk = $855;$$5647$shrunk$in = $844;$$5655$shrunk$in = $834;$$5663$shrunk$in = $824;
     label = 44;
     break;
    }
    case 2:  {
     $856 = HEAP16[$$6673>>1]|0;
     $857 = $856&65535;
     $858 = HEAP8[$20>>0]|0;
     $859 = $858&255;
     $860 = (79212 + ($859<<2)|0);
     $861 = HEAP32[$860>>2]|0;
     $862 = HEAP32[$21>>2]|0;
     $863 = $862 & $857;
     $864 = HEAP8[$22>>0]|0;
     $865 = $864&255;
     $866 = $863 >>> $865;
     $867 = (($861) + ($866)|0);
     $868 = HEAP8[$23>>0]|0;
     $869 = $868&255;
     $870 = (79212 + ($869<<2)|0);
     $871 = HEAP32[$870>>2]|0;
     $872 = HEAP32[$24>>2]|0;
     $873 = $872 & $857;
     $874 = HEAP8[$25>>0]|0;
     $875 = $874&255;
     $876 = $873 >>> $875;
     $877 = (($871) + ($876)|0);
     $878 = HEAP8[$26>>0]|0;
     $879 = $878&255;
     $880 = (79212 + ($879<<2)|0);
     $881 = HEAP32[$880>>2]|0;
     $882 = HEAP32[$27>>2]|0;
     $883 = $882 & $857;
     $884 = HEAP8[$28>>0]|0;
     $885 = $884&255;
     $886 = $883 >>> $885;
     $887 = (($881) + ($886)|0);
     $888 = HEAP8[$29>>0]|0;
     $889 = $888&255;
     $890 = (79212 + ($889<<2)|0);
     $891 = HEAP32[$890>>2]|0;
     $892 = HEAP32[$30>>2]|0;
     $893 = $892 & $857;
     $894 = HEAP8[$31>>0]|0;
     $895 = $894&255;
     $896 = $893 >>> $895;
     $897 = (($891) + ($896)|0);
     $898 = HEAP8[$897>>0]|0;
     $$5639$shrunk = $898;$$5647$shrunk$in = $887;$$5655$shrunk$in = $877;$$5663$shrunk$in = $867;
     label = 44;
     break;
    }
    case 3:  {
     $899 = HEAP8[$22>>0]|0;
     $div702 = ($899&255) >>> 3;
     $900 = $div702&255;
     $901 = (($$6673) + ($900)|0);
     $902 = HEAP8[$25>>0]|0;
     $div703 = ($902&255) >>> 3;
     $903 = $div703&255;
     $904 = (($$6673) + ($903)|0);
     $905 = HEAP8[$28>>0]|0;
     $div704 = ($905&255) >>> 3;
     $906 = $div704&255;
     $907 = (($$6673) + ($906)|0);
     $$5639$shrunk = -1;$$5647$shrunk$in = $907;$$5655$shrunk$in = $904;$$5663$shrunk$in = $901;
     label = 44;
     break;
    }
    case 4:  {
     $908 = HEAP32[$$6673>>2]|0;
     $909 = HEAP8[$20>>0]|0;
     $910 = $909&255;
     $911 = (79212 + ($910<<2)|0);
     $912 = HEAP32[$911>>2]|0;
     $913 = HEAP32[$21>>2]|0;
     $914 = $913 & $908;
     $915 = HEAP8[$22>>0]|0;
     $916 = $915&255;
     $917 = $914 >>> $916;
     $918 = (($912) + ($917)|0);
     $919 = HEAP8[$23>>0]|0;
     $920 = $919&255;
     $921 = (79212 + ($920<<2)|0);
     $922 = HEAP32[$921>>2]|0;
     $923 = HEAP32[$24>>2]|0;
     $924 = $923 & $908;
     $925 = HEAP8[$25>>0]|0;
     $926 = $925&255;
     $927 = $924 >>> $926;
     $928 = (($922) + ($927)|0);
     $929 = HEAP8[$26>>0]|0;
     $930 = $929&255;
     $931 = (79212 + ($930<<2)|0);
     $932 = HEAP32[$931>>2]|0;
     $933 = HEAP32[$27>>2]|0;
     $934 = $933 & $908;
     $935 = HEAP8[$28>>0]|0;
     $936 = $935&255;
     $937 = $934 >>> $936;
     $938 = (($932) + ($937)|0);
     $939 = HEAP8[$29>>0]|0;
     $940 = $939&255;
     $941 = (79212 + ($940<<2)|0);
     $942 = HEAP32[$941>>2]|0;
     $943 = HEAP32[$30>>2]|0;
     $944 = $943 & $908;
     $945 = HEAP8[$31>>0]|0;
     $946 = $945&255;
     $947 = $944 >>> $946;
     $948 = (($942) + ($947)|0);
     $949 = HEAP8[$948>>0]|0;
     $$5639$shrunk = $949;$$5647$shrunk$in = $938;$$5655$shrunk$in = $928;$$5663$shrunk$in = $918;
     label = 44;
     break;
    }
    default: {
     $$5639$shrunk773 = 0;$$5647$shrunk772 = 0;$$5647774 = 0;$$5655$shrunk771 = 0;$$5655775 = 0;$964 = 0;
    }
    }
    if ((label|0) == 44) {
     label = 0;
     $$5647$shrunk = HEAP8[$$5647$shrunk$in>>0]|0;
     $$5655$shrunk = HEAP8[$$5655$shrunk$in>>0]|0;
     $$5663$shrunk = HEAP8[$$5663$shrunk$in>>0]|0;
     $$5647 = $$5647$shrunk&255;
     $$5655 = $$5655$shrunk&255;
     $950 = ($$5663$shrunk<<24>>24)==(0);
     $$5663 = $$5663$shrunk&255;
     $951 = $$5663 << 22;
     $952 = $951 | 3145728;
     $$798 = $950 ? 0 : $952;
     $$5639$shrunk773 = $$5639$shrunk;$$5647$shrunk772 = $$5647$shrunk;$$5647774 = $$5647;$$5655$shrunk771 = $$5655$shrunk;$$5655775 = $$5655;$964 = $$798;
    }
    $953 = ($$5655$shrunk771<<24>>24)==(0);
    $954 = $$5655775 << 12;
    $955 = $954 | 3072;
    $956 = $953 ? 0 : $955;
    $957 = ($$5647$shrunk772<<24>>24)==(0);
    $958 = $$5647774 << 2;
    $959 = $958 | 3;
    $960 = $957 ? 0 : $959;
    $div696 = (($$5639$shrunk773&255) / 85)&-1;
    $961 = $div696&255;
    $962 = $961 << 30;
    $963 = $962 | $964;
    $965 = $963 | $960;
    $966 = $965 | $956;
    HEAP32[$$6681>>2] = $966;
    $967 = ((($$6681)) + 4|0);
    $968 = (($$6673) + ($13)|0);
    $$6 = $$5;$$7674 = $968;$$7682 = $967;
    label = 46;
    continue;
   }
   else if ((label|0) == 46) {
    label = 0;
    switch ($12<<24>>24) {
    case 1:  {
     $969 = HEAP8[$$7674>>0]|0;
     $970 = $969&255;
     $971 = HEAP8[$20>>0]|0;
     $972 = $971&255;
     $973 = (79212 + ($972<<2)|0);
     $974 = HEAP32[$973>>2]|0;
     $975 = HEAP32[$21>>2]|0;
     $976 = $975 & $970;
     $977 = HEAP8[$22>>0]|0;
     $978 = $977&255;
     $979 = $976 >>> $978;
     $980 = (($974) + ($979)|0);
     $981 = HEAP8[$23>>0]|0;
     $982 = $981&255;
     $983 = (79212 + ($982<<2)|0);
     $984 = HEAP32[$983>>2]|0;
     $985 = HEAP32[$24>>2]|0;
     $986 = $985 & $970;
     $987 = HEAP8[$25>>0]|0;
     $988 = $987&255;
     $989 = $986 >>> $988;
     $990 = (($984) + ($989)|0);
     $991 = HEAP8[$26>>0]|0;
     $992 = $991&255;
     $993 = (79212 + ($992<<2)|0);
     $994 = HEAP32[$993>>2]|0;
     $995 = HEAP32[$27>>2]|0;
     $996 = $995 & $970;
     $997 = HEAP8[$28>>0]|0;
     $998 = $997&255;
     $999 = $996 >>> $998;
     $1000 = (($994) + ($999)|0);
     $1001 = HEAP8[$29>>0]|0;
     $1002 = $1001&255;
     $1003 = (79212 + ($1002<<2)|0);
     $1004 = HEAP32[$1003>>2]|0;
     $1005 = HEAP32[$30>>2]|0;
     $1006 = $1005 & $970;
     $1007 = HEAP8[$31>>0]|0;
     $1008 = $1007&255;
     $1009 = $1006 >>> $1008;
     $1010 = (($1004) + ($1009)|0);
     $1011 = HEAP8[$1010>>0]|0;
     $$6640$shrunk = $1011;$$6648$shrunk$in = $1000;$$6656$shrunk$in = $990;$$6664$shrunk$in = $980;
     label = 51;
     break;
    }
    case 2:  {
     $1012 = HEAP16[$$7674>>1]|0;
     $1013 = $1012&65535;
     $1014 = HEAP8[$20>>0]|0;
     $1015 = $1014&255;
     $1016 = (79212 + ($1015<<2)|0);
     $1017 = HEAP32[$1016>>2]|0;
     $1018 = HEAP32[$21>>2]|0;
     $1019 = $1018 & $1013;
     $1020 = HEAP8[$22>>0]|0;
     $1021 = $1020&255;
     $1022 = $1019 >>> $1021;
     $1023 = (($1017) + ($1022)|0);
     $1024 = HEAP8[$23>>0]|0;
     $1025 = $1024&255;
     $1026 = (79212 + ($1025<<2)|0);
     $1027 = HEAP32[$1026>>2]|0;
     $1028 = HEAP32[$24>>2]|0;
     $1029 = $1028 & $1013;
     $1030 = HEAP8[$25>>0]|0;
     $1031 = $1030&255;
     $1032 = $1029 >>> $1031;
     $1033 = (($1027) + ($1032)|0);
     $1034 = HEAP8[$26>>0]|0;
     $1035 = $1034&255;
     $1036 = (79212 + ($1035<<2)|0);
     $1037 = HEAP32[$1036>>2]|0;
     $1038 = HEAP32[$27>>2]|0;
     $1039 = $1038 & $1013;
     $1040 = HEAP8[$28>>0]|0;
     $1041 = $1040&255;
     $1042 = $1039 >>> $1041;
     $1043 = (($1037) + ($1042)|0);
     $1044 = HEAP8[$29>>0]|0;
     $1045 = $1044&255;
     $1046 = (79212 + ($1045<<2)|0);
     $1047 = HEAP32[$1046>>2]|0;
     $1048 = HEAP32[$30>>2]|0;
     $1049 = $1048 & $1013;
     $1050 = HEAP8[$31>>0]|0;
     $1051 = $1050&255;
     $1052 = $1049 >>> $1051;
     $1053 = (($1047) + ($1052)|0);
     $1054 = HEAP8[$1053>>0]|0;
     $$6640$shrunk = $1054;$$6648$shrunk$in = $1043;$$6656$shrunk$in = $1033;$$6664$shrunk$in = $1023;
     label = 51;
     break;
    }
    case 3:  {
     $1055 = HEAP8[$22>>0]|0;
     $div699 = ($1055&255) >>> 3;
     $1056 = $div699&255;
     $1057 = (($$7674) + ($1056)|0);
     $1058 = HEAP8[$25>>0]|0;
     $div700 = ($1058&255) >>> 3;
     $1059 = $div700&255;
     $1060 = (($$7674) + ($1059)|0);
     $1061 = HEAP8[$28>>0]|0;
     $div701 = ($1061&255) >>> 3;
     $1062 = $div701&255;
     $1063 = (($$7674) + ($1062)|0);
     $$6640$shrunk = -1;$$6648$shrunk$in = $1063;$$6656$shrunk$in = $1060;$$6664$shrunk$in = $1057;
     label = 51;
     break;
    }
    case 4:  {
     $1064 = HEAP32[$$7674>>2]|0;
     $1065 = HEAP8[$20>>0]|0;
     $1066 = $1065&255;
     $1067 = (79212 + ($1066<<2)|0);
     $1068 = HEAP32[$1067>>2]|0;
     $1069 = HEAP32[$21>>2]|0;
     $1070 = $1069 & $1064;
     $1071 = HEAP8[$22>>0]|0;
     $1072 = $1071&255;
     $1073 = $1070 >>> $1072;
     $1074 = (($1068) + ($1073)|0);
     $1075 = HEAP8[$23>>0]|0;
     $1076 = $1075&255;
     $1077 = (79212 + ($1076<<2)|0);
     $1078 = HEAP32[$1077>>2]|0;
     $1079 = HEAP32[$24>>2]|0;
     $1080 = $1079 & $1064;
     $1081 = HEAP8[$25>>0]|0;
     $1082 = $1081&255;
     $1083 = $1080 >>> $1082;
     $1084 = (($1078) + ($1083)|0);
     $1085 = HEAP8[$26>>0]|0;
     $1086 = $1085&255;
     $1087 = (79212 + ($1086<<2)|0);
     $1088 = HEAP32[$1087>>2]|0;
     $1089 = HEAP32[$27>>2]|0;
     $1090 = $1089 & $1064;
     $1091 = HEAP8[$28>>0]|0;
     $1092 = $1091&255;
     $1093 = $1090 >>> $1092;
     $1094 = (($1088) + ($1093)|0);
     $1095 = HEAP8[$29>>0]|0;
     $1096 = $1095&255;
     $1097 = (79212 + ($1096<<2)|0);
     $1098 = HEAP32[$1097>>2]|0;
     $1099 = HEAP32[$30>>2]|0;
     $1100 = $1099 & $1064;
     $1101 = HEAP8[$31>>0]|0;
     $1102 = $1101&255;
     $1103 = $1100 >>> $1102;
     $1104 = (($1098) + ($1103)|0);
     $1105 = HEAP8[$1104>>0]|0;
     $$6640$shrunk = $1105;$$6648$shrunk$in = $1094;$$6656$shrunk$in = $1084;$$6664$shrunk$in = $1074;
     label = 51;
     break;
    }
    default: {
     $$6640$shrunk782 = 0;$$6648$shrunk781 = 0;$$6648783 = 0;$$6656$shrunk780 = 0;$$6656784 = 0;$1120 = 0;
    }
    }
    if ((label|0) == 51) {
     label = 0;
     $$6648$shrunk = HEAP8[$$6648$shrunk$in>>0]|0;
     $$6656$shrunk = HEAP8[$$6656$shrunk$in>>0]|0;
     $$6664$shrunk = HEAP8[$$6664$shrunk$in>>0]|0;
     $$6648 = $$6648$shrunk&255;
     $$6656 = $$6656$shrunk&255;
     $1106 = ($$6664$shrunk<<24>>24)==(0);
     $$6664 = $$6664$shrunk&255;
     $1107 = $$6664 << 22;
     $1108 = $1107 | 3145728;
     $$799 = $1106 ? 0 : $1108;
     $$6640$shrunk782 = $$6640$shrunk;$$6648$shrunk781 = $$6648$shrunk;$$6648783 = $$6648;$$6656$shrunk780 = $$6656$shrunk;$$6656784 = $$6656;$1120 = $$799;
    }
    $1109 = ($$6656$shrunk780<<24>>24)==(0);
    $1110 = $$6656784 << 12;
    $1111 = $1110 | 3072;
    $1112 = $1109 ? 0 : $1111;
    $1113 = ($$6648$shrunk781<<24>>24)==(0);
    $1114 = $$6648783 << 2;
    $1115 = $1114 | 3;
    $1116 = $1113 ? 0 : $1115;
    $div698 = (($$6640$shrunk782&255) / 85)&-1;
    $1117 = $div698&255;
    $1118 = $1117 << 30;
    $1119 = $1118 | $1120;
    $1121 = $1119 | $1116;
    $1122 = $1121 | $1112;
    HEAP32[$$7682>>2] = $1122;
    $1123 = ((($$7682)) + 4|0);
    $1124 = (($$7674) + ($13)|0);
    $$7 = $$6;$$8 = $1124;$$8683 = $1123;
    label = 53;
    continue;
   }
   else if ((label|0) == 53) {
    label = 0;
    switch ($12<<24>>24) {
    case 1:  {
     $1125 = HEAP8[$$8>>0]|0;
     $1126 = $1125&255;
     $1127 = HEAP8[$20>>0]|0;
     $1128 = $1127&255;
     $1129 = (79212 + ($1128<<2)|0);
     $1130 = HEAP32[$1129>>2]|0;
     $1131 = HEAP32[$21>>2]|0;
     $1132 = $1131 & $1126;
     $1133 = HEAP8[$22>>0]|0;
     $1134 = $1133&255;
     $1135 = $1132 >>> $1134;
     $1136 = (($1130) + ($1135)|0);
     $1137 = HEAP8[$23>>0]|0;
     $1138 = $1137&255;
     $1139 = (79212 + ($1138<<2)|0);
     $1140 = HEAP32[$1139>>2]|0;
     $1141 = HEAP32[$24>>2]|0;
     $1142 = $1141 & $1126;
     $1143 = HEAP8[$25>>0]|0;
     $1144 = $1143&255;
     $1145 = $1142 >>> $1144;
     $1146 = (($1140) + ($1145)|0);
     $1147 = HEAP8[$26>>0]|0;
     $1148 = $1147&255;
     $1149 = (79212 + ($1148<<2)|0);
     $1150 = HEAP32[$1149>>2]|0;
     $1151 = HEAP32[$27>>2]|0;
     $1152 = $1151 & $1126;
     $1153 = HEAP8[$28>>0]|0;
     $1154 = $1153&255;
     $1155 = $1152 >>> $1154;
     $1156 = (($1150) + ($1155)|0);
     $1157 = HEAP8[$29>>0]|0;
     $1158 = $1157&255;
     $1159 = (79212 + ($1158<<2)|0);
     $1160 = HEAP32[$1159>>2]|0;
     $1161 = HEAP32[$30>>2]|0;
     $1162 = $1161 & $1126;
     $1163 = HEAP8[$31>>0]|0;
     $1164 = $1163&255;
     $1165 = $1162 >>> $1164;
     $1166 = (($1160) + ($1165)|0);
     $1167 = HEAP8[$1166>>0]|0;
     $$7641$shrunk = $1167;$$7649$shrunk$in = $1156;$$7657$shrunk$in = $1146;$$7665$shrunk$in = $1136;
     label = 58;
     break;
    }
    case 2:  {
     $1168 = HEAP16[$$8>>1]|0;
     $1169 = $1168&65535;
     $1170 = HEAP8[$20>>0]|0;
     $1171 = $1170&255;
     $1172 = (79212 + ($1171<<2)|0);
     $1173 = HEAP32[$1172>>2]|0;
     $1174 = HEAP32[$21>>2]|0;
     $1175 = $1174 & $1169;
     $1176 = HEAP8[$22>>0]|0;
     $1177 = $1176&255;
     $1178 = $1175 >>> $1177;
     $1179 = (($1173) + ($1178)|0);
     $1180 = HEAP8[$23>>0]|0;
     $1181 = $1180&255;
     $1182 = (79212 + ($1181<<2)|0);
     $1183 = HEAP32[$1182>>2]|0;
     $1184 = HEAP32[$24>>2]|0;
     $1185 = $1184 & $1169;
     $1186 = HEAP8[$25>>0]|0;
     $1187 = $1186&255;
     $1188 = $1185 >>> $1187;
     $1189 = (($1183) + ($1188)|0);
     $1190 = HEAP8[$26>>0]|0;
     $1191 = $1190&255;
     $1192 = (79212 + ($1191<<2)|0);
     $1193 = HEAP32[$1192>>2]|0;
     $1194 = HEAP32[$27>>2]|0;
     $1195 = $1194 & $1169;
     $1196 = HEAP8[$28>>0]|0;
     $1197 = $1196&255;
     $1198 = $1195 >>> $1197;
     $1199 = (($1193) + ($1198)|0);
     $1200 = HEAP8[$29>>0]|0;
     $1201 = $1200&255;
     $1202 = (79212 + ($1201<<2)|0);
     $1203 = HEAP32[$1202>>2]|0;
     $1204 = HEAP32[$30>>2]|0;
     $1205 = $1204 & $1169;
     $1206 = HEAP8[$31>>0]|0;
     $1207 = $1206&255;
     $1208 = $1205 >>> $1207;
     $1209 = (($1203) + ($1208)|0);
     $1210 = HEAP8[$1209>>0]|0;
     $$7641$shrunk = $1210;$$7649$shrunk$in = $1199;$$7657$shrunk$in = $1189;$$7665$shrunk$in = $1179;
     label = 58;
     break;
    }
    case 3:  {
     $1211 = HEAP8[$22>>0]|0;
     $div720 = ($1211&255) >>> 3;
     $1212 = $div720&255;
     $1213 = (($$8) + ($1212)|0);
     $1214 = HEAP8[$25>>0]|0;
     $div721 = ($1214&255) >>> 3;
     $1215 = $div721&255;
     $1216 = (($$8) + ($1215)|0);
     $1217 = HEAP8[$28>>0]|0;
     $div722 = ($1217&255) >>> 3;
     $1218 = $div722&255;
     $1219 = (($$8) + ($1218)|0);
     $$7641$shrunk = -1;$$7649$shrunk$in = $1219;$$7657$shrunk$in = $1216;$$7665$shrunk$in = $1213;
     label = 58;
     break;
    }
    case 4:  {
     $1220 = HEAP32[$$8>>2]|0;
     $1221 = HEAP8[$20>>0]|0;
     $1222 = $1221&255;
     $1223 = (79212 + ($1222<<2)|0);
     $1224 = HEAP32[$1223>>2]|0;
     $1225 = HEAP32[$21>>2]|0;
     $1226 = $1225 & $1220;
     $1227 = HEAP8[$22>>0]|0;
     $1228 = $1227&255;
     $1229 = $1226 >>> $1228;
     $1230 = (($1224) + ($1229)|0);
     $1231 = HEAP8[$23>>0]|0;
     $1232 = $1231&255;
     $1233 = (79212 + ($1232<<2)|0);
     $1234 = HEAP32[$1233>>2]|0;
     $1235 = HEAP32[$24>>2]|0;
     $1236 = $1235 & $1220;
     $1237 = HEAP8[$25>>0]|0;
     $1238 = $1237&255;
     $1239 = $1236 >>> $1238;
     $1240 = (($1234) + ($1239)|0);
     $1241 = HEAP8[$26>>0]|0;
     $1242 = $1241&255;
     $1243 = (79212 + ($1242<<2)|0);
     $1244 = HEAP32[$1243>>2]|0;
     $1245 = HEAP32[$27>>2]|0;
     $1246 = $1245 & $1220;
     $1247 = HEAP8[$28>>0]|0;
     $1248 = $1247&255;
     $1249 = $1246 >>> $1248;
     $1250 = (($1244) + ($1249)|0);
     $1251 = HEAP8[$29>>0]|0;
     $1252 = $1251&255;
     $1253 = (79212 + ($1252<<2)|0);
     $1254 = HEAP32[$1253>>2]|0;
     $1255 = HEAP32[$30>>2]|0;
     $1256 = $1255 & $1220;
     $1257 = HEAP8[$31>>0]|0;
     $1258 = $1257&255;
     $1259 = $1256 >>> $1258;
     $1260 = (($1254) + ($1259)|0);
     $1261 = HEAP8[$1260>>0]|0;
     $$7641$shrunk = $1261;$$7649$shrunk$in = $1250;$$7657$shrunk$in = $1240;$$7665$shrunk$in = $1230;
     label = 58;
     break;
    }
    default: {
     $$7641$shrunk791 = 0;$$7649$shrunk790 = 0;$$7649792 = 0;$$7657$shrunk789 = 0;$$7657793 = 0;$1276 = 0;
    }
    }
    if ((label|0) == 58) {
     label = 0;
     $$7649$shrunk = HEAP8[$$7649$shrunk$in>>0]|0;
     $$7657$shrunk = HEAP8[$$7657$shrunk$in>>0]|0;
     $$7665$shrunk = HEAP8[$$7665$shrunk$in>>0]|0;
     $$7649 = $$7649$shrunk&255;
     $$7657 = $$7657$shrunk&255;
     $1262 = ($$7665$shrunk<<24>>24)==(0);
     $$7665 = $$7665$shrunk&255;
     $1263 = $$7665 << 22;
     $1264 = $1263 | 3145728;
     $$800 = $1262 ? 0 : $1264;
     $$7641$shrunk791 = $$7641$shrunk;$$7649$shrunk790 = $$7649$shrunk;$$7649792 = $$7649;$$7657$shrunk789 = $$7657$shrunk;$$7657793 = $$7657;$1276 = $$800;
    }
    $1265 = ($$7657$shrunk789<<24>>24)==(0);
    $1266 = $$7657793 << 12;
    $1267 = $1266 | 3072;
    $1268 = $1265 ? 0 : $1267;
    $1269 = ($$7649$shrunk790<<24>>24)==(0);
    $1270 = $$7649792 << 2;
    $1271 = $1270 | 3;
    $1272 = $1269 ? 0 : $1271;
    $div = (($$7641$shrunk791&255) / 85)&-1;
    $1273 = $div&255;
    $1274 = $1273 << 30;
    $1275 = $1274 | $1276;
    $1277 = $1275 | $1272;
    $1278 = $1277 | $1268;
    HEAP32[$$8683>>2] = $1278;
    $1279 = ((($$8683)) + 4|0);
    $1280 = (($$8) + ($13)|0);
    $1281 = (($$7) + -1)|0;
    $1282 = ($$7|0)>(1);
    if ($1282) {
     $$0 = $1281;$$1668 = $1280;$$1676 = $1279;
     label = 4;
     continue;
    } else {
     break;
    }
   }
  }
  $1283 = (($1280) + ($6)|0);
  $1284 = (($1279) + ($8)|0);
  $1285 = ($32|0)==(0);
  if ($1285) {
   label = 62;
   break;
  } else {
   $$0667802 = $1283;$$0675801 = $1284;$$in = $32;
  }
 }
 if ((label|0) == 60) {
  // unreachable;
 }
 else if ((label|0) == 62) {
  return;
 }
}
function _Blit4to4MaskAlpha($0) {
 $0 = $0|0;
 var $$0$us = 0, $$0135$us = 0, $$0143202 = 0, $$0143202$us = 0, $$0143202$us208 = 0, $$0151201 = 0, $$0151201$us = 0, $$0151201$us209 = 0, $$1$us180 = 0, $$10$us = 0, $$10161$us = 0, $$11$us179 = 0, $$11162$us178 = 0, $$1136$us215 = 0, $$1144$us = 0, $$1152$us = 0, $$12 = 0, $$12163 = 0, $$13 = 0, $$13164 = 0;
 var $$14 = 0, $$14165 = 0, $$15 = 0, $$15166 = 0, $$16 = 0, $$16167 = 0, $$17 = 0, $$17168 = 0, $$2 = 0, $$2137 = 0, $$2145$us214 = 0, $$2153$us213 = 0, $$3 = 0, $$3138 = 0, $$3146 = 0, $$3154 = 0, $$4 = 0, $$4139 = 0, $$4147 = 0, $$4155 = 0;
 var $$5 = 0, $$5140 = 0, $$5148 = 0, $$5156 = 0, $$6 = 0, $$6141 = 0, $$6149 = 0, $$6157 = 0, $$7 = 0, $$7142 = 0, $$7150 = 0, $$7158 = 0, $$8 = 0, $$8159 = 0, $$9160171 = 0, $$9160171$us = 0, $$9160171$us174 = 0, $$9172 = 0, $$9172$us = 0, $$9172$us173 = 0;
 var $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0;
 var $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0;
 var $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0;
 var $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0;
 var $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0;
 var $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0;
 var $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0;
 var $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0;
 var $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0;
 var $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $trunc = 0;
 var $trunc$clear = 0, $trunc$clear2 = 0, $trunc169 = 0, $trunc169$clear = 0, $trunc169$clear1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$0>>2]|0;
 $6 = ((($0)) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($0)) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($0)) + 36|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($0)) + 40|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($0)) + 44|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ((($15)) + 24|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==(0);
 if ($18) {
  $151 = ((($13)) + 12|0);
  $152 = HEAP32[$151>>2]|0;
  $153 = ((($13)) + 16|0);
  $154 = HEAP32[$153>>2]|0;
  $155 = $154 | $152;
  $156 = ((($13)) + 20|0);
  $157 = HEAP32[$156>>2]|0;
  $158 = $155 | $157;
  $159 = (($4) + -1)|0;
  $160 = ($4|0)==(0);
  if ($160) {
   return;
  }
  $161 = (($2) + 7)|0;
  $162 = (($161|0) / 8)&-1;
  $trunc = $2&255;
  $trunc$clear = $trunc & 7;
  switch ($trunc$clear<<24>>24) {
  case 0:  {
   $$9160171$us = $9;$$9172$us = $5;$200 = $159;
   while(1) {
    $$0$us = $162;$$10$us = $$9172$us;$$10161$us = $$9160171$us;
    while(1) {
     $163 = HEAP32[$$10$us>>2]|0;
     $164 = $163 & $158;
     HEAP32[$$10161$us>>2] = $164;
     $165 = ((($$10161$us)) + 4|0);
     $166 = ((($$10$us)) + 4|0);
     $167 = HEAP32[$166>>2]|0;
     $168 = $167 & $158;
     HEAP32[$165>>2] = $168;
     $169 = ((($$10161$us)) + 8|0);
     $170 = ((($$10$us)) + 8|0);
     $171 = HEAP32[$170>>2]|0;
     $172 = $171 & $158;
     HEAP32[$169>>2] = $172;
     $173 = ((($$10161$us)) + 12|0);
     $174 = ((($$10$us)) + 12|0);
     $175 = HEAP32[$174>>2]|0;
     $176 = $175 & $158;
     HEAP32[$173>>2] = $176;
     $177 = ((($$10161$us)) + 16|0);
     $178 = ((($$10$us)) + 16|0);
     $179 = HEAP32[$178>>2]|0;
     $180 = $179 & $158;
     HEAP32[$177>>2] = $180;
     $181 = ((($$10161$us)) + 20|0);
     $182 = ((($$10$us)) + 20|0);
     $183 = HEAP32[$182>>2]|0;
     $184 = $183 & $158;
     HEAP32[$181>>2] = $184;
     $185 = ((($$10161$us)) + 24|0);
     $186 = ((($$10$us)) + 24|0);
     $187 = HEAP32[$186>>2]|0;
     $188 = $187 & $158;
     HEAP32[$185>>2] = $188;
     $189 = ((($$10161$us)) + 28|0);
     $190 = ((($$10$us)) + 28|0);
     $191 = HEAP32[$190>>2]|0;
     $192 = $191 & $158;
     HEAP32[$189>>2] = $192;
     $193 = ((($$10161$us)) + 32|0);
     $194 = ((($$10$us)) + 32|0);
     $195 = (($$0$us) + -1)|0;
     $196 = ($$0$us|0)>(1);
     if ($196) {
      $$0$us = $195;$$10$us = $194;$$10161$us = $193;
     } else {
      break;
     }
    }
    $197 = (($194) + ($7)|0);
    $198 = (($193) + ($11)|0);
    $199 = (($200) + -1)|0;
    $201 = ($200|0)==(0);
    if ($201) {
     break;
    } else {
     $$9160171$us = $198;$$9172$us = $197;$200 = $199;
    }
   }
   return;
   break;
  }
  case 7:  {
   $$9160171$us174 = $9;$$9172$us173 = $5;$239 = $159;
   while(1) {
    $$1$us180 = $162;$$11$us179 = $$9172$us173;$$11162$us178 = $$9160171$us174;
    while(1) {
     $209 = HEAP32[$$11$us179>>2]|0;
     $210 = $209 & $158;
     HEAP32[$$11162$us178>>2] = $210;
     $211 = ((($$11162$us178)) + 4|0);
     $212 = ((($$11$us179)) + 4|0);
     $213 = HEAP32[$212>>2]|0;
     $214 = $213 & $158;
     HEAP32[$211>>2] = $214;
     $215 = ((($$11162$us178)) + 8|0);
     $216 = ((($$11$us179)) + 8|0);
     $217 = HEAP32[$216>>2]|0;
     $218 = $217 & $158;
     HEAP32[$215>>2] = $218;
     $219 = ((($$11162$us178)) + 12|0);
     $220 = ((($$11$us179)) + 12|0);
     $221 = HEAP32[$220>>2]|0;
     $222 = $221 & $158;
     HEAP32[$219>>2] = $222;
     $223 = ((($$11162$us178)) + 16|0);
     $224 = ((($$11$us179)) + 16|0);
     $225 = HEAP32[$224>>2]|0;
     $226 = $225 & $158;
     HEAP32[$223>>2] = $226;
     $227 = ((($$11162$us178)) + 20|0);
     $228 = ((($$11$us179)) + 20|0);
     $229 = HEAP32[$228>>2]|0;
     $230 = $229 & $158;
     HEAP32[$227>>2] = $230;
     $231 = ((($$11162$us178)) + 24|0);
     $232 = ((($$11$us179)) + 24|0);
     $233 = HEAP32[$232>>2]|0;
     $234 = $233 & $158;
     HEAP32[$231>>2] = $234;
     $206 = ((($$11162$us178)) + 28|0);
     $204 = ((($$11$us179)) + 28|0);
     $235 = ($$1$us180|0)>(1);
     if (!($235)) {
      break;
     }
     $202 = (($$1$us180) + -1)|0;
     $203 = HEAP32[$204>>2]|0;
     $205 = $203 & $158;
     HEAP32[$206>>2] = $205;
     $207 = ((($$11162$us178)) + 32|0);
     $208 = ((($$11$us179)) + 32|0);
     $$1$us180 = $202;$$11$us179 = $208;$$11162$us178 = $207;
    }
    $236 = (($204) + ($7)|0);
    $237 = (($206) + ($11)|0);
    $238 = (($239) + -1)|0;
    $240 = ($239|0)==(0);
    if ($240) {
     break;
    } else {
     $$9160171$us174 = $237;$$9172$us173 = $236;$239 = $238;
    }
   }
   return;
   break;
  }
  default: {
   $$9160171 = $9;$$9172 = $5;$278 = $159;
   L7: while(1) {
    $trunc$clear2 = $trunc & 7;
    switch ($trunc$clear2<<24>>24) {
    case 1:  {
     $$17 = $$9172;$$17168 = $$9160171;$$7 = $162;
     label = 37;
     break;
    }
    case 2:  {
     $$16 = $$9172;$$16167 = $$9160171;$$6 = $162;
     label = 36;
     break;
    }
    case 6:  {
     $$12 = $$9172;$$12163 = $$9160171;$$2 = $162;
     label = 32;
     break;
    }
    case 5:  {
     $$13 = $$9172;$$13164 = $$9160171;$$3 = $162;
     label = 33;
     break;
    }
    case 4:  {
     $$14 = $$9172;$$14165 = $$9160171;$$4 = $162;
     label = 34;
     break;
    }
    case 3:  {
     $$15 = $$9172;$$15166 = $$9160171;$$5 = $162;
     label = 35;
     break;
    }
    default: {
     label = 38;
     break L7;
    }
    }
    while(1) {
     if ((label|0) == 32) {
      label = 0;
      $252 = HEAP32[$$12>>2]|0;
      $253 = $252 & $158;
      HEAP32[$$12163>>2] = $253;
      $254 = ((($$12163)) + 4|0);
      $255 = ((($$12)) + 4|0);
      $$13 = $255;$$13164 = $254;$$3 = $$2;
      label = 33;
      continue;
     }
     else if ((label|0) == 33) {
      label = 0;
      $256 = HEAP32[$$13>>2]|0;
      $257 = $256 & $158;
      HEAP32[$$13164>>2] = $257;
      $258 = ((($$13164)) + 4|0);
      $259 = ((($$13)) + 4|0);
      $$14 = $259;$$14165 = $258;$$4 = $$3;
      label = 34;
      continue;
     }
     else if ((label|0) == 34) {
      label = 0;
      $260 = HEAP32[$$14>>2]|0;
      $261 = $260 & $158;
      HEAP32[$$14165>>2] = $261;
      $262 = ((($$14165)) + 4|0);
      $263 = ((($$14)) + 4|0);
      $$15 = $263;$$15166 = $262;$$5 = $$4;
      label = 35;
      continue;
     }
     else if ((label|0) == 35) {
      label = 0;
      $264 = HEAP32[$$15>>2]|0;
      $265 = $264 & $158;
      HEAP32[$$15166>>2] = $265;
      $266 = ((($$15166)) + 4|0);
      $267 = ((($$15)) + 4|0);
      $$16 = $267;$$16167 = $266;$$6 = $$5;
      label = 36;
      continue;
     }
     else if ((label|0) == 36) {
      label = 0;
      $268 = HEAP32[$$16>>2]|0;
      $269 = $268 & $158;
      HEAP32[$$16167>>2] = $269;
      $270 = ((($$16167)) + 4|0);
      $271 = ((($$16)) + 4|0);
      $$17 = $271;$$17168 = $270;$$7 = $$6;
      label = 37;
      continue;
     }
     else if ((label|0) == 37) {
      label = 0;
      $272 = HEAP32[$$17>>2]|0;
      $273 = $272 & $158;
      HEAP32[$$17168>>2] = $273;
      $245 = ((($$17168)) + 4|0);
      $243 = ((($$17)) + 4|0);
      $274 = ($$7|0)>(1);
      if (!($274)) {
       break;
      }
      $241 = (($$7) + -1)|0;
      $242 = HEAP32[$243>>2]|0;
      $244 = $242 & $158;
      HEAP32[$245>>2] = $244;
      $246 = ((($$17168)) + 8|0);
      $247 = ((($$17)) + 8|0);
      $248 = HEAP32[$247>>2]|0;
      $249 = $248 & $158;
      HEAP32[$246>>2] = $249;
      $250 = ((($$17168)) + 12|0);
      $251 = ((($$17)) + 12|0);
      $$12 = $251;$$12163 = $250;$$2 = $241;
      label = 32;
      continue;
     }
    }
    $275 = (($243) + ($7)|0);
    $276 = (($245) + ($11)|0);
    $277 = (($278) + -1)|0;
    $279 = ($278|0)==(0);
    if ($279) {
     label = 40;
     break;
    } else {
     $$9160171 = $276;$$9172 = $275;$278 = $277;
    }
   }
   if ((label|0) == 38) {
    // unreachable;
   }
   else if ((label|0) == 40) {
    return;
   }
  }
  }
 } else {
  $19 = ((($0)) + 63|0);
  $20 = HEAP8[$19>>0]|0;
  $21 = $20&255;
  $22 = ((($15)) + 31|0);
  $23 = HEAP8[$22>>0]|0;
  $24 = $23&255;
  $25 = $21 >>> $24;
  $26 = ((($15)) + 35|0);
  $27 = HEAP8[$26>>0]|0;
  $28 = $27&255;
  $29 = $25 << $28;
  $30 = (($4) + -1)|0;
  $31 = ($4|0)==(0);
  if ($31) {
   return;
  }
  $32 = (($2) + 7)|0;
  $33 = (($32|0) / 8)&-1;
  $trunc169 = $2&255;
  $trunc169$clear = $trunc169 & 7;
  switch ($trunc169$clear<<24>>24) {
  case 0:  {
   $$0143202$us = $5;$$0151201$us = $9;$71 = $30;
   while(1) {
    $$0135$us = $33;$$1144$us = $$0143202$us;$$1152$us = $$0151201$us;
    while(1) {
     $34 = HEAP32[$$1144$us>>2]|0;
     $35 = $34 | $29;
     HEAP32[$$1152$us>>2] = $35;
     $36 = ((($$1152$us)) + 4|0);
     $37 = ((($$1144$us)) + 4|0);
     $38 = HEAP32[$37>>2]|0;
     $39 = $38 | $29;
     HEAP32[$36>>2] = $39;
     $40 = ((($$1152$us)) + 8|0);
     $41 = ((($$1144$us)) + 8|0);
     $42 = HEAP32[$41>>2]|0;
     $43 = $42 | $29;
     HEAP32[$40>>2] = $43;
     $44 = ((($$1152$us)) + 12|0);
     $45 = ((($$1144$us)) + 12|0);
     $46 = HEAP32[$45>>2]|0;
     $47 = $46 | $29;
     HEAP32[$44>>2] = $47;
     $48 = ((($$1152$us)) + 16|0);
     $49 = ((($$1144$us)) + 16|0);
     $50 = HEAP32[$49>>2]|0;
     $51 = $50 | $29;
     HEAP32[$48>>2] = $51;
     $52 = ((($$1152$us)) + 20|0);
     $53 = ((($$1144$us)) + 20|0);
     $54 = HEAP32[$53>>2]|0;
     $55 = $54 | $29;
     HEAP32[$52>>2] = $55;
     $56 = ((($$1152$us)) + 24|0);
     $57 = ((($$1144$us)) + 24|0);
     $58 = HEAP32[$57>>2]|0;
     $59 = $58 | $29;
     HEAP32[$56>>2] = $59;
     $60 = ((($$1152$us)) + 28|0);
     $61 = ((($$1144$us)) + 28|0);
     $62 = HEAP32[$61>>2]|0;
     $63 = $62 | $29;
     HEAP32[$60>>2] = $63;
     $64 = ((($$1152$us)) + 32|0);
     $65 = ((($$1144$us)) + 32|0);
     $66 = (($$0135$us) + -1)|0;
     $67 = ($$0135$us|0)>(1);
     if ($67) {
      $$0135$us = $66;$$1144$us = $65;$$1152$us = $64;
     } else {
      break;
     }
    }
    $68 = (($65) + ($7)|0);
    $69 = (($64) + ($11)|0);
    $70 = (($71) + -1)|0;
    $72 = ($71|0)==(0);
    if ($72) {
     break;
    } else {
     $$0143202$us = $68;$$0151201$us = $69;$71 = $70;
    }
   }
   return;
   break;
  }
  case 7:  {
   $$0143202$us208 = $5;$$0151201$us209 = $9;$110 = $30;
   while(1) {
    $$1136$us215 = $33;$$2145$us214 = $$0143202$us208;$$2153$us213 = $$0151201$us209;
    while(1) {
     $80 = HEAP32[$$2145$us214>>2]|0;
     $81 = $80 | $29;
     HEAP32[$$2153$us213>>2] = $81;
     $82 = ((($$2153$us213)) + 4|0);
     $83 = ((($$2145$us214)) + 4|0);
     $84 = HEAP32[$83>>2]|0;
     $85 = $84 | $29;
     HEAP32[$82>>2] = $85;
     $86 = ((($$2153$us213)) + 8|0);
     $87 = ((($$2145$us214)) + 8|0);
     $88 = HEAP32[$87>>2]|0;
     $89 = $88 | $29;
     HEAP32[$86>>2] = $89;
     $90 = ((($$2153$us213)) + 12|0);
     $91 = ((($$2145$us214)) + 12|0);
     $92 = HEAP32[$91>>2]|0;
     $93 = $92 | $29;
     HEAP32[$90>>2] = $93;
     $94 = ((($$2153$us213)) + 16|0);
     $95 = ((($$2145$us214)) + 16|0);
     $96 = HEAP32[$95>>2]|0;
     $97 = $96 | $29;
     HEAP32[$94>>2] = $97;
     $98 = ((($$2153$us213)) + 20|0);
     $99 = ((($$2145$us214)) + 20|0);
     $100 = HEAP32[$99>>2]|0;
     $101 = $100 | $29;
     HEAP32[$98>>2] = $101;
     $102 = ((($$2153$us213)) + 24|0);
     $103 = ((($$2145$us214)) + 24|0);
     $104 = HEAP32[$103>>2]|0;
     $105 = $104 | $29;
     HEAP32[$102>>2] = $105;
     $77 = ((($$2153$us213)) + 28|0);
     $75 = ((($$2145$us214)) + 28|0);
     $106 = ($$1136$us215|0)>(1);
     if (!($106)) {
      break;
     }
     $73 = (($$1136$us215) + -1)|0;
     $74 = HEAP32[$75>>2]|0;
     $76 = $74 | $29;
     HEAP32[$77>>2] = $76;
     $78 = ((($$2153$us213)) + 32|0);
     $79 = ((($$2145$us214)) + 32|0);
     $$1136$us215 = $73;$$2145$us214 = $79;$$2153$us213 = $78;
    }
    $107 = (($75) + ($7)|0);
    $108 = (($77) + ($11)|0);
    $109 = (($110) + -1)|0;
    $111 = ($110|0)==(0);
    if ($111) {
     break;
    } else {
     $$0143202$us208 = $107;$$0151201$us209 = $108;$110 = $109;
    }
   }
   return;
   break;
  }
  default: {
   $$0143202 = $5;$$0151201 = $9;$149 = $30;
   L40: while(1) {
    $trunc169$clear1 = $trunc169 & 7;
    switch ($trunc169$clear1<<24>>24) {
    case 1:  {
     $$7142 = $33;$$8 = $$0143202;$$8159 = $$0151201;
     label = 18;
     break;
    }
    case 2:  {
     $$6141 = $33;$$7150 = $$0143202;$$7158 = $$0151201;
     label = 17;
     break;
    }
    case 6:  {
     $$2137 = $33;$$3146 = $$0143202;$$3154 = $$0151201;
     label = 13;
     break;
    }
    case 5:  {
     $$3138 = $33;$$4147 = $$0143202;$$4155 = $$0151201;
     label = 14;
     break;
    }
    case 4:  {
     $$4139 = $33;$$5148 = $$0143202;$$5156 = $$0151201;
     label = 15;
     break;
    }
    case 3:  {
     $$5140 = $33;$$6149 = $$0143202;$$6157 = $$0151201;
     label = 16;
     break;
    }
    default: {
     label = 19;
     break L40;
    }
    }
    while(1) {
     if ((label|0) == 13) {
      label = 0;
      $123 = HEAP32[$$3146>>2]|0;
      $124 = $123 | $29;
      HEAP32[$$3154>>2] = $124;
      $125 = ((($$3154)) + 4|0);
      $126 = ((($$3146)) + 4|0);
      $$3138 = $$2137;$$4147 = $126;$$4155 = $125;
      label = 14;
      continue;
     }
     else if ((label|0) == 14) {
      label = 0;
      $127 = HEAP32[$$4147>>2]|0;
      $128 = $127 | $29;
      HEAP32[$$4155>>2] = $128;
      $129 = ((($$4155)) + 4|0);
      $130 = ((($$4147)) + 4|0);
      $$4139 = $$3138;$$5148 = $130;$$5156 = $129;
      label = 15;
      continue;
     }
     else if ((label|0) == 15) {
      label = 0;
      $131 = HEAP32[$$5148>>2]|0;
      $132 = $131 | $29;
      HEAP32[$$5156>>2] = $132;
      $133 = ((($$5156)) + 4|0);
      $134 = ((($$5148)) + 4|0);
      $$5140 = $$4139;$$6149 = $134;$$6157 = $133;
      label = 16;
      continue;
     }
     else if ((label|0) == 16) {
      label = 0;
      $135 = HEAP32[$$6149>>2]|0;
      $136 = $135 | $29;
      HEAP32[$$6157>>2] = $136;
      $137 = ((($$6157)) + 4|0);
      $138 = ((($$6149)) + 4|0);
      $$6141 = $$5140;$$7150 = $138;$$7158 = $137;
      label = 17;
      continue;
     }
     else if ((label|0) == 17) {
      label = 0;
      $139 = HEAP32[$$7150>>2]|0;
      $140 = $139 | $29;
      HEAP32[$$7158>>2] = $140;
      $141 = ((($$7158)) + 4|0);
      $142 = ((($$7150)) + 4|0);
      $$7142 = $$6141;$$8 = $142;$$8159 = $141;
      label = 18;
      continue;
     }
     else if ((label|0) == 18) {
      label = 0;
      $143 = HEAP32[$$8>>2]|0;
      $144 = $143 | $29;
      HEAP32[$$8159>>2] = $144;
      $116 = ((($$8159)) + 4|0);
      $114 = ((($$8)) + 4|0);
      $145 = ($$7142|0)>(1);
      if (!($145)) {
       break;
      }
      $112 = (($$7142) + -1)|0;
      $113 = HEAP32[$114>>2]|0;
      $115 = $113 | $29;
      HEAP32[$116>>2] = $115;
      $117 = ((($$8159)) + 8|0);
      $118 = ((($$8)) + 8|0);
      $119 = HEAP32[$118>>2]|0;
      $120 = $119 | $29;
      HEAP32[$117>>2] = $120;
      $121 = ((($$8159)) + 12|0);
      $122 = ((($$8)) + 12|0);
      $$2137 = $112;$$3146 = $122;$$3154 = $121;
      label = 13;
      continue;
     }
    }
    $146 = (($114) + ($7)|0);
    $147 = (($116) + ($11)|0);
    $148 = (($149) + -1)|0;
    $150 = ($149|0)==(0);
    if ($150) {
     label = 40;
     break;
    } else {
     $$0143202 = $146;$$0151201 = $147;$149 = $148;
    }
   }
   if ((label|0) == 19) {
    // unreachable;
   }
   else if ((label|0) == 40) {
    return;
   }
  }
  }
 }
}
function _Blit2to2Key($0) {
 $0 = $0|0;
 var $$0$us = 0, $$0101110 = 0, $$0101110$us = 0, $$093111 = 0, $$093111$us = 0, $$1 = 0, $$1102$us = 0, $$194$us = 0, $$2 = 0, $$2103 = 0, $$295 = 0, $$3 = 0, $$3104 = 0, $$396 = 0, $$4 = 0, $$4105 = 0, $$497 = 0, $$5 = 0, $$5106 = 0, $$598 = 0;
 var $$6 = 0, $$6107 = 0, $$699 = 0, $$7 = 0, $$7100 = 0, $$7108 = 0, $$8 = 0, $$8109 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $trunc = 0, $trunc$clear = 0, $trunc$clear1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$0>>2]|0;
 $6 = ((($0)) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($0)) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($0)) + 36|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($0)) + 56|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($0)) + 40|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ((($15)) + 24|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = $17 ^ -1;
 $19 = (($7|0) / 2)&-1;
 $20 = (($11|0) / 2)&-1;
 $21 = $13 & $18;
 $22 = (($4) + -1)|0;
 $23 = ($4|0)==(0);
 if ($23) {
  return;
 }
 $24 = (($2) + 7)|0;
 $25 = (($24|0) / 8)&-1;
 $trunc = $2&255;
 $trunc$clear = $trunc & 7;
 $26 = ($trunc$clear<<24>>24)==(0);
 if ($26) {
  $$0101110$us = $5;$$093111$us = $9;$80 = $22;
  while(1) {
   $$0$us = $25;$$1102$us = $$0101110$us;$$194$us = $$093111$us;
   while(1) {
    $27 = HEAP16[$$1102$us>>1]|0;
    $28 = $27&65535;
    $29 = $28 & $18;
    $30 = ($29|0)==($21|0);
    if (!($30)) {
     HEAP16[$$194$us>>1] = $27;
    }
    $31 = ((($$1102$us)) + 2|0);
    $32 = HEAP16[$31>>1]|0;
    $33 = $32&65535;
    $34 = $33 & $18;
    $35 = ($34|0)==($21|0);
    if (!($35)) {
     $36 = ((($$194$us)) + 2|0);
     HEAP16[$36>>1] = $32;
    }
    $37 = ((($$1102$us)) + 4|0);
    $38 = HEAP16[$37>>1]|0;
    $39 = $38&65535;
    $40 = $39 & $18;
    $41 = ($40|0)==($21|0);
    if (!($41)) {
     $42 = ((($$194$us)) + 4|0);
     HEAP16[$42>>1] = $38;
    }
    $43 = ((($$1102$us)) + 6|0);
    $44 = HEAP16[$43>>1]|0;
    $45 = $44&65535;
    $46 = $45 & $18;
    $47 = ($46|0)==($21|0);
    if (!($47)) {
     $48 = ((($$194$us)) + 6|0);
     HEAP16[$48>>1] = $44;
    }
    $49 = ((($$1102$us)) + 8|0);
    $50 = HEAP16[$49>>1]|0;
    $51 = $50&65535;
    $52 = $51 & $18;
    $53 = ($52|0)==($21|0);
    if (!($53)) {
     $54 = ((($$194$us)) + 8|0);
     HEAP16[$54>>1] = $50;
    }
    $55 = ((($$1102$us)) + 10|0);
    $56 = HEAP16[$55>>1]|0;
    $57 = $56&65535;
    $58 = $57 & $18;
    $59 = ($58|0)==($21|0);
    if (!($59)) {
     $60 = ((($$194$us)) + 10|0);
     HEAP16[$60>>1] = $56;
    }
    $61 = ((($$1102$us)) + 12|0);
    $62 = HEAP16[$61>>1]|0;
    $63 = $62&65535;
    $64 = $63 & $18;
    $65 = ($64|0)==($21|0);
    if (!($65)) {
     $66 = ((($$194$us)) + 12|0);
     HEAP16[$66>>1] = $62;
    }
    $67 = ((($$1102$us)) + 14|0);
    $68 = HEAP16[$67>>1]|0;
    $69 = $68&65535;
    $70 = $69 & $18;
    $71 = ($70|0)==($21|0);
    if (!($71)) {
     $72 = ((($$194$us)) + 14|0);
     HEAP16[$72>>1] = $68;
    }
    $73 = ((($$194$us)) + 16|0);
    $74 = ((($$1102$us)) + 16|0);
    $75 = (($$0$us) + -1)|0;
    $76 = ($$0$us|0)>(1);
    if ($76) {
     $$0$us = $75;$$1102$us = $74;$$194$us = $73;
    } else {
     break;
    }
   }
   $77 = (($74) + ($19<<1)|0);
   $78 = (($73) + ($20<<1)|0);
   $79 = (($80) + -1)|0;
   $81 = ($80|0)==(0);
   if ($81) {
    break;
   } else {
    $$0101110$us = $77;$$093111$us = $78;$80 = $79;
   }
  }
  return;
 } else {
  $$0101110 = $5;$$093111 = $9;$135 = $22;
 }
 L35: while(1) {
  $trunc$clear1 = $trunc & 7;
  switch ($trunc$clear1<<24>>24) {
  case 1:  {
   $$7 = $25;$$8 = $$093111;$$8109 = $$0101110;
   label = 44;
   break;
  }
  case 7:  {
   $$1 = $25;$$2103 = $$0101110;$$295 = $$093111;
   label = 26;
   break;
  }
  case 6:  {
   $$2 = $25;$$3104 = $$0101110;$$396 = $$093111;
   label = 29;
   break;
  }
  case 5:  {
   $$3 = $25;$$4105 = $$0101110;$$497 = $$093111;
   label = 32;
   break;
  }
  case 4:  {
   $$4 = $25;$$5106 = $$0101110;$$598 = $$093111;
   label = 35;
   break;
  }
  case 3:  {
   $$5 = $25;$$6107 = $$0101110;$$699 = $$093111;
   label = 38;
   break;
  }
  case 2:  {
   $$6 = $25;$$7100 = $$093111;$$7108 = $$0101110;
   label = 41;
   break;
  }
  default: {
   label = 47;
   break L35;
  }
  }
  while(1) {
   if ((label|0) == 26) {
    label = 0;
    $90 = HEAP16[$$2103>>1]|0;
    $91 = $90&65535;
    $92 = $91 & $18;
    $93 = ($92|0)==($21|0);
    if (!($93)) {
     HEAP16[$$295>>1] = $90;
    }
    $94 = ((($$295)) + 2|0);
    $95 = ((($$2103)) + 2|0);
    $$2 = $$1;$$3104 = $95;$$396 = $94;
    label = 29;
    continue;
   }
   else if ((label|0) == 29) {
    label = 0;
    $96 = HEAP16[$$3104>>1]|0;
    $97 = $96&65535;
    $98 = $97 & $18;
    $99 = ($98|0)==($21|0);
    if (!($99)) {
     HEAP16[$$396>>1] = $96;
    }
    $100 = ((($$396)) + 2|0);
    $101 = ((($$3104)) + 2|0);
    $$3 = $$2;$$4105 = $101;$$497 = $100;
    label = 32;
    continue;
   }
   else if ((label|0) == 32) {
    label = 0;
    $102 = HEAP16[$$4105>>1]|0;
    $103 = $102&65535;
    $104 = $103 & $18;
    $105 = ($104|0)==($21|0);
    if (!($105)) {
     HEAP16[$$497>>1] = $102;
    }
    $106 = ((($$497)) + 2|0);
    $107 = ((($$4105)) + 2|0);
    $$4 = $$3;$$5106 = $107;$$598 = $106;
    label = 35;
    continue;
   }
   else if ((label|0) == 35) {
    label = 0;
    $108 = HEAP16[$$5106>>1]|0;
    $109 = $108&65535;
    $110 = $109 & $18;
    $111 = ($110|0)==($21|0);
    if (!($111)) {
     HEAP16[$$598>>1] = $108;
    }
    $112 = ((($$598)) + 2|0);
    $113 = ((($$5106)) + 2|0);
    $$5 = $$4;$$6107 = $113;$$699 = $112;
    label = 38;
    continue;
   }
   else if ((label|0) == 38) {
    label = 0;
    $114 = HEAP16[$$6107>>1]|0;
    $115 = $114&65535;
    $116 = $115 & $18;
    $117 = ($116|0)==($21|0);
    if (!($117)) {
     HEAP16[$$699>>1] = $114;
    }
    $118 = ((($$699)) + 2|0);
    $119 = ((($$6107)) + 2|0);
    $$6 = $$5;$$7100 = $118;$$7108 = $119;
    label = 41;
    continue;
   }
   else if ((label|0) == 41) {
    label = 0;
    $120 = HEAP16[$$7108>>1]|0;
    $121 = $120&65535;
    $122 = $121 & $18;
    $123 = ($122|0)==($21|0);
    if (!($123)) {
     HEAP16[$$7100>>1] = $120;
    }
    $124 = ((($$7100)) + 2|0);
    $125 = ((($$7108)) + 2|0);
    $$7 = $$6;$$8 = $124;$$8109 = $125;
    label = 44;
    continue;
   }
   else if ((label|0) == 44) {
    label = 0;
    $126 = HEAP16[$$8109>>1]|0;
    $127 = $126&65535;
    $128 = $127 & $18;
    $129 = ($128|0)==($21|0);
    if (!($129)) {
     HEAP16[$$8>>1] = $126;
    }
    $87 = ((($$8)) + 2|0);
    $83 = ((($$8109)) + 2|0);
    $130 = (($$7) + -1)|0;
    $131 = ($$7|0)>(1);
    if (!($131)) {
     break;
    }
    $82 = HEAP16[$83>>1]|0;
    $84 = $82&65535;
    $85 = $84 & $18;
    $86 = ($85|0)==($21|0);
    if (!($86)) {
     HEAP16[$87>>1] = $82;
    }
    $88 = ((($$8)) + 4|0);
    $89 = ((($$8109)) + 4|0);
    $$1 = $130;$$2103 = $89;$$295 = $88;
    label = 26;
    continue;
   }
  }
  $132 = (($83) + ($19<<1)|0);
  $133 = (($87) + ($20<<1)|0);
  $134 = (($135) + -1)|0;
  $136 = ($135|0)==(0);
  if ($136) {
   label = 49;
   break;
  } else {
   $$0101110 = $132;$$093111 = $133;$135 = $134;
  }
 }
 if ((label|0) == 47) {
  // unreachable;
 }
 else if ((label|0) == 49) {
  return;
 }
}
function _BlitNto1Key($0) {
 $0 = $0|0;
 var $$0 = 0, $$01014 = 0, $$01014$ph = 0, $$010321163 = 0, $$010481162 = 0, $$0966 = 0, $$0974 = 0, $$0974$shrunk = 0, $$0982 = 0, $$0982$shrunk = 0, $$0982$shrunk$ph = 0, $$0982$shrunk$ph$in = 0, $$0998$shrunk = 0, $$0998$shrunk$ph = 0, $$0998$shrunk$ph$in = 0, $$1 = 0, $$10 = 0, $$10$shrunk = 0, $$101008$shrunk = 0, $$101008$shrunk$ph = 0;
 var $$101008$shrunk$ph$in = 0, $$101024 = 0, $$101024$ph = 0, $$101042 = 0, $$101058 = 0, $$10992 = 0, $$10992$shrunk = 0, $$10992$shrunk$ph = 0, $$10992$shrunk$ph$in = 0, $$11 = 0, $$11$shrunk = 0, $$11015 = 0, $$11015$ph = 0, $$11033 = 0, $$11049 = 0, $$111009$shrunk = 0, $$111009$shrunk$ph = 0, $$111009$shrunk$ph$in = 0, $$111025 = 0, $$111025$ph = 0;
 var $$111043 = 0, $$111059 = 0, $$11993 = 0, $$11993$shrunk = 0, $$11993$shrunk$ph = 0, $$11993$shrunk$ph$in = 0, $$12 = 0, $$12$shrunk = 0, $$121010$shrunk = 0, $$121010$shrunk$ph = 0, $$121010$shrunk$ph$in = 0, $$121026 = 0, $$121026$ph = 0, $$121044 = 0, $$121060 = 0, $$12994 = 0, $$12994$shrunk = 0, $$12994$shrunk$ph = 0, $$12994$shrunk$ph$in = 0, $$13 = 0;
 var $$13$shrunk = 0, $$131011$shrunk = 0, $$131011$shrunk$ph = 0, $$131011$shrunk$ph$in = 0, $$131027 = 0, $$131027$ph = 0, $$131045 = 0, $$131061 = 0, $$13995 = 0, $$13995$shrunk = 0, $$13995$shrunk$ph = 0, $$13995$shrunk$ph$in = 0, $$14 = 0, $$14$shrunk = 0, $$141012$shrunk = 0, $$141012$shrunk$ph = 0, $$141012$shrunk$ph$in = 0, $$141028 = 0, $$141028$ph = 0, $$141046 = 0;
 var $$141062 = 0, $$14996 = 0, $$14996$shrunk = 0, $$14996$shrunk$ph = 0, $$14996$shrunk$ph$in = 0, $$15 = 0, $$15$shrunk = 0, $$151013$shrunk = 0, $$151013$shrunk$ph = 0, $$151013$shrunk$ph$in = 0, $$151029 = 0, $$151029$ph = 0, $$151047 = 0, $$151063 = 0, $$15997 = 0, $$15997$shrunk = 0, $$15997$shrunk$ph = 0, $$15997$shrunk$ph$in = 0, $$16 = 0, $$161064 = 0;
 var $$17 = 0, $$171065 = 0, $$1967 = 0, $$1975 = 0, $$1975$shrunk = 0, $$1983 = 0, $$1983$shrunk = 0, $$1983$shrunk$ph = 0, $$1983$shrunk$ph$in = 0, $$1999$shrunk = 0, $$1999$shrunk$ph = 0, $$1999$shrunk$ph$in = 0, $$2 = 0, $$21000$shrunk = 0, $$21000$shrunk$ph = 0, $$21000$shrunk$ph$in = 0, $$21016 = 0, $$21016$ph = 0, $$21034 = 0, $$21050 = 0;
 var $$2968 = 0, $$2976 = 0, $$2976$shrunk = 0, $$2984 = 0, $$2984$shrunk = 0, $$2984$shrunk$ph = 0, $$2984$shrunk$ph$in = 0, $$3 = 0, $$31001$shrunk = 0, $$31001$shrunk$ph = 0, $$31001$shrunk$ph$in = 0, $$31017 = 0, $$31017$ph = 0, $$31035 = 0, $$31051 = 0, $$3969 = 0, $$3977 = 0, $$3977$shrunk = 0, $$3985 = 0, $$3985$shrunk = 0;
 var $$3985$shrunk$ph = 0, $$3985$shrunk$ph$in = 0, $$4 = 0, $$41002$shrunk = 0, $$41002$shrunk$ph = 0, $$41002$shrunk$ph$in = 0, $$41018 = 0, $$41018$ph = 0, $$41036 = 0, $$41052 = 0, $$4970 = 0, $$4978 = 0, $$4978$shrunk = 0, $$4986 = 0, $$4986$shrunk = 0, $$4986$shrunk$ph = 0, $$4986$shrunk$ph$in = 0, $$5 = 0, $$51003$shrunk = 0, $$51003$shrunk$ph = 0;
 var $$51003$shrunk$ph$in = 0, $$51019 = 0, $$51019$ph = 0, $$51037 = 0, $$51053 = 0, $$5971 = 0, $$5979 = 0, $$5979$shrunk = 0, $$5987 = 0, $$5987$shrunk = 0, $$5987$shrunk$ph = 0, $$5987$shrunk$ph$in = 0, $$6 = 0, $$61004$shrunk = 0, $$61004$shrunk$ph = 0, $$61004$shrunk$ph$in = 0, $$61020 = 0, $$61020$ph = 0, $$61038 = 0, $$61054 = 0;
 var $$6972 = 0, $$6980 = 0, $$6980$shrunk = 0, $$6988 = 0, $$6988$shrunk = 0, $$6988$shrunk$ph = 0, $$6988$shrunk$ph$in = 0, $$7 = 0, $$71005$shrunk = 0, $$71005$shrunk$ph = 0, $$71005$shrunk$ph$in = 0, $$71021 = 0, $$71021$ph = 0, $$71039 = 0, $$71055 = 0, $$7973 = 0, $$7981 = 0, $$7981$shrunk = 0, $$7989 = 0, $$7989$shrunk = 0;
 var $$7989$shrunk$ph = 0, $$7989$shrunk$ph$in = 0, $$8 = 0, $$8$shrunk = 0, $$81006$shrunk = 0, $$81006$shrunk$ph = 0, $$81006$shrunk$ph$in = 0, $$81022 = 0, $$81022$ph = 0, $$81040 = 0, $$81056 = 0, $$8990 = 0, $$8990$shrunk = 0, $$8990$shrunk$ph = 0, $$8990$shrunk$ph$in = 0, $$9 = 0, $$9$shrunk = 0, $$91007$shrunk = 0, $$91007$shrunk$ph = 0, $$91007$shrunk$ph$in = 0;
 var $$91023 = 0, $$91023$ph = 0, $$910411165 = 0, $$910571164 = 0, $$9991 = 0, $$9991$shrunk = 0, $$9991$shrunk$ph = 0, $$9991$shrunk$ph$in = 0, $$sink = 0, $$sink1131 = 0, $$sink1133 = 0, $$sink1135 = 0, $$sink1137 = 0, $$sink1139 = 0, $$sink1141 = 0, $$sink1143 = 0, $$sink1145 = 0, $$sink1147 = 0, $$sink1149 = 0, $$sink1151 = 0;
 var $$sink1153 = 0, $$sink1155 = 0, $$sink1157 = 0, $$sink1159 = 0, $1 = 0, $10 = 0, $100 = 0, $1000 = 0, $1001 = 0, $1002 = 0, $1003 = 0, $1004 = 0, $1005 = 0, $1006 = 0, $1007 = 0, $1008 = 0, $1009 = 0, $101 = 0, $1010 = 0, $1011 = 0;
 var $1012 = 0, $1013 = 0, $1014 = 0, $1015 = 0, $1016 = 0, $1017 = 0, $1018 = 0, $1019 = 0, $102 = 0, $1020 = 0, $1021 = 0, $1022 = 0, $1023 = 0, $1024 = 0, $1025 = 0, $1026 = 0, $1027 = 0, $1028 = 0, $1029 = 0, $103 = 0;
 var $1030 = 0, $1031 = 0, $1032 = 0, $1033 = 0, $1034 = 0, $1035 = 0, $1036 = 0, $1037 = 0, $1038 = 0, $1039 = 0, $104 = 0, $1040 = 0, $1041 = 0, $1042 = 0, $1043 = 0, $1044 = 0, $1045 = 0, $1046 = 0, $1047 = 0, $1048 = 0;
 var $1049 = 0, $105 = 0, $1050 = 0, $1051 = 0, $1052 = 0, $1053 = 0, $1054 = 0, $1055 = 0, $1056 = 0, $1057 = 0, $1058 = 0, $1059 = 0, $106 = 0, $1060 = 0, $1061 = 0, $1062 = 0, $1063 = 0, $1064 = 0, $1065 = 0, $1066 = 0;
 var $1067 = 0, $1068 = 0, $1069 = 0, $107 = 0, $1070 = 0, $1071 = 0, $1072 = 0, $1073 = 0, $1074 = 0, $1075 = 0, $1076 = 0, $1077 = 0, $1078 = 0, $1079 = 0, $108 = 0, $1080 = 0, $1081 = 0, $1082 = 0, $1083 = 0, $1084 = 0;
 var $1085 = 0, $1086 = 0, $1087 = 0, $1088 = 0, $1089 = 0, $109 = 0, $1090 = 0, $1091 = 0, $1092 = 0, $1093 = 0, $1094 = 0, $1095 = 0, $1096 = 0, $1097 = 0, $1098 = 0, $1099 = 0, $11 = 0, $110 = 0, $1100 = 0, $1101 = 0;
 var $1102 = 0, $1103 = 0, $1104 = 0, $1105 = 0, $1106 = 0, $1107 = 0, $1108 = 0, $1109 = 0, $111 = 0, $1110 = 0, $1111 = 0, $1112 = 0, $1113 = 0, $1114 = 0, $1115 = 0, $1116 = 0, $1117 = 0, $1118 = 0, $1119 = 0, $112 = 0;
 var $1120 = 0, $1121 = 0, $1122 = 0, $1123 = 0, $1124 = 0, $1125 = 0, $1126 = 0, $1127 = 0, $1128 = 0, $1129 = 0, $113 = 0, $1130 = 0, $1131 = 0, $1132 = 0, $1133 = 0, $1134 = 0, $1135 = 0, $1136 = 0, $1137 = 0, $1138 = 0;
 var $1139 = 0, $114 = 0, $1140 = 0, $1141 = 0, $1142 = 0, $1143 = 0, $1144 = 0, $1145 = 0, $1146 = 0, $1147 = 0, $1148 = 0, $1149 = 0, $115 = 0, $1150 = 0, $1151 = 0, $1152 = 0, $1153 = 0, $1154 = 0, $1155 = 0, $1156 = 0;
 var $1157 = 0, $1158 = 0, $1159 = 0, $116 = 0, $1160 = 0, $1161 = 0, $1162 = 0, $1163 = 0, $1164 = 0, $1165 = 0, $1166 = 0, $1167 = 0, $1168 = 0, $1169 = 0, $117 = 0, $1170 = 0, $1171 = 0, $1172 = 0, $1173 = 0, $1174 = 0;
 var $1175 = 0, $1176 = 0, $1177 = 0, $1178 = 0, $1179 = 0, $118 = 0, $1180 = 0, $1181 = 0, $1182 = 0, $1183 = 0, $1184 = 0, $1185 = 0, $1186 = 0, $1187 = 0, $1188 = 0, $1189 = 0, $119 = 0, $1190 = 0, $1191 = 0, $1192 = 0;
 var $1193 = 0, $1194 = 0, $1195 = 0, $1196 = 0, $1197 = 0, $1198 = 0, $1199 = 0, $12 = 0, $120 = 0, $1200 = 0, $1201 = 0, $1202 = 0, $1203 = 0, $1204 = 0, $1205 = 0, $1206 = 0, $1207 = 0, $1208 = 0, $1209 = 0, $121 = 0;
 var $1210 = 0, $1211 = 0, $1212 = 0, $1213 = 0, $1214 = 0, $1215 = 0, $1216 = 0, $1217 = 0, $1218 = 0, $1219 = 0, $122 = 0, $1220 = 0, $1221 = 0, $1222 = 0, $1223 = 0, $1224 = 0, $1225 = 0, $1226 = 0, $1227 = 0, $1228 = 0;
 var $1229 = 0, $123 = 0, $1230 = 0, $1231 = 0, $1232 = 0, $1233 = 0, $1234 = 0, $1235 = 0, $1236 = 0, $1237 = 0, $1238 = 0, $1239 = 0, $124 = 0, $1240 = 0, $1241 = 0, $1242 = 0, $1243 = 0, $1244 = 0, $1245 = 0, $1246 = 0;
 var $1247 = 0, $1248 = 0, $1249 = 0, $125 = 0, $1250 = 0, $1251 = 0, $1252 = 0, $1253 = 0, $1254 = 0, $1255 = 0, $1256 = 0, $1257 = 0, $1258 = 0, $1259 = 0, $126 = 0, $1260 = 0, $1261 = 0, $1262 = 0, $1263 = 0, $1264 = 0;
 var $1265 = 0, $1266 = 0, $1267 = 0, $1268 = 0, $1269 = 0, $127 = 0, $1270 = 0, $1271 = 0, $1272 = 0, $1273 = 0, $1274 = 0, $1275 = 0, $1276 = 0, $1277 = 0, $1278 = 0, $1279 = 0, $128 = 0, $1280 = 0, $1281 = 0, $1282 = 0;
 var $1283 = 0, $1284 = 0, $1285 = 0, $1286 = 0, $1287 = 0, $1288 = 0, $1289 = 0, $129 = 0, $1290 = 0, $1291 = 0, $1292 = 0, $1293 = 0, $1294 = 0, $1295 = 0, $1296 = 0, $1297 = 0, $1298 = 0, $1299 = 0, $13 = 0, $130 = 0;
 var $1300 = 0, $1301 = 0, $1302 = 0, $1303 = 0, $1304 = 0, $1305 = 0, $1306 = 0, $1307 = 0, $1308 = 0, $1309 = 0, $131 = 0, $1310 = 0, $1311 = 0, $1312 = 0, $1313 = 0, $1314 = 0, $1315 = 0, $1316 = 0, $1317 = 0, $1318 = 0;
 var $1319 = 0, $132 = 0, $1320 = 0, $1321 = 0, $1322 = 0, $1323 = 0, $1324 = 0, $1325 = 0, $1326 = 0, $1327 = 0, $1328 = 0, $1329 = 0, $133 = 0, $1330 = 0, $1331 = 0, $1332 = 0, $1333 = 0, $1334 = 0, $1335 = 0, $1336 = 0;
 var $1337 = 0, $1338 = 0, $1339 = 0, $134 = 0, $1340 = 0, $1341 = 0, $1342 = 0, $1343 = 0, $1344 = 0, $1345 = 0, $1346 = 0, $1347 = 0, $1348 = 0, $1349 = 0, $135 = 0, $1350 = 0, $1351 = 0, $1352 = 0, $1353 = 0, $1354 = 0;
 var $1355 = 0, $1356 = 0, $1357 = 0, $1358 = 0, $1359 = 0, $136 = 0, $1360 = 0, $1361 = 0, $1362 = 0, $1363 = 0, $1364 = 0, $1365 = 0, $1366 = 0, $1367 = 0, $1368 = 0, $1369 = 0, $137 = 0, $1370 = 0, $1371 = 0, $1372 = 0;
 var $1373 = 0, $1374 = 0, $1375 = 0, $1376 = 0, $1377 = 0, $1378 = 0, $1379 = 0, $138 = 0, $1380 = 0, $1381 = 0, $1382 = 0, $1383 = 0, $1384 = 0, $1385 = 0, $1386 = 0, $1387 = 0, $1388 = 0, $1389 = 0, $139 = 0, $1390 = 0;
 var $1391 = 0, $1392 = 0, $1393 = 0, $1394 = 0, $1395 = 0, $1396 = 0, $1397 = 0, $1398 = 0, $1399 = 0, $14 = 0, $140 = 0, $1400 = 0, $1401 = 0, $1402 = 0, $1403 = 0, $1404 = 0, $1405 = 0, $1406 = 0, $1407 = 0, $1408 = 0;
 var $1409 = 0, $141 = 0, $1410 = 0, $1411 = 0, $1412 = 0, $1413 = 0, $1414 = 0, $1415 = 0, $1416 = 0, $1417 = 0, $1418 = 0, $1419 = 0, $142 = 0, $1420 = 0, $1421 = 0, $1422 = 0, $1423 = 0, $1424 = 0, $1425 = 0, $1426 = 0;
 var $1427 = 0, $1428 = 0, $1429 = 0, $143 = 0, $1430 = 0, $1431 = 0, $1432 = 0, $1433 = 0, $1434 = 0, $1435 = 0, $1436 = 0, $1437 = 0, $1438 = 0, $1439 = 0, $144 = 0, $1440 = 0, $1441 = 0, $1442 = 0, $1443 = 0, $1444 = 0;
 var $1445 = 0, $1446 = 0, $1447 = 0, $1448 = 0, $1449 = 0, $145 = 0, $1450 = 0, $1451 = 0, $1452 = 0, $1453 = 0, $1454 = 0, $1455 = 0, $1456 = 0, $1457 = 0, $1458 = 0, $1459 = 0, $146 = 0, $1460 = 0, $1461 = 0, $1462 = 0;
 var $1463 = 0, $1464 = 0, $1465 = 0, $1466 = 0, $1467 = 0, $1468 = 0, $1469 = 0, $147 = 0, $1470 = 0, $1471 = 0, $1472 = 0, $1473 = 0, $1474 = 0, $1475 = 0, $1476 = 0, $1477 = 0, $1478 = 0, $1479 = 0, $148 = 0, $1480 = 0;
 var $1481 = 0, $1482 = 0, $1483 = 0, $1484 = 0, $1485 = 0, $1486 = 0, $1487 = 0, $1488 = 0, $1489 = 0, $149 = 0, $1490 = 0, $1491 = 0, $1492 = 0, $1493 = 0, $1494 = 0, $1495 = 0, $1496 = 0, $1497 = 0, $1498 = 0, $1499 = 0;
 var $15 = 0, $150 = 0, $1500 = 0, $1501 = 0, $1502 = 0, $1503 = 0, $1504 = 0, $1505 = 0, $1506 = 0, $1507 = 0, $1508 = 0, $1509 = 0, $151 = 0, $1510 = 0, $1511 = 0, $1512 = 0, $1513 = 0, $1514 = 0, $1515 = 0, $1516 = 0;
 var $1517 = 0, $1518 = 0, $1519 = 0, $152 = 0, $1520 = 0, $1521 = 0, $1522 = 0, $1523 = 0, $1524 = 0, $1525 = 0, $1526 = 0, $1527 = 0, $1528 = 0, $1529 = 0, $153 = 0, $1530 = 0, $1531 = 0, $1532 = 0, $1533 = 0, $1534 = 0;
 var $1535 = 0, $1536 = 0, $1537 = 0, $1538 = 0, $1539 = 0, $154 = 0, $1540 = 0, $1541 = 0, $1542 = 0, $1543 = 0, $1544 = 0, $1545 = 0, $1546 = 0, $1547 = 0, $1548 = 0, $1549 = 0, $155 = 0, $1550 = 0, $1551 = 0, $1552 = 0;
 var $1553 = 0, $1554 = 0, $1555 = 0, $1556 = 0, $1557 = 0, $1558 = 0, $1559 = 0, $156 = 0, $1560 = 0, $1561 = 0, $1562 = 0, $1563 = 0, $1564 = 0, $1565 = 0, $1566 = 0, $1567 = 0, $1568 = 0, $1569 = 0, $157 = 0, $1570 = 0;
 var $1571 = 0, $1572 = 0, $1573 = 0, $1574 = 0, $1575 = 0, $1576 = 0, $1577 = 0, $1578 = 0, $1579 = 0, $158 = 0, $1580 = 0, $1581 = 0, $1582 = 0, $1583 = 0, $1584 = 0, $1585 = 0, $1586 = 0, $1587 = 0, $1588 = 0, $1589 = 0;
 var $159 = 0, $1590 = 0, $1591 = 0, $1592 = 0, $1593 = 0, $1594 = 0, $1595 = 0, $1596 = 0, $1597 = 0, $1598 = 0, $1599 = 0, $16 = 0, $160 = 0, $1600 = 0, $1601 = 0, $1602 = 0, $1603 = 0, $1604 = 0, $1605 = 0, $1606 = 0;
 var $1607 = 0, $1608 = 0, $1609 = 0, $161 = 0, $1610 = 0, $1611 = 0, $1612 = 0, $1613 = 0, $1614 = 0, $1615 = 0, $1616 = 0, $1617 = 0, $1618 = 0, $1619 = 0, $162 = 0, $1620 = 0, $1621 = 0, $1622 = 0, $1623 = 0, $1624 = 0;
 var $1625 = 0, $1626 = 0, $1627 = 0, $1628 = 0, $1629 = 0, $163 = 0, $1630 = 0, $1631 = 0, $1632 = 0, $1633 = 0, $1634 = 0, $1635 = 0, $1636 = 0, $1637 = 0, $1638 = 0, $1639 = 0, $164 = 0, $1640 = 0, $1641 = 0, $1642 = 0;
 var $1643 = 0, $1644 = 0, $1645 = 0, $1646 = 0, $1647 = 0, $1648 = 0, $1649 = 0, $165 = 0, $1650 = 0, $1651 = 0, $1652 = 0, $1653 = 0, $1654 = 0, $1655 = 0, $1656 = 0, $1657 = 0, $1658 = 0, $1659 = 0, $166 = 0, $1660 = 0;
 var $1661 = 0, $1662 = 0, $1663 = 0, $1664 = 0, $1665 = 0, $1666 = 0, $1667 = 0, $1668 = 0, $1669 = 0, $167 = 0, $1670 = 0, $1671 = 0, $1672 = 0, $1673 = 0, $1674 = 0, $1675 = 0, $1676 = 0, $1677 = 0, $1678 = 0, $1679 = 0;
 var $168 = 0, $1680 = 0, $1681 = 0, $1682 = 0, $1683 = 0, $1684 = 0, $1685 = 0, $1686 = 0, $1687 = 0, $1688 = 0, $1689 = 0, $169 = 0, $1690 = 0, $1691 = 0, $1692 = 0, $1693 = 0, $1694 = 0, $1695 = 0, $1696 = 0, $1697 = 0;
 var $1698 = 0, $1699 = 0, $17 = 0, $170 = 0, $1700 = 0, $1701 = 0, $1702 = 0, $1703 = 0, $1704 = 0, $1705 = 0, $1706 = 0, $1707 = 0, $1708 = 0, $1709 = 0, $171 = 0, $1710 = 0, $1711 = 0, $1712 = 0, $1713 = 0, $1714 = 0;
 var $1715 = 0, $1716 = 0, $1717 = 0, $1718 = 0, $1719 = 0, $172 = 0, $1720 = 0, $1721 = 0, $1722 = 0, $1723 = 0, $1724 = 0, $1725 = 0, $1726 = 0, $1727 = 0, $1728 = 0, $1729 = 0, $173 = 0, $1730 = 0, $1731 = 0, $1732 = 0;
 var $1733 = 0, $1734 = 0, $1735 = 0, $1736 = 0, $1737 = 0, $1738 = 0, $1739 = 0, $174 = 0, $1740 = 0, $1741 = 0, $1742 = 0, $1743 = 0, $1744 = 0, $1745 = 0, $1746 = 0, $1747 = 0, $1748 = 0, $1749 = 0, $175 = 0, $1750 = 0;
 var $1751 = 0, $1752 = 0, $1753 = 0, $1754 = 0, $1755 = 0, $1756 = 0, $1757 = 0, $1758 = 0, $1759 = 0, $176 = 0, $1760 = 0, $1761 = 0, $1762 = 0, $1763 = 0, $1764 = 0, $1765 = 0, $1766 = 0, $1767 = 0, $1768 = 0, $1769 = 0;
 var $177 = 0, $1770 = 0, $1771 = 0, $1772 = 0, $1773 = 0, $1774 = 0, $1775 = 0, $1776 = 0, $1777 = 0, $1778 = 0, $1779 = 0, $178 = 0, $1780 = 0, $1781 = 0, $1782 = 0, $1783 = 0, $1784 = 0, $1785 = 0, $1786 = 0, $1787 = 0;
 var $1788 = 0, $1789 = 0, $179 = 0, $1790 = 0, $1791 = 0, $1792 = 0, $1793 = 0, $1794 = 0, $1795 = 0, $1796 = 0, $1797 = 0, $1798 = 0, $1799 = 0, $18 = 0, $180 = 0, $1800 = 0, $1801 = 0, $1802 = 0, $1803 = 0, $1804 = 0;
 var $1805 = 0, $1806 = 0, $1807 = 0, $1808 = 0, $1809 = 0, $181 = 0, $1810 = 0, $1811 = 0, $1812 = 0, $1813 = 0, $1814 = 0, $1815 = 0, $1816 = 0, $1817 = 0, $1818 = 0, $1819 = 0, $182 = 0, $1820 = 0, $1821 = 0, $1822 = 0;
 var $1823 = 0, $1824 = 0, $1825 = 0, $1826 = 0, $1827 = 0, $1828 = 0, $1829 = 0, $183 = 0, $1830 = 0, $1831 = 0, $1832 = 0, $1833 = 0, $1834 = 0, $1835 = 0, $1836 = 0, $1837 = 0, $1838 = 0, $1839 = 0, $184 = 0, $1840 = 0;
 var $1841 = 0, $1842 = 0, $1843 = 0, $1844 = 0, $1845 = 0, $1846 = 0, $1847 = 0, $1848 = 0, $1849 = 0, $185 = 0, $1850 = 0, $1851 = 0, $1852 = 0, $1853 = 0, $1854 = 0, $1855 = 0, $1856 = 0, $1857 = 0, $1858 = 0, $1859 = 0;
 var $186 = 0, $1860 = 0, $1861 = 0, $1862 = 0, $1863 = 0, $1864 = 0, $1865 = 0, $1866 = 0, $1867 = 0, $1868 = 0, $1869 = 0, $187 = 0, $1870 = 0, $1871 = 0, $1872 = 0, $1873 = 0, $1874 = 0, $1875 = 0, $1876 = 0, $1877 = 0;
 var $1878 = 0, $1879 = 0, $188 = 0, $1880 = 0, $1881 = 0, $1882 = 0, $1883 = 0, $1884 = 0, $1885 = 0, $1886 = 0, $1887 = 0, $1888 = 0, $1889 = 0, $189 = 0, $1890 = 0, $1891 = 0, $1892 = 0, $1893 = 0, $1894 = 0, $1895 = 0;
 var $1896 = 0, $1897 = 0, $1898 = 0, $1899 = 0, $19 = 0, $190 = 0, $1900 = 0, $1901 = 0, $1902 = 0, $1903 = 0, $1904 = 0, $1905 = 0, $1906 = 0, $1907 = 0, $1908 = 0, $1909 = 0, $191 = 0, $1910 = 0, $1911 = 0, $1912 = 0;
 var $1913 = 0, $1914 = 0, $1915 = 0, $1916 = 0, $1917 = 0, $1918 = 0, $1919 = 0, $192 = 0, $1920 = 0, $1921 = 0, $1922 = 0, $1923 = 0, $1924 = 0, $1925 = 0, $1926 = 0, $1927 = 0, $1928 = 0, $1929 = 0, $193 = 0, $1930 = 0;
 var $1931 = 0, $1932 = 0, $1933 = 0, $1934 = 0, $1935 = 0, $1936 = 0, $1937 = 0, $1938 = 0, $1939 = 0, $194 = 0, $1940 = 0, $1941 = 0, $1942 = 0, $1943 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0;
 var $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0;
 var $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0;
 var $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0;
 var $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0;
 var $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0;
 var $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0;
 var $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0;
 var $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0;
 var $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0;
 var $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0;
 var $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0;
 var $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0;
 var $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0;
 var $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0;
 var $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0;
 var $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0;
 var $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0;
 var $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0;
 var $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0;
 var $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0;
 var $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0;
 var $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0;
 var $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0;
 var $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0;
 var $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0;
 var $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0;
 var $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0;
 var $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0;
 var $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0;
 var $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0;
 var $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0;
 var $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0;
 var $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0;
 var $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0;
 var $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0;
 var $830 = 0, $831 = 0, $832 = 0, $833 = 0, $834 = 0, $835 = 0, $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0;
 var $849 = 0, $85 = 0, $850 = 0, $851 = 0, $852 = 0, $853 = 0, $854 = 0, $855 = 0, $856 = 0, $857 = 0, $858 = 0, $859 = 0, $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0;
 var $867 = 0, $868 = 0, $869 = 0, $87 = 0, $870 = 0, $871 = 0, $872 = 0, $873 = 0, $874 = 0, $875 = 0, $876 = 0, $877 = 0, $878 = 0, $879 = 0, $88 = 0, $880 = 0, $881 = 0, $882 = 0, $883 = 0, $884 = 0;
 var $885 = 0, $886 = 0, $887 = 0, $888 = 0, $889 = 0, $89 = 0, $890 = 0, $891 = 0, $892 = 0, $893 = 0, $894 = 0, $895 = 0, $896 = 0, $897 = 0, $898 = 0, $899 = 0, $9 = 0, $90 = 0, $900 = 0, $901 = 0;
 var $902 = 0, $903 = 0, $904 = 0, $905 = 0, $906 = 0, $907 = 0, $908 = 0, $909 = 0, $91 = 0, $910 = 0, $911 = 0, $912 = 0, $913 = 0, $914 = 0, $915 = 0, $916 = 0, $917 = 0, $918 = 0, $919 = 0, $92 = 0;
 var $920 = 0, $921 = 0, $922 = 0, $923 = 0, $924 = 0, $925 = 0, $926 = 0, $927 = 0, $928 = 0, $929 = 0, $93 = 0, $930 = 0, $931 = 0, $932 = 0, $933 = 0, $934 = 0, $935 = 0, $936 = 0, $937 = 0, $938 = 0;
 var $939 = 0, $94 = 0, $940 = 0, $941 = 0, $942 = 0, $943 = 0, $944 = 0, $945 = 0, $946 = 0, $947 = 0, $948 = 0, $949 = 0, $95 = 0, $950 = 0, $951 = 0, $952 = 0, $953 = 0, $954 = 0, $955 = 0, $956 = 0;
 var $957 = 0, $958 = 0, $959 = 0, $96 = 0, $960 = 0, $961 = 0, $962 = 0, $963 = 0, $964 = 0, $965 = 0, $966 = 0, $967 = 0, $968 = 0, $969 = 0, $97 = 0, $970 = 0, $971 = 0, $972 = 0, $973 = 0, $974 = 0;
 var $975 = 0, $976 = 0, $977 = 0, $978 = 0, $979 = 0, $98 = 0, $980 = 0, $981 = 0, $982 = 0, $983 = 0, $984 = 0, $985 = 0, $986 = 0, $987 = 0, $988 = 0, $989 = 0, $99 = 0, $990 = 0, $991 = 0, $992 = 0;
 var $993 = 0, $994 = 0, $995 = 0, $996 = 0, $997 = 0, $998 = 0, $999 = 0, $div = 0, $div1074 = 0, $div1075 = 0, $div1076 = 0, $div1077 = 0, $div1078 = 0, $div1079 = 0, $div1080 = 0, $div1081 = 0, $div1082 = 0, $div1083 = 0, $div1084 = 0, $div1085 = 0;
 var $div1086 = 0, $div1087 = 0, $div1088 = 0, $div1089 = 0, $div1090 = 0, $div1091 = 0, $div1092 = 0, $div1093 = 0, $div1094 = 0, $div1095 = 0, $div1096 = 0, $div1106 = 0, $div1107 = 0, $div1108 = 0, $div1109 = 0, $div1110 = 0, $div1111 = 0, $div1112 = 0, $div1113 = 0, $div1114 = 0;
 var $div1115 = 0, $div1116 = 0, $div1117 = 0, $div1118 = 0, $div1119 = 0, $div1120 = 0, $div1121 = 0, $div1122 = 0, $div1123 = 0, $div1124 = 0, $div1125 = 0, $div1126 = 0, $div1127 = 0, $div1128 = 0, $div1129 = 0, $trunc = 0, $trunc$clear = 0, $trunc1097 = 0, $trunc1097$clear = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$0>>2]|0;
 $6 = ((($0)) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($0)) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($0)) + 36|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($0)) + 40|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($0)) + 48|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ((($0)) + 56|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ((($13)) + 24|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = $19 ^ -1;
 $21 = ((($13)) + 9|0);
 $22 = HEAP8[$21>>0]|0;
 $23 = $22&255;
 $24 = $17 & $20;
 $25 = ($15|0)==(0|0);
 $26 = (($4) + -1)|0;
 $27 = ($4|0)==(0);
 if ($25) {
  if ($27) {
   return;
  }
  $39 = (($2) + 7)|0;
  $40 = (($39|0) / 8)&-1;
  $trunc1097 = $2&255;
  $41 = ((($13)) + 28|0);
  $42 = ((($13)) + 12|0);
  $43 = ((($13)) + 32|0);
  $44 = ((($13)) + 29|0);
  $45 = ((($13)) + 16|0);
  $46 = ((($13)) + 33|0);
  $47 = ((($13)) + 30|0);
  $48 = ((($13)) + 20|0);
  $49 = ((($13)) + 34|0);
  $$010321163 = $5;$$010481162 = $9;$991 = $26;
  L6: while(1) {
   $trunc1097$clear = $trunc1097 & 7;
   switch ($trunc1097$clear<<24>>24) {
   case 0:  {
    $$0966 = $40;$$11033 = $$010321163;$$11049 = $$010481162;
    label = 7;
    break;
   }
   case 7:  {
    $$1967 = $40;$$21034 = $$010321163;$$21050 = $$010481162;
    label = 16;
    break;
   }
   case 6:  {
    $$2968 = $40;$$31035 = $$010321163;$$31051 = $$010481162;
    label = 25;
    break;
   }
   case 5:  {
    $$3969 = $40;$$41036 = $$010321163;$$41052 = $$010481162;
    label = 34;
    break;
   }
   case 4:  {
    $$4970 = $40;$$51037 = $$010321163;$$51053 = $$010481162;
    label = 43;
    break;
   }
   case 3:  {
    $$5971 = $40;$$61038 = $$010321163;$$61054 = $$010481162;
    label = 52;
    break;
   }
   case 2:  {
    $$6972 = $40;$$71039 = $$010321163;$$71055 = $$010481162;
    label = 61;
    break;
   }
   case 1:  {
    $$7973 = $40;$$81040 = $$010321163;$$81056 = $$010481162;
    label = 70;
    break;
   }
   default: {
    label = 79;
    break L6;
   }
   }
   while(1) {
    if ((label|0) == 7) {
     label = 0;
     switch ($22<<24>>24) {
     case 1:  {
      $50 = HEAP8[$$11033>>0]|0;
      $51 = $50&255;
      $52 = HEAP8[$41>>0]|0;
      $53 = $52&255;
      $54 = (79212 + ($53<<2)|0);
      $55 = HEAP32[$54>>2]|0;
      $56 = HEAP32[$42>>2]|0;
      $57 = $56 & $51;
      $58 = HEAP8[$43>>0]|0;
      $59 = $58&255;
      $60 = $57 >>> $59;
      $61 = (($55) + ($60)|0);
      $62 = HEAP8[$44>>0]|0;
      $63 = $62&255;
      $64 = (79212 + ($63<<2)|0);
      $65 = HEAP32[$64>>2]|0;
      $66 = HEAP32[$45>>2]|0;
      $67 = $66 & $51;
      $68 = HEAP8[$46>>0]|0;
      $69 = $68&255;
      $70 = $67 >>> $69;
      $71 = (($65) + ($70)|0);
      $72 = HEAP8[$47>>0]|0;
      $73 = $72&255;
      $74 = (79212 + ($73<<2)|0);
      $75 = HEAP32[$74>>2]|0;
      $76 = HEAP32[$48>>2]|0;
      $77 = $76 & $51;
      $78 = HEAP8[$49>>0]|0;
      $79 = $78&255;
      $80 = $77 >>> $79;
      $81 = (($75) + ($80)|0);
      $$01014$ph = $51;$$0982$shrunk$ph$in = $71;$$0998$shrunk$ph$in = $61;$$sink = $81;
      label = 12;
      break;
     }
     case 2:  {
      $82 = HEAP16[$$11033>>1]|0;
      $83 = $82&65535;
      $84 = HEAP8[$41>>0]|0;
      $85 = $84&255;
      $86 = (79212 + ($85<<2)|0);
      $87 = HEAP32[$86>>2]|0;
      $88 = HEAP32[$42>>2]|0;
      $89 = $88 & $83;
      $90 = HEAP8[$43>>0]|0;
      $91 = $90&255;
      $92 = $89 >>> $91;
      $93 = (($87) + ($92)|0);
      $94 = HEAP8[$44>>0]|0;
      $95 = $94&255;
      $96 = (79212 + ($95<<2)|0);
      $97 = HEAP32[$96>>2]|0;
      $98 = HEAP32[$45>>2]|0;
      $99 = $98 & $83;
      $100 = HEAP8[$46>>0]|0;
      $101 = $100&255;
      $102 = $99 >>> $101;
      $103 = (($97) + ($102)|0);
      $104 = HEAP8[$47>>0]|0;
      $105 = $104&255;
      $106 = (79212 + ($105<<2)|0);
      $107 = HEAP32[$106>>2]|0;
      $108 = HEAP32[$48>>2]|0;
      $109 = $108 & $83;
      $110 = HEAP8[$49>>0]|0;
      $111 = $110&255;
      $112 = $109 >>> $111;
      $113 = (($107) + ($112)|0);
      $$01014$ph = $83;$$0982$shrunk$ph$in = $103;$$0998$shrunk$ph$in = $93;$$sink = $113;
      label = 12;
      break;
     }
     case 3:  {
      $114 = HEAP8[$43>>0]|0;
      $div1124 = ($114&255) >>> 3;
      $115 = $div1124&255;
      $116 = (($$11033) + ($115)|0);
      $117 = HEAP8[$46>>0]|0;
      $div1125 = ($117&255) >>> 3;
      $118 = $div1125&255;
      $119 = (($$11033) + ($118)|0);
      $120 = HEAP8[$49>>0]|0;
      $div1126 = ($120&255) >>> 3;
      $121 = $div1126&255;
      $122 = (($$11033) + ($121)|0);
      $$01014$ph = 0;$$0982$shrunk$ph$in = $119;$$0998$shrunk$ph$in = $116;$$sink = $122;
      label = 12;
      break;
     }
     case 4:  {
      $123 = HEAP32[$$11033>>2]|0;
      $124 = HEAP8[$41>>0]|0;
      $125 = $124&255;
      $126 = (79212 + ($125<<2)|0);
      $127 = HEAP32[$126>>2]|0;
      $128 = HEAP32[$42>>2]|0;
      $129 = $128 & $123;
      $130 = HEAP8[$43>>0]|0;
      $131 = $130&255;
      $132 = $129 >>> $131;
      $133 = (($127) + ($132)|0);
      $134 = HEAP8[$44>>0]|0;
      $135 = $134&255;
      $136 = (79212 + ($135<<2)|0);
      $137 = HEAP32[$136>>2]|0;
      $138 = HEAP32[$45>>2]|0;
      $139 = $138 & $123;
      $140 = HEAP8[$46>>0]|0;
      $141 = $140&255;
      $142 = $139 >>> $141;
      $143 = (($137) + ($142)|0);
      $144 = HEAP8[$47>>0]|0;
      $145 = $144&255;
      $146 = (79212 + ($145<<2)|0);
      $147 = HEAP32[$146>>2]|0;
      $148 = HEAP32[$48>>2]|0;
      $149 = $148 & $123;
      $150 = HEAP8[$49>>0]|0;
      $151 = $150&255;
      $152 = $149 >>> $151;
      $153 = (($147) + ($152)|0);
      $$01014$ph = $123;$$0982$shrunk$ph$in = $143;$$0998$shrunk$ph$in = $133;$$sink = $153;
      label = 12;
      break;
     }
     default: {
      $$01014 = 0;$$0974$shrunk = 0;$$0982$shrunk = 0;$$0998$shrunk = 0;
     }
     }
     if ((label|0) == 12) {
      label = 0;
      $$0982$shrunk$ph = HEAP8[$$0982$shrunk$ph$in>>0]|0;
      $$0998$shrunk$ph = HEAP8[$$0998$shrunk$ph$in>>0]|0;
      $154 = HEAP8[$$sink>>0]|0;
      $$01014 = $$01014$ph;$$0974$shrunk = $154;$$0982$shrunk = $$0982$shrunk$ph;$$0998$shrunk = $$0998$shrunk$ph;
     }
     $155 = $$01014 & $20;
     $156 = ($155|0)==($24|0);
     if (!($156)) {
      $$0974 = $$0974$shrunk&255;
      $$0982 = $$0982$shrunk&255;
      $157 = $$0998$shrunk & -32;
      $158 = $157&255;
      $159 = $$0982 >>> 5;
      $160 = $159 << 2;
      $161 = $160 | $158;
      $162 = $$0974 >>> 6;
      $163 = $161 | $162;
      $164 = $163&255;
      HEAP8[$$11049>>0] = $164;
     }
     $165 = ((($$11049)) + 1|0);
     $166 = (($$11033) + ($23)|0);
     $$1967 = $$0966;$$21034 = $166;$$21050 = $165;
     label = 16;
     continue;
    }
    else if ((label|0) == 16) {
     label = 0;
     switch ($22<<24>>24) {
     case 1:  {
      $167 = HEAP8[$$21034>>0]|0;
      $168 = $167&255;
      $169 = HEAP8[$41>>0]|0;
      $170 = $169&255;
      $171 = (79212 + ($170<<2)|0);
      $172 = HEAP32[$171>>2]|0;
      $173 = HEAP32[$42>>2]|0;
      $174 = $173 & $168;
      $175 = HEAP8[$43>>0]|0;
      $176 = $175&255;
      $177 = $174 >>> $176;
      $178 = (($172) + ($177)|0);
      $179 = HEAP8[$44>>0]|0;
      $180 = $179&255;
      $181 = (79212 + ($180<<2)|0);
      $182 = HEAP32[$181>>2]|0;
      $183 = HEAP32[$45>>2]|0;
      $184 = $183 & $168;
      $185 = HEAP8[$46>>0]|0;
      $186 = $185&255;
      $187 = $184 >>> $186;
      $188 = (($182) + ($187)|0);
      $189 = HEAP8[$47>>0]|0;
      $190 = $189&255;
      $191 = (79212 + ($190<<2)|0);
      $192 = HEAP32[$191>>2]|0;
      $193 = HEAP32[$48>>2]|0;
      $194 = $193 & $168;
      $195 = HEAP8[$49>>0]|0;
      $196 = $195&255;
      $197 = $194 >>> $196;
      $198 = (($192) + ($197)|0);
      $$11015$ph = $168;$$1983$shrunk$ph$in = $188;$$1999$shrunk$ph$in = $178;$$sink1131 = $198;
      label = 21;
      break;
     }
     case 2:  {
      $199 = HEAP16[$$21034>>1]|0;
      $200 = $199&65535;
      $201 = HEAP8[$41>>0]|0;
      $202 = $201&255;
      $203 = (79212 + ($202<<2)|0);
      $204 = HEAP32[$203>>2]|0;
      $205 = HEAP32[$42>>2]|0;
      $206 = $205 & $200;
      $207 = HEAP8[$43>>0]|0;
      $208 = $207&255;
      $209 = $206 >>> $208;
      $210 = (($204) + ($209)|0);
      $211 = HEAP8[$44>>0]|0;
      $212 = $211&255;
      $213 = (79212 + ($212<<2)|0);
      $214 = HEAP32[$213>>2]|0;
      $215 = HEAP32[$45>>2]|0;
      $216 = $215 & $200;
      $217 = HEAP8[$46>>0]|0;
      $218 = $217&255;
      $219 = $216 >>> $218;
      $220 = (($214) + ($219)|0);
      $221 = HEAP8[$47>>0]|0;
      $222 = $221&255;
      $223 = (79212 + ($222<<2)|0);
      $224 = HEAP32[$223>>2]|0;
      $225 = HEAP32[$48>>2]|0;
      $226 = $225 & $200;
      $227 = HEAP8[$49>>0]|0;
      $228 = $227&255;
      $229 = $226 >>> $228;
      $230 = (($224) + ($229)|0);
      $$11015$ph = $200;$$1983$shrunk$ph$in = $220;$$1999$shrunk$ph$in = $210;$$sink1131 = $230;
      label = 21;
      break;
     }
     case 3:  {
      $231 = HEAP8[$43>>0]|0;
      $div1121 = ($231&255) >>> 3;
      $232 = $div1121&255;
      $233 = (($$21034) + ($232)|0);
      $234 = HEAP8[$46>>0]|0;
      $div1122 = ($234&255) >>> 3;
      $235 = $div1122&255;
      $236 = (($$21034) + ($235)|0);
      $237 = HEAP8[$49>>0]|0;
      $div1123 = ($237&255) >>> 3;
      $238 = $div1123&255;
      $239 = (($$21034) + ($238)|0);
      $$11015$ph = 0;$$1983$shrunk$ph$in = $236;$$1999$shrunk$ph$in = $233;$$sink1131 = $239;
      label = 21;
      break;
     }
     case 4:  {
      $240 = HEAP32[$$21034>>2]|0;
      $241 = HEAP8[$41>>0]|0;
      $242 = $241&255;
      $243 = (79212 + ($242<<2)|0);
      $244 = HEAP32[$243>>2]|0;
      $245 = HEAP32[$42>>2]|0;
      $246 = $245 & $240;
      $247 = HEAP8[$43>>0]|0;
      $248 = $247&255;
      $249 = $246 >>> $248;
      $250 = (($244) + ($249)|0);
      $251 = HEAP8[$44>>0]|0;
      $252 = $251&255;
      $253 = (79212 + ($252<<2)|0);
      $254 = HEAP32[$253>>2]|0;
      $255 = HEAP32[$45>>2]|0;
      $256 = $255 & $240;
      $257 = HEAP8[$46>>0]|0;
      $258 = $257&255;
      $259 = $256 >>> $258;
      $260 = (($254) + ($259)|0);
      $261 = HEAP8[$47>>0]|0;
      $262 = $261&255;
      $263 = (79212 + ($262<<2)|0);
      $264 = HEAP32[$263>>2]|0;
      $265 = HEAP32[$48>>2]|0;
      $266 = $265 & $240;
      $267 = HEAP8[$49>>0]|0;
      $268 = $267&255;
      $269 = $266 >>> $268;
      $270 = (($264) + ($269)|0);
      $$11015$ph = $240;$$1983$shrunk$ph$in = $260;$$1999$shrunk$ph$in = $250;$$sink1131 = $270;
      label = 21;
      break;
     }
     default: {
      $$11015 = 0;$$1975$shrunk = 0;$$1983$shrunk = 0;$$1999$shrunk = 0;
     }
     }
     if ((label|0) == 21) {
      label = 0;
      $$1983$shrunk$ph = HEAP8[$$1983$shrunk$ph$in>>0]|0;
      $$1999$shrunk$ph = HEAP8[$$1999$shrunk$ph$in>>0]|0;
      $271 = HEAP8[$$sink1131>>0]|0;
      $$11015 = $$11015$ph;$$1975$shrunk = $271;$$1983$shrunk = $$1983$shrunk$ph;$$1999$shrunk = $$1999$shrunk$ph;
     }
     $272 = $$11015 & $20;
     $273 = ($272|0)==($24|0);
     if (!($273)) {
      $$1975 = $$1975$shrunk&255;
      $$1983 = $$1983$shrunk&255;
      $274 = $$1999$shrunk & -32;
      $275 = $274&255;
      $276 = $$1983 >>> 5;
      $277 = $276 << 2;
      $278 = $277 | $275;
      $279 = $$1975 >>> 6;
      $280 = $278 | $279;
      $281 = $280&255;
      HEAP8[$$21050>>0] = $281;
     }
     $282 = ((($$21050)) + 1|0);
     $283 = (($$21034) + ($23)|0);
     $$2968 = $$1967;$$31035 = $283;$$31051 = $282;
     label = 25;
     continue;
    }
    else if ((label|0) == 25) {
     label = 0;
     switch ($22<<24>>24) {
     case 1:  {
      $284 = HEAP8[$$31035>>0]|0;
      $285 = $284&255;
      $286 = HEAP8[$41>>0]|0;
      $287 = $286&255;
      $288 = (79212 + ($287<<2)|0);
      $289 = HEAP32[$288>>2]|0;
      $290 = HEAP32[$42>>2]|0;
      $291 = $290 & $285;
      $292 = HEAP8[$43>>0]|0;
      $293 = $292&255;
      $294 = $291 >>> $293;
      $295 = (($289) + ($294)|0);
      $296 = HEAP8[$44>>0]|0;
      $297 = $296&255;
      $298 = (79212 + ($297<<2)|0);
      $299 = HEAP32[$298>>2]|0;
      $300 = HEAP32[$45>>2]|0;
      $301 = $300 & $285;
      $302 = HEAP8[$46>>0]|0;
      $303 = $302&255;
      $304 = $301 >>> $303;
      $305 = (($299) + ($304)|0);
      $306 = HEAP8[$47>>0]|0;
      $307 = $306&255;
      $308 = (79212 + ($307<<2)|0);
      $309 = HEAP32[$308>>2]|0;
      $310 = HEAP32[$48>>2]|0;
      $311 = $310 & $285;
      $312 = HEAP8[$49>>0]|0;
      $313 = $312&255;
      $314 = $311 >>> $313;
      $315 = (($309) + ($314)|0);
      $$21000$shrunk$ph$in = $295;$$21016$ph = $285;$$2984$shrunk$ph$in = $305;$$sink1133 = $315;
      label = 30;
      break;
     }
     case 2:  {
      $316 = HEAP16[$$31035>>1]|0;
      $317 = $316&65535;
      $318 = HEAP8[$41>>0]|0;
      $319 = $318&255;
      $320 = (79212 + ($319<<2)|0);
      $321 = HEAP32[$320>>2]|0;
      $322 = HEAP32[$42>>2]|0;
      $323 = $322 & $317;
      $324 = HEAP8[$43>>0]|0;
      $325 = $324&255;
      $326 = $323 >>> $325;
      $327 = (($321) + ($326)|0);
      $328 = HEAP8[$44>>0]|0;
      $329 = $328&255;
      $330 = (79212 + ($329<<2)|0);
      $331 = HEAP32[$330>>2]|0;
      $332 = HEAP32[$45>>2]|0;
      $333 = $332 & $317;
      $334 = HEAP8[$46>>0]|0;
      $335 = $334&255;
      $336 = $333 >>> $335;
      $337 = (($331) + ($336)|0);
      $338 = HEAP8[$47>>0]|0;
      $339 = $338&255;
      $340 = (79212 + ($339<<2)|0);
      $341 = HEAP32[$340>>2]|0;
      $342 = HEAP32[$48>>2]|0;
      $343 = $342 & $317;
      $344 = HEAP8[$49>>0]|0;
      $345 = $344&255;
      $346 = $343 >>> $345;
      $347 = (($341) + ($346)|0);
      $$21000$shrunk$ph$in = $327;$$21016$ph = $317;$$2984$shrunk$ph$in = $337;$$sink1133 = $347;
      label = 30;
      break;
     }
     case 3:  {
      $348 = HEAP8[$43>>0]|0;
      $div1118 = ($348&255) >>> 3;
      $349 = $div1118&255;
      $350 = (($$31035) + ($349)|0);
      $351 = HEAP8[$46>>0]|0;
      $div1119 = ($351&255) >>> 3;
      $352 = $div1119&255;
      $353 = (($$31035) + ($352)|0);
      $354 = HEAP8[$49>>0]|0;
      $div1120 = ($354&255) >>> 3;
      $355 = $div1120&255;
      $356 = (($$31035) + ($355)|0);
      $$21000$shrunk$ph$in = $350;$$21016$ph = 0;$$2984$shrunk$ph$in = $353;$$sink1133 = $356;
      label = 30;
      break;
     }
     case 4:  {
      $357 = HEAP32[$$31035>>2]|0;
      $358 = HEAP8[$41>>0]|0;
      $359 = $358&255;
      $360 = (79212 + ($359<<2)|0);
      $361 = HEAP32[$360>>2]|0;
      $362 = HEAP32[$42>>2]|0;
      $363 = $362 & $357;
      $364 = HEAP8[$43>>0]|0;
      $365 = $364&255;
      $366 = $363 >>> $365;
      $367 = (($361) + ($366)|0);
      $368 = HEAP8[$44>>0]|0;
      $369 = $368&255;
      $370 = (79212 + ($369<<2)|0);
      $371 = HEAP32[$370>>2]|0;
      $372 = HEAP32[$45>>2]|0;
      $373 = $372 & $357;
      $374 = HEAP8[$46>>0]|0;
      $375 = $374&255;
      $376 = $373 >>> $375;
      $377 = (($371) + ($376)|0);
      $378 = HEAP8[$47>>0]|0;
      $379 = $378&255;
      $380 = (79212 + ($379<<2)|0);
      $381 = HEAP32[$380>>2]|0;
      $382 = HEAP32[$48>>2]|0;
      $383 = $382 & $357;
      $384 = HEAP8[$49>>0]|0;
      $385 = $384&255;
      $386 = $383 >>> $385;
      $387 = (($381) + ($386)|0);
      $$21000$shrunk$ph$in = $367;$$21016$ph = $357;$$2984$shrunk$ph$in = $377;$$sink1133 = $387;
      label = 30;
      break;
     }
     default: {
      $$21000$shrunk = 0;$$21016 = 0;$$2976$shrunk = 0;$$2984$shrunk = 0;
     }
     }
     if ((label|0) == 30) {
      label = 0;
      $$2984$shrunk$ph = HEAP8[$$2984$shrunk$ph$in>>0]|0;
      $$21000$shrunk$ph = HEAP8[$$21000$shrunk$ph$in>>0]|0;
      $388 = HEAP8[$$sink1133>>0]|0;
      $$21000$shrunk = $$21000$shrunk$ph;$$21016 = $$21016$ph;$$2976$shrunk = $388;$$2984$shrunk = $$2984$shrunk$ph;
     }
     $389 = $$21016 & $20;
     $390 = ($389|0)==($24|0);
     if (!($390)) {
      $$2976 = $$2976$shrunk&255;
      $$2984 = $$2984$shrunk&255;
      $391 = $$21000$shrunk & -32;
      $392 = $391&255;
      $393 = $$2984 >>> 5;
      $394 = $393 << 2;
      $395 = $394 | $392;
      $396 = $$2976 >>> 6;
      $397 = $395 | $396;
      $398 = $397&255;
      HEAP8[$$31051>>0] = $398;
     }
     $399 = ((($$31051)) + 1|0);
     $400 = (($$31035) + ($23)|0);
     $$3969 = $$2968;$$41036 = $400;$$41052 = $399;
     label = 34;
     continue;
    }
    else if ((label|0) == 34) {
     label = 0;
     switch ($22<<24>>24) {
     case 1:  {
      $401 = HEAP8[$$41036>>0]|0;
      $402 = $401&255;
      $403 = HEAP8[$41>>0]|0;
      $404 = $403&255;
      $405 = (79212 + ($404<<2)|0);
      $406 = HEAP32[$405>>2]|0;
      $407 = HEAP32[$42>>2]|0;
      $408 = $407 & $402;
      $409 = HEAP8[$43>>0]|0;
      $410 = $409&255;
      $411 = $408 >>> $410;
      $412 = (($406) + ($411)|0);
      $413 = HEAP8[$44>>0]|0;
      $414 = $413&255;
      $415 = (79212 + ($414<<2)|0);
      $416 = HEAP32[$415>>2]|0;
      $417 = HEAP32[$45>>2]|0;
      $418 = $417 & $402;
      $419 = HEAP8[$46>>0]|0;
      $420 = $419&255;
      $421 = $418 >>> $420;
      $422 = (($416) + ($421)|0);
      $423 = HEAP8[$47>>0]|0;
      $424 = $423&255;
      $425 = (79212 + ($424<<2)|0);
      $426 = HEAP32[$425>>2]|0;
      $427 = HEAP32[$48>>2]|0;
      $428 = $427 & $402;
      $429 = HEAP8[$49>>0]|0;
      $430 = $429&255;
      $431 = $428 >>> $430;
      $432 = (($426) + ($431)|0);
      $$31001$shrunk$ph$in = $412;$$31017$ph = $402;$$3985$shrunk$ph$in = $422;$$sink1135 = $432;
      label = 39;
      break;
     }
     case 2:  {
      $433 = HEAP16[$$41036>>1]|0;
      $434 = $433&65535;
      $435 = HEAP8[$41>>0]|0;
      $436 = $435&255;
      $437 = (79212 + ($436<<2)|0);
      $438 = HEAP32[$437>>2]|0;
      $439 = HEAP32[$42>>2]|0;
      $440 = $439 & $434;
      $441 = HEAP8[$43>>0]|0;
      $442 = $441&255;
      $443 = $440 >>> $442;
      $444 = (($438) + ($443)|0);
      $445 = HEAP8[$44>>0]|0;
      $446 = $445&255;
      $447 = (79212 + ($446<<2)|0);
      $448 = HEAP32[$447>>2]|0;
      $449 = HEAP32[$45>>2]|0;
      $450 = $449 & $434;
      $451 = HEAP8[$46>>0]|0;
      $452 = $451&255;
      $453 = $450 >>> $452;
      $454 = (($448) + ($453)|0);
      $455 = HEAP8[$47>>0]|0;
      $456 = $455&255;
      $457 = (79212 + ($456<<2)|0);
      $458 = HEAP32[$457>>2]|0;
      $459 = HEAP32[$48>>2]|0;
      $460 = $459 & $434;
      $461 = HEAP8[$49>>0]|0;
      $462 = $461&255;
      $463 = $460 >>> $462;
      $464 = (($458) + ($463)|0);
      $$31001$shrunk$ph$in = $444;$$31017$ph = $434;$$3985$shrunk$ph$in = $454;$$sink1135 = $464;
      label = 39;
      break;
     }
     case 3:  {
      $465 = HEAP8[$43>>0]|0;
      $div1115 = ($465&255) >>> 3;
      $466 = $div1115&255;
      $467 = (($$41036) + ($466)|0);
      $468 = HEAP8[$46>>0]|0;
      $div1116 = ($468&255) >>> 3;
      $469 = $div1116&255;
      $470 = (($$41036) + ($469)|0);
      $471 = HEAP8[$49>>0]|0;
      $div1117 = ($471&255) >>> 3;
      $472 = $div1117&255;
      $473 = (($$41036) + ($472)|0);
      $$31001$shrunk$ph$in = $467;$$31017$ph = 0;$$3985$shrunk$ph$in = $470;$$sink1135 = $473;
      label = 39;
      break;
     }
     case 4:  {
      $474 = HEAP32[$$41036>>2]|0;
      $475 = HEAP8[$41>>0]|0;
      $476 = $475&255;
      $477 = (79212 + ($476<<2)|0);
      $478 = HEAP32[$477>>2]|0;
      $479 = HEAP32[$42>>2]|0;
      $480 = $479 & $474;
      $481 = HEAP8[$43>>0]|0;
      $482 = $481&255;
      $483 = $480 >>> $482;
      $484 = (($478) + ($483)|0);
      $485 = HEAP8[$44>>0]|0;
      $486 = $485&255;
      $487 = (79212 + ($486<<2)|0);
      $488 = HEAP32[$487>>2]|0;
      $489 = HEAP32[$45>>2]|0;
      $490 = $489 & $474;
      $491 = HEAP8[$46>>0]|0;
      $492 = $491&255;
      $493 = $490 >>> $492;
      $494 = (($488) + ($493)|0);
      $495 = HEAP8[$47>>0]|0;
      $496 = $495&255;
      $497 = (79212 + ($496<<2)|0);
      $498 = HEAP32[$497>>2]|0;
      $499 = HEAP32[$48>>2]|0;
      $500 = $499 & $474;
      $501 = HEAP8[$49>>0]|0;
      $502 = $501&255;
      $503 = $500 >>> $502;
      $504 = (($498) + ($503)|0);
      $$31001$shrunk$ph$in = $484;$$31017$ph = $474;$$3985$shrunk$ph$in = $494;$$sink1135 = $504;
      label = 39;
      break;
     }
     default: {
      $$31001$shrunk = 0;$$31017 = 0;$$3977$shrunk = 0;$$3985$shrunk = 0;
     }
     }
     if ((label|0) == 39) {
      label = 0;
      $$3985$shrunk$ph = HEAP8[$$3985$shrunk$ph$in>>0]|0;
      $$31001$shrunk$ph = HEAP8[$$31001$shrunk$ph$in>>0]|0;
      $505 = HEAP8[$$sink1135>>0]|0;
      $$31001$shrunk = $$31001$shrunk$ph;$$31017 = $$31017$ph;$$3977$shrunk = $505;$$3985$shrunk = $$3985$shrunk$ph;
     }
     $506 = $$31017 & $20;
     $507 = ($506|0)==($24|0);
     if (!($507)) {
      $$3977 = $$3977$shrunk&255;
      $$3985 = $$3985$shrunk&255;
      $508 = $$31001$shrunk & -32;
      $509 = $508&255;
      $510 = $$3985 >>> 5;
      $511 = $510 << 2;
      $512 = $511 | $509;
      $513 = $$3977 >>> 6;
      $514 = $512 | $513;
      $515 = $514&255;
      HEAP8[$$41052>>0] = $515;
     }
     $516 = ((($$41052)) + 1|0);
     $517 = (($$41036) + ($23)|0);
     $$4970 = $$3969;$$51037 = $517;$$51053 = $516;
     label = 43;
     continue;
    }
    else if ((label|0) == 43) {
     label = 0;
     switch ($22<<24>>24) {
     case 1:  {
      $518 = HEAP8[$$51037>>0]|0;
      $519 = $518&255;
      $520 = HEAP8[$41>>0]|0;
      $521 = $520&255;
      $522 = (79212 + ($521<<2)|0);
      $523 = HEAP32[$522>>2]|0;
      $524 = HEAP32[$42>>2]|0;
      $525 = $524 & $519;
      $526 = HEAP8[$43>>0]|0;
      $527 = $526&255;
      $528 = $525 >>> $527;
      $529 = (($523) + ($528)|0);
      $530 = HEAP8[$44>>0]|0;
      $531 = $530&255;
      $532 = (79212 + ($531<<2)|0);
      $533 = HEAP32[$532>>2]|0;
      $534 = HEAP32[$45>>2]|0;
      $535 = $534 & $519;
      $536 = HEAP8[$46>>0]|0;
      $537 = $536&255;
      $538 = $535 >>> $537;
      $539 = (($533) + ($538)|0);
      $540 = HEAP8[$47>>0]|0;
      $541 = $540&255;
      $542 = (79212 + ($541<<2)|0);
      $543 = HEAP32[$542>>2]|0;
      $544 = HEAP32[$48>>2]|0;
      $545 = $544 & $519;
      $546 = HEAP8[$49>>0]|0;
      $547 = $546&255;
      $548 = $545 >>> $547;
      $549 = (($543) + ($548)|0);
      $$41002$shrunk$ph$in = $529;$$41018$ph = $519;$$4986$shrunk$ph$in = $539;$$sink1137 = $549;
      label = 48;
      break;
     }
     case 2:  {
      $550 = HEAP16[$$51037>>1]|0;
      $551 = $550&65535;
      $552 = HEAP8[$41>>0]|0;
      $553 = $552&255;
      $554 = (79212 + ($553<<2)|0);
      $555 = HEAP32[$554>>2]|0;
      $556 = HEAP32[$42>>2]|0;
      $557 = $556 & $551;
      $558 = HEAP8[$43>>0]|0;
      $559 = $558&255;
      $560 = $557 >>> $559;
      $561 = (($555) + ($560)|0);
      $562 = HEAP8[$44>>0]|0;
      $563 = $562&255;
      $564 = (79212 + ($563<<2)|0);
      $565 = HEAP32[$564>>2]|0;
      $566 = HEAP32[$45>>2]|0;
      $567 = $566 & $551;
      $568 = HEAP8[$46>>0]|0;
      $569 = $568&255;
      $570 = $567 >>> $569;
      $571 = (($565) + ($570)|0);
      $572 = HEAP8[$47>>0]|0;
      $573 = $572&255;
      $574 = (79212 + ($573<<2)|0);
      $575 = HEAP32[$574>>2]|0;
      $576 = HEAP32[$48>>2]|0;
      $577 = $576 & $551;
      $578 = HEAP8[$49>>0]|0;
      $579 = $578&255;
      $580 = $577 >>> $579;
      $581 = (($575) + ($580)|0);
      $$41002$shrunk$ph$in = $561;$$41018$ph = $551;$$4986$shrunk$ph$in = $571;$$sink1137 = $581;
      label = 48;
      break;
     }
     case 3:  {
      $582 = HEAP8[$43>>0]|0;
      $div1112 = ($582&255) >>> 3;
      $583 = $div1112&255;
      $584 = (($$51037) + ($583)|0);
      $585 = HEAP8[$46>>0]|0;
      $div1113 = ($585&255) >>> 3;
      $586 = $div1113&255;
      $587 = (($$51037) + ($586)|0);
      $588 = HEAP8[$49>>0]|0;
      $div1114 = ($588&255) >>> 3;
      $589 = $div1114&255;
      $590 = (($$51037) + ($589)|0);
      $$41002$shrunk$ph$in = $584;$$41018$ph = 0;$$4986$shrunk$ph$in = $587;$$sink1137 = $590;
      label = 48;
      break;
     }
     case 4:  {
      $591 = HEAP32[$$51037>>2]|0;
      $592 = HEAP8[$41>>0]|0;
      $593 = $592&255;
      $594 = (79212 + ($593<<2)|0);
      $595 = HEAP32[$594>>2]|0;
      $596 = HEAP32[$42>>2]|0;
      $597 = $596 & $591;
      $598 = HEAP8[$43>>0]|0;
      $599 = $598&255;
      $600 = $597 >>> $599;
      $601 = (($595) + ($600)|0);
      $602 = HEAP8[$44>>0]|0;
      $603 = $602&255;
      $604 = (79212 + ($603<<2)|0);
      $605 = HEAP32[$604>>2]|0;
      $606 = HEAP32[$45>>2]|0;
      $607 = $606 & $591;
      $608 = HEAP8[$46>>0]|0;
      $609 = $608&255;
      $610 = $607 >>> $609;
      $611 = (($605) + ($610)|0);
      $612 = HEAP8[$47>>0]|0;
      $613 = $612&255;
      $614 = (79212 + ($613<<2)|0);
      $615 = HEAP32[$614>>2]|0;
      $616 = HEAP32[$48>>2]|0;
      $617 = $616 & $591;
      $618 = HEAP8[$49>>0]|0;
      $619 = $618&255;
      $620 = $617 >>> $619;
      $621 = (($615) + ($620)|0);
      $$41002$shrunk$ph$in = $601;$$41018$ph = $591;$$4986$shrunk$ph$in = $611;$$sink1137 = $621;
      label = 48;
      break;
     }
     default: {
      $$41002$shrunk = 0;$$41018 = 0;$$4978$shrunk = 0;$$4986$shrunk = 0;
     }
     }
     if ((label|0) == 48) {
      label = 0;
      $$4986$shrunk$ph = HEAP8[$$4986$shrunk$ph$in>>0]|0;
      $$41002$shrunk$ph = HEAP8[$$41002$shrunk$ph$in>>0]|0;
      $622 = HEAP8[$$sink1137>>0]|0;
      $$41002$shrunk = $$41002$shrunk$ph;$$41018 = $$41018$ph;$$4978$shrunk = $622;$$4986$shrunk = $$4986$shrunk$ph;
     }
     $623 = $$41018 & $20;
     $624 = ($623|0)==($24|0);
     if (!($624)) {
      $$4978 = $$4978$shrunk&255;
      $$4986 = $$4986$shrunk&255;
      $625 = $$41002$shrunk & -32;
      $626 = $625&255;
      $627 = $$4986 >>> 5;
      $628 = $627 << 2;
      $629 = $628 | $626;
      $630 = $$4978 >>> 6;
      $631 = $629 | $630;
      $632 = $631&255;
      HEAP8[$$51053>>0] = $632;
     }
     $633 = ((($$51053)) + 1|0);
     $634 = (($$51037) + ($23)|0);
     $$5971 = $$4970;$$61038 = $634;$$61054 = $633;
     label = 52;
     continue;
    }
    else if ((label|0) == 52) {
     label = 0;
     switch ($22<<24>>24) {
     case 1:  {
      $635 = HEAP8[$$61038>>0]|0;
      $636 = $635&255;
      $637 = HEAP8[$41>>0]|0;
      $638 = $637&255;
      $639 = (79212 + ($638<<2)|0);
      $640 = HEAP32[$639>>2]|0;
      $641 = HEAP32[$42>>2]|0;
      $642 = $641 & $636;
      $643 = HEAP8[$43>>0]|0;
      $644 = $643&255;
      $645 = $642 >>> $644;
      $646 = (($640) + ($645)|0);
      $647 = HEAP8[$44>>0]|0;
      $648 = $647&255;
      $649 = (79212 + ($648<<2)|0);
      $650 = HEAP32[$649>>2]|0;
      $651 = HEAP32[$45>>2]|0;
      $652 = $651 & $636;
      $653 = HEAP8[$46>>0]|0;
      $654 = $653&255;
      $655 = $652 >>> $654;
      $656 = (($650) + ($655)|0);
      $657 = HEAP8[$47>>0]|0;
      $658 = $657&255;
      $659 = (79212 + ($658<<2)|0);
      $660 = HEAP32[$659>>2]|0;
      $661 = HEAP32[$48>>2]|0;
      $662 = $661 & $636;
      $663 = HEAP8[$49>>0]|0;
      $664 = $663&255;
      $665 = $662 >>> $664;
      $666 = (($660) + ($665)|0);
      $$51003$shrunk$ph$in = $646;$$51019$ph = $636;$$5987$shrunk$ph$in = $656;$$sink1139 = $666;
      label = 57;
      break;
     }
     case 2:  {
      $667 = HEAP16[$$61038>>1]|0;
      $668 = $667&65535;
      $669 = HEAP8[$41>>0]|0;
      $670 = $669&255;
      $671 = (79212 + ($670<<2)|0);
      $672 = HEAP32[$671>>2]|0;
      $673 = HEAP32[$42>>2]|0;
      $674 = $673 & $668;
      $675 = HEAP8[$43>>0]|0;
      $676 = $675&255;
      $677 = $674 >>> $676;
      $678 = (($672) + ($677)|0);
      $679 = HEAP8[$44>>0]|0;
      $680 = $679&255;
      $681 = (79212 + ($680<<2)|0);
      $682 = HEAP32[$681>>2]|0;
      $683 = HEAP32[$45>>2]|0;
      $684 = $683 & $668;
      $685 = HEAP8[$46>>0]|0;
      $686 = $685&255;
      $687 = $684 >>> $686;
      $688 = (($682) + ($687)|0);
      $689 = HEAP8[$47>>0]|0;
      $690 = $689&255;
      $691 = (79212 + ($690<<2)|0);
      $692 = HEAP32[$691>>2]|0;
      $693 = HEAP32[$48>>2]|0;
      $694 = $693 & $668;
      $695 = HEAP8[$49>>0]|0;
      $696 = $695&255;
      $697 = $694 >>> $696;
      $698 = (($692) + ($697)|0);
      $$51003$shrunk$ph$in = $678;$$51019$ph = $668;$$5987$shrunk$ph$in = $688;$$sink1139 = $698;
      label = 57;
      break;
     }
     case 3:  {
      $699 = HEAP8[$43>>0]|0;
      $div1109 = ($699&255) >>> 3;
      $700 = $div1109&255;
      $701 = (($$61038) + ($700)|0);
      $702 = HEAP8[$46>>0]|0;
      $div1110 = ($702&255) >>> 3;
      $703 = $div1110&255;
      $704 = (($$61038) + ($703)|0);
      $705 = HEAP8[$49>>0]|0;
      $div1111 = ($705&255) >>> 3;
      $706 = $div1111&255;
      $707 = (($$61038) + ($706)|0);
      $$51003$shrunk$ph$in = $701;$$51019$ph = 0;$$5987$shrunk$ph$in = $704;$$sink1139 = $707;
      label = 57;
      break;
     }
     case 4:  {
      $708 = HEAP32[$$61038>>2]|0;
      $709 = HEAP8[$41>>0]|0;
      $710 = $709&255;
      $711 = (79212 + ($710<<2)|0);
      $712 = HEAP32[$711>>2]|0;
      $713 = HEAP32[$42>>2]|0;
      $714 = $713 & $708;
      $715 = HEAP8[$43>>0]|0;
      $716 = $715&255;
      $717 = $714 >>> $716;
      $718 = (($712) + ($717)|0);
      $719 = HEAP8[$44>>0]|0;
      $720 = $719&255;
      $721 = (79212 + ($720<<2)|0);
      $722 = HEAP32[$721>>2]|0;
      $723 = HEAP32[$45>>2]|0;
      $724 = $723 & $708;
      $725 = HEAP8[$46>>0]|0;
      $726 = $725&255;
      $727 = $724 >>> $726;
      $728 = (($722) + ($727)|0);
      $729 = HEAP8[$47>>0]|0;
      $730 = $729&255;
      $731 = (79212 + ($730<<2)|0);
      $732 = HEAP32[$731>>2]|0;
      $733 = HEAP32[$48>>2]|0;
      $734 = $733 & $708;
      $735 = HEAP8[$49>>0]|0;
      $736 = $735&255;
      $737 = $734 >>> $736;
      $738 = (($732) + ($737)|0);
      $$51003$shrunk$ph$in = $718;$$51019$ph = $708;$$5987$shrunk$ph$in = $728;$$sink1139 = $738;
      label = 57;
      break;
     }
     default: {
      $$51003$shrunk = 0;$$51019 = 0;$$5979$shrunk = 0;$$5987$shrunk = 0;
     }
     }
     if ((label|0) == 57) {
      label = 0;
      $$5987$shrunk$ph = HEAP8[$$5987$shrunk$ph$in>>0]|0;
      $$51003$shrunk$ph = HEAP8[$$51003$shrunk$ph$in>>0]|0;
      $739 = HEAP8[$$sink1139>>0]|0;
      $$51003$shrunk = $$51003$shrunk$ph;$$51019 = $$51019$ph;$$5979$shrunk = $739;$$5987$shrunk = $$5987$shrunk$ph;
     }
     $740 = $$51019 & $20;
     $741 = ($740|0)==($24|0);
     if (!($741)) {
      $$5979 = $$5979$shrunk&255;
      $$5987 = $$5987$shrunk&255;
      $742 = $$51003$shrunk & -32;
      $743 = $742&255;
      $744 = $$5987 >>> 5;
      $745 = $744 << 2;
      $746 = $745 | $743;
      $747 = $$5979 >>> 6;
      $748 = $746 | $747;
      $749 = $748&255;
      HEAP8[$$61054>>0] = $749;
     }
     $750 = ((($$61054)) + 1|0);
     $751 = (($$61038) + ($23)|0);
     $$6972 = $$5971;$$71039 = $751;$$71055 = $750;
     label = 61;
     continue;
    }
    else if ((label|0) == 61) {
     label = 0;
     switch ($22<<24>>24) {
     case 1:  {
      $752 = HEAP8[$$71039>>0]|0;
      $753 = $752&255;
      $754 = HEAP8[$41>>0]|0;
      $755 = $754&255;
      $756 = (79212 + ($755<<2)|0);
      $757 = HEAP32[$756>>2]|0;
      $758 = HEAP32[$42>>2]|0;
      $759 = $758 & $753;
      $760 = HEAP8[$43>>0]|0;
      $761 = $760&255;
      $762 = $759 >>> $761;
      $763 = (($757) + ($762)|0);
      $764 = HEAP8[$44>>0]|0;
      $765 = $764&255;
      $766 = (79212 + ($765<<2)|0);
      $767 = HEAP32[$766>>2]|0;
      $768 = HEAP32[$45>>2]|0;
      $769 = $768 & $753;
      $770 = HEAP8[$46>>0]|0;
      $771 = $770&255;
      $772 = $769 >>> $771;
      $773 = (($767) + ($772)|0);
      $774 = HEAP8[$47>>0]|0;
      $775 = $774&255;
      $776 = (79212 + ($775<<2)|0);
      $777 = HEAP32[$776>>2]|0;
      $778 = HEAP32[$48>>2]|0;
      $779 = $778 & $753;
      $780 = HEAP8[$49>>0]|0;
      $781 = $780&255;
      $782 = $779 >>> $781;
      $783 = (($777) + ($782)|0);
      $$61004$shrunk$ph$in = $763;$$61020$ph = $753;$$6988$shrunk$ph$in = $773;$$sink1141 = $783;
      label = 66;
      break;
     }
     case 2:  {
      $784 = HEAP16[$$71039>>1]|0;
      $785 = $784&65535;
      $786 = HEAP8[$41>>0]|0;
      $787 = $786&255;
      $788 = (79212 + ($787<<2)|0);
      $789 = HEAP32[$788>>2]|0;
      $790 = HEAP32[$42>>2]|0;
      $791 = $790 & $785;
      $792 = HEAP8[$43>>0]|0;
      $793 = $792&255;
      $794 = $791 >>> $793;
      $795 = (($789) + ($794)|0);
      $796 = HEAP8[$44>>0]|0;
      $797 = $796&255;
      $798 = (79212 + ($797<<2)|0);
      $799 = HEAP32[$798>>2]|0;
      $800 = HEAP32[$45>>2]|0;
      $801 = $800 & $785;
      $802 = HEAP8[$46>>0]|0;
      $803 = $802&255;
      $804 = $801 >>> $803;
      $805 = (($799) + ($804)|0);
      $806 = HEAP8[$47>>0]|0;
      $807 = $806&255;
      $808 = (79212 + ($807<<2)|0);
      $809 = HEAP32[$808>>2]|0;
      $810 = HEAP32[$48>>2]|0;
      $811 = $810 & $785;
      $812 = HEAP8[$49>>0]|0;
      $813 = $812&255;
      $814 = $811 >>> $813;
      $815 = (($809) + ($814)|0);
      $$61004$shrunk$ph$in = $795;$$61020$ph = $785;$$6988$shrunk$ph$in = $805;$$sink1141 = $815;
      label = 66;
      break;
     }
     case 3:  {
      $816 = HEAP8[$43>>0]|0;
      $div1106 = ($816&255) >>> 3;
      $817 = $div1106&255;
      $818 = (($$71039) + ($817)|0);
      $819 = HEAP8[$46>>0]|0;
      $div1107 = ($819&255) >>> 3;
      $820 = $div1107&255;
      $821 = (($$71039) + ($820)|0);
      $822 = HEAP8[$49>>0]|0;
      $div1108 = ($822&255) >>> 3;
      $823 = $div1108&255;
      $824 = (($$71039) + ($823)|0);
      $$61004$shrunk$ph$in = $818;$$61020$ph = 0;$$6988$shrunk$ph$in = $821;$$sink1141 = $824;
      label = 66;
      break;
     }
     case 4:  {
      $825 = HEAP32[$$71039>>2]|0;
      $826 = HEAP8[$41>>0]|0;
      $827 = $826&255;
      $828 = (79212 + ($827<<2)|0);
      $829 = HEAP32[$828>>2]|0;
      $830 = HEAP32[$42>>2]|0;
      $831 = $830 & $825;
      $832 = HEAP8[$43>>0]|0;
      $833 = $832&255;
      $834 = $831 >>> $833;
      $835 = (($829) + ($834)|0);
      $836 = HEAP8[$44>>0]|0;
      $837 = $836&255;
      $838 = (79212 + ($837<<2)|0);
      $839 = HEAP32[$838>>2]|0;
      $840 = HEAP32[$45>>2]|0;
      $841 = $840 & $825;
      $842 = HEAP8[$46>>0]|0;
      $843 = $842&255;
      $844 = $841 >>> $843;
      $845 = (($839) + ($844)|0);
      $846 = HEAP8[$47>>0]|0;
      $847 = $846&255;
      $848 = (79212 + ($847<<2)|0);
      $849 = HEAP32[$848>>2]|0;
      $850 = HEAP32[$48>>2]|0;
      $851 = $850 & $825;
      $852 = HEAP8[$49>>0]|0;
      $853 = $852&255;
      $854 = $851 >>> $853;
      $855 = (($849) + ($854)|0);
      $$61004$shrunk$ph$in = $835;$$61020$ph = $825;$$6988$shrunk$ph$in = $845;$$sink1141 = $855;
      label = 66;
      break;
     }
     default: {
      $$61004$shrunk = 0;$$61020 = 0;$$6980$shrunk = 0;$$6988$shrunk = 0;
     }
     }
     if ((label|0) == 66) {
      label = 0;
      $$6988$shrunk$ph = HEAP8[$$6988$shrunk$ph$in>>0]|0;
      $$61004$shrunk$ph = HEAP8[$$61004$shrunk$ph$in>>0]|0;
      $856 = HEAP8[$$sink1141>>0]|0;
      $$61004$shrunk = $$61004$shrunk$ph;$$61020 = $$61020$ph;$$6980$shrunk = $856;$$6988$shrunk = $$6988$shrunk$ph;
     }
     $857 = $$61020 & $20;
     $858 = ($857|0)==($24|0);
     if (!($858)) {
      $$6980 = $$6980$shrunk&255;
      $$6988 = $$6988$shrunk&255;
      $859 = $$61004$shrunk & -32;
      $860 = $859&255;
      $861 = $$6988 >>> 5;
      $862 = $861 << 2;
      $863 = $862 | $860;
      $864 = $$6980 >>> 6;
      $865 = $863 | $864;
      $866 = $865&255;
      HEAP8[$$71055>>0] = $866;
     }
     $867 = ((($$71055)) + 1|0);
     $868 = (($$71039) + ($23)|0);
     $$7973 = $$6972;$$81040 = $868;$$81056 = $867;
     label = 70;
     continue;
    }
    else if ((label|0) == 70) {
     label = 0;
     switch ($22<<24>>24) {
     case 1:  {
      $869 = HEAP8[$$81040>>0]|0;
      $870 = $869&255;
      $871 = HEAP8[$41>>0]|0;
      $872 = $871&255;
      $873 = (79212 + ($872<<2)|0);
      $874 = HEAP32[$873>>2]|0;
      $875 = HEAP32[$42>>2]|0;
      $876 = $875 & $870;
      $877 = HEAP8[$43>>0]|0;
      $878 = $877&255;
      $879 = $876 >>> $878;
      $880 = (($874) + ($879)|0);
      $881 = HEAP8[$44>>0]|0;
      $882 = $881&255;
      $883 = (79212 + ($882<<2)|0);
      $884 = HEAP32[$883>>2]|0;
      $885 = HEAP32[$45>>2]|0;
      $886 = $885 & $870;
      $887 = HEAP8[$46>>0]|0;
      $888 = $887&255;
      $889 = $886 >>> $888;
      $890 = (($884) + ($889)|0);
      $891 = HEAP8[$47>>0]|0;
      $892 = $891&255;
      $893 = (79212 + ($892<<2)|0);
      $894 = HEAP32[$893>>2]|0;
      $895 = HEAP32[$48>>2]|0;
      $896 = $895 & $870;
      $897 = HEAP8[$49>>0]|0;
      $898 = $897&255;
      $899 = $896 >>> $898;
      $900 = (($894) + ($899)|0);
      $$71005$shrunk$ph$in = $880;$$71021$ph = $870;$$7989$shrunk$ph$in = $890;$$sink1143 = $900;
      label = 75;
      break;
     }
     case 2:  {
      $901 = HEAP16[$$81040>>1]|0;
      $902 = $901&65535;
      $903 = HEAP8[$41>>0]|0;
      $904 = $903&255;
      $905 = (79212 + ($904<<2)|0);
      $906 = HEAP32[$905>>2]|0;
      $907 = HEAP32[$42>>2]|0;
      $908 = $907 & $902;
      $909 = HEAP8[$43>>0]|0;
      $910 = $909&255;
      $911 = $908 >>> $910;
      $912 = (($906) + ($911)|0);
      $913 = HEAP8[$44>>0]|0;
      $914 = $913&255;
      $915 = (79212 + ($914<<2)|0);
      $916 = HEAP32[$915>>2]|0;
      $917 = HEAP32[$45>>2]|0;
      $918 = $917 & $902;
      $919 = HEAP8[$46>>0]|0;
      $920 = $919&255;
      $921 = $918 >>> $920;
      $922 = (($916) + ($921)|0);
      $923 = HEAP8[$47>>0]|0;
      $924 = $923&255;
      $925 = (79212 + ($924<<2)|0);
      $926 = HEAP32[$925>>2]|0;
      $927 = HEAP32[$48>>2]|0;
      $928 = $927 & $902;
      $929 = HEAP8[$49>>0]|0;
      $930 = $929&255;
      $931 = $928 >>> $930;
      $932 = (($926) + ($931)|0);
      $$71005$shrunk$ph$in = $912;$$71021$ph = $902;$$7989$shrunk$ph$in = $922;$$sink1143 = $932;
      label = 75;
      break;
     }
     case 3:  {
      $933 = HEAP8[$43>>0]|0;
      $div1127 = ($933&255) >>> 3;
      $934 = $div1127&255;
      $935 = (($$81040) + ($934)|0);
      $936 = HEAP8[$46>>0]|0;
      $div1128 = ($936&255) >>> 3;
      $937 = $div1128&255;
      $938 = (($$81040) + ($937)|0);
      $939 = HEAP8[$49>>0]|0;
      $div1129 = ($939&255) >>> 3;
      $940 = $div1129&255;
      $941 = (($$81040) + ($940)|0);
      $$71005$shrunk$ph$in = $935;$$71021$ph = 0;$$7989$shrunk$ph$in = $938;$$sink1143 = $941;
      label = 75;
      break;
     }
     case 4:  {
      $942 = HEAP32[$$81040>>2]|0;
      $943 = HEAP8[$41>>0]|0;
      $944 = $943&255;
      $945 = (79212 + ($944<<2)|0);
      $946 = HEAP32[$945>>2]|0;
      $947 = HEAP32[$42>>2]|0;
      $948 = $947 & $942;
      $949 = HEAP8[$43>>0]|0;
      $950 = $949&255;
      $951 = $948 >>> $950;
      $952 = (($946) + ($951)|0);
      $953 = HEAP8[$44>>0]|0;
      $954 = $953&255;
      $955 = (79212 + ($954<<2)|0);
      $956 = HEAP32[$955>>2]|0;
      $957 = HEAP32[$45>>2]|0;
      $958 = $957 & $942;
      $959 = HEAP8[$46>>0]|0;
      $960 = $959&255;
      $961 = $958 >>> $960;
      $962 = (($956) + ($961)|0);
      $963 = HEAP8[$47>>0]|0;
      $964 = $963&255;
      $965 = (79212 + ($964<<2)|0);
      $966 = HEAP32[$965>>2]|0;
      $967 = HEAP32[$48>>2]|0;
      $968 = $967 & $942;
      $969 = HEAP8[$49>>0]|0;
      $970 = $969&255;
      $971 = $968 >>> $970;
      $972 = (($966) + ($971)|0);
      $$71005$shrunk$ph$in = $952;$$71021$ph = $942;$$7989$shrunk$ph$in = $962;$$sink1143 = $972;
      label = 75;
      break;
     }
     default: {
      $$71005$shrunk = 0;$$71021 = 0;$$7981$shrunk = 0;$$7989$shrunk = 0;
     }
     }
     if ((label|0) == 75) {
      label = 0;
      $$7989$shrunk$ph = HEAP8[$$7989$shrunk$ph$in>>0]|0;
      $$71005$shrunk$ph = HEAP8[$$71005$shrunk$ph$in>>0]|0;
      $973 = HEAP8[$$sink1143>>0]|0;
      $$71005$shrunk = $$71005$shrunk$ph;$$71021 = $$71021$ph;$$7981$shrunk = $973;$$7989$shrunk = $$7989$shrunk$ph;
     }
     $974 = $$71021 & $20;
     $975 = ($974|0)==($24|0);
     if (!($975)) {
      $$7981 = $$7981$shrunk&255;
      $$7989 = $$7989$shrunk&255;
      $976 = $$71005$shrunk & -32;
      $977 = $976&255;
      $978 = $$7989 >>> 5;
      $979 = $978 << 2;
      $980 = $979 | $977;
      $981 = $$7981 >>> 6;
      $982 = $980 | $981;
      $983 = $982&255;
      HEAP8[$$81056>>0] = $983;
     }
     $984 = ((($$81056)) + 1|0);
     $985 = (($$81040) + ($23)|0);
     $986 = (($$7973) + -1)|0;
     $987 = ($$7973|0)>(1);
     if ($987) {
      $$0966 = $986;$$11033 = $985;$$11049 = $984;
      label = 7;
      continue;
     } else {
      break;
     }
    }
   }
   $988 = (($985) + ($7)|0);
   $989 = (($984) + ($11)|0);
   $990 = (($991) + -1)|0;
   $992 = ($991|0)==(0);
   if ($992) {
    label = 156;
    break;
   } else {
    $$010321163 = $988;$$010481162 = $989;$991 = $990;
   }
  }
  if ((label|0) == 79) {
   // unreachable;
  }
  else if ((label|0) == 156) {
   return;
  }
 } else {
  if ($27) {
   return;
  }
  $28 = (($2) + 7)|0;
  $29 = (($28|0) / 8)&-1;
  $trunc = $2&255;
  $30 = ((($13)) + 28|0);
  $31 = ((($13)) + 12|0);
  $32 = ((($13)) + 32|0);
  $33 = ((($13)) + 29|0);
  $34 = ((($13)) + 16|0);
  $35 = ((($13)) + 33|0);
  $36 = ((($13)) + 30|0);
  $37 = ((($13)) + 20|0);
  $38 = ((($13)) + 34|0);
  $$910411165 = $5;$$910571164 = $9;$1942 = $26;
  L114: while(1) {
   $trunc$clear = $trunc & 7;
   switch ($trunc$clear<<24>>24) {
   case 0:  {
    $$0 = $29;$$101042 = $$910411165;$$101058 = $$910571164;
    label = 82;
    break;
   }
   case 7:  {
    $$1 = $29;$$111043 = $$910411165;$$111059 = $$910571164;
    label = 91;
    break;
   }
   case 6:  {
    $$121044 = $$910411165;$$121060 = $$910571164;$$2 = $29;
    label = 100;
    break;
   }
   case 5:  {
    $$131045 = $$910411165;$$131061 = $$910571164;$$3 = $29;
    label = 109;
    break;
   }
   case 4:  {
    $$141046 = $$910411165;$$141062 = $$910571164;$$4 = $29;
    label = 118;
    break;
   }
   case 3:  {
    $$151047 = $$910411165;$$151063 = $$910571164;$$5 = $29;
    label = 127;
    break;
   }
   case 2:  {
    $$16 = $$910411165;$$161064 = $$910571164;$$6 = $29;
    label = 136;
    break;
   }
   case 1:  {
    $$17 = $$910411165;$$171065 = $$910571164;$$7 = $29;
    label = 145;
    break;
   }
   default: {
    label = 154;
    break L114;
   }
   }
   while(1) {
    if ((label|0) == 82) {
     label = 0;
     switch ($22<<24>>24) {
     case 1:  {
      $993 = HEAP8[$$101042>>0]|0;
      $994 = $993&255;
      $995 = HEAP8[$30>>0]|0;
      $996 = $995&255;
      $997 = (79212 + ($996<<2)|0);
      $998 = HEAP32[$997>>2]|0;
      $999 = HEAP32[$31>>2]|0;
      $1000 = $999 & $994;
      $1001 = HEAP8[$32>>0]|0;
      $1002 = $1001&255;
      $1003 = $1000 >>> $1002;
      $1004 = (($998) + ($1003)|0);
      $1005 = HEAP8[$33>>0]|0;
      $1006 = $1005&255;
      $1007 = (79212 + ($1006<<2)|0);
      $1008 = HEAP32[$1007>>2]|0;
      $1009 = HEAP32[$34>>2]|0;
      $1010 = $1009 & $994;
      $1011 = HEAP8[$35>>0]|0;
      $1012 = $1011&255;
      $1013 = $1010 >>> $1012;
      $1014 = (($1008) + ($1013)|0);
      $1015 = HEAP8[$36>>0]|0;
      $1016 = $1015&255;
      $1017 = (79212 + ($1016<<2)|0);
      $1018 = HEAP32[$1017>>2]|0;
      $1019 = HEAP32[$37>>2]|0;
      $1020 = $1019 & $994;
      $1021 = HEAP8[$38>>0]|0;
      $1022 = $1021&255;
      $1023 = $1020 >>> $1022;
      $1024 = (($1018) + ($1023)|0);
      $$81006$shrunk$ph$in = $1004;$$81022$ph = $994;$$8990$shrunk$ph$in = $1014;$$sink1145 = $1024;
      label = 87;
      break;
     }
     case 2:  {
      $1025 = HEAP16[$$101042>>1]|0;
      $1026 = $1025&65535;
      $1027 = HEAP8[$30>>0]|0;
      $1028 = $1027&255;
      $1029 = (79212 + ($1028<<2)|0);
      $1030 = HEAP32[$1029>>2]|0;
      $1031 = HEAP32[$31>>2]|0;
      $1032 = $1031 & $1026;
      $1033 = HEAP8[$32>>0]|0;
      $1034 = $1033&255;
      $1035 = $1032 >>> $1034;
      $1036 = (($1030) + ($1035)|0);
      $1037 = HEAP8[$33>>0]|0;
      $1038 = $1037&255;
      $1039 = (79212 + ($1038<<2)|0);
      $1040 = HEAP32[$1039>>2]|0;
      $1041 = HEAP32[$34>>2]|0;
      $1042 = $1041 & $1026;
      $1043 = HEAP8[$35>>0]|0;
      $1044 = $1043&255;
      $1045 = $1042 >>> $1044;
      $1046 = (($1040) + ($1045)|0);
      $1047 = HEAP8[$36>>0]|0;
      $1048 = $1047&255;
      $1049 = (79212 + ($1048<<2)|0);
      $1050 = HEAP32[$1049>>2]|0;
      $1051 = HEAP32[$37>>2]|0;
      $1052 = $1051 & $1026;
      $1053 = HEAP8[$38>>0]|0;
      $1054 = $1053&255;
      $1055 = $1052 >>> $1054;
      $1056 = (($1050) + ($1055)|0);
      $$81006$shrunk$ph$in = $1036;$$81022$ph = $1026;$$8990$shrunk$ph$in = $1046;$$sink1145 = $1056;
      label = 87;
      break;
     }
     case 3:  {
      $1057 = HEAP8[$32>>0]|0;
      $div1091 = ($1057&255) >>> 3;
      $1058 = $div1091&255;
      $1059 = (($$101042) + ($1058)|0);
      $1060 = HEAP8[$35>>0]|0;
      $div1092 = ($1060&255) >>> 3;
      $1061 = $div1092&255;
      $1062 = (($$101042) + ($1061)|0);
      $1063 = HEAP8[$38>>0]|0;
      $div1093 = ($1063&255) >>> 3;
      $1064 = $div1093&255;
      $1065 = (($$101042) + ($1064)|0);
      $$81006$shrunk$ph$in = $1059;$$81022$ph = 0;$$8990$shrunk$ph$in = $1062;$$sink1145 = $1065;
      label = 87;
      break;
     }
     case 4:  {
      $1066 = HEAP32[$$101042>>2]|0;
      $1067 = HEAP8[$30>>0]|0;
      $1068 = $1067&255;
      $1069 = (79212 + ($1068<<2)|0);
      $1070 = HEAP32[$1069>>2]|0;
      $1071 = HEAP32[$31>>2]|0;
      $1072 = $1071 & $1066;
      $1073 = HEAP8[$32>>0]|0;
      $1074 = $1073&255;
      $1075 = $1072 >>> $1074;
      $1076 = (($1070) + ($1075)|0);
      $1077 = HEAP8[$33>>0]|0;
      $1078 = $1077&255;
      $1079 = (79212 + ($1078<<2)|0);
      $1080 = HEAP32[$1079>>2]|0;
      $1081 = HEAP32[$34>>2]|0;
      $1082 = $1081 & $1066;
      $1083 = HEAP8[$35>>0]|0;
      $1084 = $1083&255;
      $1085 = $1082 >>> $1084;
      $1086 = (($1080) + ($1085)|0);
      $1087 = HEAP8[$36>>0]|0;
      $1088 = $1087&255;
      $1089 = (79212 + ($1088<<2)|0);
      $1090 = HEAP32[$1089>>2]|0;
      $1091 = HEAP32[$37>>2]|0;
      $1092 = $1091 & $1066;
      $1093 = HEAP8[$38>>0]|0;
      $1094 = $1093&255;
      $1095 = $1092 >>> $1094;
      $1096 = (($1090) + ($1095)|0);
      $$81006$shrunk$ph$in = $1076;$$81022$ph = $1066;$$8990$shrunk$ph$in = $1086;$$sink1145 = $1096;
      label = 87;
      break;
     }
     default: {
      $$8$shrunk = 0;$$81006$shrunk = 0;$$81022 = 0;$$8990$shrunk = 0;
     }
     }
     if ((label|0) == 87) {
      label = 0;
      $$8990$shrunk$ph = HEAP8[$$8990$shrunk$ph$in>>0]|0;
      $$81006$shrunk$ph = HEAP8[$$81006$shrunk$ph$in>>0]|0;
      $1097 = HEAP8[$$sink1145>>0]|0;
      $$8$shrunk = $1097;$$81006$shrunk = $$81006$shrunk$ph;$$81022 = $$81022$ph;$$8990$shrunk = $$8990$shrunk$ph;
     }
     $1098 = $$81022 & $20;
     $1099 = ($1098|0)==($24|0);
     if (!($1099)) {
      $$8 = $$8$shrunk&255;
      $$8990 = $$8990$shrunk&255;
      $1100 = $$81006$shrunk & -32;
      $1101 = $1100&255;
      $1102 = $$8990 >>> 5;
      $1103 = $1102 << 2;
      $1104 = $1103 | $1101;
      $1105 = $$8 >>> 6;
      $1106 = $1104 | $1105;
      $1107 = (($15) + ($1106)|0);
      $1108 = HEAP8[$1107>>0]|0;
      HEAP8[$$101058>>0] = $1108;
     }
     $1109 = ((($$101058)) + 1|0);
     $1110 = (($$101042) + ($23)|0);
     $$1 = $$0;$$111043 = $1110;$$111059 = $1109;
     label = 91;
     continue;
    }
    else if ((label|0) == 91) {
     label = 0;
     switch ($22<<24>>24) {
     case 1:  {
      $1111 = HEAP8[$$111043>>0]|0;
      $1112 = $1111&255;
      $1113 = HEAP8[$30>>0]|0;
      $1114 = $1113&255;
      $1115 = (79212 + ($1114<<2)|0);
      $1116 = HEAP32[$1115>>2]|0;
      $1117 = HEAP32[$31>>2]|0;
      $1118 = $1117 & $1112;
      $1119 = HEAP8[$32>>0]|0;
      $1120 = $1119&255;
      $1121 = $1118 >>> $1120;
      $1122 = (($1116) + ($1121)|0);
      $1123 = HEAP8[$33>>0]|0;
      $1124 = $1123&255;
      $1125 = (79212 + ($1124<<2)|0);
      $1126 = HEAP32[$1125>>2]|0;
      $1127 = HEAP32[$34>>2]|0;
      $1128 = $1127 & $1112;
      $1129 = HEAP8[$35>>0]|0;
      $1130 = $1129&255;
      $1131 = $1128 >>> $1130;
      $1132 = (($1126) + ($1131)|0);
      $1133 = HEAP8[$36>>0]|0;
      $1134 = $1133&255;
      $1135 = (79212 + ($1134<<2)|0);
      $1136 = HEAP32[$1135>>2]|0;
      $1137 = HEAP32[$37>>2]|0;
      $1138 = $1137 & $1112;
      $1139 = HEAP8[$38>>0]|0;
      $1140 = $1139&255;
      $1141 = $1138 >>> $1140;
      $1142 = (($1136) + ($1141)|0);
      $$91007$shrunk$ph$in = $1122;$$91023$ph = $1112;$$9991$shrunk$ph$in = $1132;$$sink1147 = $1142;
      label = 96;
      break;
     }
     case 2:  {
      $1143 = HEAP16[$$111043>>1]|0;
      $1144 = $1143&65535;
      $1145 = HEAP8[$30>>0]|0;
      $1146 = $1145&255;
      $1147 = (79212 + ($1146<<2)|0);
      $1148 = HEAP32[$1147>>2]|0;
      $1149 = HEAP32[$31>>2]|0;
      $1150 = $1149 & $1144;
      $1151 = HEAP8[$32>>0]|0;
      $1152 = $1151&255;
      $1153 = $1150 >>> $1152;
      $1154 = (($1148) + ($1153)|0);
      $1155 = HEAP8[$33>>0]|0;
      $1156 = $1155&255;
      $1157 = (79212 + ($1156<<2)|0);
      $1158 = HEAP32[$1157>>2]|0;
      $1159 = HEAP32[$34>>2]|0;
      $1160 = $1159 & $1144;
      $1161 = HEAP8[$35>>0]|0;
      $1162 = $1161&255;
      $1163 = $1160 >>> $1162;
      $1164 = (($1158) + ($1163)|0);
      $1165 = HEAP8[$36>>0]|0;
      $1166 = $1165&255;
      $1167 = (79212 + ($1166<<2)|0);
      $1168 = HEAP32[$1167>>2]|0;
      $1169 = HEAP32[$37>>2]|0;
      $1170 = $1169 & $1144;
      $1171 = HEAP8[$38>>0]|0;
      $1172 = $1171&255;
      $1173 = $1170 >>> $1172;
      $1174 = (($1168) + ($1173)|0);
      $$91007$shrunk$ph$in = $1154;$$91023$ph = $1144;$$9991$shrunk$ph$in = $1164;$$sink1147 = $1174;
      label = 96;
      break;
     }
     case 3:  {
      $1175 = HEAP8[$32>>0]|0;
      $div1088 = ($1175&255) >>> 3;
      $1176 = $div1088&255;
      $1177 = (($$111043) + ($1176)|0);
      $1178 = HEAP8[$35>>0]|0;
      $div1089 = ($1178&255) >>> 3;
      $1179 = $div1089&255;
      $1180 = (($$111043) + ($1179)|0);
      $1181 = HEAP8[$38>>0]|0;
      $div1090 = ($1181&255) >>> 3;
      $1182 = $div1090&255;
      $1183 = (($$111043) + ($1182)|0);
      $$91007$shrunk$ph$in = $1177;$$91023$ph = 0;$$9991$shrunk$ph$in = $1180;$$sink1147 = $1183;
      label = 96;
      break;
     }
     case 4:  {
      $1184 = HEAP32[$$111043>>2]|0;
      $1185 = HEAP8[$30>>0]|0;
      $1186 = $1185&255;
      $1187 = (79212 + ($1186<<2)|0);
      $1188 = HEAP32[$1187>>2]|0;
      $1189 = HEAP32[$31>>2]|0;
      $1190 = $1189 & $1184;
      $1191 = HEAP8[$32>>0]|0;
      $1192 = $1191&255;
      $1193 = $1190 >>> $1192;
      $1194 = (($1188) + ($1193)|0);
      $1195 = HEAP8[$33>>0]|0;
      $1196 = $1195&255;
      $1197 = (79212 + ($1196<<2)|0);
      $1198 = HEAP32[$1197>>2]|0;
      $1199 = HEAP32[$34>>2]|0;
      $1200 = $1199 & $1184;
      $1201 = HEAP8[$35>>0]|0;
      $1202 = $1201&255;
      $1203 = $1200 >>> $1202;
      $1204 = (($1198) + ($1203)|0);
      $1205 = HEAP8[$36>>0]|0;
      $1206 = $1205&255;
      $1207 = (79212 + ($1206<<2)|0);
      $1208 = HEAP32[$1207>>2]|0;
      $1209 = HEAP32[$37>>2]|0;
      $1210 = $1209 & $1184;
      $1211 = HEAP8[$38>>0]|0;
      $1212 = $1211&255;
      $1213 = $1210 >>> $1212;
      $1214 = (($1208) + ($1213)|0);
      $$91007$shrunk$ph$in = $1194;$$91023$ph = $1184;$$9991$shrunk$ph$in = $1204;$$sink1147 = $1214;
      label = 96;
      break;
     }
     default: {
      $$9$shrunk = 0;$$91007$shrunk = 0;$$91023 = 0;$$9991$shrunk = 0;
     }
     }
     if ((label|0) == 96) {
      label = 0;
      $$9991$shrunk$ph = HEAP8[$$9991$shrunk$ph$in>>0]|0;
      $$91007$shrunk$ph = HEAP8[$$91007$shrunk$ph$in>>0]|0;
      $1215 = HEAP8[$$sink1147>>0]|0;
      $$9$shrunk = $1215;$$91007$shrunk = $$91007$shrunk$ph;$$91023 = $$91023$ph;$$9991$shrunk = $$9991$shrunk$ph;
     }
     $1216 = $$91023 & $20;
     $1217 = ($1216|0)==($24|0);
     if (!($1217)) {
      $$9 = $$9$shrunk&255;
      $$9991 = $$9991$shrunk&255;
      $1218 = $$91007$shrunk & -32;
      $1219 = $1218&255;
      $1220 = $$9991 >>> 5;
      $1221 = $1220 << 2;
      $1222 = $1221 | $1219;
      $1223 = $$9 >>> 6;
      $1224 = $1222 | $1223;
      $1225 = (($15) + ($1224)|0);
      $1226 = HEAP8[$1225>>0]|0;
      HEAP8[$$111059>>0] = $1226;
     }
     $1227 = ((($$111059)) + 1|0);
     $1228 = (($$111043) + ($23)|0);
     $$121044 = $1228;$$121060 = $1227;$$2 = $$1;
     label = 100;
     continue;
    }
    else if ((label|0) == 100) {
     label = 0;
     switch ($22<<24>>24) {
     case 1:  {
      $1229 = HEAP8[$$121044>>0]|0;
      $1230 = $1229&255;
      $1231 = HEAP8[$30>>0]|0;
      $1232 = $1231&255;
      $1233 = (79212 + ($1232<<2)|0);
      $1234 = HEAP32[$1233>>2]|0;
      $1235 = HEAP32[$31>>2]|0;
      $1236 = $1235 & $1230;
      $1237 = HEAP8[$32>>0]|0;
      $1238 = $1237&255;
      $1239 = $1236 >>> $1238;
      $1240 = (($1234) + ($1239)|0);
      $1241 = HEAP8[$33>>0]|0;
      $1242 = $1241&255;
      $1243 = (79212 + ($1242<<2)|0);
      $1244 = HEAP32[$1243>>2]|0;
      $1245 = HEAP32[$34>>2]|0;
      $1246 = $1245 & $1230;
      $1247 = HEAP8[$35>>0]|0;
      $1248 = $1247&255;
      $1249 = $1246 >>> $1248;
      $1250 = (($1244) + ($1249)|0);
      $1251 = HEAP8[$36>>0]|0;
      $1252 = $1251&255;
      $1253 = (79212 + ($1252<<2)|0);
      $1254 = HEAP32[$1253>>2]|0;
      $1255 = HEAP32[$37>>2]|0;
      $1256 = $1255 & $1230;
      $1257 = HEAP8[$38>>0]|0;
      $1258 = $1257&255;
      $1259 = $1256 >>> $1258;
      $1260 = (($1254) + ($1259)|0);
      $$101008$shrunk$ph$in = $1240;$$101024$ph = $1230;$$10992$shrunk$ph$in = $1250;$$sink1149 = $1260;
      label = 105;
      break;
     }
     case 2:  {
      $1261 = HEAP16[$$121044>>1]|0;
      $1262 = $1261&65535;
      $1263 = HEAP8[$30>>0]|0;
      $1264 = $1263&255;
      $1265 = (79212 + ($1264<<2)|0);
      $1266 = HEAP32[$1265>>2]|0;
      $1267 = HEAP32[$31>>2]|0;
      $1268 = $1267 & $1262;
      $1269 = HEAP8[$32>>0]|0;
      $1270 = $1269&255;
      $1271 = $1268 >>> $1270;
      $1272 = (($1266) + ($1271)|0);
      $1273 = HEAP8[$33>>0]|0;
      $1274 = $1273&255;
      $1275 = (79212 + ($1274<<2)|0);
      $1276 = HEAP32[$1275>>2]|0;
      $1277 = HEAP32[$34>>2]|0;
      $1278 = $1277 & $1262;
      $1279 = HEAP8[$35>>0]|0;
      $1280 = $1279&255;
      $1281 = $1278 >>> $1280;
      $1282 = (($1276) + ($1281)|0);
      $1283 = HEAP8[$36>>0]|0;
      $1284 = $1283&255;
      $1285 = (79212 + ($1284<<2)|0);
      $1286 = HEAP32[$1285>>2]|0;
      $1287 = HEAP32[$37>>2]|0;
      $1288 = $1287 & $1262;
      $1289 = HEAP8[$38>>0]|0;
      $1290 = $1289&255;
      $1291 = $1288 >>> $1290;
      $1292 = (($1286) + ($1291)|0);
      $$101008$shrunk$ph$in = $1272;$$101024$ph = $1262;$$10992$shrunk$ph$in = $1282;$$sink1149 = $1292;
      label = 105;
      break;
     }
     case 3:  {
      $1293 = HEAP8[$32>>0]|0;
      $div1085 = ($1293&255) >>> 3;
      $1294 = $div1085&255;
      $1295 = (($$121044) + ($1294)|0);
      $1296 = HEAP8[$35>>0]|0;
      $div1086 = ($1296&255) >>> 3;
      $1297 = $div1086&255;
      $1298 = (($$121044) + ($1297)|0);
      $1299 = HEAP8[$38>>0]|0;
      $div1087 = ($1299&255) >>> 3;
      $1300 = $div1087&255;
      $1301 = (($$121044) + ($1300)|0);
      $$101008$shrunk$ph$in = $1295;$$101024$ph = 0;$$10992$shrunk$ph$in = $1298;$$sink1149 = $1301;
      label = 105;
      break;
     }
     case 4:  {
      $1302 = HEAP32[$$121044>>2]|0;
      $1303 = HEAP8[$30>>0]|0;
      $1304 = $1303&255;
      $1305 = (79212 + ($1304<<2)|0);
      $1306 = HEAP32[$1305>>2]|0;
      $1307 = HEAP32[$31>>2]|0;
      $1308 = $1307 & $1302;
      $1309 = HEAP8[$32>>0]|0;
      $1310 = $1309&255;
      $1311 = $1308 >>> $1310;
      $1312 = (($1306) + ($1311)|0);
      $1313 = HEAP8[$33>>0]|0;
      $1314 = $1313&255;
      $1315 = (79212 + ($1314<<2)|0);
      $1316 = HEAP32[$1315>>2]|0;
      $1317 = HEAP32[$34>>2]|0;
      $1318 = $1317 & $1302;
      $1319 = HEAP8[$35>>0]|0;
      $1320 = $1319&255;
      $1321 = $1318 >>> $1320;
      $1322 = (($1316) + ($1321)|0);
      $1323 = HEAP8[$36>>0]|0;
      $1324 = $1323&255;
      $1325 = (79212 + ($1324<<2)|0);
      $1326 = HEAP32[$1325>>2]|0;
      $1327 = HEAP32[$37>>2]|0;
      $1328 = $1327 & $1302;
      $1329 = HEAP8[$38>>0]|0;
      $1330 = $1329&255;
      $1331 = $1328 >>> $1330;
      $1332 = (($1326) + ($1331)|0);
      $$101008$shrunk$ph$in = $1312;$$101024$ph = $1302;$$10992$shrunk$ph$in = $1322;$$sink1149 = $1332;
      label = 105;
      break;
     }
     default: {
      $$10$shrunk = 0;$$101008$shrunk = 0;$$101024 = 0;$$10992$shrunk = 0;
     }
     }
     if ((label|0) == 105) {
      label = 0;
      $$10992$shrunk$ph = HEAP8[$$10992$shrunk$ph$in>>0]|0;
      $$101008$shrunk$ph = HEAP8[$$101008$shrunk$ph$in>>0]|0;
      $1333 = HEAP8[$$sink1149>>0]|0;
      $$10$shrunk = $1333;$$101008$shrunk = $$101008$shrunk$ph;$$101024 = $$101024$ph;$$10992$shrunk = $$10992$shrunk$ph;
     }
     $1334 = $$101024 & $20;
     $1335 = ($1334|0)==($24|0);
     if (!($1335)) {
      $$10 = $$10$shrunk&255;
      $$10992 = $$10992$shrunk&255;
      $1336 = $$101008$shrunk & -32;
      $1337 = $1336&255;
      $1338 = $$10992 >>> 5;
      $1339 = $1338 << 2;
      $1340 = $1339 | $1337;
      $1341 = $$10 >>> 6;
      $1342 = $1340 | $1341;
      $1343 = (($15) + ($1342)|0);
      $1344 = HEAP8[$1343>>0]|0;
      HEAP8[$$121060>>0] = $1344;
     }
     $1345 = ((($$121060)) + 1|0);
     $1346 = (($$121044) + ($23)|0);
     $$131045 = $1346;$$131061 = $1345;$$3 = $$2;
     label = 109;
     continue;
    }
    else if ((label|0) == 109) {
     label = 0;
     switch ($22<<24>>24) {
     case 1:  {
      $1347 = HEAP8[$$131045>>0]|0;
      $1348 = $1347&255;
      $1349 = HEAP8[$30>>0]|0;
      $1350 = $1349&255;
      $1351 = (79212 + ($1350<<2)|0);
      $1352 = HEAP32[$1351>>2]|0;
      $1353 = HEAP32[$31>>2]|0;
      $1354 = $1353 & $1348;
      $1355 = HEAP8[$32>>0]|0;
      $1356 = $1355&255;
      $1357 = $1354 >>> $1356;
      $1358 = (($1352) + ($1357)|0);
      $1359 = HEAP8[$33>>0]|0;
      $1360 = $1359&255;
      $1361 = (79212 + ($1360<<2)|0);
      $1362 = HEAP32[$1361>>2]|0;
      $1363 = HEAP32[$34>>2]|0;
      $1364 = $1363 & $1348;
      $1365 = HEAP8[$35>>0]|0;
      $1366 = $1365&255;
      $1367 = $1364 >>> $1366;
      $1368 = (($1362) + ($1367)|0);
      $1369 = HEAP8[$36>>0]|0;
      $1370 = $1369&255;
      $1371 = (79212 + ($1370<<2)|0);
      $1372 = HEAP32[$1371>>2]|0;
      $1373 = HEAP32[$37>>2]|0;
      $1374 = $1373 & $1348;
      $1375 = HEAP8[$38>>0]|0;
      $1376 = $1375&255;
      $1377 = $1374 >>> $1376;
      $1378 = (($1372) + ($1377)|0);
      $$111009$shrunk$ph$in = $1358;$$111025$ph = $1348;$$11993$shrunk$ph$in = $1368;$$sink1151 = $1378;
      label = 114;
      break;
     }
     case 2:  {
      $1379 = HEAP16[$$131045>>1]|0;
      $1380 = $1379&65535;
      $1381 = HEAP8[$30>>0]|0;
      $1382 = $1381&255;
      $1383 = (79212 + ($1382<<2)|0);
      $1384 = HEAP32[$1383>>2]|0;
      $1385 = HEAP32[$31>>2]|0;
      $1386 = $1385 & $1380;
      $1387 = HEAP8[$32>>0]|0;
      $1388 = $1387&255;
      $1389 = $1386 >>> $1388;
      $1390 = (($1384) + ($1389)|0);
      $1391 = HEAP8[$33>>0]|0;
      $1392 = $1391&255;
      $1393 = (79212 + ($1392<<2)|0);
      $1394 = HEAP32[$1393>>2]|0;
      $1395 = HEAP32[$34>>2]|0;
      $1396 = $1395 & $1380;
      $1397 = HEAP8[$35>>0]|0;
      $1398 = $1397&255;
      $1399 = $1396 >>> $1398;
      $1400 = (($1394) + ($1399)|0);
      $1401 = HEAP8[$36>>0]|0;
      $1402 = $1401&255;
      $1403 = (79212 + ($1402<<2)|0);
      $1404 = HEAP32[$1403>>2]|0;
      $1405 = HEAP32[$37>>2]|0;
      $1406 = $1405 & $1380;
      $1407 = HEAP8[$38>>0]|0;
      $1408 = $1407&255;
      $1409 = $1406 >>> $1408;
      $1410 = (($1404) + ($1409)|0);
      $$111009$shrunk$ph$in = $1390;$$111025$ph = $1380;$$11993$shrunk$ph$in = $1400;$$sink1151 = $1410;
      label = 114;
      break;
     }
     case 3:  {
      $1411 = HEAP8[$32>>0]|0;
      $div1082 = ($1411&255) >>> 3;
      $1412 = $div1082&255;
      $1413 = (($$131045) + ($1412)|0);
      $1414 = HEAP8[$35>>0]|0;
      $div1083 = ($1414&255) >>> 3;
      $1415 = $div1083&255;
      $1416 = (($$131045) + ($1415)|0);
      $1417 = HEAP8[$38>>0]|0;
      $div1084 = ($1417&255) >>> 3;
      $1418 = $div1084&255;
      $1419 = (($$131045) + ($1418)|0);
      $$111009$shrunk$ph$in = $1413;$$111025$ph = 0;$$11993$shrunk$ph$in = $1416;$$sink1151 = $1419;
      label = 114;
      break;
     }
     case 4:  {
      $1420 = HEAP32[$$131045>>2]|0;
      $1421 = HEAP8[$30>>0]|0;
      $1422 = $1421&255;
      $1423 = (79212 + ($1422<<2)|0);
      $1424 = HEAP32[$1423>>2]|0;
      $1425 = HEAP32[$31>>2]|0;
      $1426 = $1425 & $1420;
      $1427 = HEAP8[$32>>0]|0;
      $1428 = $1427&255;
      $1429 = $1426 >>> $1428;
      $1430 = (($1424) + ($1429)|0);
      $1431 = HEAP8[$33>>0]|0;
      $1432 = $1431&255;
      $1433 = (79212 + ($1432<<2)|0);
      $1434 = HEAP32[$1433>>2]|0;
      $1435 = HEAP32[$34>>2]|0;
      $1436 = $1435 & $1420;
      $1437 = HEAP8[$35>>0]|0;
      $1438 = $1437&255;
      $1439 = $1436 >>> $1438;
      $1440 = (($1434) + ($1439)|0);
      $1441 = HEAP8[$36>>0]|0;
      $1442 = $1441&255;
      $1443 = (79212 + ($1442<<2)|0);
      $1444 = HEAP32[$1443>>2]|0;
      $1445 = HEAP32[$37>>2]|0;
      $1446 = $1445 & $1420;
      $1447 = HEAP8[$38>>0]|0;
      $1448 = $1447&255;
      $1449 = $1446 >>> $1448;
      $1450 = (($1444) + ($1449)|0);
      $$111009$shrunk$ph$in = $1430;$$111025$ph = $1420;$$11993$shrunk$ph$in = $1440;$$sink1151 = $1450;
      label = 114;
      break;
     }
     default: {
      $$11$shrunk = 0;$$111009$shrunk = 0;$$111025 = 0;$$11993$shrunk = 0;
     }
     }
     if ((label|0) == 114) {
      label = 0;
      $$11993$shrunk$ph = HEAP8[$$11993$shrunk$ph$in>>0]|0;
      $$111009$shrunk$ph = HEAP8[$$111009$shrunk$ph$in>>0]|0;
      $1451 = HEAP8[$$sink1151>>0]|0;
      $$11$shrunk = $1451;$$111009$shrunk = $$111009$shrunk$ph;$$111025 = $$111025$ph;$$11993$shrunk = $$11993$shrunk$ph;
     }
     $1452 = $$111025 & $20;
     $1453 = ($1452|0)==($24|0);
     if (!($1453)) {
      $$11 = $$11$shrunk&255;
      $$11993 = $$11993$shrunk&255;
      $1454 = $$111009$shrunk & -32;
      $1455 = $1454&255;
      $1456 = $$11993 >>> 5;
      $1457 = $1456 << 2;
      $1458 = $1457 | $1455;
      $1459 = $$11 >>> 6;
      $1460 = $1458 | $1459;
      $1461 = (($15) + ($1460)|0);
      $1462 = HEAP8[$1461>>0]|0;
      HEAP8[$$131061>>0] = $1462;
     }
     $1463 = ((($$131061)) + 1|0);
     $1464 = (($$131045) + ($23)|0);
     $$141046 = $1464;$$141062 = $1463;$$4 = $$3;
     label = 118;
     continue;
    }
    else if ((label|0) == 118) {
     label = 0;
     switch ($22<<24>>24) {
     case 1:  {
      $1465 = HEAP8[$$141046>>0]|0;
      $1466 = $1465&255;
      $1467 = HEAP8[$30>>0]|0;
      $1468 = $1467&255;
      $1469 = (79212 + ($1468<<2)|0);
      $1470 = HEAP32[$1469>>2]|0;
      $1471 = HEAP32[$31>>2]|0;
      $1472 = $1471 & $1466;
      $1473 = HEAP8[$32>>0]|0;
      $1474 = $1473&255;
      $1475 = $1472 >>> $1474;
      $1476 = (($1470) + ($1475)|0);
      $1477 = HEAP8[$33>>0]|0;
      $1478 = $1477&255;
      $1479 = (79212 + ($1478<<2)|0);
      $1480 = HEAP32[$1479>>2]|0;
      $1481 = HEAP32[$34>>2]|0;
      $1482 = $1481 & $1466;
      $1483 = HEAP8[$35>>0]|0;
      $1484 = $1483&255;
      $1485 = $1482 >>> $1484;
      $1486 = (($1480) + ($1485)|0);
      $1487 = HEAP8[$36>>0]|0;
      $1488 = $1487&255;
      $1489 = (79212 + ($1488<<2)|0);
      $1490 = HEAP32[$1489>>2]|0;
      $1491 = HEAP32[$37>>2]|0;
      $1492 = $1491 & $1466;
      $1493 = HEAP8[$38>>0]|0;
      $1494 = $1493&255;
      $1495 = $1492 >>> $1494;
      $1496 = (($1490) + ($1495)|0);
      $$121010$shrunk$ph$in = $1476;$$121026$ph = $1466;$$12994$shrunk$ph$in = $1486;$$sink1153 = $1496;
      label = 123;
      break;
     }
     case 2:  {
      $1497 = HEAP16[$$141046>>1]|0;
      $1498 = $1497&65535;
      $1499 = HEAP8[$30>>0]|0;
      $1500 = $1499&255;
      $1501 = (79212 + ($1500<<2)|0);
      $1502 = HEAP32[$1501>>2]|0;
      $1503 = HEAP32[$31>>2]|0;
      $1504 = $1503 & $1498;
      $1505 = HEAP8[$32>>0]|0;
      $1506 = $1505&255;
      $1507 = $1504 >>> $1506;
      $1508 = (($1502) + ($1507)|0);
      $1509 = HEAP8[$33>>0]|0;
      $1510 = $1509&255;
      $1511 = (79212 + ($1510<<2)|0);
      $1512 = HEAP32[$1511>>2]|0;
      $1513 = HEAP32[$34>>2]|0;
      $1514 = $1513 & $1498;
      $1515 = HEAP8[$35>>0]|0;
      $1516 = $1515&255;
      $1517 = $1514 >>> $1516;
      $1518 = (($1512) + ($1517)|0);
      $1519 = HEAP8[$36>>0]|0;
      $1520 = $1519&255;
      $1521 = (79212 + ($1520<<2)|0);
      $1522 = HEAP32[$1521>>2]|0;
      $1523 = HEAP32[$37>>2]|0;
      $1524 = $1523 & $1498;
      $1525 = HEAP8[$38>>0]|0;
      $1526 = $1525&255;
      $1527 = $1524 >>> $1526;
      $1528 = (($1522) + ($1527)|0);
      $$121010$shrunk$ph$in = $1508;$$121026$ph = $1498;$$12994$shrunk$ph$in = $1518;$$sink1153 = $1528;
      label = 123;
      break;
     }
     case 3:  {
      $1529 = HEAP8[$32>>0]|0;
      $div1079 = ($1529&255) >>> 3;
      $1530 = $div1079&255;
      $1531 = (($$141046) + ($1530)|0);
      $1532 = HEAP8[$35>>0]|0;
      $div1080 = ($1532&255) >>> 3;
      $1533 = $div1080&255;
      $1534 = (($$141046) + ($1533)|0);
      $1535 = HEAP8[$38>>0]|0;
      $div1081 = ($1535&255) >>> 3;
      $1536 = $div1081&255;
      $1537 = (($$141046) + ($1536)|0);
      $$121010$shrunk$ph$in = $1531;$$121026$ph = 0;$$12994$shrunk$ph$in = $1534;$$sink1153 = $1537;
      label = 123;
      break;
     }
     case 4:  {
      $1538 = HEAP32[$$141046>>2]|0;
      $1539 = HEAP8[$30>>0]|0;
      $1540 = $1539&255;
      $1541 = (79212 + ($1540<<2)|0);
      $1542 = HEAP32[$1541>>2]|0;
      $1543 = HEAP32[$31>>2]|0;
      $1544 = $1543 & $1538;
      $1545 = HEAP8[$32>>0]|0;
      $1546 = $1545&255;
      $1547 = $1544 >>> $1546;
      $1548 = (($1542) + ($1547)|0);
      $1549 = HEAP8[$33>>0]|0;
      $1550 = $1549&255;
      $1551 = (79212 + ($1550<<2)|0);
      $1552 = HEAP32[$1551>>2]|0;
      $1553 = HEAP32[$34>>2]|0;
      $1554 = $1553 & $1538;
      $1555 = HEAP8[$35>>0]|0;
      $1556 = $1555&255;
      $1557 = $1554 >>> $1556;
      $1558 = (($1552) + ($1557)|0);
      $1559 = HEAP8[$36>>0]|0;
      $1560 = $1559&255;
      $1561 = (79212 + ($1560<<2)|0);
      $1562 = HEAP32[$1561>>2]|0;
      $1563 = HEAP32[$37>>2]|0;
      $1564 = $1563 & $1538;
      $1565 = HEAP8[$38>>0]|0;
      $1566 = $1565&255;
      $1567 = $1564 >>> $1566;
      $1568 = (($1562) + ($1567)|0);
      $$121010$shrunk$ph$in = $1548;$$121026$ph = $1538;$$12994$shrunk$ph$in = $1558;$$sink1153 = $1568;
      label = 123;
      break;
     }
     default: {
      $$12$shrunk = 0;$$121010$shrunk = 0;$$121026 = 0;$$12994$shrunk = 0;
     }
     }
     if ((label|0) == 123) {
      label = 0;
      $$12994$shrunk$ph = HEAP8[$$12994$shrunk$ph$in>>0]|0;
      $$121010$shrunk$ph = HEAP8[$$121010$shrunk$ph$in>>0]|0;
      $1569 = HEAP8[$$sink1153>>0]|0;
      $$12$shrunk = $1569;$$121010$shrunk = $$121010$shrunk$ph;$$121026 = $$121026$ph;$$12994$shrunk = $$12994$shrunk$ph;
     }
     $1570 = $$121026 & $20;
     $1571 = ($1570|0)==($24|0);
     if (!($1571)) {
      $$12 = $$12$shrunk&255;
      $$12994 = $$12994$shrunk&255;
      $1572 = $$121010$shrunk & -32;
      $1573 = $1572&255;
      $1574 = $$12994 >>> 5;
      $1575 = $1574 << 2;
      $1576 = $1575 | $1573;
      $1577 = $$12 >>> 6;
      $1578 = $1576 | $1577;
      $1579 = (($15) + ($1578)|0);
      $1580 = HEAP8[$1579>>0]|0;
      HEAP8[$$141062>>0] = $1580;
     }
     $1581 = ((($$141062)) + 1|0);
     $1582 = (($$141046) + ($23)|0);
     $$151047 = $1582;$$151063 = $1581;$$5 = $$4;
     label = 127;
     continue;
    }
    else if ((label|0) == 127) {
     label = 0;
     switch ($22<<24>>24) {
     case 1:  {
      $1583 = HEAP8[$$151047>>0]|0;
      $1584 = $1583&255;
      $1585 = HEAP8[$30>>0]|0;
      $1586 = $1585&255;
      $1587 = (79212 + ($1586<<2)|0);
      $1588 = HEAP32[$1587>>2]|0;
      $1589 = HEAP32[$31>>2]|0;
      $1590 = $1589 & $1584;
      $1591 = HEAP8[$32>>0]|0;
      $1592 = $1591&255;
      $1593 = $1590 >>> $1592;
      $1594 = (($1588) + ($1593)|0);
      $1595 = HEAP8[$33>>0]|0;
      $1596 = $1595&255;
      $1597 = (79212 + ($1596<<2)|0);
      $1598 = HEAP32[$1597>>2]|0;
      $1599 = HEAP32[$34>>2]|0;
      $1600 = $1599 & $1584;
      $1601 = HEAP8[$35>>0]|0;
      $1602 = $1601&255;
      $1603 = $1600 >>> $1602;
      $1604 = (($1598) + ($1603)|0);
      $1605 = HEAP8[$36>>0]|0;
      $1606 = $1605&255;
      $1607 = (79212 + ($1606<<2)|0);
      $1608 = HEAP32[$1607>>2]|0;
      $1609 = HEAP32[$37>>2]|0;
      $1610 = $1609 & $1584;
      $1611 = HEAP8[$38>>0]|0;
      $1612 = $1611&255;
      $1613 = $1610 >>> $1612;
      $1614 = (($1608) + ($1613)|0);
      $$131011$shrunk$ph$in = $1594;$$131027$ph = $1584;$$13995$shrunk$ph$in = $1604;$$sink1155 = $1614;
      label = 132;
      break;
     }
     case 2:  {
      $1615 = HEAP16[$$151047>>1]|0;
      $1616 = $1615&65535;
      $1617 = HEAP8[$30>>0]|0;
      $1618 = $1617&255;
      $1619 = (79212 + ($1618<<2)|0);
      $1620 = HEAP32[$1619>>2]|0;
      $1621 = HEAP32[$31>>2]|0;
      $1622 = $1621 & $1616;
      $1623 = HEAP8[$32>>0]|0;
      $1624 = $1623&255;
      $1625 = $1622 >>> $1624;
      $1626 = (($1620) + ($1625)|0);
      $1627 = HEAP8[$33>>0]|0;
      $1628 = $1627&255;
      $1629 = (79212 + ($1628<<2)|0);
      $1630 = HEAP32[$1629>>2]|0;
      $1631 = HEAP32[$34>>2]|0;
      $1632 = $1631 & $1616;
      $1633 = HEAP8[$35>>0]|0;
      $1634 = $1633&255;
      $1635 = $1632 >>> $1634;
      $1636 = (($1630) + ($1635)|0);
      $1637 = HEAP8[$36>>0]|0;
      $1638 = $1637&255;
      $1639 = (79212 + ($1638<<2)|0);
      $1640 = HEAP32[$1639>>2]|0;
      $1641 = HEAP32[$37>>2]|0;
      $1642 = $1641 & $1616;
      $1643 = HEAP8[$38>>0]|0;
      $1644 = $1643&255;
      $1645 = $1642 >>> $1644;
      $1646 = (($1640) + ($1645)|0);
      $$131011$shrunk$ph$in = $1626;$$131027$ph = $1616;$$13995$shrunk$ph$in = $1636;$$sink1155 = $1646;
      label = 132;
      break;
     }
     case 3:  {
      $1647 = HEAP8[$32>>0]|0;
      $div1076 = ($1647&255) >>> 3;
      $1648 = $div1076&255;
      $1649 = (($$151047) + ($1648)|0);
      $1650 = HEAP8[$35>>0]|0;
      $div1077 = ($1650&255) >>> 3;
      $1651 = $div1077&255;
      $1652 = (($$151047) + ($1651)|0);
      $1653 = HEAP8[$38>>0]|0;
      $div1078 = ($1653&255) >>> 3;
      $1654 = $div1078&255;
      $1655 = (($$151047) + ($1654)|0);
      $$131011$shrunk$ph$in = $1649;$$131027$ph = 0;$$13995$shrunk$ph$in = $1652;$$sink1155 = $1655;
      label = 132;
      break;
     }
     case 4:  {
      $1656 = HEAP32[$$151047>>2]|0;
      $1657 = HEAP8[$30>>0]|0;
      $1658 = $1657&255;
      $1659 = (79212 + ($1658<<2)|0);
      $1660 = HEAP32[$1659>>2]|0;
      $1661 = HEAP32[$31>>2]|0;
      $1662 = $1661 & $1656;
      $1663 = HEAP8[$32>>0]|0;
      $1664 = $1663&255;
      $1665 = $1662 >>> $1664;
      $1666 = (($1660) + ($1665)|0);
      $1667 = HEAP8[$33>>0]|0;
      $1668 = $1667&255;
      $1669 = (79212 + ($1668<<2)|0);
      $1670 = HEAP32[$1669>>2]|0;
      $1671 = HEAP32[$34>>2]|0;
      $1672 = $1671 & $1656;
      $1673 = HEAP8[$35>>0]|0;
      $1674 = $1673&255;
      $1675 = $1672 >>> $1674;
      $1676 = (($1670) + ($1675)|0);
      $1677 = HEAP8[$36>>0]|0;
      $1678 = $1677&255;
      $1679 = (79212 + ($1678<<2)|0);
      $1680 = HEAP32[$1679>>2]|0;
      $1681 = HEAP32[$37>>2]|0;
      $1682 = $1681 & $1656;
      $1683 = HEAP8[$38>>0]|0;
      $1684 = $1683&255;
      $1685 = $1682 >>> $1684;
      $1686 = (($1680) + ($1685)|0);
      $$131011$shrunk$ph$in = $1666;$$131027$ph = $1656;$$13995$shrunk$ph$in = $1676;$$sink1155 = $1686;
      label = 132;
      break;
     }
     default: {
      $$13$shrunk = 0;$$131011$shrunk = 0;$$131027 = 0;$$13995$shrunk = 0;
     }
     }
     if ((label|0) == 132) {
      label = 0;
      $$13995$shrunk$ph = HEAP8[$$13995$shrunk$ph$in>>0]|0;
      $$131011$shrunk$ph = HEAP8[$$131011$shrunk$ph$in>>0]|0;
      $1687 = HEAP8[$$sink1155>>0]|0;
      $$13$shrunk = $1687;$$131011$shrunk = $$131011$shrunk$ph;$$131027 = $$131027$ph;$$13995$shrunk = $$13995$shrunk$ph;
     }
     $1688 = $$131027 & $20;
     $1689 = ($1688|0)==($24|0);
     if (!($1689)) {
      $$13 = $$13$shrunk&255;
      $$13995 = $$13995$shrunk&255;
      $1690 = $$131011$shrunk & -32;
      $1691 = $1690&255;
      $1692 = $$13995 >>> 5;
      $1693 = $1692 << 2;
      $1694 = $1693 | $1691;
      $1695 = $$13 >>> 6;
      $1696 = $1694 | $1695;
      $1697 = (($15) + ($1696)|0);
      $1698 = HEAP8[$1697>>0]|0;
      HEAP8[$$151063>>0] = $1698;
     }
     $1699 = ((($$151063)) + 1|0);
     $1700 = (($$151047) + ($23)|0);
     $$16 = $1700;$$161064 = $1699;$$6 = $$5;
     label = 136;
     continue;
    }
    else if ((label|0) == 136) {
     label = 0;
     switch ($22<<24>>24) {
     case 1:  {
      $1701 = HEAP8[$$16>>0]|0;
      $1702 = $1701&255;
      $1703 = HEAP8[$30>>0]|0;
      $1704 = $1703&255;
      $1705 = (79212 + ($1704<<2)|0);
      $1706 = HEAP32[$1705>>2]|0;
      $1707 = HEAP32[$31>>2]|0;
      $1708 = $1707 & $1702;
      $1709 = HEAP8[$32>>0]|0;
      $1710 = $1709&255;
      $1711 = $1708 >>> $1710;
      $1712 = (($1706) + ($1711)|0);
      $1713 = HEAP8[$33>>0]|0;
      $1714 = $1713&255;
      $1715 = (79212 + ($1714<<2)|0);
      $1716 = HEAP32[$1715>>2]|0;
      $1717 = HEAP32[$34>>2]|0;
      $1718 = $1717 & $1702;
      $1719 = HEAP8[$35>>0]|0;
      $1720 = $1719&255;
      $1721 = $1718 >>> $1720;
      $1722 = (($1716) + ($1721)|0);
      $1723 = HEAP8[$36>>0]|0;
      $1724 = $1723&255;
      $1725 = (79212 + ($1724<<2)|0);
      $1726 = HEAP32[$1725>>2]|0;
      $1727 = HEAP32[$37>>2]|0;
      $1728 = $1727 & $1702;
      $1729 = HEAP8[$38>>0]|0;
      $1730 = $1729&255;
      $1731 = $1728 >>> $1730;
      $1732 = (($1726) + ($1731)|0);
      $$141012$shrunk$ph$in = $1712;$$141028$ph = $1702;$$14996$shrunk$ph$in = $1722;$$sink1157 = $1732;
      label = 141;
      break;
     }
     case 2:  {
      $1733 = HEAP16[$$16>>1]|0;
      $1734 = $1733&65535;
      $1735 = HEAP8[$30>>0]|0;
      $1736 = $1735&255;
      $1737 = (79212 + ($1736<<2)|0);
      $1738 = HEAP32[$1737>>2]|0;
      $1739 = HEAP32[$31>>2]|0;
      $1740 = $1739 & $1734;
      $1741 = HEAP8[$32>>0]|0;
      $1742 = $1741&255;
      $1743 = $1740 >>> $1742;
      $1744 = (($1738) + ($1743)|0);
      $1745 = HEAP8[$33>>0]|0;
      $1746 = $1745&255;
      $1747 = (79212 + ($1746<<2)|0);
      $1748 = HEAP32[$1747>>2]|0;
      $1749 = HEAP32[$34>>2]|0;
      $1750 = $1749 & $1734;
      $1751 = HEAP8[$35>>0]|0;
      $1752 = $1751&255;
      $1753 = $1750 >>> $1752;
      $1754 = (($1748) + ($1753)|0);
      $1755 = HEAP8[$36>>0]|0;
      $1756 = $1755&255;
      $1757 = (79212 + ($1756<<2)|0);
      $1758 = HEAP32[$1757>>2]|0;
      $1759 = HEAP32[$37>>2]|0;
      $1760 = $1759 & $1734;
      $1761 = HEAP8[$38>>0]|0;
      $1762 = $1761&255;
      $1763 = $1760 >>> $1762;
      $1764 = (($1758) + ($1763)|0);
      $$141012$shrunk$ph$in = $1744;$$141028$ph = $1734;$$14996$shrunk$ph$in = $1754;$$sink1157 = $1764;
      label = 141;
      break;
     }
     case 3:  {
      $1765 = HEAP8[$32>>0]|0;
      $div = ($1765&255) >>> 3;
      $1766 = $div&255;
      $1767 = (($$16) + ($1766)|0);
      $1768 = HEAP8[$35>>0]|0;
      $div1074 = ($1768&255) >>> 3;
      $1769 = $div1074&255;
      $1770 = (($$16) + ($1769)|0);
      $1771 = HEAP8[$38>>0]|0;
      $div1075 = ($1771&255) >>> 3;
      $1772 = $div1075&255;
      $1773 = (($$16) + ($1772)|0);
      $$141012$shrunk$ph$in = $1767;$$141028$ph = 0;$$14996$shrunk$ph$in = $1770;$$sink1157 = $1773;
      label = 141;
      break;
     }
     case 4:  {
      $1774 = HEAP32[$$16>>2]|0;
      $1775 = HEAP8[$30>>0]|0;
      $1776 = $1775&255;
      $1777 = (79212 + ($1776<<2)|0);
      $1778 = HEAP32[$1777>>2]|0;
      $1779 = HEAP32[$31>>2]|0;
      $1780 = $1779 & $1774;
      $1781 = HEAP8[$32>>0]|0;
      $1782 = $1781&255;
      $1783 = $1780 >>> $1782;
      $1784 = (($1778) + ($1783)|0);
      $1785 = HEAP8[$33>>0]|0;
      $1786 = $1785&255;
      $1787 = (79212 + ($1786<<2)|0);
      $1788 = HEAP32[$1787>>2]|0;
      $1789 = HEAP32[$34>>2]|0;
      $1790 = $1789 & $1774;
      $1791 = HEAP8[$35>>0]|0;
      $1792 = $1791&255;
      $1793 = $1790 >>> $1792;
      $1794 = (($1788) + ($1793)|0);
      $1795 = HEAP8[$36>>0]|0;
      $1796 = $1795&255;
      $1797 = (79212 + ($1796<<2)|0);
      $1798 = HEAP32[$1797>>2]|0;
      $1799 = HEAP32[$37>>2]|0;
      $1800 = $1799 & $1774;
      $1801 = HEAP8[$38>>0]|0;
      $1802 = $1801&255;
      $1803 = $1800 >>> $1802;
      $1804 = (($1798) + ($1803)|0);
      $$141012$shrunk$ph$in = $1784;$$141028$ph = $1774;$$14996$shrunk$ph$in = $1794;$$sink1157 = $1804;
      label = 141;
      break;
     }
     default: {
      $$14$shrunk = 0;$$141012$shrunk = 0;$$141028 = 0;$$14996$shrunk = 0;
     }
     }
     if ((label|0) == 141) {
      label = 0;
      $$14996$shrunk$ph = HEAP8[$$14996$shrunk$ph$in>>0]|0;
      $$141012$shrunk$ph = HEAP8[$$141012$shrunk$ph$in>>0]|0;
      $1805 = HEAP8[$$sink1157>>0]|0;
      $$14$shrunk = $1805;$$141012$shrunk = $$141012$shrunk$ph;$$141028 = $$141028$ph;$$14996$shrunk = $$14996$shrunk$ph;
     }
     $1806 = $$141028 & $20;
     $1807 = ($1806|0)==($24|0);
     if (!($1807)) {
      $$14 = $$14$shrunk&255;
      $$14996 = $$14996$shrunk&255;
      $1808 = $$141012$shrunk & -32;
      $1809 = $1808&255;
      $1810 = $$14996 >>> 5;
      $1811 = $1810 << 2;
      $1812 = $1811 | $1809;
      $1813 = $$14 >>> 6;
      $1814 = $1812 | $1813;
      $1815 = (($15) + ($1814)|0);
      $1816 = HEAP8[$1815>>0]|0;
      HEAP8[$$161064>>0] = $1816;
     }
     $1817 = ((($$161064)) + 1|0);
     $1818 = (($$16) + ($23)|0);
     $$17 = $1818;$$171065 = $1817;$$7 = $$6;
     label = 145;
     continue;
    }
    else if ((label|0) == 145) {
     label = 0;
     switch ($22<<24>>24) {
     case 1:  {
      $1819 = HEAP8[$$17>>0]|0;
      $1820 = $1819&255;
      $1821 = HEAP8[$30>>0]|0;
      $1822 = $1821&255;
      $1823 = (79212 + ($1822<<2)|0);
      $1824 = HEAP32[$1823>>2]|0;
      $1825 = HEAP32[$31>>2]|0;
      $1826 = $1825 & $1820;
      $1827 = HEAP8[$32>>0]|0;
      $1828 = $1827&255;
      $1829 = $1826 >>> $1828;
      $1830 = (($1824) + ($1829)|0);
      $1831 = HEAP8[$33>>0]|0;
      $1832 = $1831&255;
      $1833 = (79212 + ($1832<<2)|0);
      $1834 = HEAP32[$1833>>2]|0;
      $1835 = HEAP32[$34>>2]|0;
      $1836 = $1835 & $1820;
      $1837 = HEAP8[$35>>0]|0;
      $1838 = $1837&255;
      $1839 = $1836 >>> $1838;
      $1840 = (($1834) + ($1839)|0);
      $1841 = HEAP8[$36>>0]|0;
      $1842 = $1841&255;
      $1843 = (79212 + ($1842<<2)|0);
      $1844 = HEAP32[$1843>>2]|0;
      $1845 = HEAP32[$37>>2]|0;
      $1846 = $1845 & $1820;
      $1847 = HEAP8[$38>>0]|0;
      $1848 = $1847&255;
      $1849 = $1846 >>> $1848;
      $1850 = (($1844) + ($1849)|0);
      $$151013$shrunk$ph$in = $1830;$$151029$ph = $1820;$$15997$shrunk$ph$in = $1840;$$sink1159 = $1850;
      label = 150;
      break;
     }
     case 2:  {
      $1851 = HEAP16[$$17>>1]|0;
      $1852 = $1851&65535;
      $1853 = HEAP8[$30>>0]|0;
      $1854 = $1853&255;
      $1855 = (79212 + ($1854<<2)|0);
      $1856 = HEAP32[$1855>>2]|0;
      $1857 = HEAP32[$31>>2]|0;
      $1858 = $1857 & $1852;
      $1859 = HEAP8[$32>>0]|0;
      $1860 = $1859&255;
      $1861 = $1858 >>> $1860;
      $1862 = (($1856) + ($1861)|0);
      $1863 = HEAP8[$33>>0]|0;
      $1864 = $1863&255;
      $1865 = (79212 + ($1864<<2)|0);
      $1866 = HEAP32[$1865>>2]|0;
      $1867 = HEAP32[$34>>2]|0;
      $1868 = $1867 & $1852;
      $1869 = HEAP8[$35>>0]|0;
      $1870 = $1869&255;
      $1871 = $1868 >>> $1870;
      $1872 = (($1866) + ($1871)|0);
      $1873 = HEAP8[$36>>0]|0;
      $1874 = $1873&255;
      $1875 = (79212 + ($1874<<2)|0);
      $1876 = HEAP32[$1875>>2]|0;
      $1877 = HEAP32[$37>>2]|0;
      $1878 = $1877 & $1852;
      $1879 = HEAP8[$38>>0]|0;
      $1880 = $1879&255;
      $1881 = $1878 >>> $1880;
      $1882 = (($1876) + ($1881)|0);
      $$151013$shrunk$ph$in = $1862;$$151029$ph = $1852;$$15997$shrunk$ph$in = $1872;$$sink1159 = $1882;
      label = 150;
      break;
     }
     case 3:  {
      $1883 = HEAP8[$32>>0]|0;
      $div1094 = ($1883&255) >>> 3;
      $1884 = $div1094&255;
      $1885 = (($$17) + ($1884)|0);
      $1886 = HEAP8[$35>>0]|0;
      $div1095 = ($1886&255) >>> 3;
      $1887 = $div1095&255;
      $1888 = (($$17) + ($1887)|0);
      $1889 = HEAP8[$38>>0]|0;
      $div1096 = ($1889&255) >>> 3;
      $1890 = $div1096&255;
      $1891 = (($$17) + ($1890)|0);
      $$151013$shrunk$ph$in = $1885;$$151029$ph = 0;$$15997$shrunk$ph$in = $1888;$$sink1159 = $1891;
      label = 150;
      break;
     }
     case 4:  {
      $1892 = HEAP32[$$17>>2]|0;
      $1893 = HEAP8[$30>>0]|0;
      $1894 = $1893&255;
      $1895 = (79212 + ($1894<<2)|0);
      $1896 = HEAP32[$1895>>2]|0;
      $1897 = HEAP32[$31>>2]|0;
      $1898 = $1897 & $1892;
      $1899 = HEAP8[$32>>0]|0;
      $1900 = $1899&255;
      $1901 = $1898 >>> $1900;
      $1902 = (($1896) + ($1901)|0);
      $1903 = HEAP8[$33>>0]|0;
      $1904 = $1903&255;
      $1905 = (79212 + ($1904<<2)|0);
      $1906 = HEAP32[$1905>>2]|0;
      $1907 = HEAP32[$34>>2]|0;
      $1908 = $1907 & $1892;
      $1909 = HEAP8[$35>>0]|0;
      $1910 = $1909&255;
      $1911 = $1908 >>> $1910;
      $1912 = (($1906) + ($1911)|0);
      $1913 = HEAP8[$36>>0]|0;
      $1914 = $1913&255;
      $1915 = (79212 + ($1914<<2)|0);
      $1916 = HEAP32[$1915>>2]|0;
      $1917 = HEAP32[$37>>2]|0;
      $1918 = $1917 & $1892;
      $1919 = HEAP8[$38>>0]|0;
      $1920 = $1919&255;
      $1921 = $1918 >>> $1920;
      $1922 = (($1916) + ($1921)|0);
      $$151013$shrunk$ph$in = $1902;$$151029$ph = $1892;$$15997$shrunk$ph$in = $1912;$$sink1159 = $1922;
      label = 150;
      break;
     }
     default: {
      $$15$shrunk = 0;$$151013$shrunk = 0;$$151029 = 0;$$15997$shrunk = 0;
     }
     }
     if ((label|0) == 150) {
      label = 0;
      $$15997$shrunk$ph = HEAP8[$$15997$shrunk$ph$in>>0]|0;
      $$151013$shrunk$ph = HEAP8[$$151013$shrunk$ph$in>>0]|0;
      $1923 = HEAP8[$$sink1159>>0]|0;
      $$15$shrunk = $1923;$$151013$shrunk = $$151013$shrunk$ph;$$151029 = $$151029$ph;$$15997$shrunk = $$15997$shrunk$ph;
     }
     $1924 = $$151029 & $20;
     $1925 = ($1924|0)==($24|0);
     if (!($1925)) {
      $$15 = $$15$shrunk&255;
      $$15997 = $$15997$shrunk&255;
      $1926 = $$151013$shrunk & -32;
      $1927 = $1926&255;
      $1928 = $$15997 >>> 5;
      $1929 = $1928 << 2;
      $1930 = $1929 | $1927;
      $1931 = $$15 >>> 6;
      $1932 = $1930 | $1931;
      $1933 = (($15) + ($1932)|0);
      $1934 = HEAP8[$1933>>0]|0;
      HEAP8[$$171065>>0] = $1934;
     }
     $1935 = ((($$171065)) + 1|0);
     $1936 = (($$17) + ($23)|0);
     $1937 = (($$7) + -1)|0;
     $1938 = ($$7|0)>(1);
     if ($1938) {
      $$0 = $1937;$$101042 = $1936;$$101058 = $1935;
      label = 82;
      continue;
     } else {
      break;
     }
    }
   }
   $1939 = (($1936) + ($7)|0);
   $1940 = (($1935) + ($11)|0);
   $1941 = (($1942) + -1)|0;
   $1943 = ($1942|0)==(0);
   if ($1943) {
    label = 156;
    break;
   } else {
    $$910411165 = $1939;$$910571164 = $1940;$1942 = $1941;
   }
  }
  if ((label|0) == 154) {
   // unreachable;
  }
  else if ((label|0) == 156) {
   return;
  }
 }
}
function _BlitNtoNKeyCopyAlpha($0) {
 $0 = $0|0;
 var $$010201142 = 0, $$010211141 = 0, $$01030 = 0, $$01038 = 0, $$01038$shrunk = 0, $$01046 = 0, $$01046$shrunk = 0, $$01054 = 0, $$01054$shrunk = 0, $$01062 = 0, $$01062$shrunk = 0, $$01070 = 0, $$1 = 0, $$11022 = 0, $$11031 = 0, $$11039 = 0, $$11039$shrunk = 0, $$11047 = 0, $$11047$shrunk = 0, $$11055 = 0;
 var $$11055$shrunk = 0, $$11063 = 0, $$11063$shrunk = 0, $$11071 = 0, $$2 = 0, $$21023 = 0, $$21032 = 0, $$21040 = 0, $$21040$shrunk = 0, $$21048 = 0, $$21048$shrunk = 0, $$21056 = 0, $$21056$shrunk = 0, $$21064 = 0, $$21064$shrunk = 0, $$21072 = 0, $$3 = 0, $$31024 = 0, $$31033 = 0, $$31041 = 0;
 var $$31041$shrunk = 0, $$31049 = 0, $$31049$shrunk = 0, $$31057 = 0, $$31057$shrunk = 0, $$31065 = 0, $$31065$shrunk = 0, $$31073 = 0, $$4 = 0, $$41025 = 0, $$41034 = 0, $$41042 = 0, $$41042$shrunk = 0, $$41050 = 0, $$41050$shrunk = 0, $$41058 = 0, $$41058$shrunk = 0, $$41066 = 0, $$41066$shrunk = 0, $$41074 = 0;
 var $$5 = 0, $$51026 = 0, $$51035 = 0, $$51043 = 0, $$51043$shrunk = 0, $$51051 = 0, $$51051$shrunk = 0, $$51059 = 0, $$51059$shrunk = 0, $$51067 = 0, $$51067$shrunk = 0, $$51075 = 0, $$6 = 0, $$61027 = 0, $$61036 = 0, $$61044 = 0, $$61044$shrunk = 0, $$61052 = 0, $$61052$shrunk = 0, $$61060 = 0;
 var $$61060$shrunk = 0, $$61068 = 0, $$61068$shrunk = 0, $$61076 = 0, $$7 = 0, $$71028 = 0, $$71037 = 0, $$71045 = 0, $$71045$shrunk = 0, $$71053 = 0, $$71053$shrunk = 0, $$71061 = 0, $$71061$shrunk = 0, $$71069 = 0, $$71069$shrunk = 0, $$71077 = 0, $$8 = 0, $$81029 = 0, $$in = 0, $1 = 0;
 var $10 = 0, $100 = 0, $1000 = 0, $1001 = 0, $1002 = 0, $1003 = 0, $1004 = 0, $1005 = 0, $1006 = 0, $1007 = 0, $1008 = 0, $1009 = 0, $101 = 0, $1010 = 0, $1011 = 0, $1012 = 0, $1013 = 0, $1014 = 0, $1015 = 0, $1016 = 0;
 var $1017 = 0, $1018 = 0, $1019 = 0, $102 = 0, $1020 = 0, $1021 = 0, $1022 = 0, $1023 = 0, $1024 = 0, $1025 = 0, $1026 = 0, $1027 = 0, $1028 = 0, $1029 = 0, $103 = 0, $1030 = 0, $1031 = 0, $1032 = 0, $1033 = 0, $1034 = 0;
 var $1035 = 0, $1036 = 0, $1037 = 0, $1038 = 0, $1039 = 0, $104 = 0, $1040 = 0, $1041 = 0, $1042 = 0, $1043 = 0, $1044 = 0, $1045 = 0, $1046 = 0, $1047 = 0, $1048 = 0, $1049 = 0, $105 = 0, $1050 = 0, $1051 = 0, $1052 = 0;
 var $1053 = 0, $1054 = 0, $1055 = 0, $1056 = 0, $1057 = 0, $1058 = 0, $1059 = 0, $106 = 0, $1060 = 0, $1061 = 0, $1062 = 0, $1063 = 0, $1064 = 0, $1065 = 0, $1066 = 0, $1067 = 0, $1068 = 0, $1069 = 0, $107 = 0, $1070 = 0;
 var $1071 = 0, $1072 = 0, $1073 = 0, $1074 = 0, $1075 = 0, $1076 = 0, $1077 = 0, $1078 = 0, $1079 = 0, $108 = 0, $1080 = 0, $1081 = 0, $1082 = 0, $1083 = 0, $1084 = 0, $1085 = 0, $1086 = 0, $1087 = 0, $1088 = 0, $1089 = 0;
 var $109 = 0, $1090 = 0, $1091 = 0, $1092 = 0, $1093 = 0, $1094 = 0, $1095 = 0, $1096 = 0, $1097 = 0, $1098 = 0, $1099 = 0, $11 = 0, $110 = 0, $1100 = 0, $1101 = 0, $1102 = 0, $1103 = 0, $1104 = 0, $1105 = 0, $1106 = 0;
 var $1107 = 0, $1108 = 0, $1109 = 0, $111 = 0, $1110 = 0, $1111 = 0, $1112 = 0, $1113 = 0, $1114 = 0, $1115 = 0, $1116 = 0, $1117 = 0, $1118 = 0, $1119 = 0, $112 = 0, $1120 = 0, $1121 = 0, $1122 = 0, $1123 = 0, $1124 = 0;
 var $1125 = 0, $1126 = 0, $1127 = 0, $1128 = 0, $1129 = 0, $113 = 0, $1130 = 0, $1131 = 0, $1132 = 0, $1133 = 0, $1134 = 0, $1135 = 0, $1136 = 0, $1137 = 0, $1138 = 0, $1139 = 0, $114 = 0, $1140 = 0, $1141 = 0, $1142 = 0;
 var $1143 = 0, $1144 = 0, $1145 = 0, $1146 = 0, $1147 = 0, $1148 = 0, $1149 = 0, $115 = 0, $1150 = 0, $1151 = 0, $1152 = 0, $1153 = 0, $1154 = 0, $1155 = 0, $1156 = 0, $1157 = 0, $1158 = 0, $1159 = 0, $116 = 0, $1160 = 0;
 var $1161 = 0, $1162 = 0, $1163 = 0, $1164 = 0, $1165 = 0, $1166 = 0, $1167 = 0, $1168 = 0, $1169 = 0, $117 = 0, $1170 = 0, $1171 = 0, $1172 = 0, $1173 = 0, $1174 = 0, $1175 = 0, $1176 = 0, $1177 = 0, $1178 = 0, $1179 = 0;
 var $118 = 0, $1180 = 0, $1181 = 0, $1182 = 0, $1183 = 0, $1184 = 0, $1185 = 0, $1186 = 0, $1187 = 0, $1188 = 0, $1189 = 0, $119 = 0, $1190 = 0, $1191 = 0, $1192 = 0, $1193 = 0, $1194 = 0, $1195 = 0, $1196 = 0, $1197 = 0;
 var $1198 = 0, $1199 = 0, $12 = 0, $120 = 0, $1200 = 0, $1201 = 0, $1202 = 0, $1203 = 0, $1204 = 0, $1205 = 0, $1206 = 0, $1207 = 0, $1208 = 0, $1209 = 0, $121 = 0, $1210 = 0, $1211 = 0, $1212 = 0, $1213 = 0, $1214 = 0;
 var $1215 = 0, $1216 = 0, $1217 = 0, $1218 = 0, $1219 = 0, $122 = 0, $1220 = 0, $1221 = 0, $1222 = 0, $1223 = 0, $1224 = 0, $1225 = 0, $1226 = 0, $1227 = 0, $1228 = 0, $1229 = 0, $123 = 0, $1230 = 0, $1231 = 0, $1232 = 0;
 var $1233 = 0, $1234 = 0, $1235 = 0, $1236 = 0, $1237 = 0, $1238 = 0, $1239 = 0, $124 = 0, $1240 = 0, $1241 = 0, $1242 = 0, $1243 = 0, $1244 = 0, $1245 = 0, $1246 = 0, $1247 = 0, $1248 = 0, $1249 = 0, $125 = 0, $1250 = 0;
 var $1251 = 0, $1252 = 0, $1253 = 0, $1254 = 0, $1255 = 0, $1256 = 0, $1257 = 0, $1258 = 0, $1259 = 0, $126 = 0, $1260 = 0, $1261 = 0, $1262 = 0, $1263 = 0, $1264 = 0, $1265 = 0, $1266 = 0, $1267 = 0, $1268 = 0, $1269 = 0;
 var $127 = 0, $1270 = 0, $1271 = 0, $1272 = 0, $1273 = 0, $1274 = 0, $1275 = 0, $1276 = 0, $1277 = 0, $1278 = 0, $1279 = 0, $128 = 0, $1280 = 0, $1281 = 0, $1282 = 0, $1283 = 0, $1284 = 0, $1285 = 0, $1286 = 0, $1287 = 0;
 var $1288 = 0, $1289 = 0, $129 = 0, $1290 = 0, $1291 = 0, $1292 = 0, $1293 = 0, $1294 = 0, $1295 = 0, $1296 = 0, $1297 = 0, $1298 = 0, $1299 = 0, $13 = 0, $130 = 0, $1300 = 0, $1301 = 0, $1302 = 0, $1303 = 0, $1304 = 0;
 var $1305 = 0, $1306 = 0, $1307 = 0, $1308 = 0, $1309 = 0, $131 = 0, $1310 = 0, $1311 = 0, $1312 = 0, $1313 = 0, $1314 = 0, $1315 = 0, $1316 = 0, $1317 = 0, $1318 = 0, $1319 = 0, $132 = 0, $1320 = 0, $1321 = 0, $1322 = 0;
 var $1323 = 0, $1324 = 0, $1325 = 0, $1326 = 0, $1327 = 0, $1328 = 0, $1329 = 0, $133 = 0, $1330 = 0, $1331 = 0, $1332 = 0, $1333 = 0, $1334 = 0, $1335 = 0, $1336 = 0, $1337 = 0, $1338 = 0, $1339 = 0, $134 = 0, $1340 = 0;
 var $1341 = 0, $1342 = 0, $1343 = 0, $1344 = 0, $1345 = 0, $1346 = 0, $1347 = 0, $1348 = 0, $1349 = 0, $135 = 0, $1350 = 0, $1351 = 0, $1352 = 0, $1353 = 0, $1354 = 0, $1355 = 0, $1356 = 0, $1357 = 0, $1358 = 0, $1359 = 0;
 var $136 = 0, $1360 = 0, $1361 = 0, $1362 = 0, $1363 = 0, $1364 = 0, $1365 = 0, $1366 = 0, $1367 = 0, $1368 = 0, $1369 = 0, $137 = 0, $1370 = 0, $1371 = 0, $1372 = 0, $1373 = 0, $1374 = 0, $1375 = 0, $1376 = 0, $1377 = 0;
 var $1378 = 0, $1379 = 0, $138 = 0, $1380 = 0, $1381 = 0, $1382 = 0, $1383 = 0, $1384 = 0, $1385 = 0, $1386 = 0, $1387 = 0, $1388 = 0, $1389 = 0, $139 = 0, $1390 = 0, $1391 = 0, $1392 = 0, $1393 = 0, $1394 = 0, $1395 = 0;
 var $1396 = 0, $1397 = 0, $1398 = 0, $1399 = 0, $14 = 0, $140 = 0, $1400 = 0, $1401 = 0, $1402 = 0, $1403 = 0, $1404 = 0, $1405 = 0, $1406 = 0, $1407 = 0, $1408 = 0, $1409 = 0, $141 = 0, $1410 = 0, $1411 = 0, $1412 = 0;
 var $1413 = 0, $1414 = 0, $1415 = 0, $1416 = 0, $1417 = 0, $1418 = 0, $1419 = 0, $142 = 0, $1420 = 0, $1421 = 0, $1422 = 0, $1423 = 0, $1424 = 0, $1425 = 0, $1426 = 0, $1427 = 0, $1428 = 0, $1429 = 0, $143 = 0, $1430 = 0;
 var $1431 = 0, $1432 = 0, $1433 = 0, $1434 = 0, $1435 = 0, $1436 = 0, $1437 = 0, $1438 = 0, $1439 = 0, $144 = 0, $1440 = 0, $1441 = 0, $1442 = 0, $1443 = 0, $1444 = 0, $1445 = 0, $1446 = 0, $1447 = 0, $1448 = 0, $1449 = 0;
 var $145 = 0, $1450 = 0, $1451 = 0, $1452 = 0, $1453 = 0, $1454 = 0, $1455 = 0, $1456 = 0, $1457 = 0, $1458 = 0, $1459 = 0, $146 = 0, $1460 = 0, $1461 = 0, $1462 = 0, $1463 = 0, $1464 = 0, $1465 = 0, $1466 = 0, $1467 = 0;
 var $1468 = 0, $1469 = 0, $147 = 0, $1470 = 0, $1471 = 0, $1472 = 0, $1473 = 0, $1474 = 0, $1475 = 0, $1476 = 0, $1477 = 0, $1478 = 0, $1479 = 0, $148 = 0, $1480 = 0, $1481 = 0, $1482 = 0, $1483 = 0, $1484 = 0, $1485 = 0;
 var $1486 = 0, $1487 = 0, $1488 = 0, $1489 = 0, $149 = 0, $1490 = 0, $1491 = 0, $1492 = 0, $1493 = 0, $1494 = 0, $1495 = 0, $1496 = 0, $1497 = 0, $1498 = 0, $1499 = 0, $15 = 0, $150 = 0, $1500 = 0, $1501 = 0, $1502 = 0;
 var $1503 = 0, $1504 = 0, $1505 = 0, $1506 = 0, $1507 = 0, $1508 = 0, $1509 = 0, $151 = 0, $1510 = 0, $1511 = 0, $1512 = 0, $1513 = 0, $1514 = 0, $1515 = 0, $1516 = 0, $1517 = 0, $1518 = 0, $1519 = 0, $152 = 0, $1520 = 0;
 var $1521 = 0, $1522 = 0, $1523 = 0, $1524 = 0, $1525 = 0, $1526 = 0, $1527 = 0, $1528 = 0, $1529 = 0, $153 = 0, $1530 = 0, $1531 = 0, $1532 = 0, $1533 = 0, $1534 = 0, $1535 = 0, $1536 = 0, $1537 = 0, $1538 = 0, $1539 = 0;
 var $154 = 0, $1540 = 0, $1541 = 0, $1542 = 0, $1543 = 0, $1544 = 0, $1545 = 0, $1546 = 0, $1547 = 0, $1548 = 0, $1549 = 0, $155 = 0, $1550 = 0, $1551 = 0, $1552 = 0, $1553 = 0, $1554 = 0, $1555 = 0, $1556 = 0, $1557 = 0;
 var $1558 = 0, $1559 = 0, $156 = 0, $1560 = 0, $1561 = 0, $1562 = 0, $1563 = 0, $1564 = 0, $1565 = 0, $1566 = 0, $1567 = 0, $1568 = 0, $1569 = 0, $157 = 0, $1570 = 0, $1571 = 0, $1572 = 0, $1573 = 0, $1574 = 0, $1575 = 0;
 var $1576 = 0, $1577 = 0, $1578 = 0, $1579 = 0, $158 = 0, $1580 = 0, $1581 = 0, $1582 = 0, $1583 = 0, $1584 = 0, $1585 = 0, $1586 = 0, $1587 = 0, $1588 = 0, $1589 = 0, $159 = 0, $1590 = 0, $1591 = 0, $1592 = 0, $1593 = 0;
 var $1594 = 0, $1595 = 0, $1596 = 0, $1597 = 0, $1598 = 0, $1599 = 0, $16 = 0, $160 = 0, $1600 = 0, $1601 = 0, $1602 = 0, $1603 = 0, $1604 = 0, $1605 = 0, $1606 = 0, $1607 = 0, $1608 = 0, $1609 = 0, $161 = 0, $1610 = 0;
 var $1611 = 0, $1612 = 0, $1613 = 0, $1614 = 0, $1615 = 0, $1616 = 0, $1617 = 0, $1618 = 0, $1619 = 0, $162 = 0, $1620 = 0, $1621 = 0, $1622 = 0, $1623 = 0, $1624 = 0, $1625 = 0, $1626 = 0, $1627 = 0, $1628 = 0, $1629 = 0;
 var $163 = 0, $1630 = 0, $1631 = 0, $1632 = 0, $1633 = 0, $1634 = 0, $1635 = 0, $1636 = 0, $1637 = 0, $1638 = 0, $1639 = 0, $164 = 0, $1640 = 0, $1641 = 0, $1642 = 0, $1643 = 0, $1644 = 0, $1645 = 0, $1646 = 0, $1647 = 0;
 var $1648 = 0, $1649 = 0, $165 = 0, $1650 = 0, $1651 = 0, $1652 = 0, $1653 = 0, $1654 = 0, $1655 = 0, $1656 = 0, $1657 = 0, $1658 = 0, $1659 = 0, $166 = 0, $1660 = 0, $1661 = 0, $1662 = 0, $1663 = 0, $1664 = 0, $1665 = 0;
 var $1666 = 0, $1667 = 0, $1668 = 0, $1669 = 0, $167 = 0, $1670 = 0, $1671 = 0, $1672 = 0, $1673 = 0, $1674 = 0, $1675 = 0, $1676 = 0, $1677 = 0, $1678 = 0, $1679 = 0, $168 = 0, $1680 = 0, $1681 = 0, $1682 = 0, $1683 = 0;
 var $1684 = 0, $1685 = 0, $1686 = 0, $1687 = 0, $1688 = 0, $1689 = 0, $169 = 0, $1690 = 0, $1691 = 0, $1692 = 0, $1693 = 0, $1694 = 0, $1695 = 0, $1696 = 0, $1697 = 0, $1698 = 0, $1699 = 0, $17 = 0, $170 = 0, $1700 = 0;
 var $1701 = 0, $1702 = 0, $1703 = 0, $1704 = 0, $1705 = 0, $1706 = 0, $1707 = 0, $1708 = 0, $1709 = 0, $171 = 0, $1710 = 0, $1711 = 0, $1712 = 0, $1713 = 0, $1714 = 0, $1715 = 0, $1716 = 0, $1717 = 0, $1718 = 0, $1719 = 0;
 var $172 = 0, $1720 = 0, $1721 = 0, $1722 = 0, $1723 = 0, $1724 = 0, $1725 = 0, $1726 = 0, $1727 = 0, $1728 = 0, $1729 = 0, $173 = 0, $1730 = 0, $1731 = 0, $1732 = 0, $1733 = 0, $1734 = 0, $1735 = 0, $1736 = 0, $1737 = 0;
 var $1738 = 0, $1739 = 0, $174 = 0, $1740 = 0, $1741 = 0, $1742 = 0, $1743 = 0, $1744 = 0, $1745 = 0, $1746 = 0, $1747 = 0, $1748 = 0, $1749 = 0, $175 = 0, $1750 = 0, $1751 = 0, $1752 = 0, $1753 = 0, $1754 = 0, $1755 = 0;
 var $1756 = 0, $1757 = 0, $1758 = 0, $1759 = 0, $176 = 0, $1760 = 0, $1761 = 0, $1762 = 0, $1763 = 0, $1764 = 0, $1765 = 0, $1766 = 0, $1767 = 0, $1768 = 0, $1769 = 0, $177 = 0, $1770 = 0, $1771 = 0, $1772 = 0, $1773 = 0;
 var $1774 = 0, $1775 = 0, $1776 = 0, $1777 = 0, $1778 = 0, $1779 = 0, $178 = 0, $1780 = 0, $1781 = 0, $1782 = 0, $1783 = 0, $1784 = 0, $1785 = 0, $1786 = 0, $1787 = 0, $1788 = 0, $1789 = 0, $179 = 0, $1790 = 0, $1791 = 0;
 var $1792 = 0, $1793 = 0, $1794 = 0, $1795 = 0, $1796 = 0, $1797 = 0, $1798 = 0, $1799 = 0, $18 = 0, $180 = 0, $1800 = 0, $1801 = 0, $1802 = 0, $1803 = 0, $1804 = 0, $1805 = 0, $1806 = 0, $1807 = 0, $1808 = 0, $1809 = 0;
 var $181 = 0, $1810 = 0, $1811 = 0, $1812 = 0, $1813 = 0, $1814 = 0, $1815 = 0, $1816 = 0, $1817 = 0, $1818 = 0, $1819 = 0, $182 = 0, $1820 = 0, $1821 = 0, $1822 = 0, $1823 = 0, $1824 = 0, $1825 = 0, $1826 = 0, $1827 = 0;
 var $1828 = 0, $1829 = 0, $183 = 0, $1830 = 0, $1831 = 0, $1832 = 0, $1833 = 0, $1834 = 0, $1835 = 0, $1836 = 0, $1837 = 0, $1838 = 0, $1839 = 0, $184 = 0, $1840 = 0, $1841 = 0, $1842 = 0, $1843 = 0, $1844 = 0, $1845 = 0;
 var $1846 = 0, $1847 = 0, $1848 = 0, $1849 = 0, $185 = 0, $1850 = 0, $1851 = 0, $1852 = 0, $1853 = 0, $1854 = 0, $1855 = 0, $1856 = 0, $1857 = 0, $1858 = 0, $1859 = 0, $186 = 0, $1860 = 0, $1861 = 0, $1862 = 0, $1863 = 0;
 var $1864 = 0, $1865 = 0, $1866 = 0, $1867 = 0, $1868 = 0, $1869 = 0, $187 = 0, $1870 = 0, $1871 = 0, $1872 = 0, $1873 = 0, $1874 = 0, $1875 = 0, $1876 = 0, $1877 = 0, $1878 = 0, $1879 = 0, $188 = 0, $1880 = 0, $1881 = 0;
 var $1882 = 0, $1883 = 0, $1884 = 0, $1885 = 0, $1886 = 0, $1887 = 0, $1888 = 0, $1889 = 0, $189 = 0, $1890 = 0, $1891 = 0, $1892 = 0, $1893 = 0, $1894 = 0, $1895 = 0, $1896 = 0, $1897 = 0, $1898 = 0, $1899 = 0, $19 = 0;
 var $190 = 0, $1900 = 0, $1901 = 0, $1902 = 0, $1903 = 0, $1904 = 0, $1905 = 0, $1906 = 0, $1907 = 0, $1908 = 0, $1909 = 0, $191 = 0, $1910 = 0, $1911 = 0, $1912 = 0, $1913 = 0, $1914 = 0, $1915 = 0, $1916 = 0, $1917 = 0;
 var $1918 = 0, $1919 = 0, $192 = 0, $1920 = 0, $1921 = 0, $1922 = 0, $1923 = 0, $1924 = 0, $1925 = 0, $1926 = 0, $1927 = 0, $1928 = 0, $1929 = 0, $193 = 0, $1930 = 0, $1931 = 0, $1932 = 0, $1933 = 0, $1934 = 0, $1935 = 0;
 var $1936 = 0, $1937 = 0, $1938 = 0, $1939 = 0, $194 = 0, $1940 = 0, $1941 = 0, $1942 = 0, $1943 = 0, $1944 = 0, $1945 = 0, $1946 = 0, $1947 = 0, $1948 = 0, $1949 = 0, $195 = 0, $1950 = 0, $1951 = 0, $1952 = 0, $1953 = 0;
 var $1954 = 0, $1955 = 0, $1956 = 0, $1957 = 0, $1958 = 0, $1959 = 0, $196 = 0, $1960 = 0, $1961 = 0, $1962 = 0, $1963 = 0, $1964 = 0, $1965 = 0, $1966 = 0, $1967 = 0, $1968 = 0, $1969 = 0, $197 = 0, $1970 = 0, $1971 = 0;
 var $1972 = 0, $1973 = 0, $1974 = 0, $1975 = 0, $1976 = 0, $1977 = 0, $1978 = 0, $1979 = 0, $198 = 0, $1980 = 0, $1981 = 0, $1982 = 0, $1983 = 0, $1984 = 0, $1985 = 0, $1986 = 0, $1987 = 0, $1988 = 0, $1989 = 0, $199 = 0;
 var $1990 = 0, $1991 = 0, $1992 = 0, $1993 = 0, $1994 = 0, $1995 = 0, $1996 = 0, $1997 = 0, $1998 = 0, $1999 = 0, $2 = 0, $20 = 0, $200 = 0, $2000 = 0, $2001 = 0, $2002 = 0, $2003 = 0, $2004 = 0, $2005 = 0, $2006 = 0;
 var $2007 = 0, $2008 = 0, $2009 = 0, $201 = 0, $2010 = 0, $2011 = 0, $2012 = 0, $2013 = 0, $2014 = 0, $2015 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0;
 var $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0;
 var $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0;
 var $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0;
 var $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0;
 var $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0;
 var $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0;
 var $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0;
 var $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0;
 var $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0;
 var $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0;
 var $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0;
 var $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0;
 var $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0;
 var $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0;
 var $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0;
 var $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0;
 var $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0;
 var $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0;
 var $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0;
 var $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0;
 var $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0;
 var $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0;
 var $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0;
 var $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0;
 var $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0;
 var $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0;
 var $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0;
 var $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0;
 var $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0;
 var $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0;
 var $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0;
 var $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0;
 var $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0;
 var $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0, $823 = 0;
 var $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = 0, $834 = 0, $835 = 0, $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = 0, $841 = 0;
 var $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0, $850 = 0, $851 = 0, $852 = 0, $853 = 0, $854 = 0, $855 = 0, $856 = 0, $857 = 0, $858 = 0, $859 = 0, $86 = 0;
 var $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0, $869 = 0, $87 = 0, $870 = 0, $871 = 0, $872 = 0, $873 = 0, $874 = 0, $875 = 0, $876 = 0, $877 = 0, $878 = 0;
 var $879 = 0, $88 = 0, $880 = 0, $881 = 0, $882 = 0, $883 = 0, $884 = 0, $885 = 0, $886 = 0, $887 = 0, $888 = 0, $889 = 0, $89 = 0, $890 = 0, $891 = 0, $892 = 0, $893 = 0, $894 = 0, $895 = 0, $896 = 0;
 var $897 = 0, $898 = 0, $899 = 0, $9 = 0, $90 = 0, $900 = 0, $901 = 0, $902 = 0, $903 = 0, $904 = 0, $905 = 0, $906 = 0, $907 = 0, $908 = 0, $909 = 0, $91 = 0, $910 = 0, $911 = 0, $912 = 0, $913 = 0;
 var $914 = 0, $915 = 0, $916 = 0, $917 = 0, $918 = 0, $919 = 0, $92 = 0, $920 = 0, $921 = 0, $922 = 0, $923 = 0, $924 = 0, $925 = 0, $926 = 0, $927 = 0, $928 = 0, $929 = 0, $93 = 0, $930 = 0, $931 = 0;
 var $932 = 0, $933 = 0, $934 = 0, $935 = 0, $936 = 0, $937 = 0, $938 = 0, $939 = 0, $94 = 0, $940 = 0, $941 = 0, $942 = 0, $943 = 0, $944 = 0, $945 = 0, $946 = 0, $947 = 0, $948 = 0, $949 = 0, $95 = 0;
 var $950 = 0, $951 = 0, $952 = 0, $953 = 0, $954 = 0, $955 = 0, $956 = 0, $957 = 0, $958 = 0, $959 = 0, $96 = 0, $960 = 0, $961 = 0, $962 = 0, $963 = 0, $964 = 0, $965 = 0, $966 = 0, $967 = 0, $968 = 0;
 var $969 = 0, $97 = 0, $970 = 0, $971 = 0, $972 = 0, $973 = 0, $974 = 0, $975 = 0, $976 = 0, $977 = 0, $978 = 0, $979 = 0, $98 = 0, $980 = 0, $981 = 0, $982 = 0, $983 = 0, $984 = 0, $985 = 0, $986 = 0;
 var $987 = 0, $988 = 0, $989 = 0, $99 = 0, $990 = 0, $991 = 0, $992 = 0, $993 = 0, $994 = 0, $995 = 0, $996 = 0, $997 = 0, $998 = 0, $999 = 0, $div = 0, $div1087 = 0, $div1088 = 0, $div1089 = 0, $div1090 = 0, $div1091 = 0;
 var $div1093 = 0, $div1094 = 0, $div1095 = 0, $div1096 = 0, $div1097 = 0, $div1098 = 0, $div1100 = 0, $div1101 = 0, $div1102 = 0, $div1103 = 0, $div1104 = 0, $div1105 = 0, $div1107 = 0, $div1108 = 0, $div1109 = 0, $div1110 = 0, $div1111 = 0, $div1112 = 0, $div1114 = 0, $div1115 = 0;
 var $div1116 = 0, $div1117 = 0, $div1118 = 0, $div1119 = 0, $div1121 = 0, $div1122 = 0, $div1123 = 0, $div1124 = 0, $div1125 = 0, $div1126 = 0, $div1128 = 0, $div1129 = 0, $div1130 = 0, $div1131 = 0, $div1132 = 0, $div1133 = 0, $div1135 = 0, $div1136 = 0, $div1137 = 0, $div1138 = 0;
 var $div1139 = 0, $div1140 = 0, $trunc = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($0)) + 36|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($0)) + 56|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ((($0)) + 40|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ((($0)) + 44|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ((($12)) + 24|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $16 ^ -1;
 $18 = ((($12)) + 9|0);
 $19 = HEAP8[$18>>0]|0;
 $20 = ((($14)) + 9|0);
 $21 = HEAP8[$20>>0]|0;
 $22 = $10 & $17;
 $23 = ($4|0)==(0);
 if ($23) {
  return;
 }
 $24 = ((($0)) + 20|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = HEAP32[$0>>2]|0;
 $27 = (($2) + 7)|0;
 $28 = (($27|0) / 8)&-1;
 $trunc = $2&255;
 $29 = $19&255;
 $30 = $21&255;
 $31 = ((($14)) + 28|0);
 $32 = ((($14)) + 32|0);
 $33 = ((($14)) + 29|0);
 $34 = ((($14)) + 33|0);
 $35 = ((($14)) + 30|0);
 $36 = ((($14)) + 34|0);
 $37 = ((($14)) + 31|0);
 $38 = ((($14)) + 35|0);
 $39 = ((($12)) + 28|0);
 $40 = ((($12)) + 12|0);
 $41 = ((($12)) + 32|0);
 $42 = ((($12)) + 29|0);
 $43 = ((($12)) + 16|0);
 $44 = ((($12)) + 33|0);
 $45 = ((($12)) + 30|0);
 $46 = ((($12)) + 20|0);
 $47 = ((($12)) + 34|0);
 $48 = ((($12)) + 31|0);
 $49 = ((($12)) + 35|0);
 $$010201142 = $26;$$010211141 = $25;$$in = $4;
 L4: while(1) {
  $50 = (($$in) + -1)|0;
  $trunc$clear = $trunc & 7;
  switch ($trunc$clear<<24>>24) {
  case 0:  {
   $$01070 = $28;$$1 = $$010201142;$$11022 = $$010211141;
   label = 4;
   break;
  }
  case 7:  {
   $$11071 = $28;$$2 = $$010201142;$$21023 = $$010211141;
   label = 16;
   break;
  }
  case 6:  {
   $$21072 = $28;$$3 = $$010201142;$$31024 = $$010211141;
   label = 28;
   break;
  }
  case 5:  {
   $$31073 = $28;$$4 = $$010201142;$$41025 = $$010211141;
   label = 40;
   break;
  }
  case 4:  {
   $$41074 = $28;$$5 = $$010201142;$$51026 = $$010211141;
   label = 52;
   break;
  }
  case 3:  {
   $$51075 = $28;$$6 = $$010201142;$$61027 = $$010211141;
   label = 64;
   break;
  }
  case 2:  {
   $$61076 = $28;$$7 = $$010201142;$$71028 = $$010211141;
   label = 76;
   break;
  }
  case 1:  {
   $$71077 = $28;$$8 = $$010201142;$$81029 = $$010211141;
   label = 88;
   break;
  }
  default: {
   label = 100;
   break L4;
  }
  }
  while(1) {
   if ((label|0) == 4) {
    label = 0;
    switch ($19<<24>>24) {
    case 1:  {
     $51 = HEAP8[$$1>>0]|0;
     $52 = $51&255;
     $53 = HEAP8[$39>>0]|0;
     $54 = $53&255;
     $55 = (79212 + ($54<<2)|0);
     $56 = HEAP32[$55>>2]|0;
     $57 = HEAP32[$40>>2]|0;
     $58 = $57 & $52;
     $59 = HEAP8[$41>>0]|0;
     $60 = $59&255;
     $61 = $58 >>> $60;
     $62 = (($56) + ($61)|0);
     $63 = HEAP8[$62>>0]|0;
     $64 = HEAP8[$42>>0]|0;
     $65 = $64&255;
     $66 = (79212 + ($65<<2)|0);
     $67 = HEAP32[$66>>2]|0;
     $68 = HEAP32[$43>>2]|0;
     $69 = $68 & $52;
     $70 = HEAP8[$44>>0]|0;
     $71 = $70&255;
     $72 = $69 >>> $71;
     $73 = (($67) + ($72)|0);
     $74 = HEAP8[$73>>0]|0;
     $75 = HEAP8[$45>>0]|0;
     $76 = $75&255;
     $77 = (79212 + ($76<<2)|0);
     $78 = HEAP32[$77>>2]|0;
     $79 = HEAP32[$46>>2]|0;
     $80 = $79 & $52;
     $81 = HEAP8[$47>>0]|0;
     $82 = $81&255;
     $83 = $80 >>> $82;
     $84 = (($78) + ($83)|0);
     $85 = HEAP8[$84>>0]|0;
     $86 = HEAP8[$48>>0]|0;
     $87 = $86&255;
     $88 = (79212 + ($87<<2)|0);
     $89 = HEAP32[$88>>2]|0;
     $90 = HEAP32[$15>>2]|0;
     $91 = $90 & $52;
     $92 = HEAP8[$49>>0]|0;
     $93 = $92&255;
     $94 = $91 >>> $93;
     $95 = (($89) + ($94)|0);
     $96 = HEAP8[$95>>0]|0;
     $$01030 = $52;$$01038$shrunk = $63;$$01046$shrunk = $74;$$01054$shrunk = $85;$$01062$shrunk = $96;
     break;
    }
    case 2:  {
     $97 = HEAP16[$$1>>1]|0;
     $98 = $97&65535;
     $99 = HEAP8[$39>>0]|0;
     $100 = $99&255;
     $101 = (79212 + ($100<<2)|0);
     $102 = HEAP32[$101>>2]|0;
     $103 = HEAP32[$40>>2]|0;
     $104 = $103 & $98;
     $105 = HEAP8[$41>>0]|0;
     $106 = $105&255;
     $107 = $104 >>> $106;
     $108 = (($102) + ($107)|0);
     $109 = HEAP8[$108>>0]|0;
     $110 = HEAP8[$42>>0]|0;
     $111 = $110&255;
     $112 = (79212 + ($111<<2)|0);
     $113 = HEAP32[$112>>2]|0;
     $114 = HEAP32[$43>>2]|0;
     $115 = $114 & $98;
     $116 = HEAP8[$44>>0]|0;
     $117 = $116&255;
     $118 = $115 >>> $117;
     $119 = (($113) + ($118)|0);
     $120 = HEAP8[$119>>0]|0;
     $121 = HEAP8[$45>>0]|0;
     $122 = $121&255;
     $123 = (79212 + ($122<<2)|0);
     $124 = HEAP32[$123>>2]|0;
     $125 = HEAP32[$46>>2]|0;
     $126 = $125 & $98;
     $127 = HEAP8[$47>>0]|0;
     $128 = $127&255;
     $129 = $126 >>> $128;
     $130 = (($124) + ($129)|0);
     $131 = HEAP8[$130>>0]|0;
     $132 = HEAP8[$48>>0]|0;
     $133 = $132&255;
     $134 = (79212 + ($133<<2)|0);
     $135 = HEAP32[$134>>2]|0;
     $136 = HEAP32[$15>>2]|0;
     $137 = $136 & $98;
     $138 = HEAP8[$49>>0]|0;
     $139 = $138&255;
     $140 = $137 >>> $139;
     $141 = (($135) + ($140)|0);
     $142 = HEAP8[$141>>0]|0;
     $$01030 = $98;$$01038$shrunk = $109;$$01046$shrunk = $120;$$01054$shrunk = $131;$$01062$shrunk = $142;
     break;
    }
    case 3:  {
     $143 = HEAP8[$41>>0]|0;
     $div1131 = ($143&255) >>> 3;
     $144 = $div1131&255;
     $145 = (($$1) + ($144)|0);
     $146 = HEAP8[$145>>0]|0;
     $147 = HEAP8[$44>>0]|0;
     $div1132 = ($147&255) >>> 3;
     $148 = $div1132&255;
     $149 = (($$1) + ($148)|0);
     $150 = HEAP8[$149>>0]|0;
     $151 = HEAP8[$47>>0]|0;
     $div1133 = ($151&255) >>> 3;
     $152 = $div1133&255;
     $153 = (($$1) + ($152)|0);
     $154 = HEAP8[$153>>0]|0;
     $$01030 = 0;$$01038$shrunk = $146;$$01046$shrunk = $150;$$01054$shrunk = $154;$$01062$shrunk = -1;
     break;
    }
    case 4:  {
     $155 = HEAP32[$$1>>2]|0;
     $156 = HEAP8[$39>>0]|0;
     $157 = $156&255;
     $158 = (79212 + ($157<<2)|0);
     $159 = HEAP32[$158>>2]|0;
     $160 = HEAP32[$40>>2]|0;
     $161 = $160 & $155;
     $162 = HEAP8[$41>>0]|0;
     $163 = $162&255;
     $164 = $161 >>> $163;
     $165 = (($159) + ($164)|0);
     $166 = HEAP8[$165>>0]|0;
     $167 = HEAP8[$42>>0]|0;
     $168 = $167&255;
     $169 = (79212 + ($168<<2)|0);
     $170 = HEAP32[$169>>2]|0;
     $171 = HEAP32[$43>>2]|0;
     $172 = $171 & $155;
     $173 = HEAP8[$44>>0]|0;
     $174 = $173&255;
     $175 = $172 >>> $174;
     $176 = (($170) + ($175)|0);
     $177 = HEAP8[$176>>0]|0;
     $178 = HEAP8[$45>>0]|0;
     $179 = $178&255;
     $180 = (79212 + ($179<<2)|0);
     $181 = HEAP32[$180>>2]|0;
     $182 = HEAP32[$46>>2]|0;
     $183 = $182 & $155;
     $184 = HEAP8[$47>>0]|0;
     $185 = $184&255;
     $186 = $183 >>> $185;
     $187 = (($181) + ($186)|0);
     $188 = HEAP8[$187>>0]|0;
     $189 = HEAP8[$48>>0]|0;
     $190 = $189&255;
     $191 = (79212 + ($190<<2)|0);
     $192 = HEAP32[$191>>2]|0;
     $193 = HEAP32[$15>>2]|0;
     $194 = $193 & $155;
     $195 = HEAP8[$49>>0]|0;
     $196 = $195&255;
     $197 = $194 >>> $196;
     $198 = (($192) + ($197)|0);
     $199 = HEAP8[$198>>0]|0;
     $$01030 = $155;$$01038$shrunk = $166;$$01046$shrunk = $177;$$01054$shrunk = $188;$$01062$shrunk = $199;
     break;
    }
    default: {
     $$01030 = 0;$$01038$shrunk = 0;$$01046$shrunk = 0;$$01054$shrunk = 0;$$01062$shrunk = 0;
    }
    }
    $$01038 = $$01038$shrunk&255;
    $$01046 = $$01046$shrunk&255;
    $$01054 = $$01054$shrunk&255;
    $$01062 = $$01062$shrunk&255;
    $200 = $$01030 & $17;
    $201 = ($200|0)==($22|0);
    L15: do {
     if (!($201)) {
      switch ($21<<24>>24) {
      case 1:  {
       $202 = HEAP8[$31>>0]|0;
       $203 = $202&255;
       $204 = $$01038 >>> $203;
       $205 = HEAP8[$32>>0]|0;
       $206 = $205&255;
       $207 = $204 << $206;
       $208 = HEAP8[$33>>0]|0;
       $209 = $208&255;
       $210 = $$01046 >>> $209;
       $211 = HEAP8[$34>>0]|0;
       $212 = $211&255;
       $213 = $210 << $212;
       $214 = $213 | $207;
       $215 = HEAP8[$35>>0]|0;
       $216 = $215&255;
       $217 = $$01054 >>> $216;
       $218 = HEAP8[$36>>0]|0;
       $219 = $218&255;
       $220 = $217 << $219;
       $221 = $214 | $220;
       $222 = HEAP8[$37>>0]|0;
       $223 = $222&255;
       $224 = $$01062 >>> $223;
       $225 = HEAP8[$38>>0]|0;
       $226 = $225&255;
       $227 = $224 << $226;
       $228 = $221 | $227;
       $229 = $228&255;
       HEAP8[$$11022>>0] = $229;
       break L15;
       break;
      }
      case 2:  {
       $230 = HEAP8[$31>>0]|0;
       $231 = $230&255;
       $232 = $$01038 >>> $231;
       $233 = HEAP8[$32>>0]|0;
       $234 = $233&255;
       $235 = $232 << $234;
       $236 = HEAP8[$33>>0]|0;
       $237 = $236&255;
       $238 = $$01046 >>> $237;
       $239 = HEAP8[$34>>0]|0;
       $240 = $239&255;
       $241 = $238 << $240;
       $242 = $241 | $235;
       $243 = HEAP8[$35>>0]|0;
       $244 = $243&255;
       $245 = $$01054 >>> $244;
       $246 = HEAP8[$36>>0]|0;
       $247 = $246&255;
       $248 = $245 << $247;
       $249 = $242 | $248;
       $250 = HEAP8[$37>>0]|0;
       $251 = $250&255;
       $252 = $$01062 >>> $251;
       $253 = HEAP8[$38>>0]|0;
       $254 = $253&255;
       $255 = $252 << $254;
       $256 = $249 | $255;
       $257 = $256&65535;
       HEAP16[$$11022>>1] = $257;
       break L15;
       break;
      }
      case 3:  {
       $258 = HEAP8[$32>>0]|0;
       $div1128 = ($258&255) >>> 3;
       $259 = $div1128&255;
       $260 = (($$11022) + ($259)|0);
       HEAP8[$260>>0] = $$01038$shrunk;
       $261 = HEAP8[$34>>0]|0;
       $div1129 = ($261&255) >>> 3;
       $262 = $div1129&255;
       $263 = (($$11022) + ($262)|0);
       HEAP8[$263>>0] = $$01046$shrunk;
       $264 = HEAP8[$36>>0]|0;
       $div1130 = ($264&255) >>> 3;
       $265 = $div1130&255;
       $266 = (($$11022) + ($265)|0);
       HEAP8[$266>>0] = $$01054$shrunk;
       break L15;
       break;
      }
      case 4:  {
       $267 = HEAP8[$31>>0]|0;
       $268 = $267&255;
       $269 = $$01038 >>> $268;
       $270 = HEAP8[$32>>0]|0;
       $271 = $270&255;
       $272 = $269 << $271;
       $273 = HEAP8[$33>>0]|0;
       $274 = $273&255;
       $275 = $$01046 >>> $274;
       $276 = HEAP8[$34>>0]|0;
       $277 = $276&255;
       $278 = $275 << $277;
       $279 = $278 | $272;
       $280 = HEAP8[$35>>0]|0;
       $281 = $280&255;
       $282 = $$01054 >>> $281;
       $283 = HEAP8[$36>>0]|0;
       $284 = $283&255;
       $285 = $282 << $284;
       $286 = $279 | $285;
       $287 = HEAP8[$37>>0]|0;
       $288 = $287&255;
       $289 = $$01062 >>> $288;
       $290 = HEAP8[$38>>0]|0;
       $291 = $290&255;
       $292 = $289 << $291;
       $293 = $286 | $292;
       HEAP32[$$11022>>2] = $293;
       break L15;
       break;
      }
      default: {
       break L15;
      }
      }
     }
    } while(0);
    $294 = (($$11022) + ($30)|0);
    $295 = (($$1) + ($29)|0);
    $$11071 = $$01070;$$2 = $295;$$21023 = $294;
    label = 16;
    continue;
   }
   else if ((label|0) == 16) {
    label = 0;
    switch ($19<<24>>24) {
    case 1:  {
     $296 = HEAP8[$$2>>0]|0;
     $297 = $296&255;
     $298 = HEAP8[$39>>0]|0;
     $299 = $298&255;
     $300 = (79212 + ($299<<2)|0);
     $301 = HEAP32[$300>>2]|0;
     $302 = HEAP32[$40>>2]|0;
     $303 = $302 & $297;
     $304 = HEAP8[$41>>0]|0;
     $305 = $304&255;
     $306 = $303 >>> $305;
     $307 = (($301) + ($306)|0);
     $308 = HEAP8[$307>>0]|0;
     $309 = HEAP8[$42>>0]|0;
     $310 = $309&255;
     $311 = (79212 + ($310<<2)|0);
     $312 = HEAP32[$311>>2]|0;
     $313 = HEAP32[$43>>2]|0;
     $314 = $313 & $297;
     $315 = HEAP8[$44>>0]|0;
     $316 = $315&255;
     $317 = $314 >>> $316;
     $318 = (($312) + ($317)|0);
     $319 = HEAP8[$318>>0]|0;
     $320 = HEAP8[$45>>0]|0;
     $321 = $320&255;
     $322 = (79212 + ($321<<2)|0);
     $323 = HEAP32[$322>>2]|0;
     $324 = HEAP32[$46>>2]|0;
     $325 = $324 & $297;
     $326 = HEAP8[$47>>0]|0;
     $327 = $326&255;
     $328 = $325 >>> $327;
     $329 = (($323) + ($328)|0);
     $330 = HEAP8[$329>>0]|0;
     $331 = HEAP8[$48>>0]|0;
     $332 = $331&255;
     $333 = (79212 + ($332<<2)|0);
     $334 = HEAP32[$333>>2]|0;
     $335 = HEAP32[$15>>2]|0;
     $336 = $335 & $297;
     $337 = HEAP8[$49>>0]|0;
     $338 = $337&255;
     $339 = $336 >>> $338;
     $340 = (($334) + ($339)|0);
     $341 = HEAP8[$340>>0]|0;
     $$11031 = $297;$$11039$shrunk = $308;$$11047$shrunk = $319;$$11055$shrunk = $330;$$11063$shrunk = $341;
     break;
    }
    case 2:  {
     $342 = HEAP16[$$2>>1]|0;
     $343 = $342&65535;
     $344 = HEAP8[$39>>0]|0;
     $345 = $344&255;
     $346 = (79212 + ($345<<2)|0);
     $347 = HEAP32[$346>>2]|0;
     $348 = HEAP32[$40>>2]|0;
     $349 = $348 & $343;
     $350 = HEAP8[$41>>0]|0;
     $351 = $350&255;
     $352 = $349 >>> $351;
     $353 = (($347) + ($352)|0);
     $354 = HEAP8[$353>>0]|0;
     $355 = HEAP8[$42>>0]|0;
     $356 = $355&255;
     $357 = (79212 + ($356<<2)|0);
     $358 = HEAP32[$357>>2]|0;
     $359 = HEAP32[$43>>2]|0;
     $360 = $359 & $343;
     $361 = HEAP8[$44>>0]|0;
     $362 = $361&255;
     $363 = $360 >>> $362;
     $364 = (($358) + ($363)|0);
     $365 = HEAP8[$364>>0]|0;
     $366 = HEAP8[$45>>0]|0;
     $367 = $366&255;
     $368 = (79212 + ($367<<2)|0);
     $369 = HEAP32[$368>>2]|0;
     $370 = HEAP32[$46>>2]|0;
     $371 = $370 & $343;
     $372 = HEAP8[$47>>0]|0;
     $373 = $372&255;
     $374 = $371 >>> $373;
     $375 = (($369) + ($374)|0);
     $376 = HEAP8[$375>>0]|0;
     $377 = HEAP8[$48>>0]|0;
     $378 = $377&255;
     $379 = (79212 + ($378<<2)|0);
     $380 = HEAP32[$379>>2]|0;
     $381 = HEAP32[$15>>2]|0;
     $382 = $381 & $343;
     $383 = HEAP8[$49>>0]|0;
     $384 = $383&255;
     $385 = $382 >>> $384;
     $386 = (($380) + ($385)|0);
     $387 = HEAP8[$386>>0]|0;
     $$11031 = $343;$$11039$shrunk = $354;$$11047$shrunk = $365;$$11055$shrunk = $376;$$11063$shrunk = $387;
     break;
    }
    case 3:  {
     $388 = HEAP8[$41>>0]|0;
     $div1124 = ($388&255) >>> 3;
     $389 = $div1124&255;
     $390 = (($$2) + ($389)|0);
     $391 = HEAP8[$390>>0]|0;
     $392 = HEAP8[$44>>0]|0;
     $div1125 = ($392&255) >>> 3;
     $393 = $div1125&255;
     $394 = (($$2) + ($393)|0);
     $395 = HEAP8[$394>>0]|0;
     $396 = HEAP8[$47>>0]|0;
     $div1126 = ($396&255) >>> 3;
     $397 = $div1126&255;
     $398 = (($$2) + ($397)|0);
     $399 = HEAP8[$398>>0]|0;
     $$11031 = 0;$$11039$shrunk = $391;$$11047$shrunk = $395;$$11055$shrunk = $399;$$11063$shrunk = -1;
     break;
    }
    case 4:  {
     $400 = HEAP32[$$2>>2]|0;
     $401 = HEAP8[$39>>0]|0;
     $402 = $401&255;
     $403 = (79212 + ($402<<2)|0);
     $404 = HEAP32[$403>>2]|0;
     $405 = HEAP32[$40>>2]|0;
     $406 = $405 & $400;
     $407 = HEAP8[$41>>0]|0;
     $408 = $407&255;
     $409 = $406 >>> $408;
     $410 = (($404) + ($409)|0);
     $411 = HEAP8[$410>>0]|0;
     $412 = HEAP8[$42>>0]|0;
     $413 = $412&255;
     $414 = (79212 + ($413<<2)|0);
     $415 = HEAP32[$414>>2]|0;
     $416 = HEAP32[$43>>2]|0;
     $417 = $416 & $400;
     $418 = HEAP8[$44>>0]|0;
     $419 = $418&255;
     $420 = $417 >>> $419;
     $421 = (($415) + ($420)|0);
     $422 = HEAP8[$421>>0]|0;
     $423 = HEAP8[$45>>0]|0;
     $424 = $423&255;
     $425 = (79212 + ($424<<2)|0);
     $426 = HEAP32[$425>>2]|0;
     $427 = HEAP32[$46>>2]|0;
     $428 = $427 & $400;
     $429 = HEAP8[$47>>0]|0;
     $430 = $429&255;
     $431 = $428 >>> $430;
     $432 = (($426) + ($431)|0);
     $433 = HEAP8[$432>>0]|0;
     $434 = HEAP8[$48>>0]|0;
     $435 = $434&255;
     $436 = (79212 + ($435<<2)|0);
     $437 = HEAP32[$436>>2]|0;
     $438 = HEAP32[$15>>2]|0;
     $439 = $438 & $400;
     $440 = HEAP8[$49>>0]|0;
     $441 = $440&255;
     $442 = $439 >>> $441;
     $443 = (($437) + ($442)|0);
     $444 = HEAP8[$443>>0]|0;
     $$11031 = $400;$$11039$shrunk = $411;$$11047$shrunk = $422;$$11055$shrunk = $433;$$11063$shrunk = $444;
     break;
    }
    default: {
     $$11031 = 0;$$11039$shrunk = 0;$$11047$shrunk = 0;$$11055$shrunk = 0;$$11063$shrunk = 0;
    }
    }
    $$11039 = $$11039$shrunk&255;
    $$11047 = $$11047$shrunk&255;
    $$11055 = $$11055$shrunk&255;
    $$11063 = $$11063$shrunk&255;
    $445 = $$11031 & $17;
    $446 = ($445|0)==($22|0);
    L30: do {
     if (!($446)) {
      switch ($21<<24>>24) {
      case 1:  {
       $447 = HEAP8[$31>>0]|0;
       $448 = $447&255;
       $449 = $$11039 >>> $448;
       $450 = HEAP8[$32>>0]|0;
       $451 = $450&255;
       $452 = $449 << $451;
       $453 = HEAP8[$33>>0]|0;
       $454 = $453&255;
       $455 = $$11047 >>> $454;
       $456 = HEAP8[$34>>0]|0;
       $457 = $456&255;
       $458 = $455 << $457;
       $459 = $458 | $452;
       $460 = HEAP8[$35>>0]|0;
       $461 = $460&255;
       $462 = $$11055 >>> $461;
       $463 = HEAP8[$36>>0]|0;
       $464 = $463&255;
       $465 = $462 << $464;
       $466 = $459 | $465;
       $467 = HEAP8[$37>>0]|0;
       $468 = $467&255;
       $469 = $$11063 >>> $468;
       $470 = HEAP8[$38>>0]|0;
       $471 = $470&255;
       $472 = $469 << $471;
       $473 = $466 | $472;
       $474 = $473&255;
       HEAP8[$$21023>>0] = $474;
       break L30;
       break;
      }
      case 2:  {
       $475 = HEAP8[$31>>0]|0;
       $476 = $475&255;
       $477 = $$11039 >>> $476;
       $478 = HEAP8[$32>>0]|0;
       $479 = $478&255;
       $480 = $477 << $479;
       $481 = HEAP8[$33>>0]|0;
       $482 = $481&255;
       $483 = $$11047 >>> $482;
       $484 = HEAP8[$34>>0]|0;
       $485 = $484&255;
       $486 = $483 << $485;
       $487 = $486 | $480;
       $488 = HEAP8[$35>>0]|0;
       $489 = $488&255;
       $490 = $$11055 >>> $489;
       $491 = HEAP8[$36>>0]|0;
       $492 = $491&255;
       $493 = $490 << $492;
       $494 = $487 | $493;
       $495 = HEAP8[$37>>0]|0;
       $496 = $495&255;
       $497 = $$11063 >>> $496;
       $498 = HEAP8[$38>>0]|0;
       $499 = $498&255;
       $500 = $497 << $499;
       $501 = $494 | $500;
       $502 = $501&65535;
       HEAP16[$$21023>>1] = $502;
       break L30;
       break;
      }
      case 3:  {
       $503 = HEAP8[$32>>0]|0;
       $div1121 = ($503&255) >>> 3;
       $504 = $div1121&255;
       $505 = (($$21023) + ($504)|0);
       HEAP8[$505>>0] = $$11039$shrunk;
       $506 = HEAP8[$34>>0]|0;
       $div1122 = ($506&255) >>> 3;
       $507 = $div1122&255;
       $508 = (($$21023) + ($507)|0);
       HEAP8[$508>>0] = $$11047$shrunk;
       $509 = HEAP8[$36>>0]|0;
       $div1123 = ($509&255) >>> 3;
       $510 = $div1123&255;
       $511 = (($$21023) + ($510)|0);
       HEAP8[$511>>0] = $$11055$shrunk;
       break L30;
       break;
      }
      case 4:  {
       $512 = HEAP8[$31>>0]|0;
       $513 = $512&255;
       $514 = $$11039 >>> $513;
       $515 = HEAP8[$32>>0]|0;
       $516 = $515&255;
       $517 = $514 << $516;
       $518 = HEAP8[$33>>0]|0;
       $519 = $518&255;
       $520 = $$11047 >>> $519;
       $521 = HEAP8[$34>>0]|0;
       $522 = $521&255;
       $523 = $520 << $522;
       $524 = $523 | $517;
       $525 = HEAP8[$35>>0]|0;
       $526 = $525&255;
       $527 = $$11055 >>> $526;
       $528 = HEAP8[$36>>0]|0;
       $529 = $528&255;
       $530 = $527 << $529;
       $531 = $524 | $530;
       $532 = HEAP8[$37>>0]|0;
       $533 = $532&255;
       $534 = $$11063 >>> $533;
       $535 = HEAP8[$38>>0]|0;
       $536 = $535&255;
       $537 = $534 << $536;
       $538 = $531 | $537;
       HEAP32[$$21023>>2] = $538;
       break L30;
       break;
      }
      default: {
       break L30;
      }
      }
     }
    } while(0);
    $539 = (($$21023) + ($30)|0);
    $540 = (($$2) + ($29)|0);
    $$21072 = $$11071;$$3 = $540;$$31024 = $539;
    label = 28;
    continue;
   }
   else if ((label|0) == 28) {
    label = 0;
    switch ($19<<24>>24) {
    case 1:  {
     $541 = HEAP8[$$3>>0]|0;
     $542 = $541&255;
     $543 = HEAP8[$39>>0]|0;
     $544 = $543&255;
     $545 = (79212 + ($544<<2)|0);
     $546 = HEAP32[$545>>2]|0;
     $547 = HEAP32[$40>>2]|0;
     $548 = $547 & $542;
     $549 = HEAP8[$41>>0]|0;
     $550 = $549&255;
     $551 = $548 >>> $550;
     $552 = (($546) + ($551)|0);
     $553 = HEAP8[$552>>0]|0;
     $554 = HEAP8[$42>>0]|0;
     $555 = $554&255;
     $556 = (79212 + ($555<<2)|0);
     $557 = HEAP32[$556>>2]|0;
     $558 = HEAP32[$43>>2]|0;
     $559 = $558 & $542;
     $560 = HEAP8[$44>>0]|0;
     $561 = $560&255;
     $562 = $559 >>> $561;
     $563 = (($557) + ($562)|0);
     $564 = HEAP8[$563>>0]|0;
     $565 = HEAP8[$45>>0]|0;
     $566 = $565&255;
     $567 = (79212 + ($566<<2)|0);
     $568 = HEAP32[$567>>2]|0;
     $569 = HEAP32[$46>>2]|0;
     $570 = $569 & $542;
     $571 = HEAP8[$47>>0]|0;
     $572 = $571&255;
     $573 = $570 >>> $572;
     $574 = (($568) + ($573)|0);
     $575 = HEAP8[$574>>0]|0;
     $576 = HEAP8[$48>>0]|0;
     $577 = $576&255;
     $578 = (79212 + ($577<<2)|0);
     $579 = HEAP32[$578>>2]|0;
     $580 = HEAP32[$15>>2]|0;
     $581 = $580 & $542;
     $582 = HEAP8[$49>>0]|0;
     $583 = $582&255;
     $584 = $581 >>> $583;
     $585 = (($579) + ($584)|0);
     $586 = HEAP8[$585>>0]|0;
     $$21032 = $542;$$21040$shrunk = $553;$$21048$shrunk = $564;$$21056$shrunk = $575;$$21064$shrunk = $586;
     break;
    }
    case 2:  {
     $587 = HEAP16[$$3>>1]|0;
     $588 = $587&65535;
     $589 = HEAP8[$39>>0]|0;
     $590 = $589&255;
     $591 = (79212 + ($590<<2)|0);
     $592 = HEAP32[$591>>2]|0;
     $593 = HEAP32[$40>>2]|0;
     $594 = $593 & $588;
     $595 = HEAP8[$41>>0]|0;
     $596 = $595&255;
     $597 = $594 >>> $596;
     $598 = (($592) + ($597)|0);
     $599 = HEAP8[$598>>0]|0;
     $600 = HEAP8[$42>>0]|0;
     $601 = $600&255;
     $602 = (79212 + ($601<<2)|0);
     $603 = HEAP32[$602>>2]|0;
     $604 = HEAP32[$43>>2]|0;
     $605 = $604 & $588;
     $606 = HEAP8[$44>>0]|0;
     $607 = $606&255;
     $608 = $605 >>> $607;
     $609 = (($603) + ($608)|0);
     $610 = HEAP8[$609>>0]|0;
     $611 = HEAP8[$45>>0]|0;
     $612 = $611&255;
     $613 = (79212 + ($612<<2)|0);
     $614 = HEAP32[$613>>2]|0;
     $615 = HEAP32[$46>>2]|0;
     $616 = $615 & $588;
     $617 = HEAP8[$47>>0]|0;
     $618 = $617&255;
     $619 = $616 >>> $618;
     $620 = (($614) + ($619)|0);
     $621 = HEAP8[$620>>0]|0;
     $622 = HEAP8[$48>>0]|0;
     $623 = $622&255;
     $624 = (79212 + ($623<<2)|0);
     $625 = HEAP32[$624>>2]|0;
     $626 = HEAP32[$15>>2]|0;
     $627 = $626 & $588;
     $628 = HEAP8[$49>>0]|0;
     $629 = $628&255;
     $630 = $627 >>> $629;
     $631 = (($625) + ($630)|0);
     $632 = HEAP8[$631>>0]|0;
     $$21032 = $588;$$21040$shrunk = $599;$$21048$shrunk = $610;$$21056$shrunk = $621;$$21064$shrunk = $632;
     break;
    }
    case 3:  {
     $633 = HEAP8[$41>>0]|0;
     $div1117 = ($633&255) >>> 3;
     $634 = $div1117&255;
     $635 = (($$3) + ($634)|0);
     $636 = HEAP8[$635>>0]|0;
     $637 = HEAP8[$44>>0]|0;
     $div1118 = ($637&255) >>> 3;
     $638 = $div1118&255;
     $639 = (($$3) + ($638)|0);
     $640 = HEAP8[$639>>0]|0;
     $641 = HEAP8[$47>>0]|0;
     $div1119 = ($641&255) >>> 3;
     $642 = $div1119&255;
     $643 = (($$3) + ($642)|0);
     $644 = HEAP8[$643>>0]|0;
     $$21032 = 0;$$21040$shrunk = $636;$$21048$shrunk = $640;$$21056$shrunk = $644;$$21064$shrunk = -1;
     break;
    }
    case 4:  {
     $645 = HEAP32[$$3>>2]|0;
     $646 = HEAP8[$39>>0]|0;
     $647 = $646&255;
     $648 = (79212 + ($647<<2)|0);
     $649 = HEAP32[$648>>2]|0;
     $650 = HEAP32[$40>>2]|0;
     $651 = $650 & $645;
     $652 = HEAP8[$41>>0]|0;
     $653 = $652&255;
     $654 = $651 >>> $653;
     $655 = (($649) + ($654)|0);
     $656 = HEAP8[$655>>0]|0;
     $657 = HEAP8[$42>>0]|0;
     $658 = $657&255;
     $659 = (79212 + ($658<<2)|0);
     $660 = HEAP32[$659>>2]|0;
     $661 = HEAP32[$43>>2]|0;
     $662 = $661 & $645;
     $663 = HEAP8[$44>>0]|0;
     $664 = $663&255;
     $665 = $662 >>> $664;
     $666 = (($660) + ($665)|0);
     $667 = HEAP8[$666>>0]|0;
     $668 = HEAP8[$45>>0]|0;
     $669 = $668&255;
     $670 = (79212 + ($669<<2)|0);
     $671 = HEAP32[$670>>2]|0;
     $672 = HEAP32[$46>>2]|0;
     $673 = $672 & $645;
     $674 = HEAP8[$47>>0]|0;
     $675 = $674&255;
     $676 = $673 >>> $675;
     $677 = (($671) + ($676)|0);
     $678 = HEAP8[$677>>0]|0;
     $679 = HEAP8[$48>>0]|0;
     $680 = $679&255;
     $681 = (79212 + ($680<<2)|0);
     $682 = HEAP32[$681>>2]|0;
     $683 = HEAP32[$15>>2]|0;
     $684 = $683 & $645;
     $685 = HEAP8[$49>>0]|0;
     $686 = $685&255;
     $687 = $684 >>> $686;
     $688 = (($682) + ($687)|0);
     $689 = HEAP8[$688>>0]|0;
     $$21032 = $645;$$21040$shrunk = $656;$$21048$shrunk = $667;$$21056$shrunk = $678;$$21064$shrunk = $689;
     break;
    }
    default: {
     $$21032 = 0;$$21040$shrunk = 0;$$21048$shrunk = 0;$$21056$shrunk = 0;$$21064$shrunk = 0;
    }
    }
    $$21040 = $$21040$shrunk&255;
    $$21048 = $$21048$shrunk&255;
    $$21056 = $$21056$shrunk&255;
    $$21064 = $$21064$shrunk&255;
    $690 = $$21032 & $17;
    $691 = ($690|0)==($22|0);
    L45: do {
     if (!($691)) {
      switch ($21<<24>>24) {
      case 1:  {
       $692 = HEAP8[$31>>0]|0;
       $693 = $692&255;
       $694 = $$21040 >>> $693;
       $695 = HEAP8[$32>>0]|0;
       $696 = $695&255;
       $697 = $694 << $696;
       $698 = HEAP8[$33>>0]|0;
       $699 = $698&255;
       $700 = $$21048 >>> $699;
       $701 = HEAP8[$34>>0]|0;
       $702 = $701&255;
       $703 = $700 << $702;
       $704 = $703 | $697;
       $705 = HEAP8[$35>>0]|0;
       $706 = $705&255;
       $707 = $$21056 >>> $706;
       $708 = HEAP8[$36>>0]|0;
       $709 = $708&255;
       $710 = $707 << $709;
       $711 = $704 | $710;
       $712 = HEAP8[$37>>0]|0;
       $713 = $712&255;
       $714 = $$21064 >>> $713;
       $715 = HEAP8[$38>>0]|0;
       $716 = $715&255;
       $717 = $714 << $716;
       $718 = $711 | $717;
       $719 = $718&255;
       HEAP8[$$31024>>0] = $719;
       break L45;
       break;
      }
      case 2:  {
       $720 = HEAP8[$31>>0]|0;
       $721 = $720&255;
       $722 = $$21040 >>> $721;
       $723 = HEAP8[$32>>0]|0;
       $724 = $723&255;
       $725 = $722 << $724;
       $726 = HEAP8[$33>>0]|0;
       $727 = $726&255;
       $728 = $$21048 >>> $727;
       $729 = HEAP8[$34>>0]|0;
       $730 = $729&255;
       $731 = $728 << $730;
       $732 = $731 | $725;
       $733 = HEAP8[$35>>0]|0;
       $734 = $733&255;
       $735 = $$21056 >>> $734;
       $736 = HEAP8[$36>>0]|0;
       $737 = $736&255;
       $738 = $735 << $737;
       $739 = $732 | $738;
       $740 = HEAP8[$37>>0]|0;
       $741 = $740&255;
       $742 = $$21064 >>> $741;
       $743 = HEAP8[$38>>0]|0;
       $744 = $743&255;
       $745 = $742 << $744;
       $746 = $739 | $745;
       $747 = $746&65535;
       HEAP16[$$31024>>1] = $747;
       break L45;
       break;
      }
      case 3:  {
       $748 = HEAP8[$32>>0]|0;
       $div1114 = ($748&255) >>> 3;
       $749 = $div1114&255;
       $750 = (($$31024) + ($749)|0);
       HEAP8[$750>>0] = $$21040$shrunk;
       $751 = HEAP8[$34>>0]|0;
       $div1115 = ($751&255) >>> 3;
       $752 = $div1115&255;
       $753 = (($$31024) + ($752)|0);
       HEAP8[$753>>0] = $$21048$shrunk;
       $754 = HEAP8[$36>>0]|0;
       $div1116 = ($754&255) >>> 3;
       $755 = $div1116&255;
       $756 = (($$31024) + ($755)|0);
       HEAP8[$756>>0] = $$21056$shrunk;
       break L45;
       break;
      }
      case 4:  {
       $757 = HEAP8[$31>>0]|0;
       $758 = $757&255;
       $759 = $$21040 >>> $758;
       $760 = HEAP8[$32>>0]|0;
       $761 = $760&255;
       $762 = $759 << $761;
       $763 = HEAP8[$33>>0]|0;
       $764 = $763&255;
       $765 = $$21048 >>> $764;
       $766 = HEAP8[$34>>0]|0;
       $767 = $766&255;
       $768 = $765 << $767;
       $769 = $768 | $762;
       $770 = HEAP8[$35>>0]|0;
       $771 = $770&255;
       $772 = $$21056 >>> $771;
       $773 = HEAP8[$36>>0]|0;
       $774 = $773&255;
       $775 = $772 << $774;
       $776 = $769 | $775;
       $777 = HEAP8[$37>>0]|0;
       $778 = $777&255;
       $779 = $$21064 >>> $778;
       $780 = HEAP8[$38>>0]|0;
       $781 = $780&255;
       $782 = $779 << $781;
       $783 = $776 | $782;
       HEAP32[$$31024>>2] = $783;
       break L45;
       break;
      }
      default: {
       break L45;
      }
      }
     }
    } while(0);
    $784 = (($$31024) + ($30)|0);
    $785 = (($$3) + ($29)|0);
    $$31073 = $$21072;$$4 = $785;$$41025 = $784;
    label = 40;
    continue;
   }
   else if ((label|0) == 40) {
    label = 0;
    switch ($19<<24>>24) {
    case 1:  {
     $786 = HEAP8[$$4>>0]|0;
     $787 = $786&255;
     $788 = HEAP8[$39>>0]|0;
     $789 = $788&255;
     $790 = (79212 + ($789<<2)|0);
     $791 = HEAP32[$790>>2]|0;
     $792 = HEAP32[$40>>2]|0;
     $793 = $792 & $787;
     $794 = HEAP8[$41>>0]|0;
     $795 = $794&255;
     $796 = $793 >>> $795;
     $797 = (($791) + ($796)|0);
     $798 = HEAP8[$797>>0]|0;
     $799 = HEAP8[$42>>0]|0;
     $800 = $799&255;
     $801 = (79212 + ($800<<2)|0);
     $802 = HEAP32[$801>>2]|0;
     $803 = HEAP32[$43>>2]|0;
     $804 = $803 & $787;
     $805 = HEAP8[$44>>0]|0;
     $806 = $805&255;
     $807 = $804 >>> $806;
     $808 = (($802) + ($807)|0);
     $809 = HEAP8[$808>>0]|0;
     $810 = HEAP8[$45>>0]|0;
     $811 = $810&255;
     $812 = (79212 + ($811<<2)|0);
     $813 = HEAP32[$812>>2]|0;
     $814 = HEAP32[$46>>2]|0;
     $815 = $814 & $787;
     $816 = HEAP8[$47>>0]|0;
     $817 = $816&255;
     $818 = $815 >>> $817;
     $819 = (($813) + ($818)|0);
     $820 = HEAP8[$819>>0]|0;
     $821 = HEAP8[$48>>0]|0;
     $822 = $821&255;
     $823 = (79212 + ($822<<2)|0);
     $824 = HEAP32[$823>>2]|0;
     $825 = HEAP32[$15>>2]|0;
     $826 = $825 & $787;
     $827 = HEAP8[$49>>0]|0;
     $828 = $827&255;
     $829 = $826 >>> $828;
     $830 = (($824) + ($829)|0);
     $831 = HEAP8[$830>>0]|0;
     $$31033 = $787;$$31041$shrunk = $798;$$31049$shrunk = $809;$$31057$shrunk = $820;$$31065$shrunk = $831;
     break;
    }
    case 2:  {
     $832 = HEAP16[$$4>>1]|0;
     $833 = $832&65535;
     $834 = HEAP8[$39>>0]|0;
     $835 = $834&255;
     $836 = (79212 + ($835<<2)|0);
     $837 = HEAP32[$836>>2]|0;
     $838 = HEAP32[$40>>2]|0;
     $839 = $838 & $833;
     $840 = HEAP8[$41>>0]|0;
     $841 = $840&255;
     $842 = $839 >>> $841;
     $843 = (($837) + ($842)|0);
     $844 = HEAP8[$843>>0]|0;
     $845 = HEAP8[$42>>0]|0;
     $846 = $845&255;
     $847 = (79212 + ($846<<2)|0);
     $848 = HEAP32[$847>>2]|0;
     $849 = HEAP32[$43>>2]|0;
     $850 = $849 & $833;
     $851 = HEAP8[$44>>0]|0;
     $852 = $851&255;
     $853 = $850 >>> $852;
     $854 = (($848) + ($853)|0);
     $855 = HEAP8[$854>>0]|0;
     $856 = HEAP8[$45>>0]|0;
     $857 = $856&255;
     $858 = (79212 + ($857<<2)|0);
     $859 = HEAP32[$858>>2]|0;
     $860 = HEAP32[$46>>2]|0;
     $861 = $860 & $833;
     $862 = HEAP8[$47>>0]|0;
     $863 = $862&255;
     $864 = $861 >>> $863;
     $865 = (($859) + ($864)|0);
     $866 = HEAP8[$865>>0]|0;
     $867 = HEAP8[$48>>0]|0;
     $868 = $867&255;
     $869 = (79212 + ($868<<2)|0);
     $870 = HEAP32[$869>>2]|0;
     $871 = HEAP32[$15>>2]|0;
     $872 = $871 & $833;
     $873 = HEAP8[$49>>0]|0;
     $874 = $873&255;
     $875 = $872 >>> $874;
     $876 = (($870) + ($875)|0);
     $877 = HEAP8[$876>>0]|0;
     $$31033 = $833;$$31041$shrunk = $844;$$31049$shrunk = $855;$$31057$shrunk = $866;$$31065$shrunk = $877;
     break;
    }
    case 3:  {
     $878 = HEAP8[$41>>0]|0;
     $div1110 = ($878&255) >>> 3;
     $879 = $div1110&255;
     $880 = (($$4) + ($879)|0);
     $881 = HEAP8[$880>>0]|0;
     $882 = HEAP8[$44>>0]|0;
     $div1111 = ($882&255) >>> 3;
     $883 = $div1111&255;
     $884 = (($$4) + ($883)|0);
     $885 = HEAP8[$884>>0]|0;
     $886 = HEAP8[$47>>0]|0;
     $div1112 = ($886&255) >>> 3;
     $887 = $div1112&255;
     $888 = (($$4) + ($887)|0);
     $889 = HEAP8[$888>>0]|0;
     $$31033 = 0;$$31041$shrunk = $881;$$31049$shrunk = $885;$$31057$shrunk = $889;$$31065$shrunk = -1;
     break;
    }
    case 4:  {
     $890 = HEAP32[$$4>>2]|0;
     $891 = HEAP8[$39>>0]|0;
     $892 = $891&255;
     $893 = (79212 + ($892<<2)|0);
     $894 = HEAP32[$893>>2]|0;
     $895 = HEAP32[$40>>2]|0;
     $896 = $895 & $890;
     $897 = HEAP8[$41>>0]|0;
     $898 = $897&255;
     $899 = $896 >>> $898;
     $900 = (($894) + ($899)|0);
     $901 = HEAP8[$900>>0]|0;
     $902 = HEAP8[$42>>0]|0;
     $903 = $902&255;
     $904 = (79212 + ($903<<2)|0);
     $905 = HEAP32[$904>>2]|0;
     $906 = HEAP32[$43>>2]|0;
     $907 = $906 & $890;
     $908 = HEAP8[$44>>0]|0;
     $909 = $908&255;
     $910 = $907 >>> $909;
     $911 = (($905) + ($910)|0);
     $912 = HEAP8[$911>>0]|0;
     $913 = HEAP8[$45>>0]|0;
     $914 = $913&255;
     $915 = (79212 + ($914<<2)|0);
     $916 = HEAP32[$915>>2]|0;
     $917 = HEAP32[$46>>2]|0;
     $918 = $917 & $890;
     $919 = HEAP8[$47>>0]|0;
     $920 = $919&255;
     $921 = $918 >>> $920;
     $922 = (($916) + ($921)|0);
     $923 = HEAP8[$922>>0]|0;
     $924 = HEAP8[$48>>0]|0;
     $925 = $924&255;
     $926 = (79212 + ($925<<2)|0);
     $927 = HEAP32[$926>>2]|0;
     $928 = HEAP32[$15>>2]|0;
     $929 = $928 & $890;
     $930 = HEAP8[$49>>0]|0;
     $931 = $930&255;
     $932 = $929 >>> $931;
     $933 = (($927) + ($932)|0);
     $934 = HEAP8[$933>>0]|0;
     $$31033 = $890;$$31041$shrunk = $901;$$31049$shrunk = $912;$$31057$shrunk = $923;$$31065$shrunk = $934;
     break;
    }
    default: {
     $$31033 = 0;$$31041$shrunk = 0;$$31049$shrunk = 0;$$31057$shrunk = 0;$$31065$shrunk = 0;
    }
    }
    $$31041 = $$31041$shrunk&255;
    $$31049 = $$31049$shrunk&255;
    $$31057 = $$31057$shrunk&255;
    $$31065 = $$31065$shrunk&255;
    $935 = $$31033 & $17;
    $936 = ($935|0)==($22|0);
    L60: do {
     if (!($936)) {
      switch ($21<<24>>24) {
      case 1:  {
       $937 = HEAP8[$31>>0]|0;
       $938 = $937&255;
       $939 = $$31041 >>> $938;
       $940 = HEAP8[$32>>0]|0;
       $941 = $940&255;
       $942 = $939 << $941;
       $943 = HEAP8[$33>>0]|0;
       $944 = $943&255;
       $945 = $$31049 >>> $944;
       $946 = HEAP8[$34>>0]|0;
       $947 = $946&255;
       $948 = $945 << $947;
       $949 = $948 | $942;
       $950 = HEAP8[$35>>0]|0;
       $951 = $950&255;
       $952 = $$31057 >>> $951;
       $953 = HEAP8[$36>>0]|0;
       $954 = $953&255;
       $955 = $952 << $954;
       $956 = $949 | $955;
       $957 = HEAP8[$37>>0]|0;
       $958 = $957&255;
       $959 = $$31065 >>> $958;
       $960 = HEAP8[$38>>0]|0;
       $961 = $960&255;
       $962 = $959 << $961;
       $963 = $956 | $962;
       $964 = $963&255;
       HEAP8[$$41025>>0] = $964;
       break L60;
       break;
      }
      case 2:  {
       $965 = HEAP8[$31>>0]|0;
       $966 = $965&255;
       $967 = $$31041 >>> $966;
       $968 = HEAP8[$32>>0]|0;
       $969 = $968&255;
       $970 = $967 << $969;
       $971 = HEAP8[$33>>0]|0;
       $972 = $971&255;
       $973 = $$31049 >>> $972;
       $974 = HEAP8[$34>>0]|0;
       $975 = $974&255;
       $976 = $973 << $975;
       $977 = $976 | $970;
       $978 = HEAP8[$35>>0]|0;
       $979 = $978&255;
       $980 = $$31057 >>> $979;
       $981 = HEAP8[$36>>0]|0;
       $982 = $981&255;
       $983 = $980 << $982;
       $984 = $977 | $983;
       $985 = HEAP8[$37>>0]|0;
       $986 = $985&255;
       $987 = $$31065 >>> $986;
       $988 = HEAP8[$38>>0]|0;
       $989 = $988&255;
       $990 = $987 << $989;
       $991 = $984 | $990;
       $992 = $991&65535;
       HEAP16[$$41025>>1] = $992;
       break L60;
       break;
      }
      case 3:  {
       $993 = HEAP8[$32>>0]|0;
       $div1107 = ($993&255) >>> 3;
       $994 = $div1107&255;
       $995 = (($$41025) + ($994)|0);
       HEAP8[$995>>0] = $$31041$shrunk;
       $996 = HEAP8[$34>>0]|0;
       $div1108 = ($996&255) >>> 3;
       $997 = $div1108&255;
       $998 = (($$41025) + ($997)|0);
       HEAP8[$998>>0] = $$31049$shrunk;
       $999 = HEAP8[$36>>0]|0;
       $div1109 = ($999&255) >>> 3;
       $1000 = $div1109&255;
       $1001 = (($$41025) + ($1000)|0);
       HEAP8[$1001>>0] = $$31057$shrunk;
       break L60;
       break;
      }
      case 4:  {
       $1002 = HEAP8[$31>>0]|0;
       $1003 = $1002&255;
       $1004 = $$31041 >>> $1003;
       $1005 = HEAP8[$32>>0]|0;
       $1006 = $1005&255;
       $1007 = $1004 << $1006;
       $1008 = HEAP8[$33>>0]|0;
       $1009 = $1008&255;
       $1010 = $$31049 >>> $1009;
       $1011 = HEAP8[$34>>0]|0;
       $1012 = $1011&255;
       $1013 = $1010 << $1012;
       $1014 = $1013 | $1007;
       $1015 = HEAP8[$35>>0]|0;
       $1016 = $1015&255;
       $1017 = $$31057 >>> $1016;
       $1018 = HEAP8[$36>>0]|0;
       $1019 = $1018&255;
       $1020 = $1017 << $1019;
       $1021 = $1014 | $1020;
       $1022 = HEAP8[$37>>0]|0;
       $1023 = $1022&255;
       $1024 = $$31065 >>> $1023;
       $1025 = HEAP8[$38>>0]|0;
       $1026 = $1025&255;
       $1027 = $1024 << $1026;
       $1028 = $1021 | $1027;
       HEAP32[$$41025>>2] = $1028;
       break L60;
       break;
      }
      default: {
       break L60;
      }
      }
     }
    } while(0);
    $1029 = (($$41025) + ($30)|0);
    $1030 = (($$4) + ($29)|0);
    $$41074 = $$31073;$$5 = $1030;$$51026 = $1029;
    label = 52;
    continue;
   }
   else if ((label|0) == 52) {
    label = 0;
    switch ($19<<24>>24) {
    case 1:  {
     $1031 = HEAP8[$$5>>0]|0;
     $1032 = $1031&255;
     $1033 = HEAP8[$39>>0]|0;
     $1034 = $1033&255;
     $1035 = (79212 + ($1034<<2)|0);
     $1036 = HEAP32[$1035>>2]|0;
     $1037 = HEAP32[$40>>2]|0;
     $1038 = $1037 & $1032;
     $1039 = HEAP8[$41>>0]|0;
     $1040 = $1039&255;
     $1041 = $1038 >>> $1040;
     $1042 = (($1036) + ($1041)|0);
     $1043 = HEAP8[$1042>>0]|0;
     $1044 = HEAP8[$42>>0]|0;
     $1045 = $1044&255;
     $1046 = (79212 + ($1045<<2)|0);
     $1047 = HEAP32[$1046>>2]|0;
     $1048 = HEAP32[$43>>2]|0;
     $1049 = $1048 & $1032;
     $1050 = HEAP8[$44>>0]|0;
     $1051 = $1050&255;
     $1052 = $1049 >>> $1051;
     $1053 = (($1047) + ($1052)|0);
     $1054 = HEAP8[$1053>>0]|0;
     $1055 = HEAP8[$45>>0]|0;
     $1056 = $1055&255;
     $1057 = (79212 + ($1056<<2)|0);
     $1058 = HEAP32[$1057>>2]|0;
     $1059 = HEAP32[$46>>2]|0;
     $1060 = $1059 & $1032;
     $1061 = HEAP8[$47>>0]|0;
     $1062 = $1061&255;
     $1063 = $1060 >>> $1062;
     $1064 = (($1058) + ($1063)|0);
     $1065 = HEAP8[$1064>>0]|0;
     $1066 = HEAP8[$48>>0]|0;
     $1067 = $1066&255;
     $1068 = (79212 + ($1067<<2)|0);
     $1069 = HEAP32[$1068>>2]|0;
     $1070 = HEAP32[$15>>2]|0;
     $1071 = $1070 & $1032;
     $1072 = HEAP8[$49>>0]|0;
     $1073 = $1072&255;
     $1074 = $1071 >>> $1073;
     $1075 = (($1069) + ($1074)|0);
     $1076 = HEAP8[$1075>>0]|0;
     $$41034 = $1032;$$41042$shrunk = $1043;$$41050$shrunk = $1054;$$41058$shrunk = $1065;$$41066$shrunk = $1076;
     break;
    }
    case 2:  {
     $1077 = HEAP16[$$5>>1]|0;
     $1078 = $1077&65535;
     $1079 = HEAP8[$39>>0]|0;
     $1080 = $1079&255;
     $1081 = (79212 + ($1080<<2)|0);
     $1082 = HEAP32[$1081>>2]|0;
     $1083 = HEAP32[$40>>2]|0;
     $1084 = $1083 & $1078;
     $1085 = HEAP8[$41>>0]|0;
     $1086 = $1085&255;
     $1087 = $1084 >>> $1086;
     $1088 = (($1082) + ($1087)|0);
     $1089 = HEAP8[$1088>>0]|0;
     $1090 = HEAP8[$42>>0]|0;
     $1091 = $1090&255;
     $1092 = (79212 + ($1091<<2)|0);
     $1093 = HEAP32[$1092>>2]|0;
     $1094 = HEAP32[$43>>2]|0;
     $1095 = $1094 & $1078;
     $1096 = HEAP8[$44>>0]|0;
     $1097 = $1096&255;
     $1098 = $1095 >>> $1097;
     $1099 = (($1093) + ($1098)|0);
     $1100 = HEAP8[$1099>>0]|0;
     $1101 = HEAP8[$45>>0]|0;
     $1102 = $1101&255;
     $1103 = (79212 + ($1102<<2)|0);
     $1104 = HEAP32[$1103>>2]|0;
     $1105 = HEAP32[$46>>2]|0;
     $1106 = $1105 & $1078;
     $1107 = HEAP8[$47>>0]|0;
     $1108 = $1107&255;
     $1109 = $1106 >>> $1108;
     $1110 = (($1104) + ($1109)|0);
     $1111 = HEAP8[$1110>>0]|0;
     $1112 = HEAP8[$48>>0]|0;
     $1113 = $1112&255;
     $1114 = (79212 + ($1113<<2)|0);
     $1115 = HEAP32[$1114>>2]|0;
     $1116 = HEAP32[$15>>2]|0;
     $1117 = $1116 & $1078;
     $1118 = HEAP8[$49>>0]|0;
     $1119 = $1118&255;
     $1120 = $1117 >>> $1119;
     $1121 = (($1115) + ($1120)|0);
     $1122 = HEAP8[$1121>>0]|0;
     $$41034 = $1078;$$41042$shrunk = $1089;$$41050$shrunk = $1100;$$41058$shrunk = $1111;$$41066$shrunk = $1122;
     break;
    }
    case 3:  {
     $1123 = HEAP8[$41>>0]|0;
     $div1103 = ($1123&255) >>> 3;
     $1124 = $div1103&255;
     $1125 = (($$5) + ($1124)|0);
     $1126 = HEAP8[$1125>>0]|0;
     $1127 = HEAP8[$44>>0]|0;
     $div1104 = ($1127&255) >>> 3;
     $1128 = $div1104&255;
     $1129 = (($$5) + ($1128)|0);
     $1130 = HEAP8[$1129>>0]|0;
     $1131 = HEAP8[$47>>0]|0;
     $div1105 = ($1131&255) >>> 3;
     $1132 = $div1105&255;
     $1133 = (($$5) + ($1132)|0);
     $1134 = HEAP8[$1133>>0]|0;
     $$41034 = 0;$$41042$shrunk = $1126;$$41050$shrunk = $1130;$$41058$shrunk = $1134;$$41066$shrunk = -1;
     break;
    }
    case 4:  {
     $1135 = HEAP32[$$5>>2]|0;
     $1136 = HEAP8[$39>>0]|0;
     $1137 = $1136&255;
     $1138 = (79212 + ($1137<<2)|0);
     $1139 = HEAP32[$1138>>2]|0;
     $1140 = HEAP32[$40>>2]|0;
     $1141 = $1140 & $1135;
     $1142 = HEAP8[$41>>0]|0;
     $1143 = $1142&255;
     $1144 = $1141 >>> $1143;
     $1145 = (($1139) + ($1144)|0);
     $1146 = HEAP8[$1145>>0]|0;
     $1147 = HEAP8[$42>>0]|0;
     $1148 = $1147&255;
     $1149 = (79212 + ($1148<<2)|0);
     $1150 = HEAP32[$1149>>2]|0;
     $1151 = HEAP32[$43>>2]|0;
     $1152 = $1151 & $1135;
     $1153 = HEAP8[$44>>0]|0;
     $1154 = $1153&255;
     $1155 = $1152 >>> $1154;
     $1156 = (($1150) + ($1155)|0);
     $1157 = HEAP8[$1156>>0]|0;
     $1158 = HEAP8[$45>>0]|0;
     $1159 = $1158&255;
     $1160 = (79212 + ($1159<<2)|0);
     $1161 = HEAP32[$1160>>2]|0;
     $1162 = HEAP32[$46>>2]|0;
     $1163 = $1162 & $1135;
     $1164 = HEAP8[$47>>0]|0;
     $1165 = $1164&255;
     $1166 = $1163 >>> $1165;
     $1167 = (($1161) + ($1166)|0);
     $1168 = HEAP8[$1167>>0]|0;
     $1169 = HEAP8[$48>>0]|0;
     $1170 = $1169&255;
     $1171 = (79212 + ($1170<<2)|0);
     $1172 = HEAP32[$1171>>2]|0;
     $1173 = HEAP32[$15>>2]|0;
     $1174 = $1173 & $1135;
     $1175 = HEAP8[$49>>0]|0;
     $1176 = $1175&255;
     $1177 = $1174 >>> $1176;
     $1178 = (($1172) + ($1177)|0);
     $1179 = HEAP8[$1178>>0]|0;
     $$41034 = $1135;$$41042$shrunk = $1146;$$41050$shrunk = $1157;$$41058$shrunk = $1168;$$41066$shrunk = $1179;
     break;
    }
    default: {
     $$41034 = 0;$$41042$shrunk = 0;$$41050$shrunk = 0;$$41058$shrunk = 0;$$41066$shrunk = 0;
    }
    }
    $$41042 = $$41042$shrunk&255;
    $$41050 = $$41050$shrunk&255;
    $$41058 = $$41058$shrunk&255;
    $$41066 = $$41066$shrunk&255;
    $1180 = $$41034 & $17;
    $1181 = ($1180|0)==($22|0);
    L75: do {
     if (!($1181)) {
      switch ($21<<24>>24) {
      case 1:  {
       $1182 = HEAP8[$31>>0]|0;
       $1183 = $1182&255;
       $1184 = $$41042 >>> $1183;
       $1185 = HEAP8[$32>>0]|0;
       $1186 = $1185&255;
       $1187 = $1184 << $1186;
       $1188 = HEAP8[$33>>0]|0;
       $1189 = $1188&255;
       $1190 = $$41050 >>> $1189;
       $1191 = HEAP8[$34>>0]|0;
       $1192 = $1191&255;
       $1193 = $1190 << $1192;
       $1194 = $1193 | $1187;
       $1195 = HEAP8[$35>>0]|0;
       $1196 = $1195&255;
       $1197 = $$41058 >>> $1196;
       $1198 = HEAP8[$36>>0]|0;
       $1199 = $1198&255;
       $1200 = $1197 << $1199;
       $1201 = $1194 | $1200;
       $1202 = HEAP8[$37>>0]|0;
       $1203 = $1202&255;
       $1204 = $$41066 >>> $1203;
       $1205 = HEAP8[$38>>0]|0;
       $1206 = $1205&255;
       $1207 = $1204 << $1206;
       $1208 = $1201 | $1207;
       $1209 = $1208&255;
       HEAP8[$$51026>>0] = $1209;
       break L75;
       break;
      }
      case 2:  {
       $1210 = HEAP8[$31>>0]|0;
       $1211 = $1210&255;
       $1212 = $$41042 >>> $1211;
       $1213 = HEAP8[$32>>0]|0;
       $1214 = $1213&255;
       $1215 = $1212 << $1214;
       $1216 = HEAP8[$33>>0]|0;
       $1217 = $1216&255;
       $1218 = $$41050 >>> $1217;
       $1219 = HEAP8[$34>>0]|0;
       $1220 = $1219&255;
       $1221 = $1218 << $1220;
       $1222 = $1221 | $1215;
       $1223 = HEAP8[$35>>0]|0;
       $1224 = $1223&255;
       $1225 = $$41058 >>> $1224;
       $1226 = HEAP8[$36>>0]|0;
       $1227 = $1226&255;
       $1228 = $1225 << $1227;
       $1229 = $1222 | $1228;
       $1230 = HEAP8[$37>>0]|0;
       $1231 = $1230&255;
       $1232 = $$41066 >>> $1231;
       $1233 = HEAP8[$38>>0]|0;
       $1234 = $1233&255;
       $1235 = $1232 << $1234;
       $1236 = $1229 | $1235;
       $1237 = $1236&65535;
       HEAP16[$$51026>>1] = $1237;
       break L75;
       break;
      }
      case 3:  {
       $1238 = HEAP8[$32>>0]|0;
       $div1100 = ($1238&255) >>> 3;
       $1239 = $div1100&255;
       $1240 = (($$51026) + ($1239)|0);
       HEAP8[$1240>>0] = $$41042$shrunk;
       $1241 = HEAP8[$34>>0]|0;
       $div1101 = ($1241&255) >>> 3;
       $1242 = $div1101&255;
       $1243 = (($$51026) + ($1242)|0);
       HEAP8[$1243>>0] = $$41050$shrunk;
       $1244 = HEAP8[$36>>0]|0;
       $div1102 = ($1244&255) >>> 3;
       $1245 = $div1102&255;
       $1246 = (($$51026) + ($1245)|0);
       HEAP8[$1246>>0] = $$41058$shrunk;
       break L75;
       break;
      }
      case 4:  {
       $1247 = HEAP8[$31>>0]|0;
       $1248 = $1247&255;
       $1249 = $$41042 >>> $1248;
       $1250 = HEAP8[$32>>0]|0;
       $1251 = $1250&255;
       $1252 = $1249 << $1251;
       $1253 = HEAP8[$33>>0]|0;
       $1254 = $1253&255;
       $1255 = $$41050 >>> $1254;
       $1256 = HEAP8[$34>>0]|0;
       $1257 = $1256&255;
       $1258 = $1255 << $1257;
       $1259 = $1258 | $1252;
       $1260 = HEAP8[$35>>0]|0;
       $1261 = $1260&255;
       $1262 = $$41058 >>> $1261;
       $1263 = HEAP8[$36>>0]|0;
       $1264 = $1263&255;
       $1265 = $1262 << $1264;
       $1266 = $1259 | $1265;
       $1267 = HEAP8[$37>>0]|0;
       $1268 = $1267&255;
       $1269 = $$41066 >>> $1268;
       $1270 = HEAP8[$38>>0]|0;
       $1271 = $1270&255;
       $1272 = $1269 << $1271;
       $1273 = $1266 | $1272;
       HEAP32[$$51026>>2] = $1273;
       break L75;
       break;
      }
      default: {
       break L75;
      }
      }
     }
    } while(0);
    $1274 = (($$51026) + ($30)|0);
    $1275 = (($$5) + ($29)|0);
    $$51075 = $$41074;$$6 = $1275;$$61027 = $1274;
    label = 64;
    continue;
   }
   else if ((label|0) == 64) {
    label = 0;
    switch ($19<<24>>24) {
    case 1:  {
     $1276 = HEAP8[$$6>>0]|0;
     $1277 = $1276&255;
     $1278 = HEAP8[$39>>0]|0;
     $1279 = $1278&255;
     $1280 = (79212 + ($1279<<2)|0);
     $1281 = HEAP32[$1280>>2]|0;
     $1282 = HEAP32[$40>>2]|0;
     $1283 = $1282 & $1277;
     $1284 = HEAP8[$41>>0]|0;
     $1285 = $1284&255;
     $1286 = $1283 >>> $1285;
     $1287 = (($1281) + ($1286)|0);
     $1288 = HEAP8[$1287>>0]|0;
     $1289 = HEAP8[$42>>0]|0;
     $1290 = $1289&255;
     $1291 = (79212 + ($1290<<2)|0);
     $1292 = HEAP32[$1291>>2]|0;
     $1293 = HEAP32[$43>>2]|0;
     $1294 = $1293 & $1277;
     $1295 = HEAP8[$44>>0]|0;
     $1296 = $1295&255;
     $1297 = $1294 >>> $1296;
     $1298 = (($1292) + ($1297)|0);
     $1299 = HEAP8[$1298>>0]|0;
     $1300 = HEAP8[$45>>0]|0;
     $1301 = $1300&255;
     $1302 = (79212 + ($1301<<2)|0);
     $1303 = HEAP32[$1302>>2]|0;
     $1304 = HEAP32[$46>>2]|0;
     $1305 = $1304 & $1277;
     $1306 = HEAP8[$47>>0]|0;
     $1307 = $1306&255;
     $1308 = $1305 >>> $1307;
     $1309 = (($1303) + ($1308)|0);
     $1310 = HEAP8[$1309>>0]|0;
     $1311 = HEAP8[$48>>0]|0;
     $1312 = $1311&255;
     $1313 = (79212 + ($1312<<2)|0);
     $1314 = HEAP32[$1313>>2]|0;
     $1315 = HEAP32[$15>>2]|0;
     $1316 = $1315 & $1277;
     $1317 = HEAP8[$49>>0]|0;
     $1318 = $1317&255;
     $1319 = $1316 >>> $1318;
     $1320 = (($1314) + ($1319)|0);
     $1321 = HEAP8[$1320>>0]|0;
     $$51035 = $1277;$$51043$shrunk = $1288;$$51051$shrunk = $1299;$$51059$shrunk = $1310;$$51067$shrunk = $1321;
     break;
    }
    case 2:  {
     $1322 = HEAP16[$$6>>1]|0;
     $1323 = $1322&65535;
     $1324 = HEAP8[$39>>0]|0;
     $1325 = $1324&255;
     $1326 = (79212 + ($1325<<2)|0);
     $1327 = HEAP32[$1326>>2]|0;
     $1328 = HEAP32[$40>>2]|0;
     $1329 = $1328 & $1323;
     $1330 = HEAP8[$41>>0]|0;
     $1331 = $1330&255;
     $1332 = $1329 >>> $1331;
     $1333 = (($1327) + ($1332)|0);
     $1334 = HEAP8[$1333>>0]|0;
     $1335 = HEAP8[$42>>0]|0;
     $1336 = $1335&255;
     $1337 = (79212 + ($1336<<2)|0);
     $1338 = HEAP32[$1337>>2]|0;
     $1339 = HEAP32[$43>>2]|0;
     $1340 = $1339 & $1323;
     $1341 = HEAP8[$44>>0]|0;
     $1342 = $1341&255;
     $1343 = $1340 >>> $1342;
     $1344 = (($1338) + ($1343)|0);
     $1345 = HEAP8[$1344>>0]|0;
     $1346 = HEAP8[$45>>0]|0;
     $1347 = $1346&255;
     $1348 = (79212 + ($1347<<2)|0);
     $1349 = HEAP32[$1348>>2]|0;
     $1350 = HEAP32[$46>>2]|0;
     $1351 = $1350 & $1323;
     $1352 = HEAP8[$47>>0]|0;
     $1353 = $1352&255;
     $1354 = $1351 >>> $1353;
     $1355 = (($1349) + ($1354)|0);
     $1356 = HEAP8[$1355>>0]|0;
     $1357 = HEAP8[$48>>0]|0;
     $1358 = $1357&255;
     $1359 = (79212 + ($1358<<2)|0);
     $1360 = HEAP32[$1359>>2]|0;
     $1361 = HEAP32[$15>>2]|0;
     $1362 = $1361 & $1323;
     $1363 = HEAP8[$49>>0]|0;
     $1364 = $1363&255;
     $1365 = $1362 >>> $1364;
     $1366 = (($1360) + ($1365)|0);
     $1367 = HEAP8[$1366>>0]|0;
     $$51035 = $1323;$$51043$shrunk = $1334;$$51051$shrunk = $1345;$$51059$shrunk = $1356;$$51067$shrunk = $1367;
     break;
    }
    case 3:  {
     $1368 = HEAP8[$41>>0]|0;
     $div1096 = ($1368&255) >>> 3;
     $1369 = $div1096&255;
     $1370 = (($$6) + ($1369)|0);
     $1371 = HEAP8[$1370>>0]|0;
     $1372 = HEAP8[$44>>0]|0;
     $div1097 = ($1372&255) >>> 3;
     $1373 = $div1097&255;
     $1374 = (($$6) + ($1373)|0);
     $1375 = HEAP8[$1374>>0]|0;
     $1376 = HEAP8[$47>>0]|0;
     $div1098 = ($1376&255) >>> 3;
     $1377 = $div1098&255;
     $1378 = (($$6) + ($1377)|0);
     $1379 = HEAP8[$1378>>0]|0;
     $$51035 = 0;$$51043$shrunk = $1371;$$51051$shrunk = $1375;$$51059$shrunk = $1379;$$51067$shrunk = -1;
     break;
    }
    case 4:  {
     $1380 = HEAP32[$$6>>2]|0;
     $1381 = HEAP8[$39>>0]|0;
     $1382 = $1381&255;
     $1383 = (79212 + ($1382<<2)|0);
     $1384 = HEAP32[$1383>>2]|0;
     $1385 = HEAP32[$40>>2]|0;
     $1386 = $1385 & $1380;
     $1387 = HEAP8[$41>>0]|0;
     $1388 = $1387&255;
     $1389 = $1386 >>> $1388;
     $1390 = (($1384) + ($1389)|0);
     $1391 = HEAP8[$1390>>0]|0;
     $1392 = HEAP8[$42>>0]|0;
     $1393 = $1392&255;
     $1394 = (79212 + ($1393<<2)|0);
     $1395 = HEAP32[$1394>>2]|0;
     $1396 = HEAP32[$43>>2]|0;
     $1397 = $1396 & $1380;
     $1398 = HEAP8[$44>>0]|0;
     $1399 = $1398&255;
     $1400 = $1397 >>> $1399;
     $1401 = (($1395) + ($1400)|0);
     $1402 = HEAP8[$1401>>0]|0;
     $1403 = HEAP8[$45>>0]|0;
     $1404 = $1403&255;
     $1405 = (79212 + ($1404<<2)|0);
     $1406 = HEAP32[$1405>>2]|0;
     $1407 = HEAP32[$46>>2]|0;
     $1408 = $1407 & $1380;
     $1409 = HEAP8[$47>>0]|0;
     $1410 = $1409&255;
     $1411 = $1408 >>> $1410;
     $1412 = (($1406) + ($1411)|0);
     $1413 = HEAP8[$1412>>0]|0;
     $1414 = HEAP8[$48>>0]|0;
     $1415 = $1414&255;
     $1416 = (79212 + ($1415<<2)|0);
     $1417 = HEAP32[$1416>>2]|0;
     $1418 = HEAP32[$15>>2]|0;
     $1419 = $1418 & $1380;
     $1420 = HEAP8[$49>>0]|0;
     $1421 = $1420&255;
     $1422 = $1419 >>> $1421;
     $1423 = (($1417) + ($1422)|0);
     $1424 = HEAP8[$1423>>0]|0;
     $$51035 = $1380;$$51043$shrunk = $1391;$$51051$shrunk = $1402;$$51059$shrunk = $1413;$$51067$shrunk = $1424;
     break;
    }
    default: {
     $$51035 = 0;$$51043$shrunk = 0;$$51051$shrunk = 0;$$51059$shrunk = 0;$$51067$shrunk = 0;
    }
    }
    $$51043 = $$51043$shrunk&255;
    $$51051 = $$51051$shrunk&255;
    $$51059 = $$51059$shrunk&255;
    $$51067 = $$51067$shrunk&255;
    $1425 = $$51035 & $17;
    $1426 = ($1425|0)==($22|0);
    L90: do {
     if (!($1426)) {
      switch ($21<<24>>24) {
      case 1:  {
       $1427 = HEAP8[$31>>0]|0;
       $1428 = $1427&255;
       $1429 = $$51043 >>> $1428;
       $1430 = HEAP8[$32>>0]|0;
       $1431 = $1430&255;
       $1432 = $1429 << $1431;
       $1433 = HEAP8[$33>>0]|0;
       $1434 = $1433&255;
       $1435 = $$51051 >>> $1434;
       $1436 = HEAP8[$34>>0]|0;
       $1437 = $1436&255;
       $1438 = $1435 << $1437;
       $1439 = $1438 | $1432;
       $1440 = HEAP8[$35>>0]|0;
       $1441 = $1440&255;
       $1442 = $$51059 >>> $1441;
       $1443 = HEAP8[$36>>0]|0;
       $1444 = $1443&255;
       $1445 = $1442 << $1444;
       $1446 = $1439 | $1445;
       $1447 = HEAP8[$37>>0]|0;
       $1448 = $1447&255;
       $1449 = $$51067 >>> $1448;
       $1450 = HEAP8[$38>>0]|0;
       $1451 = $1450&255;
       $1452 = $1449 << $1451;
       $1453 = $1446 | $1452;
       $1454 = $1453&255;
       HEAP8[$$61027>>0] = $1454;
       break L90;
       break;
      }
      case 2:  {
       $1455 = HEAP8[$31>>0]|0;
       $1456 = $1455&255;
       $1457 = $$51043 >>> $1456;
       $1458 = HEAP8[$32>>0]|0;
       $1459 = $1458&255;
       $1460 = $1457 << $1459;
       $1461 = HEAP8[$33>>0]|0;
       $1462 = $1461&255;
       $1463 = $$51051 >>> $1462;
       $1464 = HEAP8[$34>>0]|0;
       $1465 = $1464&255;
       $1466 = $1463 << $1465;
       $1467 = $1466 | $1460;
       $1468 = HEAP8[$35>>0]|0;
       $1469 = $1468&255;
       $1470 = $$51059 >>> $1469;
       $1471 = HEAP8[$36>>0]|0;
       $1472 = $1471&255;
       $1473 = $1470 << $1472;
       $1474 = $1467 | $1473;
       $1475 = HEAP8[$37>>0]|0;
       $1476 = $1475&255;
       $1477 = $$51067 >>> $1476;
       $1478 = HEAP8[$38>>0]|0;
       $1479 = $1478&255;
       $1480 = $1477 << $1479;
       $1481 = $1474 | $1480;
       $1482 = $1481&65535;
       HEAP16[$$61027>>1] = $1482;
       break L90;
       break;
      }
      case 3:  {
       $1483 = HEAP8[$32>>0]|0;
       $div1093 = ($1483&255) >>> 3;
       $1484 = $div1093&255;
       $1485 = (($$61027) + ($1484)|0);
       HEAP8[$1485>>0] = $$51043$shrunk;
       $1486 = HEAP8[$34>>0]|0;
       $div1094 = ($1486&255) >>> 3;
       $1487 = $div1094&255;
       $1488 = (($$61027) + ($1487)|0);
       HEAP8[$1488>>0] = $$51051$shrunk;
       $1489 = HEAP8[$36>>0]|0;
       $div1095 = ($1489&255) >>> 3;
       $1490 = $div1095&255;
       $1491 = (($$61027) + ($1490)|0);
       HEAP8[$1491>>0] = $$51059$shrunk;
       break L90;
       break;
      }
      case 4:  {
       $1492 = HEAP8[$31>>0]|0;
       $1493 = $1492&255;
       $1494 = $$51043 >>> $1493;
       $1495 = HEAP8[$32>>0]|0;
       $1496 = $1495&255;
       $1497 = $1494 << $1496;
       $1498 = HEAP8[$33>>0]|0;
       $1499 = $1498&255;
       $1500 = $$51051 >>> $1499;
       $1501 = HEAP8[$34>>0]|0;
       $1502 = $1501&255;
       $1503 = $1500 << $1502;
       $1504 = $1503 | $1497;
       $1505 = HEAP8[$35>>0]|0;
       $1506 = $1505&255;
       $1507 = $$51059 >>> $1506;
       $1508 = HEAP8[$36>>0]|0;
       $1509 = $1508&255;
       $1510 = $1507 << $1509;
       $1511 = $1504 | $1510;
       $1512 = HEAP8[$37>>0]|0;
       $1513 = $1512&255;
       $1514 = $$51067 >>> $1513;
       $1515 = HEAP8[$38>>0]|0;
       $1516 = $1515&255;
       $1517 = $1514 << $1516;
       $1518 = $1511 | $1517;
       HEAP32[$$61027>>2] = $1518;
       break L90;
       break;
      }
      default: {
       break L90;
      }
      }
     }
    } while(0);
    $1519 = (($$61027) + ($30)|0);
    $1520 = (($$6) + ($29)|0);
    $$61076 = $$51075;$$7 = $1520;$$71028 = $1519;
    label = 76;
    continue;
   }
   else if ((label|0) == 76) {
    label = 0;
    switch ($19<<24>>24) {
    case 1:  {
     $1521 = HEAP8[$$7>>0]|0;
     $1522 = $1521&255;
     $1523 = HEAP8[$39>>0]|0;
     $1524 = $1523&255;
     $1525 = (79212 + ($1524<<2)|0);
     $1526 = HEAP32[$1525>>2]|0;
     $1527 = HEAP32[$40>>2]|0;
     $1528 = $1527 & $1522;
     $1529 = HEAP8[$41>>0]|0;
     $1530 = $1529&255;
     $1531 = $1528 >>> $1530;
     $1532 = (($1526) + ($1531)|0);
     $1533 = HEAP8[$1532>>0]|0;
     $1534 = HEAP8[$42>>0]|0;
     $1535 = $1534&255;
     $1536 = (79212 + ($1535<<2)|0);
     $1537 = HEAP32[$1536>>2]|0;
     $1538 = HEAP32[$43>>2]|0;
     $1539 = $1538 & $1522;
     $1540 = HEAP8[$44>>0]|0;
     $1541 = $1540&255;
     $1542 = $1539 >>> $1541;
     $1543 = (($1537) + ($1542)|0);
     $1544 = HEAP8[$1543>>0]|0;
     $1545 = HEAP8[$45>>0]|0;
     $1546 = $1545&255;
     $1547 = (79212 + ($1546<<2)|0);
     $1548 = HEAP32[$1547>>2]|0;
     $1549 = HEAP32[$46>>2]|0;
     $1550 = $1549 & $1522;
     $1551 = HEAP8[$47>>0]|0;
     $1552 = $1551&255;
     $1553 = $1550 >>> $1552;
     $1554 = (($1548) + ($1553)|0);
     $1555 = HEAP8[$1554>>0]|0;
     $1556 = HEAP8[$48>>0]|0;
     $1557 = $1556&255;
     $1558 = (79212 + ($1557<<2)|0);
     $1559 = HEAP32[$1558>>2]|0;
     $1560 = HEAP32[$15>>2]|0;
     $1561 = $1560 & $1522;
     $1562 = HEAP8[$49>>0]|0;
     $1563 = $1562&255;
     $1564 = $1561 >>> $1563;
     $1565 = (($1559) + ($1564)|0);
     $1566 = HEAP8[$1565>>0]|0;
     $$61036 = $1522;$$61044$shrunk = $1533;$$61052$shrunk = $1544;$$61060$shrunk = $1555;$$61068$shrunk = $1566;
     break;
    }
    case 2:  {
     $1567 = HEAP16[$$7>>1]|0;
     $1568 = $1567&65535;
     $1569 = HEAP8[$39>>0]|0;
     $1570 = $1569&255;
     $1571 = (79212 + ($1570<<2)|0);
     $1572 = HEAP32[$1571>>2]|0;
     $1573 = HEAP32[$40>>2]|0;
     $1574 = $1573 & $1568;
     $1575 = HEAP8[$41>>0]|0;
     $1576 = $1575&255;
     $1577 = $1574 >>> $1576;
     $1578 = (($1572) + ($1577)|0);
     $1579 = HEAP8[$1578>>0]|0;
     $1580 = HEAP8[$42>>0]|0;
     $1581 = $1580&255;
     $1582 = (79212 + ($1581<<2)|0);
     $1583 = HEAP32[$1582>>2]|0;
     $1584 = HEAP32[$43>>2]|0;
     $1585 = $1584 & $1568;
     $1586 = HEAP8[$44>>0]|0;
     $1587 = $1586&255;
     $1588 = $1585 >>> $1587;
     $1589 = (($1583) + ($1588)|0);
     $1590 = HEAP8[$1589>>0]|0;
     $1591 = HEAP8[$45>>0]|0;
     $1592 = $1591&255;
     $1593 = (79212 + ($1592<<2)|0);
     $1594 = HEAP32[$1593>>2]|0;
     $1595 = HEAP32[$46>>2]|0;
     $1596 = $1595 & $1568;
     $1597 = HEAP8[$47>>0]|0;
     $1598 = $1597&255;
     $1599 = $1596 >>> $1598;
     $1600 = (($1594) + ($1599)|0);
     $1601 = HEAP8[$1600>>0]|0;
     $1602 = HEAP8[$48>>0]|0;
     $1603 = $1602&255;
     $1604 = (79212 + ($1603<<2)|0);
     $1605 = HEAP32[$1604>>2]|0;
     $1606 = HEAP32[$15>>2]|0;
     $1607 = $1606 & $1568;
     $1608 = HEAP8[$49>>0]|0;
     $1609 = $1608&255;
     $1610 = $1607 >>> $1609;
     $1611 = (($1605) + ($1610)|0);
     $1612 = HEAP8[$1611>>0]|0;
     $$61036 = $1568;$$61044$shrunk = $1579;$$61052$shrunk = $1590;$$61060$shrunk = $1601;$$61068$shrunk = $1612;
     break;
    }
    case 3:  {
     $1613 = HEAP8[$41>>0]|0;
     $div1089 = ($1613&255) >>> 3;
     $1614 = $div1089&255;
     $1615 = (($$7) + ($1614)|0);
     $1616 = HEAP8[$1615>>0]|0;
     $1617 = HEAP8[$44>>0]|0;
     $div1090 = ($1617&255) >>> 3;
     $1618 = $div1090&255;
     $1619 = (($$7) + ($1618)|0);
     $1620 = HEAP8[$1619>>0]|0;
     $1621 = HEAP8[$47>>0]|0;
     $div1091 = ($1621&255) >>> 3;
     $1622 = $div1091&255;
     $1623 = (($$7) + ($1622)|0);
     $1624 = HEAP8[$1623>>0]|0;
     $$61036 = 0;$$61044$shrunk = $1616;$$61052$shrunk = $1620;$$61060$shrunk = $1624;$$61068$shrunk = -1;
     break;
    }
    case 4:  {
     $1625 = HEAP32[$$7>>2]|0;
     $1626 = HEAP8[$39>>0]|0;
     $1627 = $1626&255;
     $1628 = (79212 + ($1627<<2)|0);
     $1629 = HEAP32[$1628>>2]|0;
     $1630 = HEAP32[$40>>2]|0;
     $1631 = $1630 & $1625;
     $1632 = HEAP8[$41>>0]|0;
     $1633 = $1632&255;
     $1634 = $1631 >>> $1633;
     $1635 = (($1629) + ($1634)|0);
     $1636 = HEAP8[$1635>>0]|0;
     $1637 = HEAP8[$42>>0]|0;
     $1638 = $1637&255;
     $1639 = (79212 + ($1638<<2)|0);
     $1640 = HEAP32[$1639>>2]|0;
     $1641 = HEAP32[$43>>2]|0;
     $1642 = $1641 & $1625;
     $1643 = HEAP8[$44>>0]|0;
     $1644 = $1643&255;
     $1645 = $1642 >>> $1644;
     $1646 = (($1640) + ($1645)|0);
     $1647 = HEAP8[$1646>>0]|0;
     $1648 = HEAP8[$45>>0]|0;
     $1649 = $1648&255;
     $1650 = (79212 + ($1649<<2)|0);
     $1651 = HEAP32[$1650>>2]|0;
     $1652 = HEAP32[$46>>2]|0;
     $1653 = $1652 & $1625;
     $1654 = HEAP8[$47>>0]|0;
     $1655 = $1654&255;
     $1656 = $1653 >>> $1655;
     $1657 = (($1651) + ($1656)|0);
     $1658 = HEAP8[$1657>>0]|0;
     $1659 = HEAP8[$48>>0]|0;
     $1660 = $1659&255;
     $1661 = (79212 + ($1660<<2)|0);
     $1662 = HEAP32[$1661>>2]|0;
     $1663 = HEAP32[$15>>2]|0;
     $1664 = $1663 & $1625;
     $1665 = HEAP8[$49>>0]|0;
     $1666 = $1665&255;
     $1667 = $1664 >>> $1666;
     $1668 = (($1662) + ($1667)|0);
     $1669 = HEAP8[$1668>>0]|0;
     $$61036 = $1625;$$61044$shrunk = $1636;$$61052$shrunk = $1647;$$61060$shrunk = $1658;$$61068$shrunk = $1669;
     break;
    }
    default: {
     $$61036 = 0;$$61044$shrunk = 0;$$61052$shrunk = 0;$$61060$shrunk = 0;$$61068$shrunk = 0;
    }
    }
    $$61044 = $$61044$shrunk&255;
    $$61052 = $$61052$shrunk&255;
    $$61060 = $$61060$shrunk&255;
    $$61068 = $$61068$shrunk&255;
    $1670 = $$61036 & $17;
    $1671 = ($1670|0)==($22|0);
    L105: do {
     if (!($1671)) {
      switch ($21<<24>>24) {
      case 1:  {
       $1672 = HEAP8[$31>>0]|0;
       $1673 = $1672&255;
       $1674 = $$61044 >>> $1673;
       $1675 = HEAP8[$32>>0]|0;
       $1676 = $1675&255;
       $1677 = $1674 << $1676;
       $1678 = HEAP8[$33>>0]|0;
       $1679 = $1678&255;
       $1680 = $$61052 >>> $1679;
       $1681 = HEAP8[$34>>0]|0;
       $1682 = $1681&255;
       $1683 = $1680 << $1682;
       $1684 = $1683 | $1677;
       $1685 = HEAP8[$35>>0]|0;
       $1686 = $1685&255;
       $1687 = $$61060 >>> $1686;
       $1688 = HEAP8[$36>>0]|0;
       $1689 = $1688&255;
       $1690 = $1687 << $1689;
       $1691 = $1684 | $1690;
       $1692 = HEAP8[$37>>0]|0;
       $1693 = $1692&255;
       $1694 = $$61068 >>> $1693;
       $1695 = HEAP8[$38>>0]|0;
       $1696 = $1695&255;
       $1697 = $1694 << $1696;
       $1698 = $1691 | $1697;
       $1699 = $1698&255;
       HEAP8[$$71028>>0] = $1699;
       break L105;
       break;
      }
      case 2:  {
       $1700 = HEAP8[$31>>0]|0;
       $1701 = $1700&255;
       $1702 = $$61044 >>> $1701;
       $1703 = HEAP8[$32>>0]|0;
       $1704 = $1703&255;
       $1705 = $1702 << $1704;
       $1706 = HEAP8[$33>>0]|0;
       $1707 = $1706&255;
       $1708 = $$61052 >>> $1707;
       $1709 = HEAP8[$34>>0]|0;
       $1710 = $1709&255;
       $1711 = $1708 << $1710;
       $1712 = $1711 | $1705;
       $1713 = HEAP8[$35>>0]|0;
       $1714 = $1713&255;
       $1715 = $$61060 >>> $1714;
       $1716 = HEAP8[$36>>0]|0;
       $1717 = $1716&255;
       $1718 = $1715 << $1717;
       $1719 = $1712 | $1718;
       $1720 = HEAP8[$37>>0]|0;
       $1721 = $1720&255;
       $1722 = $$61068 >>> $1721;
       $1723 = HEAP8[$38>>0]|0;
       $1724 = $1723&255;
       $1725 = $1722 << $1724;
       $1726 = $1719 | $1725;
       $1727 = $1726&65535;
       HEAP16[$$71028>>1] = $1727;
       break L105;
       break;
      }
      case 3:  {
       $1728 = HEAP8[$32>>0]|0;
       $div = ($1728&255) >>> 3;
       $1729 = $div&255;
       $1730 = (($$71028) + ($1729)|0);
       HEAP8[$1730>>0] = $$61044$shrunk;
       $1731 = HEAP8[$34>>0]|0;
       $div1087 = ($1731&255) >>> 3;
       $1732 = $div1087&255;
       $1733 = (($$71028) + ($1732)|0);
       HEAP8[$1733>>0] = $$61052$shrunk;
       $1734 = HEAP8[$36>>0]|0;
       $div1088 = ($1734&255) >>> 3;
       $1735 = $div1088&255;
       $1736 = (($$71028) + ($1735)|0);
       HEAP8[$1736>>0] = $$61060$shrunk;
       break L105;
       break;
      }
      case 4:  {
       $1737 = HEAP8[$31>>0]|0;
       $1738 = $1737&255;
       $1739 = $$61044 >>> $1738;
       $1740 = HEAP8[$32>>0]|0;
       $1741 = $1740&255;
       $1742 = $1739 << $1741;
       $1743 = HEAP8[$33>>0]|0;
       $1744 = $1743&255;
       $1745 = $$61052 >>> $1744;
       $1746 = HEAP8[$34>>0]|0;
       $1747 = $1746&255;
       $1748 = $1745 << $1747;
       $1749 = $1748 | $1742;
       $1750 = HEAP8[$35>>0]|0;
       $1751 = $1750&255;
       $1752 = $$61060 >>> $1751;
       $1753 = HEAP8[$36>>0]|0;
       $1754 = $1753&255;
       $1755 = $1752 << $1754;
       $1756 = $1749 | $1755;
       $1757 = HEAP8[$37>>0]|0;
       $1758 = $1757&255;
       $1759 = $$61068 >>> $1758;
       $1760 = HEAP8[$38>>0]|0;
       $1761 = $1760&255;
       $1762 = $1759 << $1761;
       $1763 = $1756 | $1762;
       HEAP32[$$71028>>2] = $1763;
       break L105;
       break;
      }
      default: {
       break L105;
      }
      }
     }
    } while(0);
    $1764 = (($$71028) + ($30)|0);
    $1765 = (($$7) + ($29)|0);
    $$71077 = $$61076;$$8 = $1765;$$81029 = $1764;
    label = 88;
    continue;
   }
   else if ((label|0) == 88) {
    label = 0;
    switch ($19<<24>>24) {
    case 1:  {
     $1766 = HEAP8[$$8>>0]|0;
     $1767 = $1766&255;
     $1768 = HEAP8[$39>>0]|0;
     $1769 = $1768&255;
     $1770 = (79212 + ($1769<<2)|0);
     $1771 = HEAP32[$1770>>2]|0;
     $1772 = HEAP32[$40>>2]|0;
     $1773 = $1772 & $1767;
     $1774 = HEAP8[$41>>0]|0;
     $1775 = $1774&255;
     $1776 = $1773 >>> $1775;
     $1777 = (($1771) + ($1776)|0);
     $1778 = HEAP8[$1777>>0]|0;
     $1779 = HEAP8[$42>>0]|0;
     $1780 = $1779&255;
     $1781 = (79212 + ($1780<<2)|0);
     $1782 = HEAP32[$1781>>2]|0;
     $1783 = HEAP32[$43>>2]|0;
     $1784 = $1783 & $1767;
     $1785 = HEAP8[$44>>0]|0;
     $1786 = $1785&255;
     $1787 = $1784 >>> $1786;
     $1788 = (($1782) + ($1787)|0);
     $1789 = HEAP8[$1788>>0]|0;
     $1790 = HEAP8[$45>>0]|0;
     $1791 = $1790&255;
     $1792 = (79212 + ($1791<<2)|0);
     $1793 = HEAP32[$1792>>2]|0;
     $1794 = HEAP32[$46>>2]|0;
     $1795 = $1794 & $1767;
     $1796 = HEAP8[$47>>0]|0;
     $1797 = $1796&255;
     $1798 = $1795 >>> $1797;
     $1799 = (($1793) + ($1798)|0);
     $1800 = HEAP8[$1799>>0]|0;
     $1801 = HEAP8[$48>>0]|0;
     $1802 = $1801&255;
     $1803 = (79212 + ($1802<<2)|0);
     $1804 = HEAP32[$1803>>2]|0;
     $1805 = HEAP32[$15>>2]|0;
     $1806 = $1805 & $1767;
     $1807 = HEAP8[$49>>0]|0;
     $1808 = $1807&255;
     $1809 = $1806 >>> $1808;
     $1810 = (($1804) + ($1809)|0);
     $1811 = HEAP8[$1810>>0]|0;
     $$71037 = $1767;$$71045$shrunk = $1778;$$71053$shrunk = $1789;$$71061$shrunk = $1800;$$71069$shrunk = $1811;
     break;
    }
    case 2:  {
     $1812 = HEAP16[$$8>>1]|0;
     $1813 = $1812&65535;
     $1814 = HEAP8[$39>>0]|0;
     $1815 = $1814&255;
     $1816 = (79212 + ($1815<<2)|0);
     $1817 = HEAP32[$1816>>2]|0;
     $1818 = HEAP32[$40>>2]|0;
     $1819 = $1818 & $1813;
     $1820 = HEAP8[$41>>0]|0;
     $1821 = $1820&255;
     $1822 = $1819 >>> $1821;
     $1823 = (($1817) + ($1822)|0);
     $1824 = HEAP8[$1823>>0]|0;
     $1825 = HEAP8[$42>>0]|0;
     $1826 = $1825&255;
     $1827 = (79212 + ($1826<<2)|0);
     $1828 = HEAP32[$1827>>2]|0;
     $1829 = HEAP32[$43>>2]|0;
     $1830 = $1829 & $1813;
     $1831 = HEAP8[$44>>0]|0;
     $1832 = $1831&255;
     $1833 = $1830 >>> $1832;
     $1834 = (($1828) + ($1833)|0);
     $1835 = HEAP8[$1834>>0]|0;
     $1836 = HEAP8[$45>>0]|0;
     $1837 = $1836&255;
     $1838 = (79212 + ($1837<<2)|0);
     $1839 = HEAP32[$1838>>2]|0;
     $1840 = HEAP32[$46>>2]|0;
     $1841 = $1840 & $1813;
     $1842 = HEAP8[$47>>0]|0;
     $1843 = $1842&255;
     $1844 = $1841 >>> $1843;
     $1845 = (($1839) + ($1844)|0);
     $1846 = HEAP8[$1845>>0]|0;
     $1847 = HEAP8[$48>>0]|0;
     $1848 = $1847&255;
     $1849 = (79212 + ($1848<<2)|0);
     $1850 = HEAP32[$1849>>2]|0;
     $1851 = HEAP32[$15>>2]|0;
     $1852 = $1851 & $1813;
     $1853 = HEAP8[$49>>0]|0;
     $1854 = $1853&255;
     $1855 = $1852 >>> $1854;
     $1856 = (($1850) + ($1855)|0);
     $1857 = HEAP8[$1856>>0]|0;
     $$71037 = $1813;$$71045$shrunk = $1824;$$71053$shrunk = $1835;$$71061$shrunk = $1846;$$71069$shrunk = $1857;
     break;
    }
    case 3:  {
     $1858 = HEAP8[$41>>0]|0;
     $div1138 = ($1858&255) >>> 3;
     $1859 = $div1138&255;
     $1860 = (($$8) + ($1859)|0);
     $1861 = HEAP8[$1860>>0]|0;
     $1862 = HEAP8[$44>>0]|0;
     $div1139 = ($1862&255) >>> 3;
     $1863 = $div1139&255;
     $1864 = (($$8) + ($1863)|0);
     $1865 = HEAP8[$1864>>0]|0;
     $1866 = HEAP8[$47>>0]|0;
     $div1140 = ($1866&255) >>> 3;
     $1867 = $div1140&255;
     $1868 = (($$8) + ($1867)|0);
     $1869 = HEAP8[$1868>>0]|0;
     $$71037 = 0;$$71045$shrunk = $1861;$$71053$shrunk = $1865;$$71061$shrunk = $1869;$$71069$shrunk = -1;
     break;
    }
    case 4:  {
     $1870 = HEAP32[$$8>>2]|0;
     $1871 = HEAP8[$39>>0]|0;
     $1872 = $1871&255;
     $1873 = (79212 + ($1872<<2)|0);
     $1874 = HEAP32[$1873>>2]|0;
     $1875 = HEAP32[$40>>2]|0;
     $1876 = $1875 & $1870;
     $1877 = HEAP8[$41>>0]|0;
     $1878 = $1877&255;
     $1879 = $1876 >>> $1878;
     $1880 = (($1874) + ($1879)|0);
     $1881 = HEAP8[$1880>>0]|0;
     $1882 = HEAP8[$42>>0]|0;
     $1883 = $1882&255;
     $1884 = (79212 + ($1883<<2)|0);
     $1885 = HEAP32[$1884>>2]|0;
     $1886 = HEAP32[$43>>2]|0;
     $1887 = $1886 & $1870;
     $1888 = HEAP8[$44>>0]|0;
     $1889 = $1888&255;
     $1890 = $1887 >>> $1889;
     $1891 = (($1885) + ($1890)|0);
     $1892 = HEAP8[$1891>>0]|0;
     $1893 = HEAP8[$45>>0]|0;
     $1894 = $1893&255;
     $1895 = (79212 + ($1894<<2)|0);
     $1896 = HEAP32[$1895>>2]|0;
     $1897 = HEAP32[$46>>2]|0;
     $1898 = $1897 & $1870;
     $1899 = HEAP8[$47>>0]|0;
     $1900 = $1899&255;
     $1901 = $1898 >>> $1900;
     $1902 = (($1896) + ($1901)|0);
     $1903 = HEAP8[$1902>>0]|0;
     $1904 = HEAP8[$48>>0]|0;
     $1905 = $1904&255;
     $1906 = (79212 + ($1905<<2)|0);
     $1907 = HEAP32[$1906>>2]|0;
     $1908 = HEAP32[$15>>2]|0;
     $1909 = $1908 & $1870;
     $1910 = HEAP8[$49>>0]|0;
     $1911 = $1910&255;
     $1912 = $1909 >>> $1911;
     $1913 = (($1907) + ($1912)|0);
     $1914 = HEAP8[$1913>>0]|0;
     $$71037 = $1870;$$71045$shrunk = $1881;$$71053$shrunk = $1892;$$71061$shrunk = $1903;$$71069$shrunk = $1914;
     break;
    }
    default: {
     $$71037 = 0;$$71045$shrunk = 0;$$71053$shrunk = 0;$$71061$shrunk = 0;$$71069$shrunk = 0;
    }
    }
    $$71045 = $$71045$shrunk&255;
    $$71053 = $$71053$shrunk&255;
    $$71061 = $$71061$shrunk&255;
    $$71069 = $$71069$shrunk&255;
    $1915 = $$71037 & $17;
    $1916 = ($1915|0)==($22|0);
    L120: do {
     if (!($1916)) {
      switch ($21<<24>>24) {
      case 1:  {
       $1917 = HEAP8[$31>>0]|0;
       $1918 = $1917&255;
       $1919 = $$71045 >>> $1918;
       $1920 = HEAP8[$32>>0]|0;
       $1921 = $1920&255;
       $1922 = $1919 << $1921;
       $1923 = HEAP8[$33>>0]|0;
       $1924 = $1923&255;
       $1925 = $$71053 >>> $1924;
       $1926 = HEAP8[$34>>0]|0;
       $1927 = $1926&255;
       $1928 = $1925 << $1927;
       $1929 = $1928 | $1922;
       $1930 = HEAP8[$35>>0]|0;
       $1931 = $1930&255;
       $1932 = $$71061 >>> $1931;
       $1933 = HEAP8[$36>>0]|0;
       $1934 = $1933&255;
       $1935 = $1932 << $1934;
       $1936 = $1929 | $1935;
       $1937 = HEAP8[$37>>0]|0;
       $1938 = $1937&255;
       $1939 = $$71069 >>> $1938;
       $1940 = HEAP8[$38>>0]|0;
       $1941 = $1940&255;
       $1942 = $1939 << $1941;
       $1943 = $1936 | $1942;
       $1944 = $1943&255;
       HEAP8[$$81029>>0] = $1944;
       break L120;
       break;
      }
      case 2:  {
       $1945 = HEAP8[$31>>0]|0;
       $1946 = $1945&255;
       $1947 = $$71045 >>> $1946;
       $1948 = HEAP8[$32>>0]|0;
       $1949 = $1948&255;
       $1950 = $1947 << $1949;
       $1951 = HEAP8[$33>>0]|0;
       $1952 = $1951&255;
       $1953 = $$71053 >>> $1952;
       $1954 = HEAP8[$34>>0]|0;
       $1955 = $1954&255;
       $1956 = $1953 << $1955;
       $1957 = $1956 | $1950;
       $1958 = HEAP8[$35>>0]|0;
       $1959 = $1958&255;
       $1960 = $$71061 >>> $1959;
       $1961 = HEAP8[$36>>0]|0;
       $1962 = $1961&255;
       $1963 = $1960 << $1962;
       $1964 = $1957 | $1963;
       $1965 = HEAP8[$37>>0]|0;
       $1966 = $1965&255;
       $1967 = $$71069 >>> $1966;
       $1968 = HEAP8[$38>>0]|0;
       $1969 = $1968&255;
       $1970 = $1967 << $1969;
       $1971 = $1964 | $1970;
       $1972 = $1971&65535;
       HEAP16[$$81029>>1] = $1972;
       break L120;
       break;
      }
      case 3:  {
       $1973 = HEAP8[$32>>0]|0;
       $div1135 = ($1973&255) >>> 3;
       $1974 = $div1135&255;
       $1975 = (($$81029) + ($1974)|0);
       HEAP8[$1975>>0] = $$71045$shrunk;
       $1976 = HEAP8[$34>>0]|0;
       $div1136 = ($1976&255) >>> 3;
       $1977 = $div1136&255;
       $1978 = (($$81029) + ($1977)|0);
       HEAP8[$1978>>0] = $$71053$shrunk;
       $1979 = HEAP8[$36>>0]|0;
       $div1137 = ($1979&255) >>> 3;
       $1980 = $div1137&255;
       $1981 = (($$81029) + ($1980)|0);
       HEAP8[$1981>>0] = $$71061$shrunk;
       break L120;
       break;
      }
      case 4:  {
       $1982 = HEAP8[$31>>0]|0;
       $1983 = $1982&255;
       $1984 = $$71045 >>> $1983;
       $1985 = HEAP8[$32>>0]|0;
       $1986 = $1985&255;
       $1987 = $1984 << $1986;
       $1988 = HEAP8[$33>>0]|0;
       $1989 = $1988&255;
       $1990 = $$71053 >>> $1989;
       $1991 = HEAP8[$34>>0]|0;
       $1992 = $1991&255;
       $1993 = $1990 << $1992;
       $1994 = $1993 | $1987;
       $1995 = HEAP8[$35>>0]|0;
       $1996 = $1995&255;
       $1997 = $$71061 >>> $1996;
       $1998 = HEAP8[$36>>0]|0;
       $1999 = $1998&255;
       $2000 = $1997 << $1999;
       $2001 = $1994 | $2000;
       $2002 = HEAP8[$37>>0]|0;
       $2003 = $2002&255;
       $2004 = $$71069 >>> $2003;
       $2005 = HEAP8[$38>>0]|0;
       $2006 = $2005&255;
       $2007 = $2004 << $2006;
       $2008 = $2001 | $2007;
       HEAP32[$$81029>>2] = $2008;
       break L120;
       break;
      }
      default: {
       break L120;
      }
      }
     }
    } while(0);
    $2009 = (($$81029) + ($30)|0);
    $2010 = (($$8) + ($29)|0);
    $2011 = (($$71077) + -1)|0;
    $2012 = ($$71077|0)>(1);
    if ($2012) {
     $$01070 = $2011;$$1 = $2010;$$11022 = $2009;
     label = 4;
     continue;
    } else {
     break;
    }
   }
  }
  $2013 = (($2010) + ($6)|0);
  $2014 = (($2009) + ($8)|0);
  $2015 = ($50|0)==(0);
  if ($2015) {
   label = 102;
   break;
  } else {
   $$010201142 = $2013;$$010211141 = $2014;$$in = $50;
  }
 }
 if ((label|0) == 100) {
  // unreachable;
 }
 else if ((label|0) == 102) {
  return;
 }
}
function _Blit_RGB888_RGB565($0) {
 $0 = $0|0;
 var $$0 = 0, $$07593 = 0, $$08392 = 0, $$1 = 0, $$176 = 0, $$184 = 0, $$2 = 0, $$277 = 0, $$285 = 0, $$3 = 0, $$378 = 0, $$386 = 0, $$4 = 0, $$479 = 0, $$487 = 0, $$5 = 0, $$580 = 0, $$588 = 0, $$6 = 0, $$681 = 0;
 var $$689 = 0, $$7 = 0, $$782 = 0, $$790 = 0, $$8 = 0, $$891 = 0, $$in = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $trunc = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6|0) / 4)&-1;
 $8 = ((($0)) + 36|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9|0) / 2)&-1;
 $11 = ($4|0)==(0);
 if ($11) {
  return;
 }
 $12 = ((($0)) + 20|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = HEAP32[$0>>2]|0;
 $15 = (($2) + 7)|0;
 $16 = (($15|0) / 8)&-1;
 $trunc = $2&255;
 $$07593 = $14;$$08392 = $13;$$in = $4;
 L4: while(1) {
  $17 = (($$in) + -1)|0;
  $trunc$clear = $trunc & 7;
  switch ($trunc$clear<<24>>24) {
  case 0:  {
   $$0 = $16;$$176 = $$07593;$$184 = $$08392;
   label = 4;
   break;
  }
  case 7:  {
   $$1 = $16;$$277 = $$07593;$$285 = $$08392;
   label = 5;
   break;
  }
  case 6:  {
   $$2 = $16;$$378 = $$07593;$$386 = $$08392;
   label = 6;
   break;
  }
  case 5:  {
   $$3 = $16;$$479 = $$07593;$$487 = $$08392;
   label = 7;
   break;
  }
  case 4:  {
   $$4 = $16;$$580 = $$07593;$$588 = $$08392;
   label = 8;
   break;
  }
  case 3:  {
   $$5 = $16;$$681 = $$07593;$$689 = $$08392;
   label = 9;
   break;
  }
  case 2:  {
   $$6 = $16;$$782 = $$07593;$$790 = $$08392;
   label = 10;
   break;
  }
  case 1:  {
   $$7 = $16;$$8 = $$07593;$$891 = $$08392;
   label = 11;
   break;
  }
  default: {
   label = 12;
   break L4;
  }
  }
  while(1) {
   if ((label|0) == 4) {
    label = 0;
    $18 = HEAP32[$$176>>2]|0;
    $19 = $18 >>> 8;
    $20 = $19 & 63488;
    $21 = $18 >>> 5;
    $22 = $21 & 2016;
    $23 = $20 | $22;
    $24 = $18 >>> 3;
    $25 = $24 & 31;
    $26 = $23 | $25;
    $27 = $26&65535;
    HEAP16[$$184>>1] = $27;
    $28 = ((($$176)) + 4|0);
    $29 = ((($$184)) + 2|0);
    $$1 = $$0;$$277 = $28;$$285 = $29;
    label = 5;
    continue;
   }
   else if ((label|0) == 5) {
    label = 0;
    $30 = HEAP32[$$277>>2]|0;
    $31 = $30 >>> 8;
    $32 = $31 & 63488;
    $33 = $30 >>> 5;
    $34 = $33 & 2016;
    $35 = $32 | $34;
    $36 = $30 >>> 3;
    $37 = $36 & 31;
    $38 = $35 | $37;
    $39 = $38&65535;
    HEAP16[$$285>>1] = $39;
    $40 = ((($$277)) + 4|0);
    $41 = ((($$285)) + 2|0);
    $$2 = $$1;$$378 = $40;$$386 = $41;
    label = 6;
    continue;
   }
   else if ((label|0) == 6) {
    label = 0;
    $42 = HEAP32[$$378>>2]|0;
    $43 = $42 >>> 8;
    $44 = $43 & 63488;
    $45 = $42 >>> 5;
    $46 = $45 & 2016;
    $47 = $44 | $46;
    $48 = $42 >>> 3;
    $49 = $48 & 31;
    $50 = $47 | $49;
    $51 = $50&65535;
    HEAP16[$$386>>1] = $51;
    $52 = ((($$378)) + 4|0);
    $53 = ((($$386)) + 2|0);
    $$3 = $$2;$$479 = $52;$$487 = $53;
    label = 7;
    continue;
   }
   else if ((label|0) == 7) {
    label = 0;
    $54 = HEAP32[$$479>>2]|0;
    $55 = $54 >>> 8;
    $56 = $55 & 63488;
    $57 = $54 >>> 5;
    $58 = $57 & 2016;
    $59 = $56 | $58;
    $60 = $54 >>> 3;
    $61 = $60 & 31;
    $62 = $59 | $61;
    $63 = $62&65535;
    HEAP16[$$487>>1] = $63;
    $64 = ((($$479)) + 4|0);
    $65 = ((($$487)) + 2|0);
    $$4 = $$3;$$580 = $64;$$588 = $65;
    label = 8;
    continue;
   }
   else if ((label|0) == 8) {
    label = 0;
    $66 = HEAP32[$$580>>2]|0;
    $67 = $66 >>> 8;
    $68 = $67 & 63488;
    $69 = $66 >>> 5;
    $70 = $69 & 2016;
    $71 = $68 | $70;
    $72 = $66 >>> 3;
    $73 = $72 & 31;
    $74 = $71 | $73;
    $75 = $74&65535;
    HEAP16[$$588>>1] = $75;
    $76 = ((($$580)) + 4|0);
    $77 = ((($$588)) + 2|0);
    $$5 = $$4;$$681 = $76;$$689 = $77;
    label = 9;
    continue;
   }
   else if ((label|0) == 9) {
    label = 0;
    $78 = HEAP32[$$681>>2]|0;
    $79 = $78 >>> 8;
    $80 = $79 & 63488;
    $81 = $78 >>> 5;
    $82 = $81 & 2016;
    $83 = $80 | $82;
    $84 = $78 >>> 3;
    $85 = $84 & 31;
    $86 = $83 | $85;
    $87 = $86&65535;
    HEAP16[$$689>>1] = $87;
    $88 = ((($$681)) + 4|0);
    $89 = ((($$689)) + 2|0);
    $$6 = $$5;$$782 = $88;$$790 = $89;
    label = 10;
    continue;
   }
   else if ((label|0) == 10) {
    label = 0;
    $90 = HEAP32[$$782>>2]|0;
    $91 = $90 >>> 8;
    $92 = $91 & 63488;
    $93 = $90 >>> 5;
    $94 = $93 & 2016;
    $95 = $92 | $94;
    $96 = $90 >>> 3;
    $97 = $96 & 31;
    $98 = $95 | $97;
    $99 = $98&65535;
    HEAP16[$$790>>1] = $99;
    $100 = ((($$782)) + 4|0);
    $101 = ((($$790)) + 2|0);
    $$7 = $$6;$$8 = $100;$$891 = $101;
    label = 11;
    continue;
   }
   else if ((label|0) == 11) {
    label = 0;
    $102 = HEAP32[$$8>>2]|0;
    $103 = $102 >>> 8;
    $104 = $103 & 63488;
    $105 = $102 >>> 5;
    $106 = $105 & 2016;
    $107 = $104 | $106;
    $108 = $102 >>> 3;
    $109 = $108 & 31;
    $110 = $107 | $109;
    $111 = $110&65535;
    HEAP16[$$891>>1] = $111;
    $112 = ((($$8)) + 4|0);
    $113 = ((($$891)) + 2|0);
    $114 = (($$7) + -1)|0;
    $115 = ($$7|0)>(1);
    if ($115) {
     $$0 = $114;$$176 = $112;$$184 = $113;
     label = 4;
     continue;
    } else {
     break;
    }
   }
  }
  $116 = (($112) + ($7<<2)|0);
  $117 = (($113) + ($10<<1)|0);
  $118 = ($17|0)==(0);
  if ($118) {
   label = 14;
   break;
  } else {
   $$07593 = $116;$$08392 = $117;$$in = $17;
  }
 }
 if ((label|0) == 12) {
  // unreachable;
 }
 else if ((label|0) == 14) {
  return;
 }
}
function _Blit_RGB888_RGB555($0) {
 $0 = $0|0;
 var $$0 = 0, $$07593 = 0, $$08392 = 0, $$1 = 0, $$176 = 0, $$184 = 0, $$2 = 0, $$277 = 0, $$285 = 0, $$3 = 0, $$378 = 0, $$386 = 0, $$4 = 0, $$479 = 0, $$487 = 0, $$5 = 0, $$580 = 0, $$588 = 0, $$6 = 0, $$681 = 0;
 var $$689 = 0, $$7 = 0, $$782 = 0, $$790 = 0, $$8 = 0, $$891 = 0, $$in = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $trunc = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6|0) / 4)&-1;
 $8 = ((($0)) + 36|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9|0) / 2)&-1;
 $11 = ($4|0)==(0);
 if ($11) {
  return;
 }
 $12 = ((($0)) + 20|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = HEAP32[$0>>2]|0;
 $15 = (($2) + 7)|0;
 $16 = (($15|0) / 8)&-1;
 $trunc = $2&255;
 $$07593 = $14;$$08392 = $13;$$in = $4;
 L4: while(1) {
  $17 = (($$in) + -1)|0;
  $trunc$clear = $trunc & 7;
  switch ($trunc$clear<<24>>24) {
  case 0:  {
   $$0 = $16;$$176 = $$07593;$$184 = $$08392;
   label = 4;
   break;
  }
  case 7:  {
   $$1 = $16;$$277 = $$07593;$$285 = $$08392;
   label = 5;
   break;
  }
  case 6:  {
   $$2 = $16;$$378 = $$07593;$$386 = $$08392;
   label = 6;
   break;
  }
  case 5:  {
   $$3 = $16;$$479 = $$07593;$$487 = $$08392;
   label = 7;
   break;
  }
  case 4:  {
   $$4 = $16;$$580 = $$07593;$$588 = $$08392;
   label = 8;
   break;
  }
  case 3:  {
   $$5 = $16;$$681 = $$07593;$$689 = $$08392;
   label = 9;
   break;
  }
  case 2:  {
   $$6 = $16;$$782 = $$07593;$$790 = $$08392;
   label = 10;
   break;
  }
  case 1:  {
   $$7 = $16;$$8 = $$07593;$$891 = $$08392;
   label = 11;
   break;
  }
  default: {
   label = 12;
   break L4;
  }
  }
  while(1) {
   if ((label|0) == 4) {
    label = 0;
    $18 = HEAP32[$$176>>2]|0;
    $19 = $18 >>> 9;
    $20 = $19 & 31744;
    $21 = $18 >>> 6;
    $22 = $21 & 992;
    $23 = $20 | $22;
    $24 = $18 >>> 3;
    $25 = $24 & 31;
    $26 = $23 | $25;
    $27 = $26&65535;
    HEAP16[$$184>>1] = $27;
    $28 = ((($$176)) + 4|0);
    $29 = ((($$184)) + 2|0);
    $$1 = $$0;$$277 = $28;$$285 = $29;
    label = 5;
    continue;
   }
   else if ((label|0) == 5) {
    label = 0;
    $30 = HEAP32[$$277>>2]|0;
    $31 = $30 >>> 9;
    $32 = $31 & 31744;
    $33 = $30 >>> 6;
    $34 = $33 & 992;
    $35 = $32 | $34;
    $36 = $30 >>> 3;
    $37 = $36 & 31;
    $38 = $35 | $37;
    $39 = $38&65535;
    HEAP16[$$285>>1] = $39;
    $40 = ((($$277)) + 4|0);
    $41 = ((($$285)) + 2|0);
    $$2 = $$1;$$378 = $40;$$386 = $41;
    label = 6;
    continue;
   }
   else if ((label|0) == 6) {
    label = 0;
    $42 = HEAP32[$$378>>2]|0;
    $43 = $42 >>> 9;
    $44 = $43 & 31744;
    $45 = $42 >>> 6;
    $46 = $45 & 992;
    $47 = $44 | $46;
    $48 = $42 >>> 3;
    $49 = $48 & 31;
    $50 = $47 | $49;
    $51 = $50&65535;
    HEAP16[$$386>>1] = $51;
    $52 = ((($$378)) + 4|0);
    $53 = ((($$386)) + 2|0);
    $$3 = $$2;$$479 = $52;$$487 = $53;
    label = 7;
    continue;
   }
   else if ((label|0) == 7) {
    label = 0;
    $54 = HEAP32[$$479>>2]|0;
    $55 = $54 >>> 9;
    $56 = $55 & 31744;
    $57 = $54 >>> 6;
    $58 = $57 & 992;
    $59 = $56 | $58;
    $60 = $54 >>> 3;
    $61 = $60 & 31;
    $62 = $59 | $61;
    $63 = $62&65535;
    HEAP16[$$487>>1] = $63;
    $64 = ((($$479)) + 4|0);
    $65 = ((($$487)) + 2|0);
    $$4 = $$3;$$580 = $64;$$588 = $65;
    label = 8;
    continue;
   }
   else if ((label|0) == 8) {
    label = 0;
    $66 = HEAP32[$$580>>2]|0;
    $67 = $66 >>> 9;
    $68 = $67 & 31744;
    $69 = $66 >>> 6;
    $70 = $69 & 992;
    $71 = $68 | $70;
    $72 = $66 >>> 3;
    $73 = $72 & 31;
    $74 = $71 | $73;
    $75 = $74&65535;
    HEAP16[$$588>>1] = $75;
    $76 = ((($$580)) + 4|0);
    $77 = ((($$588)) + 2|0);
    $$5 = $$4;$$681 = $76;$$689 = $77;
    label = 9;
    continue;
   }
   else if ((label|0) == 9) {
    label = 0;
    $78 = HEAP32[$$681>>2]|0;
    $79 = $78 >>> 9;
    $80 = $79 & 31744;
    $81 = $78 >>> 6;
    $82 = $81 & 992;
    $83 = $80 | $82;
    $84 = $78 >>> 3;
    $85 = $84 & 31;
    $86 = $83 | $85;
    $87 = $86&65535;
    HEAP16[$$689>>1] = $87;
    $88 = ((($$681)) + 4|0);
    $89 = ((($$689)) + 2|0);
    $$6 = $$5;$$782 = $88;$$790 = $89;
    label = 10;
    continue;
   }
   else if ((label|0) == 10) {
    label = 0;
    $90 = HEAP32[$$782>>2]|0;
    $91 = $90 >>> 9;
    $92 = $91 & 31744;
    $93 = $90 >>> 6;
    $94 = $93 & 992;
    $95 = $92 | $94;
    $96 = $90 >>> 3;
    $97 = $96 & 31;
    $98 = $95 | $97;
    $99 = $98&65535;
    HEAP16[$$790>>1] = $99;
    $100 = ((($$782)) + 4|0);
    $101 = ((($$790)) + 2|0);
    $$7 = $$6;$$8 = $100;$$891 = $101;
    label = 11;
    continue;
   }
   else if ((label|0) == 11) {
    label = 0;
    $102 = HEAP32[$$8>>2]|0;
    $103 = $102 >>> 9;
    $104 = $103 & 31744;
    $105 = $102 >>> 6;
    $106 = $105 & 992;
    $107 = $104 | $106;
    $108 = $102 >>> 3;
    $109 = $108 & 31;
    $110 = $107 | $109;
    $111 = $110&65535;
    HEAP16[$$891>>1] = $111;
    $112 = ((($$8)) + 4|0);
    $113 = ((($$891)) + 2|0);
    $114 = (($$7) + -1)|0;
    $115 = ($$7|0)>(1);
    if ($115) {
     $$0 = $114;$$176 = $112;$$184 = $113;
     label = 4;
     continue;
    } else {
     break;
    }
   }
  }
  $116 = (($112) + ($7<<2)|0);
  $117 = (($113) + ($10<<1)|0);
  $118 = ($17|0)==(0);
  if ($118) {
   label = 14;
   break;
  } else {
   $$07593 = $116;$$08392 = $117;$$in = $17;
  }
 }
 if ((label|0) == 12) {
  // unreachable;
 }
 else if ((label|0) == 14) {
  return;
 }
}
function _Blit_RGB565_ARGB8888($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 _Blit_RGB565_32($0,85812);
 return;
}
function _Blit_RGB565_ABGR8888($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 _Blit_RGB565_32($0,83764);
 return;
}
function _Blit_RGB565_RGBA8888($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 _Blit_RGB565_32($0,81716);
 return;
}
function _Blit_RGB565_BGRA8888($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 _Blit_RGB565_32($0,79668);
 return;
}
function _Blit_RGB565_32($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$07593 = 0, $$08392 = 0, $$1 = 0, $$176 = 0, $$184 = 0, $$2 = 0, $$277 = 0, $$285 = 0, $$3 = 0, $$378 = 0, $$386 = 0, $$4 = 0, $$479 = 0, $$487 = 0, $$5 = 0, $$580 = 0, $$588 = 0, $$6 = 0, $$681 = 0;
 var $$689 = 0, $$7 = 0, $$782 = 0, $$790 = 0, $$8 = 0, $$891 = 0, $$in = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $trunc = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($0)) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($0)) + 36|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9|0) / 4)&-1;
 $11 = ($5|0)==(0);
 if ($11) {
  return;
 }
 $12 = ((($0)) + 20|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = HEAP32[$0>>2]|0;
 $15 = (($3) + 7)|0;
 $16 = (($15|0) / 8)&-1;
 $trunc = $3&255;
 $$07593 = $14;$$08392 = $13;$$in = $5;
 L4: while(1) {
  $17 = (($$in) + -1)|0;
  $trunc$clear = $trunc & 7;
  switch ($trunc$clear<<24>>24) {
  case 0:  {
   $$0 = $16;$$176 = $$07593;$$184 = $$08392;
   label = 4;
   break;
  }
  case 7:  {
   $$1 = $16;$$277 = $$07593;$$285 = $$08392;
   label = 5;
   break;
  }
  case 6:  {
   $$2 = $16;$$378 = $$07593;$$386 = $$08392;
   label = 6;
   break;
  }
  case 5:  {
   $$3 = $16;$$479 = $$07593;$$487 = $$08392;
   label = 7;
   break;
  }
  case 4:  {
   $$4 = $16;$$580 = $$07593;$$588 = $$08392;
   label = 8;
   break;
  }
  case 3:  {
   $$5 = $16;$$681 = $$07593;$$689 = $$08392;
   label = 9;
   break;
  }
  case 2:  {
   $$6 = $16;$$782 = $$07593;$$790 = $$08392;
   label = 10;
   break;
  }
  case 1:  {
   $$7 = $16;$$8 = $$07593;$$891 = $$08392;
   label = 11;
   break;
  }
  default: {
   label = 12;
   break L4;
  }
  }
  while(1) {
   if ((label|0) == 4) {
    label = 0;
    $18 = HEAP8[$$176>>0]|0;
    $19 = $18&255;
    $20 = $19 << 1;
    $21 = (($1) + ($20<<2)|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = ((($$176)) + 1|0);
    $24 = HEAP8[$23>>0]|0;
    $25 = $24&255;
    $26 = $25 << 1;
    $27 = $26 | 1;
    $28 = (($1) + ($27<<2)|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = (($29) + ($22))|0;
    $31 = ((($$184)) + 4|0);
    HEAP32[$$184>>2] = $30;
    $32 = ((($$176)) + 2|0);
    $$1 = $$0;$$277 = $32;$$285 = $31;
    label = 5;
    continue;
   }
   else if ((label|0) == 5) {
    label = 0;
    $33 = HEAP8[$$277>>0]|0;
    $34 = $33&255;
    $35 = $34 << 1;
    $36 = (($1) + ($35<<2)|0);
    $37 = HEAP32[$36>>2]|0;
    $38 = ((($$277)) + 1|0);
    $39 = HEAP8[$38>>0]|0;
    $40 = $39&255;
    $41 = $40 << 1;
    $42 = $41 | 1;
    $43 = (($1) + ($42<<2)|0);
    $44 = HEAP32[$43>>2]|0;
    $45 = (($44) + ($37))|0;
    $46 = ((($$285)) + 4|0);
    HEAP32[$$285>>2] = $45;
    $47 = ((($$277)) + 2|0);
    $$2 = $$1;$$378 = $47;$$386 = $46;
    label = 6;
    continue;
   }
   else if ((label|0) == 6) {
    label = 0;
    $48 = HEAP8[$$378>>0]|0;
    $49 = $48&255;
    $50 = $49 << 1;
    $51 = (($1) + ($50<<2)|0);
    $52 = HEAP32[$51>>2]|0;
    $53 = ((($$378)) + 1|0);
    $54 = HEAP8[$53>>0]|0;
    $55 = $54&255;
    $56 = $55 << 1;
    $57 = $56 | 1;
    $58 = (($1) + ($57<<2)|0);
    $59 = HEAP32[$58>>2]|0;
    $60 = (($59) + ($52))|0;
    $61 = ((($$386)) + 4|0);
    HEAP32[$$386>>2] = $60;
    $62 = ((($$378)) + 2|0);
    $$3 = $$2;$$479 = $62;$$487 = $61;
    label = 7;
    continue;
   }
   else if ((label|0) == 7) {
    label = 0;
    $63 = HEAP8[$$479>>0]|0;
    $64 = $63&255;
    $65 = $64 << 1;
    $66 = (($1) + ($65<<2)|0);
    $67 = HEAP32[$66>>2]|0;
    $68 = ((($$479)) + 1|0);
    $69 = HEAP8[$68>>0]|0;
    $70 = $69&255;
    $71 = $70 << 1;
    $72 = $71 | 1;
    $73 = (($1) + ($72<<2)|0);
    $74 = HEAP32[$73>>2]|0;
    $75 = (($74) + ($67))|0;
    $76 = ((($$487)) + 4|0);
    HEAP32[$$487>>2] = $75;
    $77 = ((($$479)) + 2|0);
    $$4 = $$3;$$580 = $77;$$588 = $76;
    label = 8;
    continue;
   }
   else if ((label|0) == 8) {
    label = 0;
    $78 = HEAP8[$$580>>0]|0;
    $79 = $78&255;
    $80 = $79 << 1;
    $81 = (($1) + ($80<<2)|0);
    $82 = HEAP32[$81>>2]|0;
    $83 = ((($$580)) + 1|0);
    $84 = HEAP8[$83>>0]|0;
    $85 = $84&255;
    $86 = $85 << 1;
    $87 = $86 | 1;
    $88 = (($1) + ($87<<2)|0);
    $89 = HEAP32[$88>>2]|0;
    $90 = (($89) + ($82))|0;
    $91 = ((($$588)) + 4|0);
    HEAP32[$$588>>2] = $90;
    $92 = ((($$580)) + 2|0);
    $$5 = $$4;$$681 = $92;$$689 = $91;
    label = 9;
    continue;
   }
   else if ((label|0) == 9) {
    label = 0;
    $93 = HEAP8[$$681>>0]|0;
    $94 = $93&255;
    $95 = $94 << 1;
    $96 = (($1) + ($95<<2)|0);
    $97 = HEAP32[$96>>2]|0;
    $98 = ((($$681)) + 1|0);
    $99 = HEAP8[$98>>0]|0;
    $100 = $99&255;
    $101 = $100 << 1;
    $102 = $101 | 1;
    $103 = (($1) + ($102<<2)|0);
    $104 = HEAP32[$103>>2]|0;
    $105 = (($104) + ($97))|0;
    $106 = ((($$689)) + 4|0);
    HEAP32[$$689>>2] = $105;
    $107 = ((($$681)) + 2|0);
    $$6 = $$5;$$782 = $107;$$790 = $106;
    label = 10;
    continue;
   }
   else if ((label|0) == 10) {
    label = 0;
    $108 = HEAP8[$$782>>0]|0;
    $109 = $108&255;
    $110 = $109 << 1;
    $111 = (($1) + ($110<<2)|0);
    $112 = HEAP32[$111>>2]|0;
    $113 = ((($$782)) + 1|0);
    $114 = HEAP8[$113>>0]|0;
    $115 = $114&255;
    $116 = $115 << 1;
    $117 = $116 | 1;
    $118 = (($1) + ($117<<2)|0);
    $119 = HEAP32[$118>>2]|0;
    $120 = (($119) + ($112))|0;
    $121 = ((($$790)) + 4|0);
    HEAP32[$$790>>2] = $120;
    $122 = ((($$782)) + 2|0);
    $$7 = $$6;$$8 = $122;$$891 = $121;
    label = 11;
    continue;
   }
   else if ((label|0) == 11) {
    label = 0;
    $123 = HEAP8[$$8>>0]|0;
    $124 = $123&255;
    $125 = $124 << 1;
    $126 = (($1) + ($125<<2)|0);
    $127 = HEAP32[$126>>2]|0;
    $128 = ((($$8)) + 1|0);
    $129 = HEAP8[$128>>0]|0;
    $130 = $129&255;
    $131 = $130 << 1;
    $132 = $131 | 1;
    $133 = (($1) + ($132<<2)|0);
    $134 = HEAP32[$133>>2]|0;
    $135 = (($134) + ($127))|0;
    $136 = ((($$891)) + 4|0);
    HEAP32[$$891>>2] = $135;
    $137 = ((($$8)) + 2|0);
    $138 = (($$7) + -1)|0;
    $139 = ($$7|0)>(1);
    if ($139) {
     $$0 = $138;$$176 = $137;$$184 = $136;
     label = 4;
     continue;
    } else {
     break;
    }
   }
  }
  $140 = (($137) + ($7)|0);
  $141 = (($136) + ($10<<2)|0);
  $142 = ($17|0)==(0);
  if ($142) {
   label = 14;
   break;
  } else {
   $$07593 = $140;$$08392 = $141;$$in = $17;
  }
 }
 if ((label|0) == 12) {
  // unreachable;
 }
 else if ((label|0) == 14) {
  return;
 }
}
function _BlitARGBto555PixelAlpha($0) {
 $0 = $0|0;
 var $$0146164 = 0, $$0147163 = 0, $$0152 = 0, $$1 = 0, $$1148 = 0, $$1153 = 0, $$2 = 0, $$2149 = 0, $$2154 = 0, $$3 = 0, $$3150 = 0, $$3155 = 0, $$4 = 0, $$4151 = 0, $$in = 0, $$sink156 = 0, $$sink158 = 0, $$sink160 = 0, $$sink162 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0;
 var $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $trunc = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $6 >> 2;
 $8 = ((($0)) + 36|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $9 >> 1;
 $11 = ($4|0)==(0);
 if ($11) {
  return;
 }
 $12 = ((($0)) + 20|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = HEAP32[$0>>2]|0;
 $15 = (($2) + 3)|0;
 $16 = (($15|0) / 4)&-1;
 $trunc = $2&255;
 $$0146164 = $14;$$0147163 = $13;$$in = $4;
 L4: while(1) {
  $17 = (($$in) + -1)|0;
  $trunc$clear = $trunc & 3;
  switch ($trunc$clear<<24>>24) {
  case 0:  {
   $$0152 = $16;$$1 = $$0146164;$$1148 = $$0147163;
   label = 4;
   break;
  }
  case 3:  {
   $$1153 = $16;$$2 = $$0146164;$$2149 = $$0147163;
   label = 10;
   break;
  }
  case 2:  {
   $$2154 = $16;$$3 = $$0146164;$$3150 = $$0147163;
   label = 16;
   break;
  }
  case 1:  {
   $$3155 = $16;$$4 = $$0146164;$$4151 = $$0147163;
   label = 22;
   break;
  }
  default: {
   label = 28;
   break L4;
  }
  }
  while(1) {
   if ((label|0) == 4) {
    label = 0;
    $18 = HEAP32[$$1>>2]|0;
    $19 = $18 >>> 27;
    $20 = ($19|0)==(0);
    if (!($20)) {
     $21 = ($19|0)==(31);
     $22 = $18 >>> 9;
     $23 = $18 >>> 3;
     $24 = $22 & 31744;
     $25 = $23 & 31;
     if ($21) {
      $26 = $18 >>> 6;
      $27 = $26 & 992;
      $28 = $24 | $27;
      $29 = $28 | $25;
      $$sink156 = $29;
     } else {
      $30 = HEAP16[$$1148>>1]|0;
      $31 = $30&65535;
      $32 = $18 << 10;
      $33 = $32 & 65011712;
      $34 = $33 | $24;
      $35 = $34 | $25;
      $36 = $31 << 16;
      $37 = $36 | $31;
      $38 = $37 & 65043487;
      $39 = (($35) - ($38))|0;
      $40 = Math_imul($39, $19)|0;
      $41 = $40 >>> 5;
      $42 = (($41) + ($38))|0;
      $43 = $42 & 65043487;
      $44 = $43 >>> 16;
      $45 = $44 | $43;
      $$sink156 = $45;
     }
     $46 = $$sink156&65535;
     HEAP16[$$1148>>1] = $46;
    }
    $47 = ((($$1)) + 4|0);
    $48 = ((($$1148)) + 2|0);
    $$1153 = $$0152;$$2 = $47;$$2149 = $48;
    label = 10;
    continue;
   }
   else if ((label|0) == 10) {
    label = 0;
    $49 = HEAP32[$$2>>2]|0;
    $50 = $49 >>> 27;
    $51 = ($50|0)==(0);
    if (!($51)) {
     $52 = ($50|0)==(31);
     $53 = $49 >>> 9;
     $54 = $49 >>> 3;
     $55 = $53 & 31744;
     $56 = $54 & 31;
     if ($52) {
      $57 = $49 >>> 6;
      $58 = $57 & 992;
      $59 = $55 | $58;
      $60 = $59 | $56;
      $$sink158 = $60;
     } else {
      $61 = HEAP16[$$2149>>1]|0;
      $62 = $61&65535;
      $63 = $49 << 10;
      $64 = $63 & 65011712;
      $65 = $64 | $55;
      $66 = $65 | $56;
      $67 = $62 << 16;
      $68 = $67 | $62;
      $69 = $68 & 65043487;
      $70 = (($66) - ($69))|0;
      $71 = Math_imul($70, $50)|0;
      $72 = $71 >>> 5;
      $73 = (($72) + ($69))|0;
      $74 = $73 & 65043487;
      $75 = $74 >>> 16;
      $76 = $75 | $74;
      $$sink158 = $76;
     }
     $77 = $$sink158&65535;
     HEAP16[$$2149>>1] = $77;
    }
    $78 = ((($$2)) + 4|0);
    $79 = ((($$2149)) + 2|0);
    $$2154 = $$1153;$$3 = $78;$$3150 = $79;
    label = 16;
    continue;
   }
   else if ((label|0) == 16) {
    label = 0;
    $80 = HEAP32[$$3>>2]|0;
    $81 = $80 >>> 27;
    $82 = ($81|0)==(0);
    if (!($82)) {
     $83 = ($81|0)==(31);
     $84 = $80 >>> 9;
     $85 = $80 >>> 3;
     $86 = $84 & 31744;
     $87 = $85 & 31;
     if ($83) {
      $88 = $80 >>> 6;
      $89 = $88 & 992;
      $90 = $86 | $89;
      $91 = $90 | $87;
      $$sink160 = $91;
     } else {
      $92 = HEAP16[$$3150>>1]|0;
      $93 = $92&65535;
      $94 = $80 << 10;
      $95 = $94 & 65011712;
      $96 = $95 | $86;
      $97 = $96 | $87;
      $98 = $93 << 16;
      $99 = $98 | $93;
      $100 = $99 & 65043487;
      $101 = (($97) - ($100))|0;
      $102 = Math_imul($101, $81)|0;
      $103 = $102 >>> 5;
      $104 = (($103) + ($100))|0;
      $105 = $104 & 65043487;
      $106 = $105 >>> 16;
      $107 = $106 | $105;
      $$sink160 = $107;
     }
     $108 = $$sink160&65535;
     HEAP16[$$3150>>1] = $108;
    }
    $109 = ((($$3)) + 4|0);
    $110 = ((($$3150)) + 2|0);
    $$3155 = $$2154;$$4 = $109;$$4151 = $110;
    label = 22;
    continue;
   }
   else if ((label|0) == 22) {
    label = 0;
    $111 = HEAP32[$$4>>2]|0;
    $112 = $111 >>> 27;
    $113 = ($112|0)==(0);
    if (!($113)) {
     $114 = ($112|0)==(31);
     $115 = $111 >>> 3;
     $116 = $115 & 31;
     $117 = $111 >>> 9;
     $118 = $117 & 31744;
     if ($114) {
      $119 = $111 >>> 6;
      $120 = $119 & 992;
      $121 = $118 | $120;
      $122 = $121 | $116;
      $$sink162 = $122;
     } else {
      $123 = HEAP16[$$4151>>1]|0;
      $124 = $123&65535;
      $125 = $111 << 10;
      $126 = $125 & 65011712;
      $127 = $126 | $118;
      $128 = $127 | $116;
      $129 = $124 << 16;
      $130 = $129 | $124;
      $131 = $130 & 65043487;
      $132 = (($128) - ($131))|0;
      $133 = Math_imul($132, $112)|0;
      $134 = $133 >>> 5;
      $135 = (($134) + ($131))|0;
      $136 = $135 & 65043487;
      $137 = $136 >>> 16;
      $138 = $137 | $136;
      $$sink162 = $138;
     }
     $139 = $$sink162&65535;
     HEAP16[$$4151>>1] = $139;
    }
    $140 = ((($$4)) + 4|0);
    $141 = ((($$4151)) + 2|0);
    $142 = (($$3155) + -1)|0;
    $143 = ($$3155|0)>(1);
    if ($143) {
     $$0152 = $142;$$1 = $140;$$1148 = $141;
     label = 4;
     continue;
    } else {
     break;
    }
   }
  }
  $144 = (($140) + ($7<<2)|0);
  $145 = (($141) + ($10<<1)|0);
  $146 = ($17|0)==(0);
  if ($146) {
   label = 30;
   break;
  } else {
   $$0146164 = $144;$$0147163 = $145;$$in = $17;
  }
 }
 if ((label|0) == 28) {
  // unreachable;
 }
 else if ((label|0) == 30) {
  return;
 }
}
function _BlitNtoNPixelAlpha($0) {
 $0 = $0|0;
 var $$08281120 = 0, $$08291119 = 0, $$0834 = 0, $$0834922 = 0, $$0834926 = 0, $$0838 = 0, $$0838923 = 0, $$0838927 = 0, $$0842 = 0, $$0842924 = 0, $$0842928 = 0, $$0846 = 0, $$0846929 = 0, $$0850 = 0, $$0850$shrunk = 0, $$0854 = 0, $$0854$shrunk = 0, $$0858 = 0, $$0858$shrunk = 0, $$0862 = 0;
 var $$0862$shrunk = 0, $$0866 = 0, $$1 = 0, $$1830 = 0, $$1835 = 0, $$1835936 = 0, $$1835940 = 0, $$1839 = 0, $$1839937 = 0, $$1839941 = 0, $$1843 = 0, $$1843938 = 0, $$1843942 = 0, $$1847 = 0, $$1847943 = 0, $$1851 = 0, $$1851$shrunk = 0, $$1855 = 0, $$1855$shrunk = 0, $$1859 = 0;
 var $$1859$shrunk = 0, $$1863 = 0, $$1863$shrunk = 0, $$1867 = 0, $$2 = 0, $$2831 = 0, $$2836 = 0, $$2836950 = 0, $$2836954 = 0, $$2840 = 0, $$2840951 = 0, $$2840955 = 0, $$2844 = 0, $$2844952 = 0, $$2844956 = 0, $$2848 = 0, $$2848957 = 0, $$2852 = 0, $$2852$shrunk = 0, $$2856 = 0;
 var $$2856$shrunk = 0, $$2860 = 0, $$2860$shrunk = 0, $$2864 = 0, $$2864$shrunk = 0, $$2868 = 0, $$3 = 0, $$3832 = 0, $$3837 = 0, $$3837964 = 0, $$3837968 = 0, $$3841 = 0, $$3841965 = 0, $$3841969 = 0, $$3845 = 0, $$3845966 = 0, $$3845970 = 0, $$3849 = 0, $$3849971 = 0, $$3853 = 0;
 var $$3853$shrunk = 0, $$3857 = 0, $$3857$shrunk = 0, $$3861 = 0, $$3861$shrunk = 0, $$3865 = 0, $$3865$shrunk = 0, $$3869 = 0, $$4 = 0, $$4833 = 0, $$in = 0, $$sink1004 = 0, $$sink1040 = 0, $$sink1076 = 0, $$sink1112 = 0, $1 = 0, $10 = 0, $100 = 0, $1000 = 0, $1001 = 0;
 var $1002 = 0, $1003 = 0, $1004 = 0, $1005 = 0, $1006 = 0, $1007 = 0, $1008 = 0, $1009 = 0, $101 = 0, $1010 = 0, $1011 = 0, $1012 = 0, $1013 = 0, $1014 = 0, $1015 = 0, $1016 = 0, $1017 = 0, $1018 = 0, $1019 = 0, $102 = 0;
 var $1020 = 0, $1021 = 0, $1022 = 0, $1023 = 0, $1024 = 0, $1025 = 0, $1026 = 0, $1027 = 0, $1028 = 0, $1029 = 0, $103 = 0, $1030 = 0, $1031 = 0, $1032 = 0, $1033 = 0, $1034 = 0, $1035 = 0, $1036 = 0, $1037 = 0, $1038 = 0;
 var $1039 = 0, $104 = 0, $1040 = 0, $1041 = 0, $1042 = 0, $1043 = 0, $1044 = 0, $1045 = 0, $1046 = 0, $1047 = 0, $1048 = 0, $1049 = 0, $105 = 0, $1050 = 0, $1051 = 0, $1052 = 0, $1053 = 0, $1054 = 0, $1055 = 0, $1056 = 0;
 var $1057 = 0, $1058 = 0, $1059 = 0, $106 = 0, $1060 = 0, $1061 = 0, $1062 = 0, $1063 = 0, $1064 = 0, $1065 = 0, $1066 = 0, $1067 = 0, $1068 = 0, $1069 = 0, $107 = 0, $1070 = 0, $1071 = 0, $1072 = 0, $1073 = 0, $1074 = 0;
 var $1075 = 0, $1076 = 0, $1077 = 0, $1078 = 0, $1079 = 0, $108 = 0, $1080 = 0, $1081 = 0, $1082 = 0, $1083 = 0, $1084 = 0, $1085 = 0, $1086 = 0, $1087 = 0, $1088 = 0, $1089 = 0, $109 = 0, $1090 = 0, $1091 = 0, $1092 = 0;
 var $1093 = 0, $1094 = 0, $1095 = 0, $1096 = 0, $1097 = 0, $1098 = 0, $1099 = 0, $11 = 0, $110 = 0, $1100 = 0, $1101 = 0, $1102 = 0, $1103 = 0, $1104 = 0, $1105 = 0, $1106 = 0, $1107 = 0, $1108 = 0, $1109 = 0, $111 = 0;
 var $1110 = 0, $1111 = 0, $1112 = 0, $1113 = 0, $1114 = 0, $1115 = 0, $1116 = 0, $1117 = 0, $1118 = 0, $1119 = 0, $112 = 0, $1120 = 0, $1121 = 0, $1122 = 0, $1123 = 0, $1124 = 0, $1125 = 0, $1126 = 0, $1127 = 0, $1128 = 0;
 var $1129 = 0, $113 = 0, $1130 = 0, $1131 = 0, $1132 = 0, $1133 = 0, $1134 = 0, $1135 = 0, $1136 = 0, $1137 = 0, $1138 = 0, $1139 = 0, $114 = 0, $1140 = 0, $1141 = 0, $1142 = 0, $1143 = 0, $1144 = 0, $1145 = 0, $1146 = 0;
 var $1147 = 0, $1148 = 0, $1149 = 0, $115 = 0, $1150 = 0, $1151 = 0, $1152 = 0, $1153 = 0, $1154 = 0, $1155 = 0, $1156 = 0, $1157 = 0, $1158 = 0, $1159 = 0, $116 = 0, $1160 = 0, $1161 = 0, $1162 = 0, $1163 = 0, $1164 = 0;
 var $1165 = 0, $1166 = 0, $1167 = 0, $1168 = 0, $1169 = 0, $117 = 0, $1170 = 0, $1171 = 0, $1172 = 0, $1173 = 0, $1174 = 0, $1175 = 0, $1176 = 0, $1177 = 0, $1178 = 0, $1179 = 0, $118 = 0, $1180 = 0, $1181 = 0, $1182 = 0;
 var $1183 = 0, $1184 = 0, $1185 = 0, $1186 = 0, $1187 = 0, $1188 = 0, $1189 = 0, $119 = 0, $1190 = 0, $1191 = 0, $1192 = 0, $1193 = 0, $1194 = 0, $1195 = 0, $1196 = 0, $1197 = 0, $1198 = 0, $1199 = 0, $12 = 0, $120 = 0;
 var $1200 = 0, $1201 = 0, $1202 = 0, $1203 = 0, $1204 = 0, $1205 = 0, $1206 = 0, $1207 = 0, $1208 = 0, $1209 = 0, $121 = 0, $1210 = 0, $1211 = 0, $1212 = 0, $1213 = 0, $1214 = 0, $1215 = 0, $1216 = 0, $1217 = 0, $1218 = 0;
 var $1219 = 0, $122 = 0, $1220 = 0, $1221 = 0, $1222 = 0, $1223 = 0, $1224 = 0, $1225 = 0, $1226 = 0, $1227 = 0, $1228 = 0, $1229 = 0, $123 = 0, $1230 = 0, $1231 = 0, $1232 = 0, $1233 = 0, $1234 = 0, $1235 = 0, $1236 = 0;
 var $1237 = 0, $1238 = 0, $1239 = 0, $124 = 0, $1240 = 0, $1241 = 0, $1242 = 0, $1243 = 0, $1244 = 0, $1245 = 0, $1246 = 0, $1247 = 0, $1248 = 0, $1249 = 0, $125 = 0, $1250 = 0, $1251 = 0, $1252 = 0, $1253 = 0, $1254 = 0;
 var $1255 = 0, $1256 = 0, $1257 = 0, $1258 = 0, $1259 = 0, $126 = 0, $1260 = 0, $1261 = 0, $1262 = 0, $1263 = 0, $1264 = 0, $1265 = 0, $1266 = 0, $1267 = 0, $1268 = 0, $1269 = 0, $127 = 0, $1270 = 0, $1271 = 0, $1272 = 0;
 var $1273 = 0, $1274 = 0, $1275 = 0, $1276 = 0, $1277 = 0, $1278 = 0, $1279 = 0, $128 = 0, $1280 = 0, $1281 = 0, $1282 = 0, $1283 = 0, $1284 = 0, $1285 = 0, $1286 = 0, $1287 = 0, $1288 = 0, $1289 = 0, $129 = 0, $1290 = 0;
 var $1291 = 0, $1292 = 0, $1293 = 0, $1294 = 0, $1295 = 0, $1296 = 0, $1297 = 0, $1298 = 0, $1299 = 0, $13 = 0, $130 = 0, $1300 = 0, $1301 = 0, $1302 = 0, $1303 = 0, $1304 = 0, $1305 = 0, $1306 = 0, $1307 = 0, $1308 = 0;
 var $1309 = 0, $131 = 0, $1310 = 0, $1311 = 0, $1312 = 0, $1313 = 0, $1314 = 0, $1315 = 0, $1316 = 0, $1317 = 0, $1318 = 0, $1319 = 0, $132 = 0, $1320 = 0, $1321 = 0, $1322 = 0, $1323 = 0, $1324 = 0, $1325 = 0, $1326 = 0;
 var $1327 = 0, $1328 = 0, $1329 = 0, $133 = 0, $1330 = 0, $1331 = 0, $1332 = 0, $1333 = 0, $1334 = 0, $1335 = 0, $1336 = 0, $1337 = 0, $1338 = 0, $1339 = 0, $134 = 0, $1340 = 0, $1341 = 0, $1342 = 0, $1343 = 0, $1344 = 0;
 var $1345 = 0, $1346 = 0, $1347 = 0, $1348 = 0, $1349 = 0, $135 = 0, $1350 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0;
 var $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0;
 var $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0;
 var $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0;
 var $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0;
 var $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0;
 var $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0;
 var $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0;
 var $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0;
 var $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0;
 var $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0;
 var $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0;
 var $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0;
 var $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0;
 var $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0;
 var $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0;
 var $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0;
 var $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0;
 var $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0;
 var $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0;
 var $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0;
 var $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0;
 var $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0;
 var $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0;
 var $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0;
 var $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0;
 var $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0;
 var $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0;
 var $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0;
 var $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0;
 var $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0;
 var $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0;
 var $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0;
 var $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0;
 var $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0;
 var $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0;
 var $832 = 0, $833 = 0, $834 = 0, $835 = 0, $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0;
 var $850 = 0, $851 = 0, $852 = 0, $853 = 0, $854 = 0, $855 = 0, $856 = 0, $857 = 0, $858 = 0, $859 = 0, $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0;
 var $869 = 0, $87 = 0, $870 = 0, $871 = 0, $872 = 0, $873 = 0, $874 = 0, $875 = 0, $876 = 0, $877 = 0, $878 = 0, $879 = 0, $88 = 0, $880 = 0, $881 = 0, $882 = 0, $883 = 0, $884 = 0, $885 = 0, $886 = 0;
 var $887 = 0, $888 = 0, $889 = 0, $89 = 0, $890 = 0, $891 = 0, $892 = 0, $893 = 0, $894 = 0, $895 = 0, $896 = 0, $897 = 0, $898 = 0, $899 = 0, $9 = 0, $90 = 0, $900 = 0, $901 = 0, $902 = 0, $903 = 0;
 var $904 = 0, $905 = 0, $906 = 0, $907 = 0, $908 = 0, $909 = 0, $91 = 0, $910 = 0, $911 = 0, $912 = 0, $913 = 0, $914 = 0, $915 = 0, $916 = 0, $917 = 0, $918 = 0, $919 = 0, $92 = 0, $920 = 0, $921 = 0;
 var $922 = 0, $923 = 0, $924 = 0, $925 = 0, $926 = 0, $927 = 0, $928 = 0, $929 = 0, $93 = 0, $930 = 0, $931 = 0, $932 = 0, $933 = 0, $934 = 0, $935 = 0, $936 = 0, $937 = 0, $938 = 0, $939 = 0, $94 = 0;
 var $940 = 0, $941 = 0, $942 = 0, $943 = 0, $944 = 0, $945 = 0, $946 = 0, $947 = 0, $948 = 0, $949 = 0, $95 = 0, $950 = 0, $951 = 0, $952 = 0, $953 = 0, $954 = 0, $955 = 0, $956 = 0, $957 = 0, $958 = 0;
 var $959 = 0, $96 = 0, $960 = 0, $961 = 0, $962 = 0, $963 = 0, $964 = 0, $965 = 0, $966 = 0, $967 = 0, $968 = 0, $969 = 0, $97 = 0, $970 = 0, $971 = 0, $972 = 0, $973 = 0, $974 = 0, $975 = 0, $976 = 0;
 var $977 = 0, $978 = 0, $979 = 0, $98 = 0, $980 = 0, $981 = 0, $982 = 0, $983 = 0, $984 = 0, $985 = 0, $986 = 0, $987 = 0, $988 = 0, $989 = 0, $99 = 0, $990 = 0, $991 = 0, $992 = 0, $993 = 0, $994 = 0;
 var $995 = 0, $996 = 0, $997 = 0, $998 = 0, $999 = 0, $div = 0, $div876 = 0, $div877 = 0, $div878 = 0, $div879 = 0, $div880 = 0, $div881 = 0, $div882 = 0, $div883 = 0, $div886 = 0, $div887 = 0, $div888 = 0, $div889 = 0, $div890 = 0, $div891 = 0;
 var $div892 = 0, $div893 = 0, $div894 = 0, $div897 = 0, $div898 = 0, $div899 = 0, $div900 = 0, $div901 = 0, $div902 = 0, $div903 = 0, $div904 = 0, $div905 = 0, $div908 = 0, $div909 = 0, $div910 = 0, $div911 = 0, $div912 = 0, $div913 = 0, $div914 = 0, $div915 = 0;
 var $div916 = 0, $trunc = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($0)) + 36|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($0)) + 40|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ((($0)) + 44|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ((($10)) + 9|0);
 $14 = HEAP8[$13>>0]|0;
 $15 = $14&255;
 $16 = ((($12)) + 9|0);
 $17 = HEAP8[$16>>0]|0;
 $18 = $17&255;
 $19 = ($4|0)==(0);
 if ($19) {
  return;
 }
 $20 = ((($0)) + 20|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = HEAP32[$0>>2]|0;
 $23 = (($2) + 3)|0;
 $24 = (($23|0) / 4)&-1;
 $trunc = $2&255;
 $25 = ((($10)) + 28|0);
 $26 = ((($10)) + 12|0);
 $27 = ((($10)) + 32|0);
 $28 = ((($10)) + 29|0);
 $29 = ((($10)) + 16|0);
 $30 = ((($10)) + 33|0);
 $31 = ((($10)) + 30|0);
 $32 = ((($10)) + 20|0);
 $33 = ((($10)) + 34|0);
 $34 = ((($10)) + 31|0);
 $35 = ((($10)) + 24|0);
 $36 = ((($10)) + 35|0);
 $37 = ((($12)) + 28|0);
 $38 = ((($12)) + 32|0);
 $39 = ((($12)) + 29|0);
 $40 = ((($12)) + 33|0);
 $41 = ((($12)) + 30|0);
 $42 = ((($12)) + 34|0);
 $43 = ((($12)) + 31|0);
 $44 = ((($12)) + 35|0);
 $45 = ((($12)) + 12|0);
 $46 = ((($12)) + 16|0);
 $47 = ((($12)) + 20|0);
 $48 = ((($12)) + 24|0);
 $$08281120 = $22;$$08291119 = $21;$$in = $4;
 L4: while(1) {
  $49 = (($$in) + -1)|0;
  $trunc$clear = $trunc & 3;
  switch ($trunc$clear<<24>>24) {
  case 0:  {
   $$0866 = $24;$$1 = $$08281120;$$1830 = $$08291119;
   label = 4;
   break;
  }
  case 3:  {
   $$1867 = $24;$$2 = $$08281120;$$2831 = $$08291119;
   label = 21;
   break;
  }
  case 2:  {
   $$2868 = $24;$$3 = $$08281120;$$3832 = $$08291119;
   label = 38;
   break;
  }
  case 1:  {
   $$3869 = $24;$$4 = $$08281120;$$4833 = $$08291119;
   label = 55;
   break;
  }
  default: {
   label = 72;
   break L4;
  }
  }
  while(1) {
   if ((label|0) == 4) {
    label = 0;
    switch ($14<<24>>24) {
    case 1:  {
     $50 = HEAP8[$$1>>0]|0;
     $51 = $50&255;
     $$sink1004 = $51;
     label = 9;
     break;
    }
    case 2:  {
     $52 = HEAP16[$$1>>1]|0;
     $53 = $52&65535;
     $$sink1004 = $53;
     label = 9;
     break;
    }
    case 3:  {
     $54 = HEAP8[$27>>0]|0;
     $div903 = ($54&255) >>> 3;
     $55 = $div903&255;
     $56 = (($$1) + ($55)|0);
     $57 = HEAP8[$56>>0]|0;
     $58 = HEAP8[$30>>0]|0;
     $div904 = ($58&255) >>> 3;
     $59 = $div904&255;
     $60 = (($$1) + ($59)|0);
     $61 = HEAP8[$60>>0]|0;
     $62 = HEAP8[$33>>0]|0;
     $div905 = ($62&255) >>> 3;
     $63 = $div905&255;
     $64 = (($$1) + ($63)|0);
     $65 = HEAP8[$64>>0]|0;
     $$0834922 = $57&255;
     $$0838923 = $61&255;
     $$0842924 = $65&255;
     $$0834926 = $$0834922;$$0838927 = $$0838923;$$0842928 = $$0842924;$$0846929 = 255;
     label = 10;
     break;
    }
    case 4:  {
     $66 = HEAP32[$$1>>2]|0;
     $$sink1004 = $66;
     label = 9;
     break;
    }
    default: {
    }
    }
    if ((label|0) == 9) {
     label = 0;
     $67 = HEAP8[$25>>0]|0;
     $68 = $67&255;
     $69 = (79212 + ($68<<2)|0);
     $70 = HEAP32[$69>>2]|0;
     $71 = HEAP32[$26>>2]|0;
     $72 = $71 & $$sink1004;
     $73 = HEAP8[$27>>0]|0;
     $74 = $73&255;
     $75 = $72 >>> $74;
     $76 = (($70) + ($75)|0);
     $77 = HEAP8[$76>>0]|0;
     $78 = HEAP8[$28>>0]|0;
     $79 = $78&255;
     $80 = (79212 + ($79<<2)|0);
     $81 = HEAP32[$80>>2]|0;
     $82 = HEAP32[$29>>2]|0;
     $83 = $82 & $$sink1004;
     $84 = HEAP8[$30>>0]|0;
     $85 = $84&255;
     $86 = $83 >>> $85;
     $87 = (($81) + ($86)|0);
     $88 = HEAP8[$87>>0]|0;
     $89 = HEAP8[$31>>0]|0;
     $90 = $89&255;
     $91 = (79212 + ($90<<2)|0);
     $92 = HEAP32[$91>>2]|0;
     $93 = HEAP32[$32>>2]|0;
     $94 = $93 & $$sink1004;
     $95 = HEAP8[$33>>0]|0;
     $96 = $95&255;
     $97 = $94 >>> $96;
     $98 = (($92) + ($97)|0);
     $99 = HEAP8[$98>>0]|0;
     $100 = HEAP8[$34>>0]|0;
     $101 = $100&255;
     $102 = (79212 + ($101<<2)|0);
     $103 = HEAP32[$102>>2]|0;
     $104 = HEAP32[$35>>2]|0;
     $105 = $104 & $$sink1004;
     $106 = HEAP8[$36>>0]|0;
     $107 = $106&255;
     $108 = $105 >>> $107;
     $109 = (($103) + ($108)|0);
     $110 = HEAP8[$109>>0]|0;
     $$0834 = $77&255;
     $$0838 = $88&255;
     $$0842 = $99&255;
     $$0846 = $110&255;
     $111 = ($110<<24>>24)==(0);
     if (!($111)) {
      $$0834926 = $$0834;$$0838927 = $$0838;$$0842928 = $$0842;$$0846929 = $$0846;
      label = 10;
     }
    }
    L16: do {
     if ((label|0) == 10) {
      label = 0;
      switch ($17<<24>>24) {
      case 1:  {
       $112 = HEAP8[$$1830>>0]|0;
       $113 = $112&255;
       $114 = HEAP8[$37>>0]|0;
       $115 = $114&255;
       $116 = (79212 + ($115<<2)|0);
       $117 = HEAP32[$116>>2]|0;
       $118 = HEAP32[$45>>2]|0;
       $119 = $118 & $113;
       $120 = HEAP8[$38>>0]|0;
       $121 = $120&255;
       $122 = $119 >>> $121;
       $123 = (($117) + ($122)|0);
       $124 = HEAP8[$123>>0]|0;
       $125 = HEAP8[$39>>0]|0;
       $126 = $125&255;
       $127 = (79212 + ($126<<2)|0);
       $128 = HEAP32[$127>>2]|0;
       $129 = HEAP32[$46>>2]|0;
       $130 = $129 & $113;
       $131 = HEAP8[$40>>0]|0;
       $132 = $131&255;
       $133 = $130 >>> $132;
       $134 = (($128) + ($133)|0);
       $135 = HEAP8[$134>>0]|0;
       $136 = HEAP8[$41>>0]|0;
       $137 = $136&255;
       $138 = (79212 + ($137<<2)|0);
       $139 = HEAP32[$138>>2]|0;
       $140 = HEAP32[$47>>2]|0;
       $141 = $140 & $113;
       $142 = HEAP8[$42>>0]|0;
       $143 = $142&255;
       $144 = $141 >>> $143;
       $145 = (($139) + ($144)|0);
       $146 = HEAP8[$145>>0]|0;
       $147 = HEAP8[$43>>0]|0;
       $148 = $147&255;
       $149 = (79212 + ($148<<2)|0);
       $150 = HEAP32[$149>>2]|0;
       $151 = HEAP32[$48>>2]|0;
       $152 = $151 & $113;
       $153 = HEAP8[$44>>0]|0;
       $154 = $153&255;
       $155 = $152 >>> $154;
       $156 = (($150) + ($155)|0);
       $157 = HEAP8[$156>>0]|0;
       $$0850$shrunk = $124;$$0854$shrunk = $135;$$0858$shrunk = $146;$$0862$shrunk = $157;
       break;
      }
      case 2:  {
       $158 = HEAP16[$$1830>>1]|0;
       $159 = $158&65535;
       $160 = HEAP8[$37>>0]|0;
       $161 = $160&255;
       $162 = (79212 + ($161<<2)|0);
       $163 = HEAP32[$162>>2]|0;
       $164 = HEAP32[$45>>2]|0;
       $165 = $164 & $159;
       $166 = HEAP8[$38>>0]|0;
       $167 = $166&255;
       $168 = $165 >>> $167;
       $169 = (($163) + ($168)|0);
       $170 = HEAP8[$169>>0]|0;
       $171 = HEAP8[$39>>0]|0;
       $172 = $171&255;
       $173 = (79212 + ($172<<2)|0);
       $174 = HEAP32[$173>>2]|0;
       $175 = HEAP32[$46>>2]|0;
       $176 = $175 & $159;
       $177 = HEAP8[$40>>0]|0;
       $178 = $177&255;
       $179 = $176 >>> $178;
       $180 = (($174) + ($179)|0);
       $181 = HEAP8[$180>>0]|0;
       $182 = HEAP8[$41>>0]|0;
       $183 = $182&255;
       $184 = (79212 + ($183<<2)|0);
       $185 = HEAP32[$184>>2]|0;
       $186 = HEAP32[$47>>2]|0;
       $187 = $186 & $159;
       $188 = HEAP8[$42>>0]|0;
       $189 = $188&255;
       $190 = $187 >>> $189;
       $191 = (($185) + ($190)|0);
       $192 = HEAP8[$191>>0]|0;
       $193 = HEAP8[$43>>0]|0;
       $194 = $193&255;
       $195 = (79212 + ($194<<2)|0);
       $196 = HEAP32[$195>>2]|0;
       $197 = HEAP32[$48>>2]|0;
       $198 = $197 & $159;
       $199 = HEAP8[$44>>0]|0;
       $200 = $199&255;
       $201 = $198 >>> $200;
       $202 = (($196) + ($201)|0);
       $203 = HEAP8[$202>>0]|0;
       $$0850$shrunk = $170;$$0854$shrunk = $181;$$0858$shrunk = $192;$$0862$shrunk = $203;
       break;
      }
      case 3:  {
       $204 = HEAP8[$38>>0]|0;
       $div900 = ($204&255) >>> 3;
       $205 = $div900&255;
       $206 = (($$1830) + ($205)|0);
       $207 = HEAP8[$206>>0]|0;
       $208 = HEAP8[$40>>0]|0;
       $div901 = ($208&255) >>> 3;
       $209 = $div901&255;
       $210 = (($$1830) + ($209)|0);
       $211 = HEAP8[$210>>0]|0;
       $212 = HEAP8[$42>>0]|0;
       $div902 = ($212&255) >>> 3;
       $213 = $div902&255;
       $214 = (($$1830) + ($213)|0);
       $215 = HEAP8[$214>>0]|0;
       $$0850$shrunk = $207;$$0854$shrunk = $211;$$0858$shrunk = $215;$$0862$shrunk = -1;
       break;
      }
      case 4:  {
       $216 = HEAP32[$$1830>>2]|0;
       $217 = HEAP8[$37>>0]|0;
       $218 = $217&255;
       $219 = (79212 + ($218<<2)|0);
       $220 = HEAP32[$219>>2]|0;
       $221 = HEAP32[$45>>2]|0;
       $222 = $221 & $216;
       $223 = HEAP8[$38>>0]|0;
       $224 = $223&255;
       $225 = $222 >>> $224;
       $226 = (($220) + ($225)|0);
       $227 = HEAP8[$226>>0]|0;
       $228 = HEAP8[$39>>0]|0;
       $229 = $228&255;
       $230 = (79212 + ($229<<2)|0);
       $231 = HEAP32[$230>>2]|0;
       $232 = HEAP32[$46>>2]|0;
       $233 = $232 & $216;
       $234 = HEAP8[$40>>0]|0;
       $235 = $234&255;
       $236 = $233 >>> $235;
       $237 = (($231) + ($236)|0);
       $238 = HEAP8[$237>>0]|0;
       $239 = HEAP8[$41>>0]|0;
       $240 = $239&255;
       $241 = (79212 + ($240<<2)|0);
       $242 = HEAP32[$241>>2]|0;
       $243 = HEAP32[$47>>2]|0;
       $244 = $243 & $216;
       $245 = HEAP8[$42>>0]|0;
       $246 = $245&255;
       $247 = $244 >>> $246;
       $248 = (($242) + ($247)|0);
       $249 = HEAP8[$248>>0]|0;
       $250 = HEAP8[$43>>0]|0;
       $251 = $250&255;
       $252 = (79212 + ($251<<2)|0);
       $253 = HEAP32[$252>>2]|0;
       $254 = HEAP32[$48>>2]|0;
       $255 = $254 & $216;
       $256 = HEAP8[$44>>0]|0;
       $257 = $256&255;
       $258 = $255 >>> $257;
       $259 = (($253) + ($258)|0);
       $260 = HEAP8[$259>>0]|0;
       $$0850$shrunk = $227;$$0854$shrunk = $238;$$0858$shrunk = $249;$$0862$shrunk = $260;
       break;
      }
      default: {
       $$0850$shrunk = 0;$$0854$shrunk = 0;$$0858$shrunk = 0;$$0862$shrunk = 0;
      }
      }
      $$0850 = $$0850$shrunk&255;
      $$0854 = $$0854$shrunk&255;
      $$0858 = $$0858$shrunk&255;
      $$0862 = $$0862$shrunk&255;
      $261 = (($$0834926) - ($$0850))|0;
      $262 = Math_imul($261, $$0846929)|0;
      $263 = (($262>>>0) / 255)&-1;
      $264 = (($263) + ($$0850))|0;
      $265 = (($$0838927) - ($$0854))|0;
      $266 = Math_imul($265, $$0846929)|0;
      $267 = (($266>>>0) / 255)&-1;
      $268 = (($267) + ($$0854))|0;
      $269 = (($$0842928) - ($$0858))|0;
      $270 = Math_imul($269, $$0846929)|0;
      $271 = (($270>>>0) / 255)&-1;
      $272 = (($271) + ($$0858))|0;
      $273 = (($$0862) + ($$0846929))|0;
      $274 = Math_imul($$0862, $$0846929)|0;
      $275 = (($274>>>0) / 255)&-1;
      $276 = (($273) - ($275))|0;
      switch ($17<<24>>24) {
      case 1:  {
       $277 = HEAP8[$37>>0]|0;
       $278 = $277&255;
       $279 = $264 >>> $278;
       $280 = HEAP8[$38>>0]|0;
       $281 = $280&255;
       $282 = $279 << $281;
       $283 = HEAP8[$39>>0]|0;
       $284 = $283&255;
       $285 = $268 >>> $284;
       $286 = HEAP8[$40>>0]|0;
       $287 = $286&255;
       $288 = $285 << $287;
       $289 = $288 | $282;
       $290 = HEAP8[$41>>0]|0;
       $291 = $290&255;
       $292 = $272 >>> $291;
       $293 = HEAP8[$42>>0]|0;
       $294 = $293&255;
       $295 = $292 << $294;
       $296 = $289 | $295;
       $297 = HEAP8[$43>>0]|0;
       $298 = $297&255;
       $299 = $276 >>> $298;
       $300 = HEAP8[$44>>0]|0;
       $301 = $300&255;
       $302 = $299 << $301;
       $303 = $296 | $302;
       $304 = $303&255;
       HEAP8[$$1830>>0] = $304;
       break L16;
       break;
      }
      case 2:  {
       $305 = HEAP8[$37>>0]|0;
       $306 = $305&255;
       $307 = $264 >>> $306;
       $308 = HEAP8[$38>>0]|0;
       $309 = $308&255;
       $310 = $307 << $309;
       $311 = HEAP8[$39>>0]|0;
       $312 = $311&255;
       $313 = $268 >>> $312;
       $314 = HEAP8[$40>>0]|0;
       $315 = $314&255;
       $316 = $313 << $315;
       $317 = $316 | $310;
       $318 = HEAP8[$41>>0]|0;
       $319 = $318&255;
       $320 = $272 >>> $319;
       $321 = HEAP8[$42>>0]|0;
       $322 = $321&255;
       $323 = $320 << $322;
       $324 = $317 | $323;
       $325 = HEAP8[$43>>0]|0;
       $326 = $325&255;
       $327 = $276 >>> $326;
       $328 = HEAP8[$44>>0]|0;
       $329 = $328&255;
       $330 = $327 << $329;
       $331 = $324 | $330;
       $332 = $331&65535;
       HEAP16[$$1830>>1] = $332;
       break L16;
       break;
      }
      case 3:  {
       $333 = $264&255;
       $334 = HEAP8[$38>>0]|0;
       $div897 = ($334&255) >>> 3;
       $335 = $div897&255;
       $336 = (($$1830) + ($335)|0);
       HEAP8[$336>>0] = $333;
       $337 = $268&255;
       $338 = HEAP8[$40>>0]|0;
       $div898 = ($338&255) >>> 3;
       $339 = $div898&255;
       $340 = (($$1830) + ($339)|0);
       HEAP8[$340>>0] = $337;
       $341 = $272&255;
       $342 = HEAP8[$42>>0]|0;
       $div899 = ($342&255) >>> 3;
       $343 = $div899&255;
       $344 = (($$1830) + ($343)|0);
       HEAP8[$344>>0] = $341;
       break L16;
       break;
      }
      case 4:  {
       $345 = HEAP8[$37>>0]|0;
       $346 = $345&255;
       $347 = $264 >>> $346;
       $348 = HEAP8[$38>>0]|0;
       $349 = $348&255;
       $350 = $347 << $349;
       $351 = HEAP8[$39>>0]|0;
       $352 = $351&255;
       $353 = $268 >>> $352;
       $354 = HEAP8[$40>>0]|0;
       $355 = $354&255;
       $356 = $353 << $355;
       $357 = $356 | $350;
       $358 = HEAP8[$41>>0]|0;
       $359 = $358&255;
       $360 = $272 >>> $359;
       $361 = HEAP8[$42>>0]|0;
       $362 = $361&255;
       $363 = $360 << $362;
       $364 = $357 | $363;
       $365 = HEAP8[$43>>0]|0;
       $366 = $365&255;
       $367 = $276 >>> $366;
       $368 = HEAP8[$44>>0]|0;
       $369 = $368&255;
       $370 = $367 << $369;
       $371 = $364 | $370;
       HEAP32[$$1830>>2] = $371;
       break L16;
       break;
      }
      default: {
       break L16;
      }
      }
     }
    } while(0);
    $372 = (($$1) + ($15)|0);
    $373 = (($$1830) + ($18)|0);
    $$1867 = $$0866;$$2 = $372;$$2831 = $373;
    label = 21;
    continue;
   }
   else if ((label|0) == 21) {
    label = 0;
    switch ($14<<24>>24) {
    case 1:  {
     $374 = HEAP8[$$2>>0]|0;
     $375 = $374&255;
     $$sink1040 = $375;
     label = 26;
     break;
    }
    case 2:  {
     $376 = HEAP16[$$2>>1]|0;
     $377 = $376&65535;
     $$sink1040 = $377;
     label = 26;
     break;
    }
    case 3:  {
     $378 = HEAP8[$27>>0]|0;
     $div892 = ($378&255) >>> 3;
     $379 = $div892&255;
     $380 = (($$2) + ($379)|0);
     $381 = HEAP8[$380>>0]|0;
     $382 = HEAP8[$30>>0]|0;
     $div893 = ($382&255) >>> 3;
     $383 = $div893&255;
     $384 = (($$2) + ($383)|0);
     $385 = HEAP8[$384>>0]|0;
     $386 = HEAP8[$33>>0]|0;
     $div894 = ($386&255) >>> 3;
     $387 = $div894&255;
     $388 = (($$2) + ($387)|0);
     $389 = HEAP8[$388>>0]|0;
     $$1835936 = $381&255;
     $$1839937 = $385&255;
     $$1843938 = $389&255;
     $$1835940 = $$1835936;$$1839941 = $$1839937;$$1843942 = $$1843938;$$1847943 = 255;
     label = 27;
     break;
    }
    case 4:  {
     $390 = HEAP32[$$2>>2]|0;
     $$sink1040 = $390;
     label = 26;
     break;
    }
    default: {
    }
    }
    if ((label|0) == 26) {
     label = 0;
     $391 = HEAP8[$25>>0]|0;
     $392 = $391&255;
     $393 = (79212 + ($392<<2)|0);
     $394 = HEAP32[$393>>2]|0;
     $395 = HEAP32[$26>>2]|0;
     $396 = $395 & $$sink1040;
     $397 = HEAP8[$27>>0]|0;
     $398 = $397&255;
     $399 = $396 >>> $398;
     $400 = (($394) + ($399)|0);
     $401 = HEAP8[$400>>0]|0;
     $402 = HEAP8[$28>>0]|0;
     $403 = $402&255;
     $404 = (79212 + ($403<<2)|0);
     $405 = HEAP32[$404>>2]|0;
     $406 = HEAP32[$29>>2]|0;
     $407 = $406 & $$sink1040;
     $408 = HEAP8[$30>>0]|0;
     $409 = $408&255;
     $410 = $407 >>> $409;
     $411 = (($405) + ($410)|0);
     $412 = HEAP8[$411>>0]|0;
     $413 = HEAP8[$31>>0]|0;
     $414 = $413&255;
     $415 = (79212 + ($414<<2)|0);
     $416 = HEAP32[$415>>2]|0;
     $417 = HEAP32[$32>>2]|0;
     $418 = $417 & $$sink1040;
     $419 = HEAP8[$33>>0]|0;
     $420 = $419&255;
     $421 = $418 >>> $420;
     $422 = (($416) + ($421)|0);
     $423 = HEAP8[$422>>0]|0;
     $424 = HEAP8[$34>>0]|0;
     $425 = $424&255;
     $426 = (79212 + ($425<<2)|0);
     $427 = HEAP32[$426>>2]|0;
     $428 = HEAP32[$35>>2]|0;
     $429 = $428 & $$sink1040;
     $430 = HEAP8[$36>>0]|0;
     $431 = $430&255;
     $432 = $429 >>> $431;
     $433 = (($427) + ($432)|0);
     $434 = HEAP8[$433>>0]|0;
     $$1835 = $401&255;
     $$1839 = $412&255;
     $$1843 = $423&255;
     $$1847 = $434&255;
     $435 = ($434<<24>>24)==(0);
     if (!($435)) {
      $$1835940 = $$1835;$$1839941 = $$1839;$$1843942 = $$1843;$$1847943 = $$1847;
      label = 27;
     }
    }
    L38: do {
     if ((label|0) == 27) {
      label = 0;
      switch ($17<<24>>24) {
      case 1:  {
       $436 = HEAP8[$$2831>>0]|0;
       $437 = $436&255;
       $438 = HEAP8[$37>>0]|0;
       $439 = $438&255;
       $440 = (79212 + ($439<<2)|0);
       $441 = HEAP32[$440>>2]|0;
       $442 = HEAP32[$45>>2]|0;
       $443 = $442 & $437;
       $444 = HEAP8[$38>>0]|0;
       $445 = $444&255;
       $446 = $443 >>> $445;
       $447 = (($441) + ($446)|0);
       $448 = HEAP8[$447>>0]|0;
       $449 = HEAP8[$39>>0]|0;
       $450 = $449&255;
       $451 = (79212 + ($450<<2)|0);
       $452 = HEAP32[$451>>2]|0;
       $453 = HEAP32[$46>>2]|0;
       $454 = $453 & $437;
       $455 = HEAP8[$40>>0]|0;
       $456 = $455&255;
       $457 = $454 >>> $456;
       $458 = (($452) + ($457)|0);
       $459 = HEAP8[$458>>0]|0;
       $460 = HEAP8[$41>>0]|0;
       $461 = $460&255;
       $462 = (79212 + ($461<<2)|0);
       $463 = HEAP32[$462>>2]|0;
       $464 = HEAP32[$47>>2]|0;
       $465 = $464 & $437;
       $466 = HEAP8[$42>>0]|0;
       $467 = $466&255;
       $468 = $465 >>> $467;
       $469 = (($463) + ($468)|0);
       $470 = HEAP8[$469>>0]|0;
       $471 = HEAP8[$43>>0]|0;
       $472 = $471&255;
       $473 = (79212 + ($472<<2)|0);
       $474 = HEAP32[$473>>2]|0;
       $475 = HEAP32[$48>>2]|0;
       $476 = $475 & $437;
       $477 = HEAP8[$44>>0]|0;
       $478 = $477&255;
       $479 = $476 >>> $478;
       $480 = (($474) + ($479)|0);
       $481 = HEAP8[$480>>0]|0;
       $$1851$shrunk = $448;$$1855$shrunk = $459;$$1859$shrunk = $470;$$1863$shrunk = $481;
       break;
      }
      case 2:  {
       $482 = HEAP16[$$2831>>1]|0;
       $483 = $482&65535;
       $484 = HEAP8[$37>>0]|0;
       $485 = $484&255;
       $486 = (79212 + ($485<<2)|0);
       $487 = HEAP32[$486>>2]|0;
       $488 = HEAP32[$45>>2]|0;
       $489 = $488 & $483;
       $490 = HEAP8[$38>>0]|0;
       $491 = $490&255;
       $492 = $489 >>> $491;
       $493 = (($487) + ($492)|0);
       $494 = HEAP8[$493>>0]|0;
       $495 = HEAP8[$39>>0]|0;
       $496 = $495&255;
       $497 = (79212 + ($496<<2)|0);
       $498 = HEAP32[$497>>2]|0;
       $499 = HEAP32[$46>>2]|0;
       $500 = $499 & $483;
       $501 = HEAP8[$40>>0]|0;
       $502 = $501&255;
       $503 = $500 >>> $502;
       $504 = (($498) + ($503)|0);
       $505 = HEAP8[$504>>0]|0;
       $506 = HEAP8[$41>>0]|0;
       $507 = $506&255;
       $508 = (79212 + ($507<<2)|0);
       $509 = HEAP32[$508>>2]|0;
       $510 = HEAP32[$47>>2]|0;
       $511 = $510 & $483;
       $512 = HEAP8[$42>>0]|0;
       $513 = $512&255;
       $514 = $511 >>> $513;
       $515 = (($509) + ($514)|0);
       $516 = HEAP8[$515>>0]|0;
       $517 = HEAP8[$43>>0]|0;
       $518 = $517&255;
       $519 = (79212 + ($518<<2)|0);
       $520 = HEAP32[$519>>2]|0;
       $521 = HEAP32[$48>>2]|0;
       $522 = $521 & $483;
       $523 = HEAP8[$44>>0]|0;
       $524 = $523&255;
       $525 = $522 >>> $524;
       $526 = (($520) + ($525)|0);
       $527 = HEAP8[$526>>0]|0;
       $$1851$shrunk = $494;$$1855$shrunk = $505;$$1859$shrunk = $516;$$1863$shrunk = $527;
       break;
      }
      case 3:  {
       $528 = HEAP8[$38>>0]|0;
       $div889 = ($528&255) >>> 3;
       $529 = $div889&255;
       $530 = (($$2831) + ($529)|0);
       $531 = HEAP8[$530>>0]|0;
       $532 = HEAP8[$40>>0]|0;
       $div890 = ($532&255) >>> 3;
       $533 = $div890&255;
       $534 = (($$2831) + ($533)|0);
       $535 = HEAP8[$534>>0]|0;
       $536 = HEAP8[$42>>0]|0;
       $div891 = ($536&255) >>> 3;
       $537 = $div891&255;
       $538 = (($$2831) + ($537)|0);
       $539 = HEAP8[$538>>0]|0;
       $$1851$shrunk = $531;$$1855$shrunk = $535;$$1859$shrunk = $539;$$1863$shrunk = -1;
       break;
      }
      case 4:  {
       $540 = HEAP32[$$2831>>2]|0;
       $541 = HEAP8[$37>>0]|0;
       $542 = $541&255;
       $543 = (79212 + ($542<<2)|0);
       $544 = HEAP32[$543>>2]|0;
       $545 = HEAP32[$45>>2]|0;
       $546 = $545 & $540;
       $547 = HEAP8[$38>>0]|0;
       $548 = $547&255;
       $549 = $546 >>> $548;
       $550 = (($544) + ($549)|0);
       $551 = HEAP8[$550>>0]|0;
       $552 = HEAP8[$39>>0]|0;
       $553 = $552&255;
       $554 = (79212 + ($553<<2)|0);
       $555 = HEAP32[$554>>2]|0;
       $556 = HEAP32[$46>>2]|0;
       $557 = $556 & $540;
       $558 = HEAP8[$40>>0]|0;
       $559 = $558&255;
       $560 = $557 >>> $559;
       $561 = (($555) + ($560)|0);
       $562 = HEAP8[$561>>0]|0;
       $563 = HEAP8[$41>>0]|0;
       $564 = $563&255;
       $565 = (79212 + ($564<<2)|0);
       $566 = HEAP32[$565>>2]|0;
       $567 = HEAP32[$47>>2]|0;
       $568 = $567 & $540;
       $569 = HEAP8[$42>>0]|0;
       $570 = $569&255;
       $571 = $568 >>> $570;
       $572 = (($566) + ($571)|0);
       $573 = HEAP8[$572>>0]|0;
       $574 = HEAP8[$43>>0]|0;
       $575 = $574&255;
       $576 = (79212 + ($575<<2)|0);
       $577 = HEAP32[$576>>2]|0;
       $578 = HEAP32[$48>>2]|0;
       $579 = $578 & $540;
       $580 = HEAP8[$44>>0]|0;
       $581 = $580&255;
       $582 = $579 >>> $581;
       $583 = (($577) + ($582)|0);
       $584 = HEAP8[$583>>0]|0;
       $$1851$shrunk = $551;$$1855$shrunk = $562;$$1859$shrunk = $573;$$1863$shrunk = $584;
       break;
      }
      default: {
       $$1851$shrunk = 0;$$1855$shrunk = 0;$$1859$shrunk = 0;$$1863$shrunk = 0;
      }
      }
      $$1851 = $$1851$shrunk&255;
      $$1855 = $$1855$shrunk&255;
      $$1859 = $$1859$shrunk&255;
      $$1863 = $$1863$shrunk&255;
      $585 = (($$1835940) - ($$1851))|0;
      $586 = Math_imul($585, $$1847943)|0;
      $587 = (($586>>>0) / 255)&-1;
      $588 = (($587) + ($$1851))|0;
      $589 = (($$1839941) - ($$1855))|0;
      $590 = Math_imul($589, $$1847943)|0;
      $591 = (($590>>>0) / 255)&-1;
      $592 = (($591) + ($$1855))|0;
      $593 = (($$1843942) - ($$1859))|0;
      $594 = Math_imul($593, $$1847943)|0;
      $595 = (($594>>>0) / 255)&-1;
      $596 = (($595) + ($$1859))|0;
      $597 = (($$1863) + ($$1847943))|0;
      $598 = Math_imul($$1863, $$1847943)|0;
      $599 = (($598>>>0) / 255)&-1;
      $600 = (($597) - ($599))|0;
      switch ($17<<24>>24) {
      case 1:  {
       $601 = HEAP8[$37>>0]|0;
       $602 = $601&255;
       $603 = $588 >>> $602;
       $604 = HEAP8[$38>>0]|0;
       $605 = $604&255;
       $606 = $603 << $605;
       $607 = HEAP8[$39>>0]|0;
       $608 = $607&255;
       $609 = $592 >>> $608;
       $610 = HEAP8[$40>>0]|0;
       $611 = $610&255;
       $612 = $609 << $611;
       $613 = $612 | $606;
       $614 = HEAP8[$41>>0]|0;
       $615 = $614&255;
       $616 = $596 >>> $615;
       $617 = HEAP8[$42>>0]|0;
       $618 = $617&255;
       $619 = $616 << $618;
       $620 = $613 | $619;
       $621 = HEAP8[$43>>0]|0;
       $622 = $621&255;
       $623 = $600 >>> $622;
       $624 = HEAP8[$44>>0]|0;
       $625 = $624&255;
       $626 = $623 << $625;
       $627 = $620 | $626;
       $628 = $627&255;
       HEAP8[$$2831>>0] = $628;
       break L38;
       break;
      }
      case 2:  {
       $629 = HEAP8[$37>>0]|0;
       $630 = $629&255;
       $631 = $588 >>> $630;
       $632 = HEAP8[$38>>0]|0;
       $633 = $632&255;
       $634 = $631 << $633;
       $635 = HEAP8[$39>>0]|0;
       $636 = $635&255;
       $637 = $592 >>> $636;
       $638 = HEAP8[$40>>0]|0;
       $639 = $638&255;
       $640 = $637 << $639;
       $641 = $640 | $634;
       $642 = HEAP8[$41>>0]|0;
       $643 = $642&255;
       $644 = $596 >>> $643;
       $645 = HEAP8[$42>>0]|0;
       $646 = $645&255;
       $647 = $644 << $646;
       $648 = $641 | $647;
       $649 = HEAP8[$43>>0]|0;
       $650 = $649&255;
       $651 = $600 >>> $650;
       $652 = HEAP8[$44>>0]|0;
       $653 = $652&255;
       $654 = $651 << $653;
       $655 = $648 | $654;
       $656 = $655&65535;
       HEAP16[$$2831>>1] = $656;
       break L38;
       break;
      }
      case 3:  {
       $657 = $588&255;
       $658 = HEAP8[$38>>0]|0;
       $div886 = ($658&255) >>> 3;
       $659 = $div886&255;
       $660 = (($$2831) + ($659)|0);
       HEAP8[$660>>0] = $657;
       $661 = $592&255;
       $662 = HEAP8[$40>>0]|0;
       $div887 = ($662&255) >>> 3;
       $663 = $div887&255;
       $664 = (($$2831) + ($663)|0);
       HEAP8[$664>>0] = $661;
       $665 = $596&255;
       $666 = HEAP8[$42>>0]|0;
       $div888 = ($666&255) >>> 3;
       $667 = $div888&255;
       $668 = (($$2831) + ($667)|0);
       HEAP8[$668>>0] = $665;
       break L38;
       break;
      }
      case 4:  {
       $669 = HEAP8[$37>>0]|0;
       $670 = $669&255;
       $671 = $588 >>> $670;
       $672 = HEAP8[$38>>0]|0;
       $673 = $672&255;
       $674 = $671 << $673;
       $675 = HEAP8[$39>>0]|0;
       $676 = $675&255;
       $677 = $592 >>> $676;
       $678 = HEAP8[$40>>0]|0;
       $679 = $678&255;
       $680 = $677 << $679;
       $681 = $680 | $674;
       $682 = HEAP8[$41>>0]|0;
       $683 = $682&255;
       $684 = $596 >>> $683;
       $685 = HEAP8[$42>>0]|0;
       $686 = $685&255;
       $687 = $684 << $686;
       $688 = $681 | $687;
       $689 = HEAP8[$43>>0]|0;
       $690 = $689&255;
       $691 = $600 >>> $690;
       $692 = HEAP8[$44>>0]|0;
       $693 = $692&255;
       $694 = $691 << $693;
       $695 = $688 | $694;
       HEAP32[$$2831>>2] = $695;
       break L38;
       break;
      }
      default: {
       break L38;
      }
      }
     }
    } while(0);
    $696 = (($$2) + ($15)|0);
    $697 = (($$2831) + ($18)|0);
    $$2868 = $$1867;$$3 = $696;$$3832 = $697;
    label = 38;
    continue;
   }
   else if ((label|0) == 38) {
    label = 0;
    switch ($14<<24>>24) {
    case 1:  {
     $698 = HEAP8[$$3>>0]|0;
     $699 = $698&255;
     $$sink1076 = $699;
     label = 43;
     break;
    }
    case 2:  {
     $700 = HEAP16[$$3>>1]|0;
     $701 = $700&65535;
     $$sink1076 = $701;
     label = 43;
     break;
    }
    case 3:  {
     $702 = HEAP8[$27>>0]|0;
     $div881 = ($702&255) >>> 3;
     $703 = $div881&255;
     $704 = (($$3) + ($703)|0);
     $705 = HEAP8[$704>>0]|0;
     $706 = HEAP8[$30>>0]|0;
     $div882 = ($706&255) >>> 3;
     $707 = $div882&255;
     $708 = (($$3) + ($707)|0);
     $709 = HEAP8[$708>>0]|0;
     $710 = HEAP8[$33>>0]|0;
     $div883 = ($710&255) >>> 3;
     $711 = $div883&255;
     $712 = (($$3) + ($711)|0);
     $713 = HEAP8[$712>>0]|0;
     $$2836950 = $705&255;
     $$2840951 = $709&255;
     $$2844952 = $713&255;
     $$2836954 = $$2836950;$$2840955 = $$2840951;$$2844956 = $$2844952;$$2848957 = 255;
     label = 44;
     break;
    }
    case 4:  {
     $714 = HEAP32[$$3>>2]|0;
     $$sink1076 = $714;
     label = 43;
     break;
    }
    default: {
    }
    }
    if ((label|0) == 43) {
     label = 0;
     $715 = HEAP8[$25>>0]|0;
     $716 = $715&255;
     $717 = (79212 + ($716<<2)|0);
     $718 = HEAP32[$717>>2]|0;
     $719 = HEAP32[$26>>2]|0;
     $720 = $719 & $$sink1076;
     $721 = HEAP8[$27>>0]|0;
     $722 = $721&255;
     $723 = $720 >>> $722;
     $724 = (($718) + ($723)|0);
     $725 = HEAP8[$724>>0]|0;
     $726 = HEAP8[$28>>0]|0;
     $727 = $726&255;
     $728 = (79212 + ($727<<2)|0);
     $729 = HEAP32[$728>>2]|0;
     $730 = HEAP32[$29>>2]|0;
     $731 = $730 & $$sink1076;
     $732 = HEAP8[$30>>0]|0;
     $733 = $732&255;
     $734 = $731 >>> $733;
     $735 = (($729) + ($734)|0);
     $736 = HEAP8[$735>>0]|0;
     $737 = HEAP8[$31>>0]|0;
     $738 = $737&255;
     $739 = (79212 + ($738<<2)|0);
     $740 = HEAP32[$739>>2]|0;
     $741 = HEAP32[$32>>2]|0;
     $742 = $741 & $$sink1076;
     $743 = HEAP8[$33>>0]|0;
     $744 = $743&255;
     $745 = $742 >>> $744;
     $746 = (($740) + ($745)|0);
     $747 = HEAP8[$746>>0]|0;
     $748 = HEAP8[$34>>0]|0;
     $749 = $748&255;
     $750 = (79212 + ($749<<2)|0);
     $751 = HEAP32[$750>>2]|0;
     $752 = HEAP32[$35>>2]|0;
     $753 = $752 & $$sink1076;
     $754 = HEAP8[$36>>0]|0;
     $755 = $754&255;
     $756 = $753 >>> $755;
     $757 = (($751) + ($756)|0);
     $758 = HEAP8[$757>>0]|0;
     $$2836 = $725&255;
     $$2840 = $736&255;
     $$2844 = $747&255;
     $$2848 = $758&255;
     $759 = ($758<<24>>24)==(0);
     if (!($759)) {
      $$2836954 = $$2836;$$2840955 = $$2840;$$2844956 = $$2844;$$2848957 = $$2848;
      label = 44;
     }
    }
    L60: do {
     if ((label|0) == 44) {
      label = 0;
      switch ($17<<24>>24) {
      case 1:  {
       $760 = HEAP8[$$3832>>0]|0;
       $761 = $760&255;
       $762 = HEAP8[$37>>0]|0;
       $763 = $762&255;
       $764 = (79212 + ($763<<2)|0);
       $765 = HEAP32[$764>>2]|0;
       $766 = HEAP32[$45>>2]|0;
       $767 = $766 & $761;
       $768 = HEAP8[$38>>0]|0;
       $769 = $768&255;
       $770 = $767 >>> $769;
       $771 = (($765) + ($770)|0);
       $772 = HEAP8[$771>>0]|0;
       $773 = HEAP8[$39>>0]|0;
       $774 = $773&255;
       $775 = (79212 + ($774<<2)|0);
       $776 = HEAP32[$775>>2]|0;
       $777 = HEAP32[$46>>2]|0;
       $778 = $777 & $761;
       $779 = HEAP8[$40>>0]|0;
       $780 = $779&255;
       $781 = $778 >>> $780;
       $782 = (($776) + ($781)|0);
       $783 = HEAP8[$782>>0]|0;
       $784 = HEAP8[$41>>0]|0;
       $785 = $784&255;
       $786 = (79212 + ($785<<2)|0);
       $787 = HEAP32[$786>>2]|0;
       $788 = HEAP32[$47>>2]|0;
       $789 = $788 & $761;
       $790 = HEAP8[$42>>0]|0;
       $791 = $790&255;
       $792 = $789 >>> $791;
       $793 = (($787) + ($792)|0);
       $794 = HEAP8[$793>>0]|0;
       $795 = HEAP8[$43>>0]|0;
       $796 = $795&255;
       $797 = (79212 + ($796<<2)|0);
       $798 = HEAP32[$797>>2]|0;
       $799 = HEAP32[$48>>2]|0;
       $800 = $799 & $761;
       $801 = HEAP8[$44>>0]|0;
       $802 = $801&255;
       $803 = $800 >>> $802;
       $804 = (($798) + ($803)|0);
       $805 = HEAP8[$804>>0]|0;
       $$2852$shrunk = $772;$$2856$shrunk = $783;$$2860$shrunk = $794;$$2864$shrunk = $805;
       break;
      }
      case 2:  {
       $806 = HEAP16[$$3832>>1]|0;
       $807 = $806&65535;
       $808 = HEAP8[$37>>0]|0;
       $809 = $808&255;
       $810 = (79212 + ($809<<2)|0);
       $811 = HEAP32[$810>>2]|0;
       $812 = HEAP32[$45>>2]|0;
       $813 = $812 & $807;
       $814 = HEAP8[$38>>0]|0;
       $815 = $814&255;
       $816 = $813 >>> $815;
       $817 = (($811) + ($816)|0);
       $818 = HEAP8[$817>>0]|0;
       $819 = HEAP8[$39>>0]|0;
       $820 = $819&255;
       $821 = (79212 + ($820<<2)|0);
       $822 = HEAP32[$821>>2]|0;
       $823 = HEAP32[$46>>2]|0;
       $824 = $823 & $807;
       $825 = HEAP8[$40>>0]|0;
       $826 = $825&255;
       $827 = $824 >>> $826;
       $828 = (($822) + ($827)|0);
       $829 = HEAP8[$828>>0]|0;
       $830 = HEAP8[$41>>0]|0;
       $831 = $830&255;
       $832 = (79212 + ($831<<2)|0);
       $833 = HEAP32[$832>>2]|0;
       $834 = HEAP32[$47>>2]|0;
       $835 = $834 & $807;
       $836 = HEAP8[$42>>0]|0;
       $837 = $836&255;
       $838 = $835 >>> $837;
       $839 = (($833) + ($838)|0);
       $840 = HEAP8[$839>>0]|0;
       $841 = HEAP8[$43>>0]|0;
       $842 = $841&255;
       $843 = (79212 + ($842<<2)|0);
       $844 = HEAP32[$843>>2]|0;
       $845 = HEAP32[$48>>2]|0;
       $846 = $845 & $807;
       $847 = HEAP8[$44>>0]|0;
       $848 = $847&255;
       $849 = $846 >>> $848;
       $850 = (($844) + ($849)|0);
       $851 = HEAP8[$850>>0]|0;
       $$2852$shrunk = $818;$$2856$shrunk = $829;$$2860$shrunk = $840;$$2864$shrunk = $851;
       break;
      }
      case 3:  {
       $852 = HEAP8[$38>>0]|0;
       $div878 = ($852&255) >>> 3;
       $853 = $div878&255;
       $854 = (($$3832) + ($853)|0);
       $855 = HEAP8[$854>>0]|0;
       $856 = HEAP8[$40>>0]|0;
       $div879 = ($856&255) >>> 3;
       $857 = $div879&255;
       $858 = (($$3832) + ($857)|0);
       $859 = HEAP8[$858>>0]|0;
       $860 = HEAP8[$42>>0]|0;
       $div880 = ($860&255) >>> 3;
       $861 = $div880&255;
       $862 = (($$3832) + ($861)|0);
       $863 = HEAP8[$862>>0]|0;
       $$2852$shrunk = $855;$$2856$shrunk = $859;$$2860$shrunk = $863;$$2864$shrunk = -1;
       break;
      }
      case 4:  {
       $864 = HEAP32[$$3832>>2]|0;
       $865 = HEAP8[$37>>0]|0;
       $866 = $865&255;
       $867 = (79212 + ($866<<2)|0);
       $868 = HEAP32[$867>>2]|0;
       $869 = HEAP32[$45>>2]|0;
       $870 = $869 & $864;
       $871 = HEAP8[$38>>0]|0;
       $872 = $871&255;
       $873 = $870 >>> $872;
       $874 = (($868) + ($873)|0);
       $875 = HEAP8[$874>>0]|0;
       $876 = HEAP8[$39>>0]|0;
       $877 = $876&255;
       $878 = (79212 + ($877<<2)|0);
       $879 = HEAP32[$878>>2]|0;
       $880 = HEAP32[$46>>2]|0;
       $881 = $880 & $864;
       $882 = HEAP8[$40>>0]|0;
       $883 = $882&255;
       $884 = $881 >>> $883;
       $885 = (($879) + ($884)|0);
       $886 = HEAP8[$885>>0]|0;
       $887 = HEAP8[$41>>0]|0;
       $888 = $887&255;
       $889 = (79212 + ($888<<2)|0);
       $890 = HEAP32[$889>>2]|0;
       $891 = HEAP32[$47>>2]|0;
       $892 = $891 & $864;
       $893 = HEAP8[$42>>0]|0;
       $894 = $893&255;
       $895 = $892 >>> $894;
       $896 = (($890) + ($895)|0);
       $897 = HEAP8[$896>>0]|0;
       $898 = HEAP8[$43>>0]|0;
       $899 = $898&255;
       $900 = (79212 + ($899<<2)|0);
       $901 = HEAP32[$900>>2]|0;
       $902 = HEAP32[$48>>2]|0;
       $903 = $902 & $864;
       $904 = HEAP8[$44>>0]|0;
       $905 = $904&255;
       $906 = $903 >>> $905;
       $907 = (($901) + ($906)|0);
       $908 = HEAP8[$907>>0]|0;
       $$2852$shrunk = $875;$$2856$shrunk = $886;$$2860$shrunk = $897;$$2864$shrunk = $908;
       break;
      }
      default: {
       $$2852$shrunk = 0;$$2856$shrunk = 0;$$2860$shrunk = 0;$$2864$shrunk = 0;
      }
      }
      $$2852 = $$2852$shrunk&255;
      $$2856 = $$2856$shrunk&255;
      $$2860 = $$2860$shrunk&255;
      $$2864 = $$2864$shrunk&255;
      $909 = (($$2836954) - ($$2852))|0;
      $910 = Math_imul($909, $$2848957)|0;
      $911 = (($910>>>0) / 255)&-1;
      $912 = (($911) + ($$2852))|0;
      $913 = (($$2840955) - ($$2856))|0;
      $914 = Math_imul($913, $$2848957)|0;
      $915 = (($914>>>0) / 255)&-1;
      $916 = (($915) + ($$2856))|0;
      $917 = (($$2844956) - ($$2860))|0;
      $918 = Math_imul($917, $$2848957)|0;
      $919 = (($918>>>0) / 255)&-1;
      $920 = (($919) + ($$2860))|0;
      $921 = (($$2864) + ($$2848957))|0;
      $922 = Math_imul($$2864, $$2848957)|0;
      $923 = (($922>>>0) / 255)&-1;
      $924 = (($921) - ($923))|0;
      switch ($17<<24>>24) {
      case 1:  {
       $925 = HEAP8[$37>>0]|0;
       $926 = $925&255;
       $927 = $912 >>> $926;
       $928 = HEAP8[$38>>0]|0;
       $929 = $928&255;
       $930 = $927 << $929;
       $931 = HEAP8[$39>>0]|0;
       $932 = $931&255;
       $933 = $916 >>> $932;
       $934 = HEAP8[$40>>0]|0;
       $935 = $934&255;
       $936 = $933 << $935;
       $937 = $936 | $930;
       $938 = HEAP8[$41>>0]|0;
       $939 = $938&255;
       $940 = $920 >>> $939;
       $941 = HEAP8[$42>>0]|0;
       $942 = $941&255;
       $943 = $940 << $942;
       $944 = $937 | $943;
       $945 = HEAP8[$43>>0]|0;
       $946 = $945&255;
       $947 = $924 >>> $946;
       $948 = HEAP8[$44>>0]|0;
       $949 = $948&255;
       $950 = $947 << $949;
       $951 = $944 | $950;
       $952 = $951&255;
       HEAP8[$$3832>>0] = $952;
       break L60;
       break;
      }
      case 2:  {
       $953 = HEAP8[$37>>0]|0;
       $954 = $953&255;
       $955 = $912 >>> $954;
       $956 = HEAP8[$38>>0]|0;
       $957 = $956&255;
       $958 = $955 << $957;
       $959 = HEAP8[$39>>0]|0;
       $960 = $959&255;
       $961 = $916 >>> $960;
       $962 = HEAP8[$40>>0]|0;
       $963 = $962&255;
       $964 = $961 << $963;
       $965 = $964 | $958;
       $966 = HEAP8[$41>>0]|0;
       $967 = $966&255;
       $968 = $920 >>> $967;
       $969 = HEAP8[$42>>0]|0;
       $970 = $969&255;
       $971 = $968 << $970;
       $972 = $965 | $971;
       $973 = HEAP8[$43>>0]|0;
       $974 = $973&255;
       $975 = $924 >>> $974;
       $976 = HEAP8[$44>>0]|0;
       $977 = $976&255;
       $978 = $975 << $977;
       $979 = $972 | $978;
       $980 = $979&65535;
       HEAP16[$$3832>>1] = $980;
       break L60;
       break;
      }
      case 3:  {
       $981 = $912&255;
       $982 = HEAP8[$38>>0]|0;
       $div = ($982&255) >>> 3;
       $983 = $div&255;
       $984 = (($$3832) + ($983)|0);
       HEAP8[$984>>0] = $981;
       $985 = $916&255;
       $986 = HEAP8[$40>>0]|0;
       $div876 = ($986&255) >>> 3;
       $987 = $div876&255;
       $988 = (($$3832) + ($987)|0);
       HEAP8[$988>>0] = $985;
       $989 = $920&255;
       $990 = HEAP8[$42>>0]|0;
       $div877 = ($990&255) >>> 3;
       $991 = $div877&255;
       $992 = (($$3832) + ($991)|0);
       HEAP8[$992>>0] = $989;
       break L60;
       break;
      }
      case 4:  {
       $993 = HEAP8[$37>>0]|0;
       $994 = $993&255;
       $995 = $912 >>> $994;
       $996 = HEAP8[$38>>0]|0;
       $997 = $996&255;
       $998 = $995 << $997;
       $999 = HEAP8[$39>>0]|0;
       $1000 = $999&255;
       $1001 = $916 >>> $1000;
       $1002 = HEAP8[$40>>0]|0;
       $1003 = $1002&255;
       $1004 = $1001 << $1003;
       $1005 = $1004 | $998;
       $1006 = HEAP8[$41>>0]|0;
       $1007 = $1006&255;
       $1008 = $920 >>> $1007;
       $1009 = HEAP8[$42>>0]|0;
       $1010 = $1009&255;
       $1011 = $1008 << $1010;
       $1012 = $1005 | $1011;
       $1013 = HEAP8[$43>>0]|0;
       $1014 = $1013&255;
       $1015 = $924 >>> $1014;
       $1016 = HEAP8[$44>>0]|0;
       $1017 = $1016&255;
       $1018 = $1015 << $1017;
       $1019 = $1012 | $1018;
       HEAP32[$$3832>>2] = $1019;
       break L60;
       break;
      }
      default: {
       break L60;
      }
      }
     }
    } while(0);
    $1020 = (($$3) + ($15)|0);
    $1021 = (($$3832) + ($18)|0);
    $$3869 = $$2868;$$4 = $1020;$$4833 = $1021;
    label = 55;
    continue;
   }
   else if ((label|0) == 55) {
    label = 0;
    switch ($14<<24>>24) {
    case 1:  {
     $1022 = HEAP8[$$4>>0]|0;
     $1023 = $1022&255;
     $$sink1112 = $1023;
     label = 60;
     break;
    }
    case 2:  {
     $1024 = HEAP16[$$4>>1]|0;
     $1025 = $1024&65535;
     $$sink1112 = $1025;
     label = 60;
     break;
    }
    case 3:  {
     $1026 = HEAP8[$27>>0]|0;
     $div914 = ($1026&255) >>> 3;
     $1027 = $div914&255;
     $1028 = (($$4) + ($1027)|0);
     $1029 = HEAP8[$1028>>0]|0;
     $1030 = HEAP8[$30>>0]|0;
     $div915 = ($1030&255) >>> 3;
     $1031 = $div915&255;
     $1032 = (($$4) + ($1031)|0);
     $1033 = HEAP8[$1032>>0]|0;
     $1034 = HEAP8[$33>>0]|0;
     $div916 = ($1034&255) >>> 3;
     $1035 = $div916&255;
     $1036 = (($$4) + ($1035)|0);
     $1037 = HEAP8[$1036>>0]|0;
     $$3837964 = $1029&255;
     $$3841965 = $1033&255;
     $$3845966 = $1037&255;
     $$3837968 = $$3837964;$$3841969 = $$3841965;$$3845970 = $$3845966;$$3849971 = 255;
     label = 61;
     break;
    }
    case 4:  {
     $1038 = HEAP32[$$4>>2]|0;
     $$sink1112 = $1038;
     label = 60;
     break;
    }
    default: {
    }
    }
    if ((label|0) == 60) {
     label = 0;
     $1039 = HEAP8[$25>>0]|0;
     $1040 = $1039&255;
     $1041 = (79212 + ($1040<<2)|0);
     $1042 = HEAP32[$1041>>2]|0;
     $1043 = HEAP32[$26>>2]|0;
     $1044 = $1043 & $$sink1112;
     $1045 = HEAP8[$27>>0]|0;
     $1046 = $1045&255;
     $1047 = $1044 >>> $1046;
     $1048 = (($1042) + ($1047)|0);
     $1049 = HEAP8[$1048>>0]|0;
     $1050 = HEAP8[$28>>0]|0;
     $1051 = $1050&255;
     $1052 = (79212 + ($1051<<2)|0);
     $1053 = HEAP32[$1052>>2]|0;
     $1054 = HEAP32[$29>>2]|0;
     $1055 = $1054 & $$sink1112;
     $1056 = HEAP8[$30>>0]|0;
     $1057 = $1056&255;
     $1058 = $1055 >>> $1057;
     $1059 = (($1053) + ($1058)|0);
     $1060 = HEAP8[$1059>>0]|0;
     $1061 = HEAP8[$31>>0]|0;
     $1062 = $1061&255;
     $1063 = (79212 + ($1062<<2)|0);
     $1064 = HEAP32[$1063>>2]|0;
     $1065 = HEAP32[$32>>2]|0;
     $1066 = $1065 & $$sink1112;
     $1067 = HEAP8[$33>>0]|0;
     $1068 = $1067&255;
     $1069 = $1066 >>> $1068;
     $1070 = (($1064) + ($1069)|0);
     $1071 = HEAP8[$1070>>0]|0;
     $1072 = HEAP8[$34>>0]|0;
     $1073 = $1072&255;
     $1074 = (79212 + ($1073<<2)|0);
     $1075 = HEAP32[$1074>>2]|0;
     $1076 = HEAP32[$35>>2]|0;
     $1077 = $1076 & $$sink1112;
     $1078 = HEAP8[$36>>0]|0;
     $1079 = $1078&255;
     $1080 = $1077 >>> $1079;
     $1081 = (($1075) + ($1080)|0);
     $1082 = HEAP8[$1081>>0]|0;
     $$3837 = $1049&255;
     $$3841 = $1060&255;
     $$3845 = $1071&255;
     $$3849 = $1082&255;
     $1083 = ($1082<<24>>24)==(0);
     if (!($1083)) {
      $$3837968 = $$3837;$$3841969 = $$3841;$$3845970 = $$3845;$$3849971 = $$3849;
      label = 61;
     }
    }
    L82: do {
     if ((label|0) == 61) {
      label = 0;
      switch ($17<<24>>24) {
      case 1:  {
       $1084 = HEAP8[$$4833>>0]|0;
       $1085 = $1084&255;
       $1086 = HEAP8[$37>>0]|0;
       $1087 = $1086&255;
       $1088 = (79212 + ($1087<<2)|0);
       $1089 = HEAP32[$1088>>2]|0;
       $1090 = HEAP32[$45>>2]|0;
       $1091 = $1090 & $1085;
       $1092 = HEAP8[$38>>0]|0;
       $1093 = $1092&255;
       $1094 = $1091 >>> $1093;
       $1095 = (($1089) + ($1094)|0);
       $1096 = HEAP8[$1095>>0]|0;
       $1097 = HEAP8[$39>>0]|0;
       $1098 = $1097&255;
       $1099 = (79212 + ($1098<<2)|0);
       $1100 = HEAP32[$1099>>2]|0;
       $1101 = HEAP32[$46>>2]|0;
       $1102 = $1101 & $1085;
       $1103 = HEAP8[$40>>0]|0;
       $1104 = $1103&255;
       $1105 = $1102 >>> $1104;
       $1106 = (($1100) + ($1105)|0);
       $1107 = HEAP8[$1106>>0]|0;
       $1108 = HEAP8[$41>>0]|0;
       $1109 = $1108&255;
       $1110 = (79212 + ($1109<<2)|0);
       $1111 = HEAP32[$1110>>2]|0;
       $1112 = HEAP32[$47>>2]|0;
       $1113 = $1112 & $1085;
       $1114 = HEAP8[$42>>0]|0;
       $1115 = $1114&255;
       $1116 = $1113 >>> $1115;
       $1117 = (($1111) + ($1116)|0);
       $1118 = HEAP8[$1117>>0]|0;
       $1119 = HEAP8[$43>>0]|0;
       $1120 = $1119&255;
       $1121 = (79212 + ($1120<<2)|0);
       $1122 = HEAP32[$1121>>2]|0;
       $1123 = HEAP32[$48>>2]|0;
       $1124 = $1123 & $1085;
       $1125 = HEAP8[$44>>0]|0;
       $1126 = $1125&255;
       $1127 = $1124 >>> $1126;
       $1128 = (($1122) + ($1127)|0);
       $1129 = HEAP8[$1128>>0]|0;
       $$3853$shrunk = $1096;$$3857$shrunk = $1107;$$3861$shrunk = $1118;$$3865$shrunk = $1129;
       break;
      }
      case 2:  {
       $1130 = HEAP16[$$4833>>1]|0;
       $1131 = $1130&65535;
       $1132 = HEAP8[$37>>0]|0;
       $1133 = $1132&255;
       $1134 = (79212 + ($1133<<2)|0);
       $1135 = HEAP32[$1134>>2]|0;
       $1136 = HEAP32[$45>>2]|0;
       $1137 = $1136 & $1131;
       $1138 = HEAP8[$38>>0]|0;
       $1139 = $1138&255;
       $1140 = $1137 >>> $1139;
       $1141 = (($1135) + ($1140)|0);
       $1142 = HEAP8[$1141>>0]|0;
       $1143 = HEAP8[$39>>0]|0;
       $1144 = $1143&255;
       $1145 = (79212 + ($1144<<2)|0);
       $1146 = HEAP32[$1145>>2]|0;
       $1147 = HEAP32[$46>>2]|0;
       $1148 = $1147 & $1131;
       $1149 = HEAP8[$40>>0]|0;
       $1150 = $1149&255;
       $1151 = $1148 >>> $1150;
       $1152 = (($1146) + ($1151)|0);
       $1153 = HEAP8[$1152>>0]|0;
       $1154 = HEAP8[$41>>0]|0;
       $1155 = $1154&255;
       $1156 = (79212 + ($1155<<2)|0);
       $1157 = HEAP32[$1156>>2]|0;
       $1158 = HEAP32[$47>>2]|0;
       $1159 = $1158 & $1131;
       $1160 = HEAP8[$42>>0]|0;
       $1161 = $1160&255;
       $1162 = $1159 >>> $1161;
       $1163 = (($1157) + ($1162)|0);
       $1164 = HEAP8[$1163>>0]|0;
       $1165 = HEAP8[$43>>0]|0;
       $1166 = $1165&255;
       $1167 = (79212 + ($1166<<2)|0);
       $1168 = HEAP32[$1167>>2]|0;
       $1169 = HEAP32[$48>>2]|0;
       $1170 = $1169 & $1131;
       $1171 = HEAP8[$44>>0]|0;
       $1172 = $1171&255;
       $1173 = $1170 >>> $1172;
       $1174 = (($1168) + ($1173)|0);
       $1175 = HEAP8[$1174>>0]|0;
       $$3853$shrunk = $1142;$$3857$shrunk = $1153;$$3861$shrunk = $1164;$$3865$shrunk = $1175;
       break;
      }
      case 3:  {
       $1176 = HEAP8[$38>>0]|0;
       $div911 = ($1176&255) >>> 3;
       $1177 = $div911&255;
       $1178 = (($$4833) + ($1177)|0);
       $1179 = HEAP8[$1178>>0]|0;
       $1180 = HEAP8[$40>>0]|0;
       $div912 = ($1180&255) >>> 3;
       $1181 = $div912&255;
       $1182 = (($$4833) + ($1181)|0);
       $1183 = HEAP8[$1182>>0]|0;
       $1184 = HEAP8[$42>>0]|0;
       $div913 = ($1184&255) >>> 3;
       $1185 = $div913&255;
       $1186 = (($$4833) + ($1185)|0);
       $1187 = HEAP8[$1186>>0]|0;
       $$3853$shrunk = $1179;$$3857$shrunk = $1183;$$3861$shrunk = $1187;$$3865$shrunk = -1;
       break;
      }
      case 4:  {
       $1188 = HEAP32[$$4833>>2]|0;
       $1189 = HEAP8[$37>>0]|0;
       $1190 = $1189&255;
       $1191 = (79212 + ($1190<<2)|0);
       $1192 = HEAP32[$1191>>2]|0;
       $1193 = HEAP32[$45>>2]|0;
       $1194 = $1193 & $1188;
       $1195 = HEAP8[$38>>0]|0;
       $1196 = $1195&255;
       $1197 = $1194 >>> $1196;
       $1198 = (($1192) + ($1197)|0);
       $1199 = HEAP8[$1198>>0]|0;
       $1200 = HEAP8[$39>>0]|0;
       $1201 = $1200&255;
       $1202 = (79212 + ($1201<<2)|0);
       $1203 = HEAP32[$1202>>2]|0;
       $1204 = HEAP32[$46>>2]|0;
       $1205 = $1204 & $1188;
       $1206 = HEAP8[$40>>0]|0;
       $1207 = $1206&255;
       $1208 = $1205 >>> $1207;
       $1209 = (($1203) + ($1208)|0);
       $1210 = HEAP8[$1209>>0]|0;
       $1211 = HEAP8[$41>>0]|0;
       $1212 = $1211&255;
       $1213 = (79212 + ($1212<<2)|0);
       $1214 = HEAP32[$1213>>2]|0;
       $1215 = HEAP32[$47>>2]|0;
       $1216 = $1215 & $1188;
       $1217 = HEAP8[$42>>0]|0;
       $1218 = $1217&255;
       $1219 = $1216 >>> $1218;
       $1220 = (($1214) + ($1219)|0);
       $1221 = HEAP8[$1220>>0]|0;
       $1222 = HEAP8[$43>>0]|0;
       $1223 = $1222&255;
       $1224 = (79212 + ($1223<<2)|0);
       $1225 = HEAP32[$1224>>2]|0;
       $1226 = HEAP32[$48>>2]|0;
       $1227 = $1226 & $1188;
       $1228 = HEAP8[$44>>0]|0;
       $1229 = $1228&255;
       $1230 = $1227 >>> $1229;
       $1231 = (($1225) + ($1230)|0);
       $1232 = HEAP8[$1231>>0]|0;
       $$3853$shrunk = $1199;$$3857$shrunk = $1210;$$3861$shrunk = $1221;$$3865$shrunk = $1232;
       break;
      }
      default: {
       $$3853$shrunk = 0;$$3857$shrunk = 0;$$3861$shrunk = 0;$$3865$shrunk = 0;
      }
      }
      $$3853 = $$3853$shrunk&255;
      $$3857 = $$3857$shrunk&255;
      $$3861 = $$3861$shrunk&255;
      $$3865 = $$3865$shrunk&255;
      $1233 = (($$3837968) - ($$3853))|0;
      $1234 = Math_imul($1233, $$3849971)|0;
      $1235 = (($1234>>>0) / 255)&-1;
      $1236 = (($1235) + ($$3853))|0;
      $1237 = (($$3841969) - ($$3857))|0;
      $1238 = Math_imul($1237, $$3849971)|0;
      $1239 = (($1238>>>0) / 255)&-1;
      $1240 = (($1239) + ($$3857))|0;
      $1241 = (($$3845970) - ($$3861))|0;
      $1242 = Math_imul($1241, $$3849971)|0;
      $1243 = (($1242>>>0) / 255)&-1;
      $1244 = (($1243) + ($$3861))|0;
      $1245 = (($$3865) + ($$3849971))|0;
      $1246 = Math_imul($$3865, $$3849971)|0;
      $1247 = (($1246>>>0) / 255)&-1;
      $1248 = (($1245) - ($1247))|0;
      switch ($17<<24>>24) {
      case 1:  {
       $1249 = HEAP8[$37>>0]|0;
       $1250 = $1249&255;
       $1251 = $1236 >>> $1250;
       $1252 = HEAP8[$38>>0]|0;
       $1253 = $1252&255;
       $1254 = $1251 << $1253;
       $1255 = HEAP8[$39>>0]|0;
       $1256 = $1255&255;
       $1257 = $1240 >>> $1256;
       $1258 = HEAP8[$40>>0]|0;
       $1259 = $1258&255;
       $1260 = $1257 << $1259;
       $1261 = $1260 | $1254;
       $1262 = HEAP8[$41>>0]|0;
       $1263 = $1262&255;
       $1264 = $1244 >>> $1263;
       $1265 = HEAP8[$42>>0]|0;
       $1266 = $1265&255;
       $1267 = $1264 << $1266;
       $1268 = $1261 | $1267;
       $1269 = HEAP8[$43>>0]|0;
       $1270 = $1269&255;
       $1271 = $1248 >>> $1270;
       $1272 = HEAP8[$44>>0]|0;
       $1273 = $1272&255;
       $1274 = $1271 << $1273;
       $1275 = $1268 | $1274;
       $1276 = $1275&255;
       HEAP8[$$4833>>0] = $1276;
       break L82;
       break;
      }
      case 2:  {
       $1277 = HEAP8[$37>>0]|0;
       $1278 = $1277&255;
       $1279 = $1236 >>> $1278;
       $1280 = HEAP8[$38>>0]|0;
       $1281 = $1280&255;
       $1282 = $1279 << $1281;
       $1283 = HEAP8[$39>>0]|0;
       $1284 = $1283&255;
       $1285 = $1240 >>> $1284;
       $1286 = HEAP8[$40>>0]|0;
       $1287 = $1286&255;
       $1288 = $1285 << $1287;
       $1289 = $1288 | $1282;
       $1290 = HEAP8[$41>>0]|0;
       $1291 = $1290&255;
       $1292 = $1244 >>> $1291;
       $1293 = HEAP8[$42>>0]|0;
       $1294 = $1293&255;
       $1295 = $1292 << $1294;
       $1296 = $1289 | $1295;
       $1297 = HEAP8[$43>>0]|0;
       $1298 = $1297&255;
       $1299 = $1248 >>> $1298;
       $1300 = HEAP8[$44>>0]|0;
       $1301 = $1300&255;
       $1302 = $1299 << $1301;
       $1303 = $1296 | $1302;
       $1304 = $1303&65535;
       HEAP16[$$4833>>1] = $1304;
       break L82;
       break;
      }
      case 3:  {
       $1305 = $1236&255;
       $1306 = HEAP8[$38>>0]|0;
       $div908 = ($1306&255) >>> 3;
       $1307 = $div908&255;
       $1308 = (($$4833) + ($1307)|0);
       HEAP8[$1308>>0] = $1305;
       $1309 = $1240&255;
       $1310 = HEAP8[$40>>0]|0;
       $div909 = ($1310&255) >>> 3;
       $1311 = $div909&255;
       $1312 = (($$4833) + ($1311)|0);
       HEAP8[$1312>>0] = $1309;
       $1313 = $1244&255;
       $1314 = HEAP8[$42>>0]|0;
       $div910 = ($1314&255) >>> 3;
       $1315 = $div910&255;
       $1316 = (($$4833) + ($1315)|0);
       HEAP8[$1316>>0] = $1313;
       break L82;
       break;
      }
      case 4:  {
       $1317 = HEAP8[$37>>0]|0;
       $1318 = $1317&255;
       $1319 = $1236 >>> $1318;
       $1320 = HEAP8[$38>>0]|0;
       $1321 = $1320&255;
       $1322 = $1319 << $1321;
       $1323 = HEAP8[$39>>0]|0;
       $1324 = $1323&255;
       $1325 = $1240 >>> $1324;
       $1326 = HEAP8[$40>>0]|0;
       $1327 = $1326&255;
       $1328 = $1325 << $1327;
       $1329 = $1328 | $1322;
       $1330 = HEAP8[$41>>0]|0;
       $1331 = $1330&255;
       $1332 = $1244 >>> $1331;
       $1333 = HEAP8[$42>>0]|0;
       $1334 = $1333&255;
       $1335 = $1332 << $1334;
       $1336 = $1329 | $1335;
       $1337 = HEAP8[$43>>0]|0;
       $1338 = $1337&255;
       $1339 = $1248 >>> $1338;
       $1340 = HEAP8[$44>>0]|0;
       $1341 = $1340&255;
       $1342 = $1339 << $1341;
       $1343 = $1336 | $1342;
       HEAP32[$$4833>>2] = $1343;
       break L82;
       break;
      }
      default: {
       break L82;
      }
      }
     }
    } while(0);
    $1344 = (($$4) + ($15)|0);
    $1345 = (($$4833) + ($18)|0);
    $1346 = (($$3869) + -1)|0;
    $1347 = ($$3869|0)>(1);
    if ($1347) {
     $$0866 = $1346;$$1 = $1344;$$1830 = $1345;
     label = 4;
     continue;
    } else {
     break;
    }
   }
  }
  $1348 = (($1344) + ($6)|0);
  $1349 = (($1345) + ($8)|0);
  $1350 = ($49|0)==(0);
  if ($1350) {
   label = 74;
   break;
  } else {
   $$08281120 = $1348;$$08291119 = $1349;$$in = $49;
  }
 }
 if ((label|0) == 72) {
  // unreachable;
 }
 else if ((label|0) == 74) {
  return;
 }
}
function _BlitARGBto565PixelAlpha($0) {
 $0 = $0|0;
 var $$0146164 = 0, $$0147163 = 0, $$0152 = 0, $$1 = 0, $$1148 = 0, $$1153 = 0, $$2 = 0, $$2149 = 0, $$2154 = 0, $$3 = 0, $$3150 = 0, $$3155 = 0, $$4 = 0, $$4151 = 0, $$in = 0, $$sink156 = 0, $$sink158 = 0, $$sink160 = 0, $$sink162 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0;
 var $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $trunc = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $6 >> 2;
 $8 = ((($0)) + 36|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $9 >> 1;
 $11 = ($4|0)==(0);
 if ($11) {
  return;
 }
 $12 = ((($0)) + 20|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = HEAP32[$0>>2]|0;
 $15 = (($2) + 3)|0;
 $16 = (($15|0) / 4)&-1;
 $trunc = $2&255;
 $$0146164 = $14;$$0147163 = $13;$$in = $4;
 L4: while(1) {
  $17 = (($$in) + -1)|0;
  $trunc$clear = $trunc & 3;
  switch ($trunc$clear<<24>>24) {
  case 0:  {
   $$0152 = $16;$$1 = $$0146164;$$1148 = $$0147163;
   label = 4;
   break;
  }
  case 3:  {
   $$1153 = $16;$$2 = $$0146164;$$2149 = $$0147163;
   label = 10;
   break;
  }
  case 2:  {
   $$2154 = $16;$$3 = $$0146164;$$3150 = $$0147163;
   label = 16;
   break;
  }
  case 1:  {
   $$3155 = $16;$$4 = $$0146164;$$4151 = $$0147163;
   label = 22;
   break;
  }
  default: {
   label = 28;
   break L4;
  }
  }
  while(1) {
   if ((label|0) == 4) {
    label = 0;
    $18 = HEAP32[$$1>>2]|0;
    $19 = $18 >>> 27;
    $20 = ($19|0)==(0);
    if (!($20)) {
     $21 = ($19|0)==(31);
     $22 = $18 >>> 3;
     $23 = $22 & 31;
     $24 = $18 >>> 8;
     $25 = $24 & 63488;
     if ($21) {
      $26 = $18 >>> 5;
      $27 = $26 & 2016;
      $28 = $25 | $27;
      $29 = $28 | $23;
      $$sink156 = $29;
     } else {
      $30 = HEAP16[$$1148>>1]|0;
      $31 = $30&65535;
      $32 = $18 << 11;
      $33 = $32 & 132120576;
      $34 = $33 | $25;
      $35 = $34 | $23;
      $36 = $31 << 16;
      $37 = $36 | $31;
      $38 = $37 & 132184095;
      $39 = (($35) - ($38))|0;
      $40 = Math_imul($39, $19)|0;
      $41 = $40 >>> 5;
      $42 = (($41) + ($38))|0;
      $43 = $42 & 132184095;
      $44 = $43 >>> 16;
      $45 = $44 | $43;
      $$sink156 = $45;
     }
     $46 = $$sink156&65535;
     HEAP16[$$1148>>1] = $46;
    }
    $47 = ((($$1)) + 4|0);
    $48 = ((($$1148)) + 2|0);
    $$1153 = $$0152;$$2 = $47;$$2149 = $48;
    label = 10;
    continue;
   }
   else if ((label|0) == 10) {
    label = 0;
    $49 = HEAP32[$$2>>2]|0;
    $50 = $49 >>> 27;
    $51 = ($50|0)==(0);
    if (!($51)) {
     $52 = ($50|0)==(31);
     $53 = $49 >>> 8;
     $54 = $49 >>> 3;
     $55 = $53 & 63488;
     $56 = $54 & 31;
     if ($52) {
      $57 = $49 >>> 5;
      $58 = $57 & 2016;
      $59 = $55 | $58;
      $60 = $59 | $56;
      $$sink158 = $60;
     } else {
      $61 = HEAP16[$$2149>>1]|0;
      $62 = $61&65535;
      $63 = $49 << 11;
      $64 = $63 & 132120576;
      $65 = $64 | $55;
      $66 = $65 | $56;
      $67 = $62 << 16;
      $68 = $67 | $62;
      $69 = $68 & 132184095;
      $70 = (($66) - ($69))|0;
      $71 = Math_imul($70, $50)|0;
      $72 = $71 >>> 5;
      $73 = (($72) + ($69))|0;
      $74 = $73 & 132184095;
      $75 = $74 >>> 16;
      $76 = $75 | $74;
      $$sink158 = $76;
     }
     $77 = $$sink158&65535;
     HEAP16[$$2149>>1] = $77;
    }
    $78 = ((($$2)) + 4|0);
    $79 = ((($$2149)) + 2|0);
    $$2154 = $$1153;$$3 = $78;$$3150 = $79;
    label = 16;
    continue;
   }
   else if ((label|0) == 16) {
    label = 0;
    $80 = HEAP32[$$3>>2]|0;
    $81 = $80 >>> 27;
    $82 = ($81|0)==(0);
    if (!($82)) {
     $83 = ($81|0)==(31);
     $84 = $80 >>> 8;
     $85 = $80 >>> 3;
     $86 = $85 & 31;
     $87 = $84 & 63488;
     if ($83) {
      $88 = $80 >>> 5;
      $89 = $88 & 2016;
      $90 = $87 | $89;
      $91 = $90 | $86;
      $$sink160 = $91;
     } else {
      $92 = HEAP16[$$3150>>1]|0;
      $93 = $92&65535;
      $94 = $80 << 11;
      $95 = $94 & 132120576;
      $96 = $95 | $87;
      $97 = $96 | $86;
      $98 = $93 << 16;
      $99 = $98 | $93;
      $100 = $99 & 132184095;
      $101 = (($97) - ($100))|0;
      $102 = Math_imul($101, $81)|0;
      $103 = $102 >>> 5;
      $104 = (($103) + ($100))|0;
      $105 = $104 & 132184095;
      $106 = $105 >>> 16;
      $107 = $106 | $105;
      $$sink160 = $107;
     }
     $108 = $$sink160&65535;
     HEAP16[$$3150>>1] = $108;
    }
    $109 = ((($$3)) + 4|0);
    $110 = ((($$3150)) + 2|0);
    $$3155 = $$2154;$$4 = $109;$$4151 = $110;
    label = 22;
    continue;
   }
   else if ((label|0) == 22) {
    label = 0;
    $111 = HEAP32[$$4>>2]|0;
    $112 = $111 >>> 27;
    $113 = ($112|0)==(0);
    if (!($113)) {
     $114 = ($112|0)==(31);
     $115 = $111 >>> 3;
     $116 = $111 >>> 8;
     $117 = $116 & 63488;
     $118 = $115 & 31;
     if ($114) {
      $119 = $111 >>> 5;
      $120 = $119 & 2016;
      $121 = $117 | $120;
      $122 = $121 | $118;
      $$sink162 = $122;
     } else {
      $123 = HEAP16[$$4151>>1]|0;
      $124 = $123&65535;
      $125 = $111 << 11;
      $126 = $125 & 132120576;
      $127 = $126 | $117;
      $128 = $127 | $118;
      $129 = $124 << 16;
      $130 = $129 | $124;
      $131 = $130 & 132184095;
      $132 = (($128) - ($131))|0;
      $133 = Math_imul($132, $112)|0;
      $134 = $133 >>> 5;
      $135 = (($134) + ($131))|0;
      $136 = $135 & 132184095;
      $137 = $136 >>> 16;
      $138 = $137 | $136;
      $$sink162 = $138;
     }
     $139 = $$sink162&65535;
     HEAP16[$$4151>>1] = $139;
    }
    $140 = ((($$4)) + 4|0);
    $141 = ((($$4151)) + 2|0);
    $142 = (($$3155) + -1)|0;
    $143 = ($$3155|0)>(1);
    if ($143) {
     $$0152 = $142;$$1 = $140;$$1148 = $141;
     label = 4;
     continue;
    } else {
     break;
    }
   }
  }
  $144 = (($140) + ($7<<2)|0);
  $145 = (($141) + ($10<<1)|0);
  $146 = ($17|0)==(0);
  if ($146) {
   label = 30;
   break;
  } else {
   $$0146164 = $144;$$0147163 = $145;$$in = $17;
  }
 }
 if ((label|0) == 28) {
  // unreachable;
 }
 else if ((label|0) == 30) {
  return;
 }
}
function _Blit555to555SurfaceAlpha($0) {
 $0 = $0|0;
 var $$0104115 = 0, $$0104115$us = 0, $$0105114 = 0, $$0105114$us = 0, $$0110$us = 0, $$1$us = 0, $$1106$us = 0, $$1111 = 0, $$2 = 0, $$2107 = 0, $$2112 = 0, $$3 = 0, $$3108 = 0, $$3113 = 0, $$4 = 0, $$4109 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0;
 var $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0;
 var $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0;
 var $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0;
 var $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0;
 var $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0;
 var $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $trunc = 0, $trunc$clear = 0, $trunc$clear1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 63|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(-128);
 if ($3) {
  _Blit16to16SurfaceAlpha128($0,-1058);
  return;
 }
 $4 = $2&255;
 $5 = ((($0)) + 24|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($0)) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$0>>2]|0;
 $10 = ((($0)) + 16|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11 >> 1;
 $13 = ((($0)) + 20|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ((($0)) + 36|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $16 >> 1;
 $18 = $4 >>> 3;
 $19 = (($8) + -1)|0;
 $20 = ($8|0)==(0);
 if ($20) {
  return;
 }
 $21 = (($6) + 3)|0;
 $22 = (($21|0) / 4)&-1;
 $trunc = $6&255;
 $trunc$clear = $trunc & 3;
 $23 = ($trunc$clear<<24>>24)==(0);
 if ($23) {
  $$0104115$us = $9;$$0105114$us = $14;$109 = $19;
  while(1) {
   $$0110$us = $22;$$1$us = $$0104115$us;$$1106$us = $$0105114$us;
   while(1) {
    $24 = ((($$1$us)) + 2|0);
    $25 = HEAP16[$$1$us>>1]|0;
    $26 = $25&65535;
    $27 = HEAP16[$$1106$us>>1]|0;
    $28 = $27&65535;
    $29 = $26 << 16;
    $30 = $29 | $26;
    $31 = $30 & 65043487;
    $32 = $28 << 16;
    $33 = $32 | $28;
    $34 = $33 & 65043487;
    $35 = (($31) - ($34))|0;
    $36 = Math_imul($35, $18)|0;
    $37 = $36 >>> 5;
    $38 = (($37) + ($34))|0;
    $39 = $38 & 65043487;
    $40 = $39 >>> 16;
    $41 = $40 | $39;
    $42 = $41&65535;
    $43 = ((($$1106$us)) + 2|0);
    HEAP16[$$1106$us>>1] = $42;
    $44 = ((($$1$us)) + 4|0);
    $45 = HEAP16[$24>>1]|0;
    $46 = $45&65535;
    $47 = HEAP16[$43>>1]|0;
    $48 = $47&65535;
    $49 = $46 << 16;
    $50 = $49 | $46;
    $51 = $50 & 65043487;
    $52 = $48 << 16;
    $53 = $52 | $48;
    $54 = $53 & 65043487;
    $55 = (($51) - ($54))|0;
    $56 = Math_imul($55, $18)|0;
    $57 = $56 >>> 5;
    $58 = (($57) + ($54))|0;
    $59 = $58 & 65043487;
    $60 = $59 >>> 16;
    $61 = $60 | $59;
    $62 = $61&65535;
    $63 = ((($$1106$us)) + 4|0);
    HEAP16[$43>>1] = $62;
    $64 = ((($$1$us)) + 6|0);
    $65 = HEAP16[$44>>1]|0;
    $66 = $65&65535;
    $67 = HEAP16[$63>>1]|0;
    $68 = $67&65535;
    $69 = $66 << 16;
    $70 = $69 | $66;
    $71 = $70 & 65043487;
    $72 = $68 << 16;
    $73 = $72 | $68;
    $74 = $73 & 65043487;
    $75 = (($71) - ($74))|0;
    $76 = Math_imul($75, $18)|0;
    $77 = $76 >>> 5;
    $78 = (($77) + ($74))|0;
    $79 = $78 & 65043487;
    $80 = $79 >>> 16;
    $81 = $80 | $79;
    $82 = $81&65535;
    $83 = ((($$1106$us)) + 6|0);
    HEAP16[$63>>1] = $82;
    $84 = ((($$1$us)) + 8|0);
    $85 = HEAP16[$64>>1]|0;
    $86 = $85&65535;
    $87 = HEAP16[$83>>1]|0;
    $88 = $87&65535;
    $89 = $86 << 16;
    $90 = $89 | $86;
    $91 = $90 & 65043487;
    $92 = $88 << 16;
    $93 = $92 | $88;
    $94 = $93 & 65043487;
    $95 = (($91) - ($94))|0;
    $96 = Math_imul($95, $18)|0;
    $97 = $96 >>> 5;
    $98 = (($97) + ($94))|0;
    $99 = $98 & 65043487;
    $100 = $99 >>> 16;
    $101 = $100 | $99;
    $102 = $101&65535;
    $103 = ((($$1106$us)) + 8|0);
    HEAP16[$83>>1] = $102;
    $104 = (($$0110$us) + -1)|0;
    $105 = ($$0110$us|0)>(1);
    if ($105) {
     $$0110$us = $104;$$1$us = $84;$$1106$us = $103;
    } else {
     break;
    }
   }
   $106 = (($84) + ($12<<1)|0);
   $107 = (($103) + ($17<<1)|0);
   $108 = (($109) + -1)|0;
   $110 = ($109|0)==(0);
   if ($110) {
    break;
   } else {
    $$0104115$us = $106;$$0105114$us = $107;$109 = $108;
   }
  }
  return;
 } else {
  $$0104115 = $9;$$0105114 = $14;$196 = $19;
 }
 L15: while(1) {
  $trunc$clear1 = $trunc & 3;
  switch ($trunc$clear1<<24>>24) {
  case 1:  {
   $$3113 = $22;$$4 = $$0104115;$$4109 = $$0105114;
   label = 12;
   break;
  }
  case 3:  {
   $$1111 = $22;$$2 = $$0104115;$$2107 = $$0105114;
   label = 10;
   break;
  }
  case 2:  {
   $$2112 = $22;$$3 = $$0104115;$$3108 = $$0105114;
   label = 11;
   break;
  }
  default: {
   label = 13;
   break L15;
  }
  }
  while(1) {
   if ((label|0) == 10) {
    label = 0;
    $134 = ((($$2)) + 2|0);
    $135 = HEAP16[$$2>>1]|0;
    $136 = $135&65535;
    $137 = HEAP16[$$2107>>1]|0;
    $138 = $137&65535;
    $139 = $136 << 16;
    $140 = $139 | $136;
    $141 = $140 & 65043487;
    $142 = $138 << 16;
    $143 = $142 | $138;
    $144 = $143 & 65043487;
    $145 = (($141) - ($144))|0;
    $146 = Math_imul($145, $18)|0;
    $147 = $146 >>> 5;
    $148 = (($147) + ($144))|0;
    $149 = $148 & 65043487;
    $150 = $149 >>> 16;
    $151 = $150 | $149;
    $152 = $151&65535;
    $153 = ((($$2107)) + 2|0);
    HEAP16[$$2107>>1] = $152;
    $$2112 = $$1111;$$3 = $134;$$3108 = $153;
    label = 11;
    continue;
   }
   else if ((label|0) == 11) {
    label = 0;
    $154 = ((($$3)) + 2|0);
    $155 = HEAP16[$$3>>1]|0;
    $156 = $155&65535;
    $157 = HEAP16[$$3108>>1]|0;
    $158 = $157&65535;
    $159 = $156 << 16;
    $160 = $159 | $156;
    $161 = $160 & 65043487;
    $162 = $158 << 16;
    $163 = $162 | $158;
    $164 = $163 & 65043487;
    $165 = (($161) - ($164))|0;
    $166 = Math_imul($165, $18)|0;
    $167 = $166 >>> 5;
    $168 = (($167) + ($164))|0;
    $169 = $168 & 65043487;
    $170 = $169 >>> 16;
    $171 = $170 | $169;
    $172 = $171&65535;
    $173 = ((($$3108)) + 2|0);
    HEAP16[$$3108>>1] = $172;
    $$3113 = $$2112;$$4 = $154;$$4109 = $173;
    label = 12;
    continue;
   }
   else if ((label|0) == 12) {
    label = 0;
    $114 = ((($$4)) + 2|0);
    $174 = HEAP16[$$4>>1]|0;
    $175 = $174&65535;
    $176 = HEAP16[$$4109>>1]|0;
    $177 = $176&65535;
    $178 = $175 << 16;
    $179 = $178 | $175;
    $180 = $179 & 65043487;
    $181 = $177 << 16;
    $182 = $181 | $177;
    $183 = $182 & 65043487;
    $184 = (($180) - ($183))|0;
    $185 = Math_imul($184, $18)|0;
    $186 = $185 >>> 5;
    $187 = (($186) + ($183))|0;
    $188 = $187 & 65043487;
    $189 = $188 >>> 16;
    $190 = $189 | $188;
    $191 = $190&65535;
    $117 = ((($$4109)) + 2|0);
    HEAP16[$$4109>>1] = $191;
    $192 = ($$3113|0)>(1);
    if (!($192)) {
     break;
    }
    $111 = (($$3113) + -1)|0;
    $112 = ((($$4)) + 4|0);
    $113 = HEAP16[$114>>1]|0;
    $115 = $113&65535;
    $116 = HEAP16[$117>>1]|0;
    $118 = $116&65535;
    $119 = $115 << 16;
    $120 = $119 | $115;
    $121 = $120 & 65043487;
    $122 = $118 << 16;
    $123 = $122 | $118;
    $124 = $123 & 65043487;
    $125 = (($121) - ($124))|0;
    $126 = Math_imul($125, $18)|0;
    $127 = $126 >>> 5;
    $128 = (($127) + ($124))|0;
    $129 = $128 & 65043487;
    $130 = $129 >>> 16;
    $131 = $130 | $129;
    $132 = $131&65535;
    $133 = ((($$4109)) + 4|0);
    HEAP16[$117>>1] = $132;
    $$1111 = $111;$$2 = $112;$$2107 = $133;
    label = 10;
    continue;
   }
  }
  $193 = (($114) + ($12<<1)|0);
  $194 = (($117) + ($17<<1)|0);
  $195 = (($196) + -1)|0;
  $197 = ($196|0)==(0);
  if ($197) {
   label = 15;
   break;
  } else {
   $$0104115 = $193;$$0105114 = $194;$196 = $195;
  }
 }
 if ((label|0) == 13) {
  // unreachable;
 }
 else if ((label|0) == 15) {
  return;
 }
}
function _BlitNtoNSurfaceAlpha($0) {
 $0 = $0|0;
 var $$0778873 = 0, $$0779872 = 0, $$0784 = 0, $$0784$shrunk = 0, $$0784$shrunk$ph = 0, $$0784$shrunk$ph$in = 0, $$0788 = 0, $$0788$shrunk = 0, $$0788$shrunk$ph = 0, $$0788$shrunk$ph$in = 0, $$0792 = 0, $$0792$shrunk = 0, $$0796 = 0, $$0796$shrunk = 0, $$0800 = 0, $$0800$shrunk = 0, $$0804 = 0, $$0804$shrunk = 0, $$0808 = 0, $$0808$shrunk = 0;
 var $$0812 = 0, $$1 = 0, $$1780 = 0, $$1785 = 0, $$1785$shrunk = 0, $$1785$shrunk$ph = 0, $$1785$shrunk$ph$in = 0, $$1789 = 0, $$1789$shrunk = 0, $$1789$shrunk$ph = 0, $$1789$shrunk$ph$in = 0, $$1793 = 0, $$1793$shrunk = 0, $$1797 = 0, $$1797$shrunk = 0, $$1801 = 0, $$1801$shrunk = 0, $$1805 = 0, $$1805$shrunk = 0, $$1809 = 0;
 var $$1809$shrunk = 0, $$1813 = 0, $$2 = 0, $$2781 = 0, $$2786 = 0, $$2786$shrunk = 0, $$2786$shrunk$ph = 0, $$2786$shrunk$ph$in = 0, $$2790 = 0, $$2790$shrunk = 0, $$2790$shrunk$ph = 0, $$2790$shrunk$ph$in = 0, $$2794 = 0, $$2794$shrunk = 0, $$2798 = 0, $$2798$shrunk = 0, $$2802 = 0, $$2802$shrunk = 0, $$2806 = 0, $$2806$shrunk = 0;
 var $$2810 = 0, $$2810$shrunk = 0, $$2814 = 0, $$3 = 0, $$3782 = 0, $$3787 = 0, $$3787$shrunk = 0, $$3787$shrunk$ph = 0, $$3787$shrunk$ph$in = 0, $$3791 = 0, $$3791$shrunk = 0, $$3791$shrunk$ph = 0, $$3791$shrunk$ph$in = 0, $$3795 = 0, $$3795$shrunk = 0, $$3799 = 0, $$3799$shrunk = 0, $$3803 = 0, $$3803$shrunk = 0, $$3807 = 0;
 var $$3807$shrunk = 0, $$3811 = 0, $$3811$shrunk = 0, $$3815 = 0, $$4 = 0, $$4783 = 0, $$in = 0, $$sink = 0, $$sink864 = 0, $$sink866 = 0, $$sink868 = 0, $1 = 0, $10 = 0, $100 = 0, $1000 = 0, $1001 = 0, $1002 = 0, $1003 = 0, $1004 = 0, $1005 = 0;
 var $1006 = 0, $1007 = 0, $1008 = 0, $1009 = 0, $101 = 0, $1010 = 0, $1011 = 0, $1012 = 0, $1013 = 0, $1014 = 0, $1015 = 0, $1016 = 0, $1017 = 0, $1018 = 0, $1019 = 0, $102 = 0, $1020 = 0, $1021 = 0, $1022 = 0, $1023 = 0;
 var $1024 = 0, $1025 = 0, $1026 = 0, $1027 = 0, $1028 = 0, $1029 = 0, $103 = 0, $1030 = 0, $1031 = 0, $1032 = 0, $1033 = 0, $1034 = 0, $1035 = 0, $1036 = 0, $1037 = 0, $1038 = 0, $1039 = 0, $104 = 0, $1040 = 0, $1041 = 0;
 var $1042 = 0, $1043 = 0, $1044 = 0, $1045 = 0, $1046 = 0, $1047 = 0, $1048 = 0, $1049 = 0, $105 = 0, $1050 = 0, $1051 = 0, $1052 = 0, $1053 = 0, $1054 = 0, $1055 = 0, $1056 = 0, $1057 = 0, $1058 = 0, $1059 = 0, $106 = 0;
 var $1060 = 0, $1061 = 0, $1062 = 0, $1063 = 0, $1064 = 0, $1065 = 0, $1066 = 0, $1067 = 0, $1068 = 0, $1069 = 0, $107 = 0, $1070 = 0, $1071 = 0, $1072 = 0, $1073 = 0, $1074 = 0, $1075 = 0, $1076 = 0, $1077 = 0, $1078 = 0;
 var $1079 = 0, $108 = 0, $1080 = 0, $1081 = 0, $1082 = 0, $1083 = 0, $1084 = 0, $1085 = 0, $1086 = 0, $1087 = 0, $1088 = 0, $1089 = 0, $109 = 0, $1090 = 0, $1091 = 0, $1092 = 0, $1093 = 0, $1094 = 0, $1095 = 0, $1096 = 0;
 var $1097 = 0, $1098 = 0, $1099 = 0, $11 = 0, $110 = 0, $1100 = 0, $1101 = 0, $1102 = 0, $1103 = 0, $1104 = 0, $1105 = 0, $1106 = 0, $1107 = 0, $1108 = 0, $1109 = 0, $111 = 0, $1110 = 0, $1111 = 0, $1112 = 0, $1113 = 0;
 var $1114 = 0, $1115 = 0, $1116 = 0, $1117 = 0, $1118 = 0, $1119 = 0, $112 = 0, $1120 = 0, $1121 = 0, $1122 = 0, $1123 = 0, $1124 = 0, $1125 = 0, $1126 = 0, $1127 = 0, $1128 = 0, $1129 = 0, $113 = 0, $1130 = 0, $1131 = 0;
 var $1132 = 0, $1133 = 0, $1134 = 0, $1135 = 0, $1136 = 0, $1137 = 0, $1138 = 0, $1139 = 0, $114 = 0, $1140 = 0, $1141 = 0, $1142 = 0, $1143 = 0, $1144 = 0, $1145 = 0, $1146 = 0, $1147 = 0, $1148 = 0, $1149 = 0, $115 = 0;
 var $1150 = 0, $1151 = 0, $1152 = 0, $1153 = 0, $1154 = 0, $1155 = 0, $1156 = 0, $1157 = 0, $1158 = 0, $1159 = 0, $116 = 0, $1160 = 0, $1161 = 0, $1162 = 0, $1163 = 0, $1164 = 0, $1165 = 0, $1166 = 0, $1167 = 0, $1168 = 0;
 var $1169 = 0, $117 = 0, $1170 = 0, $1171 = 0, $1172 = 0, $1173 = 0, $1174 = 0, $1175 = 0, $1176 = 0, $1177 = 0, $1178 = 0, $1179 = 0, $118 = 0, $1180 = 0, $1181 = 0, $1182 = 0, $1183 = 0, $1184 = 0, $1185 = 0, $1186 = 0;
 var $1187 = 0, $1188 = 0, $1189 = 0, $119 = 0, $1190 = 0, $1191 = 0, $1192 = 0, $1193 = 0, $1194 = 0, $1195 = 0, $1196 = 0, $1197 = 0, $1198 = 0, $1199 = 0, $12 = 0, $120 = 0, $1200 = 0, $1201 = 0, $1202 = 0, $1203 = 0;
 var $1204 = 0, $1205 = 0, $1206 = 0, $1207 = 0, $1208 = 0, $1209 = 0, $121 = 0, $1210 = 0, $1211 = 0, $1212 = 0, $1213 = 0, $1214 = 0, $1215 = 0, $1216 = 0, $1217 = 0, $1218 = 0, $1219 = 0, $122 = 0, $1220 = 0, $1221 = 0;
 var $1222 = 0, $1223 = 0, $1224 = 0, $1225 = 0, $1226 = 0, $1227 = 0, $1228 = 0, $1229 = 0, $123 = 0, $1230 = 0, $1231 = 0, $1232 = 0, $1233 = 0, $1234 = 0, $1235 = 0, $1236 = 0, $1237 = 0, $1238 = 0, $1239 = 0, $124 = 0;
 var $1240 = 0, $1241 = 0, $1242 = 0, $1243 = 0, $1244 = 0, $1245 = 0, $1246 = 0, $1247 = 0, $1248 = 0, $1249 = 0, $125 = 0, $1250 = 0, $1251 = 0, $1252 = 0, $1253 = 0, $1254 = 0, $1255 = 0, $1256 = 0, $1257 = 0, $1258 = 0;
 var $1259 = 0, $126 = 0, $1260 = 0, $1261 = 0, $1262 = 0, $1263 = 0, $1264 = 0, $1265 = 0, $1266 = 0, $1267 = 0, $1268 = 0, $1269 = 0, $127 = 0, $1270 = 0, $1271 = 0, $1272 = 0, $1273 = 0, $1274 = 0, $1275 = 0, $1276 = 0;
 var $1277 = 0, $1278 = 0, $1279 = 0, $128 = 0, $1280 = 0, $1281 = 0, $1282 = 0, $1283 = 0, $1284 = 0, $1285 = 0, $1286 = 0, $1287 = 0, $1288 = 0, $1289 = 0, $129 = 0, $1290 = 0, $1291 = 0, $1292 = 0, $1293 = 0, $1294 = 0;
 var $1295 = 0, $1296 = 0, $1297 = 0, $1298 = 0, $1299 = 0, $13 = 0, $130 = 0, $1300 = 0, $1301 = 0, $1302 = 0, $1303 = 0, $1304 = 0, $1305 = 0, $1306 = 0, $1307 = 0, $1308 = 0, $1309 = 0, $131 = 0, $1310 = 0, $1311 = 0;
 var $1312 = 0, $1313 = 0, $1314 = 0, $1315 = 0, $1316 = 0, $1317 = 0, $1318 = 0, $1319 = 0, $132 = 0, $1320 = 0, $1321 = 0, $1322 = 0, $1323 = 0, $1324 = 0, $1325 = 0, $1326 = 0, $1327 = 0, $1328 = 0, $1329 = 0, $133 = 0;
 var $1330 = 0, $1331 = 0, $1332 = 0, $1333 = 0, $1334 = 0, $1335 = 0, $1336 = 0, $1337 = 0, $1338 = 0, $1339 = 0, $134 = 0, $1340 = 0, $1341 = 0, $1342 = 0, $1343 = 0, $1344 = 0, $1345 = 0, $1346 = 0, $1347 = 0, $1348 = 0;
 var $1349 = 0, $135 = 0, $1350 = 0, $1351 = 0, $1352 = 0, $1353 = 0, $1354 = 0, $1355 = 0, $1356 = 0, $1357 = 0, $1358 = 0, $1359 = 0, $136 = 0, $1360 = 0, $1361 = 0, $1362 = 0, $1363 = 0, $1364 = 0, $1365 = 0, $1366 = 0;
 var $1367 = 0, $1368 = 0, $1369 = 0, $137 = 0, $1370 = 0, $1371 = 0, $1372 = 0, $1373 = 0, $1374 = 0, $1375 = 0, $1376 = 0, $1377 = 0, $1378 = 0, $1379 = 0, $138 = 0, $1380 = 0, $1381 = 0, $1382 = 0, $1383 = 0, $1384 = 0;
 var $1385 = 0, $1386 = 0, $1387 = 0, $1388 = 0, $1389 = 0, $139 = 0, $1390 = 0, $1391 = 0, $1392 = 0, $1393 = 0, $1394 = 0, $1395 = 0, $1396 = 0, $1397 = 0, $1398 = 0, $1399 = 0, $14 = 0, $140 = 0, $1400 = 0, $1401 = 0;
 var $1402 = 0, $1403 = 0, $1404 = 0, $1405 = 0, $1406 = 0, $1407 = 0, $1408 = 0, $1409 = 0, $141 = 0, $1410 = 0, $1411 = 0, $1412 = 0, $1413 = 0, $1414 = 0, $1415 = 0, $1416 = 0, $1417 = 0, $1418 = 0, $1419 = 0, $142 = 0;
 var $1420 = 0, $1421 = 0, $1422 = 0, $1423 = 0, $1424 = 0, $1425 = 0, $1426 = 0, $1427 = 0, $1428 = 0, $1429 = 0, $143 = 0, $1430 = 0, $1431 = 0, $1432 = 0, $1433 = 0, $1434 = 0, $1435 = 0, $1436 = 0, $1437 = 0, $1438 = 0;
 var $1439 = 0, $144 = 0, $1440 = 0, $1441 = 0, $1442 = 0, $1443 = 0, $1444 = 0, $1445 = 0, $1446 = 0, $1447 = 0, $1448 = 0, $1449 = 0, $145 = 0, $1450 = 0, $1451 = 0, $1452 = 0, $1453 = 0, $1454 = 0, $1455 = 0, $1456 = 0;
 var $1457 = 0, $1458 = 0, $1459 = 0, $146 = 0, $1460 = 0, $1461 = 0, $1462 = 0, $1463 = 0, $1464 = 0, $1465 = 0, $1466 = 0, $1467 = 0, $1468 = 0, $1469 = 0, $147 = 0, $1470 = 0, $1471 = 0, $1472 = 0, $1473 = 0, $1474 = 0;
 var $1475 = 0, $1476 = 0, $1477 = 0, $1478 = 0, $1479 = 0, $148 = 0, $1480 = 0, $1481 = 0, $1482 = 0, $1483 = 0, $1484 = 0, $1485 = 0, $1486 = 0, $1487 = 0, $1488 = 0, $1489 = 0, $149 = 0, $1490 = 0, $1491 = 0, $1492 = 0;
 var $1493 = 0, $1494 = 0, $1495 = 0, $1496 = 0, $1497 = 0, $1498 = 0, $1499 = 0, $15 = 0, $150 = 0, $1500 = 0, $1501 = 0, $1502 = 0, $1503 = 0, $1504 = 0, $1505 = 0, $1506 = 0, $1507 = 0, $1508 = 0, $1509 = 0, $151 = 0;
 var $1510 = 0, $1511 = 0, $1512 = 0, $1513 = 0, $1514 = 0, $1515 = 0, $1516 = 0, $1517 = 0, $1518 = 0, $1519 = 0, $152 = 0, $1520 = 0, $1521 = 0, $1522 = 0, $1523 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0;
 var $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0;
 var $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0;
 var $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0;
 var $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0;
 var $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0;
 var $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0;
 var $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0;
 var $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0;
 var $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0;
 var $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0;
 var $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0;
 var $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0;
 var $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0;
 var $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0;
 var $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0;
 var $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0;
 var $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0;
 var $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0;
 var $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0;
 var $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0;
 var $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0;
 var $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0;
 var $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0;
 var $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0;
 var $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0;
 var $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0;
 var $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0;
 var $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0;
 var $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0;
 var $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0;
 var $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0;
 var $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0;
 var $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0;
 var $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0;
 var $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0;
 var $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0;
 var $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0, $823 = 0;
 var $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = 0, $834 = 0, $835 = 0, $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = 0, $841 = 0;
 var $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0, $850 = 0, $851 = 0, $852 = 0, $853 = 0, $854 = 0, $855 = 0, $856 = 0, $857 = 0, $858 = 0, $859 = 0, $86 = 0;
 var $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0, $869 = 0, $87 = 0, $870 = 0, $871 = 0, $872 = 0, $873 = 0, $874 = 0, $875 = 0, $876 = 0, $877 = 0, $878 = 0;
 var $879 = 0, $88 = 0, $880 = 0, $881 = 0, $882 = 0, $883 = 0, $884 = 0, $885 = 0, $886 = 0, $887 = 0, $888 = 0, $889 = 0, $89 = 0, $890 = 0, $891 = 0, $892 = 0, $893 = 0, $894 = 0, $895 = 0, $896 = 0;
 var $897 = 0, $898 = 0, $899 = 0, $9 = 0, $90 = 0, $900 = 0, $901 = 0, $902 = 0, $903 = 0, $904 = 0, $905 = 0, $906 = 0, $907 = 0, $908 = 0, $909 = 0, $91 = 0, $910 = 0, $911 = 0, $912 = 0, $913 = 0;
 var $914 = 0, $915 = 0, $916 = 0, $917 = 0, $918 = 0, $919 = 0, $92 = 0, $920 = 0, $921 = 0, $922 = 0, $923 = 0, $924 = 0, $925 = 0, $926 = 0, $927 = 0, $928 = 0, $929 = 0, $93 = 0, $930 = 0, $931 = 0;
 var $932 = 0, $933 = 0, $934 = 0, $935 = 0, $936 = 0, $937 = 0, $938 = 0, $939 = 0, $94 = 0, $940 = 0, $941 = 0, $942 = 0, $943 = 0, $944 = 0, $945 = 0, $946 = 0, $947 = 0, $948 = 0, $949 = 0, $95 = 0;
 var $950 = 0, $951 = 0, $952 = 0, $953 = 0, $954 = 0, $955 = 0, $956 = 0, $957 = 0, $958 = 0, $959 = 0, $96 = 0, $960 = 0, $961 = 0, $962 = 0, $963 = 0, $964 = 0, $965 = 0, $966 = 0, $967 = 0, $968 = 0;
 var $969 = 0, $97 = 0, $970 = 0, $971 = 0, $972 = 0, $973 = 0, $974 = 0, $975 = 0, $976 = 0, $977 = 0, $978 = 0, $979 = 0, $98 = 0, $980 = 0, $981 = 0, $982 = 0, $983 = 0, $984 = 0, $985 = 0, $986 = 0;
 var $987 = 0, $988 = 0, $989 = 0, $99 = 0, $990 = 0, $991 = 0, $992 = 0, $993 = 0, $994 = 0, $995 = 0, $996 = 0, $997 = 0, $998 = 0, $999 = 0, $div = 0, $div828 = 0, $div829 = 0, $div830 = 0, $div831 = 0, $div832 = 0;
 var $div833 = 0, $div834 = 0, $div835 = 0, $div836 = 0, $div837 = 0, $div838 = 0, $div839 = 0, $div840 = 0, $div841 = 0, $div842 = 0, $div843 = 0, $div844 = 0, $div845 = 0, $div846 = 0, $div847 = 0, $div848 = 0, $div849 = 0, $div850 = 0, $div851 = 0, $div852 = 0;
 var $div853 = 0, $div854 = 0, $div855 = 0, $div856 = 0, $div857 = 0, $div858 = 0, $div859 = 0, $div860 = 0, $div861 = 0, $div862 = 0, $or$cond = 0, $trunc = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($0)) + 36|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($0)) + 40|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ((($0)) + 44|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ((($10)) + 9|0);
 $14 = HEAP8[$13>>0]|0;
 $15 = $14&255;
 $16 = ((($12)) + 9|0);
 $17 = HEAP8[$16>>0]|0;
 $18 = $17&255;
 $19 = ((($0)) + 63|0);
 $20 = HEAP8[$19>>0]|0;
 $21 = $20&255;
 $22 = ($20<<24>>24)==(0);
 $23 = ($4|0)==(0);
 $or$cond = $22 | $23;
 if ($or$cond) {
  return;
 }
 $24 = ((($0)) + 20|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = HEAP32[$0>>2]|0;
 $27 = (($2) + 3)|0;
 $28 = (($27|0) / 4)&-1;
 $trunc = $2&255;
 $29 = ((($12)) + 28|0);
 $30 = ((($12)) + 32|0);
 $31 = ((($12)) + 29|0);
 $32 = ((($12)) + 33|0);
 $33 = ((($12)) + 30|0);
 $34 = ((($12)) + 34|0);
 $35 = ((($12)) + 31|0);
 $36 = ((($12)) + 35|0);
 $37 = ((($12)) + 12|0);
 $38 = ((($12)) + 16|0);
 $39 = ((($12)) + 20|0);
 $40 = ((($12)) + 24|0);
 $41 = ((($10)) + 28|0);
 $42 = ((($10)) + 12|0);
 $43 = ((($10)) + 32|0);
 $44 = ((($10)) + 29|0);
 $45 = ((($10)) + 16|0);
 $46 = ((($10)) + 33|0);
 $47 = ((($10)) + 30|0);
 $48 = ((($10)) + 20|0);
 $49 = ((($10)) + 34|0);
 $$0778873 = $26;$$0779872 = $25;$$in = $4;
 L4: while(1) {
  $50 = (($$in) + -1)|0;
  $trunc$clear = $trunc & 3;
  switch ($trunc$clear<<24>>24) {
  case 0:  {
   $$0812 = $28;$$1 = $$0778873;$$1780 = $$0779872;
   label = 4;
   break;
  }
  case 3:  {
   $$1813 = $28;$$2 = $$0778873;$$2781 = $$0779872;
   label = 21;
   break;
  }
  case 2:  {
   $$2814 = $28;$$3 = $$0778873;$$3782 = $$0779872;
   label = 38;
   break;
  }
  case 1:  {
   $$3815 = $28;$$4 = $$0778873;$$4783 = $$0779872;
   label = 55;
   break;
  }
  default: {
   label = 72;
   break L4;
  }
  }
  while(1) {
   if ((label|0) == 4) {
    label = 0;
    switch ($14<<24>>24) {
    case 1:  {
     $51 = HEAP8[$$1>>0]|0;
     $52 = $51&255;
     $53 = HEAP8[$41>>0]|0;
     $54 = $53&255;
     $55 = (79212 + ($54<<2)|0);
     $56 = HEAP32[$55>>2]|0;
     $57 = HEAP32[$42>>2]|0;
     $58 = $57 & $52;
     $59 = HEAP8[$43>>0]|0;
     $60 = $59&255;
     $61 = $58 >>> $60;
     $62 = (($56) + ($61)|0);
     $63 = HEAP8[$44>>0]|0;
     $64 = $63&255;
     $65 = (79212 + ($64<<2)|0);
     $66 = HEAP32[$65>>2]|0;
     $67 = HEAP32[$45>>2]|0;
     $68 = $67 & $52;
     $69 = HEAP8[$46>>0]|0;
     $70 = $69&255;
     $71 = $68 >>> $70;
     $72 = (($66) + ($71)|0);
     $73 = HEAP8[$47>>0]|0;
     $74 = $73&255;
     $75 = (79212 + ($74<<2)|0);
     $76 = HEAP32[$75>>2]|0;
     $77 = HEAP32[$48>>2]|0;
     $78 = $77 & $52;
     $79 = HEAP8[$49>>0]|0;
     $80 = $79&255;
     $81 = $78 >>> $80;
     $82 = (($76) + ($81)|0);
     $$0784$shrunk$ph$in = $62;$$0788$shrunk$ph$in = $72;$$sink = $82;
     label = 9;
     break;
    }
    case 2:  {
     $83 = HEAP16[$$1>>1]|0;
     $84 = $83&65535;
     $85 = HEAP8[$41>>0]|0;
     $86 = $85&255;
     $87 = (79212 + ($86<<2)|0);
     $88 = HEAP32[$87>>2]|0;
     $89 = HEAP32[$42>>2]|0;
     $90 = $89 & $84;
     $91 = HEAP8[$43>>0]|0;
     $92 = $91&255;
     $93 = $90 >>> $92;
     $94 = (($88) + ($93)|0);
     $95 = HEAP8[$44>>0]|0;
     $96 = $95&255;
     $97 = (79212 + ($96<<2)|0);
     $98 = HEAP32[$97>>2]|0;
     $99 = HEAP32[$45>>2]|0;
     $100 = $99 & $84;
     $101 = HEAP8[$46>>0]|0;
     $102 = $101&255;
     $103 = $100 >>> $102;
     $104 = (($98) + ($103)|0);
     $105 = HEAP8[$47>>0]|0;
     $106 = $105&255;
     $107 = (79212 + ($106<<2)|0);
     $108 = HEAP32[$107>>2]|0;
     $109 = HEAP32[$48>>2]|0;
     $110 = $109 & $84;
     $111 = HEAP8[$49>>0]|0;
     $112 = $111&255;
     $113 = $110 >>> $112;
     $114 = (($108) + ($113)|0);
     $$0784$shrunk$ph$in = $94;$$0788$shrunk$ph$in = $104;$$sink = $114;
     label = 9;
     break;
    }
    case 3:  {
     $115 = HEAP8[$43>>0]|0;
     $div851 = ($115&255) >>> 3;
     $116 = $div851&255;
     $117 = (($$1) + ($116)|0);
     $118 = HEAP8[$46>>0]|0;
     $div852 = ($118&255) >>> 3;
     $119 = $div852&255;
     $120 = (($$1) + ($119)|0);
     $121 = HEAP8[$49>>0]|0;
     $div853 = ($121&255) >>> 3;
     $122 = $div853&255;
     $123 = (($$1) + ($122)|0);
     $$0784$shrunk$ph$in = $117;$$0788$shrunk$ph$in = $120;$$sink = $123;
     label = 9;
     break;
    }
    case 4:  {
     $124 = HEAP32[$$1>>2]|0;
     $125 = HEAP8[$41>>0]|0;
     $126 = $125&255;
     $127 = (79212 + ($126<<2)|0);
     $128 = HEAP32[$127>>2]|0;
     $129 = HEAP32[$42>>2]|0;
     $130 = $129 & $124;
     $131 = HEAP8[$43>>0]|0;
     $132 = $131&255;
     $133 = $130 >>> $132;
     $134 = (($128) + ($133)|0);
     $135 = HEAP8[$44>>0]|0;
     $136 = $135&255;
     $137 = (79212 + ($136<<2)|0);
     $138 = HEAP32[$137>>2]|0;
     $139 = HEAP32[$45>>2]|0;
     $140 = $139 & $124;
     $141 = HEAP8[$46>>0]|0;
     $142 = $141&255;
     $143 = $140 >>> $142;
     $144 = (($138) + ($143)|0);
     $145 = HEAP8[$47>>0]|0;
     $146 = $145&255;
     $147 = (79212 + ($146<<2)|0);
     $148 = HEAP32[$147>>2]|0;
     $149 = HEAP32[$48>>2]|0;
     $150 = $149 & $124;
     $151 = HEAP8[$49>>0]|0;
     $152 = $151&255;
     $153 = $150 >>> $152;
     $154 = (($148) + ($153)|0);
     $$0784$shrunk$ph$in = $134;$$0788$shrunk$ph$in = $144;$$sink = $154;
     label = 9;
     break;
    }
    default: {
     $$0784$shrunk = 0;$$0788$shrunk = 0;$$0792$shrunk = 0;
    }
    }
    if ((label|0) == 9) {
     label = 0;
     $$0784$shrunk$ph = HEAP8[$$0784$shrunk$ph$in>>0]|0;
     $$0788$shrunk$ph = HEAP8[$$0788$shrunk$ph$in>>0]|0;
     $155 = HEAP8[$$sink>>0]|0;
     $$0784$shrunk = $$0784$shrunk$ph;$$0788$shrunk = $$0788$shrunk$ph;$$0792$shrunk = $155;
    }
    $$0784 = $$0784$shrunk&255;
    $$0788 = $$0788$shrunk&255;
    $$0792 = $$0792$shrunk&255;
    switch ($17<<24>>24) {
    case 1:  {
     $156 = HEAP8[$$1780>>0]|0;
     $157 = $156&255;
     $158 = HEAP8[$29>>0]|0;
     $159 = $158&255;
     $160 = (79212 + ($159<<2)|0);
     $161 = HEAP32[$160>>2]|0;
     $162 = HEAP32[$37>>2]|0;
     $163 = $162 & $157;
     $164 = HEAP8[$30>>0]|0;
     $165 = $164&255;
     $166 = $163 >>> $165;
     $167 = (($161) + ($166)|0);
     $168 = HEAP8[$167>>0]|0;
     $169 = HEAP8[$31>>0]|0;
     $170 = $169&255;
     $171 = (79212 + ($170<<2)|0);
     $172 = HEAP32[$171>>2]|0;
     $173 = HEAP32[$38>>2]|0;
     $174 = $173 & $157;
     $175 = HEAP8[$32>>0]|0;
     $176 = $175&255;
     $177 = $174 >>> $176;
     $178 = (($172) + ($177)|0);
     $179 = HEAP8[$178>>0]|0;
     $180 = HEAP8[$33>>0]|0;
     $181 = $180&255;
     $182 = (79212 + ($181<<2)|0);
     $183 = HEAP32[$182>>2]|0;
     $184 = HEAP32[$39>>2]|0;
     $185 = $184 & $157;
     $186 = HEAP8[$34>>0]|0;
     $187 = $186&255;
     $188 = $185 >>> $187;
     $189 = (($183) + ($188)|0);
     $190 = HEAP8[$189>>0]|0;
     $191 = HEAP8[$35>>0]|0;
     $192 = $191&255;
     $193 = (79212 + ($192<<2)|0);
     $194 = HEAP32[$193>>2]|0;
     $195 = HEAP32[$40>>2]|0;
     $196 = $195 & $157;
     $197 = HEAP8[$36>>0]|0;
     $198 = $197&255;
     $199 = $196 >>> $198;
     $200 = (($194) + ($199)|0);
     $201 = HEAP8[$200>>0]|0;
     $$0796$shrunk = $168;$$0800$shrunk = $179;$$0804$shrunk = $190;$$0808$shrunk = $201;
     break;
    }
    case 2:  {
     $202 = HEAP16[$$1780>>1]|0;
     $203 = $202&65535;
     $204 = HEAP8[$29>>0]|0;
     $205 = $204&255;
     $206 = (79212 + ($205<<2)|0);
     $207 = HEAP32[$206>>2]|0;
     $208 = HEAP32[$37>>2]|0;
     $209 = $208 & $203;
     $210 = HEAP8[$30>>0]|0;
     $211 = $210&255;
     $212 = $209 >>> $211;
     $213 = (($207) + ($212)|0);
     $214 = HEAP8[$213>>0]|0;
     $215 = HEAP8[$31>>0]|0;
     $216 = $215&255;
     $217 = (79212 + ($216<<2)|0);
     $218 = HEAP32[$217>>2]|0;
     $219 = HEAP32[$38>>2]|0;
     $220 = $219 & $203;
     $221 = HEAP8[$32>>0]|0;
     $222 = $221&255;
     $223 = $220 >>> $222;
     $224 = (($218) + ($223)|0);
     $225 = HEAP8[$224>>0]|0;
     $226 = HEAP8[$33>>0]|0;
     $227 = $226&255;
     $228 = (79212 + ($227<<2)|0);
     $229 = HEAP32[$228>>2]|0;
     $230 = HEAP32[$39>>2]|0;
     $231 = $230 & $203;
     $232 = HEAP8[$34>>0]|0;
     $233 = $232&255;
     $234 = $231 >>> $233;
     $235 = (($229) + ($234)|0);
     $236 = HEAP8[$235>>0]|0;
     $237 = HEAP8[$35>>0]|0;
     $238 = $237&255;
     $239 = (79212 + ($238<<2)|0);
     $240 = HEAP32[$239>>2]|0;
     $241 = HEAP32[$40>>2]|0;
     $242 = $241 & $203;
     $243 = HEAP8[$36>>0]|0;
     $244 = $243&255;
     $245 = $242 >>> $244;
     $246 = (($240) + ($245)|0);
     $247 = HEAP8[$246>>0]|0;
     $$0796$shrunk = $214;$$0800$shrunk = $225;$$0804$shrunk = $236;$$0808$shrunk = $247;
     break;
    }
    case 3:  {
     $248 = HEAP8[$30>>0]|0;
     $div848 = ($248&255) >>> 3;
     $249 = $div848&255;
     $250 = (($$1780) + ($249)|0);
     $251 = HEAP8[$250>>0]|0;
     $252 = HEAP8[$32>>0]|0;
     $div849 = ($252&255) >>> 3;
     $253 = $div849&255;
     $254 = (($$1780) + ($253)|0);
     $255 = HEAP8[$254>>0]|0;
     $256 = HEAP8[$34>>0]|0;
     $div850 = ($256&255) >>> 3;
     $257 = $div850&255;
     $258 = (($$1780) + ($257)|0);
     $259 = HEAP8[$258>>0]|0;
     $$0796$shrunk = $251;$$0800$shrunk = $255;$$0804$shrunk = $259;$$0808$shrunk = -1;
     break;
    }
    case 4:  {
     $260 = HEAP32[$$1780>>2]|0;
     $261 = HEAP8[$29>>0]|0;
     $262 = $261&255;
     $263 = (79212 + ($262<<2)|0);
     $264 = HEAP32[$263>>2]|0;
     $265 = HEAP32[$37>>2]|0;
     $266 = $265 & $260;
     $267 = HEAP8[$30>>0]|0;
     $268 = $267&255;
     $269 = $266 >>> $268;
     $270 = (($264) + ($269)|0);
     $271 = HEAP8[$270>>0]|0;
     $272 = HEAP8[$31>>0]|0;
     $273 = $272&255;
     $274 = (79212 + ($273<<2)|0);
     $275 = HEAP32[$274>>2]|0;
     $276 = HEAP32[$38>>2]|0;
     $277 = $276 & $260;
     $278 = HEAP8[$32>>0]|0;
     $279 = $278&255;
     $280 = $277 >>> $279;
     $281 = (($275) + ($280)|0);
     $282 = HEAP8[$281>>0]|0;
     $283 = HEAP8[$33>>0]|0;
     $284 = $283&255;
     $285 = (79212 + ($284<<2)|0);
     $286 = HEAP32[$285>>2]|0;
     $287 = HEAP32[$39>>2]|0;
     $288 = $287 & $260;
     $289 = HEAP8[$34>>0]|0;
     $290 = $289&255;
     $291 = $288 >>> $290;
     $292 = (($286) + ($291)|0);
     $293 = HEAP8[$292>>0]|0;
     $294 = HEAP8[$35>>0]|0;
     $295 = $294&255;
     $296 = (79212 + ($295<<2)|0);
     $297 = HEAP32[$296>>2]|0;
     $298 = HEAP32[$40>>2]|0;
     $299 = $298 & $260;
     $300 = HEAP8[$36>>0]|0;
     $301 = $300&255;
     $302 = $299 >>> $301;
     $303 = (($297) + ($302)|0);
     $304 = HEAP8[$303>>0]|0;
     $$0796$shrunk = $271;$$0800$shrunk = $282;$$0804$shrunk = $293;$$0808$shrunk = $304;
     break;
    }
    default: {
     $$0796$shrunk = 0;$$0800$shrunk = 0;$$0804$shrunk = 0;$$0808$shrunk = 0;
    }
    }
    $$0796 = $$0796$shrunk&255;
    $$0800 = $$0800$shrunk&255;
    $$0804 = $$0804$shrunk&255;
    $$0808 = $$0808$shrunk&255;
    $305 = (($$0784) - ($$0796))|0;
    $306 = Math_imul($305, $21)|0;
    $307 = (($306>>>0) / 255)&-1;
    $308 = (($307) + ($$0796))|0;
    $309 = (($$0788) - ($$0800))|0;
    $310 = Math_imul($309, $21)|0;
    $311 = (($310>>>0) / 255)&-1;
    $312 = (($311) + ($$0800))|0;
    $313 = (($$0792) - ($$0804))|0;
    $314 = Math_imul($313, $21)|0;
    $315 = (($314>>>0) / 255)&-1;
    $316 = (($315) + ($$0804))|0;
    $317 = (($$0808) + ($21))|0;
    $318 = Math_imul($$0808, $21)|0;
    $319 = (($318>>>0) / 255)&-1;
    $320 = (($317) - ($319))|0;
    switch ($17<<24>>24) {
    case 1:  {
     $321 = HEAP8[$29>>0]|0;
     $322 = $321&255;
     $323 = $308 >>> $322;
     $324 = HEAP8[$30>>0]|0;
     $325 = $324&255;
     $326 = $323 << $325;
     $327 = HEAP8[$31>>0]|0;
     $328 = $327&255;
     $329 = $312 >>> $328;
     $330 = HEAP8[$32>>0]|0;
     $331 = $330&255;
     $332 = $329 << $331;
     $333 = $332 | $326;
     $334 = HEAP8[$33>>0]|0;
     $335 = $334&255;
     $336 = $316 >>> $335;
     $337 = HEAP8[$34>>0]|0;
     $338 = $337&255;
     $339 = $336 << $338;
     $340 = $333 | $339;
     $341 = HEAP8[$35>>0]|0;
     $342 = $341&255;
     $343 = $320 >>> $342;
     $344 = HEAP8[$36>>0]|0;
     $345 = $344&255;
     $346 = $343 << $345;
     $347 = $340 | $346;
     $348 = $347&255;
     HEAP8[$$1780>>0] = $348;
     break;
    }
    case 2:  {
     $349 = HEAP8[$29>>0]|0;
     $350 = $349&255;
     $351 = $308 >>> $350;
     $352 = HEAP8[$30>>0]|0;
     $353 = $352&255;
     $354 = $351 << $353;
     $355 = HEAP8[$31>>0]|0;
     $356 = $355&255;
     $357 = $312 >>> $356;
     $358 = HEAP8[$32>>0]|0;
     $359 = $358&255;
     $360 = $357 << $359;
     $361 = $360 | $354;
     $362 = HEAP8[$33>>0]|0;
     $363 = $362&255;
     $364 = $316 >>> $363;
     $365 = HEAP8[$34>>0]|0;
     $366 = $365&255;
     $367 = $364 << $366;
     $368 = $361 | $367;
     $369 = HEAP8[$35>>0]|0;
     $370 = $369&255;
     $371 = $320 >>> $370;
     $372 = HEAP8[$36>>0]|0;
     $373 = $372&255;
     $374 = $371 << $373;
     $375 = $368 | $374;
     $376 = $375&65535;
     HEAP16[$$1780>>1] = $376;
     break;
    }
    case 3:  {
     $377 = $308&255;
     $378 = HEAP8[$30>>0]|0;
     $div845 = ($378&255) >>> 3;
     $379 = $div845&255;
     $380 = (($$1780) + ($379)|0);
     HEAP8[$380>>0] = $377;
     $381 = $312&255;
     $382 = HEAP8[$32>>0]|0;
     $div846 = ($382&255) >>> 3;
     $383 = $div846&255;
     $384 = (($$1780) + ($383)|0);
     HEAP8[$384>>0] = $381;
     $385 = $316&255;
     $386 = HEAP8[$34>>0]|0;
     $div847 = ($386&255) >>> 3;
     $387 = $div847&255;
     $388 = (($$1780) + ($387)|0);
     HEAP8[$388>>0] = $385;
     break;
    }
    case 4:  {
     $389 = HEAP8[$29>>0]|0;
     $390 = $389&255;
     $391 = $308 >>> $390;
     $392 = HEAP8[$30>>0]|0;
     $393 = $392&255;
     $394 = $391 << $393;
     $395 = HEAP8[$31>>0]|0;
     $396 = $395&255;
     $397 = $312 >>> $396;
     $398 = HEAP8[$32>>0]|0;
     $399 = $398&255;
     $400 = $397 << $399;
     $401 = $400 | $394;
     $402 = HEAP8[$33>>0]|0;
     $403 = $402&255;
     $404 = $316 >>> $403;
     $405 = HEAP8[$34>>0]|0;
     $406 = $405&255;
     $407 = $404 << $406;
     $408 = $401 | $407;
     $409 = HEAP8[$35>>0]|0;
     $410 = $409&255;
     $411 = $320 >>> $410;
     $412 = HEAP8[$36>>0]|0;
     $413 = $412&255;
     $414 = $411 << $413;
     $415 = $408 | $414;
     HEAP32[$$1780>>2] = $415;
     break;
    }
    default: {
    }
    }
    $416 = (($$1) + ($15)|0);
    $417 = (($$1780) + ($18)|0);
    $$1813 = $$0812;$$2 = $416;$$2781 = $417;
    label = 21;
    continue;
   }
   else if ((label|0) == 21) {
    label = 0;
    switch ($14<<24>>24) {
    case 1:  {
     $418 = HEAP8[$$2>>0]|0;
     $419 = $418&255;
     $420 = HEAP8[$41>>0]|0;
     $421 = $420&255;
     $422 = (79212 + ($421<<2)|0);
     $423 = HEAP32[$422>>2]|0;
     $424 = HEAP32[$42>>2]|0;
     $425 = $424 & $419;
     $426 = HEAP8[$43>>0]|0;
     $427 = $426&255;
     $428 = $425 >>> $427;
     $429 = (($423) + ($428)|0);
     $430 = HEAP8[$44>>0]|0;
     $431 = $430&255;
     $432 = (79212 + ($431<<2)|0);
     $433 = HEAP32[$432>>2]|0;
     $434 = HEAP32[$45>>2]|0;
     $435 = $434 & $419;
     $436 = HEAP8[$46>>0]|0;
     $437 = $436&255;
     $438 = $435 >>> $437;
     $439 = (($433) + ($438)|0);
     $440 = HEAP8[$47>>0]|0;
     $441 = $440&255;
     $442 = (79212 + ($441<<2)|0);
     $443 = HEAP32[$442>>2]|0;
     $444 = HEAP32[$48>>2]|0;
     $445 = $444 & $419;
     $446 = HEAP8[$49>>0]|0;
     $447 = $446&255;
     $448 = $445 >>> $447;
     $449 = (($443) + ($448)|0);
     $$1785$shrunk$ph$in = $429;$$1789$shrunk$ph$in = $439;$$sink864 = $449;
     label = 26;
     break;
    }
    case 2:  {
     $450 = HEAP16[$$2>>1]|0;
     $451 = $450&65535;
     $452 = HEAP8[$41>>0]|0;
     $453 = $452&255;
     $454 = (79212 + ($453<<2)|0);
     $455 = HEAP32[$454>>2]|0;
     $456 = HEAP32[$42>>2]|0;
     $457 = $456 & $451;
     $458 = HEAP8[$43>>0]|0;
     $459 = $458&255;
     $460 = $457 >>> $459;
     $461 = (($455) + ($460)|0);
     $462 = HEAP8[$44>>0]|0;
     $463 = $462&255;
     $464 = (79212 + ($463<<2)|0);
     $465 = HEAP32[$464>>2]|0;
     $466 = HEAP32[$45>>2]|0;
     $467 = $466 & $451;
     $468 = HEAP8[$46>>0]|0;
     $469 = $468&255;
     $470 = $467 >>> $469;
     $471 = (($465) + ($470)|0);
     $472 = HEAP8[$47>>0]|0;
     $473 = $472&255;
     $474 = (79212 + ($473<<2)|0);
     $475 = HEAP32[$474>>2]|0;
     $476 = HEAP32[$48>>2]|0;
     $477 = $476 & $451;
     $478 = HEAP8[$49>>0]|0;
     $479 = $478&255;
     $480 = $477 >>> $479;
     $481 = (($475) + ($480)|0);
     $$1785$shrunk$ph$in = $461;$$1789$shrunk$ph$in = $471;$$sink864 = $481;
     label = 26;
     break;
    }
    case 3:  {
     $482 = HEAP8[$43>>0]|0;
     $div842 = ($482&255) >>> 3;
     $483 = $div842&255;
     $484 = (($$2) + ($483)|0);
     $485 = HEAP8[$46>>0]|0;
     $div843 = ($485&255) >>> 3;
     $486 = $div843&255;
     $487 = (($$2) + ($486)|0);
     $488 = HEAP8[$49>>0]|0;
     $div844 = ($488&255) >>> 3;
     $489 = $div844&255;
     $490 = (($$2) + ($489)|0);
     $$1785$shrunk$ph$in = $484;$$1789$shrunk$ph$in = $487;$$sink864 = $490;
     label = 26;
     break;
    }
    case 4:  {
     $491 = HEAP32[$$2>>2]|0;
     $492 = HEAP8[$41>>0]|0;
     $493 = $492&255;
     $494 = (79212 + ($493<<2)|0);
     $495 = HEAP32[$494>>2]|0;
     $496 = HEAP32[$42>>2]|0;
     $497 = $496 & $491;
     $498 = HEAP8[$43>>0]|0;
     $499 = $498&255;
     $500 = $497 >>> $499;
     $501 = (($495) + ($500)|0);
     $502 = HEAP8[$44>>0]|0;
     $503 = $502&255;
     $504 = (79212 + ($503<<2)|0);
     $505 = HEAP32[$504>>2]|0;
     $506 = HEAP32[$45>>2]|0;
     $507 = $506 & $491;
     $508 = HEAP8[$46>>0]|0;
     $509 = $508&255;
     $510 = $507 >>> $509;
     $511 = (($505) + ($510)|0);
     $512 = HEAP8[$47>>0]|0;
     $513 = $512&255;
     $514 = (79212 + ($513<<2)|0);
     $515 = HEAP32[$514>>2]|0;
     $516 = HEAP32[$48>>2]|0;
     $517 = $516 & $491;
     $518 = HEAP8[$49>>0]|0;
     $519 = $518&255;
     $520 = $517 >>> $519;
     $521 = (($515) + ($520)|0);
     $$1785$shrunk$ph$in = $501;$$1789$shrunk$ph$in = $511;$$sink864 = $521;
     label = 26;
     break;
    }
    default: {
     $$1785$shrunk = 0;$$1789$shrunk = 0;$$1793$shrunk = 0;
    }
    }
    if ((label|0) == 26) {
     label = 0;
     $$1785$shrunk$ph = HEAP8[$$1785$shrunk$ph$in>>0]|0;
     $$1789$shrunk$ph = HEAP8[$$1789$shrunk$ph$in>>0]|0;
     $522 = HEAP8[$$sink864>>0]|0;
     $$1785$shrunk = $$1785$shrunk$ph;$$1789$shrunk = $$1789$shrunk$ph;$$1793$shrunk = $522;
    }
    $$1785 = $$1785$shrunk&255;
    $$1789 = $$1789$shrunk&255;
    $$1793 = $$1793$shrunk&255;
    switch ($17<<24>>24) {
    case 1:  {
     $523 = HEAP8[$$2781>>0]|0;
     $524 = $523&255;
     $525 = HEAP8[$29>>0]|0;
     $526 = $525&255;
     $527 = (79212 + ($526<<2)|0);
     $528 = HEAP32[$527>>2]|0;
     $529 = HEAP32[$37>>2]|0;
     $530 = $529 & $524;
     $531 = HEAP8[$30>>0]|0;
     $532 = $531&255;
     $533 = $530 >>> $532;
     $534 = (($528) + ($533)|0);
     $535 = HEAP8[$534>>0]|0;
     $536 = HEAP8[$31>>0]|0;
     $537 = $536&255;
     $538 = (79212 + ($537<<2)|0);
     $539 = HEAP32[$538>>2]|0;
     $540 = HEAP32[$38>>2]|0;
     $541 = $540 & $524;
     $542 = HEAP8[$32>>0]|0;
     $543 = $542&255;
     $544 = $541 >>> $543;
     $545 = (($539) + ($544)|0);
     $546 = HEAP8[$545>>0]|0;
     $547 = HEAP8[$33>>0]|0;
     $548 = $547&255;
     $549 = (79212 + ($548<<2)|0);
     $550 = HEAP32[$549>>2]|0;
     $551 = HEAP32[$39>>2]|0;
     $552 = $551 & $524;
     $553 = HEAP8[$34>>0]|0;
     $554 = $553&255;
     $555 = $552 >>> $554;
     $556 = (($550) + ($555)|0);
     $557 = HEAP8[$556>>0]|0;
     $558 = HEAP8[$35>>0]|0;
     $559 = $558&255;
     $560 = (79212 + ($559<<2)|0);
     $561 = HEAP32[$560>>2]|0;
     $562 = HEAP32[$40>>2]|0;
     $563 = $562 & $524;
     $564 = HEAP8[$36>>0]|0;
     $565 = $564&255;
     $566 = $563 >>> $565;
     $567 = (($561) + ($566)|0);
     $568 = HEAP8[$567>>0]|0;
     $$1797$shrunk = $535;$$1801$shrunk = $546;$$1805$shrunk = $557;$$1809$shrunk = $568;
     break;
    }
    case 2:  {
     $569 = HEAP16[$$2781>>1]|0;
     $570 = $569&65535;
     $571 = HEAP8[$29>>0]|0;
     $572 = $571&255;
     $573 = (79212 + ($572<<2)|0);
     $574 = HEAP32[$573>>2]|0;
     $575 = HEAP32[$37>>2]|0;
     $576 = $575 & $570;
     $577 = HEAP8[$30>>0]|0;
     $578 = $577&255;
     $579 = $576 >>> $578;
     $580 = (($574) + ($579)|0);
     $581 = HEAP8[$580>>0]|0;
     $582 = HEAP8[$31>>0]|0;
     $583 = $582&255;
     $584 = (79212 + ($583<<2)|0);
     $585 = HEAP32[$584>>2]|0;
     $586 = HEAP32[$38>>2]|0;
     $587 = $586 & $570;
     $588 = HEAP8[$32>>0]|0;
     $589 = $588&255;
     $590 = $587 >>> $589;
     $591 = (($585) + ($590)|0);
     $592 = HEAP8[$591>>0]|0;
     $593 = HEAP8[$33>>0]|0;
     $594 = $593&255;
     $595 = (79212 + ($594<<2)|0);
     $596 = HEAP32[$595>>2]|0;
     $597 = HEAP32[$39>>2]|0;
     $598 = $597 & $570;
     $599 = HEAP8[$34>>0]|0;
     $600 = $599&255;
     $601 = $598 >>> $600;
     $602 = (($596) + ($601)|0);
     $603 = HEAP8[$602>>0]|0;
     $604 = HEAP8[$35>>0]|0;
     $605 = $604&255;
     $606 = (79212 + ($605<<2)|0);
     $607 = HEAP32[$606>>2]|0;
     $608 = HEAP32[$40>>2]|0;
     $609 = $608 & $570;
     $610 = HEAP8[$36>>0]|0;
     $611 = $610&255;
     $612 = $609 >>> $611;
     $613 = (($607) + ($612)|0);
     $614 = HEAP8[$613>>0]|0;
     $$1797$shrunk = $581;$$1801$shrunk = $592;$$1805$shrunk = $603;$$1809$shrunk = $614;
     break;
    }
    case 3:  {
     $615 = HEAP8[$30>>0]|0;
     $div839 = ($615&255) >>> 3;
     $616 = $div839&255;
     $617 = (($$2781) + ($616)|0);
     $618 = HEAP8[$617>>0]|0;
     $619 = HEAP8[$32>>0]|0;
     $div840 = ($619&255) >>> 3;
     $620 = $div840&255;
     $621 = (($$2781) + ($620)|0);
     $622 = HEAP8[$621>>0]|0;
     $623 = HEAP8[$34>>0]|0;
     $div841 = ($623&255) >>> 3;
     $624 = $div841&255;
     $625 = (($$2781) + ($624)|0);
     $626 = HEAP8[$625>>0]|0;
     $$1797$shrunk = $618;$$1801$shrunk = $622;$$1805$shrunk = $626;$$1809$shrunk = -1;
     break;
    }
    case 4:  {
     $627 = HEAP32[$$2781>>2]|0;
     $628 = HEAP8[$29>>0]|0;
     $629 = $628&255;
     $630 = (79212 + ($629<<2)|0);
     $631 = HEAP32[$630>>2]|0;
     $632 = HEAP32[$37>>2]|0;
     $633 = $632 & $627;
     $634 = HEAP8[$30>>0]|0;
     $635 = $634&255;
     $636 = $633 >>> $635;
     $637 = (($631) + ($636)|0);
     $638 = HEAP8[$637>>0]|0;
     $639 = HEAP8[$31>>0]|0;
     $640 = $639&255;
     $641 = (79212 + ($640<<2)|0);
     $642 = HEAP32[$641>>2]|0;
     $643 = HEAP32[$38>>2]|0;
     $644 = $643 & $627;
     $645 = HEAP8[$32>>0]|0;
     $646 = $645&255;
     $647 = $644 >>> $646;
     $648 = (($642) + ($647)|0);
     $649 = HEAP8[$648>>0]|0;
     $650 = HEAP8[$33>>0]|0;
     $651 = $650&255;
     $652 = (79212 + ($651<<2)|0);
     $653 = HEAP32[$652>>2]|0;
     $654 = HEAP32[$39>>2]|0;
     $655 = $654 & $627;
     $656 = HEAP8[$34>>0]|0;
     $657 = $656&255;
     $658 = $655 >>> $657;
     $659 = (($653) + ($658)|0);
     $660 = HEAP8[$659>>0]|0;
     $661 = HEAP8[$35>>0]|0;
     $662 = $661&255;
     $663 = (79212 + ($662<<2)|0);
     $664 = HEAP32[$663>>2]|0;
     $665 = HEAP32[$40>>2]|0;
     $666 = $665 & $627;
     $667 = HEAP8[$36>>0]|0;
     $668 = $667&255;
     $669 = $666 >>> $668;
     $670 = (($664) + ($669)|0);
     $671 = HEAP8[$670>>0]|0;
     $$1797$shrunk = $638;$$1801$shrunk = $649;$$1805$shrunk = $660;$$1809$shrunk = $671;
     break;
    }
    default: {
     $$1797$shrunk = 0;$$1801$shrunk = 0;$$1805$shrunk = 0;$$1809$shrunk = 0;
    }
    }
    $$1797 = $$1797$shrunk&255;
    $$1801 = $$1801$shrunk&255;
    $$1805 = $$1805$shrunk&255;
    $$1809 = $$1809$shrunk&255;
    $672 = (($$1785) - ($$1797))|0;
    $673 = Math_imul($672, $21)|0;
    $674 = (($673>>>0) / 255)&-1;
    $675 = (($674) + ($$1797))|0;
    $676 = (($$1789) - ($$1801))|0;
    $677 = Math_imul($676, $21)|0;
    $678 = (($677>>>0) / 255)&-1;
    $679 = (($678) + ($$1801))|0;
    $680 = (($$1793) - ($$1805))|0;
    $681 = Math_imul($680, $21)|0;
    $682 = (($681>>>0) / 255)&-1;
    $683 = (($682) + ($$1805))|0;
    $684 = (($$1809) + ($21))|0;
    $685 = Math_imul($$1809, $21)|0;
    $686 = (($685>>>0) / 255)&-1;
    $687 = (($684) - ($686))|0;
    switch ($17<<24>>24) {
    case 1:  {
     $688 = HEAP8[$29>>0]|0;
     $689 = $688&255;
     $690 = $675 >>> $689;
     $691 = HEAP8[$30>>0]|0;
     $692 = $691&255;
     $693 = $690 << $692;
     $694 = HEAP8[$31>>0]|0;
     $695 = $694&255;
     $696 = $679 >>> $695;
     $697 = HEAP8[$32>>0]|0;
     $698 = $697&255;
     $699 = $696 << $698;
     $700 = $699 | $693;
     $701 = HEAP8[$33>>0]|0;
     $702 = $701&255;
     $703 = $683 >>> $702;
     $704 = HEAP8[$34>>0]|0;
     $705 = $704&255;
     $706 = $703 << $705;
     $707 = $700 | $706;
     $708 = HEAP8[$35>>0]|0;
     $709 = $708&255;
     $710 = $687 >>> $709;
     $711 = HEAP8[$36>>0]|0;
     $712 = $711&255;
     $713 = $710 << $712;
     $714 = $707 | $713;
     $715 = $714&255;
     HEAP8[$$2781>>0] = $715;
     break;
    }
    case 2:  {
     $716 = HEAP8[$29>>0]|0;
     $717 = $716&255;
     $718 = $675 >>> $717;
     $719 = HEAP8[$30>>0]|0;
     $720 = $719&255;
     $721 = $718 << $720;
     $722 = HEAP8[$31>>0]|0;
     $723 = $722&255;
     $724 = $679 >>> $723;
     $725 = HEAP8[$32>>0]|0;
     $726 = $725&255;
     $727 = $724 << $726;
     $728 = $727 | $721;
     $729 = HEAP8[$33>>0]|0;
     $730 = $729&255;
     $731 = $683 >>> $730;
     $732 = HEAP8[$34>>0]|0;
     $733 = $732&255;
     $734 = $731 << $733;
     $735 = $728 | $734;
     $736 = HEAP8[$35>>0]|0;
     $737 = $736&255;
     $738 = $687 >>> $737;
     $739 = HEAP8[$36>>0]|0;
     $740 = $739&255;
     $741 = $738 << $740;
     $742 = $735 | $741;
     $743 = $742&65535;
     HEAP16[$$2781>>1] = $743;
     break;
    }
    case 3:  {
     $744 = $675&255;
     $745 = HEAP8[$30>>0]|0;
     $div836 = ($745&255) >>> 3;
     $746 = $div836&255;
     $747 = (($$2781) + ($746)|0);
     HEAP8[$747>>0] = $744;
     $748 = $679&255;
     $749 = HEAP8[$32>>0]|0;
     $div837 = ($749&255) >>> 3;
     $750 = $div837&255;
     $751 = (($$2781) + ($750)|0);
     HEAP8[$751>>0] = $748;
     $752 = $683&255;
     $753 = HEAP8[$34>>0]|0;
     $div838 = ($753&255) >>> 3;
     $754 = $div838&255;
     $755 = (($$2781) + ($754)|0);
     HEAP8[$755>>0] = $752;
     break;
    }
    case 4:  {
     $756 = HEAP8[$29>>0]|0;
     $757 = $756&255;
     $758 = $675 >>> $757;
     $759 = HEAP8[$30>>0]|0;
     $760 = $759&255;
     $761 = $758 << $760;
     $762 = HEAP8[$31>>0]|0;
     $763 = $762&255;
     $764 = $679 >>> $763;
     $765 = HEAP8[$32>>0]|0;
     $766 = $765&255;
     $767 = $764 << $766;
     $768 = $767 | $761;
     $769 = HEAP8[$33>>0]|0;
     $770 = $769&255;
     $771 = $683 >>> $770;
     $772 = HEAP8[$34>>0]|0;
     $773 = $772&255;
     $774 = $771 << $773;
     $775 = $768 | $774;
     $776 = HEAP8[$35>>0]|0;
     $777 = $776&255;
     $778 = $687 >>> $777;
     $779 = HEAP8[$36>>0]|0;
     $780 = $779&255;
     $781 = $778 << $780;
     $782 = $775 | $781;
     HEAP32[$$2781>>2] = $782;
     break;
    }
    default: {
    }
    }
    $783 = (($$2) + ($15)|0);
    $784 = (($$2781) + ($18)|0);
    $$2814 = $$1813;$$3 = $783;$$3782 = $784;
    label = 38;
    continue;
   }
   else if ((label|0) == 38) {
    label = 0;
    switch ($14<<24>>24) {
    case 1:  {
     $785 = HEAP8[$$3>>0]|0;
     $786 = $785&255;
     $787 = HEAP8[$41>>0]|0;
     $788 = $787&255;
     $789 = (79212 + ($788<<2)|0);
     $790 = HEAP32[$789>>2]|0;
     $791 = HEAP32[$42>>2]|0;
     $792 = $791 & $786;
     $793 = HEAP8[$43>>0]|0;
     $794 = $793&255;
     $795 = $792 >>> $794;
     $796 = (($790) + ($795)|0);
     $797 = HEAP8[$44>>0]|0;
     $798 = $797&255;
     $799 = (79212 + ($798<<2)|0);
     $800 = HEAP32[$799>>2]|0;
     $801 = HEAP32[$45>>2]|0;
     $802 = $801 & $786;
     $803 = HEAP8[$46>>0]|0;
     $804 = $803&255;
     $805 = $802 >>> $804;
     $806 = (($800) + ($805)|0);
     $807 = HEAP8[$47>>0]|0;
     $808 = $807&255;
     $809 = (79212 + ($808<<2)|0);
     $810 = HEAP32[$809>>2]|0;
     $811 = HEAP32[$48>>2]|0;
     $812 = $811 & $786;
     $813 = HEAP8[$49>>0]|0;
     $814 = $813&255;
     $815 = $812 >>> $814;
     $816 = (($810) + ($815)|0);
     $$2786$shrunk$ph$in = $796;$$2790$shrunk$ph$in = $806;$$sink866 = $816;
     label = 43;
     break;
    }
    case 2:  {
     $817 = HEAP16[$$3>>1]|0;
     $818 = $817&65535;
     $819 = HEAP8[$41>>0]|0;
     $820 = $819&255;
     $821 = (79212 + ($820<<2)|0);
     $822 = HEAP32[$821>>2]|0;
     $823 = HEAP32[$42>>2]|0;
     $824 = $823 & $818;
     $825 = HEAP8[$43>>0]|0;
     $826 = $825&255;
     $827 = $824 >>> $826;
     $828 = (($822) + ($827)|0);
     $829 = HEAP8[$44>>0]|0;
     $830 = $829&255;
     $831 = (79212 + ($830<<2)|0);
     $832 = HEAP32[$831>>2]|0;
     $833 = HEAP32[$45>>2]|0;
     $834 = $833 & $818;
     $835 = HEAP8[$46>>0]|0;
     $836 = $835&255;
     $837 = $834 >>> $836;
     $838 = (($832) + ($837)|0);
     $839 = HEAP8[$47>>0]|0;
     $840 = $839&255;
     $841 = (79212 + ($840<<2)|0);
     $842 = HEAP32[$841>>2]|0;
     $843 = HEAP32[$48>>2]|0;
     $844 = $843 & $818;
     $845 = HEAP8[$49>>0]|0;
     $846 = $845&255;
     $847 = $844 >>> $846;
     $848 = (($842) + ($847)|0);
     $$2786$shrunk$ph$in = $828;$$2790$shrunk$ph$in = $838;$$sink866 = $848;
     label = 43;
     break;
    }
    case 3:  {
     $849 = HEAP8[$43>>0]|0;
     $div833 = ($849&255) >>> 3;
     $850 = $div833&255;
     $851 = (($$3) + ($850)|0);
     $852 = HEAP8[$46>>0]|0;
     $div834 = ($852&255) >>> 3;
     $853 = $div834&255;
     $854 = (($$3) + ($853)|0);
     $855 = HEAP8[$49>>0]|0;
     $div835 = ($855&255) >>> 3;
     $856 = $div835&255;
     $857 = (($$3) + ($856)|0);
     $$2786$shrunk$ph$in = $851;$$2790$shrunk$ph$in = $854;$$sink866 = $857;
     label = 43;
     break;
    }
    case 4:  {
     $858 = HEAP32[$$3>>2]|0;
     $859 = HEAP8[$41>>0]|0;
     $860 = $859&255;
     $861 = (79212 + ($860<<2)|0);
     $862 = HEAP32[$861>>2]|0;
     $863 = HEAP32[$42>>2]|0;
     $864 = $863 & $858;
     $865 = HEAP8[$43>>0]|0;
     $866 = $865&255;
     $867 = $864 >>> $866;
     $868 = (($862) + ($867)|0);
     $869 = HEAP8[$44>>0]|0;
     $870 = $869&255;
     $871 = (79212 + ($870<<2)|0);
     $872 = HEAP32[$871>>2]|0;
     $873 = HEAP32[$45>>2]|0;
     $874 = $873 & $858;
     $875 = HEAP8[$46>>0]|0;
     $876 = $875&255;
     $877 = $874 >>> $876;
     $878 = (($872) + ($877)|0);
     $879 = HEAP8[$47>>0]|0;
     $880 = $879&255;
     $881 = (79212 + ($880<<2)|0);
     $882 = HEAP32[$881>>2]|0;
     $883 = HEAP32[$48>>2]|0;
     $884 = $883 & $858;
     $885 = HEAP8[$49>>0]|0;
     $886 = $885&255;
     $887 = $884 >>> $886;
     $888 = (($882) + ($887)|0);
     $$2786$shrunk$ph$in = $868;$$2790$shrunk$ph$in = $878;$$sink866 = $888;
     label = 43;
     break;
    }
    default: {
     $$2786$shrunk = 0;$$2790$shrunk = 0;$$2794$shrunk = 0;
    }
    }
    if ((label|0) == 43) {
     label = 0;
     $$2786$shrunk$ph = HEAP8[$$2786$shrunk$ph$in>>0]|0;
     $$2790$shrunk$ph = HEAP8[$$2790$shrunk$ph$in>>0]|0;
     $889 = HEAP8[$$sink866>>0]|0;
     $$2786$shrunk = $$2786$shrunk$ph;$$2790$shrunk = $$2790$shrunk$ph;$$2794$shrunk = $889;
    }
    $$2786 = $$2786$shrunk&255;
    $$2790 = $$2790$shrunk&255;
    $$2794 = $$2794$shrunk&255;
    switch ($17<<24>>24) {
    case 1:  {
     $890 = HEAP8[$$3782>>0]|0;
     $891 = $890&255;
     $892 = HEAP8[$29>>0]|0;
     $893 = $892&255;
     $894 = (79212 + ($893<<2)|0);
     $895 = HEAP32[$894>>2]|0;
     $896 = HEAP32[$37>>2]|0;
     $897 = $896 & $891;
     $898 = HEAP8[$30>>0]|0;
     $899 = $898&255;
     $900 = $897 >>> $899;
     $901 = (($895) + ($900)|0);
     $902 = HEAP8[$901>>0]|0;
     $903 = HEAP8[$31>>0]|0;
     $904 = $903&255;
     $905 = (79212 + ($904<<2)|0);
     $906 = HEAP32[$905>>2]|0;
     $907 = HEAP32[$38>>2]|0;
     $908 = $907 & $891;
     $909 = HEAP8[$32>>0]|0;
     $910 = $909&255;
     $911 = $908 >>> $910;
     $912 = (($906) + ($911)|0);
     $913 = HEAP8[$912>>0]|0;
     $914 = HEAP8[$33>>0]|0;
     $915 = $914&255;
     $916 = (79212 + ($915<<2)|0);
     $917 = HEAP32[$916>>2]|0;
     $918 = HEAP32[$39>>2]|0;
     $919 = $918 & $891;
     $920 = HEAP8[$34>>0]|0;
     $921 = $920&255;
     $922 = $919 >>> $921;
     $923 = (($917) + ($922)|0);
     $924 = HEAP8[$923>>0]|0;
     $925 = HEAP8[$35>>0]|0;
     $926 = $925&255;
     $927 = (79212 + ($926<<2)|0);
     $928 = HEAP32[$927>>2]|0;
     $929 = HEAP32[$40>>2]|0;
     $930 = $929 & $891;
     $931 = HEAP8[$36>>0]|0;
     $932 = $931&255;
     $933 = $930 >>> $932;
     $934 = (($928) + ($933)|0);
     $935 = HEAP8[$934>>0]|0;
     $$2798$shrunk = $902;$$2802$shrunk = $913;$$2806$shrunk = $924;$$2810$shrunk = $935;
     break;
    }
    case 2:  {
     $936 = HEAP16[$$3782>>1]|0;
     $937 = $936&65535;
     $938 = HEAP8[$29>>0]|0;
     $939 = $938&255;
     $940 = (79212 + ($939<<2)|0);
     $941 = HEAP32[$940>>2]|0;
     $942 = HEAP32[$37>>2]|0;
     $943 = $942 & $937;
     $944 = HEAP8[$30>>0]|0;
     $945 = $944&255;
     $946 = $943 >>> $945;
     $947 = (($941) + ($946)|0);
     $948 = HEAP8[$947>>0]|0;
     $949 = HEAP8[$31>>0]|0;
     $950 = $949&255;
     $951 = (79212 + ($950<<2)|0);
     $952 = HEAP32[$951>>2]|0;
     $953 = HEAP32[$38>>2]|0;
     $954 = $953 & $937;
     $955 = HEAP8[$32>>0]|0;
     $956 = $955&255;
     $957 = $954 >>> $956;
     $958 = (($952) + ($957)|0);
     $959 = HEAP8[$958>>0]|0;
     $960 = HEAP8[$33>>0]|0;
     $961 = $960&255;
     $962 = (79212 + ($961<<2)|0);
     $963 = HEAP32[$962>>2]|0;
     $964 = HEAP32[$39>>2]|0;
     $965 = $964 & $937;
     $966 = HEAP8[$34>>0]|0;
     $967 = $966&255;
     $968 = $965 >>> $967;
     $969 = (($963) + ($968)|0);
     $970 = HEAP8[$969>>0]|0;
     $971 = HEAP8[$35>>0]|0;
     $972 = $971&255;
     $973 = (79212 + ($972<<2)|0);
     $974 = HEAP32[$973>>2]|0;
     $975 = HEAP32[$40>>2]|0;
     $976 = $975 & $937;
     $977 = HEAP8[$36>>0]|0;
     $978 = $977&255;
     $979 = $976 >>> $978;
     $980 = (($974) + ($979)|0);
     $981 = HEAP8[$980>>0]|0;
     $$2798$shrunk = $948;$$2802$shrunk = $959;$$2806$shrunk = $970;$$2810$shrunk = $981;
     break;
    }
    case 3:  {
     $982 = HEAP8[$30>>0]|0;
     $div830 = ($982&255) >>> 3;
     $983 = $div830&255;
     $984 = (($$3782) + ($983)|0);
     $985 = HEAP8[$984>>0]|0;
     $986 = HEAP8[$32>>0]|0;
     $div831 = ($986&255) >>> 3;
     $987 = $div831&255;
     $988 = (($$3782) + ($987)|0);
     $989 = HEAP8[$988>>0]|0;
     $990 = HEAP8[$34>>0]|0;
     $div832 = ($990&255) >>> 3;
     $991 = $div832&255;
     $992 = (($$3782) + ($991)|0);
     $993 = HEAP8[$992>>0]|0;
     $$2798$shrunk = $985;$$2802$shrunk = $989;$$2806$shrunk = $993;$$2810$shrunk = -1;
     break;
    }
    case 4:  {
     $994 = HEAP32[$$3782>>2]|0;
     $995 = HEAP8[$29>>0]|0;
     $996 = $995&255;
     $997 = (79212 + ($996<<2)|0);
     $998 = HEAP32[$997>>2]|0;
     $999 = HEAP32[$37>>2]|0;
     $1000 = $999 & $994;
     $1001 = HEAP8[$30>>0]|0;
     $1002 = $1001&255;
     $1003 = $1000 >>> $1002;
     $1004 = (($998) + ($1003)|0);
     $1005 = HEAP8[$1004>>0]|0;
     $1006 = HEAP8[$31>>0]|0;
     $1007 = $1006&255;
     $1008 = (79212 + ($1007<<2)|0);
     $1009 = HEAP32[$1008>>2]|0;
     $1010 = HEAP32[$38>>2]|0;
     $1011 = $1010 & $994;
     $1012 = HEAP8[$32>>0]|0;
     $1013 = $1012&255;
     $1014 = $1011 >>> $1013;
     $1015 = (($1009) + ($1014)|0);
     $1016 = HEAP8[$1015>>0]|0;
     $1017 = HEAP8[$33>>0]|0;
     $1018 = $1017&255;
     $1019 = (79212 + ($1018<<2)|0);
     $1020 = HEAP32[$1019>>2]|0;
     $1021 = HEAP32[$39>>2]|0;
     $1022 = $1021 & $994;
     $1023 = HEAP8[$34>>0]|0;
     $1024 = $1023&255;
     $1025 = $1022 >>> $1024;
     $1026 = (($1020) + ($1025)|0);
     $1027 = HEAP8[$1026>>0]|0;
     $1028 = HEAP8[$35>>0]|0;
     $1029 = $1028&255;
     $1030 = (79212 + ($1029<<2)|0);
     $1031 = HEAP32[$1030>>2]|0;
     $1032 = HEAP32[$40>>2]|0;
     $1033 = $1032 & $994;
     $1034 = HEAP8[$36>>0]|0;
     $1035 = $1034&255;
     $1036 = $1033 >>> $1035;
     $1037 = (($1031) + ($1036)|0);
     $1038 = HEAP8[$1037>>0]|0;
     $$2798$shrunk = $1005;$$2802$shrunk = $1016;$$2806$shrunk = $1027;$$2810$shrunk = $1038;
     break;
    }
    default: {
     $$2798$shrunk = 0;$$2802$shrunk = 0;$$2806$shrunk = 0;$$2810$shrunk = 0;
    }
    }
    $$2798 = $$2798$shrunk&255;
    $$2802 = $$2802$shrunk&255;
    $$2806 = $$2806$shrunk&255;
    $$2810 = $$2810$shrunk&255;
    $1039 = (($$2786) - ($$2798))|0;
    $1040 = Math_imul($1039, $21)|0;
    $1041 = (($1040>>>0) / 255)&-1;
    $1042 = (($1041) + ($$2798))|0;
    $1043 = (($$2790) - ($$2802))|0;
    $1044 = Math_imul($1043, $21)|0;
    $1045 = (($1044>>>0) / 255)&-1;
    $1046 = (($1045) + ($$2802))|0;
    $1047 = (($$2794) - ($$2806))|0;
    $1048 = Math_imul($1047, $21)|0;
    $1049 = (($1048>>>0) / 255)&-1;
    $1050 = (($1049) + ($$2806))|0;
    $1051 = (($$2810) + ($21))|0;
    $1052 = Math_imul($$2810, $21)|0;
    $1053 = (($1052>>>0) / 255)&-1;
    $1054 = (($1051) - ($1053))|0;
    switch ($17<<24>>24) {
    case 1:  {
     $1055 = HEAP8[$29>>0]|0;
     $1056 = $1055&255;
     $1057 = $1042 >>> $1056;
     $1058 = HEAP8[$30>>0]|0;
     $1059 = $1058&255;
     $1060 = $1057 << $1059;
     $1061 = HEAP8[$31>>0]|0;
     $1062 = $1061&255;
     $1063 = $1046 >>> $1062;
     $1064 = HEAP8[$32>>0]|0;
     $1065 = $1064&255;
     $1066 = $1063 << $1065;
     $1067 = $1066 | $1060;
     $1068 = HEAP8[$33>>0]|0;
     $1069 = $1068&255;
     $1070 = $1050 >>> $1069;
     $1071 = HEAP8[$34>>0]|0;
     $1072 = $1071&255;
     $1073 = $1070 << $1072;
     $1074 = $1067 | $1073;
     $1075 = HEAP8[$35>>0]|0;
     $1076 = $1075&255;
     $1077 = $1054 >>> $1076;
     $1078 = HEAP8[$36>>0]|0;
     $1079 = $1078&255;
     $1080 = $1077 << $1079;
     $1081 = $1074 | $1080;
     $1082 = $1081&255;
     HEAP8[$$3782>>0] = $1082;
     break;
    }
    case 2:  {
     $1083 = HEAP8[$29>>0]|0;
     $1084 = $1083&255;
     $1085 = $1042 >>> $1084;
     $1086 = HEAP8[$30>>0]|0;
     $1087 = $1086&255;
     $1088 = $1085 << $1087;
     $1089 = HEAP8[$31>>0]|0;
     $1090 = $1089&255;
     $1091 = $1046 >>> $1090;
     $1092 = HEAP8[$32>>0]|0;
     $1093 = $1092&255;
     $1094 = $1091 << $1093;
     $1095 = $1094 | $1088;
     $1096 = HEAP8[$33>>0]|0;
     $1097 = $1096&255;
     $1098 = $1050 >>> $1097;
     $1099 = HEAP8[$34>>0]|0;
     $1100 = $1099&255;
     $1101 = $1098 << $1100;
     $1102 = $1095 | $1101;
     $1103 = HEAP8[$35>>0]|0;
     $1104 = $1103&255;
     $1105 = $1054 >>> $1104;
     $1106 = HEAP8[$36>>0]|0;
     $1107 = $1106&255;
     $1108 = $1105 << $1107;
     $1109 = $1102 | $1108;
     $1110 = $1109&65535;
     HEAP16[$$3782>>1] = $1110;
     break;
    }
    case 3:  {
     $1111 = $1042&255;
     $1112 = HEAP8[$30>>0]|0;
     $div = ($1112&255) >>> 3;
     $1113 = $div&255;
     $1114 = (($$3782) + ($1113)|0);
     HEAP8[$1114>>0] = $1111;
     $1115 = $1046&255;
     $1116 = HEAP8[$32>>0]|0;
     $div828 = ($1116&255) >>> 3;
     $1117 = $div828&255;
     $1118 = (($$3782) + ($1117)|0);
     HEAP8[$1118>>0] = $1115;
     $1119 = $1050&255;
     $1120 = HEAP8[$34>>0]|0;
     $div829 = ($1120&255) >>> 3;
     $1121 = $div829&255;
     $1122 = (($$3782) + ($1121)|0);
     HEAP8[$1122>>0] = $1119;
     break;
    }
    case 4:  {
     $1123 = HEAP8[$29>>0]|0;
     $1124 = $1123&255;
     $1125 = $1042 >>> $1124;
     $1126 = HEAP8[$30>>0]|0;
     $1127 = $1126&255;
     $1128 = $1125 << $1127;
     $1129 = HEAP8[$31>>0]|0;
     $1130 = $1129&255;
     $1131 = $1046 >>> $1130;
     $1132 = HEAP8[$32>>0]|0;
     $1133 = $1132&255;
     $1134 = $1131 << $1133;
     $1135 = $1134 | $1128;
     $1136 = HEAP8[$33>>0]|0;
     $1137 = $1136&255;
     $1138 = $1050 >>> $1137;
     $1139 = HEAP8[$34>>0]|0;
     $1140 = $1139&255;
     $1141 = $1138 << $1140;
     $1142 = $1135 | $1141;
     $1143 = HEAP8[$35>>0]|0;
     $1144 = $1143&255;
     $1145 = $1054 >>> $1144;
     $1146 = HEAP8[$36>>0]|0;
     $1147 = $1146&255;
     $1148 = $1145 << $1147;
     $1149 = $1142 | $1148;
     HEAP32[$$3782>>2] = $1149;
     break;
    }
    default: {
    }
    }
    $1150 = (($$3) + ($15)|0);
    $1151 = (($$3782) + ($18)|0);
    $$3815 = $$2814;$$4 = $1150;$$4783 = $1151;
    label = 55;
    continue;
   }
   else if ((label|0) == 55) {
    label = 0;
    switch ($14<<24>>24) {
    case 1:  {
     $1152 = HEAP8[$$4>>0]|0;
     $1153 = $1152&255;
     $1154 = HEAP8[$41>>0]|0;
     $1155 = $1154&255;
     $1156 = (79212 + ($1155<<2)|0);
     $1157 = HEAP32[$1156>>2]|0;
     $1158 = HEAP32[$42>>2]|0;
     $1159 = $1158 & $1153;
     $1160 = HEAP8[$43>>0]|0;
     $1161 = $1160&255;
     $1162 = $1159 >>> $1161;
     $1163 = (($1157) + ($1162)|0);
     $1164 = HEAP8[$44>>0]|0;
     $1165 = $1164&255;
     $1166 = (79212 + ($1165<<2)|0);
     $1167 = HEAP32[$1166>>2]|0;
     $1168 = HEAP32[$45>>2]|0;
     $1169 = $1168 & $1153;
     $1170 = HEAP8[$46>>0]|0;
     $1171 = $1170&255;
     $1172 = $1169 >>> $1171;
     $1173 = (($1167) + ($1172)|0);
     $1174 = HEAP8[$47>>0]|0;
     $1175 = $1174&255;
     $1176 = (79212 + ($1175<<2)|0);
     $1177 = HEAP32[$1176>>2]|0;
     $1178 = HEAP32[$48>>2]|0;
     $1179 = $1178 & $1153;
     $1180 = HEAP8[$49>>0]|0;
     $1181 = $1180&255;
     $1182 = $1179 >>> $1181;
     $1183 = (($1177) + ($1182)|0);
     $$3787$shrunk$ph$in = $1163;$$3791$shrunk$ph$in = $1173;$$sink868 = $1183;
     label = 60;
     break;
    }
    case 2:  {
     $1184 = HEAP16[$$4>>1]|0;
     $1185 = $1184&65535;
     $1186 = HEAP8[$41>>0]|0;
     $1187 = $1186&255;
     $1188 = (79212 + ($1187<<2)|0);
     $1189 = HEAP32[$1188>>2]|0;
     $1190 = HEAP32[$42>>2]|0;
     $1191 = $1190 & $1185;
     $1192 = HEAP8[$43>>0]|0;
     $1193 = $1192&255;
     $1194 = $1191 >>> $1193;
     $1195 = (($1189) + ($1194)|0);
     $1196 = HEAP8[$44>>0]|0;
     $1197 = $1196&255;
     $1198 = (79212 + ($1197<<2)|0);
     $1199 = HEAP32[$1198>>2]|0;
     $1200 = HEAP32[$45>>2]|0;
     $1201 = $1200 & $1185;
     $1202 = HEAP8[$46>>0]|0;
     $1203 = $1202&255;
     $1204 = $1201 >>> $1203;
     $1205 = (($1199) + ($1204)|0);
     $1206 = HEAP8[$47>>0]|0;
     $1207 = $1206&255;
     $1208 = (79212 + ($1207<<2)|0);
     $1209 = HEAP32[$1208>>2]|0;
     $1210 = HEAP32[$48>>2]|0;
     $1211 = $1210 & $1185;
     $1212 = HEAP8[$49>>0]|0;
     $1213 = $1212&255;
     $1214 = $1211 >>> $1213;
     $1215 = (($1209) + ($1214)|0);
     $$3787$shrunk$ph$in = $1195;$$3791$shrunk$ph$in = $1205;$$sink868 = $1215;
     label = 60;
     break;
    }
    case 3:  {
     $1216 = HEAP8[$43>>0]|0;
     $div860 = ($1216&255) >>> 3;
     $1217 = $div860&255;
     $1218 = (($$4) + ($1217)|0);
     $1219 = HEAP8[$46>>0]|0;
     $div861 = ($1219&255) >>> 3;
     $1220 = $div861&255;
     $1221 = (($$4) + ($1220)|0);
     $1222 = HEAP8[$49>>0]|0;
     $div862 = ($1222&255) >>> 3;
     $1223 = $div862&255;
     $1224 = (($$4) + ($1223)|0);
     $$3787$shrunk$ph$in = $1218;$$3791$shrunk$ph$in = $1221;$$sink868 = $1224;
     label = 60;
     break;
    }
    case 4:  {
     $1225 = HEAP32[$$4>>2]|0;
     $1226 = HEAP8[$41>>0]|0;
     $1227 = $1226&255;
     $1228 = (79212 + ($1227<<2)|0);
     $1229 = HEAP32[$1228>>2]|0;
     $1230 = HEAP32[$42>>2]|0;
     $1231 = $1230 & $1225;
     $1232 = HEAP8[$43>>0]|0;
     $1233 = $1232&255;
     $1234 = $1231 >>> $1233;
     $1235 = (($1229) + ($1234)|0);
     $1236 = HEAP8[$44>>0]|0;
     $1237 = $1236&255;
     $1238 = (79212 + ($1237<<2)|0);
     $1239 = HEAP32[$1238>>2]|0;
     $1240 = HEAP32[$45>>2]|0;
     $1241 = $1240 & $1225;
     $1242 = HEAP8[$46>>0]|0;
     $1243 = $1242&255;
     $1244 = $1241 >>> $1243;
     $1245 = (($1239) + ($1244)|0);
     $1246 = HEAP8[$47>>0]|0;
     $1247 = $1246&255;
     $1248 = (79212 + ($1247<<2)|0);
     $1249 = HEAP32[$1248>>2]|0;
     $1250 = HEAP32[$48>>2]|0;
     $1251 = $1250 & $1225;
     $1252 = HEAP8[$49>>0]|0;
     $1253 = $1252&255;
     $1254 = $1251 >>> $1253;
     $1255 = (($1249) + ($1254)|0);
     $$3787$shrunk$ph$in = $1235;$$3791$shrunk$ph$in = $1245;$$sink868 = $1255;
     label = 60;
     break;
    }
    default: {
     $$3787$shrunk = 0;$$3791$shrunk = 0;$$3795$shrunk = 0;
    }
    }
    if ((label|0) == 60) {
     label = 0;
     $$3787$shrunk$ph = HEAP8[$$3787$shrunk$ph$in>>0]|0;
     $$3791$shrunk$ph = HEAP8[$$3791$shrunk$ph$in>>0]|0;
     $1256 = HEAP8[$$sink868>>0]|0;
     $$3787$shrunk = $$3787$shrunk$ph;$$3791$shrunk = $$3791$shrunk$ph;$$3795$shrunk = $1256;
    }
    $$3787 = $$3787$shrunk&255;
    $$3791 = $$3791$shrunk&255;
    $$3795 = $$3795$shrunk&255;
    switch ($17<<24>>24) {
    case 1:  {
     $1257 = HEAP8[$$4783>>0]|0;
     $1258 = $1257&255;
     $1259 = HEAP8[$29>>0]|0;
     $1260 = $1259&255;
     $1261 = (79212 + ($1260<<2)|0);
     $1262 = HEAP32[$1261>>2]|0;
     $1263 = HEAP32[$37>>2]|0;
     $1264 = $1263 & $1258;
     $1265 = HEAP8[$30>>0]|0;
     $1266 = $1265&255;
     $1267 = $1264 >>> $1266;
     $1268 = (($1262) + ($1267)|0);
     $1269 = HEAP8[$1268>>0]|0;
     $1270 = HEAP8[$31>>0]|0;
     $1271 = $1270&255;
     $1272 = (79212 + ($1271<<2)|0);
     $1273 = HEAP32[$1272>>2]|0;
     $1274 = HEAP32[$38>>2]|0;
     $1275 = $1274 & $1258;
     $1276 = HEAP8[$32>>0]|0;
     $1277 = $1276&255;
     $1278 = $1275 >>> $1277;
     $1279 = (($1273) + ($1278)|0);
     $1280 = HEAP8[$1279>>0]|0;
     $1281 = HEAP8[$33>>0]|0;
     $1282 = $1281&255;
     $1283 = (79212 + ($1282<<2)|0);
     $1284 = HEAP32[$1283>>2]|0;
     $1285 = HEAP32[$39>>2]|0;
     $1286 = $1285 & $1258;
     $1287 = HEAP8[$34>>0]|0;
     $1288 = $1287&255;
     $1289 = $1286 >>> $1288;
     $1290 = (($1284) + ($1289)|0);
     $1291 = HEAP8[$1290>>0]|0;
     $1292 = HEAP8[$35>>0]|0;
     $1293 = $1292&255;
     $1294 = (79212 + ($1293<<2)|0);
     $1295 = HEAP32[$1294>>2]|0;
     $1296 = HEAP32[$40>>2]|0;
     $1297 = $1296 & $1258;
     $1298 = HEAP8[$36>>0]|0;
     $1299 = $1298&255;
     $1300 = $1297 >>> $1299;
     $1301 = (($1295) + ($1300)|0);
     $1302 = HEAP8[$1301>>0]|0;
     $$3799$shrunk = $1269;$$3803$shrunk = $1280;$$3807$shrunk = $1291;$$3811$shrunk = $1302;
     break;
    }
    case 2:  {
     $1303 = HEAP16[$$4783>>1]|0;
     $1304 = $1303&65535;
     $1305 = HEAP8[$29>>0]|0;
     $1306 = $1305&255;
     $1307 = (79212 + ($1306<<2)|0);
     $1308 = HEAP32[$1307>>2]|0;
     $1309 = HEAP32[$37>>2]|0;
     $1310 = $1309 & $1304;
     $1311 = HEAP8[$30>>0]|0;
     $1312 = $1311&255;
     $1313 = $1310 >>> $1312;
     $1314 = (($1308) + ($1313)|0);
     $1315 = HEAP8[$1314>>0]|0;
     $1316 = HEAP8[$31>>0]|0;
     $1317 = $1316&255;
     $1318 = (79212 + ($1317<<2)|0);
     $1319 = HEAP32[$1318>>2]|0;
     $1320 = HEAP32[$38>>2]|0;
     $1321 = $1320 & $1304;
     $1322 = HEAP8[$32>>0]|0;
     $1323 = $1322&255;
     $1324 = $1321 >>> $1323;
     $1325 = (($1319) + ($1324)|0);
     $1326 = HEAP8[$1325>>0]|0;
     $1327 = HEAP8[$33>>0]|0;
     $1328 = $1327&255;
     $1329 = (79212 + ($1328<<2)|0);
     $1330 = HEAP32[$1329>>2]|0;
     $1331 = HEAP32[$39>>2]|0;
     $1332 = $1331 & $1304;
     $1333 = HEAP8[$34>>0]|0;
     $1334 = $1333&255;
     $1335 = $1332 >>> $1334;
     $1336 = (($1330) + ($1335)|0);
     $1337 = HEAP8[$1336>>0]|0;
     $1338 = HEAP8[$35>>0]|0;
     $1339 = $1338&255;
     $1340 = (79212 + ($1339<<2)|0);
     $1341 = HEAP32[$1340>>2]|0;
     $1342 = HEAP32[$40>>2]|0;
     $1343 = $1342 & $1304;
     $1344 = HEAP8[$36>>0]|0;
     $1345 = $1344&255;
     $1346 = $1343 >>> $1345;
     $1347 = (($1341) + ($1346)|0);
     $1348 = HEAP8[$1347>>0]|0;
     $$3799$shrunk = $1315;$$3803$shrunk = $1326;$$3807$shrunk = $1337;$$3811$shrunk = $1348;
     break;
    }
    case 3:  {
     $1349 = HEAP8[$30>>0]|0;
     $div857 = ($1349&255) >>> 3;
     $1350 = $div857&255;
     $1351 = (($$4783) + ($1350)|0);
     $1352 = HEAP8[$1351>>0]|0;
     $1353 = HEAP8[$32>>0]|0;
     $div858 = ($1353&255) >>> 3;
     $1354 = $div858&255;
     $1355 = (($$4783) + ($1354)|0);
     $1356 = HEAP8[$1355>>0]|0;
     $1357 = HEAP8[$34>>0]|0;
     $div859 = ($1357&255) >>> 3;
     $1358 = $div859&255;
     $1359 = (($$4783) + ($1358)|0);
     $1360 = HEAP8[$1359>>0]|0;
     $$3799$shrunk = $1352;$$3803$shrunk = $1356;$$3807$shrunk = $1360;$$3811$shrunk = -1;
     break;
    }
    case 4:  {
     $1361 = HEAP32[$$4783>>2]|0;
     $1362 = HEAP8[$29>>0]|0;
     $1363 = $1362&255;
     $1364 = (79212 + ($1363<<2)|0);
     $1365 = HEAP32[$1364>>2]|0;
     $1366 = HEAP32[$37>>2]|0;
     $1367 = $1366 & $1361;
     $1368 = HEAP8[$30>>0]|0;
     $1369 = $1368&255;
     $1370 = $1367 >>> $1369;
     $1371 = (($1365) + ($1370)|0);
     $1372 = HEAP8[$1371>>0]|0;
     $1373 = HEAP8[$31>>0]|0;
     $1374 = $1373&255;
     $1375 = (79212 + ($1374<<2)|0);
     $1376 = HEAP32[$1375>>2]|0;
     $1377 = HEAP32[$38>>2]|0;
     $1378 = $1377 & $1361;
     $1379 = HEAP8[$32>>0]|0;
     $1380 = $1379&255;
     $1381 = $1378 >>> $1380;
     $1382 = (($1376) + ($1381)|0);
     $1383 = HEAP8[$1382>>0]|0;
     $1384 = HEAP8[$33>>0]|0;
     $1385 = $1384&255;
     $1386 = (79212 + ($1385<<2)|0);
     $1387 = HEAP32[$1386>>2]|0;
     $1388 = HEAP32[$39>>2]|0;
     $1389 = $1388 & $1361;
     $1390 = HEAP8[$34>>0]|0;
     $1391 = $1390&255;
     $1392 = $1389 >>> $1391;
     $1393 = (($1387) + ($1392)|0);
     $1394 = HEAP8[$1393>>0]|0;
     $1395 = HEAP8[$35>>0]|0;
     $1396 = $1395&255;
     $1397 = (79212 + ($1396<<2)|0);
     $1398 = HEAP32[$1397>>2]|0;
     $1399 = HEAP32[$40>>2]|0;
     $1400 = $1399 & $1361;
     $1401 = HEAP8[$36>>0]|0;
     $1402 = $1401&255;
     $1403 = $1400 >>> $1402;
     $1404 = (($1398) + ($1403)|0);
     $1405 = HEAP8[$1404>>0]|0;
     $$3799$shrunk = $1372;$$3803$shrunk = $1383;$$3807$shrunk = $1394;$$3811$shrunk = $1405;
     break;
    }
    default: {
     $$3799$shrunk = 0;$$3803$shrunk = 0;$$3807$shrunk = 0;$$3811$shrunk = 0;
    }
    }
    $$3799 = $$3799$shrunk&255;
    $$3803 = $$3803$shrunk&255;
    $$3807 = $$3807$shrunk&255;
    $$3811 = $$3811$shrunk&255;
    $1406 = (($$3787) - ($$3799))|0;
    $1407 = Math_imul($1406, $21)|0;
    $1408 = (($1407>>>0) / 255)&-1;
    $1409 = (($1408) + ($$3799))|0;
    $1410 = (($$3791) - ($$3803))|0;
    $1411 = Math_imul($1410, $21)|0;
    $1412 = (($1411>>>0) / 255)&-1;
    $1413 = (($1412) + ($$3803))|0;
    $1414 = (($$3795) - ($$3807))|0;
    $1415 = Math_imul($1414, $21)|0;
    $1416 = (($1415>>>0) / 255)&-1;
    $1417 = (($1416) + ($$3807))|0;
    $1418 = (($$3811) + ($21))|0;
    $1419 = Math_imul($$3811, $21)|0;
    $1420 = (($1419>>>0) / 255)&-1;
    $1421 = (($1418) - ($1420))|0;
    switch ($17<<24>>24) {
    case 1:  {
     $1422 = HEAP8[$29>>0]|0;
     $1423 = $1422&255;
     $1424 = $1409 >>> $1423;
     $1425 = HEAP8[$30>>0]|0;
     $1426 = $1425&255;
     $1427 = $1424 << $1426;
     $1428 = HEAP8[$31>>0]|0;
     $1429 = $1428&255;
     $1430 = $1413 >>> $1429;
     $1431 = HEAP8[$32>>0]|0;
     $1432 = $1431&255;
     $1433 = $1430 << $1432;
     $1434 = $1433 | $1427;
     $1435 = HEAP8[$33>>0]|0;
     $1436 = $1435&255;
     $1437 = $1417 >>> $1436;
     $1438 = HEAP8[$34>>0]|0;
     $1439 = $1438&255;
     $1440 = $1437 << $1439;
     $1441 = $1434 | $1440;
     $1442 = HEAP8[$35>>0]|0;
     $1443 = $1442&255;
     $1444 = $1421 >>> $1443;
     $1445 = HEAP8[$36>>0]|0;
     $1446 = $1445&255;
     $1447 = $1444 << $1446;
     $1448 = $1441 | $1447;
     $1449 = $1448&255;
     HEAP8[$$4783>>0] = $1449;
     break;
    }
    case 2:  {
     $1450 = HEAP8[$29>>0]|0;
     $1451 = $1450&255;
     $1452 = $1409 >>> $1451;
     $1453 = HEAP8[$30>>0]|0;
     $1454 = $1453&255;
     $1455 = $1452 << $1454;
     $1456 = HEAP8[$31>>0]|0;
     $1457 = $1456&255;
     $1458 = $1413 >>> $1457;
     $1459 = HEAP8[$32>>0]|0;
     $1460 = $1459&255;
     $1461 = $1458 << $1460;
     $1462 = $1461 | $1455;
     $1463 = HEAP8[$33>>0]|0;
     $1464 = $1463&255;
     $1465 = $1417 >>> $1464;
     $1466 = HEAP8[$34>>0]|0;
     $1467 = $1466&255;
     $1468 = $1465 << $1467;
     $1469 = $1462 | $1468;
     $1470 = HEAP8[$35>>0]|0;
     $1471 = $1470&255;
     $1472 = $1421 >>> $1471;
     $1473 = HEAP8[$36>>0]|0;
     $1474 = $1473&255;
     $1475 = $1472 << $1474;
     $1476 = $1469 | $1475;
     $1477 = $1476&65535;
     HEAP16[$$4783>>1] = $1477;
     break;
    }
    case 3:  {
     $1478 = $1409&255;
     $1479 = HEAP8[$30>>0]|0;
     $div854 = ($1479&255) >>> 3;
     $1480 = $div854&255;
     $1481 = (($$4783) + ($1480)|0);
     HEAP8[$1481>>0] = $1478;
     $1482 = $1413&255;
     $1483 = HEAP8[$32>>0]|0;
     $div855 = ($1483&255) >>> 3;
     $1484 = $div855&255;
     $1485 = (($$4783) + ($1484)|0);
     HEAP8[$1485>>0] = $1482;
     $1486 = $1417&255;
     $1487 = HEAP8[$34>>0]|0;
     $div856 = ($1487&255) >>> 3;
     $1488 = $div856&255;
     $1489 = (($$4783) + ($1488)|0);
     HEAP8[$1489>>0] = $1486;
     break;
    }
    case 4:  {
     $1490 = HEAP8[$29>>0]|0;
     $1491 = $1490&255;
     $1492 = $1409 >>> $1491;
     $1493 = HEAP8[$30>>0]|0;
     $1494 = $1493&255;
     $1495 = $1492 << $1494;
     $1496 = HEAP8[$31>>0]|0;
     $1497 = $1496&255;
     $1498 = $1413 >>> $1497;
     $1499 = HEAP8[$32>>0]|0;
     $1500 = $1499&255;
     $1501 = $1498 << $1500;
     $1502 = $1501 | $1495;
     $1503 = HEAP8[$33>>0]|0;
     $1504 = $1503&255;
     $1505 = $1417 >>> $1504;
     $1506 = HEAP8[$34>>0]|0;
     $1507 = $1506&255;
     $1508 = $1505 << $1507;
     $1509 = $1502 | $1508;
     $1510 = HEAP8[$35>>0]|0;
     $1511 = $1510&255;
     $1512 = $1421 >>> $1511;
     $1513 = HEAP8[$36>>0]|0;
     $1514 = $1513&255;
     $1515 = $1512 << $1514;
     $1516 = $1509 | $1515;
     HEAP32[$$4783>>2] = $1516;
     break;
    }
    default: {
    }
    }
    $1517 = (($$4) + ($15)|0);
    $1518 = (($$4783) + ($18)|0);
    $1519 = (($$3815) + -1)|0;
    $1520 = ($$3815|0)>(1);
    if ($1520) {
     $$0812 = $1519;$$1 = $1517;$$1780 = $1518;
     label = 4;
     continue;
    } else {
     break;
    }
   }
  }
  $1521 = (($1517) + ($6)|0);
  $1522 = (($1518) + ($8)|0);
  $1523 = ($50|0)==(0);
  if ($1523) {
   label = 74;
   break;
  } else {
   $$0778873 = $1521;$$0779872 = $1522;$$in = $50;
  }
 }
 if ((label|0) == 72) {
  // unreachable;
 }
 else if ((label|0) == 74) {
  return;
 }
}
function _Blit565to565SurfaceAlpha($0) {
 $0 = $0|0;
 var $$0104115 = 0, $$0104115$us = 0, $$0105114 = 0, $$0105114$us = 0, $$0110$us = 0, $$1$us = 0, $$1106$us = 0, $$1111 = 0, $$2 = 0, $$2107 = 0, $$2112 = 0, $$3 = 0, $$3108 = 0, $$3113 = 0, $$4 = 0, $$4109 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0;
 var $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0;
 var $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0;
 var $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0;
 var $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0;
 var $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0;
 var $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $trunc = 0, $trunc$clear = 0, $trunc$clear1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 63|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(-128);
 if ($3) {
  _Blit16to16SurfaceAlpha128($0,-2082);
  return;
 }
 $4 = $2&255;
 $5 = ((($0)) + 24|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($0)) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$0>>2]|0;
 $10 = ((($0)) + 16|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11 >> 1;
 $13 = ((($0)) + 20|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ((($0)) + 36|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $16 >> 1;
 $18 = $4 >>> 3;
 $19 = (($8) + -1)|0;
 $20 = ($8|0)==(0);
 if ($20) {
  return;
 }
 $21 = (($6) + 3)|0;
 $22 = (($21|0) / 4)&-1;
 $trunc = $6&255;
 $trunc$clear = $trunc & 3;
 $23 = ($trunc$clear<<24>>24)==(0);
 if ($23) {
  $$0104115$us = $9;$$0105114$us = $14;$109 = $19;
  while(1) {
   $$0110$us = $22;$$1$us = $$0104115$us;$$1106$us = $$0105114$us;
   while(1) {
    $24 = ((($$1$us)) + 2|0);
    $25 = HEAP16[$$1$us>>1]|0;
    $26 = $25&65535;
    $27 = HEAP16[$$1106$us>>1]|0;
    $28 = $27&65535;
    $29 = $26 << 16;
    $30 = $29 | $26;
    $31 = $30 & 132184095;
    $32 = $28 << 16;
    $33 = $32 | $28;
    $34 = $33 & 132184095;
    $35 = (($31) - ($34))|0;
    $36 = Math_imul($35, $18)|0;
    $37 = $36 >>> 5;
    $38 = (($37) + ($34))|0;
    $39 = $38 & 132184095;
    $40 = $39 >>> 16;
    $41 = $40 | $39;
    $42 = $41&65535;
    $43 = ((($$1106$us)) + 2|0);
    HEAP16[$$1106$us>>1] = $42;
    $44 = ((($$1$us)) + 4|0);
    $45 = HEAP16[$24>>1]|0;
    $46 = $45&65535;
    $47 = HEAP16[$43>>1]|0;
    $48 = $47&65535;
    $49 = $46 << 16;
    $50 = $49 | $46;
    $51 = $50 & 132184095;
    $52 = $48 << 16;
    $53 = $52 | $48;
    $54 = $53 & 132184095;
    $55 = (($51) - ($54))|0;
    $56 = Math_imul($55, $18)|0;
    $57 = $56 >>> 5;
    $58 = (($57) + ($54))|0;
    $59 = $58 & 132184095;
    $60 = $59 >>> 16;
    $61 = $60 | $59;
    $62 = $61&65535;
    $63 = ((($$1106$us)) + 4|0);
    HEAP16[$43>>1] = $62;
    $64 = ((($$1$us)) + 6|0);
    $65 = HEAP16[$44>>1]|0;
    $66 = $65&65535;
    $67 = HEAP16[$63>>1]|0;
    $68 = $67&65535;
    $69 = $66 << 16;
    $70 = $69 | $66;
    $71 = $70 & 132184095;
    $72 = $68 << 16;
    $73 = $72 | $68;
    $74 = $73 & 132184095;
    $75 = (($71) - ($74))|0;
    $76 = Math_imul($75, $18)|0;
    $77 = $76 >>> 5;
    $78 = (($77) + ($74))|0;
    $79 = $78 & 132184095;
    $80 = $79 >>> 16;
    $81 = $80 | $79;
    $82 = $81&65535;
    $83 = ((($$1106$us)) + 6|0);
    HEAP16[$63>>1] = $82;
    $84 = ((($$1$us)) + 8|0);
    $85 = HEAP16[$64>>1]|0;
    $86 = $85&65535;
    $87 = HEAP16[$83>>1]|0;
    $88 = $87&65535;
    $89 = $86 << 16;
    $90 = $89 | $86;
    $91 = $90 & 132184095;
    $92 = $88 << 16;
    $93 = $92 | $88;
    $94 = $93 & 132184095;
    $95 = (($91) - ($94))|0;
    $96 = Math_imul($95, $18)|0;
    $97 = $96 >>> 5;
    $98 = (($97) + ($94))|0;
    $99 = $98 & 132184095;
    $100 = $99 >>> 16;
    $101 = $100 | $99;
    $102 = $101&65535;
    $103 = ((($$1106$us)) + 8|0);
    HEAP16[$83>>1] = $102;
    $104 = (($$0110$us) + -1)|0;
    $105 = ($$0110$us|0)>(1);
    if ($105) {
     $$0110$us = $104;$$1$us = $84;$$1106$us = $103;
    } else {
     break;
    }
   }
   $106 = (($84) + ($12<<1)|0);
   $107 = (($103) + ($17<<1)|0);
   $108 = (($109) + -1)|0;
   $110 = ($109|0)==(0);
   if ($110) {
    break;
   } else {
    $$0104115$us = $106;$$0105114$us = $107;$109 = $108;
   }
  }
  return;
 } else {
  $$0104115 = $9;$$0105114 = $14;$196 = $19;
 }
 L15: while(1) {
  $trunc$clear1 = $trunc & 3;
  switch ($trunc$clear1<<24>>24) {
  case 1:  {
   $$3113 = $22;$$4 = $$0104115;$$4109 = $$0105114;
   label = 12;
   break;
  }
  case 3:  {
   $$1111 = $22;$$2 = $$0104115;$$2107 = $$0105114;
   label = 10;
   break;
  }
  case 2:  {
   $$2112 = $22;$$3 = $$0104115;$$3108 = $$0105114;
   label = 11;
   break;
  }
  default: {
   label = 13;
   break L15;
  }
  }
  while(1) {
   if ((label|0) == 10) {
    label = 0;
    $134 = ((($$2)) + 2|0);
    $135 = HEAP16[$$2>>1]|0;
    $136 = $135&65535;
    $137 = HEAP16[$$2107>>1]|0;
    $138 = $137&65535;
    $139 = $136 << 16;
    $140 = $139 | $136;
    $141 = $140 & 132184095;
    $142 = $138 << 16;
    $143 = $142 | $138;
    $144 = $143 & 132184095;
    $145 = (($141) - ($144))|0;
    $146 = Math_imul($145, $18)|0;
    $147 = $146 >>> 5;
    $148 = (($147) + ($144))|0;
    $149 = $148 & 132184095;
    $150 = $149 >>> 16;
    $151 = $150 | $149;
    $152 = $151&65535;
    $153 = ((($$2107)) + 2|0);
    HEAP16[$$2107>>1] = $152;
    $$2112 = $$1111;$$3 = $134;$$3108 = $153;
    label = 11;
    continue;
   }
   else if ((label|0) == 11) {
    label = 0;
    $154 = ((($$3)) + 2|0);
    $155 = HEAP16[$$3>>1]|0;
    $156 = $155&65535;
    $157 = HEAP16[$$3108>>1]|0;
    $158 = $157&65535;
    $159 = $156 << 16;
    $160 = $159 | $156;
    $161 = $160 & 132184095;
    $162 = $158 << 16;
    $163 = $162 | $158;
    $164 = $163 & 132184095;
    $165 = (($161) - ($164))|0;
    $166 = Math_imul($165, $18)|0;
    $167 = $166 >>> 5;
    $168 = (($167) + ($164))|0;
    $169 = $168 & 132184095;
    $170 = $169 >>> 16;
    $171 = $170 | $169;
    $172 = $171&65535;
    $173 = ((($$3108)) + 2|0);
    HEAP16[$$3108>>1] = $172;
    $$3113 = $$2112;$$4 = $154;$$4109 = $173;
    label = 12;
    continue;
   }
   else if ((label|0) == 12) {
    label = 0;
    $114 = ((($$4)) + 2|0);
    $174 = HEAP16[$$4>>1]|0;
    $175 = $174&65535;
    $176 = HEAP16[$$4109>>1]|0;
    $177 = $176&65535;
    $178 = $175 << 16;
    $179 = $178 | $175;
    $180 = $179 & 132184095;
    $181 = $177 << 16;
    $182 = $181 | $177;
    $183 = $182 & 132184095;
    $184 = (($180) - ($183))|0;
    $185 = Math_imul($184, $18)|0;
    $186 = $185 >>> 5;
    $187 = (($186) + ($183))|0;
    $188 = $187 & 132184095;
    $189 = $188 >>> 16;
    $190 = $189 | $188;
    $191 = $190&65535;
    $117 = ((($$4109)) + 2|0);
    HEAP16[$$4109>>1] = $191;
    $192 = ($$3113|0)>(1);
    if (!($192)) {
     break;
    }
    $111 = (($$3113) + -1)|0;
    $112 = ((($$4)) + 4|0);
    $113 = HEAP16[$114>>1]|0;
    $115 = $113&65535;
    $116 = HEAP16[$117>>1]|0;
    $118 = $116&65535;
    $119 = $115 << 16;
    $120 = $119 | $115;
    $121 = $120 & 132184095;
    $122 = $118 << 16;
    $123 = $122 | $118;
    $124 = $123 & 132184095;
    $125 = (($121) - ($124))|0;
    $126 = Math_imul($125, $18)|0;
    $127 = $126 >>> 5;
    $128 = (($127) + ($124))|0;
    $129 = $128 & 132184095;
    $130 = $129 >>> 16;
    $131 = $130 | $129;
    $132 = $131&65535;
    $133 = ((($$4109)) + 4|0);
    HEAP16[$117>>1] = $132;
    $$1111 = $111;$$2 = $112;$$2107 = $133;
    label = 10;
    continue;
   }
  }
  $193 = (($114) + ($12<<1)|0);
  $194 = (($117) + ($17<<1)|0);
  $195 = (($196) + -1)|0;
  $197 = ($196|0)==(0);
  if ($197) {
   label = 15;
   break;
  } else {
   $$0104115 = $193;$$0105114 = $194;$196 = $195;
  }
 }
 if ((label|0) == 13) {
  // unreachable;
 }
 else if ((label|0) == 15) {
  return;
 }
}
function _BlitNto1SurfaceAlphaKey($0) {
 $0 = $0|0;
 var $$0 = 0, $$0715 = 0, $$0715$shrunk = 0, $$0723 = 0, $$0723$shrunk = 0, $$0723$shrunk$ph = 0, $$0723$shrunk$ph$in = 0, $$0731 = 0, $$0731$shrunk = 0, $$0731$shrunk$ph = 0, $$0731$shrunk$ph$in = 0, $$0739 = 0, $$0739$ph = 0, $$0747826 = 0, $$0755825 = 0, $$1 = 0, $$1716 = 0, $$1716$shrunk = 0, $$1724 = 0, $$1724$shrunk = 0;
 var $$1724$shrunk$ph = 0, $$1724$shrunk$ph$in = 0, $$1732 = 0, $$1732$shrunk = 0, $$1732$shrunk$ph = 0, $$1732$shrunk$ph$in = 0, $$1740 = 0, $$1740$ph = 0, $$1748 = 0, $$1756 = 0, $$2 = 0, $$2717 = 0, $$2717$shrunk = 0, $$2725 = 0, $$2725$shrunk = 0, $$2725$shrunk$ph = 0, $$2725$shrunk$ph$in = 0, $$2733 = 0, $$2733$shrunk = 0, $$2733$shrunk$ph = 0;
 var $$2733$shrunk$ph$in = 0, $$2741 = 0, $$2741$ph = 0, $$2749 = 0, $$2757 = 0, $$3 = 0, $$3718 = 0, $$3718$shrunk = 0, $$3726 = 0, $$3726$shrunk = 0, $$3726$shrunk$ph = 0, $$3726$shrunk$ph$in = 0, $$3734 = 0, $$3734$shrunk = 0, $$3734$shrunk$ph = 0, $$3734$shrunk$ph$in = 0, $$3742 = 0, $$3742$ph = 0, $$3750 = 0, $$3758 = 0;
 var $$4 = 0, $$4719 = 0, $$4719$shrunk = 0, $$4727 = 0, $$4727$shrunk = 0, $$4727$shrunk$ph = 0, $$4727$shrunk$ph$in = 0, $$4735 = 0, $$4735$shrunk = 0, $$4735$shrunk$ph = 0, $$4735$shrunk$ph$in = 0, $$4743 = 0, $$4743$ph = 0, $$4751 = 0, $$4759 = 0, $$5 = 0, $$5720 = 0, $$5720$shrunk = 0, $$5728 = 0, $$5728$shrunk = 0;
 var $$5728$shrunk$ph = 0, $$5728$shrunk$ph$in = 0, $$5736 = 0, $$5736$shrunk = 0, $$5736$shrunk$ph = 0, $$5736$shrunk$ph$in = 0, $$5744 = 0, $$5744$ph = 0, $$5752 = 0, $$5760 = 0, $$6 = 0, $$6721 = 0, $$6721$shrunk = 0, $$6729 = 0, $$6729$shrunk = 0, $$6729$shrunk$ph = 0, $$6729$shrunk$ph$in = 0, $$6737 = 0, $$6737$shrunk = 0, $$6737$shrunk$ph = 0;
 var $$6737$shrunk$ph$in = 0, $$6745 = 0, $$6745$ph = 0, $$6753 = 0, $$6761 = 0, $$7 = 0, $$7722 = 0, $$7722$shrunk = 0, $$7730 = 0, $$7730$shrunk = 0, $$7730$shrunk$ph = 0, $$7730$shrunk$ph$in = 0, $$7738 = 0, $$7738$shrunk = 0, $$7738$shrunk$ph = 0, $$7738$shrunk$ph$in = 0, $$7746 = 0, $$7746$ph = 0, $$7754 = 0, $$7762 = 0;
 var $$8 = 0, $$8763 = 0, $$in = 0, $$sink = 0, $$sink796 = 0, $$sink798 = 0, $$sink800 = 0, $$sink802 = 0, $$sink804 = 0, $$sink806 = 0, $$sink808 = 0, $$sink810 = 0, $$sink812 = 0, $$sink814 = 0, $$sink816 = 0, $$sink818 = 0, $$sink820 = 0, $$sink822 = 0, $$sink824 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $1000 = 0, $1001 = 0, $1002 = 0, $1003 = 0, $1004 = 0, $1005 = 0, $1006 = 0, $1007 = 0, $1008 = 0, $1009 = 0, $101 = 0, $1010 = 0, $1011 = 0, $1012 = 0, $1013 = 0, $1014 = 0, $1015 = 0, $1016 = 0;
 var $1017 = 0, $1018 = 0, $1019 = 0, $102 = 0, $1020 = 0, $1021 = 0, $1022 = 0, $1023 = 0, $1024 = 0, $1025 = 0, $1026 = 0, $1027 = 0, $1028 = 0, $1029 = 0, $103 = 0, $1030 = 0, $1031 = 0, $1032 = 0, $1033 = 0, $1034 = 0;
 var $1035 = 0, $1036 = 0, $1037 = 0, $1038 = 0, $1039 = 0, $104 = 0, $1040 = 0, $1041 = 0, $1042 = 0, $1043 = 0, $1044 = 0, $1045 = 0, $1046 = 0, $1047 = 0, $1048 = 0, $1049 = 0, $105 = 0, $1050 = 0, $1051 = 0, $1052 = 0;
 var $1053 = 0, $1054 = 0, $1055 = 0, $1056 = 0, $1057 = 0, $1058 = 0, $1059 = 0, $106 = 0, $1060 = 0, $1061 = 0, $1062 = 0, $1063 = 0, $1064 = 0, $1065 = 0, $1066 = 0, $1067 = 0, $1068 = 0, $1069 = 0, $107 = 0, $1070 = 0;
 var $1071 = 0, $1072 = 0, $1073 = 0, $1074 = 0, $1075 = 0, $1076 = 0, $1077 = 0, $1078 = 0, $1079 = 0, $108 = 0, $1080 = 0, $1081 = 0, $1082 = 0, $1083 = 0, $1084 = 0, $1085 = 0, $1086 = 0, $1087 = 0, $1088 = 0, $1089 = 0;
 var $109 = 0, $1090 = 0, $1091 = 0, $1092 = 0, $1093 = 0, $1094 = 0, $1095 = 0, $1096 = 0, $1097 = 0, $1098 = 0, $1099 = 0, $11 = 0, $110 = 0, $1100 = 0, $1101 = 0, $1102 = 0, $1103 = 0, $1104 = 0, $1105 = 0, $1106 = 0;
 var $1107 = 0, $1108 = 0, $1109 = 0, $111 = 0, $1110 = 0, $1111 = 0, $1112 = 0, $1113 = 0, $1114 = 0, $1115 = 0, $1116 = 0, $1117 = 0, $1118 = 0, $1119 = 0, $112 = 0, $1120 = 0, $1121 = 0, $1122 = 0, $1123 = 0, $1124 = 0;
 var $1125 = 0, $1126 = 0, $1127 = 0, $1128 = 0, $1129 = 0, $113 = 0, $1130 = 0, $1131 = 0, $1132 = 0, $1133 = 0, $1134 = 0, $1135 = 0, $1136 = 0, $1137 = 0, $1138 = 0, $1139 = 0, $114 = 0, $1140 = 0, $1141 = 0, $1142 = 0;
 var $1143 = 0, $1144 = 0, $1145 = 0, $1146 = 0, $1147 = 0, $1148 = 0, $1149 = 0, $115 = 0, $1150 = 0, $1151 = 0, $1152 = 0, $1153 = 0, $1154 = 0, $1155 = 0, $1156 = 0, $1157 = 0, $1158 = 0, $1159 = 0, $116 = 0, $1160 = 0;
 var $1161 = 0, $1162 = 0, $1163 = 0, $1164 = 0, $1165 = 0, $1166 = 0, $1167 = 0, $1168 = 0, $1169 = 0, $117 = 0, $1170 = 0, $1171 = 0, $1172 = 0, $1173 = 0, $1174 = 0, $1175 = 0, $1176 = 0, $1177 = 0, $1178 = 0, $1179 = 0;
 var $118 = 0, $1180 = 0, $1181 = 0, $1182 = 0, $1183 = 0, $1184 = 0, $1185 = 0, $1186 = 0, $1187 = 0, $1188 = 0, $1189 = 0, $119 = 0, $1190 = 0, $1191 = 0, $1192 = 0, $1193 = 0, $1194 = 0, $1195 = 0, $1196 = 0, $1197 = 0;
 var $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0;
 var $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0;
 var $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0;
 var $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0;
 var $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0;
 var $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0;
 var $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0;
 var $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0;
 var $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0;
 var $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0;
 var $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0;
 var $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0;
 var $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0;
 var $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0;
 var $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0;
 var $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0;
 var $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0;
 var $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0;
 var $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0;
 var $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0;
 var $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0;
 var $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0;
 var $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0;
 var $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0;
 var $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0;
 var $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0;
 var $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0;
 var $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0;
 var $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0;
 var $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0;
 var $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0;
 var $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0;
 var $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0;
 var $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0;
 var $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0;
 var $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0;
 var $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0;
 var $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0;
 var $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0;
 var $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = 0, $834 = 0, $835 = 0, $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = 0;
 var $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0, $850 = 0, $851 = 0, $852 = 0, $853 = 0, $854 = 0, $855 = 0, $856 = 0, $857 = 0, $858 = 0;
 var $859 = 0, $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0, $869 = 0, $87 = 0, $870 = 0, $871 = 0, $872 = 0, $873 = 0, $874 = 0, $875 = 0, $876 = 0;
 var $877 = 0, $878 = 0, $879 = 0, $88 = 0, $880 = 0, $881 = 0, $882 = 0, $883 = 0, $884 = 0, $885 = 0, $886 = 0, $887 = 0, $888 = 0, $889 = 0, $89 = 0, $890 = 0, $891 = 0, $892 = 0, $893 = 0, $894 = 0;
 var $895 = 0, $896 = 0, $897 = 0, $898 = 0, $899 = 0, $9 = 0, $90 = 0, $900 = 0, $901 = 0, $902 = 0, $903 = 0, $904 = 0, $905 = 0, $906 = 0, $907 = 0, $908 = 0, $909 = 0, $91 = 0, $910 = 0, $911 = 0;
 var $912 = 0, $913 = 0, $914 = 0, $915 = 0, $916 = 0, $917 = 0, $918 = 0, $919 = 0, $92 = 0, $920 = 0, $921 = 0, $922 = 0, $923 = 0, $924 = 0, $925 = 0, $926 = 0, $927 = 0, $928 = 0, $929 = 0, $93 = 0;
 var $930 = 0, $931 = 0, $932 = 0, $933 = 0, $934 = 0, $935 = 0, $936 = 0, $937 = 0, $938 = 0, $939 = 0, $94 = 0, $940 = 0, $941 = 0, $942 = 0, $943 = 0, $944 = 0, $945 = 0, $946 = 0, $947 = 0, $948 = 0;
 var $949 = 0, $95 = 0, $950 = 0, $951 = 0, $952 = 0, $953 = 0, $954 = 0, $955 = 0, $956 = 0, $957 = 0, $958 = 0, $959 = 0, $96 = 0, $960 = 0, $961 = 0, $962 = 0, $963 = 0, $964 = 0, $965 = 0, $966 = 0;
 var $967 = 0, $968 = 0, $969 = 0, $97 = 0, $970 = 0, $971 = 0, $972 = 0, $973 = 0, $974 = 0, $975 = 0, $976 = 0, $977 = 0, $978 = 0, $979 = 0, $98 = 0, $980 = 0, $981 = 0, $982 = 0, $983 = 0, $984 = 0;
 var $985 = 0, $986 = 0, $987 = 0, $988 = 0, $989 = 0, $99 = 0, $990 = 0, $991 = 0, $992 = 0, $993 = 0, $994 = 0, $995 = 0, $996 = 0, $997 = 0, $998 = 0, $999 = 0, $div = 0, $div772 = 0, $div773 = 0, $div774 = 0;
 var $div775 = 0, $div776 = 0, $div777 = 0, $div778 = 0, $div779 = 0, $div780 = 0, $div781 = 0, $div782 = 0, $div783 = 0, $div784 = 0, $div785 = 0, $div786 = 0, $div787 = 0, $div788 = 0, $div789 = 0, $div790 = 0, $div791 = 0, $div792 = 0, $div793 = 0, $div794 = 0;
 var $trunc = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($0)) + 36|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($0)) + 48|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ((($0)) + 40|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ((($12)) + 9|0);
 $14 = HEAP8[$13>>0]|0;
 $15 = $14&255;
 $16 = ((($0)) + 56|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ((($0)) + 63|0);
 $19 = HEAP8[$18>>0]|0;
 $20 = $19&255;
 $21 = ($4|0)==(0);
 if ($21) {
  return;
 }
 $22 = ((($0)) + 44|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ((($0)) + 20|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = HEAP32[$0>>2]|0;
 $27 = (($2) + 7)|0;
 $28 = (($27|0) / 8)&-1;
 $trunc = $2&255;
 $29 = ((($23)) + 4|0);
 $30 = ($10|0)==(0|0);
 $31 = ((($12)) + 28|0);
 $32 = ((($12)) + 12|0);
 $33 = ((($12)) + 32|0);
 $34 = ((($12)) + 29|0);
 $35 = ((($12)) + 16|0);
 $36 = ((($12)) + 33|0);
 $37 = ((($12)) + 30|0);
 $38 = ((($12)) + 20|0);
 $39 = ((($12)) + 34|0);
 $$0747826 = $26;$$0755825 = $25;$$in = $4;
 L4: while(1) {
  $40 = (($$in) + -1)|0;
  $trunc$clear = $trunc & 7;
  switch ($trunc$clear<<24>>24) {
  case 0:  {
   $$0 = $28;$$1748 = $$0747826;$$1756 = $$0755825;
   label = 4;
   break;
  }
  case 7:  {
   $$1 = $28;$$2749 = $$0747826;$$2757 = $$0755825;
   label = 16;
   break;
  }
  case 6:  {
   $$2 = $28;$$3750 = $$0747826;$$3758 = $$0755825;
   label = 28;
   break;
  }
  case 5:  {
   $$3 = $28;$$4751 = $$0747826;$$4759 = $$0755825;
   label = 40;
   break;
  }
  case 4:  {
   $$4 = $28;$$5752 = $$0747826;$$5760 = $$0755825;
   label = 52;
   break;
  }
  case 3:  {
   $$5 = $28;$$6753 = $$0747826;$$6761 = $$0755825;
   label = 64;
   break;
  }
  case 2:  {
   $$6 = $28;$$7754 = $$0747826;$$7762 = $$0755825;
   label = 76;
   break;
  }
  case 1:  {
   $$7 = $28;$$8 = $$0747826;$$8763 = $$0755825;
   label = 88;
   break;
  }
  default: {
   label = 100;
   break L4;
  }
  }
  while(1) {
   if ((label|0) == 4) {
    label = 0;
    switch ($14<<24>>24) {
    case 1:  {
     $41 = HEAP8[$$1748>>0]|0;
     $42 = $41&255;
     $43 = HEAP8[$31>>0]|0;
     $44 = $43&255;
     $45 = (79212 + ($44<<2)|0);
     $46 = HEAP32[$45>>2]|0;
     $47 = HEAP32[$32>>2]|0;
     $48 = $47 & $42;
     $49 = HEAP8[$33>>0]|0;
     $50 = $49&255;
     $51 = $48 >>> $50;
     $52 = (($46) + ($51)|0);
     $53 = HEAP8[$34>>0]|0;
     $54 = $53&255;
     $55 = (79212 + ($54<<2)|0);
     $56 = HEAP32[$55>>2]|0;
     $57 = HEAP32[$35>>2]|0;
     $58 = $57 & $42;
     $59 = HEAP8[$36>>0]|0;
     $60 = $59&255;
     $61 = $58 >>> $60;
     $62 = (($56) + ($61)|0);
     $63 = HEAP8[$37>>0]|0;
     $64 = $63&255;
     $65 = (79212 + ($64<<2)|0);
     $66 = HEAP32[$65>>2]|0;
     $67 = HEAP32[$38>>2]|0;
     $68 = $67 & $42;
     $69 = HEAP8[$39>>0]|0;
     $70 = $69&255;
     $71 = $68 >>> $70;
     $72 = (($66) + ($71)|0);
     $$0723$shrunk$ph$in = $62;$$0731$shrunk$ph$in = $52;$$0739$ph = $42;$$sink810 = $72;
     label = 9;
     break;
    }
    case 2:  {
     $73 = HEAP16[$$1748>>1]|0;
     $74 = $73&65535;
     $75 = HEAP8[$31>>0]|0;
     $76 = $75&255;
     $77 = (79212 + ($76<<2)|0);
     $78 = HEAP32[$77>>2]|0;
     $79 = HEAP32[$32>>2]|0;
     $80 = $79 & $74;
     $81 = HEAP8[$33>>0]|0;
     $82 = $81&255;
     $83 = $80 >>> $82;
     $84 = (($78) + ($83)|0);
     $85 = HEAP8[$34>>0]|0;
     $86 = $85&255;
     $87 = (79212 + ($86<<2)|0);
     $88 = HEAP32[$87>>2]|0;
     $89 = HEAP32[$35>>2]|0;
     $90 = $89 & $74;
     $91 = HEAP8[$36>>0]|0;
     $92 = $91&255;
     $93 = $90 >>> $92;
     $94 = (($88) + ($93)|0);
     $95 = HEAP8[$37>>0]|0;
     $96 = $95&255;
     $97 = (79212 + ($96<<2)|0);
     $98 = HEAP32[$97>>2]|0;
     $99 = HEAP32[$38>>2]|0;
     $100 = $99 & $74;
     $101 = HEAP8[$39>>0]|0;
     $102 = $101&255;
     $103 = $100 >>> $102;
     $104 = (($98) + ($103)|0);
     $$0723$shrunk$ph$in = $94;$$0731$shrunk$ph$in = $84;$$0739$ph = $74;$$sink810 = $104;
     label = 9;
     break;
    }
    case 3:  {
     $105 = HEAP8[$33>>0]|0;
     $div789 = ($105&255) >>> 3;
     $106 = $div789&255;
     $107 = (($$1748) + ($106)|0);
     $108 = HEAP8[$36>>0]|0;
     $div790 = ($108&255) >>> 3;
     $109 = $div790&255;
     $110 = (($$1748) + ($109)|0);
     $111 = HEAP8[$39>>0]|0;
     $div791 = ($111&255) >>> 3;
     $112 = $div791&255;
     $113 = (($$1748) + ($112)|0);
     $$0723$shrunk$ph$in = $110;$$0731$shrunk$ph$in = $107;$$0739$ph = 0;$$sink810 = $113;
     label = 9;
     break;
    }
    case 4:  {
     $114 = HEAP32[$$1748>>2]|0;
     $115 = HEAP8[$31>>0]|0;
     $116 = $115&255;
     $117 = (79212 + ($116<<2)|0);
     $118 = HEAP32[$117>>2]|0;
     $119 = HEAP32[$32>>2]|0;
     $120 = $119 & $114;
     $121 = HEAP8[$33>>0]|0;
     $122 = $121&255;
     $123 = $120 >>> $122;
     $124 = (($118) + ($123)|0);
     $125 = HEAP8[$34>>0]|0;
     $126 = $125&255;
     $127 = (79212 + ($126<<2)|0);
     $128 = HEAP32[$127>>2]|0;
     $129 = HEAP32[$35>>2]|0;
     $130 = $129 & $114;
     $131 = HEAP8[$36>>0]|0;
     $132 = $131&255;
     $133 = $130 >>> $132;
     $134 = (($128) + ($133)|0);
     $135 = HEAP8[$37>>0]|0;
     $136 = $135&255;
     $137 = (79212 + ($136<<2)|0);
     $138 = HEAP32[$137>>2]|0;
     $139 = HEAP32[$38>>2]|0;
     $140 = $139 & $114;
     $141 = HEAP8[$39>>0]|0;
     $142 = $141&255;
     $143 = $140 >>> $142;
     $144 = (($138) + ($143)|0);
     $$0723$shrunk$ph$in = $134;$$0731$shrunk$ph$in = $124;$$0739$ph = $114;$$sink810 = $144;
     label = 9;
     break;
    }
    default: {
     $$0715$shrunk = 0;$$0723$shrunk = 0;$$0731$shrunk = 0;$$0739 = 0;
    }
    }
    if ((label|0) == 9) {
     label = 0;
     $$0723$shrunk$ph = HEAP8[$$0723$shrunk$ph$in>>0]|0;
     $$0731$shrunk$ph = HEAP8[$$0731$shrunk$ph$in>>0]|0;
     $145 = HEAP8[$$sink810>>0]|0;
     $$0715$shrunk = $145;$$0723$shrunk = $$0723$shrunk$ph;$$0731$shrunk = $$0731$shrunk$ph;$$0739 = $$0739$ph;
    }
    $146 = ($$0739|0)==($17|0);
    if (!($146)) {
     $$0715 = $$0715$shrunk&255;
     $$0723 = $$0723$shrunk&255;
     $$0731 = $$0731$shrunk&255;
     $147 = HEAP32[$29>>2]|0;
     $148 = ((($147)) + 4|0);
     $149 = HEAP32[$148>>2]|0;
     $150 = HEAP8[$$1756>>0]|0;
     $151 = $150&255;
     $152 = (($149) + ($151<<2)|0);
     $153 = HEAP8[$152>>0]|0;
     $154 = $153&255;
     $155 = (((($149) + ($151<<2)|0)) + 1|0);
     $156 = HEAP8[$155>>0]|0;
     $157 = $156&255;
     $158 = (((($149) + ($151<<2)|0)) + 2|0);
     $159 = HEAP8[$158>>0]|0;
     $160 = $159&255;
     $161 = (($$0731) - ($154))|0;
     $162 = Math_imul($161, $20)|0;
     $163 = (($162>>>0) / 255)&-1;
     $164 = (($163) + ($154))|0;
     $165 = (($$0723) - ($157))|0;
     $166 = Math_imul($165, $20)|0;
     $167 = (($166>>>0) / 255)&-1;
     $168 = (($167) + ($157))|0;
     $169 = (($$0715) - ($160))|0;
     $170 = Math_imul($169, $20)|0;
     $171 = (($170>>>0) / 255)&-1;
     $172 = (($171) + ($160))|0;
     $173 = $164 & 224;
     $174 = $172 >>> 6;
     $175 = $174 & 3;
     $176 = $168 >>> 3;
     $177 = $176 & 28;
     $178 = $177 | $173;
     $179 = $178 | $175;
     if ($30) {
      $180 = $179&255;
      $$sink = $180;
     } else {
      $181 = (($10) + ($179)|0);
      $182 = HEAP8[$181>>0]|0;
      $$sink = $182;
     }
     HEAP8[$$1756>>0] = $$sink;
    }
    $183 = ((($$1756)) + 1|0);
    $184 = (($$1748) + ($15)|0);
    $$1 = $$0;$$2749 = $184;$$2757 = $183;
    label = 16;
    continue;
   }
   else if ((label|0) == 16) {
    label = 0;
    switch ($14<<24>>24) {
    case 1:  {
     $185 = HEAP8[$$2749>>0]|0;
     $186 = $185&255;
     $187 = HEAP8[$31>>0]|0;
     $188 = $187&255;
     $189 = (79212 + ($188<<2)|0);
     $190 = HEAP32[$189>>2]|0;
     $191 = HEAP32[$32>>2]|0;
     $192 = $191 & $186;
     $193 = HEAP8[$33>>0]|0;
     $194 = $193&255;
     $195 = $192 >>> $194;
     $196 = (($190) + ($195)|0);
     $197 = HEAP8[$34>>0]|0;
     $198 = $197&255;
     $199 = (79212 + ($198<<2)|0);
     $200 = HEAP32[$199>>2]|0;
     $201 = HEAP32[$35>>2]|0;
     $202 = $201 & $186;
     $203 = HEAP8[$36>>0]|0;
     $204 = $203&255;
     $205 = $202 >>> $204;
     $206 = (($200) + ($205)|0);
     $207 = HEAP8[$37>>0]|0;
     $208 = $207&255;
     $209 = (79212 + ($208<<2)|0);
     $210 = HEAP32[$209>>2]|0;
     $211 = HEAP32[$38>>2]|0;
     $212 = $211 & $186;
     $213 = HEAP8[$39>>0]|0;
     $214 = $213&255;
     $215 = $212 >>> $214;
     $216 = (($210) + ($215)|0);
     $$1724$shrunk$ph$in = $206;$$1732$shrunk$ph$in = $196;$$1740$ph = $186;$$sink812 = $216;
     label = 21;
     break;
    }
    case 2:  {
     $217 = HEAP16[$$2749>>1]|0;
     $218 = $217&65535;
     $219 = HEAP8[$31>>0]|0;
     $220 = $219&255;
     $221 = (79212 + ($220<<2)|0);
     $222 = HEAP32[$221>>2]|0;
     $223 = HEAP32[$32>>2]|0;
     $224 = $223 & $218;
     $225 = HEAP8[$33>>0]|0;
     $226 = $225&255;
     $227 = $224 >>> $226;
     $228 = (($222) + ($227)|0);
     $229 = HEAP8[$34>>0]|0;
     $230 = $229&255;
     $231 = (79212 + ($230<<2)|0);
     $232 = HEAP32[$231>>2]|0;
     $233 = HEAP32[$35>>2]|0;
     $234 = $233 & $218;
     $235 = HEAP8[$36>>0]|0;
     $236 = $235&255;
     $237 = $234 >>> $236;
     $238 = (($232) + ($237)|0);
     $239 = HEAP8[$37>>0]|0;
     $240 = $239&255;
     $241 = (79212 + ($240<<2)|0);
     $242 = HEAP32[$241>>2]|0;
     $243 = HEAP32[$38>>2]|0;
     $244 = $243 & $218;
     $245 = HEAP8[$39>>0]|0;
     $246 = $245&255;
     $247 = $244 >>> $246;
     $248 = (($242) + ($247)|0);
     $$1724$shrunk$ph$in = $238;$$1732$shrunk$ph$in = $228;$$1740$ph = $218;$$sink812 = $248;
     label = 21;
     break;
    }
    case 3:  {
     $249 = HEAP8[$33>>0]|0;
     $div786 = ($249&255) >>> 3;
     $250 = $div786&255;
     $251 = (($$2749) + ($250)|0);
     $252 = HEAP8[$36>>0]|0;
     $div787 = ($252&255) >>> 3;
     $253 = $div787&255;
     $254 = (($$2749) + ($253)|0);
     $255 = HEAP8[$39>>0]|0;
     $div788 = ($255&255) >>> 3;
     $256 = $div788&255;
     $257 = (($$2749) + ($256)|0);
     $$1724$shrunk$ph$in = $254;$$1732$shrunk$ph$in = $251;$$1740$ph = 0;$$sink812 = $257;
     label = 21;
     break;
    }
    case 4:  {
     $258 = HEAP32[$$2749>>2]|0;
     $259 = HEAP8[$31>>0]|0;
     $260 = $259&255;
     $261 = (79212 + ($260<<2)|0);
     $262 = HEAP32[$261>>2]|0;
     $263 = HEAP32[$32>>2]|0;
     $264 = $263 & $258;
     $265 = HEAP8[$33>>0]|0;
     $266 = $265&255;
     $267 = $264 >>> $266;
     $268 = (($262) + ($267)|0);
     $269 = HEAP8[$34>>0]|0;
     $270 = $269&255;
     $271 = (79212 + ($270<<2)|0);
     $272 = HEAP32[$271>>2]|0;
     $273 = HEAP32[$35>>2]|0;
     $274 = $273 & $258;
     $275 = HEAP8[$36>>0]|0;
     $276 = $275&255;
     $277 = $274 >>> $276;
     $278 = (($272) + ($277)|0);
     $279 = HEAP8[$37>>0]|0;
     $280 = $279&255;
     $281 = (79212 + ($280<<2)|0);
     $282 = HEAP32[$281>>2]|0;
     $283 = HEAP32[$38>>2]|0;
     $284 = $283 & $258;
     $285 = HEAP8[$39>>0]|0;
     $286 = $285&255;
     $287 = $284 >>> $286;
     $288 = (($282) + ($287)|0);
     $$1724$shrunk$ph$in = $278;$$1732$shrunk$ph$in = $268;$$1740$ph = $258;$$sink812 = $288;
     label = 21;
     break;
    }
    default: {
     $$1716$shrunk = 0;$$1724$shrunk = 0;$$1732$shrunk = 0;$$1740 = 0;
    }
    }
    if ((label|0) == 21) {
     label = 0;
     $$1724$shrunk$ph = HEAP8[$$1724$shrunk$ph$in>>0]|0;
     $$1732$shrunk$ph = HEAP8[$$1732$shrunk$ph$in>>0]|0;
     $289 = HEAP8[$$sink812>>0]|0;
     $$1716$shrunk = $289;$$1724$shrunk = $$1724$shrunk$ph;$$1732$shrunk = $$1732$shrunk$ph;$$1740 = $$1740$ph;
    }
    $290 = ($$1740|0)==($17|0);
    if (!($290)) {
     $$1716 = $$1716$shrunk&255;
     $$1724 = $$1724$shrunk&255;
     $$1732 = $$1732$shrunk&255;
     $291 = HEAP32[$29>>2]|0;
     $292 = ((($291)) + 4|0);
     $293 = HEAP32[$292>>2]|0;
     $294 = HEAP8[$$2757>>0]|0;
     $295 = $294&255;
     $296 = (($293) + ($295<<2)|0);
     $297 = HEAP8[$296>>0]|0;
     $298 = $297&255;
     $299 = (((($293) + ($295<<2)|0)) + 1|0);
     $300 = HEAP8[$299>>0]|0;
     $301 = $300&255;
     $302 = (((($293) + ($295<<2)|0)) + 2|0);
     $303 = HEAP8[$302>>0]|0;
     $304 = $303&255;
     $305 = (($$1732) - ($298))|0;
     $306 = Math_imul($305, $20)|0;
     $307 = (($306>>>0) / 255)&-1;
     $308 = (($307) + ($298))|0;
     $309 = (($$1724) - ($301))|0;
     $310 = Math_imul($309, $20)|0;
     $311 = (($310>>>0) / 255)&-1;
     $312 = (($311) + ($301))|0;
     $313 = (($$1716) - ($304))|0;
     $314 = Math_imul($313, $20)|0;
     $315 = (($314>>>0) / 255)&-1;
     $316 = (($315) + ($304))|0;
     $317 = $316 >>> 6;
     $318 = $317 & 3;
     $319 = $308 & 224;
     $320 = $312 >>> 3;
     $321 = $320 & 28;
     $322 = $321 | $319;
     $323 = $322 | $318;
     if ($30) {
      $324 = $323&255;
      $$sink796 = $324;
     } else {
      $325 = (($10) + ($323)|0);
      $326 = HEAP8[$325>>0]|0;
      $$sink796 = $326;
     }
     HEAP8[$$2757>>0] = $$sink796;
    }
    $327 = ((($$2757)) + 1|0);
    $328 = (($$2749) + ($15)|0);
    $$2 = $$1;$$3750 = $328;$$3758 = $327;
    label = 28;
    continue;
   }
   else if ((label|0) == 28) {
    label = 0;
    switch ($14<<24>>24) {
    case 1:  {
     $329 = HEAP8[$$3750>>0]|0;
     $330 = $329&255;
     $331 = HEAP8[$31>>0]|0;
     $332 = $331&255;
     $333 = (79212 + ($332<<2)|0);
     $334 = HEAP32[$333>>2]|0;
     $335 = HEAP32[$32>>2]|0;
     $336 = $335 & $330;
     $337 = HEAP8[$33>>0]|0;
     $338 = $337&255;
     $339 = $336 >>> $338;
     $340 = (($334) + ($339)|0);
     $341 = HEAP8[$34>>0]|0;
     $342 = $341&255;
     $343 = (79212 + ($342<<2)|0);
     $344 = HEAP32[$343>>2]|0;
     $345 = HEAP32[$35>>2]|0;
     $346 = $345 & $330;
     $347 = HEAP8[$36>>0]|0;
     $348 = $347&255;
     $349 = $346 >>> $348;
     $350 = (($344) + ($349)|0);
     $351 = HEAP8[$37>>0]|0;
     $352 = $351&255;
     $353 = (79212 + ($352<<2)|0);
     $354 = HEAP32[$353>>2]|0;
     $355 = HEAP32[$38>>2]|0;
     $356 = $355 & $330;
     $357 = HEAP8[$39>>0]|0;
     $358 = $357&255;
     $359 = $356 >>> $358;
     $360 = (($354) + ($359)|0);
     $$2725$shrunk$ph$in = $350;$$2733$shrunk$ph$in = $340;$$2741$ph = $330;$$sink814 = $360;
     label = 33;
     break;
    }
    case 2:  {
     $361 = HEAP16[$$3750>>1]|0;
     $362 = $361&65535;
     $363 = HEAP8[$31>>0]|0;
     $364 = $363&255;
     $365 = (79212 + ($364<<2)|0);
     $366 = HEAP32[$365>>2]|0;
     $367 = HEAP32[$32>>2]|0;
     $368 = $367 & $362;
     $369 = HEAP8[$33>>0]|0;
     $370 = $369&255;
     $371 = $368 >>> $370;
     $372 = (($366) + ($371)|0);
     $373 = HEAP8[$34>>0]|0;
     $374 = $373&255;
     $375 = (79212 + ($374<<2)|0);
     $376 = HEAP32[$375>>2]|0;
     $377 = HEAP32[$35>>2]|0;
     $378 = $377 & $362;
     $379 = HEAP8[$36>>0]|0;
     $380 = $379&255;
     $381 = $378 >>> $380;
     $382 = (($376) + ($381)|0);
     $383 = HEAP8[$37>>0]|0;
     $384 = $383&255;
     $385 = (79212 + ($384<<2)|0);
     $386 = HEAP32[$385>>2]|0;
     $387 = HEAP32[$38>>2]|0;
     $388 = $387 & $362;
     $389 = HEAP8[$39>>0]|0;
     $390 = $389&255;
     $391 = $388 >>> $390;
     $392 = (($386) + ($391)|0);
     $$2725$shrunk$ph$in = $382;$$2733$shrunk$ph$in = $372;$$2741$ph = $362;$$sink814 = $392;
     label = 33;
     break;
    }
    case 3:  {
     $393 = HEAP8[$33>>0]|0;
     $div783 = ($393&255) >>> 3;
     $394 = $div783&255;
     $395 = (($$3750) + ($394)|0);
     $396 = HEAP8[$36>>0]|0;
     $div784 = ($396&255) >>> 3;
     $397 = $div784&255;
     $398 = (($$3750) + ($397)|0);
     $399 = HEAP8[$39>>0]|0;
     $div785 = ($399&255) >>> 3;
     $400 = $div785&255;
     $401 = (($$3750) + ($400)|0);
     $$2725$shrunk$ph$in = $398;$$2733$shrunk$ph$in = $395;$$2741$ph = 0;$$sink814 = $401;
     label = 33;
     break;
    }
    case 4:  {
     $402 = HEAP32[$$3750>>2]|0;
     $403 = HEAP8[$31>>0]|0;
     $404 = $403&255;
     $405 = (79212 + ($404<<2)|0);
     $406 = HEAP32[$405>>2]|0;
     $407 = HEAP32[$32>>2]|0;
     $408 = $407 & $402;
     $409 = HEAP8[$33>>0]|0;
     $410 = $409&255;
     $411 = $408 >>> $410;
     $412 = (($406) + ($411)|0);
     $413 = HEAP8[$34>>0]|0;
     $414 = $413&255;
     $415 = (79212 + ($414<<2)|0);
     $416 = HEAP32[$415>>2]|0;
     $417 = HEAP32[$35>>2]|0;
     $418 = $417 & $402;
     $419 = HEAP8[$36>>0]|0;
     $420 = $419&255;
     $421 = $418 >>> $420;
     $422 = (($416) + ($421)|0);
     $423 = HEAP8[$37>>0]|0;
     $424 = $423&255;
     $425 = (79212 + ($424<<2)|0);
     $426 = HEAP32[$425>>2]|0;
     $427 = HEAP32[$38>>2]|0;
     $428 = $427 & $402;
     $429 = HEAP8[$39>>0]|0;
     $430 = $429&255;
     $431 = $428 >>> $430;
     $432 = (($426) + ($431)|0);
     $$2725$shrunk$ph$in = $422;$$2733$shrunk$ph$in = $412;$$2741$ph = $402;$$sink814 = $432;
     label = 33;
     break;
    }
    default: {
     $$2717$shrunk = 0;$$2725$shrunk = 0;$$2733$shrunk = 0;$$2741 = 0;
    }
    }
    if ((label|0) == 33) {
     label = 0;
     $$2725$shrunk$ph = HEAP8[$$2725$shrunk$ph$in>>0]|0;
     $$2733$shrunk$ph = HEAP8[$$2733$shrunk$ph$in>>0]|0;
     $433 = HEAP8[$$sink814>>0]|0;
     $$2717$shrunk = $433;$$2725$shrunk = $$2725$shrunk$ph;$$2733$shrunk = $$2733$shrunk$ph;$$2741 = $$2741$ph;
    }
    $434 = ($$2741|0)==($17|0);
    if (!($434)) {
     $$2717 = $$2717$shrunk&255;
     $$2725 = $$2725$shrunk&255;
     $$2733 = $$2733$shrunk&255;
     $435 = HEAP32[$29>>2]|0;
     $436 = ((($435)) + 4|0);
     $437 = HEAP32[$436>>2]|0;
     $438 = HEAP8[$$3758>>0]|0;
     $439 = $438&255;
     $440 = (($437) + ($439<<2)|0);
     $441 = HEAP8[$440>>0]|0;
     $442 = $441&255;
     $443 = (((($437) + ($439<<2)|0)) + 1|0);
     $444 = HEAP8[$443>>0]|0;
     $445 = $444&255;
     $446 = (((($437) + ($439<<2)|0)) + 2|0);
     $447 = HEAP8[$446>>0]|0;
     $448 = $447&255;
     $449 = (($$2733) - ($442))|0;
     $450 = Math_imul($449, $20)|0;
     $451 = (($450>>>0) / 255)&-1;
     $452 = (($451) + ($442))|0;
     $453 = (($$2725) - ($445))|0;
     $454 = Math_imul($453, $20)|0;
     $455 = (($454>>>0) / 255)&-1;
     $456 = (($455) + ($445))|0;
     $457 = (($$2717) - ($448))|0;
     $458 = Math_imul($457, $20)|0;
     $459 = (($458>>>0) / 255)&-1;
     $460 = (($459) + ($448))|0;
     $461 = $452 & 224;
     $462 = $460 >>> 6;
     $463 = $462 & 3;
     $464 = $456 >>> 3;
     $465 = $464 & 28;
     $466 = $465 | $461;
     $467 = $466 | $463;
     if ($30) {
      $468 = $467&255;
      $$sink798 = $468;
     } else {
      $469 = (($10) + ($467)|0);
      $470 = HEAP8[$469>>0]|0;
      $$sink798 = $470;
     }
     HEAP8[$$3758>>0] = $$sink798;
    }
    $471 = ((($$3758)) + 1|0);
    $472 = (($$3750) + ($15)|0);
    $$3 = $$2;$$4751 = $472;$$4759 = $471;
    label = 40;
    continue;
   }
   else if ((label|0) == 40) {
    label = 0;
    switch ($14<<24>>24) {
    case 1:  {
     $473 = HEAP8[$$4751>>0]|0;
     $474 = $473&255;
     $475 = HEAP8[$31>>0]|0;
     $476 = $475&255;
     $477 = (79212 + ($476<<2)|0);
     $478 = HEAP32[$477>>2]|0;
     $479 = HEAP32[$32>>2]|0;
     $480 = $479 & $474;
     $481 = HEAP8[$33>>0]|0;
     $482 = $481&255;
     $483 = $480 >>> $482;
     $484 = (($478) + ($483)|0);
     $485 = HEAP8[$34>>0]|0;
     $486 = $485&255;
     $487 = (79212 + ($486<<2)|0);
     $488 = HEAP32[$487>>2]|0;
     $489 = HEAP32[$35>>2]|0;
     $490 = $489 & $474;
     $491 = HEAP8[$36>>0]|0;
     $492 = $491&255;
     $493 = $490 >>> $492;
     $494 = (($488) + ($493)|0);
     $495 = HEAP8[$37>>0]|0;
     $496 = $495&255;
     $497 = (79212 + ($496<<2)|0);
     $498 = HEAP32[$497>>2]|0;
     $499 = HEAP32[$38>>2]|0;
     $500 = $499 & $474;
     $501 = HEAP8[$39>>0]|0;
     $502 = $501&255;
     $503 = $500 >>> $502;
     $504 = (($498) + ($503)|0);
     $$3726$shrunk$ph$in = $494;$$3734$shrunk$ph$in = $484;$$3742$ph = $474;$$sink816 = $504;
     label = 45;
     break;
    }
    case 2:  {
     $505 = HEAP16[$$4751>>1]|0;
     $506 = $505&65535;
     $507 = HEAP8[$31>>0]|0;
     $508 = $507&255;
     $509 = (79212 + ($508<<2)|0);
     $510 = HEAP32[$509>>2]|0;
     $511 = HEAP32[$32>>2]|0;
     $512 = $511 & $506;
     $513 = HEAP8[$33>>0]|0;
     $514 = $513&255;
     $515 = $512 >>> $514;
     $516 = (($510) + ($515)|0);
     $517 = HEAP8[$34>>0]|0;
     $518 = $517&255;
     $519 = (79212 + ($518<<2)|0);
     $520 = HEAP32[$519>>2]|0;
     $521 = HEAP32[$35>>2]|0;
     $522 = $521 & $506;
     $523 = HEAP8[$36>>0]|0;
     $524 = $523&255;
     $525 = $522 >>> $524;
     $526 = (($520) + ($525)|0);
     $527 = HEAP8[$37>>0]|0;
     $528 = $527&255;
     $529 = (79212 + ($528<<2)|0);
     $530 = HEAP32[$529>>2]|0;
     $531 = HEAP32[$38>>2]|0;
     $532 = $531 & $506;
     $533 = HEAP8[$39>>0]|0;
     $534 = $533&255;
     $535 = $532 >>> $534;
     $536 = (($530) + ($535)|0);
     $$3726$shrunk$ph$in = $526;$$3734$shrunk$ph$in = $516;$$3742$ph = $506;$$sink816 = $536;
     label = 45;
     break;
    }
    case 3:  {
     $537 = HEAP8[$33>>0]|0;
     $div780 = ($537&255) >>> 3;
     $538 = $div780&255;
     $539 = (($$4751) + ($538)|0);
     $540 = HEAP8[$36>>0]|0;
     $div781 = ($540&255) >>> 3;
     $541 = $div781&255;
     $542 = (($$4751) + ($541)|0);
     $543 = HEAP8[$39>>0]|0;
     $div782 = ($543&255) >>> 3;
     $544 = $div782&255;
     $545 = (($$4751) + ($544)|0);
     $$3726$shrunk$ph$in = $542;$$3734$shrunk$ph$in = $539;$$3742$ph = 0;$$sink816 = $545;
     label = 45;
     break;
    }
    case 4:  {
     $546 = HEAP32[$$4751>>2]|0;
     $547 = HEAP8[$31>>0]|0;
     $548 = $547&255;
     $549 = (79212 + ($548<<2)|0);
     $550 = HEAP32[$549>>2]|0;
     $551 = HEAP32[$32>>2]|0;
     $552 = $551 & $546;
     $553 = HEAP8[$33>>0]|0;
     $554 = $553&255;
     $555 = $552 >>> $554;
     $556 = (($550) + ($555)|0);
     $557 = HEAP8[$34>>0]|0;
     $558 = $557&255;
     $559 = (79212 + ($558<<2)|0);
     $560 = HEAP32[$559>>2]|0;
     $561 = HEAP32[$35>>2]|0;
     $562 = $561 & $546;
     $563 = HEAP8[$36>>0]|0;
     $564 = $563&255;
     $565 = $562 >>> $564;
     $566 = (($560) + ($565)|0);
     $567 = HEAP8[$37>>0]|0;
     $568 = $567&255;
     $569 = (79212 + ($568<<2)|0);
     $570 = HEAP32[$569>>2]|0;
     $571 = HEAP32[$38>>2]|0;
     $572 = $571 & $546;
     $573 = HEAP8[$39>>0]|0;
     $574 = $573&255;
     $575 = $572 >>> $574;
     $576 = (($570) + ($575)|0);
     $$3726$shrunk$ph$in = $566;$$3734$shrunk$ph$in = $556;$$3742$ph = $546;$$sink816 = $576;
     label = 45;
     break;
    }
    default: {
     $$3718$shrunk = 0;$$3726$shrunk = 0;$$3734$shrunk = 0;$$3742 = 0;
    }
    }
    if ((label|0) == 45) {
     label = 0;
     $$3726$shrunk$ph = HEAP8[$$3726$shrunk$ph$in>>0]|0;
     $$3734$shrunk$ph = HEAP8[$$3734$shrunk$ph$in>>0]|0;
     $577 = HEAP8[$$sink816>>0]|0;
     $$3718$shrunk = $577;$$3726$shrunk = $$3726$shrunk$ph;$$3734$shrunk = $$3734$shrunk$ph;$$3742 = $$3742$ph;
    }
    $578 = ($$3742|0)==($17|0);
    if (!($578)) {
     $$3718 = $$3718$shrunk&255;
     $$3726 = $$3726$shrunk&255;
     $$3734 = $$3734$shrunk&255;
     $579 = HEAP32[$29>>2]|0;
     $580 = ((($579)) + 4|0);
     $581 = HEAP32[$580>>2]|0;
     $582 = HEAP8[$$4759>>0]|0;
     $583 = $582&255;
     $584 = (($581) + ($583<<2)|0);
     $585 = HEAP8[$584>>0]|0;
     $586 = $585&255;
     $587 = (((($581) + ($583<<2)|0)) + 1|0);
     $588 = HEAP8[$587>>0]|0;
     $589 = $588&255;
     $590 = (((($581) + ($583<<2)|0)) + 2|0);
     $591 = HEAP8[$590>>0]|0;
     $592 = $591&255;
     $593 = (($$3734) - ($586))|0;
     $594 = Math_imul($593, $20)|0;
     $595 = (($594>>>0) / 255)&-1;
     $596 = (($595) + ($586))|0;
     $597 = (($$3726) - ($589))|0;
     $598 = Math_imul($597, $20)|0;
     $599 = (($598>>>0) / 255)&-1;
     $600 = (($599) + ($589))|0;
     $601 = (($$3718) - ($592))|0;
     $602 = Math_imul($601, $20)|0;
     $603 = (($602>>>0) / 255)&-1;
     $604 = (($603) + ($592))|0;
     $605 = $604 >>> 6;
     $606 = $605 & 3;
     $607 = $596 & 224;
     $608 = $600 >>> 3;
     $609 = $608 & 28;
     $610 = $609 | $607;
     $611 = $610 | $606;
     if ($30) {
      $612 = $611&255;
      $$sink800 = $612;
     } else {
      $613 = (($10) + ($611)|0);
      $614 = HEAP8[$613>>0]|0;
      $$sink800 = $614;
     }
     HEAP8[$$4759>>0] = $$sink800;
    }
    $615 = ((($$4759)) + 1|0);
    $616 = (($$4751) + ($15)|0);
    $$4 = $$3;$$5752 = $616;$$5760 = $615;
    label = 52;
    continue;
   }
   else if ((label|0) == 52) {
    label = 0;
    switch ($14<<24>>24) {
    case 1:  {
     $617 = HEAP8[$$5752>>0]|0;
     $618 = $617&255;
     $619 = HEAP8[$31>>0]|0;
     $620 = $619&255;
     $621 = (79212 + ($620<<2)|0);
     $622 = HEAP32[$621>>2]|0;
     $623 = HEAP32[$32>>2]|0;
     $624 = $623 & $618;
     $625 = HEAP8[$33>>0]|0;
     $626 = $625&255;
     $627 = $624 >>> $626;
     $628 = (($622) + ($627)|0);
     $629 = HEAP8[$34>>0]|0;
     $630 = $629&255;
     $631 = (79212 + ($630<<2)|0);
     $632 = HEAP32[$631>>2]|0;
     $633 = HEAP32[$35>>2]|0;
     $634 = $633 & $618;
     $635 = HEAP8[$36>>0]|0;
     $636 = $635&255;
     $637 = $634 >>> $636;
     $638 = (($632) + ($637)|0);
     $639 = HEAP8[$37>>0]|0;
     $640 = $639&255;
     $641 = (79212 + ($640<<2)|0);
     $642 = HEAP32[$641>>2]|0;
     $643 = HEAP32[$38>>2]|0;
     $644 = $643 & $618;
     $645 = HEAP8[$39>>0]|0;
     $646 = $645&255;
     $647 = $644 >>> $646;
     $648 = (($642) + ($647)|0);
     $$4727$shrunk$ph$in = $638;$$4735$shrunk$ph$in = $628;$$4743$ph = $618;$$sink818 = $648;
     label = 57;
     break;
    }
    case 2:  {
     $649 = HEAP16[$$5752>>1]|0;
     $650 = $649&65535;
     $651 = HEAP8[$31>>0]|0;
     $652 = $651&255;
     $653 = (79212 + ($652<<2)|0);
     $654 = HEAP32[$653>>2]|0;
     $655 = HEAP32[$32>>2]|0;
     $656 = $655 & $650;
     $657 = HEAP8[$33>>0]|0;
     $658 = $657&255;
     $659 = $656 >>> $658;
     $660 = (($654) + ($659)|0);
     $661 = HEAP8[$34>>0]|0;
     $662 = $661&255;
     $663 = (79212 + ($662<<2)|0);
     $664 = HEAP32[$663>>2]|0;
     $665 = HEAP32[$35>>2]|0;
     $666 = $665 & $650;
     $667 = HEAP8[$36>>0]|0;
     $668 = $667&255;
     $669 = $666 >>> $668;
     $670 = (($664) + ($669)|0);
     $671 = HEAP8[$37>>0]|0;
     $672 = $671&255;
     $673 = (79212 + ($672<<2)|0);
     $674 = HEAP32[$673>>2]|0;
     $675 = HEAP32[$38>>2]|0;
     $676 = $675 & $650;
     $677 = HEAP8[$39>>0]|0;
     $678 = $677&255;
     $679 = $676 >>> $678;
     $680 = (($674) + ($679)|0);
     $$4727$shrunk$ph$in = $670;$$4735$shrunk$ph$in = $660;$$4743$ph = $650;$$sink818 = $680;
     label = 57;
     break;
    }
    case 3:  {
     $681 = HEAP8[$33>>0]|0;
     $div777 = ($681&255) >>> 3;
     $682 = $div777&255;
     $683 = (($$5752) + ($682)|0);
     $684 = HEAP8[$36>>0]|0;
     $div778 = ($684&255) >>> 3;
     $685 = $div778&255;
     $686 = (($$5752) + ($685)|0);
     $687 = HEAP8[$39>>0]|0;
     $div779 = ($687&255) >>> 3;
     $688 = $div779&255;
     $689 = (($$5752) + ($688)|0);
     $$4727$shrunk$ph$in = $686;$$4735$shrunk$ph$in = $683;$$4743$ph = 0;$$sink818 = $689;
     label = 57;
     break;
    }
    case 4:  {
     $690 = HEAP32[$$5752>>2]|0;
     $691 = HEAP8[$31>>0]|0;
     $692 = $691&255;
     $693 = (79212 + ($692<<2)|0);
     $694 = HEAP32[$693>>2]|0;
     $695 = HEAP32[$32>>2]|0;
     $696 = $695 & $690;
     $697 = HEAP8[$33>>0]|0;
     $698 = $697&255;
     $699 = $696 >>> $698;
     $700 = (($694) + ($699)|0);
     $701 = HEAP8[$34>>0]|0;
     $702 = $701&255;
     $703 = (79212 + ($702<<2)|0);
     $704 = HEAP32[$703>>2]|0;
     $705 = HEAP32[$35>>2]|0;
     $706 = $705 & $690;
     $707 = HEAP8[$36>>0]|0;
     $708 = $707&255;
     $709 = $706 >>> $708;
     $710 = (($704) + ($709)|0);
     $711 = HEAP8[$37>>0]|0;
     $712 = $711&255;
     $713 = (79212 + ($712<<2)|0);
     $714 = HEAP32[$713>>2]|0;
     $715 = HEAP32[$38>>2]|0;
     $716 = $715 & $690;
     $717 = HEAP8[$39>>0]|0;
     $718 = $717&255;
     $719 = $716 >>> $718;
     $720 = (($714) + ($719)|0);
     $$4727$shrunk$ph$in = $710;$$4735$shrunk$ph$in = $700;$$4743$ph = $690;$$sink818 = $720;
     label = 57;
     break;
    }
    default: {
     $$4719$shrunk = 0;$$4727$shrunk = 0;$$4735$shrunk = 0;$$4743 = 0;
    }
    }
    if ((label|0) == 57) {
     label = 0;
     $$4727$shrunk$ph = HEAP8[$$4727$shrunk$ph$in>>0]|0;
     $$4735$shrunk$ph = HEAP8[$$4735$shrunk$ph$in>>0]|0;
     $721 = HEAP8[$$sink818>>0]|0;
     $$4719$shrunk = $721;$$4727$shrunk = $$4727$shrunk$ph;$$4735$shrunk = $$4735$shrunk$ph;$$4743 = $$4743$ph;
    }
    $722 = ($$4743|0)==($17|0);
    if (!($722)) {
     $$4719 = $$4719$shrunk&255;
     $$4727 = $$4727$shrunk&255;
     $$4735 = $$4735$shrunk&255;
     $723 = HEAP32[$29>>2]|0;
     $724 = ((($723)) + 4|0);
     $725 = HEAP32[$724>>2]|0;
     $726 = HEAP8[$$5760>>0]|0;
     $727 = $726&255;
     $728 = (($725) + ($727<<2)|0);
     $729 = HEAP8[$728>>0]|0;
     $730 = $729&255;
     $731 = (((($725) + ($727<<2)|0)) + 1|0);
     $732 = HEAP8[$731>>0]|0;
     $733 = $732&255;
     $734 = (((($725) + ($727<<2)|0)) + 2|0);
     $735 = HEAP8[$734>>0]|0;
     $736 = $735&255;
     $737 = (($$4735) - ($730))|0;
     $738 = Math_imul($737, $20)|0;
     $739 = (($738>>>0) / 255)&-1;
     $740 = (($739) + ($730))|0;
     $741 = (($$4727) - ($733))|0;
     $742 = Math_imul($741, $20)|0;
     $743 = (($742>>>0) / 255)&-1;
     $744 = (($743) + ($733))|0;
     $745 = (($$4719) - ($736))|0;
     $746 = Math_imul($745, $20)|0;
     $747 = (($746>>>0) / 255)&-1;
     $748 = (($747) + ($736))|0;
     $749 = $740 & 224;
     $750 = $748 >>> 6;
     $751 = $750 & 3;
     $752 = $744 >>> 3;
     $753 = $752 & 28;
     $754 = $753 | $749;
     $755 = $754 | $751;
     if ($30) {
      $756 = $755&255;
      $$sink802 = $756;
     } else {
      $757 = (($10) + ($755)|0);
      $758 = HEAP8[$757>>0]|0;
      $$sink802 = $758;
     }
     HEAP8[$$5760>>0] = $$sink802;
    }
    $759 = ((($$5760)) + 1|0);
    $760 = (($$5752) + ($15)|0);
    $$5 = $$4;$$6753 = $760;$$6761 = $759;
    label = 64;
    continue;
   }
   else if ((label|0) == 64) {
    label = 0;
    switch ($14<<24>>24) {
    case 1:  {
     $761 = HEAP8[$$6753>>0]|0;
     $762 = $761&255;
     $763 = HEAP8[$31>>0]|0;
     $764 = $763&255;
     $765 = (79212 + ($764<<2)|0);
     $766 = HEAP32[$765>>2]|0;
     $767 = HEAP32[$32>>2]|0;
     $768 = $767 & $762;
     $769 = HEAP8[$33>>0]|0;
     $770 = $769&255;
     $771 = $768 >>> $770;
     $772 = (($766) + ($771)|0);
     $773 = HEAP8[$34>>0]|0;
     $774 = $773&255;
     $775 = (79212 + ($774<<2)|0);
     $776 = HEAP32[$775>>2]|0;
     $777 = HEAP32[$35>>2]|0;
     $778 = $777 & $762;
     $779 = HEAP8[$36>>0]|0;
     $780 = $779&255;
     $781 = $778 >>> $780;
     $782 = (($776) + ($781)|0);
     $783 = HEAP8[$37>>0]|0;
     $784 = $783&255;
     $785 = (79212 + ($784<<2)|0);
     $786 = HEAP32[$785>>2]|0;
     $787 = HEAP32[$38>>2]|0;
     $788 = $787 & $762;
     $789 = HEAP8[$39>>0]|0;
     $790 = $789&255;
     $791 = $788 >>> $790;
     $792 = (($786) + ($791)|0);
     $$5728$shrunk$ph$in = $782;$$5736$shrunk$ph$in = $772;$$5744$ph = $762;$$sink820 = $792;
     label = 69;
     break;
    }
    case 2:  {
     $793 = HEAP16[$$6753>>1]|0;
     $794 = $793&65535;
     $795 = HEAP8[$31>>0]|0;
     $796 = $795&255;
     $797 = (79212 + ($796<<2)|0);
     $798 = HEAP32[$797>>2]|0;
     $799 = HEAP32[$32>>2]|0;
     $800 = $799 & $794;
     $801 = HEAP8[$33>>0]|0;
     $802 = $801&255;
     $803 = $800 >>> $802;
     $804 = (($798) + ($803)|0);
     $805 = HEAP8[$34>>0]|0;
     $806 = $805&255;
     $807 = (79212 + ($806<<2)|0);
     $808 = HEAP32[$807>>2]|0;
     $809 = HEAP32[$35>>2]|0;
     $810 = $809 & $794;
     $811 = HEAP8[$36>>0]|0;
     $812 = $811&255;
     $813 = $810 >>> $812;
     $814 = (($808) + ($813)|0);
     $815 = HEAP8[$37>>0]|0;
     $816 = $815&255;
     $817 = (79212 + ($816<<2)|0);
     $818 = HEAP32[$817>>2]|0;
     $819 = HEAP32[$38>>2]|0;
     $820 = $819 & $794;
     $821 = HEAP8[$39>>0]|0;
     $822 = $821&255;
     $823 = $820 >>> $822;
     $824 = (($818) + ($823)|0);
     $$5728$shrunk$ph$in = $814;$$5736$shrunk$ph$in = $804;$$5744$ph = $794;$$sink820 = $824;
     label = 69;
     break;
    }
    case 3:  {
     $825 = HEAP8[$33>>0]|0;
     $div774 = ($825&255) >>> 3;
     $826 = $div774&255;
     $827 = (($$6753) + ($826)|0);
     $828 = HEAP8[$36>>0]|0;
     $div775 = ($828&255) >>> 3;
     $829 = $div775&255;
     $830 = (($$6753) + ($829)|0);
     $831 = HEAP8[$39>>0]|0;
     $div776 = ($831&255) >>> 3;
     $832 = $div776&255;
     $833 = (($$6753) + ($832)|0);
     $$5728$shrunk$ph$in = $830;$$5736$shrunk$ph$in = $827;$$5744$ph = 0;$$sink820 = $833;
     label = 69;
     break;
    }
    case 4:  {
     $834 = HEAP32[$$6753>>2]|0;
     $835 = HEAP8[$31>>0]|0;
     $836 = $835&255;
     $837 = (79212 + ($836<<2)|0);
     $838 = HEAP32[$837>>2]|0;
     $839 = HEAP32[$32>>2]|0;
     $840 = $839 & $834;
     $841 = HEAP8[$33>>0]|0;
     $842 = $841&255;
     $843 = $840 >>> $842;
     $844 = (($838) + ($843)|0);
     $845 = HEAP8[$34>>0]|0;
     $846 = $845&255;
     $847 = (79212 + ($846<<2)|0);
     $848 = HEAP32[$847>>2]|0;
     $849 = HEAP32[$35>>2]|0;
     $850 = $849 & $834;
     $851 = HEAP8[$36>>0]|0;
     $852 = $851&255;
     $853 = $850 >>> $852;
     $854 = (($848) + ($853)|0);
     $855 = HEAP8[$37>>0]|0;
     $856 = $855&255;
     $857 = (79212 + ($856<<2)|0);
     $858 = HEAP32[$857>>2]|0;
     $859 = HEAP32[$38>>2]|0;
     $860 = $859 & $834;
     $861 = HEAP8[$39>>0]|0;
     $862 = $861&255;
     $863 = $860 >>> $862;
     $864 = (($858) + ($863)|0);
     $$5728$shrunk$ph$in = $854;$$5736$shrunk$ph$in = $844;$$5744$ph = $834;$$sink820 = $864;
     label = 69;
     break;
    }
    default: {
     $$5720$shrunk = 0;$$5728$shrunk = 0;$$5736$shrunk = 0;$$5744 = 0;
    }
    }
    if ((label|0) == 69) {
     label = 0;
     $$5728$shrunk$ph = HEAP8[$$5728$shrunk$ph$in>>0]|0;
     $$5736$shrunk$ph = HEAP8[$$5736$shrunk$ph$in>>0]|0;
     $865 = HEAP8[$$sink820>>0]|0;
     $$5720$shrunk = $865;$$5728$shrunk = $$5728$shrunk$ph;$$5736$shrunk = $$5736$shrunk$ph;$$5744 = $$5744$ph;
    }
    $866 = ($$5744|0)==($17|0);
    if (!($866)) {
     $$5720 = $$5720$shrunk&255;
     $$5728 = $$5728$shrunk&255;
     $$5736 = $$5736$shrunk&255;
     $867 = HEAP32[$29>>2]|0;
     $868 = ((($867)) + 4|0);
     $869 = HEAP32[$868>>2]|0;
     $870 = HEAP8[$$6761>>0]|0;
     $871 = $870&255;
     $872 = (($869) + ($871<<2)|0);
     $873 = HEAP8[$872>>0]|0;
     $874 = $873&255;
     $875 = (((($869) + ($871<<2)|0)) + 1|0);
     $876 = HEAP8[$875>>0]|0;
     $877 = $876&255;
     $878 = (((($869) + ($871<<2)|0)) + 2|0);
     $879 = HEAP8[$878>>0]|0;
     $880 = $879&255;
     $881 = (($$5736) - ($874))|0;
     $882 = Math_imul($881, $20)|0;
     $883 = (($882>>>0) / 255)&-1;
     $884 = (($883) + ($874))|0;
     $885 = (($$5728) - ($877))|0;
     $886 = Math_imul($885, $20)|0;
     $887 = (($886>>>0) / 255)&-1;
     $888 = (($887) + ($877))|0;
     $889 = (($$5720) - ($880))|0;
     $890 = Math_imul($889, $20)|0;
     $891 = (($890>>>0) / 255)&-1;
     $892 = (($891) + ($880))|0;
     $893 = $892 >>> 6;
     $894 = $893 & 3;
     $895 = $884 & 224;
     $896 = $888 >>> 3;
     $897 = $896 & 28;
     $898 = $897 | $895;
     $899 = $898 | $894;
     if ($30) {
      $900 = $899&255;
      $$sink804 = $900;
     } else {
      $901 = (($10) + ($899)|0);
      $902 = HEAP8[$901>>0]|0;
      $$sink804 = $902;
     }
     HEAP8[$$6761>>0] = $$sink804;
    }
    $903 = ((($$6761)) + 1|0);
    $904 = (($$6753) + ($15)|0);
    $$6 = $$5;$$7754 = $904;$$7762 = $903;
    label = 76;
    continue;
   }
   else if ((label|0) == 76) {
    label = 0;
    switch ($14<<24>>24) {
    case 1:  {
     $905 = HEAP8[$$7754>>0]|0;
     $906 = $905&255;
     $907 = HEAP8[$31>>0]|0;
     $908 = $907&255;
     $909 = (79212 + ($908<<2)|0);
     $910 = HEAP32[$909>>2]|0;
     $911 = HEAP32[$32>>2]|0;
     $912 = $911 & $906;
     $913 = HEAP8[$33>>0]|0;
     $914 = $913&255;
     $915 = $912 >>> $914;
     $916 = (($910) + ($915)|0);
     $917 = HEAP8[$34>>0]|0;
     $918 = $917&255;
     $919 = (79212 + ($918<<2)|0);
     $920 = HEAP32[$919>>2]|0;
     $921 = HEAP32[$35>>2]|0;
     $922 = $921 & $906;
     $923 = HEAP8[$36>>0]|0;
     $924 = $923&255;
     $925 = $922 >>> $924;
     $926 = (($920) + ($925)|0);
     $927 = HEAP8[$37>>0]|0;
     $928 = $927&255;
     $929 = (79212 + ($928<<2)|0);
     $930 = HEAP32[$929>>2]|0;
     $931 = HEAP32[$38>>2]|0;
     $932 = $931 & $906;
     $933 = HEAP8[$39>>0]|0;
     $934 = $933&255;
     $935 = $932 >>> $934;
     $936 = (($930) + ($935)|0);
     $$6729$shrunk$ph$in = $926;$$6737$shrunk$ph$in = $916;$$6745$ph = $906;$$sink822 = $936;
     label = 81;
     break;
    }
    case 2:  {
     $937 = HEAP16[$$7754>>1]|0;
     $938 = $937&65535;
     $939 = HEAP8[$31>>0]|0;
     $940 = $939&255;
     $941 = (79212 + ($940<<2)|0);
     $942 = HEAP32[$941>>2]|0;
     $943 = HEAP32[$32>>2]|0;
     $944 = $943 & $938;
     $945 = HEAP8[$33>>0]|0;
     $946 = $945&255;
     $947 = $944 >>> $946;
     $948 = (($942) + ($947)|0);
     $949 = HEAP8[$34>>0]|0;
     $950 = $949&255;
     $951 = (79212 + ($950<<2)|0);
     $952 = HEAP32[$951>>2]|0;
     $953 = HEAP32[$35>>2]|0;
     $954 = $953 & $938;
     $955 = HEAP8[$36>>0]|0;
     $956 = $955&255;
     $957 = $954 >>> $956;
     $958 = (($952) + ($957)|0);
     $959 = HEAP8[$37>>0]|0;
     $960 = $959&255;
     $961 = (79212 + ($960<<2)|0);
     $962 = HEAP32[$961>>2]|0;
     $963 = HEAP32[$38>>2]|0;
     $964 = $963 & $938;
     $965 = HEAP8[$39>>0]|0;
     $966 = $965&255;
     $967 = $964 >>> $966;
     $968 = (($962) + ($967)|0);
     $$6729$shrunk$ph$in = $958;$$6737$shrunk$ph$in = $948;$$6745$ph = $938;$$sink822 = $968;
     label = 81;
     break;
    }
    case 3:  {
     $969 = HEAP8[$33>>0]|0;
     $div = ($969&255) >>> 3;
     $970 = $div&255;
     $971 = (($$7754) + ($970)|0);
     $972 = HEAP8[$36>>0]|0;
     $div772 = ($972&255) >>> 3;
     $973 = $div772&255;
     $974 = (($$7754) + ($973)|0);
     $975 = HEAP8[$39>>0]|0;
     $div773 = ($975&255) >>> 3;
     $976 = $div773&255;
     $977 = (($$7754) + ($976)|0);
     $$6729$shrunk$ph$in = $974;$$6737$shrunk$ph$in = $971;$$6745$ph = 0;$$sink822 = $977;
     label = 81;
     break;
    }
    case 4:  {
     $978 = HEAP32[$$7754>>2]|0;
     $979 = HEAP8[$31>>0]|0;
     $980 = $979&255;
     $981 = (79212 + ($980<<2)|0);
     $982 = HEAP32[$981>>2]|0;
     $983 = HEAP32[$32>>2]|0;
     $984 = $983 & $978;
     $985 = HEAP8[$33>>0]|0;
     $986 = $985&255;
     $987 = $984 >>> $986;
     $988 = (($982) + ($987)|0);
     $989 = HEAP8[$34>>0]|0;
     $990 = $989&255;
     $991 = (79212 + ($990<<2)|0);
     $992 = HEAP32[$991>>2]|0;
     $993 = HEAP32[$35>>2]|0;
     $994 = $993 & $978;
     $995 = HEAP8[$36>>0]|0;
     $996 = $995&255;
     $997 = $994 >>> $996;
     $998 = (($992) + ($997)|0);
     $999 = HEAP8[$37>>0]|0;
     $1000 = $999&255;
     $1001 = (79212 + ($1000<<2)|0);
     $1002 = HEAP32[$1001>>2]|0;
     $1003 = HEAP32[$38>>2]|0;
     $1004 = $1003 & $978;
     $1005 = HEAP8[$39>>0]|0;
     $1006 = $1005&255;
     $1007 = $1004 >>> $1006;
     $1008 = (($1002) + ($1007)|0);
     $$6729$shrunk$ph$in = $998;$$6737$shrunk$ph$in = $988;$$6745$ph = $978;$$sink822 = $1008;
     label = 81;
     break;
    }
    default: {
     $$6721$shrunk = 0;$$6729$shrunk = 0;$$6737$shrunk = 0;$$6745 = 0;
    }
    }
    if ((label|0) == 81) {
     label = 0;
     $$6729$shrunk$ph = HEAP8[$$6729$shrunk$ph$in>>0]|0;
     $$6737$shrunk$ph = HEAP8[$$6737$shrunk$ph$in>>0]|0;
     $1009 = HEAP8[$$sink822>>0]|0;
     $$6721$shrunk = $1009;$$6729$shrunk = $$6729$shrunk$ph;$$6737$shrunk = $$6737$shrunk$ph;$$6745 = $$6745$ph;
    }
    $1010 = ($$6745|0)==($17|0);
    if (!($1010)) {
     $$6721 = $$6721$shrunk&255;
     $$6729 = $$6729$shrunk&255;
     $$6737 = $$6737$shrunk&255;
     $1011 = HEAP32[$29>>2]|0;
     $1012 = ((($1011)) + 4|0);
     $1013 = HEAP32[$1012>>2]|0;
     $1014 = HEAP8[$$7762>>0]|0;
     $1015 = $1014&255;
     $1016 = (($1013) + ($1015<<2)|0);
     $1017 = HEAP8[$1016>>0]|0;
     $1018 = $1017&255;
     $1019 = (((($1013) + ($1015<<2)|0)) + 1|0);
     $1020 = HEAP8[$1019>>0]|0;
     $1021 = $1020&255;
     $1022 = (((($1013) + ($1015<<2)|0)) + 2|0);
     $1023 = HEAP8[$1022>>0]|0;
     $1024 = $1023&255;
     $1025 = (($$6737) - ($1018))|0;
     $1026 = Math_imul($1025, $20)|0;
     $1027 = (($1026>>>0) / 255)&-1;
     $1028 = (($1027) + ($1018))|0;
     $1029 = (($$6729) - ($1021))|0;
     $1030 = Math_imul($1029, $20)|0;
     $1031 = (($1030>>>0) / 255)&-1;
     $1032 = (($1031) + ($1021))|0;
     $1033 = (($$6721) - ($1024))|0;
     $1034 = Math_imul($1033, $20)|0;
     $1035 = (($1034>>>0) / 255)&-1;
     $1036 = (($1035) + ($1024))|0;
     $1037 = $1028 & 224;
     $1038 = $1036 >>> 6;
     $1039 = $1038 & 3;
     $1040 = $1032 >>> 3;
     $1041 = $1040 & 28;
     $1042 = $1041 | $1037;
     $1043 = $1042 | $1039;
     if ($30) {
      $1044 = $1043&255;
      $$sink806 = $1044;
     } else {
      $1045 = (($10) + ($1043)|0);
      $1046 = HEAP8[$1045>>0]|0;
      $$sink806 = $1046;
     }
     HEAP8[$$7762>>0] = $$sink806;
    }
    $1047 = ((($$7762)) + 1|0);
    $1048 = (($$7754) + ($15)|0);
    $$7 = $$6;$$8 = $1048;$$8763 = $1047;
    label = 88;
    continue;
   }
   else if ((label|0) == 88) {
    label = 0;
    switch ($14<<24>>24) {
    case 1:  {
     $1049 = HEAP8[$$8>>0]|0;
     $1050 = $1049&255;
     $1051 = HEAP8[$31>>0]|0;
     $1052 = $1051&255;
     $1053 = (79212 + ($1052<<2)|0);
     $1054 = HEAP32[$1053>>2]|0;
     $1055 = HEAP32[$32>>2]|0;
     $1056 = $1055 & $1050;
     $1057 = HEAP8[$33>>0]|0;
     $1058 = $1057&255;
     $1059 = $1056 >>> $1058;
     $1060 = (($1054) + ($1059)|0);
     $1061 = HEAP8[$34>>0]|0;
     $1062 = $1061&255;
     $1063 = (79212 + ($1062<<2)|0);
     $1064 = HEAP32[$1063>>2]|0;
     $1065 = HEAP32[$35>>2]|0;
     $1066 = $1065 & $1050;
     $1067 = HEAP8[$36>>0]|0;
     $1068 = $1067&255;
     $1069 = $1066 >>> $1068;
     $1070 = (($1064) + ($1069)|0);
     $1071 = HEAP8[$37>>0]|0;
     $1072 = $1071&255;
     $1073 = (79212 + ($1072<<2)|0);
     $1074 = HEAP32[$1073>>2]|0;
     $1075 = HEAP32[$38>>2]|0;
     $1076 = $1075 & $1050;
     $1077 = HEAP8[$39>>0]|0;
     $1078 = $1077&255;
     $1079 = $1076 >>> $1078;
     $1080 = (($1074) + ($1079)|0);
     $$7730$shrunk$ph$in = $1070;$$7738$shrunk$ph$in = $1060;$$7746$ph = $1050;$$sink824 = $1080;
     label = 93;
     break;
    }
    case 2:  {
     $1081 = HEAP16[$$8>>1]|0;
     $1082 = $1081&65535;
     $1083 = HEAP8[$31>>0]|0;
     $1084 = $1083&255;
     $1085 = (79212 + ($1084<<2)|0);
     $1086 = HEAP32[$1085>>2]|0;
     $1087 = HEAP32[$32>>2]|0;
     $1088 = $1087 & $1082;
     $1089 = HEAP8[$33>>0]|0;
     $1090 = $1089&255;
     $1091 = $1088 >>> $1090;
     $1092 = (($1086) + ($1091)|0);
     $1093 = HEAP8[$34>>0]|0;
     $1094 = $1093&255;
     $1095 = (79212 + ($1094<<2)|0);
     $1096 = HEAP32[$1095>>2]|0;
     $1097 = HEAP32[$35>>2]|0;
     $1098 = $1097 & $1082;
     $1099 = HEAP8[$36>>0]|0;
     $1100 = $1099&255;
     $1101 = $1098 >>> $1100;
     $1102 = (($1096) + ($1101)|0);
     $1103 = HEAP8[$37>>0]|0;
     $1104 = $1103&255;
     $1105 = (79212 + ($1104<<2)|0);
     $1106 = HEAP32[$1105>>2]|0;
     $1107 = HEAP32[$38>>2]|0;
     $1108 = $1107 & $1082;
     $1109 = HEAP8[$39>>0]|0;
     $1110 = $1109&255;
     $1111 = $1108 >>> $1110;
     $1112 = (($1106) + ($1111)|0);
     $$7730$shrunk$ph$in = $1102;$$7738$shrunk$ph$in = $1092;$$7746$ph = $1082;$$sink824 = $1112;
     label = 93;
     break;
    }
    case 3:  {
     $1113 = HEAP8[$33>>0]|0;
     $div792 = ($1113&255) >>> 3;
     $1114 = $div792&255;
     $1115 = (($$8) + ($1114)|0);
     $1116 = HEAP8[$36>>0]|0;
     $div793 = ($1116&255) >>> 3;
     $1117 = $div793&255;
     $1118 = (($$8) + ($1117)|0);
     $1119 = HEAP8[$39>>0]|0;
     $div794 = ($1119&255) >>> 3;
     $1120 = $div794&255;
     $1121 = (($$8) + ($1120)|0);
     $$7730$shrunk$ph$in = $1118;$$7738$shrunk$ph$in = $1115;$$7746$ph = 0;$$sink824 = $1121;
     label = 93;
     break;
    }
    case 4:  {
     $1122 = HEAP32[$$8>>2]|0;
     $1123 = HEAP8[$31>>0]|0;
     $1124 = $1123&255;
     $1125 = (79212 + ($1124<<2)|0);
     $1126 = HEAP32[$1125>>2]|0;
     $1127 = HEAP32[$32>>2]|0;
     $1128 = $1127 & $1122;
     $1129 = HEAP8[$33>>0]|0;
     $1130 = $1129&255;
     $1131 = $1128 >>> $1130;
     $1132 = (($1126) + ($1131)|0);
     $1133 = HEAP8[$34>>0]|0;
     $1134 = $1133&255;
     $1135 = (79212 + ($1134<<2)|0);
     $1136 = HEAP32[$1135>>2]|0;
     $1137 = HEAP32[$35>>2]|0;
     $1138 = $1137 & $1122;
     $1139 = HEAP8[$36>>0]|0;
     $1140 = $1139&255;
     $1141 = $1138 >>> $1140;
     $1142 = (($1136) + ($1141)|0);
     $1143 = HEAP8[$37>>0]|0;
     $1144 = $1143&255;
     $1145 = (79212 + ($1144<<2)|0);
     $1146 = HEAP32[$1145>>2]|0;
     $1147 = HEAP32[$38>>2]|0;
     $1148 = $1147 & $1122;
     $1149 = HEAP8[$39>>0]|0;
     $1150 = $1149&255;
     $1151 = $1148 >>> $1150;
     $1152 = (($1146) + ($1151)|0);
     $$7730$shrunk$ph$in = $1142;$$7738$shrunk$ph$in = $1132;$$7746$ph = $1122;$$sink824 = $1152;
     label = 93;
     break;
    }
    default: {
     $$7722$shrunk = 0;$$7730$shrunk = 0;$$7738$shrunk = 0;$$7746 = 0;
    }
    }
    if ((label|0) == 93) {
     label = 0;
     $$7730$shrunk$ph = HEAP8[$$7730$shrunk$ph$in>>0]|0;
     $$7738$shrunk$ph = HEAP8[$$7738$shrunk$ph$in>>0]|0;
     $1153 = HEAP8[$$sink824>>0]|0;
     $$7722$shrunk = $1153;$$7730$shrunk = $$7730$shrunk$ph;$$7738$shrunk = $$7738$shrunk$ph;$$7746 = $$7746$ph;
    }
    $1154 = ($$7746|0)==($17|0);
    if (!($1154)) {
     $$7722 = $$7722$shrunk&255;
     $$7730 = $$7730$shrunk&255;
     $$7738 = $$7738$shrunk&255;
     $1155 = HEAP32[$29>>2]|0;
     $1156 = ((($1155)) + 4|0);
     $1157 = HEAP32[$1156>>2]|0;
     $1158 = HEAP8[$$8763>>0]|0;
     $1159 = $1158&255;
     $1160 = (($1157) + ($1159<<2)|0);
     $1161 = HEAP8[$1160>>0]|0;
     $1162 = $1161&255;
     $1163 = (((($1157) + ($1159<<2)|0)) + 1|0);
     $1164 = HEAP8[$1163>>0]|0;
     $1165 = $1164&255;
     $1166 = (((($1157) + ($1159<<2)|0)) + 2|0);
     $1167 = HEAP8[$1166>>0]|0;
     $1168 = $1167&255;
     $1169 = (($$7738) - ($1162))|0;
     $1170 = Math_imul($1169, $20)|0;
     $1171 = (($1170>>>0) / 255)&-1;
     $1172 = (($1171) + ($1162))|0;
     $1173 = (($$7730) - ($1165))|0;
     $1174 = Math_imul($1173, $20)|0;
     $1175 = (($1174>>>0) / 255)&-1;
     $1176 = (($1175) + ($1165))|0;
     $1177 = (($$7722) - ($1168))|0;
     $1178 = Math_imul($1177, $20)|0;
     $1179 = (($1178>>>0) / 255)&-1;
     $1180 = (($1179) + ($1168))|0;
     $1181 = $1172 & 224;
     $1182 = $1180 >>> 6;
     $1183 = $1182 & 3;
     $1184 = $1176 >>> 3;
     $1185 = $1184 & 28;
     $1186 = $1185 | $1181;
     $1187 = $1186 | $1183;
     if ($30) {
      $1188 = $1187&255;
      $$sink808 = $1188;
     } else {
      $1189 = (($10) + ($1187)|0);
      $1190 = HEAP8[$1189>>0]|0;
      $$sink808 = $1190;
     }
     HEAP8[$$8763>>0] = $$sink808;
    }
    $1191 = ((($$8763)) + 1|0);
    $1192 = (($$8) + ($15)|0);
    $1193 = (($$7) + -1)|0;
    $1194 = ($$7|0)>(1);
    if ($1194) {
     $$0 = $1193;$$1748 = $1192;$$1756 = $1191;
     label = 4;
     continue;
    } else {
     break;
    }
   }
  }
  $1195 = (($1192) + ($6)|0);
  $1196 = (($1191) + ($8)|0);
  $1197 = ($40|0)==(0);
  if ($1197) {
   label = 102;
   break;
  } else {
   $$0747826 = $1195;$$0755825 = $1196;$$in = $40;
  }
 }
 if ((label|0) == 100) {
  // unreachable;
 }
 else if ((label|0) == 102) {
  return;
 }
}
function _BlitNtoNSurfaceAlphaKey($0) {
 $0 = $0|0;
 var $$0696768 = 0, $$0697767 = 0, $$0702 = 0, $$0706 = 0, $$0706$shrunk = 0, $$0710 = 0, $$0710$shrunk = 0, $$0714 = 0, $$0714$shrunk = 0, $$0718 = 0, $$0718$shrunk = 0, $$0722 = 0, $$1 = 0, $$1698 = 0, $$1703 = 0, $$1707 = 0, $$1707$shrunk = 0, $$1711 = 0, $$1711$shrunk = 0, $$1715 = 0;
 var $$1715$shrunk = 0, $$1719 = 0, $$1719$shrunk = 0, $$1723 = 0, $$2 = 0, $$2699 = 0, $$2704 = 0, $$2708 = 0, $$2708$shrunk = 0, $$2712 = 0, $$2712$shrunk = 0, $$2716 = 0, $$2716$shrunk = 0, $$2720 = 0, $$2720$shrunk = 0, $$2724 = 0, $$3 = 0, $$3700 = 0, $$3705 = 0, $$3709 = 0;
 var $$3709$shrunk = 0, $$3713 = 0, $$3713$shrunk = 0, $$3717 = 0, $$3717$shrunk = 0, $$3721 = 0, $$3721$shrunk = 0, $$3725 = 0, $$4 = 0, $$4701 = 0, $$in = 0, $1 = 0, $10 = 0, $100 = 0, $1000 = 0, $1001 = 0, $1002 = 0, $1003 = 0, $1004 = 0, $1005 = 0;
 var $1006 = 0, $1007 = 0, $1008 = 0, $1009 = 0, $101 = 0, $1010 = 0, $1011 = 0, $1012 = 0, $1013 = 0, $1014 = 0, $1015 = 0, $1016 = 0, $1017 = 0, $1018 = 0, $1019 = 0, $102 = 0, $1020 = 0, $1021 = 0, $1022 = 0, $1023 = 0;
 var $1024 = 0, $1025 = 0, $1026 = 0, $1027 = 0, $1028 = 0, $1029 = 0, $103 = 0, $1030 = 0, $1031 = 0, $1032 = 0, $1033 = 0, $1034 = 0, $1035 = 0, $1036 = 0, $1037 = 0, $1038 = 0, $1039 = 0, $104 = 0, $1040 = 0, $1041 = 0;
 var $1042 = 0, $1043 = 0, $1044 = 0, $1045 = 0, $1046 = 0, $1047 = 0, $1048 = 0, $1049 = 0, $105 = 0, $1050 = 0, $1051 = 0, $1052 = 0, $1053 = 0, $1054 = 0, $1055 = 0, $1056 = 0, $1057 = 0, $1058 = 0, $1059 = 0, $106 = 0;
 var $1060 = 0, $1061 = 0, $1062 = 0, $1063 = 0, $1064 = 0, $1065 = 0, $1066 = 0, $1067 = 0, $1068 = 0, $1069 = 0, $107 = 0, $1070 = 0, $1071 = 0, $1072 = 0, $1073 = 0, $1074 = 0, $1075 = 0, $1076 = 0, $1077 = 0, $1078 = 0;
 var $1079 = 0, $108 = 0, $1080 = 0, $1081 = 0, $1082 = 0, $1083 = 0, $1084 = 0, $1085 = 0, $1086 = 0, $1087 = 0, $1088 = 0, $1089 = 0, $109 = 0, $1090 = 0, $1091 = 0, $1092 = 0, $1093 = 0, $1094 = 0, $1095 = 0, $1096 = 0;
 var $1097 = 0, $1098 = 0, $1099 = 0, $11 = 0, $110 = 0, $1100 = 0, $1101 = 0, $1102 = 0, $1103 = 0, $1104 = 0, $1105 = 0, $1106 = 0, $1107 = 0, $1108 = 0, $1109 = 0, $111 = 0, $1110 = 0, $1111 = 0, $1112 = 0, $1113 = 0;
 var $1114 = 0, $1115 = 0, $1116 = 0, $1117 = 0, $1118 = 0, $1119 = 0, $112 = 0, $1120 = 0, $1121 = 0, $1122 = 0, $1123 = 0, $1124 = 0, $1125 = 0, $1126 = 0, $1127 = 0, $1128 = 0, $1129 = 0, $113 = 0, $1130 = 0, $1131 = 0;
 var $1132 = 0, $1133 = 0, $1134 = 0, $1135 = 0, $1136 = 0, $1137 = 0, $1138 = 0, $1139 = 0, $114 = 0, $1140 = 0, $1141 = 0, $1142 = 0, $1143 = 0, $1144 = 0, $1145 = 0, $1146 = 0, $1147 = 0, $1148 = 0, $1149 = 0, $115 = 0;
 var $1150 = 0, $1151 = 0, $1152 = 0, $1153 = 0, $1154 = 0, $1155 = 0, $1156 = 0, $1157 = 0, $1158 = 0, $1159 = 0, $116 = 0, $1160 = 0, $1161 = 0, $1162 = 0, $1163 = 0, $1164 = 0, $1165 = 0, $1166 = 0, $1167 = 0, $1168 = 0;
 var $1169 = 0, $117 = 0, $1170 = 0, $1171 = 0, $1172 = 0, $1173 = 0, $1174 = 0, $1175 = 0, $1176 = 0, $1177 = 0, $1178 = 0, $1179 = 0, $118 = 0, $1180 = 0, $1181 = 0, $1182 = 0, $1183 = 0, $1184 = 0, $1185 = 0, $1186 = 0;
 var $1187 = 0, $1188 = 0, $1189 = 0, $119 = 0, $1190 = 0, $1191 = 0, $1192 = 0, $1193 = 0, $1194 = 0, $1195 = 0, $1196 = 0, $1197 = 0, $1198 = 0, $1199 = 0, $12 = 0, $120 = 0, $1200 = 0, $1201 = 0, $1202 = 0, $1203 = 0;
 var $1204 = 0, $1205 = 0, $1206 = 0, $1207 = 0, $1208 = 0, $1209 = 0, $121 = 0, $1210 = 0, $1211 = 0, $1212 = 0, $1213 = 0, $1214 = 0, $1215 = 0, $1216 = 0, $1217 = 0, $1218 = 0, $1219 = 0, $122 = 0, $1220 = 0, $1221 = 0;
 var $1222 = 0, $1223 = 0, $1224 = 0, $1225 = 0, $1226 = 0, $1227 = 0, $1228 = 0, $1229 = 0, $123 = 0, $1230 = 0, $1231 = 0, $1232 = 0, $1233 = 0, $1234 = 0, $1235 = 0, $1236 = 0, $1237 = 0, $1238 = 0, $1239 = 0, $124 = 0;
 var $1240 = 0, $1241 = 0, $1242 = 0, $1243 = 0, $1244 = 0, $1245 = 0, $1246 = 0, $1247 = 0, $1248 = 0, $1249 = 0, $125 = 0, $1250 = 0, $1251 = 0, $1252 = 0, $1253 = 0, $1254 = 0, $1255 = 0, $1256 = 0, $1257 = 0, $1258 = 0;
 var $1259 = 0, $126 = 0, $1260 = 0, $1261 = 0, $1262 = 0, $1263 = 0, $1264 = 0, $1265 = 0, $1266 = 0, $1267 = 0, $1268 = 0, $1269 = 0, $127 = 0, $1270 = 0, $1271 = 0, $1272 = 0, $1273 = 0, $1274 = 0, $1275 = 0, $1276 = 0;
 var $1277 = 0, $1278 = 0, $1279 = 0, $128 = 0, $1280 = 0, $1281 = 0, $1282 = 0, $1283 = 0, $1284 = 0, $1285 = 0, $1286 = 0, $1287 = 0, $1288 = 0, $1289 = 0, $129 = 0, $1290 = 0, $1291 = 0, $1292 = 0, $1293 = 0, $1294 = 0;
 var $1295 = 0, $1296 = 0, $1297 = 0, $1298 = 0, $1299 = 0, $13 = 0, $130 = 0, $1300 = 0, $1301 = 0, $1302 = 0, $1303 = 0, $1304 = 0, $1305 = 0, $1306 = 0, $1307 = 0, $1308 = 0, $1309 = 0, $131 = 0, $1310 = 0, $1311 = 0;
 var $1312 = 0, $1313 = 0, $1314 = 0, $1315 = 0, $1316 = 0, $1317 = 0, $1318 = 0, $1319 = 0, $132 = 0, $1320 = 0, $1321 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0;
 var $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0;
 var $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0;
 var $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0;
 var $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0;
 var $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0;
 var $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0;
 var $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0;
 var $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0;
 var $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0;
 var $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0;
 var $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0;
 var $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0;
 var $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0;
 var $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0;
 var $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0;
 var $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0;
 var $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0;
 var $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0;
 var $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0;
 var $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0;
 var $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0;
 var $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0;
 var $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0;
 var $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0;
 var $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0;
 var $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0;
 var $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0;
 var $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0;
 var $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0;
 var $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0;
 var $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0;
 var $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0;
 var $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0;
 var $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0;
 var $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0;
 var $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0;
 var $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0;
 var $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = 0, $825 = 0;
 var $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = 0, $834 = 0, $835 = 0, $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = 0, $841 = 0, $842 = 0, $843 = 0;
 var $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0, $850 = 0, $851 = 0, $852 = 0, $853 = 0, $854 = 0, $855 = 0, $856 = 0, $857 = 0, $858 = 0, $859 = 0, $86 = 0, $860 = 0, $861 = 0;
 var $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0, $869 = 0, $87 = 0, $870 = 0, $871 = 0, $872 = 0, $873 = 0, $874 = 0, $875 = 0, $876 = 0, $877 = 0, $878 = 0, $879 = 0, $88 = 0;
 var $880 = 0, $881 = 0, $882 = 0, $883 = 0, $884 = 0, $885 = 0, $886 = 0, $887 = 0, $888 = 0, $889 = 0, $89 = 0, $890 = 0, $891 = 0, $892 = 0, $893 = 0, $894 = 0, $895 = 0, $896 = 0, $897 = 0, $898 = 0;
 var $899 = 0, $9 = 0, $90 = 0, $900 = 0, $901 = 0, $902 = 0, $903 = 0, $904 = 0, $905 = 0, $906 = 0, $907 = 0, $908 = 0, $909 = 0, $91 = 0, $910 = 0, $911 = 0, $912 = 0, $913 = 0, $914 = 0, $915 = 0;
 var $916 = 0, $917 = 0, $918 = 0, $919 = 0, $92 = 0, $920 = 0, $921 = 0, $922 = 0, $923 = 0, $924 = 0, $925 = 0, $926 = 0, $927 = 0, $928 = 0, $929 = 0, $93 = 0, $930 = 0, $931 = 0, $932 = 0, $933 = 0;
 var $934 = 0, $935 = 0, $936 = 0, $937 = 0, $938 = 0, $939 = 0, $94 = 0, $940 = 0, $941 = 0, $942 = 0, $943 = 0, $944 = 0, $945 = 0, $946 = 0, $947 = 0, $948 = 0, $949 = 0, $95 = 0, $950 = 0, $951 = 0;
 var $952 = 0, $953 = 0, $954 = 0, $955 = 0, $956 = 0, $957 = 0, $958 = 0, $959 = 0, $96 = 0, $960 = 0, $961 = 0, $962 = 0, $963 = 0, $964 = 0, $965 = 0, $966 = 0, $967 = 0, $968 = 0, $969 = 0, $97 = 0;
 var $970 = 0, $971 = 0, $972 = 0, $973 = 0, $974 = 0, $975 = 0, $976 = 0, $977 = 0, $978 = 0, $979 = 0, $98 = 0, $980 = 0, $981 = 0, $982 = 0, $983 = 0, $984 = 0, $985 = 0, $986 = 0, $987 = 0, $988 = 0;
 var $989 = 0, $99 = 0, $990 = 0, $991 = 0, $992 = 0, $993 = 0, $994 = 0, $995 = 0, $996 = 0, $997 = 0, $998 = 0, $999 = 0, $div = 0, $div732 = 0, $div733 = 0, $div734 = 0, $div735 = 0, $div736 = 0, $div739 = 0, $div740 = 0;
 var $div741 = 0, $div742 = 0, $div743 = 0, $div744 = 0, $div747 = 0, $div748 = 0, $div749 = 0, $div750 = 0, $div751 = 0, $div752 = 0, $div755 = 0, $div756 = 0, $div757 = 0, $div758 = 0, $div759 = 0, $div760 = 0, $or$cond = 0, $or$cond761 = 0, $or$cond762 = 0, $or$cond763 = 0;
 var $trunc = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($0)) + 36|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($0)) + 40|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ((($0)) + 44|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ((($0)) + 56|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ((($10)) + 9|0);
 $16 = HEAP8[$15>>0]|0;
 $17 = $16&255;
 $18 = ((($12)) + 9|0);
 $19 = HEAP8[$18>>0]|0;
 $20 = $19&255;
 $21 = ((($0)) + 63|0);
 $22 = HEAP8[$21>>0]|0;
 $23 = $22&255;
 $24 = ($4|0)==(0);
 if ($24) {
  return;
 }
 $25 = ((($0)) + 20|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = HEAP32[$0>>2]|0;
 $28 = (($2) + 3)|0;
 $29 = (($28|0) / 4)&-1;
 $trunc = $2&255;
 $30 = ($22<<24>>24)==(0);
 $31 = ((($10)) + 28|0);
 $32 = ((($10)) + 12|0);
 $33 = ((($10)) + 32|0);
 $34 = ((($10)) + 29|0);
 $35 = ((($10)) + 16|0);
 $36 = ((($10)) + 33|0);
 $37 = ((($10)) + 30|0);
 $38 = ((($10)) + 20|0);
 $39 = ((($10)) + 34|0);
 $40 = ((($12)) + 28|0);
 $41 = ((($12)) + 32|0);
 $42 = ((($12)) + 29|0);
 $43 = ((($12)) + 33|0);
 $44 = ((($12)) + 30|0);
 $45 = ((($12)) + 34|0);
 $46 = ((($12)) + 31|0);
 $47 = ((($12)) + 35|0);
 $48 = ((($12)) + 12|0);
 $49 = ((($12)) + 16|0);
 $50 = ((($12)) + 20|0);
 $51 = ((($12)) + 24|0);
 $$0696768 = $27;$$0697767 = $26;$$in = $4;
 L4: while(1) {
  $52 = (($$in) + -1)|0;
  $trunc$clear = $trunc & 3;
  switch ($trunc$clear<<24>>24) {
  case 0:  {
   $$0722 = $29;$$1 = $$0696768;$$1698 = $$0697767;
   label = 4;
   break;
  }
  case 3:  {
   $$1723 = $29;$$2 = $$0696768;$$2699 = $$0697767;
   label = 21;
   break;
  }
  case 2:  {
   $$2724 = $29;$$3 = $$0696768;$$3700 = $$0697767;
   label = 38;
   break;
  }
  case 1:  {
   $$3725 = $29;$$4 = $$0696768;$$4701 = $$0697767;
   label = 55;
   break;
  }
  default: {
   label = 72;
   break L4;
  }
  }
  while(1) {
   if ((label|0) == 4) {
    label = 0;
    switch ($16<<24>>24) {
    case 1:  {
     $53 = HEAP8[$$1>>0]|0;
     $54 = $53&255;
     $$0702 = $54;
     break;
    }
    case 2:  {
     $55 = HEAP16[$$1>>1]|0;
     $56 = $55&65535;
     $$0702 = $56;
     break;
    }
    case 3:  {
     $57 = HEAP8[$$1>>0]|0;
     $58 = $57&255;
     $59 = ((($$1)) + 1|0);
     $60 = HEAP8[$59>>0]|0;
     $61 = $60&255;
     $62 = $61 << 8;
     $63 = $62 | $58;
     $64 = ((($$1)) + 2|0);
     $65 = HEAP8[$64>>0]|0;
     $66 = $65&255;
     $67 = $66 << 16;
     $68 = $63 | $67;
     $$0702 = $68;
     break;
    }
    case 4:  {
     $69 = HEAP32[$$1>>2]|0;
     $$0702 = $69;
     break;
    }
    default: {
     $$0702 = 0;
    }
    }
    $70 = ($$0702|0)==($14|0);
    $or$cond = $30 | $70;
    L15: do {
     if (!($or$cond)) {
      $71 = HEAP8[$31>>0]|0;
      $72 = $71&255;
      $73 = (79212 + ($72<<2)|0);
      $74 = HEAP32[$73>>2]|0;
      $75 = HEAP32[$32>>2]|0;
      $76 = $75 & $$0702;
      $77 = HEAP8[$33>>0]|0;
      $78 = $77&255;
      $79 = $76 >>> $78;
      $80 = (($74) + ($79)|0);
      $81 = HEAP8[$80>>0]|0;
      $82 = $81&255;
      $83 = HEAP8[$34>>0]|0;
      $84 = $83&255;
      $85 = (79212 + ($84<<2)|0);
      $86 = HEAP32[$85>>2]|0;
      $87 = HEAP32[$35>>2]|0;
      $88 = $87 & $$0702;
      $89 = HEAP8[$36>>0]|0;
      $90 = $89&255;
      $91 = $88 >>> $90;
      $92 = (($86) + ($91)|0);
      $93 = HEAP8[$92>>0]|0;
      $94 = $93&255;
      $95 = HEAP8[$37>>0]|0;
      $96 = $95&255;
      $97 = (79212 + ($96<<2)|0);
      $98 = HEAP32[$97>>2]|0;
      $99 = HEAP32[$38>>2]|0;
      $100 = $99 & $$0702;
      $101 = HEAP8[$39>>0]|0;
      $102 = $101&255;
      $103 = $100 >>> $102;
      $104 = (($98) + ($103)|0);
      $105 = HEAP8[$104>>0]|0;
      $106 = $105&255;
      switch ($19<<24>>24) {
      case 1:  {
       $107 = HEAP8[$$1698>>0]|0;
       $108 = $107&255;
       $109 = HEAP8[$40>>0]|0;
       $110 = $109&255;
       $111 = (79212 + ($110<<2)|0);
       $112 = HEAP32[$111>>2]|0;
       $113 = HEAP32[$48>>2]|0;
       $114 = $113 & $108;
       $115 = HEAP8[$41>>0]|0;
       $116 = $115&255;
       $117 = $114 >>> $116;
       $118 = (($112) + ($117)|0);
       $119 = HEAP8[$118>>0]|0;
       $120 = HEAP8[$42>>0]|0;
       $121 = $120&255;
       $122 = (79212 + ($121<<2)|0);
       $123 = HEAP32[$122>>2]|0;
       $124 = HEAP32[$49>>2]|0;
       $125 = $124 & $108;
       $126 = HEAP8[$43>>0]|0;
       $127 = $126&255;
       $128 = $125 >>> $127;
       $129 = (($123) + ($128)|0);
       $130 = HEAP8[$129>>0]|0;
       $131 = HEAP8[$44>>0]|0;
       $132 = $131&255;
       $133 = (79212 + ($132<<2)|0);
       $134 = HEAP32[$133>>2]|0;
       $135 = HEAP32[$50>>2]|0;
       $136 = $135 & $108;
       $137 = HEAP8[$45>>0]|0;
       $138 = $137&255;
       $139 = $136 >>> $138;
       $140 = (($134) + ($139)|0);
       $141 = HEAP8[$140>>0]|0;
       $142 = HEAP8[$46>>0]|0;
       $143 = $142&255;
       $144 = (79212 + ($143<<2)|0);
       $145 = HEAP32[$144>>2]|0;
       $146 = HEAP32[$51>>2]|0;
       $147 = $146 & $108;
       $148 = HEAP8[$47>>0]|0;
       $149 = $148&255;
       $150 = $147 >>> $149;
       $151 = (($145) + ($150)|0);
       $152 = HEAP8[$151>>0]|0;
       $$0706$shrunk = $119;$$0710$shrunk = $130;$$0714$shrunk = $141;$$0718$shrunk = $152;
       break;
      }
      case 2:  {
       $153 = HEAP16[$$1698>>1]|0;
       $154 = $153&65535;
       $155 = HEAP8[$40>>0]|0;
       $156 = $155&255;
       $157 = (79212 + ($156<<2)|0);
       $158 = HEAP32[$157>>2]|0;
       $159 = HEAP32[$48>>2]|0;
       $160 = $159 & $154;
       $161 = HEAP8[$41>>0]|0;
       $162 = $161&255;
       $163 = $160 >>> $162;
       $164 = (($158) + ($163)|0);
       $165 = HEAP8[$164>>0]|0;
       $166 = HEAP8[$42>>0]|0;
       $167 = $166&255;
       $168 = (79212 + ($167<<2)|0);
       $169 = HEAP32[$168>>2]|0;
       $170 = HEAP32[$49>>2]|0;
       $171 = $170 & $154;
       $172 = HEAP8[$43>>0]|0;
       $173 = $172&255;
       $174 = $171 >>> $173;
       $175 = (($169) + ($174)|0);
       $176 = HEAP8[$175>>0]|0;
       $177 = HEAP8[$44>>0]|0;
       $178 = $177&255;
       $179 = (79212 + ($178<<2)|0);
       $180 = HEAP32[$179>>2]|0;
       $181 = HEAP32[$50>>2]|0;
       $182 = $181 & $154;
       $183 = HEAP8[$45>>0]|0;
       $184 = $183&255;
       $185 = $182 >>> $184;
       $186 = (($180) + ($185)|0);
       $187 = HEAP8[$186>>0]|0;
       $188 = HEAP8[$46>>0]|0;
       $189 = $188&255;
       $190 = (79212 + ($189<<2)|0);
       $191 = HEAP32[$190>>2]|0;
       $192 = HEAP32[$51>>2]|0;
       $193 = $192 & $154;
       $194 = HEAP8[$47>>0]|0;
       $195 = $194&255;
       $196 = $193 >>> $195;
       $197 = (($191) + ($196)|0);
       $198 = HEAP8[$197>>0]|0;
       $$0706$shrunk = $165;$$0710$shrunk = $176;$$0714$shrunk = $187;$$0718$shrunk = $198;
       break;
      }
      case 3:  {
       $199 = HEAP8[$41>>0]|0;
       $div750 = ($199&255) >>> 3;
       $200 = $div750&255;
       $201 = (($$1698) + ($200)|0);
       $202 = HEAP8[$201>>0]|0;
       $203 = HEAP8[$43>>0]|0;
       $div751 = ($203&255) >>> 3;
       $204 = $div751&255;
       $205 = (($$1698) + ($204)|0);
       $206 = HEAP8[$205>>0]|0;
       $207 = HEAP8[$45>>0]|0;
       $div752 = ($207&255) >>> 3;
       $208 = $div752&255;
       $209 = (($$1698) + ($208)|0);
       $210 = HEAP8[$209>>0]|0;
       $$0706$shrunk = $202;$$0710$shrunk = $206;$$0714$shrunk = $210;$$0718$shrunk = -1;
       break;
      }
      case 4:  {
       $211 = HEAP32[$$1698>>2]|0;
       $212 = HEAP8[$40>>0]|0;
       $213 = $212&255;
       $214 = (79212 + ($213<<2)|0);
       $215 = HEAP32[$214>>2]|0;
       $216 = HEAP32[$48>>2]|0;
       $217 = $216 & $211;
       $218 = HEAP8[$41>>0]|0;
       $219 = $218&255;
       $220 = $217 >>> $219;
       $221 = (($215) + ($220)|0);
       $222 = HEAP8[$221>>0]|0;
       $223 = HEAP8[$42>>0]|0;
       $224 = $223&255;
       $225 = (79212 + ($224<<2)|0);
       $226 = HEAP32[$225>>2]|0;
       $227 = HEAP32[$49>>2]|0;
       $228 = $227 & $211;
       $229 = HEAP8[$43>>0]|0;
       $230 = $229&255;
       $231 = $228 >>> $230;
       $232 = (($226) + ($231)|0);
       $233 = HEAP8[$232>>0]|0;
       $234 = HEAP8[$44>>0]|0;
       $235 = $234&255;
       $236 = (79212 + ($235<<2)|0);
       $237 = HEAP32[$236>>2]|0;
       $238 = HEAP32[$50>>2]|0;
       $239 = $238 & $211;
       $240 = HEAP8[$45>>0]|0;
       $241 = $240&255;
       $242 = $239 >>> $241;
       $243 = (($237) + ($242)|0);
       $244 = HEAP8[$243>>0]|0;
       $245 = HEAP8[$46>>0]|0;
       $246 = $245&255;
       $247 = (79212 + ($246<<2)|0);
       $248 = HEAP32[$247>>2]|0;
       $249 = HEAP32[$51>>2]|0;
       $250 = $249 & $211;
       $251 = HEAP8[$47>>0]|0;
       $252 = $251&255;
       $253 = $250 >>> $252;
       $254 = (($248) + ($253)|0);
       $255 = HEAP8[$254>>0]|0;
       $$0706$shrunk = $222;$$0710$shrunk = $233;$$0714$shrunk = $244;$$0718$shrunk = $255;
       break;
      }
      default: {
       $$0706$shrunk = 0;$$0710$shrunk = 0;$$0714$shrunk = 0;$$0718$shrunk = 0;
      }
      }
      $$0706 = $$0706$shrunk&255;
      $$0710 = $$0710$shrunk&255;
      $$0714 = $$0714$shrunk&255;
      $$0718 = $$0718$shrunk&255;
      $256 = (($82) - ($$0706))|0;
      $257 = Math_imul($256, $23)|0;
      $258 = (($257>>>0) / 255)&-1;
      $259 = (($258) + ($$0706))|0;
      $260 = (($94) - ($$0710))|0;
      $261 = Math_imul($260, $23)|0;
      $262 = (($261>>>0) / 255)&-1;
      $263 = (($262) + ($$0710))|0;
      $264 = (($106) - ($$0714))|0;
      $265 = Math_imul($264, $23)|0;
      $266 = (($265>>>0) / 255)&-1;
      $267 = (($266) + ($$0714))|0;
      $268 = (($$0718) + ($23))|0;
      $269 = Math_imul($$0718, $23)|0;
      $270 = (($269>>>0) / 255)&-1;
      $271 = (($268) - ($270))|0;
      switch ($19<<24>>24) {
      case 1:  {
       $272 = HEAP8[$40>>0]|0;
       $273 = $272&255;
       $274 = $259 >>> $273;
       $275 = HEAP8[$41>>0]|0;
       $276 = $275&255;
       $277 = $274 << $276;
       $278 = HEAP8[$42>>0]|0;
       $279 = $278&255;
       $280 = $263 >>> $279;
       $281 = HEAP8[$43>>0]|0;
       $282 = $281&255;
       $283 = $280 << $282;
       $284 = $283 | $277;
       $285 = HEAP8[$44>>0]|0;
       $286 = $285&255;
       $287 = $267 >>> $286;
       $288 = HEAP8[$45>>0]|0;
       $289 = $288&255;
       $290 = $287 << $289;
       $291 = $284 | $290;
       $292 = HEAP8[$46>>0]|0;
       $293 = $292&255;
       $294 = $271 >>> $293;
       $295 = HEAP8[$47>>0]|0;
       $296 = $295&255;
       $297 = $294 << $296;
       $298 = $291 | $297;
       $299 = $298&255;
       HEAP8[$$1698>>0] = $299;
       break L15;
       break;
      }
      case 2:  {
       $300 = HEAP8[$40>>0]|0;
       $301 = $300&255;
       $302 = $259 >>> $301;
       $303 = HEAP8[$41>>0]|0;
       $304 = $303&255;
       $305 = $302 << $304;
       $306 = HEAP8[$42>>0]|0;
       $307 = $306&255;
       $308 = $263 >>> $307;
       $309 = HEAP8[$43>>0]|0;
       $310 = $309&255;
       $311 = $308 << $310;
       $312 = $311 | $305;
       $313 = HEAP8[$44>>0]|0;
       $314 = $313&255;
       $315 = $267 >>> $314;
       $316 = HEAP8[$45>>0]|0;
       $317 = $316&255;
       $318 = $315 << $317;
       $319 = $312 | $318;
       $320 = HEAP8[$46>>0]|0;
       $321 = $320&255;
       $322 = $271 >>> $321;
       $323 = HEAP8[$47>>0]|0;
       $324 = $323&255;
       $325 = $322 << $324;
       $326 = $319 | $325;
       $327 = $326&65535;
       HEAP16[$$1698>>1] = $327;
       break L15;
       break;
      }
      case 3:  {
       $328 = $259&255;
       $329 = HEAP8[$41>>0]|0;
       $div747 = ($329&255) >>> 3;
       $330 = $div747&255;
       $331 = (($$1698) + ($330)|0);
       HEAP8[$331>>0] = $328;
       $332 = $263&255;
       $333 = HEAP8[$43>>0]|0;
       $div748 = ($333&255) >>> 3;
       $334 = $div748&255;
       $335 = (($$1698) + ($334)|0);
       HEAP8[$335>>0] = $332;
       $336 = $267&255;
       $337 = HEAP8[$45>>0]|0;
       $div749 = ($337&255) >>> 3;
       $338 = $div749&255;
       $339 = (($$1698) + ($338)|0);
       HEAP8[$339>>0] = $336;
       break L15;
       break;
      }
      case 4:  {
       $340 = HEAP8[$40>>0]|0;
       $341 = $340&255;
       $342 = $259 >>> $341;
       $343 = HEAP8[$41>>0]|0;
       $344 = $343&255;
       $345 = $342 << $344;
       $346 = HEAP8[$42>>0]|0;
       $347 = $346&255;
       $348 = $263 >>> $347;
       $349 = HEAP8[$43>>0]|0;
       $350 = $349&255;
       $351 = $348 << $350;
       $352 = $351 | $345;
       $353 = HEAP8[$44>>0]|0;
       $354 = $353&255;
       $355 = $267 >>> $354;
       $356 = HEAP8[$45>>0]|0;
       $357 = $356&255;
       $358 = $355 << $357;
       $359 = $352 | $358;
       $360 = HEAP8[$46>>0]|0;
       $361 = $360&255;
       $362 = $271 >>> $361;
       $363 = HEAP8[$47>>0]|0;
       $364 = $363&255;
       $365 = $362 << $364;
       $366 = $359 | $365;
       HEAP32[$$1698>>2] = $366;
       break L15;
       break;
      }
      default: {
       break L15;
      }
      }
     }
    } while(0);
    $367 = (($$1) + ($17)|0);
    $368 = (($$1698) + ($20)|0);
    $$1723 = $$0722;$$2 = $367;$$2699 = $368;
    label = 21;
    continue;
   }
   else if ((label|0) == 21) {
    label = 0;
    switch ($16<<24>>24) {
    case 1:  {
     $369 = HEAP8[$$2>>0]|0;
     $370 = $369&255;
     $$1703 = $370;
     break;
    }
    case 2:  {
     $371 = HEAP16[$$2>>1]|0;
     $372 = $371&65535;
     $$1703 = $372;
     break;
    }
    case 3:  {
     $373 = HEAP8[$$2>>0]|0;
     $374 = $373&255;
     $375 = ((($$2)) + 1|0);
     $376 = HEAP8[$375>>0]|0;
     $377 = $376&255;
     $378 = $377 << 8;
     $379 = $378 | $374;
     $380 = ((($$2)) + 2|0);
     $381 = HEAP8[$380>>0]|0;
     $382 = $381&255;
     $383 = $382 << 16;
     $384 = $379 | $383;
     $$1703 = $384;
     break;
    }
    case 4:  {
     $385 = HEAP32[$$2>>2]|0;
     $$1703 = $385;
     break;
    }
    default: {
     $$1703 = 0;
    }
    }
    $386 = ($$1703|0)==($14|0);
    $or$cond761 = $30 | $386;
    L36: do {
     if (!($or$cond761)) {
      $387 = HEAP8[$31>>0]|0;
      $388 = $387&255;
      $389 = (79212 + ($388<<2)|0);
      $390 = HEAP32[$389>>2]|0;
      $391 = HEAP32[$32>>2]|0;
      $392 = $391 & $$1703;
      $393 = HEAP8[$33>>0]|0;
      $394 = $393&255;
      $395 = $392 >>> $394;
      $396 = (($390) + ($395)|0);
      $397 = HEAP8[$396>>0]|0;
      $398 = $397&255;
      $399 = HEAP8[$34>>0]|0;
      $400 = $399&255;
      $401 = (79212 + ($400<<2)|0);
      $402 = HEAP32[$401>>2]|0;
      $403 = HEAP32[$35>>2]|0;
      $404 = $403 & $$1703;
      $405 = HEAP8[$36>>0]|0;
      $406 = $405&255;
      $407 = $404 >>> $406;
      $408 = (($402) + ($407)|0);
      $409 = HEAP8[$408>>0]|0;
      $410 = $409&255;
      $411 = HEAP8[$37>>0]|0;
      $412 = $411&255;
      $413 = (79212 + ($412<<2)|0);
      $414 = HEAP32[$413>>2]|0;
      $415 = HEAP32[$38>>2]|0;
      $416 = $415 & $$1703;
      $417 = HEAP8[$39>>0]|0;
      $418 = $417&255;
      $419 = $416 >>> $418;
      $420 = (($414) + ($419)|0);
      $421 = HEAP8[$420>>0]|0;
      $422 = $421&255;
      switch ($19<<24>>24) {
      case 1:  {
       $423 = HEAP8[$$2699>>0]|0;
       $424 = $423&255;
       $425 = HEAP8[$40>>0]|0;
       $426 = $425&255;
       $427 = (79212 + ($426<<2)|0);
       $428 = HEAP32[$427>>2]|0;
       $429 = HEAP32[$48>>2]|0;
       $430 = $429 & $424;
       $431 = HEAP8[$41>>0]|0;
       $432 = $431&255;
       $433 = $430 >>> $432;
       $434 = (($428) + ($433)|0);
       $435 = HEAP8[$434>>0]|0;
       $436 = HEAP8[$42>>0]|0;
       $437 = $436&255;
       $438 = (79212 + ($437<<2)|0);
       $439 = HEAP32[$438>>2]|0;
       $440 = HEAP32[$49>>2]|0;
       $441 = $440 & $424;
       $442 = HEAP8[$43>>0]|0;
       $443 = $442&255;
       $444 = $441 >>> $443;
       $445 = (($439) + ($444)|0);
       $446 = HEAP8[$445>>0]|0;
       $447 = HEAP8[$44>>0]|0;
       $448 = $447&255;
       $449 = (79212 + ($448<<2)|0);
       $450 = HEAP32[$449>>2]|0;
       $451 = HEAP32[$50>>2]|0;
       $452 = $451 & $424;
       $453 = HEAP8[$45>>0]|0;
       $454 = $453&255;
       $455 = $452 >>> $454;
       $456 = (($450) + ($455)|0);
       $457 = HEAP8[$456>>0]|0;
       $458 = HEAP8[$46>>0]|0;
       $459 = $458&255;
       $460 = (79212 + ($459<<2)|0);
       $461 = HEAP32[$460>>2]|0;
       $462 = HEAP32[$51>>2]|0;
       $463 = $462 & $424;
       $464 = HEAP8[$47>>0]|0;
       $465 = $464&255;
       $466 = $463 >>> $465;
       $467 = (($461) + ($466)|0);
       $468 = HEAP8[$467>>0]|0;
       $$1707$shrunk = $435;$$1711$shrunk = $446;$$1715$shrunk = $457;$$1719$shrunk = $468;
       break;
      }
      case 2:  {
       $469 = HEAP16[$$2699>>1]|0;
       $470 = $469&65535;
       $471 = HEAP8[$40>>0]|0;
       $472 = $471&255;
       $473 = (79212 + ($472<<2)|0);
       $474 = HEAP32[$473>>2]|0;
       $475 = HEAP32[$48>>2]|0;
       $476 = $475 & $470;
       $477 = HEAP8[$41>>0]|0;
       $478 = $477&255;
       $479 = $476 >>> $478;
       $480 = (($474) + ($479)|0);
       $481 = HEAP8[$480>>0]|0;
       $482 = HEAP8[$42>>0]|0;
       $483 = $482&255;
       $484 = (79212 + ($483<<2)|0);
       $485 = HEAP32[$484>>2]|0;
       $486 = HEAP32[$49>>2]|0;
       $487 = $486 & $470;
       $488 = HEAP8[$43>>0]|0;
       $489 = $488&255;
       $490 = $487 >>> $489;
       $491 = (($485) + ($490)|0);
       $492 = HEAP8[$491>>0]|0;
       $493 = HEAP8[$44>>0]|0;
       $494 = $493&255;
       $495 = (79212 + ($494<<2)|0);
       $496 = HEAP32[$495>>2]|0;
       $497 = HEAP32[$50>>2]|0;
       $498 = $497 & $470;
       $499 = HEAP8[$45>>0]|0;
       $500 = $499&255;
       $501 = $498 >>> $500;
       $502 = (($496) + ($501)|0);
       $503 = HEAP8[$502>>0]|0;
       $504 = HEAP8[$46>>0]|0;
       $505 = $504&255;
       $506 = (79212 + ($505<<2)|0);
       $507 = HEAP32[$506>>2]|0;
       $508 = HEAP32[$51>>2]|0;
       $509 = $508 & $470;
       $510 = HEAP8[$47>>0]|0;
       $511 = $510&255;
       $512 = $509 >>> $511;
       $513 = (($507) + ($512)|0);
       $514 = HEAP8[$513>>0]|0;
       $$1707$shrunk = $481;$$1711$shrunk = $492;$$1715$shrunk = $503;$$1719$shrunk = $514;
       break;
      }
      case 3:  {
       $515 = HEAP8[$41>>0]|0;
       $div742 = ($515&255) >>> 3;
       $516 = $div742&255;
       $517 = (($$2699) + ($516)|0);
       $518 = HEAP8[$517>>0]|0;
       $519 = HEAP8[$43>>0]|0;
       $div743 = ($519&255) >>> 3;
       $520 = $div743&255;
       $521 = (($$2699) + ($520)|0);
       $522 = HEAP8[$521>>0]|0;
       $523 = HEAP8[$45>>0]|0;
       $div744 = ($523&255) >>> 3;
       $524 = $div744&255;
       $525 = (($$2699) + ($524)|0);
       $526 = HEAP8[$525>>0]|0;
       $$1707$shrunk = $518;$$1711$shrunk = $522;$$1715$shrunk = $526;$$1719$shrunk = -1;
       break;
      }
      case 4:  {
       $527 = HEAP32[$$2699>>2]|0;
       $528 = HEAP8[$40>>0]|0;
       $529 = $528&255;
       $530 = (79212 + ($529<<2)|0);
       $531 = HEAP32[$530>>2]|0;
       $532 = HEAP32[$48>>2]|0;
       $533 = $532 & $527;
       $534 = HEAP8[$41>>0]|0;
       $535 = $534&255;
       $536 = $533 >>> $535;
       $537 = (($531) + ($536)|0);
       $538 = HEAP8[$537>>0]|0;
       $539 = HEAP8[$42>>0]|0;
       $540 = $539&255;
       $541 = (79212 + ($540<<2)|0);
       $542 = HEAP32[$541>>2]|0;
       $543 = HEAP32[$49>>2]|0;
       $544 = $543 & $527;
       $545 = HEAP8[$43>>0]|0;
       $546 = $545&255;
       $547 = $544 >>> $546;
       $548 = (($542) + ($547)|0);
       $549 = HEAP8[$548>>0]|0;
       $550 = HEAP8[$44>>0]|0;
       $551 = $550&255;
       $552 = (79212 + ($551<<2)|0);
       $553 = HEAP32[$552>>2]|0;
       $554 = HEAP32[$50>>2]|0;
       $555 = $554 & $527;
       $556 = HEAP8[$45>>0]|0;
       $557 = $556&255;
       $558 = $555 >>> $557;
       $559 = (($553) + ($558)|0);
       $560 = HEAP8[$559>>0]|0;
       $561 = HEAP8[$46>>0]|0;
       $562 = $561&255;
       $563 = (79212 + ($562<<2)|0);
       $564 = HEAP32[$563>>2]|0;
       $565 = HEAP32[$51>>2]|0;
       $566 = $565 & $527;
       $567 = HEAP8[$47>>0]|0;
       $568 = $567&255;
       $569 = $566 >>> $568;
       $570 = (($564) + ($569)|0);
       $571 = HEAP8[$570>>0]|0;
       $$1707$shrunk = $538;$$1711$shrunk = $549;$$1715$shrunk = $560;$$1719$shrunk = $571;
       break;
      }
      default: {
       $$1707$shrunk = 0;$$1711$shrunk = 0;$$1715$shrunk = 0;$$1719$shrunk = 0;
      }
      }
      $$1707 = $$1707$shrunk&255;
      $$1711 = $$1711$shrunk&255;
      $$1715 = $$1715$shrunk&255;
      $$1719 = $$1719$shrunk&255;
      $572 = (($398) - ($$1707))|0;
      $573 = Math_imul($572, $23)|0;
      $574 = (($573>>>0) / 255)&-1;
      $575 = (($574) + ($$1707))|0;
      $576 = (($410) - ($$1711))|0;
      $577 = Math_imul($576, $23)|0;
      $578 = (($577>>>0) / 255)&-1;
      $579 = (($578) + ($$1711))|0;
      $580 = (($422) - ($$1715))|0;
      $581 = Math_imul($580, $23)|0;
      $582 = (($581>>>0) / 255)&-1;
      $583 = (($582) + ($$1715))|0;
      $584 = (($$1719) + ($23))|0;
      $585 = Math_imul($$1719, $23)|0;
      $586 = (($585>>>0) / 255)&-1;
      $587 = (($584) - ($586))|0;
      switch ($19<<24>>24) {
      case 1:  {
       $588 = HEAP8[$40>>0]|0;
       $589 = $588&255;
       $590 = $575 >>> $589;
       $591 = HEAP8[$41>>0]|0;
       $592 = $591&255;
       $593 = $590 << $592;
       $594 = HEAP8[$42>>0]|0;
       $595 = $594&255;
       $596 = $579 >>> $595;
       $597 = HEAP8[$43>>0]|0;
       $598 = $597&255;
       $599 = $596 << $598;
       $600 = $599 | $593;
       $601 = HEAP8[$44>>0]|0;
       $602 = $601&255;
       $603 = $583 >>> $602;
       $604 = HEAP8[$45>>0]|0;
       $605 = $604&255;
       $606 = $603 << $605;
       $607 = $600 | $606;
       $608 = HEAP8[$46>>0]|0;
       $609 = $608&255;
       $610 = $587 >>> $609;
       $611 = HEAP8[$47>>0]|0;
       $612 = $611&255;
       $613 = $610 << $612;
       $614 = $607 | $613;
       $615 = $614&255;
       HEAP8[$$2699>>0] = $615;
       break L36;
       break;
      }
      case 2:  {
       $616 = HEAP8[$40>>0]|0;
       $617 = $616&255;
       $618 = $575 >>> $617;
       $619 = HEAP8[$41>>0]|0;
       $620 = $619&255;
       $621 = $618 << $620;
       $622 = HEAP8[$42>>0]|0;
       $623 = $622&255;
       $624 = $579 >>> $623;
       $625 = HEAP8[$43>>0]|0;
       $626 = $625&255;
       $627 = $624 << $626;
       $628 = $627 | $621;
       $629 = HEAP8[$44>>0]|0;
       $630 = $629&255;
       $631 = $583 >>> $630;
       $632 = HEAP8[$45>>0]|0;
       $633 = $632&255;
       $634 = $631 << $633;
       $635 = $628 | $634;
       $636 = HEAP8[$46>>0]|0;
       $637 = $636&255;
       $638 = $587 >>> $637;
       $639 = HEAP8[$47>>0]|0;
       $640 = $639&255;
       $641 = $638 << $640;
       $642 = $635 | $641;
       $643 = $642&65535;
       HEAP16[$$2699>>1] = $643;
       break L36;
       break;
      }
      case 3:  {
       $644 = $575&255;
       $645 = HEAP8[$41>>0]|0;
       $div739 = ($645&255) >>> 3;
       $646 = $div739&255;
       $647 = (($$2699) + ($646)|0);
       HEAP8[$647>>0] = $644;
       $648 = $579&255;
       $649 = HEAP8[$43>>0]|0;
       $div740 = ($649&255) >>> 3;
       $650 = $div740&255;
       $651 = (($$2699) + ($650)|0);
       HEAP8[$651>>0] = $648;
       $652 = $583&255;
       $653 = HEAP8[$45>>0]|0;
       $div741 = ($653&255) >>> 3;
       $654 = $div741&255;
       $655 = (($$2699) + ($654)|0);
       HEAP8[$655>>0] = $652;
       break L36;
       break;
      }
      case 4:  {
       $656 = HEAP8[$40>>0]|0;
       $657 = $656&255;
       $658 = $575 >>> $657;
       $659 = HEAP8[$41>>0]|0;
       $660 = $659&255;
       $661 = $658 << $660;
       $662 = HEAP8[$42>>0]|0;
       $663 = $662&255;
       $664 = $579 >>> $663;
       $665 = HEAP8[$43>>0]|0;
       $666 = $665&255;
       $667 = $664 << $666;
       $668 = $667 | $661;
       $669 = HEAP8[$44>>0]|0;
       $670 = $669&255;
       $671 = $583 >>> $670;
       $672 = HEAP8[$45>>0]|0;
       $673 = $672&255;
       $674 = $671 << $673;
       $675 = $668 | $674;
       $676 = HEAP8[$46>>0]|0;
       $677 = $676&255;
       $678 = $587 >>> $677;
       $679 = HEAP8[$47>>0]|0;
       $680 = $679&255;
       $681 = $678 << $680;
       $682 = $675 | $681;
       HEAP32[$$2699>>2] = $682;
       break L36;
       break;
      }
      default: {
       break L36;
      }
      }
     }
    } while(0);
    $683 = (($$2) + ($17)|0);
    $684 = (($$2699) + ($20)|0);
    $$2724 = $$1723;$$3 = $683;$$3700 = $684;
    label = 38;
    continue;
   }
   else if ((label|0) == 38) {
    label = 0;
    switch ($16<<24>>24) {
    case 1:  {
     $685 = HEAP8[$$3>>0]|0;
     $686 = $685&255;
     $$2704 = $686;
     break;
    }
    case 2:  {
     $687 = HEAP16[$$3>>1]|0;
     $688 = $687&65535;
     $$2704 = $688;
     break;
    }
    case 3:  {
     $689 = HEAP8[$$3>>0]|0;
     $690 = $689&255;
     $691 = ((($$3)) + 1|0);
     $692 = HEAP8[$691>>0]|0;
     $693 = $692&255;
     $694 = $693 << 8;
     $695 = $694 | $690;
     $696 = ((($$3)) + 2|0);
     $697 = HEAP8[$696>>0]|0;
     $698 = $697&255;
     $699 = $698 << 16;
     $700 = $695 | $699;
     $$2704 = $700;
     break;
    }
    case 4:  {
     $701 = HEAP32[$$3>>2]|0;
     $$2704 = $701;
     break;
    }
    default: {
     $$2704 = 0;
    }
    }
    $702 = ($$2704|0)==($14|0);
    $or$cond762 = $30 | $702;
    L57: do {
     if (!($or$cond762)) {
      $703 = HEAP8[$31>>0]|0;
      $704 = $703&255;
      $705 = (79212 + ($704<<2)|0);
      $706 = HEAP32[$705>>2]|0;
      $707 = HEAP32[$32>>2]|0;
      $708 = $707 & $$2704;
      $709 = HEAP8[$33>>0]|0;
      $710 = $709&255;
      $711 = $708 >>> $710;
      $712 = (($706) + ($711)|0);
      $713 = HEAP8[$712>>0]|0;
      $714 = $713&255;
      $715 = HEAP8[$34>>0]|0;
      $716 = $715&255;
      $717 = (79212 + ($716<<2)|0);
      $718 = HEAP32[$717>>2]|0;
      $719 = HEAP32[$35>>2]|0;
      $720 = $719 & $$2704;
      $721 = HEAP8[$36>>0]|0;
      $722 = $721&255;
      $723 = $720 >>> $722;
      $724 = (($718) + ($723)|0);
      $725 = HEAP8[$724>>0]|0;
      $726 = $725&255;
      $727 = HEAP8[$37>>0]|0;
      $728 = $727&255;
      $729 = (79212 + ($728<<2)|0);
      $730 = HEAP32[$729>>2]|0;
      $731 = HEAP32[$38>>2]|0;
      $732 = $731 & $$2704;
      $733 = HEAP8[$39>>0]|0;
      $734 = $733&255;
      $735 = $732 >>> $734;
      $736 = (($730) + ($735)|0);
      $737 = HEAP8[$736>>0]|0;
      $738 = $737&255;
      switch ($19<<24>>24) {
      case 1:  {
       $739 = HEAP8[$$3700>>0]|0;
       $740 = $739&255;
       $741 = HEAP8[$40>>0]|0;
       $742 = $741&255;
       $743 = (79212 + ($742<<2)|0);
       $744 = HEAP32[$743>>2]|0;
       $745 = HEAP32[$48>>2]|0;
       $746 = $745 & $740;
       $747 = HEAP8[$41>>0]|0;
       $748 = $747&255;
       $749 = $746 >>> $748;
       $750 = (($744) + ($749)|0);
       $751 = HEAP8[$750>>0]|0;
       $752 = HEAP8[$42>>0]|0;
       $753 = $752&255;
       $754 = (79212 + ($753<<2)|0);
       $755 = HEAP32[$754>>2]|0;
       $756 = HEAP32[$49>>2]|0;
       $757 = $756 & $740;
       $758 = HEAP8[$43>>0]|0;
       $759 = $758&255;
       $760 = $757 >>> $759;
       $761 = (($755) + ($760)|0);
       $762 = HEAP8[$761>>0]|0;
       $763 = HEAP8[$44>>0]|0;
       $764 = $763&255;
       $765 = (79212 + ($764<<2)|0);
       $766 = HEAP32[$765>>2]|0;
       $767 = HEAP32[$50>>2]|0;
       $768 = $767 & $740;
       $769 = HEAP8[$45>>0]|0;
       $770 = $769&255;
       $771 = $768 >>> $770;
       $772 = (($766) + ($771)|0);
       $773 = HEAP8[$772>>0]|0;
       $774 = HEAP8[$46>>0]|0;
       $775 = $774&255;
       $776 = (79212 + ($775<<2)|0);
       $777 = HEAP32[$776>>2]|0;
       $778 = HEAP32[$51>>2]|0;
       $779 = $778 & $740;
       $780 = HEAP8[$47>>0]|0;
       $781 = $780&255;
       $782 = $779 >>> $781;
       $783 = (($777) + ($782)|0);
       $784 = HEAP8[$783>>0]|0;
       $$2708$shrunk = $751;$$2712$shrunk = $762;$$2716$shrunk = $773;$$2720$shrunk = $784;
       break;
      }
      case 2:  {
       $785 = HEAP16[$$3700>>1]|0;
       $786 = $785&65535;
       $787 = HEAP8[$40>>0]|0;
       $788 = $787&255;
       $789 = (79212 + ($788<<2)|0);
       $790 = HEAP32[$789>>2]|0;
       $791 = HEAP32[$48>>2]|0;
       $792 = $791 & $786;
       $793 = HEAP8[$41>>0]|0;
       $794 = $793&255;
       $795 = $792 >>> $794;
       $796 = (($790) + ($795)|0);
       $797 = HEAP8[$796>>0]|0;
       $798 = HEAP8[$42>>0]|0;
       $799 = $798&255;
       $800 = (79212 + ($799<<2)|0);
       $801 = HEAP32[$800>>2]|0;
       $802 = HEAP32[$49>>2]|0;
       $803 = $802 & $786;
       $804 = HEAP8[$43>>0]|0;
       $805 = $804&255;
       $806 = $803 >>> $805;
       $807 = (($801) + ($806)|0);
       $808 = HEAP8[$807>>0]|0;
       $809 = HEAP8[$44>>0]|0;
       $810 = $809&255;
       $811 = (79212 + ($810<<2)|0);
       $812 = HEAP32[$811>>2]|0;
       $813 = HEAP32[$50>>2]|0;
       $814 = $813 & $786;
       $815 = HEAP8[$45>>0]|0;
       $816 = $815&255;
       $817 = $814 >>> $816;
       $818 = (($812) + ($817)|0);
       $819 = HEAP8[$818>>0]|0;
       $820 = HEAP8[$46>>0]|0;
       $821 = $820&255;
       $822 = (79212 + ($821<<2)|0);
       $823 = HEAP32[$822>>2]|0;
       $824 = HEAP32[$51>>2]|0;
       $825 = $824 & $786;
       $826 = HEAP8[$47>>0]|0;
       $827 = $826&255;
       $828 = $825 >>> $827;
       $829 = (($823) + ($828)|0);
       $830 = HEAP8[$829>>0]|0;
       $$2708$shrunk = $797;$$2712$shrunk = $808;$$2716$shrunk = $819;$$2720$shrunk = $830;
       break;
      }
      case 3:  {
       $831 = HEAP8[$41>>0]|0;
       $div734 = ($831&255) >>> 3;
       $832 = $div734&255;
       $833 = (($$3700) + ($832)|0);
       $834 = HEAP8[$833>>0]|0;
       $835 = HEAP8[$43>>0]|0;
       $div735 = ($835&255) >>> 3;
       $836 = $div735&255;
       $837 = (($$3700) + ($836)|0);
       $838 = HEAP8[$837>>0]|0;
       $839 = HEAP8[$45>>0]|0;
       $div736 = ($839&255) >>> 3;
       $840 = $div736&255;
       $841 = (($$3700) + ($840)|0);
       $842 = HEAP8[$841>>0]|0;
       $$2708$shrunk = $834;$$2712$shrunk = $838;$$2716$shrunk = $842;$$2720$shrunk = -1;
       break;
      }
      case 4:  {
       $843 = HEAP32[$$3700>>2]|0;
       $844 = HEAP8[$40>>0]|0;
       $845 = $844&255;
       $846 = (79212 + ($845<<2)|0);
       $847 = HEAP32[$846>>2]|0;
       $848 = HEAP32[$48>>2]|0;
       $849 = $848 & $843;
       $850 = HEAP8[$41>>0]|0;
       $851 = $850&255;
       $852 = $849 >>> $851;
       $853 = (($847) + ($852)|0);
       $854 = HEAP8[$853>>0]|0;
       $855 = HEAP8[$42>>0]|0;
       $856 = $855&255;
       $857 = (79212 + ($856<<2)|0);
       $858 = HEAP32[$857>>2]|0;
       $859 = HEAP32[$49>>2]|0;
       $860 = $859 & $843;
       $861 = HEAP8[$43>>0]|0;
       $862 = $861&255;
       $863 = $860 >>> $862;
       $864 = (($858) + ($863)|0);
       $865 = HEAP8[$864>>0]|0;
       $866 = HEAP8[$44>>0]|0;
       $867 = $866&255;
       $868 = (79212 + ($867<<2)|0);
       $869 = HEAP32[$868>>2]|0;
       $870 = HEAP32[$50>>2]|0;
       $871 = $870 & $843;
       $872 = HEAP8[$45>>0]|0;
       $873 = $872&255;
       $874 = $871 >>> $873;
       $875 = (($869) + ($874)|0);
       $876 = HEAP8[$875>>0]|0;
       $877 = HEAP8[$46>>0]|0;
       $878 = $877&255;
       $879 = (79212 + ($878<<2)|0);
       $880 = HEAP32[$879>>2]|0;
       $881 = HEAP32[$51>>2]|0;
       $882 = $881 & $843;
       $883 = HEAP8[$47>>0]|0;
       $884 = $883&255;
       $885 = $882 >>> $884;
       $886 = (($880) + ($885)|0);
       $887 = HEAP8[$886>>0]|0;
       $$2708$shrunk = $854;$$2712$shrunk = $865;$$2716$shrunk = $876;$$2720$shrunk = $887;
       break;
      }
      default: {
       $$2708$shrunk = 0;$$2712$shrunk = 0;$$2716$shrunk = 0;$$2720$shrunk = 0;
      }
      }
      $$2708 = $$2708$shrunk&255;
      $$2712 = $$2712$shrunk&255;
      $$2716 = $$2716$shrunk&255;
      $$2720 = $$2720$shrunk&255;
      $888 = (($714) - ($$2708))|0;
      $889 = Math_imul($888, $23)|0;
      $890 = (($889>>>0) / 255)&-1;
      $891 = (($890) + ($$2708))|0;
      $892 = (($726) - ($$2712))|0;
      $893 = Math_imul($892, $23)|0;
      $894 = (($893>>>0) / 255)&-1;
      $895 = (($894) + ($$2712))|0;
      $896 = (($738) - ($$2716))|0;
      $897 = Math_imul($896, $23)|0;
      $898 = (($897>>>0) / 255)&-1;
      $899 = (($898) + ($$2716))|0;
      $900 = (($$2720) + ($23))|0;
      $901 = Math_imul($$2720, $23)|0;
      $902 = (($901>>>0) / 255)&-1;
      $903 = (($900) - ($902))|0;
      switch ($19<<24>>24) {
      case 1:  {
       $904 = HEAP8[$40>>0]|0;
       $905 = $904&255;
       $906 = $891 >>> $905;
       $907 = HEAP8[$41>>0]|0;
       $908 = $907&255;
       $909 = $906 << $908;
       $910 = HEAP8[$42>>0]|0;
       $911 = $910&255;
       $912 = $895 >>> $911;
       $913 = HEAP8[$43>>0]|0;
       $914 = $913&255;
       $915 = $912 << $914;
       $916 = $915 | $909;
       $917 = HEAP8[$44>>0]|0;
       $918 = $917&255;
       $919 = $899 >>> $918;
       $920 = HEAP8[$45>>0]|0;
       $921 = $920&255;
       $922 = $919 << $921;
       $923 = $916 | $922;
       $924 = HEAP8[$46>>0]|0;
       $925 = $924&255;
       $926 = $903 >>> $925;
       $927 = HEAP8[$47>>0]|0;
       $928 = $927&255;
       $929 = $926 << $928;
       $930 = $923 | $929;
       $931 = $930&255;
       HEAP8[$$3700>>0] = $931;
       break L57;
       break;
      }
      case 2:  {
       $932 = HEAP8[$40>>0]|0;
       $933 = $932&255;
       $934 = $891 >>> $933;
       $935 = HEAP8[$41>>0]|0;
       $936 = $935&255;
       $937 = $934 << $936;
       $938 = HEAP8[$42>>0]|0;
       $939 = $938&255;
       $940 = $895 >>> $939;
       $941 = HEAP8[$43>>0]|0;
       $942 = $941&255;
       $943 = $940 << $942;
       $944 = $943 | $937;
       $945 = HEAP8[$44>>0]|0;
       $946 = $945&255;
       $947 = $899 >>> $946;
       $948 = HEAP8[$45>>0]|0;
       $949 = $948&255;
       $950 = $947 << $949;
       $951 = $944 | $950;
       $952 = HEAP8[$46>>0]|0;
       $953 = $952&255;
       $954 = $903 >>> $953;
       $955 = HEAP8[$47>>0]|0;
       $956 = $955&255;
       $957 = $954 << $956;
       $958 = $951 | $957;
       $959 = $958&65535;
       HEAP16[$$3700>>1] = $959;
       break L57;
       break;
      }
      case 3:  {
       $960 = $891&255;
       $961 = HEAP8[$41>>0]|0;
       $div = ($961&255) >>> 3;
       $962 = $div&255;
       $963 = (($$3700) + ($962)|0);
       HEAP8[$963>>0] = $960;
       $964 = $895&255;
       $965 = HEAP8[$43>>0]|0;
       $div732 = ($965&255) >>> 3;
       $966 = $div732&255;
       $967 = (($$3700) + ($966)|0);
       HEAP8[$967>>0] = $964;
       $968 = $899&255;
       $969 = HEAP8[$45>>0]|0;
       $div733 = ($969&255) >>> 3;
       $970 = $div733&255;
       $971 = (($$3700) + ($970)|0);
       HEAP8[$971>>0] = $968;
       break L57;
       break;
      }
      case 4:  {
       $972 = HEAP8[$40>>0]|0;
       $973 = $972&255;
       $974 = $891 >>> $973;
       $975 = HEAP8[$41>>0]|0;
       $976 = $975&255;
       $977 = $974 << $976;
       $978 = HEAP8[$42>>0]|0;
       $979 = $978&255;
       $980 = $895 >>> $979;
       $981 = HEAP8[$43>>0]|0;
       $982 = $981&255;
       $983 = $980 << $982;
       $984 = $983 | $977;
       $985 = HEAP8[$44>>0]|0;
       $986 = $985&255;
       $987 = $899 >>> $986;
       $988 = HEAP8[$45>>0]|0;
       $989 = $988&255;
       $990 = $987 << $989;
       $991 = $984 | $990;
       $992 = HEAP8[$46>>0]|0;
       $993 = $992&255;
       $994 = $903 >>> $993;
       $995 = HEAP8[$47>>0]|0;
       $996 = $995&255;
       $997 = $994 << $996;
       $998 = $991 | $997;
       HEAP32[$$3700>>2] = $998;
       break L57;
       break;
      }
      default: {
       break L57;
      }
      }
     }
    } while(0);
    $999 = (($$3) + ($17)|0);
    $1000 = (($$3700) + ($20)|0);
    $$3725 = $$2724;$$4 = $999;$$4701 = $1000;
    label = 55;
    continue;
   }
   else if ((label|0) == 55) {
    label = 0;
    switch ($16<<24>>24) {
    case 1:  {
     $1001 = HEAP8[$$4>>0]|0;
     $1002 = $1001&255;
     $$3705 = $1002;
     break;
    }
    case 2:  {
     $1003 = HEAP16[$$4>>1]|0;
     $1004 = $1003&65535;
     $$3705 = $1004;
     break;
    }
    case 3:  {
     $1005 = HEAP8[$$4>>0]|0;
     $1006 = $1005&255;
     $1007 = ((($$4)) + 1|0);
     $1008 = HEAP8[$1007>>0]|0;
     $1009 = $1008&255;
     $1010 = $1009 << 8;
     $1011 = $1010 | $1006;
     $1012 = ((($$4)) + 2|0);
     $1013 = HEAP8[$1012>>0]|0;
     $1014 = $1013&255;
     $1015 = $1014 << 16;
     $1016 = $1011 | $1015;
     $$3705 = $1016;
     break;
    }
    case 4:  {
     $1017 = HEAP32[$$4>>2]|0;
     $$3705 = $1017;
     break;
    }
    default: {
     $$3705 = 0;
    }
    }
    $1018 = ($$3705|0)==($14|0);
    $or$cond763 = $30 | $1018;
    L78: do {
     if (!($or$cond763)) {
      $1019 = HEAP8[$31>>0]|0;
      $1020 = $1019&255;
      $1021 = (79212 + ($1020<<2)|0);
      $1022 = HEAP32[$1021>>2]|0;
      $1023 = HEAP32[$32>>2]|0;
      $1024 = $1023 & $$3705;
      $1025 = HEAP8[$33>>0]|0;
      $1026 = $1025&255;
      $1027 = $1024 >>> $1026;
      $1028 = (($1022) + ($1027)|0);
      $1029 = HEAP8[$1028>>0]|0;
      $1030 = $1029&255;
      $1031 = HEAP8[$34>>0]|0;
      $1032 = $1031&255;
      $1033 = (79212 + ($1032<<2)|0);
      $1034 = HEAP32[$1033>>2]|0;
      $1035 = HEAP32[$35>>2]|0;
      $1036 = $1035 & $$3705;
      $1037 = HEAP8[$36>>0]|0;
      $1038 = $1037&255;
      $1039 = $1036 >>> $1038;
      $1040 = (($1034) + ($1039)|0);
      $1041 = HEAP8[$1040>>0]|0;
      $1042 = $1041&255;
      $1043 = HEAP8[$37>>0]|0;
      $1044 = $1043&255;
      $1045 = (79212 + ($1044<<2)|0);
      $1046 = HEAP32[$1045>>2]|0;
      $1047 = HEAP32[$38>>2]|0;
      $1048 = $1047 & $$3705;
      $1049 = HEAP8[$39>>0]|0;
      $1050 = $1049&255;
      $1051 = $1048 >>> $1050;
      $1052 = (($1046) + ($1051)|0);
      $1053 = HEAP8[$1052>>0]|0;
      $1054 = $1053&255;
      switch ($19<<24>>24) {
      case 1:  {
       $1055 = HEAP8[$$4701>>0]|0;
       $1056 = $1055&255;
       $1057 = HEAP8[$40>>0]|0;
       $1058 = $1057&255;
       $1059 = (79212 + ($1058<<2)|0);
       $1060 = HEAP32[$1059>>2]|0;
       $1061 = HEAP32[$48>>2]|0;
       $1062 = $1061 & $1056;
       $1063 = HEAP8[$41>>0]|0;
       $1064 = $1063&255;
       $1065 = $1062 >>> $1064;
       $1066 = (($1060) + ($1065)|0);
       $1067 = HEAP8[$1066>>0]|0;
       $1068 = HEAP8[$42>>0]|0;
       $1069 = $1068&255;
       $1070 = (79212 + ($1069<<2)|0);
       $1071 = HEAP32[$1070>>2]|0;
       $1072 = HEAP32[$49>>2]|0;
       $1073 = $1072 & $1056;
       $1074 = HEAP8[$43>>0]|0;
       $1075 = $1074&255;
       $1076 = $1073 >>> $1075;
       $1077 = (($1071) + ($1076)|0);
       $1078 = HEAP8[$1077>>0]|0;
       $1079 = HEAP8[$44>>0]|0;
       $1080 = $1079&255;
       $1081 = (79212 + ($1080<<2)|0);
       $1082 = HEAP32[$1081>>2]|0;
       $1083 = HEAP32[$50>>2]|0;
       $1084 = $1083 & $1056;
       $1085 = HEAP8[$45>>0]|0;
       $1086 = $1085&255;
       $1087 = $1084 >>> $1086;
       $1088 = (($1082) + ($1087)|0);
       $1089 = HEAP8[$1088>>0]|0;
       $1090 = HEAP8[$46>>0]|0;
       $1091 = $1090&255;
       $1092 = (79212 + ($1091<<2)|0);
       $1093 = HEAP32[$1092>>2]|0;
       $1094 = HEAP32[$51>>2]|0;
       $1095 = $1094 & $1056;
       $1096 = HEAP8[$47>>0]|0;
       $1097 = $1096&255;
       $1098 = $1095 >>> $1097;
       $1099 = (($1093) + ($1098)|0);
       $1100 = HEAP8[$1099>>0]|0;
       $$3709$shrunk = $1067;$$3713$shrunk = $1078;$$3717$shrunk = $1089;$$3721$shrunk = $1100;
       break;
      }
      case 2:  {
       $1101 = HEAP16[$$4701>>1]|0;
       $1102 = $1101&65535;
       $1103 = HEAP8[$40>>0]|0;
       $1104 = $1103&255;
       $1105 = (79212 + ($1104<<2)|0);
       $1106 = HEAP32[$1105>>2]|0;
       $1107 = HEAP32[$48>>2]|0;
       $1108 = $1107 & $1102;
       $1109 = HEAP8[$41>>0]|0;
       $1110 = $1109&255;
       $1111 = $1108 >>> $1110;
       $1112 = (($1106) + ($1111)|0);
       $1113 = HEAP8[$1112>>0]|0;
       $1114 = HEAP8[$42>>0]|0;
       $1115 = $1114&255;
       $1116 = (79212 + ($1115<<2)|0);
       $1117 = HEAP32[$1116>>2]|0;
       $1118 = HEAP32[$49>>2]|0;
       $1119 = $1118 & $1102;
       $1120 = HEAP8[$43>>0]|0;
       $1121 = $1120&255;
       $1122 = $1119 >>> $1121;
       $1123 = (($1117) + ($1122)|0);
       $1124 = HEAP8[$1123>>0]|0;
       $1125 = HEAP8[$44>>0]|0;
       $1126 = $1125&255;
       $1127 = (79212 + ($1126<<2)|0);
       $1128 = HEAP32[$1127>>2]|0;
       $1129 = HEAP32[$50>>2]|0;
       $1130 = $1129 & $1102;
       $1131 = HEAP8[$45>>0]|0;
       $1132 = $1131&255;
       $1133 = $1130 >>> $1132;
       $1134 = (($1128) + ($1133)|0);
       $1135 = HEAP8[$1134>>0]|0;
       $1136 = HEAP8[$46>>0]|0;
       $1137 = $1136&255;
       $1138 = (79212 + ($1137<<2)|0);
       $1139 = HEAP32[$1138>>2]|0;
       $1140 = HEAP32[$51>>2]|0;
       $1141 = $1140 & $1102;
       $1142 = HEAP8[$47>>0]|0;
       $1143 = $1142&255;
       $1144 = $1141 >>> $1143;
       $1145 = (($1139) + ($1144)|0);
       $1146 = HEAP8[$1145>>0]|0;
       $$3709$shrunk = $1113;$$3713$shrunk = $1124;$$3717$shrunk = $1135;$$3721$shrunk = $1146;
       break;
      }
      case 3:  {
       $1147 = HEAP8[$41>>0]|0;
       $div758 = ($1147&255) >>> 3;
       $1148 = $div758&255;
       $1149 = (($$4701) + ($1148)|0);
       $1150 = HEAP8[$1149>>0]|0;
       $1151 = HEAP8[$43>>0]|0;
       $div759 = ($1151&255) >>> 3;
       $1152 = $div759&255;
       $1153 = (($$4701) + ($1152)|0);
       $1154 = HEAP8[$1153>>0]|0;
       $1155 = HEAP8[$45>>0]|0;
       $div760 = ($1155&255) >>> 3;
       $1156 = $div760&255;
       $1157 = (($$4701) + ($1156)|0);
       $1158 = HEAP8[$1157>>0]|0;
       $$3709$shrunk = $1150;$$3713$shrunk = $1154;$$3717$shrunk = $1158;$$3721$shrunk = -1;
       break;
      }
      case 4:  {
       $1159 = HEAP32[$$4701>>2]|0;
       $1160 = HEAP8[$40>>0]|0;
       $1161 = $1160&255;
       $1162 = (79212 + ($1161<<2)|0);
       $1163 = HEAP32[$1162>>2]|0;
       $1164 = HEAP32[$48>>2]|0;
       $1165 = $1164 & $1159;
       $1166 = HEAP8[$41>>0]|0;
       $1167 = $1166&255;
       $1168 = $1165 >>> $1167;
       $1169 = (($1163) + ($1168)|0);
       $1170 = HEAP8[$1169>>0]|0;
       $1171 = HEAP8[$42>>0]|0;
       $1172 = $1171&255;
       $1173 = (79212 + ($1172<<2)|0);
       $1174 = HEAP32[$1173>>2]|0;
       $1175 = HEAP32[$49>>2]|0;
       $1176 = $1175 & $1159;
       $1177 = HEAP8[$43>>0]|0;
       $1178 = $1177&255;
       $1179 = $1176 >>> $1178;
       $1180 = (($1174) + ($1179)|0);
       $1181 = HEAP8[$1180>>0]|0;
       $1182 = HEAP8[$44>>0]|0;
       $1183 = $1182&255;
       $1184 = (79212 + ($1183<<2)|0);
       $1185 = HEAP32[$1184>>2]|0;
       $1186 = HEAP32[$50>>2]|0;
       $1187 = $1186 & $1159;
       $1188 = HEAP8[$45>>0]|0;
       $1189 = $1188&255;
       $1190 = $1187 >>> $1189;
       $1191 = (($1185) + ($1190)|0);
       $1192 = HEAP8[$1191>>0]|0;
       $1193 = HEAP8[$46>>0]|0;
       $1194 = $1193&255;
       $1195 = (79212 + ($1194<<2)|0);
       $1196 = HEAP32[$1195>>2]|0;
       $1197 = HEAP32[$51>>2]|0;
       $1198 = $1197 & $1159;
       $1199 = HEAP8[$47>>0]|0;
       $1200 = $1199&255;
       $1201 = $1198 >>> $1200;
       $1202 = (($1196) + ($1201)|0);
       $1203 = HEAP8[$1202>>0]|0;
       $$3709$shrunk = $1170;$$3713$shrunk = $1181;$$3717$shrunk = $1192;$$3721$shrunk = $1203;
       break;
      }
      default: {
       $$3709$shrunk = 0;$$3713$shrunk = 0;$$3717$shrunk = 0;$$3721$shrunk = 0;
      }
      }
      $$3709 = $$3709$shrunk&255;
      $$3713 = $$3713$shrunk&255;
      $$3717 = $$3717$shrunk&255;
      $$3721 = $$3721$shrunk&255;
      $1204 = (($1030) - ($$3709))|0;
      $1205 = Math_imul($1204, $23)|0;
      $1206 = (($1205>>>0) / 255)&-1;
      $1207 = (($1206) + ($$3709))|0;
      $1208 = (($1042) - ($$3713))|0;
      $1209 = Math_imul($1208, $23)|0;
      $1210 = (($1209>>>0) / 255)&-1;
      $1211 = (($1210) + ($$3713))|0;
      $1212 = (($1054) - ($$3717))|0;
      $1213 = Math_imul($1212, $23)|0;
      $1214 = (($1213>>>0) / 255)&-1;
      $1215 = (($1214) + ($$3717))|0;
      $1216 = (($$3721) + ($23))|0;
      $1217 = Math_imul($$3721, $23)|0;
      $1218 = (($1217>>>0) / 255)&-1;
      $1219 = (($1216) - ($1218))|0;
      switch ($19<<24>>24) {
      case 1:  {
       $1220 = HEAP8[$40>>0]|0;
       $1221 = $1220&255;
       $1222 = $1207 >>> $1221;
       $1223 = HEAP8[$41>>0]|0;
       $1224 = $1223&255;
       $1225 = $1222 << $1224;
       $1226 = HEAP8[$42>>0]|0;
       $1227 = $1226&255;
       $1228 = $1211 >>> $1227;
       $1229 = HEAP8[$43>>0]|0;
       $1230 = $1229&255;
       $1231 = $1228 << $1230;
       $1232 = $1231 | $1225;
       $1233 = HEAP8[$44>>0]|0;
       $1234 = $1233&255;
       $1235 = $1215 >>> $1234;
       $1236 = HEAP8[$45>>0]|0;
       $1237 = $1236&255;
       $1238 = $1235 << $1237;
       $1239 = $1232 | $1238;
       $1240 = HEAP8[$46>>0]|0;
       $1241 = $1240&255;
       $1242 = $1219 >>> $1241;
       $1243 = HEAP8[$47>>0]|0;
       $1244 = $1243&255;
       $1245 = $1242 << $1244;
       $1246 = $1239 | $1245;
       $1247 = $1246&255;
       HEAP8[$$4701>>0] = $1247;
       break L78;
       break;
      }
      case 2:  {
       $1248 = HEAP8[$40>>0]|0;
       $1249 = $1248&255;
       $1250 = $1207 >>> $1249;
       $1251 = HEAP8[$41>>0]|0;
       $1252 = $1251&255;
       $1253 = $1250 << $1252;
       $1254 = HEAP8[$42>>0]|0;
       $1255 = $1254&255;
       $1256 = $1211 >>> $1255;
       $1257 = HEAP8[$43>>0]|0;
       $1258 = $1257&255;
       $1259 = $1256 << $1258;
       $1260 = $1259 | $1253;
       $1261 = HEAP8[$44>>0]|0;
       $1262 = $1261&255;
       $1263 = $1215 >>> $1262;
       $1264 = HEAP8[$45>>0]|0;
       $1265 = $1264&255;
       $1266 = $1263 << $1265;
       $1267 = $1260 | $1266;
       $1268 = HEAP8[$46>>0]|0;
       $1269 = $1268&255;
       $1270 = $1219 >>> $1269;
       $1271 = HEAP8[$47>>0]|0;
       $1272 = $1271&255;
       $1273 = $1270 << $1272;
       $1274 = $1267 | $1273;
       $1275 = $1274&65535;
       HEAP16[$$4701>>1] = $1275;
       break L78;
       break;
      }
      case 3:  {
       $1276 = $1207&255;
       $1277 = HEAP8[$41>>0]|0;
       $div755 = ($1277&255) >>> 3;
       $1278 = $div755&255;
       $1279 = (($$4701) + ($1278)|0);
       HEAP8[$1279>>0] = $1276;
       $1280 = $1211&255;
       $1281 = HEAP8[$43>>0]|0;
       $div756 = ($1281&255) >>> 3;
       $1282 = $div756&255;
       $1283 = (($$4701) + ($1282)|0);
       HEAP8[$1283>>0] = $1280;
       $1284 = $1215&255;
       $1285 = HEAP8[$45>>0]|0;
       $div757 = ($1285&255) >>> 3;
       $1286 = $div757&255;
       $1287 = (($$4701) + ($1286)|0);
       HEAP8[$1287>>0] = $1284;
       break L78;
       break;
      }
      case 4:  {
       $1288 = HEAP8[$40>>0]|0;
       $1289 = $1288&255;
       $1290 = $1207 >>> $1289;
       $1291 = HEAP8[$41>>0]|0;
       $1292 = $1291&255;
       $1293 = $1290 << $1292;
       $1294 = HEAP8[$42>>0]|0;
       $1295 = $1294&255;
       $1296 = $1211 >>> $1295;
       $1297 = HEAP8[$43>>0]|0;
       $1298 = $1297&255;
       $1299 = $1296 << $1298;
       $1300 = $1299 | $1293;
       $1301 = HEAP8[$44>>0]|0;
       $1302 = $1301&255;
       $1303 = $1215 >>> $1302;
       $1304 = HEAP8[$45>>0]|0;
       $1305 = $1304&255;
       $1306 = $1303 << $1305;
       $1307 = $1300 | $1306;
       $1308 = HEAP8[$46>>0]|0;
       $1309 = $1308&255;
       $1310 = $1219 >>> $1309;
       $1311 = HEAP8[$47>>0]|0;
       $1312 = $1311&255;
       $1313 = $1310 << $1312;
       $1314 = $1307 | $1313;
       HEAP32[$$4701>>2] = $1314;
       break L78;
       break;
      }
      default: {
       break L78;
      }
      }
     }
    } while(0);
    $1315 = (($$4) + ($17)|0);
    $1316 = (($$4701) + ($20)|0);
    $1317 = (($$3725) + -1)|0;
    $1318 = ($$3725|0)>(1);
    if ($1318) {
     $$0722 = $1317;$$1 = $1315;$$1698 = $1316;
     label = 4;
     continue;
    } else {
     break;
    }
   }
  }
  $1319 = (($1315) + ($6)|0);
  $1320 = (($1316) + ($8)|0);
  $1321 = ($52|0)==(0);
  if ($1321) {
   label = 74;
   break;
  } else {
   $$0696768 = $1319;$$0697767 = $1320;$$in = $52;
  }
 }
 if ((label|0) == 72) {
  // unreachable;
 }
 else if ((label|0) == 74) {
  return;
 }
}
function _BlitNto1PixelAlpha($0) {
 $0 = $0|0;
 var $$0 = 0, $$0422 = 0, $$0422$shrunk = 0, $$0426 = 0, $$0426$shrunk = 0, $$0430 = 0, $$0430$shrunk = 0, $$0434 = 0, $$0434$shrunk = 0, $$0439467 = 0, $$0443466 = 0, $$1 = 0, $$1423 = 0, $$1423$shrunk = 0, $$1427 = 0, $$1427$shrunk = 0, $$1431 = 0, $$1431$shrunk = 0, $$1435 = 0, $$1435$shrunk = 0;
 var $$1440 = 0, $$1444 = 0, $$2 = 0, $$2424 = 0, $$2424$shrunk = 0, $$2428 = 0, $$2428$shrunk = 0, $$2432 = 0, $$2432$shrunk = 0, $$2436 = 0, $$2436$shrunk = 0, $$2441 = 0, $$2445 = 0, $$3 = 0, $$3425 = 0, $$3425$shrunk = 0, $$3429 = 0, $$3429$shrunk = 0, $$3433 = 0, $$3433$shrunk = 0;
 var $$3437 = 0, $$3437$shrunk = 0, $$3442 = 0, $$3446 = 0, $$4 = 0, $$4447 = 0, $$in = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0;
 var $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0;
 var $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0;
 var $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0;
 var $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0;
 var $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0;
 var $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0;
 var $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0;
 var $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0;
 var $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0;
 var $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0;
 var $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0;
 var $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0;
 var $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0;
 var $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0;
 var $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0;
 var $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0;
 var $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0;
 var $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0;
 var $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0;
 var $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0;
 var $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0;
 var $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0;
 var $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0;
 var $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0;
 var $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0;
 var $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0;
 var $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0;
 var $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0;
 var $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0;
 var $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0;
 var $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0;
 var $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0;
 var $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0;
 var $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0;
 var $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $div = 0, $div455 = 0;
 var $div456 = 0, $div457 = 0, $div458 = 0, $div459 = 0, $div460 = 0, $div461 = 0, $div462 = 0, $div463 = 0, $div464 = 0, $div465 = 0, $storemerge = 0, $storemerge450 = 0, $storemerge452 = 0, $storemerge454 = 0, $trunc = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($0)) + 36|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($0)) + 48|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ((($0)) + 40|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ((($12)) + 9|0);
 $14 = HEAP8[$13>>0]|0;
 $15 = $14&255;
 $16 = ($4|0)==(0);
 if ($16) {
  return;
 }
 $17 = ((($0)) + 44|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ((($0)) + 20|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = HEAP32[$0>>2]|0;
 $22 = (($2) + 3)|0;
 $23 = (($22|0) / 4)&-1;
 $trunc = $2&255;
 $24 = ((($18)) + 4|0);
 $25 = ($10|0)==(0|0);
 $26 = ((($12)) + 28|0);
 $27 = ((($12)) + 12|0);
 $28 = ((($12)) + 32|0);
 $29 = ((($12)) + 29|0);
 $30 = ((($12)) + 16|0);
 $31 = ((($12)) + 33|0);
 $32 = ((($12)) + 30|0);
 $33 = ((($12)) + 20|0);
 $34 = ((($12)) + 34|0);
 $35 = ((($12)) + 31|0);
 $36 = ((($12)) + 24|0);
 $37 = ((($12)) + 35|0);
 $$0439467 = $21;$$0443466 = $20;$$in = $4;
 L4: while(1) {
  $38 = (($$in) + -1)|0;
  $trunc$clear = $trunc & 3;
  switch ($trunc$clear<<24>>24) {
  case 0:  {
   $$0 = $23;$$1440 = $$0439467;$$1444 = $$0443466;
   label = 4;
   break;
  }
  case 3:  {
   $$1 = $23;$$2441 = $$0439467;$$2445 = $$0443466;
   label = 13;
   break;
  }
  case 2:  {
   $$2 = $23;$$3442 = $$0439467;$$3446 = $$0443466;
   label = 22;
   break;
  }
  case 1:  {
   $$3 = $23;$$4 = $$0439467;$$4447 = $$0443466;
   label = 31;
   break;
  }
  default: {
   label = 40;
   break L4;
  }
  }
  while(1) {
   if ((label|0) == 4) {
    label = 0;
    switch ($14<<24>>24) {
    case 1:  {
     $39 = HEAP8[$$1440>>0]|0;
     $40 = $39&255;
     $41 = HEAP8[$26>>0]|0;
     $42 = $41&255;
     $43 = (79212 + ($42<<2)|0);
     $44 = HEAP32[$43>>2]|0;
     $45 = HEAP32[$27>>2]|0;
     $46 = $45 & $40;
     $47 = HEAP8[$28>>0]|0;
     $48 = $47&255;
     $49 = $46 >>> $48;
     $50 = (($44) + ($49)|0);
     $51 = HEAP8[$50>>0]|0;
     $52 = HEAP8[$29>>0]|0;
     $53 = $52&255;
     $54 = (79212 + ($53<<2)|0);
     $55 = HEAP32[$54>>2]|0;
     $56 = HEAP32[$30>>2]|0;
     $57 = $56 & $40;
     $58 = HEAP8[$31>>0]|0;
     $59 = $58&255;
     $60 = $57 >>> $59;
     $61 = (($55) + ($60)|0);
     $62 = HEAP8[$61>>0]|0;
     $63 = HEAP8[$32>>0]|0;
     $64 = $63&255;
     $65 = (79212 + ($64<<2)|0);
     $66 = HEAP32[$65>>2]|0;
     $67 = HEAP32[$33>>2]|0;
     $68 = $67 & $40;
     $69 = HEAP8[$34>>0]|0;
     $70 = $69&255;
     $71 = $68 >>> $70;
     $72 = (($66) + ($71)|0);
     $73 = HEAP8[$72>>0]|0;
     $74 = HEAP8[$35>>0]|0;
     $75 = $74&255;
     $76 = (79212 + ($75<<2)|0);
     $77 = HEAP32[$76>>2]|0;
     $78 = HEAP32[$36>>2]|0;
     $79 = $78 & $40;
     $80 = HEAP8[$37>>0]|0;
     $81 = $80&255;
     $82 = $79 >>> $81;
     $83 = (($77) + ($82)|0);
     $84 = HEAP8[$83>>0]|0;
     $$0422$shrunk = $84;$$0426$shrunk = $73;$$0430$shrunk = $62;$$0434$shrunk = $51;
     break;
    }
    case 2:  {
     $85 = HEAP16[$$1440>>1]|0;
     $86 = $85&65535;
     $87 = HEAP8[$26>>0]|0;
     $88 = $87&255;
     $89 = (79212 + ($88<<2)|0);
     $90 = HEAP32[$89>>2]|0;
     $91 = HEAP32[$27>>2]|0;
     $92 = $91 & $86;
     $93 = HEAP8[$28>>0]|0;
     $94 = $93&255;
     $95 = $92 >>> $94;
     $96 = (($90) + ($95)|0);
     $97 = HEAP8[$96>>0]|0;
     $98 = HEAP8[$29>>0]|0;
     $99 = $98&255;
     $100 = (79212 + ($99<<2)|0);
     $101 = HEAP32[$100>>2]|0;
     $102 = HEAP32[$30>>2]|0;
     $103 = $102 & $86;
     $104 = HEAP8[$31>>0]|0;
     $105 = $104&255;
     $106 = $103 >>> $105;
     $107 = (($101) + ($106)|0);
     $108 = HEAP8[$107>>0]|0;
     $109 = HEAP8[$32>>0]|0;
     $110 = $109&255;
     $111 = (79212 + ($110<<2)|0);
     $112 = HEAP32[$111>>2]|0;
     $113 = HEAP32[$33>>2]|0;
     $114 = $113 & $86;
     $115 = HEAP8[$34>>0]|0;
     $116 = $115&255;
     $117 = $114 >>> $116;
     $118 = (($112) + ($117)|0);
     $119 = HEAP8[$118>>0]|0;
     $120 = HEAP8[$35>>0]|0;
     $121 = $120&255;
     $122 = (79212 + ($121<<2)|0);
     $123 = HEAP32[$122>>2]|0;
     $124 = HEAP32[$36>>2]|0;
     $125 = $124 & $86;
     $126 = HEAP8[$37>>0]|0;
     $127 = $126&255;
     $128 = $125 >>> $127;
     $129 = (($123) + ($128)|0);
     $130 = HEAP8[$129>>0]|0;
     $$0422$shrunk = $130;$$0426$shrunk = $119;$$0430$shrunk = $108;$$0434$shrunk = $97;
     break;
    }
    case 3:  {
     $131 = HEAP8[$28>>0]|0;
     $div460 = ($131&255) >>> 3;
     $132 = $div460&255;
     $133 = (($$1440) + ($132)|0);
     $134 = HEAP8[$133>>0]|0;
     $135 = HEAP8[$31>>0]|0;
     $div461 = ($135&255) >>> 3;
     $136 = $div461&255;
     $137 = (($$1440) + ($136)|0);
     $138 = HEAP8[$137>>0]|0;
     $139 = HEAP8[$34>>0]|0;
     $div462 = ($139&255) >>> 3;
     $140 = $div462&255;
     $141 = (($$1440) + ($140)|0);
     $142 = HEAP8[$141>>0]|0;
     $$0422$shrunk = -1;$$0426$shrunk = $142;$$0430$shrunk = $138;$$0434$shrunk = $134;
     break;
    }
    case 4:  {
     $143 = HEAP32[$$1440>>2]|0;
     $144 = HEAP8[$26>>0]|0;
     $145 = $144&255;
     $146 = (79212 + ($145<<2)|0);
     $147 = HEAP32[$146>>2]|0;
     $148 = HEAP32[$27>>2]|0;
     $149 = $148 & $143;
     $150 = HEAP8[$28>>0]|0;
     $151 = $150&255;
     $152 = $149 >>> $151;
     $153 = (($147) + ($152)|0);
     $154 = HEAP8[$153>>0]|0;
     $155 = HEAP8[$29>>0]|0;
     $156 = $155&255;
     $157 = (79212 + ($156<<2)|0);
     $158 = HEAP32[$157>>2]|0;
     $159 = HEAP32[$30>>2]|0;
     $160 = $159 & $143;
     $161 = HEAP8[$31>>0]|0;
     $162 = $161&255;
     $163 = $160 >>> $162;
     $164 = (($158) + ($163)|0);
     $165 = HEAP8[$164>>0]|0;
     $166 = HEAP8[$32>>0]|0;
     $167 = $166&255;
     $168 = (79212 + ($167<<2)|0);
     $169 = HEAP32[$168>>2]|0;
     $170 = HEAP32[$33>>2]|0;
     $171 = $170 & $143;
     $172 = HEAP8[$34>>0]|0;
     $173 = $172&255;
     $174 = $171 >>> $173;
     $175 = (($169) + ($174)|0);
     $176 = HEAP8[$175>>0]|0;
     $177 = HEAP8[$35>>0]|0;
     $178 = $177&255;
     $179 = (79212 + ($178<<2)|0);
     $180 = HEAP32[$179>>2]|0;
     $181 = HEAP32[$36>>2]|0;
     $182 = $181 & $143;
     $183 = HEAP8[$37>>0]|0;
     $184 = $183&255;
     $185 = $182 >>> $184;
     $186 = (($180) + ($185)|0);
     $187 = HEAP8[$186>>0]|0;
     $$0422$shrunk = $187;$$0426$shrunk = $176;$$0430$shrunk = $165;$$0434$shrunk = $154;
     break;
    }
    default: {
     $$0422$shrunk = 0;$$0426$shrunk = 0;$$0430$shrunk = 0;$$0434$shrunk = 0;
    }
    }
    $$0422 = $$0422$shrunk&255;
    $$0426 = $$0426$shrunk&255;
    $$0430 = $$0430$shrunk&255;
    $$0434 = $$0434$shrunk&255;
    $188 = HEAP32[$24>>2]|0;
    $189 = ((($188)) + 4|0);
    $190 = HEAP32[$189>>2]|0;
    $191 = HEAP8[$$1444>>0]|0;
    $192 = $191&255;
    $193 = (($190) + ($192<<2)|0);
    $194 = HEAP8[$193>>0]|0;
    $195 = $194&255;
    $196 = (((($190) + ($192<<2)|0)) + 1|0);
    $197 = HEAP8[$196>>0]|0;
    $198 = $197&255;
    $199 = (((($190) + ($192<<2)|0)) + 2|0);
    $200 = HEAP8[$199>>0]|0;
    $201 = $200&255;
    $202 = (($$0434) - ($195))|0;
    $203 = Math_imul($202, $$0422)|0;
    $204 = (($203>>>0) / 255)&-1;
    $205 = (($204) + ($195))|0;
    $206 = (($$0430) - ($198))|0;
    $207 = Math_imul($206, $$0422)|0;
    $208 = (($207>>>0) / 255)&-1;
    $209 = (($208) + ($198))|0;
    $210 = (($$0426) - ($201))|0;
    $211 = Math_imul($210, $$0422)|0;
    $212 = (($211>>>0) / 255)&-1;
    $213 = (($212) + ($201))|0;
    $214 = $205 & 224;
    $215 = $209 >>> 3;
    $216 = $215 & 28;
    $217 = $213 >>> 6;
    $218 = $217 & 3;
    $219 = $216 | $214;
    $220 = $219 | $218;
    if ($25) {
     $221 = $220&255;
     $storemerge450 = $221;
    } else {
     $222 = (($10) + ($220)|0);
     $223 = HEAP8[$222>>0]|0;
     $storemerge450 = $223;
    }
    HEAP8[$$1444>>0] = $storemerge450;
    $224 = ((($$1444)) + 1|0);
    $225 = (($$1440) + ($15)|0);
    $$1 = $$0;$$2441 = $225;$$2445 = $224;
    label = 13;
    continue;
   }
   else if ((label|0) == 13) {
    label = 0;
    switch ($14<<24>>24) {
    case 1:  {
     $226 = HEAP8[$$2441>>0]|0;
     $227 = $226&255;
     $228 = HEAP8[$26>>0]|0;
     $229 = $228&255;
     $230 = (79212 + ($229<<2)|0);
     $231 = HEAP32[$230>>2]|0;
     $232 = HEAP32[$27>>2]|0;
     $233 = $232 & $227;
     $234 = HEAP8[$28>>0]|0;
     $235 = $234&255;
     $236 = $233 >>> $235;
     $237 = (($231) + ($236)|0);
     $238 = HEAP8[$237>>0]|0;
     $239 = HEAP8[$29>>0]|0;
     $240 = $239&255;
     $241 = (79212 + ($240<<2)|0);
     $242 = HEAP32[$241>>2]|0;
     $243 = HEAP32[$30>>2]|0;
     $244 = $243 & $227;
     $245 = HEAP8[$31>>0]|0;
     $246 = $245&255;
     $247 = $244 >>> $246;
     $248 = (($242) + ($247)|0);
     $249 = HEAP8[$248>>0]|0;
     $250 = HEAP8[$32>>0]|0;
     $251 = $250&255;
     $252 = (79212 + ($251<<2)|0);
     $253 = HEAP32[$252>>2]|0;
     $254 = HEAP32[$33>>2]|0;
     $255 = $254 & $227;
     $256 = HEAP8[$34>>0]|0;
     $257 = $256&255;
     $258 = $255 >>> $257;
     $259 = (($253) + ($258)|0);
     $260 = HEAP8[$259>>0]|0;
     $261 = HEAP8[$35>>0]|0;
     $262 = $261&255;
     $263 = (79212 + ($262<<2)|0);
     $264 = HEAP32[$263>>2]|0;
     $265 = HEAP32[$36>>2]|0;
     $266 = $265 & $227;
     $267 = HEAP8[$37>>0]|0;
     $268 = $267&255;
     $269 = $266 >>> $268;
     $270 = (($264) + ($269)|0);
     $271 = HEAP8[$270>>0]|0;
     $$1423$shrunk = $271;$$1427$shrunk = $260;$$1431$shrunk = $249;$$1435$shrunk = $238;
     break;
    }
    case 2:  {
     $272 = HEAP16[$$2441>>1]|0;
     $273 = $272&65535;
     $274 = HEAP8[$26>>0]|0;
     $275 = $274&255;
     $276 = (79212 + ($275<<2)|0);
     $277 = HEAP32[$276>>2]|0;
     $278 = HEAP32[$27>>2]|0;
     $279 = $278 & $273;
     $280 = HEAP8[$28>>0]|0;
     $281 = $280&255;
     $282 = $279 >>> $281;
     $283 = (($277) + ($282)|0);
     $284 = HEAP8[$283>>0]|0;
     $285 = HEAP8[$29>>0]|0;
     $286 = $285&255;
     $287 = (79212 + ($286<<2)|0);
     $288 = HEAP32[$287>>2]|0;
     $289 = HEAP32[$30>>2]|0;
     $290 = $289 & $273;
     $291 = HEAP8[$31>>0]|0;
     $292 = $291&255;
     $293 = $290 >>> $292;
     $294 = (($288) + ($293)|0);
     $295 = HEAP8[$294>>0]|0;
     $296 = HEAP8[$32>>0]|0;
     $297 = $296&255;
     $298 = (79212 + ($297<<2)|0);
     $299 = HEAP32[$298>>2]|0;
     $300 = HEAP32[$33>>2]|0;
     $301 = $300 & $273;
     $302 = HEAP8[$34>>0]|0;
     $303 = $302&255;
     $304 = $301 >>> $303;
     $305 = (($299) + ($304)|0);
     $306 = HEAP8[$305>>0]|0;
     $307 = HEAP8[$35>>0]|0;
     $308 = $307&255;
     $309 = (79212 + ($308<<2)|0);
     $310 = HEAP32[$309>>2]|0;
     $311 = HEAP32[$36>>2]|0;
     $312 = $311 & $273;
     $313 = HEAP8[$37>>0]|0;
     $314 = $313&255;
     $315 = $312 >>> $314;
     $316 = (($310) + ($315)|0);
     $317 = HEAP8[$316>>0]|0;
     $$1423$shrunk = $317;$$1427$shrunk = $306;$$1431$shrunk = $295;$$1435$shrunk = $284;
     break;
    }
    case 3:  {
     $318 = HEAP8[$28>>0]|0;
     $div457 = ($318&255) >>> 3;
     $319 = $div457&255;
     $320 = (($$2441) + ($319)|0);
     $321 = HEAP8[$320>>0]|0;
     $322 = HEAP8[$31>>0]|0;
     $div458 = ($322&255) >>> 3;
     $323 = $div458&255;
     $324 = (($$2441) + ($323)|0);
     $325 = HEAP8[$324>>0]|0;
     $326 = HEAP8[$34>>0]|0;
     $div459 = ($326&255) >>> 3;
     $327 = $div459&255;
     $328 = (($$2441) + ($327)|0);
     $329 = HEAP8[$328>>0]|0;
     $$1423$shrunk = -1;$$1427$shrunk = $329;$$1431$shrunk = $325;$$1435$shrunk = $321;
     break;
    }
    case 4:  {
     $330 = HEAP32[$$2441>>2]|0;
     $331 = HEAP8[$26>>0]|0;
     $332 = $331&255;
     $333 = (79212 + ($332<<2)|0);
     $334 = HEAP32[$333>>2]|0;
     $335 = HEAP32[$27>>2]|0;
     $336 = $335 & $330;
     $337 = HEAP8[$28>>0]|0;
     $338 = $337&255;
     $339 = $336 >>> $338;
     $340 = (($334) + ($339)|0);
     $341 = HEAP8[$340>>0]|0;
     $342 = HEAP8[$29>>0]|0;
     $343 = $342&255;
     $344 = (79212 + ($343<<2)|0);
     $345 = HEAP32[$344>>2]|0;
     $346 = HEAP32[$30>>2]|0;
     $347 = $346 & $330;
     $348 = HEAP8[$31>>0]|0;
     $349 = $348&255;
     $350 = $347 >>> $349;
     $351 = (($345) + ($350)|0);
     $352 = HEAP8[$351>>0]|0;
     $353 = HEAP8[$32>>0]|0;
     $354 = $353&255;
     $355 = (79212 + ($354<<2)|0);
     $356 = HEAP32[$355>>2]|0;
     $357 = HEAP32[$33>>2]|0;
     $358 = $357 & $330;
     $359 = HEAP8[$34>>0]|0;
     $360 = $359&255;
     $361 = $358 >>> $360;
     $362 = (($356) + ($361)|0);
     $363 = HEAP8[$362>>0]|0;
     $364 = HEAP8[$35>>0]|0;
     $365 = $364&255;
     $366 = (79212 + ($365<<2)|0);
     $367 = HEAP32[$366>>2]|0;
     $368 = HEAP32[$36>>2]|0;
     $369 = $368 & $330;
     $370 = HEAP8[$37>>0]|0;
     $371 = $370&255;
     $372 = $369 >>> $371;
     $373 = (($367) + ($372)|0);
     $374 = HEAP8[$373>>0]|0;
     $$1423$shrunk = $374;$$1427$shrunk = $363;$$1431$shrunk = $352;$$1435$shrunk = $341;
     break;
    }
    default: {
     $$1423$shrunk = 0;$$1427$shrunk = 0;$$1431$shrunk = 0;$$1435$shrunk = 0;
    }
    }
    $$1423 = $$1423$shrunk&255;
    $$1427 = $$1427$shrunk&255;
    $$1431 = $$1431$shrunk&255;
    $$1435 = $$1435$shrunk&255;
    $375 = HEAP32[$24>>2]|0;
    $376 = ((($375)) + 4|0);
    $377 = HEAP32[$376>>2]|0;
    $378 = HEAP8[$$2445>>0]|0;
    $379 = $378&255;
    $380 = (($377) + ($379<<2)|0);
    $381 = HEAP8[$380>>0]|0;
    $382 = $381&255;
    $383 = (((($377) + ($379<<2)|0)) + 1|0);
    $384 = HEAP8[$383>>0]|0;
    $385 = $384&255;
    $386 = (((($377) + ($379<<2)|0)) + 2|0);
    $387 = HEAP8[$386>>0]|0;
    $388 = $387&255;
    $389 = (($$1435) - ($382))|0;
    $390 = Math_imul($389, $$1423)|0;
    $391 = (($390>>>0) / 255)&-1;
    $392 = (($391) + ($382))|0;
    $393 = (($$1431) - ($385))|0;
    $394 = Math_imul($393, $$1423)|0;
    $395 = (($394>>>0) / 255)&-1;
    $396 = (($395) + ($385))|0;
    $397 = (($$1427) - ($388))|0;
    $398 = Math_imul($397, $$1423)|0;
    $399 = (($398>>>0) / 255)&-1;
    $400 = (($399) + ($388))|0;
    $401 = $400 >>> 6;
    $402 = $401 & 3;
    $403 = $392 & 224;
    $404 = $396 >>> 3;
    $405 = $404 & 28;
    $406 = $405 | $403;
    $407 = $406 | $402;
    if ($25) {
     $408 = $407&255;
     $storemerge452 = $408;
    } else {
     $409 = (($10) + ($407)|0);
     $410 = HEAP8[$409>>0]|0;
     $storemerge452 = $410;
    }
    HEAP8[$$2445>>0] = $storemerge452;
    $411 = ((($$2445)) + 1|0);
    $412 = (($$2441) + ($15)|0);
    $$2 = $$1;$$3442 = $412;$$3446 = $411;
    label = 22;
    continue;
   }
   else if ((label|0) == 22) {
    label = 0;
    switch ($14<<24>>24) {
    case 1:  {
     $413 = HEAP8[$$3442>>0]|0;
     $414 = $413&255;
     $415 = HEAP8[$26>>0]|0;
     $416 = $415&255;
     $417 = (79212 + ($416<<2)|0);
     $418 = HEAP32[$417>>2]|0;
     $419 = HEAP32[$27>>2]|0;
     $420 = $419 & $414;
     $421 = HEAP8[$28>>0]|0;
     $422 = $421&255;
     $423 = $420 >>> $422;
     $424 = (($418) + ($423)|0);
     $425 = HEAP8[$424>>0]|0;
     $426 = HEAP8[$29>>0]|0;
     $427 = $426&255;
     $428 = (79212 + ($427<<2)|0);
     $429 = HEAP32[$428>>2]|0;
     $430 = HEAP32[$30>>2]|0;
     $431 = $430 & $414;
     $432 = HEAP8[$31>>0]|0;
     $433 = $432&255;
     $434 = $431 >>> $433;
     $435 = (($429) + ($434)|0);
     $436 = HEAP8[$435>>0]|0;
     $437 = HEAP8[$32>>0]|0;
     $438 = $437&255;
     $439 = (79212 + ($438<<2)|0);
     $440 = HEAP32[$439>>2]|0;
     $441 = HEAP32[$33>>2]|0;
     $442 = $441 & $414;
     $443 = HEAP8[$34>>0]|0;
     $444 = $443&255;
     $445 = $442 >>> $444;
     $446 = (($440) + ($445)|0);
     $447 = HEAP8[$446>>0]|0;
     $448 = HEAP8[$35>>0]|0;
     $449 = $448&255;
     $450 = (79212 + ($449<<2)|0);
     $451 = HEAP32[$450>>2]|0;
     $452 = HEAP32[$36>>2]|0;
     $453 = $452 & $414;
     $454 = HEAP8[$37>>0]|0;
     $455 = $454&255;
     $456 = $453 >>> $455;
     $457 = (($451) + ($456)|0);
     $458 = HEAP8[$457>>0]|0;
     $$2424$shrunk = $458;$$2428$shrunk = $447;$$2432$shrunk = $436;$$2436$shrunk = $425;
     break;
    }
    case 2:  {
     $459 = HEAP16[$$3442>>1]|0;
     $460 = $459&65535;
     $461 = HEAP8[$26>>0]|0;
     $462 = $461&255;
     $463 = (79212 + ($462<<2)|0);
     $464 = HEAP32[$463>>2]|0;
     $465 = HEAP32[$27>>2]|0;
     $466 = $465 & $460;
     $467 = HEAP8[$28>>0]|0;
     $468 = $467&255;
     $469 = $466 >>> $468;
     $470 = (($464) + ($469)|0);
     $471 = HEAP8[$470>>0]|0;
     $472 = HEAP8[$29>>0]|0;
     $473 = $472&255;
     $474 = (79212 + ($473<<2)|0);
     $475 = HEAP32[$474>>2]|0;
     $476 = HEAP32[$30>>2]|0;
     $477 = $476 & $460;
     $478 = HEAP8[$31>>0]|0;
     $479 = $478&255;
     $480 = $477 >>> $479;
     $481 = (($475) + ($480)|0);
     $482 = HEAP8[$481>>0]|0;
     $483 = HEAP8[$32>>0]|0;
     $484 = $483&255;
     $485 = (79212 + ($484<<2)|0);
     $486 = HEAP32[$485>>2]|0;
     $487 = HEAP32[$33>>2]|0;
     $488 = $487 & $460;
     $489 = HEAP8[$34>>0]|0;
     $490 = $489&255;
     $491 = $488 >>> $490;
     $492 = (($486) + ($491)|0);
     $493 = HEAP8[$492>>0]|0;
     $494 = HEAP8[$35>>0]|0;
     $495 = $494&255;
     $496 = (79212 + ($495<<2)|0);
     $497 = HEAP32[$496>>2]|0;
     $498 = HEAP32[$36>>2]|0;
     $499 = $498 & $460;
     $500 = HEAP8[$37>>0]|0;
     $501 = $500&255;
     $502 = $499 >>> $501;
     $503 = (($497) + ($502)|0);
     $504 = HEAP8[$503>>0]|0;
     $$2424$shrunk = $504;$$2428$shrunk = $493;$$2432$shrunk = $482;$$2436$shrunk = $471;
     break;
    }
    case 3:  {
     $505 = HEAP8[$28>>0]|0;
     $div = ($505&255) >>> 3;
     $506 = $div&255;
     $507 = (($$3442) + ($506)|0);
     $508 = HEAP8[$507>>0]|0;
     $509 = HEAP8[$31>>0]|0;
     $div455 = ($509&255) >>> 3;
     $510 = $div455&255;
     $511 = (($$3442) + ($510)|0);
     $512 = HEAP8[$511>>0]|0;
     $513 = HEAP8[$34>>0]|0;
     $div456 = ($513&255) >>> 3;
     $514 = $div456&255;
     $515 = (($$3442) + ($514)|0);
     $516 = HEAP8[$515>>0]|0;
     $$2424$shrunk = -1;$$2428$shrunk = $516;$$2432$shrunk = $512;$$2436$shrunk = $508;
     break;
    }
    case 4:  {
     $517 = HEAP32[$$3442>>2]|0;
     $518 = HEAP8[$26>>0]|0;
     $519 = $518&255;
     $520 = (79212 + ($519<<2)|0);
     $521 = HEAP32[$520>>2]|0;
     $522 = HEAP32[$27>>2]|0;
     $523 = $522 & $517;
     $524 = HEAP8[$28>>0]|0;
     $525 = $524&255;
     $526 = $523 >>> $525;
     $527 = (($521) + ($526)|0);
     $528 = HEAP8[$527>>0]|0;
     $529 = HEAP8[$29>>0]|0;
     $530 = $529&255;
     $531 = (79212 + ($530<<2)|0);
     $532 = HEAP32[$531>>2]|0;
     $533 = HEAP32[$30>>2]|0;
     $534 = $533 & $517;
     $535 = HEAP8[$31>>0]|0;
     $536 = $535&255;
     $537 = $534 >>> $536;
     $538 = (($532) + ($537)|0);
     $539 = HEAP8[$538>>0]|0;
     $540 = HEAP8[$32>>0]|0;
     $541 = $540&255;
     $542 = (79212 + ($541<<2)|0);
     $543 = HEAP32[$542>>2]|0;
     $544 = HEAP32[$33>>2]|0;
     $545 = $544 & $517;
     $546 = HEAP8[$34>>0]|0;
     $547 = $546&255;
     $548 = $545 >>> $547;
     $549 = (($543) + ($548)|0);
     $550 = HEAP8[$549>>0]|0;
     $551 = HEAP8[$35>>0]|0;
     $552 = $551&255;
     $553 = (79212 + ($552<<2)|0);
     $554 = HEAP32[$553>>2]|0;
     $555 = HEAP32[$36>>2]|0;
     $556 = $555 & $517;
     $557 = HEAP8[$37>>0]|0;
     $558 = $557&255;
     $559 = $556 >>> $558;
     $560 = (($554) + ($559)|0);
     $561 = HEAP8[$560>>0]|0;
     $$2424$shrunk = $561;$$2428$shrunk = $550;$$2432$shrunk = $539;$$2436$shrunk = $528;
     break;
    }
    default: {
     $$2424$shrunk = 0;$$2428$shrunk = 0;$$2432$shrunk = 0;$$2436$shrunk = 0;
    }
    }
    $$2424 = $$2424$shrunk&255;
    $$2428 = $$2428$shrunk&255;
    $$2432 = $$2432$shrunk&255;
    $$2436 = $$2436$shrunk&255;
    $562 = HEAP32[$24>>2]|0;
    $563 = ((($562)) + 4|0);
    $564 = HEAP32[$563>>2]|0;
    $565 = HEAP8[$$3446>>0]|0;
    $566 = $565&255;
    $567 = (($564) + ($566<<2)|0);
    $568 = HEAP8[$567>>0]|0;
    $569 = $568&255;
    $570 = (((($564) + ($566<<2)|0)) + 1|0);
    $571 = HEAP8[$570>>0]|0;
    $572 = $571&255;
    $573 = (((($564) + ($566<<2)|0)) + 2|0);
    $574 = HEAP8[$573>>0]|0;
    $575 = $574&255;
    $576 = (($$2436) - ($569))|0;
    $577 = Math_imul($576, $$2424)|0;
    $578 = (($577>>>0) / 255)&-1;
    $579 = (($578) + ($569))|0;
    $580 = (($$2432) - ($572))|0;
    $581 = Math_imul($580, $$2424)|0;
    $582 = (($581>>>0) / 255)&-1;
    $583 = (($582) + ($572))|0;
    $584 = (($$2428) - ($575))|0;
    $585 = Math_imul($584, $$2424)|0;
    $586 = (($585>>>0) / 255)&-1;
    $587 = (($586) + ($575))|0;
    $588 = $587 >>> 6;
    $589 = $588 & 3;
    $590 = $579 & 224;
    $591 = $583 >>> 3;
    $592 = $591 & 28;
    $593 = $592 | $590;
    $594 = $593 | $589;
    if ($25) {
     $595 = $594&255;
     $storemerge454 = $595;
    } else {
     $596 = (($10) + ($594)|0);
     $597 = HEAP8[$596>>0]|0;
     $storemerge454 = $597;
    }
    HEAP8[$$3446>>0] = $storemerge454;
    $598 = ((($$3446)) + 1|0);
    $599 = (($$3442) + ($15)|0);
    $$3 = $$2;$$4 = $599;$$4447 = $598;
    label = 31;
    continue;
   }
   else if ((label|0) == 31) {
    label = 0;
    switch ($14<<24>>24) {
    case 1:  {
     $600 = HEAP8[$$4>>0]|0;
     $601 = $600&255;
     $602 = HEAP8[$26>>0]|0;
     $603 = $602&255;
     $604 = (79212 + ($603<<2)|0);
     $605 = HEAP32[$604>>2]|0;
     $606 = HEAP32[$27>>2]|0;
     $607 = $606 & $601;
     $608 = HEAP8[$28>>0]|0;
     $609 = $608&255;
     $610 = $607 >>> $609;
     $611 = (($605) + ($610)|0);
     $612 = HEAP8[$611>>0]|0;
     $613 = HEAP8[$29>>0]|0;
     $614 = $613&255;
     $615 = (79212 + ($614<<2)|0);
     $616 = HEAP32[$615>>2]|0;
     $617 = HEAP32[$30>>2]|0;
     $618 = $617 & $601;
     $619 = HEAP8[$31>>0]|0;
     $620 = $619&255;
     $621 = $618 >>> $620;
     $622 = (($616) + ($621)|0);
     $623 = HEAP8[$622>>0]|0;
     $624 = HEAP8[$32>>0]|0;
     $625 = $624&255;
     $626 = (79212 + ($625<<2)|0);
     $627 = HEAP32[$626>>2]|0;
     $628 = HEAP32[$33>>2]|0;
     $629 = $628 & $601;
     $630 = HEAP8[$34>>0]|0;
     $631 = $630&255;
     $632 = $629 >>> $631;
     $633 = (($627) + ($632)|0);
     $634 = HEAP8[$633>>0]|0;
     $635 = HEAP8[$35>>0]|0;
     $636 = $635&255;
     $637 = (79212 + ($636<<2)|0);
     $638 = HEAP32[$637>>2]|0;
     $639 = HEAP32[$36>>2]|0;
     $640 = $639 & $601;
     $641 = HEAP8[$37>>0]|0;
     $642 = $641&255;
     $643 = $640 >>> $642;
     $644 = (($638) + ($643)|0);
     $645 = HEAP8[$644>>0]|0;
     $$3425$shrunk = $645;$$3429$shrunk = $634;$$3433$shrunk = $623;$$3437$shrunk = $612;
     break;
    }
    case 2:  {
     $646 = HEAP16[$$4>>1]|0;
     $647 = $646&65535;
     $648 = HEAP8[$26>>0]|0;
     $649 = $648&255;
     $650 = (79212 + ($649<<2)|0);
     $651 = HEAP32[$650>>2]|0;
     $652 = HEAP32[$27>>2]|0;
     $653 = $652 & $647;
     $654 = HEAP8[$28>>0]|0;
     $655 = $654&255;
     $656 = $653 >>> $655;
     $657 = (($651) + ($656)|0);
     $658 = HEAP8[$657>>0]|0;
     $659 = HEAP8[$29>>0]|0;
     $660 = $659&255;
     $661 = (79212 + ($660<<2)|0);
     $662 = HEAP32[$661>>2]|0;
     $663 = HEAP32[$30>>2]|0;
     $664 = $663 & $647;
     $665 = HEAP8[$31>>0]|0;
     $666 = $665&255;
     $667 = $664 >>> $666;
     $668 = (($662) + ($667)|0);
     $669 = HEAP8[$668>>0]|0;
     $670 = HEAP8[$32>>0]|0;
     $671 = $670&255;
     $672 = (79212 + ($671<<2)|0);
     $673 = HEAP32[$672>>2]|0;
     $674 = HEAP32[$33>>2]|0;
     $675 = $674 & $647;
     $676 = HEAP8[$34>>0]|0;
     $677 = $676&255;
     $678 = $675 >>> $677;
     $679 = (($673) + ($678)|0);
     $680 = HEAP8[$679>>0]|0;
     $681 = HEAP8[$35>>0]|0;
     $682 = $681&255;
     $683 = (79212 + ($682<<2)|0);
     $684 = HEAP32[$683>>2]|0;
     $685 = HEAP32[$36>>2]|0;
     $686 = $685 & $647;
     $687 = HEAP8[$37>>0]|0;
     $688 = $687&255;
     $689 = $686 >>> $688;
     $690 = (($684) + ($689)|0);
     $691 = HEAP8[$690>>0]|0;
     $$3425$shrunk = $691;$$3429$shrunk = $680;$$3433$shrunk = $669;$$3437$shrunk = $658;
     break;
    }
    case 3:  {
     $692 = HEAP8[$28>>0]|0;
     $div463 = ($692&255) >>> 3;
     $693 = $div463&255;
     $694 = (($$4) + ($693)|0);
     $695 = HEAP8[$694>>0]|0;
     $696 = HEAP8[$31>>0]|0;
     $div464 = ($696&255) >>> 3;
     $697 = $div464&255;
     $698 = (($$4) + ($697)|0);
     $699 = HEAP8[$698>>0]|0;
     $700 = HEAP8[$34>>0]|0;
     $div465 = ($700&255) >>> 3;
     $701 = $div465&255;
     $702 = (($$4) + ($701)|0);
     $703 = HEAP8[$702>>0]|0;
     $$3425$shrunk = -1;$$3429$shrunk = $703;$$3433$shrunk = $699;$$3437$shrunk = $695;
     break;
    }
    case 4:  {
     $704 = HEAP32[$$4>>2]|0;
     $705 = HEAP8[$26>>0]|0;
     $706 = $705&255;
     $707 = (79212 + ($706<<2)|0);
     $708 = HEAP32[$707>>2]|0;
     $709 = HEAP32[$27>>2]|0;
     $710 = $709 & $704;
     $711 = HEAP8[$28>>0]|0;
     $712 = $711&255;
     $713 = $710 >>> $712;
     $714 = (($708) + ($713)|0);
     $715 = HEAP8[$714>>0]|0;
     $716 = HEAP8[$29>>0]|0;
     $717 = $716&255;
     $718 = (79212 + ($717<<2)|0);
     $719 = HEAP32[$718>>2]|0;
     $720 = HEAP32[$30>>2]|0;
     $721 = $720 & $704;
     $722 = HEAP8[$31>>0]|0;
     $723 = $722&255;
     $724 = $721 >>> $723;
     $725 = (($719) + ($724)|0);
     $726 = HEAP8[$725>>0]|0;
     $727 = HEAP8[$32>>0]|0;
     $728 = $727&255;
     $729 = (79212 + ($728<<2)|0);
     $730 = HEAP32[$729>>2]|0;
     $731 = HEAP32[$33>>2]|0;
     $732 = $731 & $704;
     $733 = HEAP8[$34>>0]|0;
     $734 = $733&255;
     $735 = $732 >>> $734;
     $736 = (($730) + ($735)|0);
     $737 = HEAP8[$736>>0]|0;
     $738 = HEAP8[$35>>0]|0;
     $739 = $738&255;
     $740 = (79212 + ($739<<2)|0);
     $741 = HEAP32[$740>>2]|0;
     $742 = HEAP32[$36>>2]|0;
     $743 = $742 & $704;
     $744 = HEAP8[$37>>0]|0;
     $745 = $744&255;
     $746 = $743 >>> $745;
     $747 = (($741) + ($746)|0);
     $748 = HEAP8[$747>>0]|0;
     $$3425$shrunk = $748;$$3429$shrunk = $737;$$3433$shrunk = $726;$$3437$shrunk = $715;
     break;
    }
    default: {
     $$3425$shrunk = 0;$$3429$shrunk = 0;$$3433$shrunk = 0;$$3437$shrunk = 0;
    }
    }
    $$3425 = $$3425$shrunk&255;
    $$3429 = $$3429$shrunk&255;
    $$3433 = $$3433$shrunk&255;
    $$3437 = $$3437$shrunk&255;
    $749 = HEAP32[$24>>2]|0;
    $750 = ((($749)) + 4|0);
    $751 = HEAP32[$750>>2]|0;
    $752 = HEAP8[$$4447>>0]|0;
    $753 = $752&255;
    $754 = (($751) + ($753<<2)|0);
    $755 = HEAP8[$754>>0]|0;
    $756 = $755&255;
    $757 = (((($751) + ($753<<2)|0)) + 1|0);
    $758 = HEAP8[$757>>0]|0;
    $759 = $758&255;
    $760 = (((($751) + ($753<<2)|0)) + 2|0);
    $761 = HEAP8[$760>>0]|0;
    $762 = $761&255;
    $763 = (($$3437) - ($756))|0;
    $764 = Math_imul($763, $$3425)|0;
    $765 = (($764>>>0) / 255)&-1;
    $766 = (($765) + ($756))|0;
    $767 = (($$3433) - ($759))|0;
    $768 = Math_imul($767, $$3425)|0;
    $769 = (($768>>>0) / 255)&-1;
    $770 = (($769) + ($759))|0;
    $771 = (($$3429) - ($762))|0;
    $772 = Math_imul($771, $$3425)|0;
    $773 = (($772>>>0) / 255)&-1;
    $774 = (($773) + ($762))|0;
    $775 = $774 >>> 6;
    $776 = $775 & 3;
    $777 = $766 & 224;
    $778 = $770 >>> 3;
    $779 = $778 & 28;
    $780 = $779 | $777;
    $781 = $780 | $776;
    if ($25) {
     $782 = $781&255;
     $storemerge = $782;
    } else {
     $783 = (($10) + ($781)|0);
     $784 = HEAP8[$783>>0]|0;
     $storemerge = $784;
    }
    HEAP8[$$4447>>0] = $storemerge;
    $785 = ((($$4447)) + 1|0);
    $786 = (($$4) + ($15)|0);
    $787 = (($$3) + -1)|0;
    $788 = ($$3|0)>(1);
    if ($788) {
     $$0 = $787;$$1440 = $786;$$1444 = $785;
     label = 4;
     continue;
    } else {
     break;
    }
   }
  }
  $789 = (($786) + ($6)|0);
  $790 = (($785) + ($8)|0);
  $791 = ($38|0)==(0);
  if ($791) {
   label = 42;
   break;
  } else {
   $$0439467 = $789;$$0443466 = $790;$$in = $38;
  }
 }
 if ((label|0) == 40) {
  // unreachable;
 }
 else if ((label|0) == 42) {
  return;
 }
}
function _BlitRGBtoRGBPixelAlpha($0) {
 $0 = $0|0;
 var $$0190211 = 0, $$0191210 = 0, $$0196 = 0, $$1 = 0, $$1192 = 0, $$1197 = 0, $$2 = 0, $$2193 = 0, $$2198 = 0, $$3 = 0, $$3194 = 0, $$3199 = 0, $$4 = 0, $$4195 = 0, $$in = 0, $$sink = 0, $$sink201 = 0, $$sink203 = 0, $$sink205 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $trunc = 0, $trunc$clear = 0, $trunc206 = 0, $trunc207 = 0, $trunc208 = 0, $trunc209 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $6 >> 2;
 $8 = ((($0)) + 36|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $9 >> 2;
 $11 = ($4|0)==(0);
 if ($11) {
  return;
 }
 $12 = ((($0)) + 20|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = HEAP32[$0>>2]|0;
 $15 = (($2) + 3)|0;
 $16 = (($15|0) / 4)&-1;
 $trunc = $2&255;
 $$0190211 = $14;$$0191210 = $13;$$in = $4;
 L4: while(1) {
  $17 = (($$in) + -1)|0;
  $trunc$clear = $trunc & 3;
  switch ($trunc$clear<<24>>24) {
  case 0:  {
   $$0196 = $16;$$1 = $$0190211;$$1192 = $$0191210;
   label = 4;
   break;
  }
  case 3:  {
   $$1197 = $16;$$2 = $$0190211;$$2193 = $$0191210;
   label = 8;
   break;
  }
  case 2:  {
   $$2198 = $16;$$3 = $$0190211;$$3194 = $$0191210;
   label = 12;
   break;
  }
  case 1:  {
   $$3199 = $16;$$4 = $$0190211;$$4195 = $$0191210;
   label = 16;
   break;
  }
  default: {
   label = 20;
   break L4;
  }
  }
  while(1) {
   if ((label|0) == 4) {
    label = 0;
    $18 = HEAP32[$$1>>2]|0;
    $19 = $18 >>> 24;
    $trunc207 = $19&255;
    switch ($trunc207<<24>>24) {
    case 0:  {
     break;
    }
    case -1:  {
     $$sink = $18;
     label = 6;
     break;
    }
    default: {
     $20 = HEAP32[$$1192>>2]|0;
     $21 = $20 >>> 24;
     $22 = $18 & 16711935;
     $23 = $20 & 16711935;
     $24 = (($22) - ($23))|0;
     $25 = Math_imul($24, $19)|0;
     $26 = $25 >>> 8;
     $27 = (($26) + ($23))|0;
     $28 = $27 & 16711935;
     $29 = $18 & 65280;
     $30 = $20 & 65280;
     $31 = (($29) - ($30))|0;
     $32 = Math_imul($31, $19)|0;
     $33 = $32 >>> 8;
     $34 = (($33) + ($30))|0;
     $35 = $34 & 65280;
     $36 = $19 ^ 255;
     $37 = Math_imul($21, $36)|0;
     $38 = $37 >>> 8;
     $39 = (($38) + ($19))|0;
     $40 = $39 << 24;
     $41 = $35 | $40;
     $42 = $41 | $28;
     $$sink = $42;
     label = 6;
    }
    }
    if ((label|0) == 6) {
     label = 0;
     HEAP32[$$1192>>2] = $$sink;
    }
    $43 = ((($$1)) + 4|0);
    $44 = ((($$1192)) + 4|0);
    $$1197 = $$0196;$$2 = $43;$$2193 = $44;
    label = 8;
    continue;
   }
   else if ((label|0) == 8) {
    label = 0;
    $45 = HEAP32[$$2>>2]|0;
    $46 = $45 >>> 24;
    $trunc208 = $46&255;
    switch ($trunc208<<24>>24) {
    case 0:  {
     break;
    }
    case -1:  {
     $$sink201 = $45;
     label = 10;
     break;
    }
    default: {
     $47 = HEAP32[$$2193>>2]|0;
     $48 = $47 >>> 24;
     $49 = $45 & 16711935;
     $50 = $47 & 16711935;
     $51 = (($49) - ($50))|0;
     $52 = Math_imul($51, $46)|0;
     $53 = $52 >>> 8;
     $54 = (($53) + ($50))|0;
     $55 = $54 & 16711935;
     $56 = $45 & 65280;
     $57 = $47 & 65280;
     $58 = (($56) - ($57))|0;
     $59 = Math_imul($58, $46)|0;
     $60 = $59 >>> 8;
     $61 = (($60) + ($57))|0;
     $62 = $61 & 65280;
     $63 = $46 ^ 255;
     $64 = Math_imul($48, $63)|0;
     $65 = $64 >>> 8;
     $66 = (($65) + ($46))|0;
     $67 = $66 << 24;
     $68 = $62 | $67;
     $69 = $68 | $55;
     $$sink201 = $69;
     label = 10;
    }
    }
    if ((label|0) == 10) {
     label = 0;
     HEAP32[$$2193>>2] = $$sink201;
    }
    $70 = ((($$2)) + 4|0);
    $71 = ((($$2193)) + 4|0);
    $$2198 = $$1197;$$3 = $70;$$3194 = $71;
    label = 12;
    continue;
   }
   else if ((label|0) == 12) {
    label = 0;
    $72 = HEAP32[$$3>>2]|0;
    $73 = $72 >>> 24;
    $trunc209 = $73&255;
    switch ($trunc209<<24>>24) {
    case 0:  {
     break;
    }
    case -1:  {
     $$sink203 = $72;
     label = 14;
     break;
    }
    default: {
     $74 = HEAP32[$$3194>>2]|0;
     $75 = $74 >>> 24;
     $76 = $72 & 16711935;
     $77 = $74 & 16711935;
     $78 = (($76) - ($77))|0;
     $79 = Math_imul($78, $73)|0;
     $80 = $79 >>> 8;
     $81 = (($80) + ($77))|0;
     $82 = $81 & 16711935;
     $83 = $72 & 65280;
     $84 = $74 & 65280;
     $85 = (($83) - ($84))|0;
     $86 = Math_imul($85, $73)|0;
     $87 = $86 >>> 8;
     $88 = (($87) + ($84))|0;
     $89 = $88 & 65280;
     $90 = $73 ^ 255;
     $91 = Math_imul($75, $90)|0;
     $92 = $91 >>> 8;
     $93 = (($92) + ($73))|0;
     $94 = $93 << 24;
     $95 = $89 | $94;
     $96 = $95 | $82;
     $$sink203 = $96;
     label = 14;
    }
    }
    if ((label|0) == 14) {
     label = 0;
     HEAP32[$$3194>>2] = $$sink203;
    }
    $97 = ((($$3)) + 4|0);
    $98 = ((($$3194)) + 4|0);
    $$3199 = $$2198;$$4 = $97;$$4195 = $98;
    label = 16;
    continue;
   }
   else if ((label|0) == 16) {
    label = 0;
    $99 = HEAP32[$$4>>2]|0;
    $100 = $99 >>> 24;
    $trunc206 = $100&255;
    switch ($trunc206<<24>>24) {
    case 0:  {
     break;
    }
    case -1:  {
     $$sink205 = $99;
     label = 18;
     break;
    }
    default: {
     $101 = HEAP32[$$4195>>2]|0;
     $102 = $101 >>> 24;
     $103 = $99 & 16711935;
     $104 = $101 & 16711935;
     $105 = (($103) - ($104))|0;
     $106 = Math_imul($105, $100)|0;
     $107 = $106 >>> 8;
     $108 = (($107) + ($104))|0;
     $109 = $108 & 16711935;
     $110 = $99 & 65280;
     $111 = $101 & 65280;
     $112 = (($110) - ($111))|0;
     $113 = Math_imul($112, $100)|0;
     $114 = $113 >>> 8;
     $115 = (($114) + ($111))|0;
     $116 = $115 & 65280;
     $117 = $100 ^ 255;
     $118 = Math_imul($102, $117)|0;
     $119 = $118 >>> 8;
     $120 = (($119) + ($100))|0;
     $121 = $120 << 24;
     $122 = $116 | $121;
     $123 = $122 | $109;
     $$sink205 = $123;
     label = 18;
    }
    }
    if ((label|0) == 18) {
     label = 0;
     HEAP32[$$4195>>2] = $$sink205;
    }
    $124 = ((($$4)) + 4|0);
    $125 = ((($$4195)) + 4|0);
    $126 = (($$3199) + -1)|0;
    $127 = ($$3199|0)>(1);
    if ($127) {
     $$0196 = $126;$$1 = $124;$$1192 = $125;
     label = 4;
     continue;
    } else {
     break;
    }
   }
  }
  $128 = (($124) + ($7<<2)|0);
  $129 = (($125) + ($10<<2)|0);
  $130 = ($17|0)==(0);
  if ($130) {
   label = 22;
   break;
  } else {
   $$0190211 = $128;$$0191210 = $129;$$in = $17;
  }
 }
 if ((label|0) == 20) {
  // unreachable;
 }
 else if ((label|0) == 22) {
  return;
 }
}
function _BlitNto1SurfaceAlpha($0) {
 $0 = $0|0;
 var $$0 = 0, $$0376 = 0, $$0376$shrunk = 0, $$0380 = 0, $$0380$shrunk = 0, $$0380$shrunk$ph = 0, $$0380$shrunk$ph$in = 0, $$0384 = 0, $$0384$shrunk = 0, $$0384$shrunk$ph = 0, $$0384$shrunk$ph$in = 0, $$0388422 = 0, $$0392421 = 0, $$1 = 0, $$1377 = 0, $$1377$shrunk = 0, $$1381 = 0, $$1381$shrunk = 0, $$1381$shrunk$ph = 0, $$1381$shrunk$ph$in = 0;
 var $$1385 = 0, $$1385$shrunk = 0, $$1385$shrunk$ph = 0, $$1385$shrunk$ph$in = 0, $$1389 = 0, $$1393 = 0, $$2 = 0, $$2378 = 0, $$2378$shrunk = 0, $$2382 = 0, $$2382$shrunk = 0, $$2382$shrunk$ph = 0, $$2382$shrunk$ph$in = 0, $$2386 = 0, $$2386$shrunk = 0, $$2386$shrunk$ph = 0, $$2386$shrunk$ph$in = 0, $$2390 = 0, $$2394 = 0, $$3 = 0;
 var $$3379 = 0, $$3379$shrunk = 0, $$3383 = 0, $$3383$shrunk = 0, $$3383$shrunk$ph = 0, $$3383$shrunk$ph$in = 0, $$3387 = 0, $$3387$shrunk = 0, $$3387$shrunk$ph = 0, $$3387$shrunk$ph$in = 0, $$3391 = 0, $$3395 = 0, $$4 = 0, $$4396 = 0, $$in = 0, $$sink = 0, $$sink416 = 0, $$sink418 = 0, $$sink420 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0;
 var $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0;
 var $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0;
 var $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0;
 var $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0;
 var $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0;
 var $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0;
 var $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0;
 var $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0;
 var $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0;
 var $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0;
 var $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0;
 var $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0;
 var $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0;
 var $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0;
 var $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0;
 var $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0;
 var $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0;
 var $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0;
 var $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0;
 var $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0;
 var $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0;
 var $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0;
 var $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0;
 var $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0;
 var $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0;
 var $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0;
 var $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $div = 0, $div404 = 0, $div405 = 0, $div406 = 0, $div407 = 0, $div408 = 0;
 var $div409 = 0, $div410 = 0, $div411 = 0, $div412 = 0, $div413 = 0, $div414 = 0, $storemerge = 0, $storemerge399 = 0, $storemerge401 = 0, $storemerge403 = 0, $trunc = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($0)) + 36|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($0)) + 48|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ((($0)) + 40|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ((($12)) + 9|0);
 $14 = HEAP8[$13>>0]|0;
 $15 = $14&255;
 $16 = ((($0)) + 63|0);
 $17 = HEAP8[$16>>0]|0;
 $18 = $17&255;
 $19 = ($4|0)==(0);
 if ($19) {
  return;
 }
 $20 = ((($0)) + 44|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ((($0)) + 20|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = HEAP32[$0>>2]|0;
 $25 = (($2) + 3)|0;
 $26 = (($25|0) / 4)&-1;
 $trunc = $2&255;
 $27 = ((($21)) + 4|0);
 $28 = ($10|0)==(0|0);
 $29 = ((($12)) + 28|0);
 $30 = ((($12)) + 12|0);
 $31 = ((($12)) + 32|0);
 $32 = ((($12)) + 29|0);
 $33 = ((($12)) + 16|0);
 $34 = ((($12)) + 33|0);
 $35 = ((($12)) + 30|0);
 $36 = ((($12)) + 20|0);
 $37 = ((($12)) + 34|0);
 $$0388422 = $24;$$0392421 = $23;$$in = $4;
 L4: while(1) {
  $38 = (($$in) + -1)|0;
  $trunc$clear = $trunc & 3;
  switch ($trunc$clear<<24>>24) {
  case 0:  {
   $$0 = $26;$$1389 = $$0388422;$$1393 = $$0392421;
   label = 4;
   break;
  }
  case 3:  {
   $$1 = $26;$$2390 = $$0388422;$$2394 = $$0392421;
   label = 14;
   break;
  }
  case 2:  {
   $$2 = $26;$$3391 = $$0388422;$$3395 = $$0392421;
   label = 24;
   break;
  }
  case 1:  {
   $$3 = $26;$$4 = $$0388422;$$4396 = $$0392421;
   label = 34;
   break;
  }
  default: {
   label = 44;
   break L4;
  }
  }
  while(1) {
   if ((label|0) == 4) {
    label = 0;
    switch ($14<<24>>24) {
    case 1:  {
     $39 = HEAP8[$$1389>>0]|0;
     $40 = $39&255;
     $41 = HEAP8[$29>>0]|0;
     $42 = $41&255;
     $43 = (79212 + ($42<<2)|0);
     $44 = HEAP32[$43>>2]|0;
     $45 = HEAP32[$30>>2]|0;
     $46 = $45 & $40;
     $47 = HEAP8[$31>>0]|0;
     $48 = $47&255;
     $49 = $46 >>> $48;
     $50 = (($44) + ($49)|0);
     $51 = HEAP8[$32>>0]|0;
     $52 = $51&255;
     $53 = (79212 + ($52<<2)|0);
     $54 = HEAP32[$53>>2]|0;
     $55 = HEAP32[$33>>2]|0;
     $56 = $55 & $40;
     $57 = HEAP8[$34>>0]|0;
     $58 = $57&255;
     $59 = $56 >>> $58;
     $60 = (($54) + ($59)|0);
     $61 = HEAP8[$35>>0]|0;
     $62 = $61&255;
     $63 = (79212 + ($62<<2)|0);
     $64 = HEAP32[$63>>2]|0;
     $65 = HEAP32[$36>>2]|0;
     $66 = $65 & $40;
     $67 = HEAP8[$37>>0]|0;
     $68 = $67&255;
     $69 = $66 >>> $68;
     $70 = (($64) + ($69)|0);
     $$0380$shrunk$ph$in = $60;$$0384$shrunk$ph$in = $50;$$sink = $70;
     label = 9;
     break;
    }
    case 2:  {
     $71 = HEAP16[$$1389>>1]|0;
     $72 = $71&65535;
     $73 = HEAP8[$29>>0]|0;
     $74 = $73&255;
     $75 = (79212 + ($74<<2)|0);
     $76 = HEAP32[$75>>2]|0;
     $77 = HEAP32[$30>>2]|0;
     $78 = $77 & $72;
     $79 = HEAP8[$31>>0]|0;
     $80 = $79&255;
     $81 = $78 >>> $80;
     $82 = (($76) + ($81)|0);
     $83 = HEAP8[$32>>0]|0;
     $84 = $83&255;
     $85 = (79212 + ($84<<2)|0);
     $86 = HEAP32[$85>>2]|0;
     $87 = HEAP32[$33>>2]|0;
     $88 = $87 & $72;
     $89 = HEAP8[$34>>0]|0;
     $90 = $89&255;
     $91 = $88 >>> $90;
     $92 = (($86) + ($91)|0);
     $93 = HEAP8[$35>>0]|0;
     $94 = $93&255;
     $95 = (79212 + ($94<<2)|0);
     $96 = HEAP32[$95>>2]|0;
     $97 = HEAP32[$36>>2]|0;
     $98 = $97 & $72;
     $99 = HEAP8[$37>>0]|0;
     $100 = $99&255;
     $101 = $98 >>> $100;
     $102 = (($96) + ($101)|0);
     $$0380$shrunk$ph$in = $92;$$0384$shrunk$ph$in = $82;$$sink = $102;
     label = 9;
     break;
    }
    case 3:  {
     $103 = HEAP8[$31>>0]|0;
     $div409 = ($103&255) >>> 3;
     $104 = $div409&255;
     $105 = (($$1389) + ($104)|0);
     $106 = HEAP8[$34>>0]|0;
     $div410 = ($106&255) >>> 3;
     $107 = $div410&255;
     $108 = (($$1389) + ($107)|0);
     $109 = HEAP8[$37>>0]|0;
     $div411 = ($109&255) >>> 3;
     $110 = $div411&255;
     $111 = (($$1389) + ($110)|0);
     $$0380$shrunk$ph$in = $108;$$0384$shrunk$ph$in = $105;$$sink = $111;
     label = 9;
     break;
    }
    case 4:  {
     $112 = HEAP32[$$1389>>2]|0;
     $113 = HEAP8[$29>>0]|0;
     $114 = $113&255;
     $115 = (79212 + ($114<<2)|0);
     $116 = HEAP32[$115>>2]|0;
     $117 = HEAP32[$30>>2]|0;
     $118 = $117 & $112;
     $119 = HEAP8[$31>>0]|0;
     $120 = $119&255;
     $121 = $118 >>> $120;
     $122 = (($116) + ($121)|0);
     $123 = HEAP8[$32>>0]|0;
     $124 = $123&255;
     $125 = (79212 + ($124<<2)|0);
     $126 = HEAP32[$125>>2]|0;
     $127 = HEAP32[$33>>2]|0;
     $128 = $127 & $112;
     $129 = HEAP8[$34>>0]|0;
     $130 = $129&255;
     $131 = $128 >>> $130;
     $132 = (($126) + ($131)|0);
     $133 = HEAP8[$35>>0]|0;
     $134 = $133&255;
     $135 = (79212 + ($134<<2)|0);
     $136 = HEAP32[$135>>2]|0;
     $137 = HEAP32[$36>>2]|0;
     $138 = $137 & $112;
     $139 = HEAP8[$37>>0]|0;
     $140 = $139&255;
     $141 = $138 >>> $140;
     $142 = (($136) + ($141)|0);
     $$0380$shrunk$ph$in = $132;$$0384$shrunk$ph$in = $122;$$sink = $142;
     label = 9;
     break;
    }
    default: {
     $$0376$shrunk = 0;$$0380$shrunk = 0;$$0384$shrunk = 0;
    }
    }
    if ((label|0) == 9) {
     label = 0;
     $$0380$shrunk$ph = HEAP8[$$0380$shrunk$ph$in>>0]|0;
     $$0384$shrunk$ph = HEAP8[$$0384$shrunk$ph$in>>0]|0;
     $143 = HEAP8[$$sink>>0]|0;
     $$0376$shrunk = $143;$$0380$shrunk = $$0380$shrunk$ph;$$0384$shrunk = $$0384$shrunk$ph;
    }
    $$0376 = $$0376$shrunk&255;
    $$0380 = $$0380$shrunk&255;
    $$0384 = $$0384$shrunk&255;
    $144 = HEAP32[$27>>2]|0;
    $145 = ((($144)) + 4|0);
    $146 = HEAP32[$145>>2]|0;
    $147 = HEAP8[$$1393>>0]|0;
    $148 = $147&255;
    $149 = (($146) + ($148<<2)|0);
    $150 = HEAP8[$149>>0]|0;
    $151 = $150&255;
    $152 = (((($146) + ($148<<2)|0)) + 1|0);
    $153 = HEAP8[$152>>0]|0;
    $154 = $153&255;
    $155 = (((($146) + ($148<<2)|0)) + 2|0);
    $156 = HEAP8[$155>>0]|0;
    $157 = $156&255;
    $158 = (($$0384) - ($151))|0;
    $159 = Math_imul($158, $18)|0;
    $160 = (($159>>>0) / 255)&-1;
    $161 = (($160) + ($151))|0;
    $162 = (($$0380) - ($154))|0;
    $163 = Math_imul($162, $18)|0;
    $164 = (($163>>>0) / 255)&-1;
    $165 = (($164) + ($154))|0;
    $166 = (($$0376) - ($157))|0;
    $167 = Math_imul($166, $18)|0;
    $168 = (($167>>>0) / 255)&-1;
    $169 = (($168) + ($157))|0;
    $170 = $161 & 224;
    $171 = $165 >>> 3;
    $172 = $171 & 28;
    $173 = $169 >>> 6;
    $174 = $173 & 3;
    $175 = $172 | $170;
    $176 = $175 | $174;
    if ($28) {
     $177 = $176&255;
     $storemerge399 = $177;
    } else {
     $178 = (($10) + ($176)|0);
     $179 = HEAP8[$178>>0]|0;
     $storemerge399 = $179;
    }
    HEAP8[$$1393>>0] = $storemerge399;
    $180 = ((($$1393)) + 1|0);
    $181 = (($$1389) + ($15)|0);
    $$1 = $$0;$$2390 = $181;$$2394 = $180;
    label = 14;
    continue;
   }
   else if ((label|0) == 14) {
    label = 0;
    switch ($14<<24>>24) {
    case 1:  {
     $182 = HEAP8[$$2390>>0]|0;
     $183 = $182&255;
     $184 = HEAP8[$29>>0]|0;
     $185 = $184&255;
     $186 = (79212 + ($185<<2)|0);
     $187 = HEAP32[$186>>2]|0;
     $188 = HEAP32[$30>>2]|0;
     $189 = $188 & $183;
     $190 = HEAP8[$31>>0]|0;
     $191 = $190&255;
     $192 = $189 >>> $191;
     $193 = (($187) + ($192)|0);
     $194 = HEAP8[$32>>0]|0;
     $195 = $194&255;
     $196 = (79212 + ($195<<2)|0);
     $197 = HEAP32[$196>>2]|0;
     $198 = HEAP32[$33>>2]|0;
     $199 = $198 & $183;
     $200 = HEAP8[$34>>0]|0;
     $201 = $200&255;
     $202 = $199 >>> $201;
     $203 = (($197) + ($202)|0);
     $204 = HEAP8[$35>>0]|0;
     $205 = $204&255;
     $206 = (79212 + ($205<<2)|0);
     $207 = HEAP32[$206>>2]|0;
     $208 = HEAP32[$36>>2]|0;
     $209 = $208 & $183;
     $210 = HEAP8[$37>>0]|0;
     $211 = $210&255;
     $212 = $209 >>> $211;
     $213 = (($207) + ($212)|0);
     $$1381$shrunk$ph$in = $203;$$1385$shrunk$ph$in = $193;$$sink416 = $213;
     label = 19;
     break;
    }
    case 2:  {
     $214 = HEAP16[$$2390>>1]|0;
     $215 = $214&65535;
     $216 = HEAP8[$29>>0]|0;
     $217 = $216&255;
     $218 = (79212 + ($217<<2)|0);
     $219 = HEAP32[$218>>2]|0;
     $220 = HEAP32[$30>>2]|0;
     $221 = $220 & $215;
     $222 = HEAP8[$31>>0]|0;
     $223 = $222&255;
     $224 = $221 >>> $223;
     $225 = (($219) + ($224)|0);
     $226 = HEAP8[$32>>0]|0;
     $227 = $226&255;
     $228 = (79212 + ($227<<2)|0);
     $229 = HEAP32[$228>>2]|0;
     $230 = HEAP32[$33>>2]|0;
     $231 = $230 & $215;
     $232 = HEAP8[$34>>0]|0;
     $233 = $232&255;
     $234 = $231 >>> $233;
     $235 = (($229) + ($234)|0);
     $236 = HEAP8[$35>>0]|0;
     $237 = $236&255;
     $238 = (79212 + ($237<<2)|0);
     $239 = HEAP32[$238>>2]|0;
     $240 = HEAP32[$36>>2]|0;
     $241 = $240 & $215;
     $242 = HEAP8[$37>>0]|0;
     $243 = $242&255;
     $244 = $241 >>> $243;
     $245 = (($239) + ($244)|0);
     $$1381$shrunk$ph$in = $235;$$1385$shrunk$ph$in = $225;$$sink416 = $245;
     label = 19;
     break;
    }
    case 3:  {
     $246 = HEAP8[$31>>0]|0;
     $div406 = ($246&255) >>> 3;
     $247 = $div406&255;
     $248 = (($$2390) + ($247)|0);
     $249 = HEAP8[$34>>0]|0;
     $div407 = ($249&255) >>> 3;
     $250 = $div407&255;
     $251 = (($$2390) + ($250)|0);
     $252 = HEAP8[$37>>0]|0;
     $div408 = ($252&255) >>> 3;
     $253 = $div408&255;
     $254 = (($$2390) + ($253)|0);
     $$1381$shrunk$ph$in = $251;$$1385$shrunk$ph$in = $248;$$sink416 = $254;
     label = 19;
     break;
    }
    case 4:  {
     $255 = HEAP32[$$2390>>2]|0;
     $256 = HEAP8[$29>>0]|0;
     $257 = $256&255;
     $258 = (79212 + ($257<<2)|0);
     $259 = HEAP32[$258>>2]|0;
     $260 = HEAP32[$30>>2]|0;
     $261 = $260 & $255;
     $262 = HEAP8[$31>>0]|0;
     $263 = $262&255;
     $264 = $261 >>> $263;
     $265 = (($259) + ($264)|0);
     $266 = HEAP8[$32>>0]|0;
     $267 = $266&255;
     $268 = (79212 + ($267<<2)|0);
     $269 = HEAP32[$268>>2]|0;
     $270 = HEAP32[$33>>2]|0;
     $271 = $270 & $255;
     $272 = HEAP8[$34>>0]|0;
     $273 = $272&255;
     $274 = $271 >>> $273;
     $275 = (($269) + ($274)|0);
     $276 = HEAP8[$35>>0]|0;
     $277 = $276&255;
     $278 = (79212 + ($277<<2)|0);
     $279 = HEAP32[$278>>2]|0;
     $280 = HEAP32[$36>>2]|0;
     $281 = $280 & $255;
     $282 = HEAP8[$37>>0]|0;
     $283 = $282&255;
     $284 = $281 >>> $283;
     $285 = (($279) + ($284)|0);
     $$1381$shrunk$ph$in = $275;$$1385$shrunk$ph$in = $265;$$sink416 = $285;
     label = 19;
     break;
    }
    default: {
     $$1377$shrunk = 0;$$1381$shrunk = 0;$$1385$shrunk = 0;
    }
    }
    if ((label|0) == 19) {
     label = 0;
     $$1381$shrunk$ph = HEAP8[$$1381$shrunk$ph$in>>0]|0;
     $$1385$shrunk$ph = HEAP8[$$1385$shrunk$ph$in>>0]|0;
     $286 = HEAP8[$$sink416>>0]|0;
     $$1377$shrunk = $286;$$1381$shrunk = $$1381$shrunk$ph;$$1385$shrunk = $$1385$shrunk$ph;
    }
    $$1377 = $$1377$shrunk&255;
    $$1381 = $$1381$shrunk&255;
    $$1385 = $$1385$shrunk&255;
    $287 = HEAP32[$27>>2]|0;
    $288 = ((($287)) + 4|0);
    $289 = HEAP32[$288>>2]|0;
    $290 = HEAP8[$$2394>>0]|0;
    $291 = $290&255;
    $292 = (($289) + ($291<<2)|0);
    $293 = HEAP8[$292>>0]|0;
    $294 = $293&255;
    $295 = (((($289) + ($291<<2)|0)) + 1|0);
    $296 = HEAP8[$295>>0]|0;
    $297 = $296&255;
    $298 = (((($289) + ($291<<2)|0)) + 2|0);
    $299 = HEAP8[$298>>0]|0;
    $300 = $299&255;
    $301 = (($$1385) - ($294))|0;
    $302 = Math_imul($301, $18)|0;
    $303 = (($302>>>0) / 255)&-1;
    $304 = (($303) + ($294))|0;
    $305 = (($$1381) - ($297))|0;
    $306 = Math_imul($305, $18)|0;
    $307 = (($306>>>0) / 255)&-1;
    $308 = (($307) + ($297))|0;
    $309 = (($$1377) - ($300))|0;
    $310 = Math_imul($309, $18)|0;
    $311 = (($310>>>0) / 255)&-1;
    $312 = (($311) + ($300))|0;
    $313 = $312 >>> 6;
    $314 = $313 & 3;
    $315 = $304 & 224;
    $316 = $308 >>> 3;
    $317 = $316 & 28;
    $318 = $317 | $315;
    $319 = $318 | $314;
    if ($28) {
     $320 = $319&255;
     $storemerge401 = $320;
    } else {
     $321 = (($10) + ($319)|0);
     $322 = HEAP8[$321>>0]|0;
     $storemerge401 = $322;
    }
    HEAP8[$$2394>>0] = $storemerge401;
    $323 = ((($$2394)) + 1|0);
    $324 = (($$2390) + ($15)|0);
    $$2 = $$1;$$3391 = $324;$$3395 = $323;
    label = 24;
    continue;
   }
   else if ((label|0) == 24) {
    label = 0;
    switch ($14<<24>>24) {
    case 1:  {
     $325 = HEAP8[$$3391>>0]|0;
     $326 = $325&255;
     $327 = HEAP8[$29>>0]|0;
     $328 = $327&255;
     $329 = (79212 + ($328<<2)|0);
     $330 = HEAP32[$329>>2]|0;
     $331 = HEAP32[$30>>2]|0;
     $332 = $331 & $326;
     $333 = HEAP8[$31>>0]|0;
     $334 = $333&255;
     $335 = $332 >>> $334;
     $336 = (($330) + ($335)|0);
     $337 = HEAP8[$32>>0]|0;
     $338 = $337&255;
     $339 = (79212 + ($338<<2)|0);
     $340 = HEAP32[$339>>2]|0;
     $341 = HEAP32[$33>>2]|0;
     $342 = $341 & $326;
     $343 = HEAP8[$34>>0]|0;
     $344 = $343&255;
     $345 = $342 >>> $344;
     $346 = (($340) + ($345)|0);
     $347 = HEAP8[$35>>0]|0;
     $348 = $347&255;
     $349 = (79212 + ($348<<2)|0);
     $350 = HEAP32[$349>>2]|0;
     $351 = HEAP32[$36>>2]|0;
     $352 = $351 & $326;
     $353 = HEAP8[$37>>0]|0;
     $354 = $353&255;
     $355 = $352 >>> $354;
     $356 = (($350) + ($355)|0);
     $$2382$shrunk$ph$in = $346;$$2386$shrunk$ph$in = $336;$$sink418 = $356;
     label = 29;
     break;
    }
    case 2:  {
     $357 = HEAP16[$$3391>>1]|0;
     $358 = $357&65535;
     $359 = HEAP8[$29>>0]|0;
     $360 = $359&255;
     $361 = (79212 + ($360<<2)|0);
     $362 = HEAP32[$361>>2]|0;
     $363 = HEAP32[$30>>2]|0;
     $364 = $363 & $358;
     $365 = HEAP8[$31>>0]|0;
     $366 = $365&255;
     $367 = $364 >>> $366;
     $368 = (($362) + ($367)|0);
     $369 = HEAP8[$32>>0]|0;
     $370 = $369&255;
     $371 = (79212 + ($370<<2)|0);
     $372 = HEAP32[$371>>2]|0;
     $373 = HEAP32[$33>>2]|0;
     $374 = $373 & $358;
     $375 = HEAP8[$34>>0]|0;
     $376 = $375&255;
     $377 = $374 >>> $376;
     $378 = (($372) + ($377)|0);
     $379 = HEAP8[$35>>0]|0;
     $380 = $379&255;
     $381 = (79212 + ($380<<2)|0);
     $382 = HEAP32[$381>>2]|0;
     $383 = HEAP32[$36>>2]|0;
     $384 = $383 & $358;
     $385 = HEAP8[$37>>0]|0;
     $386 = $385&255;
     $387 = $384 >>> $386;
     $388 = (($382) + ($387)|0);
     $$2382$shrunk$ph$in = $378;$$2386$shrunk$ph$in = $368;$$sink418 = $388;
     label = 29;
     break;
    }
    case 3:  {
     $389 = HEAP8[$31>>0]|0;
     $div = ($389&255) >>> 3;
     $390 = $div&255;
     $391 = (($$3391) + ($390)|0);
     $392 = HEAP8[$34>>0]|0;
     $div404 = ($392&255) >>> 3;
     $393 = $div404&255;
     $394 = (($$3391) + ($393)|0);
     $395 = HEAP8[$37>>0]|0;
     $div405 = ($395&255) >>> 3;
     $396 = $div405&255;
     $397 = (($$3391) + ($396)|0);
     $$2382$shrunk$ph$in = $394;$$2386$shrunk$ph$in = $391;$$sink418 = $397;
     label = 29;
     break;
    }
    case 4:  {
     $398 = HEAP32[$$3391>>2]|0;
     $399 = HEAP8[$29>>0]|0;
     $400 = $399&255;
     $401 = (79212 + ($400<<2)|0);
     $402 = HEAP32[$401>>2]|0;
     $403 = HEAP32[$30>>2]|0;
     $404 = $403 & $398;
     $405 = HEAP8[$31>>0]|0;
     $406 = $405&255;
     $407 = $404 >>> $406;
     $408 = (($402) + ($407)|0);
     $409 = HEAP8[$32>>0]|0;
     $410 = $409&255;
     $411 = (79212 + ($410<<2)|0);
     $412 = HEAP32[$411>>2]|0;
     $413 = HEAP32[$33>>2]|0;
     $414 = $413 & $398;
     $415 = HEAP8[$34>>0]|0;
     $416 = $415&255;
     $417 = $414 >>> $416;
     $418 = (($412) + ($417)|0);
     $419 = HEAP8[$35>>0]|0;
     $420 = $419&255;
     $421 = (79212 + ($420<<2)|0);
     $422 = HEAP32[$421>>2]|0;
     $423 = HEAP32[$36>>2]|0;
     $424 = $423 & $398;
     $425 = HEAP8[$37>>0]|0;
     $426 = $425&255;
     $427 = $424 >>> $426;
     $428 = (($422) + ($427)|0);
     $$2382$shrunk$ph$in = $418;$$2386$shrunk$ph$in = $408;$$sink418 = $428;
     label = 29;
     break;
    }
    default: {
     $$2378$shrunk = 0;$$2382$shrunk = 0;$$2386$shrunk = 0;
    }
    }
    if ((label|0) == 29) {
     label = 0;
     $$2382$shrunk$ph = HEAP8[$$2382$shrunk$ph$in>>0]|0;
     $$2386$shrunk$ph = HEAP8[$$2386$shrunk$ph$in>>0]|0;
     $429 = HEAP8[$$sink418>>0]|0;
     $$2378$shrunk = $429;$$2382$shrunk = $$2382$shrunk$ph;$$2386$shrunk = $$2386$shrunk$ph;
    }
    $$2378 = $$2378$shrunk&255;
    $$2382 = $$2382$shrunk&255;
    $$2386 = $$2386$shrunk&255;
    $430 = HEAP32[$27>>2]|0;
    $431 = ((($430)) + 4|0);
    $432 = HEAP32[$431>>2]|0;
    $433 = HEAP8[$$3395>>0]|0;
    $434 = $433&255;
    $435 = (($432) + ($434<<2)|0);
    $436 = HEAP8[$435>>0]|0;
    $437 = $436&255;
    $438 = (((($432) + ($434<<2)|0)) + 1|0);
    $439 = HEAP8[$438>>0]|0;
    $440 = $439&255;
    $441 = (((($432) + ($434<<2)|0)) + 2|0);
    $442 = HEAP8[$441>>0]|0;
    $443 = $442&255;
    $444 = (($$2386) - ($437))|0;
    $445 = Math_imul($444, $18)|0;
    $446 = (($445>>>0) / 255)&-1;
    $447 = (($446) + ($437))|0;
    $448 = (($$2382) - ($440))|0;
    $449 = Math_imul($448, $18)|0;
    $450 = (($449>>>0) / 255)&-1;
    $451 = (($450) + ($440))|0;
    $452 = (($$2378) - ($443))|0;
    $453 = Math_imul($452, $18)|0;
    $454 = (($453>>>0) / 255)&-1;
    $455 = (($454) + ($443))|0;
    $456 = $447 & 224;
    $457 = $455 >>> 6;
    $458 = $457 & 3;
    $459 = $451 >>> 3;
    $460 = $459 & 28;
    $461 = $460 | $456;
    $462 = $461 | $458;
    if ($28) {
     $463 = $462&255;
     $storemerge403 = $463;
    } else {
     $464 = (($10) + ($462)|0);
     $465 = HEAP8[$464>>0]|0;
     $storemerge403 = $465;
    }
    HEAP8[$$3395>>0] = $storemerge403;
    $466 = ((($$3395)) + 1|0);
    $467 = (($$3391) + ($15)|0);
    $$3 = $$2;$$4 = $467;$$4396 = $466;
    label = 34;
    continue;
   }
   else if ((label|0) == 34) {
    label = 0;
    switch ($14<<24>>24) {
    case 1:  {
     $468 = HEAP8[$$4>>0]|0;
     $469 = $468&255;
     $470 = HEAP8[$29>>0]|0;
     $471 = $470&255;
     $472 = (79212 + ($471<<2)|0);
     $473 = HEAP32[$472>>2]|0;
     $474 = HEAP32[$30>>2]|0;
     $475 = $474 & $469;
     $476 = HEAP8[$31>>0]|0;
     $477 = $476&255;
     $478 = $475 >>> $477;
     $479 = (($473) + ($478)|0);
     $480 = HEAP8[$32>>0]|0;
     $481 = $480&255;
     $482 = (79212 + ($481<<2)|0);
     $483 = HEAP32[$482>>2]|0;
     $484 = HEAP32[$33>>2]|0;
     $485 = $484 & $469;
     $486 = HEAP8[$34>>0]|0;
     $487 = $486&255;
     $488 = $485 >>> $487;
     $489 = (($483) + ($488)|0);
     $490 = HEAP8[$35>>0]|0;
     $491 = $490&255;
     $492 = (79212 + ($491<<2)|0);
     $493 = HEAP32[$492>>2]|0;
     $494 = HEAP32[$36>>2]|0;
     $495 = $494 & $469;
     $496 = HEAP8[$37>>0]|0;
     $497 = $496&255;
     $498 = $495 >>> $497;
     $499 = (($493) + ($498)|0);
     $$3383$shrunk$ph$in = $489;$$3387$shrunk$ph$in = $479;$$sink420 = $499;
     label = 39;
     break;
    }
    case 2:  {
     $500 = HEAP16[$$4>>1]|0;
     $501 = $500&65535;
     $502 = HEAP8[$29>>0]|0;
     $503 = $502&255;
     $504 = (79212 + ($503<<2)|0);
     $505 = HEAP32[$504>>2]|0;
     $506 = HEAP32[$30>>2]|0;
     $507 = $506 & $501;
     $508 = HEAP8[$31>>0]|0;
     $509 = $508&255;
     $510 = $507 >>> $509;
     $511 = (($505) + ($510)|0);
     $512 = HEAP8[$32>>0]|0;
     $513 = $512&255;
     $514 = (79212 + ($513<<2)|0);
     $515 = HEAP32[$514>>2]|0;
     $516 = HEAP32[$33>>2]|0;
     $517 = $516 & $501;
     $518 = HEAP8[$34>>0]|0;
     $519 = $518&255;
     $520 = $517 >>> $519;
     $521 = (($515) + ($520)|0);
     $522 = HEAP8[$35>>0]|0;
     $523 = $522&255;
     $524 = (79212 + ($523<<2)|0);
     $525 = HEAP32[$524>>2]|0;
     $526 = HEAP32[$36>>2]|0;
     $527 = $526 & $501;
     $528 = HEAP8[$37>>0]|0;
     $529 = $528&255;
     $530 = $527 >>> $529;
     $531 = (($525) + ($530)|0);
     $$3383$shrunk$ph$in = $521;$$3387$shrunk$ph$in = $511;$$sink420 = $531;
     label = 39;
     break;
    }
    case 3:  {
     $532 = HEAP8[$31>>0]|0;
     $div412 = ($532&255) >>> 3;
     $533 = $div412&255;
     $534 = (($$4) + ($533)|0);
     $535 = HEAP8[$34>>0]|0;
     $div413 = ($535&255) >>> 3;
     $536 = $div413&255;
     $537 = (($$4) + ($536)|0);
     $538 = HEAP8[$37>>0]|0;
     $div414 = ($538&255) >>> 3;
     $539 = $div414&255;
     $540 = (($$4) + ($539)|0);
     $$3383$shrunk$ph$in = $537;$$3387$shrunk$ph$in = $534;$$sink420 = $540;
     label = 39;
     break;
    }
    case 4:  {
     $541 = HEAP32[$$4>>2]|0;
     $542 = HEAP8[$29>>0]|0;
     $543 = $542&255;
     $544 = (79212 + ($543<<2)|0);
     $545 = HEAP32[$544>>2]|0;
     $546 = HEAP32[$30>>2]|0;
     $547 = $546 & $541;
     $548 = HEAP8[$31>>0]|0;
     $549 = $548&255;
     $550 = $547 >>> $549;
     $551 = (($545) + ($550)|0);
     $552 = HEAP8[$32>>0]|0;
     $553 = $552&255;
     $554 = (79212 + ($553<<2)|0);
     $555 = HEAP32[$554>>2]|0;
     $556 = HEAP32[$33>>2]|0;
     $557 = $556 & $541;
     $558 = HEAP8[$34>>0]|0;
     $559 = $558&255;
     $560 = $557 >>> $559;
     $561 = (($555) + ($560)|0);
     $562 = HEAP8[$35>>0]|0;
     $563 = $562&255;
     $564 = (79212 + ($563<<2)|0);
     $565 = HEAP32[$564>>2]|0;
     $566 = HEAP32[$36>>2]|0;
     $567 = $566 & $541;
     $568 = HEAP8[$37>>0]|0;
     $569 = $568&255;
     $570 = $567 >>> $569;
     $571 = (($565) + ($570)|0);
     $$3383$shrunk$ph$in = $561;$$3387$shrunk$ph$in = $551;$$sink420 = $571;
     label = 39;
     break;
    }
    default: {
     $$3379$shrunk = 0;$$3383$shrunk = 0;$$3387$shrunk = 0;
    }
    }
    if ((label|0) == 39) {
     label = 0;
     $$3383$shrunk$ph = HEAP8[$$3383$shrunk$ph$in>>0]|0;
     $$3387$shrunk$ph = HEAP8[$$3387$shrunk$ph$in>>0]|0;
     $572 = HEAP8[$$sink420>>0]|0;
     $$3379$shrunk = $572;$$3383$shrunk = $$3383$shrunk$ph;$$3387$shrunk = $$3387$shrunk$ph;
    }
    $$3379 = $$3379$shrunk&255;
    $$3383 = $$3383$shrunk&255;
    $$3387 = $$3387$shrunk&255;
    $573 = HEAP32[$27>>2]|0;
    $574 = ((($573)) + 4|0);
    $575 = HEAP32[$574>>2]|0;
    $576 = HEAP8[$$4396>>0]|0;
    $577 = $576&255;
    $578 = (($575) + ($577<<2)|0);
    $579 = HEAP8[$578>>0]|0;
    $580 = $579&255;
    $581 = (((($575) + ($577<<2)|0)) + 1|0);
    $582 = HEAP8[$581>>0]|0;
    $583 = $582&255;
    $584 = (((($575) + ($577<<2)|0)) + 2|0);
    $585 = HEAP8[$584>>0]|0;
    $586 = $585&255;
    $587 = (($$3387) - ($580))|0;
    $588 = Math_imul($587, $18)|0;
    $589 = (($588>>>0) / 255)&-1;
    $590 = (($589) + ($580))|0;
    $591 = (($$3383) - ($583))|0;
    $592 = Math_imul($591, $18)|0;
    $593 = (($592>>>0) / 255)&-1;
    $594 = (($593) + ($583))|0;
    $595 = (($$3379) - ($586))|0;
    $596 = Math_imul($595, $18)|0;
    $597 = (($596>>>0) / 255)&-1;
    $598 = (($597) + ($586))|0;
    $599 = $598 >>> 6;
    $600 = $599 & 3;
    $601 = $590 & 224;
    $602 = $594 >>> 3;
    $603 = $602 & 28;
    $604 = $603 | $601;
    $605 = $604 | $600;
    if ($28) {
     $606 = $605&255;
     $storemerge = $606;
    } else {
     $607 = (($10) + ($605)|0);
     $608 = HEAP8[$607>>0]|0;
     $storemerge = $608;
    }
    HEAP8[$$4396>>0] = $storemerge;
    $609 = ((($$4396)) + 1|0);
    $610 = (($$4) + ($15)|0);
    $611 = (($$3) + -1)|0;
    $612 = ($$3|0)>(1);
    if ($612) {
     $$0 = $611;$$1389 = $610;$$1393 = $609;
     label = 4;
     continue;
    } else {
     break;
    }
   }
  }
  $613 = (($610) + ($6)|0);
  $614 = (($609) + ($8)|0);
  $615 = ($38|0)==(0);
  if ($615) {
   label = 46;
   break;
  } else {
   $$0388422 = $613;$$0392421 = $614;$$in = $38;
  }
 }
 if ((label|0) == 44) {
  // unreachable;
 }
 else if ((label|0) == 46) {
  return;
 }
}
function _BlitRGBtoRGBSurfaceAlpha($0) {
 $0 = $0|0;
 var $$0$us = 0, $$0116129 = 0, $$0116129$us = 0, $$0120128 = 0, $$0120128$us = 0, $$07081$i = 0, $$07081$i$us = 0, $$07081$us$i = 0, $$07180$i = 0, $$07180$i$us = 0, $$07180$us$i = 0, $$076$us$i = 0, $$1 = 0, $$1$us$i = 0, $$1117$us = 0, $$1121$us = 0, $$172$us$i = 0, $$177$i = 0, $$2 = 0, $$2$i = 0;
 var $$2118 = 0, $$2122 = 0, $$273$i = 0, $$278$i = 0, $$3 = 0, $$3$i = 0, $$3119 = 0, $$3123 = 0, $$374$i = 0, $$379$i = 0, $$379$i$us161 = 0, $$4 = 0, $$4$i = 0, $$4$i$us163 = 0, $$4124 = 0, $$475$i = 0, $$475$i$us162 = 0, $$lcssa157 = 0, $$lcssa158 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0;
 var $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0;
 var $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0;
 var $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0;
 var $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0;
 var $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0;
 var $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0;
 var $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0;
 var $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0;
 var $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0;
 var $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0;
 var $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0;
 var $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0;
 var $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0;
 var $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $trunc = 0, $trunc$clear = 0, $trunc$clear2 = 0;
 var $trunc$i = 0, $trunc$i$clear = 0, $trunc$i$clear1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 63|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = $2&255;
 $4 = ($2<<24>>24)==(-128);
 $5 = ((($0)) + 24|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($0)) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$0>>2]|0;
 $10 = ((($0)) + 16|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11 >> 2;
 $13 = ((($0)) + 20|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ((($0)) + 36|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $16 >> 2;
 $18 = (($8) + -1)|0;
 $19 = ($8|0)==(0);
 if (!($4)) {
  if ($19) {
   return;
  }
  $20 = (($6) + 3)|0;
  $21 = (($20|0) / 4)&-1;
  $trunc = $6&255;
  $trunc$clear = $trunc & 3;
  $22 = ($trunc$clear<<24>>24)==(0);
  if ($22) {
   $$0116129$us = $14;$$0120128$us = $9;$108 = $18;
   while(1) {
    $$0$us = $21;$$1117$us = $$0116129$us;$$1121$us = $$0120128$us;
    while(1) {
     $23 = HEAP32[$$1121$us>>2]|0;
     $24 = HEAP32[$$1117$us>>2]|0;
     $25 = $23 & 16711935;
     $26 = $24 & 16711935;
     $27 = (($25) - ($26))|0;
     $28 = Math_imul($27, $3)|0;
     $29 = $28 >>> 8;
     $30 = (($29) + ($26))|0;
     $31 = $30 & 16711935;
     $32 = $23 & 65280;
     $33 = $24 & 65280;
     $34 = (($32) - ($33))|0;
     $35 = Math_imul($34, $3)|0;
     $36 = $35 >>> 8;
     $37 = (($36) + ($33))|0;
     $38 = $37 & 65280;
     $39 = $38 | $31;
     $40 = $39 | -16777216;
     HEAP32[$$1117$us>>2] = $40;
     $41 = ((($$1121$us)) + 4|0);
     $42 = ((($$1117$us)) + 4|0);
     $43 = HEAP32[$41>>2]|0;
     $44 = HEAP32[$42>>2]|0;
     $45 = $43 & 16711935;
     $46 = $44 & 16711935;
     $47 = (($45) - ($46))|0;
     $48 = Math_imul($47, $3)|0;
     $49 = $48 >>> 8;
     $50 = (($49) + ($46))|0;
     $51 = $50 & 16711935;
     $52 = $43 & 65280;
     $53 = $44 & 65280;
     $54 = (($52) - ($53))|0;
     $55 = Math_imul($54, $3)|0;
     $56 = $55 >>> 8;
     $57 = (($56) + ($53))|0;
     $58 = $57 & 65280;
     $59 = $58 | $51;
     $60 = $59 | -16777216;
     HEAP32[$42>>2] = $60;
     $61 = ((($$1121$us)) + 8|0);
     $62 = ((($$1117$us)) + 8|0);
     $63 = HEAP32[$61>>2]|0;
     $64 = HEAP32[$62>>2]|0;
     $65 = $63 & 16711935;
     $66 = $64 & 16711935;
     $67 = (($65) - ($66))|0;
     $68 = Math_imul($67, $3)|0;
     $69 = $68 >>> 8;
     $70 = (($69) + ($66))|0;
     $71 = $70 & 16711935;
     $72 = $63 & 65280;
     $73 = $64 & 65280;
     $74 = (($72) - ($73))|0;
     $75 = Math_imul($74, $3)|0;
     $76 = $75 >>> 8;
     $77 = (($76) + ($73))|0;
     $78 = $77 & 65280;
     $79 = $78 | $71;
     $80 = $79 | -16777216;
     HEAP32[$62>>2] = $80;
     $81 = ((($$1121$us)) + 12|0);
     $82 = ((($$1117$us)) + 12|0);
     $83 = HEAP32[$81>>2]|0;
     $84 = HEAP32[$82>>2]|0;
     $85 = $83 & 16711935;
     $86 = $84 & 16711935;
     $87 = (($85) - ($86))|0;
     $88 = Math_imul($87, $3)|0;
     $89 = $88 >>> 8;
     $90 = (($89) + ($86))|0;
     $91 = $90 & 16711935;
     $92 = $83 & 65280;
     $93 = $84 & 65280;
     $94 = (($92) - ($93))|0;
     $95 = Math_imul($94, $3)|0;
     $96 = $95 >>> 8;
     $97 = (($96) + ($93))|0;
     $98 = $97 & 65280;
     $99 = $98 | $91;
     $100 = $99 | -16777216;
     HEAP32[$82>>2] = $100;
     $101 = ((($$1121$us)) + 16|0);
     $102 = ((($$1117$us)) + 16|0);
     $103 = (($$0$us) + -1)|0;
     $104 = ($$0$us|0)>(1);
     if ($104) {
      $$0$us = $103;$$1117$us = $102;$$1121$us = $101;
     } else {
      break;
     }
    }
    $105 = (($101) + ($12<<2)|0);
    $106 = (($102) + ($17<<2)|0);
    $107 = (($108) + -1)|0;
    $109 = ($108|0)==(0);
    if ($109) {
     break;
    } else {
     $$0116129$us = $106;$$0120128$us = $105;$108 = $107;
    }
   }
   return;
  } else {
   $$0116129 = $14;$$0120128 = $9;$377 = $18;
  }
  L13: while(1) {
   $trunc$clear2 = $trunc & 3;
   switch ($trunc$clear2<<24>>24) {
   case 1:  {
    $$3 = $21;$$4 = $$0116129;$$4124 = $$0120128;
    label = 27;
    break;
   }
   case 3:  {
    $$1 = $21;$$2118 = $$0116129;$$2122 = $$0120128;
    label = 25;
    break;
   }
   case 2:  {
    $$2 = $21;$$3119 = $$0116129;$$3123 = $$0120128;
    label = 26;
    break;
   }
   default: {
    label = 28;
    break L13;
   }
   }
   while(1) {
    if ((label|0) == 25) {
     label = 0;
     $315 = HEAP32[$$2122>>2]|0;
     $316 = HEAP32[$$2118>>2]|0;
     $317 = $315 & 16711935;
     $318 = $316 & 16711935;
     $319 = (($317) - ($318))|0;
     $320 = Math_imul($319, $3)|0;
     $321 = $320 >>> 8;
     $322 = (($321) + ($318))|0;
     $323 = $322 & 16711935;
     $324 = $315 & 65280;
     $325 = $316 & 65280;
     $326 = (($324) - ($325))|0;
     $327 = Math_imul($326, $3)|0;
     $328 = $327 >>> 8;
     $329 = (($328) + ($325))|0;
     $330 = $329 & 65280;
     $331 = $330 | $323;
     $332 = $331 | -16777216;
     HEAP32[$$2118>>2] = $332;
     $333 = ((($$2122)) + 4|0);
     $334 = ((($$2118)) + 4|0);
     $$2 = $$1;$$3119 = $334;$$3123 = $333;
     label = 26;
     continue;
    }
    else if ((label|0) == 26) {
     label = 0;
     $335 = HEAP32[$$3123>>2]|0;
     $336 = HEAP32[$$3119>>2]|0;
     $337 = $335 & 16711935;
     $338 = $336 & 16711935;
     $339 = (($337) - ($338))|0;
     $340 = Math_imul($339, $3)|0;
     $341 = $340 >>> 8;
     $342 = (($341) + ($338))|0;
     $343 = $342 & 16711935;
     $344 = $335 & 65280;
     $345 = $336 & 65280;
     $346 = (($344) - ($345))|0;
     $347 = Math_imul($346, $3)|0;
     $348 = $347 >>> 8;
     $349 = (($348) + ($345))|0;
     $350 = $349 & 65280;
     $351 = $350 | $343;
     $352 = $351 | -16777216;
     HEAP32[$$3119>>2] = $352;
     $353 = ((($$3123)) + 4|0);
     $354 = ((($$3119)) + 4|0);
     $$3 = $$2;$$4 = $354;$$4124 = $353;
     label = 27;
     continue;
    }
    else if ((label|0) == 27) {
     label = 0;
     $355 = HEAP32[$$4124>>2]|0;
     $356 = HEAP32[$$4>>2]|0;
     $357 = $355 & 16711935;
     $358 = $356 & 16711935;
     $359 = (($357) - ($358))|0;
     $360 = Math_imul($359, $3)|0;
     $361 = $360 >>> 8;
     $362 = (($361) + ($358))|0;
     $363 = $362 & 16711935;
     $364 = $355 & 65280;
     $365 = $356 & 65280;
     $366 = (($364) - ($365))|0;
     $367 = Math_imul($366, $3)|0;
     $368 = $367 >>> 8;
     $369 = (($368) + ($365))|0;
     $370 = $369 & 65280;
     $371 = $370 | $363;
     $372 = $371 | -16777216;
     HEAP32[$$4>>2] = $372;
     $294 = ((($$4124)) + 4|0);
     $296 = ((($$4)) + 4|0);
     $373 = ($$3|0)>(1);
     if (!($373)) {
      break;
     }
     $292 = (($$3) + -1)|0;
     $293 = HEAP32[$294>>2]|0;
     $295 = HEAP32[$296>>2]|0;
     $297 = $293 & 16711935;
     $298 = $295 & 16711935;
     $299 = (($297) - ($298))|0;
     $300 = Math_imul($299, $3)|0;
     $301 = $300 >>> 8;
     $302 = (($301) + ($298))|0;
     $303 = $302 & 16711935;
     $304 = $293 & 65280;
     $305 = $295 & 65280;
     $306 = (($304) - ($305))|0;
     $307 = Math_imul($306, $3)|0;
     $308 = $307 >>> 8;
     $309 = (($308) + ($305))|0;
     $310 = $309 & 65280;
     $311 = $310 | $303;
     $312 = $311 | -16777216;
     HEAP32[$296>>2] = $312;
     $313 = ((($$4124)) + 8|0);
     $314 = ((($$4)) + 8|0);
     $$1 = $292;$$2118 = $314;$$2122 = $313;
     label = 25;
     continue;
    }
   }
   $374 = (($294) + ($12<<2)|0);
   $375 = (($296) + ($17<<2)|0);
   $376 = (($377) + -1)|0;
   $378 = ($377|0)==(0);
   if ($378) {
    label = 30;
    break;
   } else {
    $$0116129 = $375;$$0120128 = $374;$377 = $376;
   }
  }
  if ((label|0) == 28) {
   // unreachable;
  }
  else if ((label|0) == 30) {
   return;
  }
 }
 if ($19) {
  return;
 }
 $110 = (($6) + 3)|0;
 $111 = (($110|0) / 4)&-1;
 $trunc$i = $6&255;
 $trunc$i$clear = $trunc$i & 3;
 switch ($trunc$i$clear<<24>>24) {
 case 0:  {
  $$07081$us$i = $9;$$07180$us$i = $14;$235 = $18;
  while(1) {
   $$076$us$i = $111;$$1$us$i = $$07081$us$i;$$172$us$i = $$07180$us$i;
   while(1) {
    $182 = ((($$1$us$i)) + 4|0);
    $183 = HEAP32[$$1$us$i>>2]|0;
    $184 = HEAP32[$$172$us$i>>2]|0;
    $185 = $183 & 16711422;
    $186 = $184 & 16711422;
    $187 = (($186) + ($185))|0;
    $188 = $187 >>> 1;
    $189 = $183 & 65793;
    $190 = $189 & $184;
    $191 = (($188) + ($190))|0;
    $192 = $191 | -16777216;
    $193 = ((($$172$us$i)) + 4|0);
    HEAP32[$$172$us$i>>2] = $192;
    $194 = ((($$1$us$i)) + 8|0);
    $195 = HEAP32[$182>>2]|0;
    $196 = HEAP32[$193>>2]|0;
    $197 = $195 & 16711422;
    $198 = $196 & 16711422;
    $199 = (($198) + ($197))|0;
    $200 = $199 >>> 1;
    $201 = $195 & 65793;
    $202 = $201 & $196;
    $203 = (($200) + ($202))|0;
    $204 = $203 | -16777216;
    $205 = ((($$172$us$i)) + 8|0);
    HEAP32[$193>>2] = $204;
    $206 = ((($$1$us$i)) + 12|0);
    $207 = HEAP32[$194>>2]|0;
    $208 = HEAP32[$205>>2]|0;
    $209 = $207 & 16711422;
    $210 = $208 & 16711422;
    $211 = (($210) + ($209))|0;
    $212 = $211 >>> 1;
    $213 = $207 & 65793;
    $214 = $213 & $208;
    $215 = (($212) + ($214))|0;
    $216 = $215 | -16777216;
    $217 = ((($$172$us$i)) + 12|0);
    HEAP32[$205>>2] = $216;
    $218 = ((($$1$us$i)) + 16|0);
    $219 = HEAP32[$206>>2]|0;
    $220 = HEAP32[$217>>2]|0;
    $221 = $219 & 16711422;
    $222 = $220 & 16711422;
    $223 = (($222) + ($221))|0;
    $224 = $223 >>> 1;
    $225 = $219 & 65793;
    $226 = $225 & $220;
    $227 = (($224) + ($226))|0;
    $228 = $227 | -16777216;
    $229 = ((($$172$us$i)) + 16|0);
    HEAP32[$217>>2] = $228;
    $230 = (($$076$us$i) + -1)|0;
    $231 = ($$076$us$i|0)>(1);
    if ($231) {
     $$076$us$i = $230;$$1$us$i = $218;$$172$us$i = $229;
    } else {
     break;
    }
   }
   $232 = (($218) + ($12<<2)|0);
   $233 = (($229) + ($17<<2)|0);
   $234 = (($235) + -1)|0;
   $236 = ($235|0)==(0);
   if ($236) {
    break;
   } else {
    $$07081$us$i = $232;$$07180$us$i = $233;$235 = $234;
   }
  }
  return;
  break;
 }
 case 1:  {
  $112 = ($110|0)>(7);
  $$07081$i$us = $9;$$07180$i$us = $14;$128 = $18;
  while(1) {
   $113 = ((($$07081$i$us)) + 4|0);
   $114 = HEAP32[$$07081$i$us>>2]|0;
   $115 = HEAP32[$$07180$i$us>>2]|0;
   $116 = $114 & 16711422;
   $117 = $115 & 16711422;
   $118 = (($117) + ($116))|0;
   $119 = $118 >>> 1;
   $120 = $114 & 65793;
   $121 = $120 & $115;
   $122 = (($119) + ($121))|0;
   $123 = $122 | -16777216;
   $124 = ((($$07180$i$us)) + 4|0);
   HEAP32[$$07180$i$us>>2] = $123;
   if ($112) {
    $$379$i$us161 = $111;$$4$i$us163 = $$07081$i$us;$$475$i$us162 = $$07180$i$us;$133 = $113;$135 = $124;
    while(1) {
     $130 = (($$379$i$us161) + -1)|0;
     $131 = ((($$4$i$us163)) + 8|0);
     $132 = HEAP32[$133>>2]|0;
     $134 = HEAP32[$135>>2]|0;
     $136 = $132 & 16711422;
     $137 = $134 & 16711422;
     $138 = (($137) + ($136))|0;
     $139 = $138 >>> 1;
     $140 = $132 & 65793;
     $141 = $140 & $134;
     $142 = (($139) + ($141))|0;
     $143 = $142 | -16777216;
     $144 = ((($$475$i$us162)) + 8|0);
     HEAP32[$135>>2] = $143;
     $145 = ((($$4$i$us163)) + 12|0);
     $146 = HEAP32[$131>>2]|0;
     $147 = HEAP32[$144>>2]|0;
     $148 = $146 & 16711422;
     $149 = $147 & 16711422;
     $150 = (($149) + ($148))|0;
     $151 = $150 >>> 1;
     $152 = $146 & 65793;
     $153 = $152 & $147;
     $154 = (($151) + ($153))|0;
     $155 = $154 | -16777216;
     $156 = ((($$475$i$us162)) + 12|0);
     HEAP32[$144>>2] = $155;
     $157 = ((($$4$i$us163)) + 16|0);
     $158 = HEAP32[$145>>2]|0;
     $159 = HEAP32[$156>>2]|0;
     $160 = $158 & 16711422;
     $161 = $159 & 16711422;
     $162 = (($161) + ($160))|0;
     $163 = $162 >>> 1;
     $164 = $158 & 65793;
     $165 = $164 & $159;
     $166 = (($163) + ($165))|0;
     $167 = $166 | -16777216;
     $168 = ((($$475$i$us162)) + 16|0);
     HEAP32[$156>>2] = $167;
     $169 = ((($$4$i$us163)) + 20|0);
     $170 = HEAP32[$157>>2]|0;
     $171 = HEAP32[$168>>2]|0;
     $172 = $170 & 16711422;
     $173 = $171 & 16711422;
     $174 = (($173) + ($172))|0;
     $175 = $174 >>> 1;
     $176 = $170 & 65793;
     $177 = $176 & $171;
     $178 = (($175) + ($177))|0;
     $179 = $178 | -16777216;
     $180 = ((($$475$i$us162)) + 20|0);
     HEAP32[$168>>2] = $179;
     $181 = ($130|0)>(1);
     if ($181) {
      $$379$i$us161 = $130;$$4$i$us163 = $157;$$475$i$us162 = $168;$133 = $169;$135 = $180;
     } else {
      $$lcssa157 = $180;$$lcssa158 = $169;
      break;
     }
    }
   } else {
    $$lcssa157 = $124;$$lcssa158 = $113;
   }
   $125 = (($$lcssa158) + ($12<<2)|0);
   $126 = (($$lcssa157) + ($17<<2)|0);
   $127 = (($128) + -1)|0;
   $129 = ($128|0)==(0);
   if ($129) {
    break;
   } else {
    $$07081$i$us = $125;$$07180$i$us = $126;$128 = $127;
   }
  }
  return;
  break;
 }
 default: {
  $$07081$i = $9;$$07180$i = $14;$290 = $18;
  L30: while(1) {
   $trunc$i$clear1 = $trunc$i & 3;
   switch ($trunc$i$clear1<<24>>24) {
   case 1:  {
    $$379$i = $111;$$4$i = $$07081$i;$$475$i = $$07180$i;
    label = 20;
    break;
   }
   case 3:  {
    $$177$i = $111;$$2$i = $$07081$i;$$273$i = $$07180$i;
    label = 18;
    break;
   }
   case 2:  {
    $$278$i = $111;$$3$i = $$07081$i;$$374$i = $$07180$i;
    label = 19;
    break;
   }
   default: {
    label = 21;
    break L30;
   }
   }
   while(1) {
    if ((label|0) == 18) {
     label = 0;
     $252 = ((($$2$i)) + 4|0);
     $253 = HEAP32[$$2$i>>2]|0;
     $254 = HEAP32[$$273$i>>2]|0;
     $255 = $253 & 16711422;
     $256 = $254 & 16711422;
     $257 = (($256) + ($255))|0;
     $258 = $257 >>> 1;
     $259 = $253 & 65793;
     $260 = $259 & $254;
     $261 = (($258) + ($260))|0;
     $262 = $261 | -16777216;
     $263 = ((($$273$i)) + 4|0);
     HEAP32[$$273$i>>2] = $262;
     $$278$i = $$177$i;$$3$i = $252;$$374$i = $263;
     label = 19;
     continue;
    }
    else if ((label|0) == 19) {
     label = 0;
     $264 = ((($$3$i)) + 4|0);
     $265 = HEAP32[$$3$i>>2]|0;
     $266 = HEAP32[$$374$i>>2]|0;
     $267 = $265 & 16711422;
     $268 = $266 & 16711422;
     $269 = (($268) + ($267))|0;
     $270 = $269 >>> 1;
     $271 = $265 & 65793;
     $272 = $271 & $266;
     $273 = (($270) + ($272))|0;
     $274 = $273 | -16777216;
     $275 = ((($$374$i)) + 4|0);
     HEAP32[$$374$i>>2] = $274;
     $$379$i = $$278$i;$$4$i = $264;$$475$i = $275;
     label = 20;
     continue;
    }
    else if ((label|0) == 20) {
     label = 0;
     $240 = ((($$4$i)) + 4|0);
     $276 = HEAP32[$$4$i>>2]|0;
     $277 = HEAP32[$$475$i>>2]|0;
     $278 = $276 & 16711422;
     $279 = $277 & 16711422;
     $280 = (($279) + ($278))|0;
     $281 = $280 >>> 1;
     $282 = $276 & 65793;
     $283 = $282 & $277;
     $284 = (($281) + ($283))|0;
     $285 = $284 | -16777216;
     $242 = ((($$475$i)) + 4|0);
     HEAP32[$$475$i>>2] = $285;
     $286 = ($$379$i|0)>(1);
     if (!($286)) {
      break;
     }
     $237 = (($$379$i) + -1)|0;
     $238 = ((($$4$i)) + 8|0);
     $239 = HEAP32[$240>>2]|0;
     $241 = HEAP32[$242>>2]|0;
     $243 = $239 & 16711422;
     $244 = $241 & 16711422;
     $245 = (($244) + ($243))|0;
     $246 = $245 >>> 1;
     $247 = $239 & 65793;
     $248 = $247 & $241;
     $249 = (($246) + ($248))|0;
     $250 = $249 | -16777216;
     $251 = ((($$475$i)) + 8|0);
     HEAP32[$242>>2] = $250;
     $$177$i = $237;$$2$i = $238;$$273$i = $251;
     label = 18;
     continue;
    }
   }
   $287 = (($240) + ($12<<2)|0);
   $288 = (($242) + ($17<<2)|0);
   $289 = (($290) + -1)|0;
   $291 = ($290|0)==(0);
   if ($291) {
    label = 30;
    break;
   } else {
    $$07081$i = $287;$$07180$i = $288;$290 = $289;
   }
  }
  if ((label|0) == 21) {
   // unreachable;
  }
  else if ((label|0) == 30) {
   return;
  }
 }
 }
}
function _Blit16to16SurfaceAlpha128($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0154$be = 0, $$0154181 = 0, $$0155180 = 0, $$0161$lcssa = 0, $$0161166 = 0, $$0162 = 0, $$0164$lcssa = 0, $$0164$ph = 0, $$0164172 = 0, $$1 = 0, $$1156 = 0, $$1163$lcssa = 0, $$1163165 = 0, $$2$lcssa = 0, $$2157$lcssa = 0, $$2157167 = 0, $$2168 = 0, $$3 = 0, $$3158 = 0, $$4$lcssa = 0;
 var $$4$ph = 0, $$4159$lcssa = 0, $$4159$ph = 0, $$4159173 = 0, $$4174 = 0, $$5 = 0, $$5160 = 0, $$5160$sink = 0, $$in = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $scevgep = 0, $scevgep191 = 0, $scevgep192 = 0, $scevgep193 = 0, $scevgep194 = 0, $scevgep195 = 0, $scevgep196 = 0, $scevgep197 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($0)) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 >> 1;
 $9 = ((($0)) + 36|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10 >> 1;
 $12 = ($5|0)==(0);
 if ($12) {
  return;
 }
 $13 = ((($0)) + 20|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP32[$0>>2]|0;
 $16 = $1 ^ -1;
 $17 = (($3) + -1)|0;
 $18 = $1&65535;
 $19 = $18 << 16;
 $20 = $19 | $18;
 $21 = $20 ^ -1;
 $22 = (($8) + -1)|0;
 $23 = $18 ^ 65535;
 $$0154181 = $15;$$0155180 = $14;$$in = $5;
 while(1) {
  $24 = (($$in) + -1)|0;
  $25 = $$0154181;
  $26 = $$0155180;
  $27 = $25 ^ $26;
  $28 = $27 & 2;
  $29 = ($28|0)==(0);
  if ($29) {
   $87 = $25 & 2;
   $88 = ($87|0)==(0);
   if ($88) {
    $$0164$ph = $3;$$4$ph = $$0154181;$$4159$ph = $$0155180;
   } else {
    $89 = HEAP16[$$0155180>>1]|0;
    $90 = HEAP16[$$0154181>>1]|0;
    $91 = $90 & $1;
    $92 = $91&65535;
    $93 = $89 & $1;
    $94 = $93&65535;
    $95 = (($92) + ($94))|0;
    $96 = $95 >>> 1;
    $97 = $89 & $16;
    $98 = $97 & $90;
    $99 = $98&65535;
    $100 = (($96) + ($99))|0;
    $101 = $100&65535;
    HEAP16[$$0155180>>1] = $101;
    $102 = ((($$0154181)) + 2|0);
    $103 = ((($$0155180)) + 2|0);
    $$0164$ph = $17;$$4$ph = $102;$$4159$ph = $103;
   }
   $104 = ($$0164$ph|0)>(1);
   if ($104) {
    $105 = (($$0164$ph) + -2)|0;
    $106 = $105 & -2;
    $scevgep196 = ((($$4159$ph)) + 4|0);
    $scevgep197 = (($scevgep196) + ($106<<1)|0);
    $$0164172 = $$0164$ph;$$4159173 = $$4159$ph;$$4174 = $$4$ph;
    while(1) {
     $107 = HEAP32[$$4174>>2]|0;
     $108 = HEAP32[$$4159173>>2]|0;
     $109 = $107 & $20;
     $110 = $109 >>> 1;
     $111 = $108 & $20;
     $112 = $111 >>> 1;
     $113 = (($112) + ($110))|0;
     $114 = $107 & $21;
     $115 = $114 & $108;
     $116 = (($113) + ($115))|0;
     HEAP32[$$4159173>>2] = $116;
     $117 = ((($$4174)) + 4|0);
     $118 = ((($$4159173)) + 4|0);
     $119 = (($$0164172) + -2)|0;
     $120 = ($119|0)>(1);
     if ($120) {
      $$0164172 = $119;$$4159173 = $118;$$4174 = $117;
     } else {
      break;
     }
    }
    $scevgep194 = ((($$4$ph)) + 4|0);
    $scevgep195 = (($scevgep194) + ($106<<1)|0);
    $121 = (($105) - ($106))|0;
    $$0164$lcssa = $121;$$4$lcssa = $scevgep195;$$4159$lcssa = $scevgep197;
   } else {
    $$0164$lcssa = $$0164$ph;$$4$lcssa = $$4$ph;$$4159$lcssa = $$4159$ph;
   }
   $122 = ($$0164$lcssa|0)==(0);
   if ($122) {
    $$5 = $$4$lcssa;$$5160 = $$4159$lcssa;
   } else {
    $123 = HEAP16[$$4159$lcssa>>1]|0;
    $124 = HEAP16[$$4$lcssa>>1]|0;
    $125 = $124 & $1;
    $126 = $125&65535;
    $127 = $123 & $1;
    $128 = $127&65535;
    $129 = (($126) + ($128))|0;
    $130 = $129 >>> 1;
    $131 = $123 & $16;
    $132 = $131 & $124;
    $133 = $132&65535;
    $134 = (($130) + ($133))|0;
    $135 = $134&65535;
    HEAP16[$$4159$lcssa>>1] = $135;
    $136 = ((($$4$lcssa)) + 2|0);
    $137 = ((($$4159$lcssa)) + 2|0);
    $$5 = $136;$$5160 = $137;
   }
   $138 = (($$5) + ($8<<1)|0);
   $$0154$be = $138;$$5160$sink = $$5160;
  } else {
   $30 = $26 & 2;
   $31 = ($30|0)==(0);
   if ($31) {
    $$0162 = $3;$$1 = $$0154181;$$1156 = $$0155180;
   } else {
    $32 = HEAP16[$$0155180>>1]|0;
    $33 = HEAP16[$$0154181>>1]|0;
    $34 = $33 & $1;
    $35 = $34&65535;
    $36 = $32 & $1;
    $37 = $36&65535;
    $38 = (($35) + ($37))|0;
    $39 = $38 >>> 1;
    $40 = $32 & $16;
    $41 = $40 & $33;
    $42 = $41&65535;
    $43 = (($39) + ($42))|0;
    $44 = $43&65535;
    HEAP16[$$0155180>>1] = $44;
    $45 = ((($$0155180)) + 2|0);
    $46 = ((($$0154181)) + 2|0);
    $$0162 = $17;$$1 = $46;$$1156 = $45;
   }
   $47 = ((($$1)) + 2|0);
   $48 = ((($$1)) + -2|0);
   $49 = HEAP32[$48>>2]|0;
   $50 = ($$0162|0)>(1);
   if ($50) {
    $51 = (($$0162) + -2)|0;
    $52 = $51 & -2;
    $scevgep192 = ((($$1)) + 6|0);
    $scevgep193 = (($scevgep192) + ($52<<1)|0);
    $$0161166 = $49;$$1163165 = $$0162;$$2157167 = $$1156;$$2168 = $47;
    while(1) {
     $53 = HEAP32[$$2168>>2]|0;
     $54 = HEAP32[$$2157167>>2]|0;
     $55 = $$0161166 >>> 16;
     $56 = $53 << 16;
     $57 = $56 | $55;
     $58 = $57 & $20;
     $59 = $58 >>> 1;
     $60 = $54 & $20;
     $61 = $60 >>> 1;
     $62 = (($59) + ($61))|0;
     $63 = $54 & $21;
     $64 = $63 & $57;
     $65 = (($62) + ($64))|0;
     HEAP32[$$2157167>>2] = $65;
     $66 = ((($$2157167)) + 4|0);
     $67 = ((($$2168)) + 4|0);
     $68 = (($$1163165) + -2)|0;
     $69 = ($68|0)>(1);
     if ($69) {
      $$0161166 = $53;$$1163165 = $68;$$2157167 = $66;$$2168 = $67;
     } else {
      break;
     }
    }
    $scevgep = ((($$1156)) + 4|0);
    $scevgep191 = (($scevgep) + ($52<<1)|0);
    $70 = (($51) - ($52))|0;
    $$0161$lcssa = $53;$$1163$lcssa = $70;$$2$lcssa = $scevgep193;$$2157$lcssa = $scevgep191;
   } else {
    $$0161$lcssa = $49;$$1163$lcssa = $$0162;$$2$lcssa = $47;$$2157$lcssa = $$1156;
   }
   $71 = ($$1163$lcssa|0)==(0);
   if ($71) {
    $$3 = $$2$lcssa;$$3158 = $$2157$lcssa;
   } else {
    $72 = HEAP16[$$2157$lcssa>>1]|0;
    $73 = $$0161$lcssa >>> 16;
    $74 = $73 & $18;
    $75 = $72&65535;
    $76 = $72 & $1;
    $77 = $76&65535;
    $78 = (($77) + ($74))|0;
    $79 = $78 >>> 1;
    $80 = $73 & $23;
    $81 = $80 & $75;
    $82 = (($79) + ($81))|0;
    $83 = $82&65535;
    HEAP16[$$2157$lcssa>>1] = $83;
    $84 = ((($$2$lcssa)) + 2|0);
    $85 = ((($$2157$lcssa)) + 2|0);
    $$3 = $84;$$3158 = $85;
   }
   $86 = (($$3) + ($22<<1)|0);
   $$0154$be = $86;$$5160$sink = $$3158;
  }
  $139 = (($$5160$sink) + ($11<<1)|0);
  $140 = ($24|0)==(0);
  if ($140) {
   break;
  } else {
   $$0154181 = $$0154$be;$$0155180 = $139;$$in = $24;
  }
 }
 return;
}
function _Blit1toNAlpha($0) {
 $0 = $0|0;
 var $$0610671 = 0, $$0611670 = 0, $$0616 = 0, $$0616$shrunk = 0, $$0620 = 0, $$0620$shrunk = 0, $$0624 = 0, $$0624$shrunk = 0, $$0628 = 0, $$0628$shrunk = 0, $$0632 = 0, $$1 = 0, $$1612 = 0, $$1617 = 0, $$1617$shrunk = 0, $$1621 = 0, $$1621$shrunk = 0, $$1625 = 0, $$1625$shrunk = 0, $$1629 = 0;
 var $$1629$shrunk = 0, $$1633 = 0, $$2 = 0, $$2613 = 0, $$2618 = 0, $$2618$shrunk = 0, $$2622 = 0, $$2622$shrunk = 0, $$2626 = 0, $$2626$shrunk = 0, $$2630 = 0, $$2630$shrunk = 0, $$2634 = 0, $$3 = 0, $$3614 = 0, $$3619 = 0, $$3619$shrunk = 0, $$3623 = 0, $$3623$shrunk = 0, $$3627 = 0;
 var $$3627$shrunk = 0, $$3631 = 0, $$3631$shrunk = 0, $$3635 = 0, $$4 = 0, $$4615 = 0, $$in = 0, $1 = 0, $10 = 0, $100 = 0, $1000 = 0, $1001 = 0, $1002 = 0, $1003 = 0, $1004 = 0, $1005 = 0, $1006 = 0, $1007 = 0, $1008 = 0, $1009 = 0;
 var $101 = 0, $1010 = 0, $1011 = 0, $1012 = 0, $1013 = 0, $1014 = 0, $1015 = 0, $1016 = 0, $1017 = 0, $1018 = 0, $1019 = 0, $102 = 0, $1020 = 0, $1021 = 0, $1022 = 0, $1023 = 0, $1024 = 0, $1025 = 0, $1026 = 0, $1027 = 0;
 var $1028 = 0, $1029 = 0, $103 = 0, $1030 = 0, $1031 = 0, $1032 = 0, $1033 = 0, $1034 = 0, $1035 = 0, $1036 = 0, $1037 = 0, $1038 = 0, $1039 = 0, $104 = 0, $1040 = 0, $1041 = 0, $1042 = 0, $1043 = 0, $1044 = 0, $1045 = 0;
 var $1046 = 0, $1047 = 0, $1048 = 0, $1049 = 0, $105 = 0, $1050 = 0, $1051 = 0, $1052 = 0, $1053 = 0, $1054 = 0, $1055 = 0, $1056 = 0, $1057 = 0, $1058 = 0, $1059 = 0, $106 = 0, $1060 = 0, $1061 = 0, $1062 = 0, $1063 = 0;
 var $1064 = 0, $1065 = 0, $1066 = 0, $1067 = 0, $1068 = 0, $1069 = 0, $107 = 0, $1070 = 0, $1071 = 0, $1072 = 0, $1073 = 0, $1074 = 0, $1075 = 0, $1076 = 0, $1077 = 0, $1078 = 0, $1079 = 0, $108 = 0, $1080 = 0, $1081 = 0;
 var $1082 = 0, $1083 = 0, $1084 = 0, $1085 = 0, $1086 = 0, $1087 = 0, $1088 = 0, $1089 = 0, $109 = 0, $1090 = 0, $1091 = 0, $1092 = 0, $1093 = 0, $1094 = 0, $1095 = 0, $1096 = 0, $1097 = 0, $1098 = 0, $1099 = 0, $11 = 0;
 var $110 = 0, $1100 = 0, $1101 = 0, $1102 = 0, $1103 = 0, $1104 = 0, $1105 = 0, $1106 = 0, $1107 = 0, $1108 = 0, $1109 = 0, $111 = 0, $1110 = 0, $1111 = 0, $1112 = 0, $1113 = 0, $1114 = 0, $1115 = 0, $1116 = 0, $1117 = 0;
 var $1118 = 0, $1119 = 0, $112 = 0, $1120 = 0, $1121 = 0, $1122 = 0, $1123 = 0, $1124 = 0, $1125 = 0, $1126 = 0, $1127 = 0, $1128 = 0, $1129 = 0, $113 = 0, $1130 = 0, $1131 = 0, $1132 = 0, $1133 = 0, $1134 = 0, $1135 = 0;
 var $1136 = 0, $1137 = 0, $1138 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0;
 var $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0;
 var $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0;
 var $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0;
 var $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0;
 var $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0;
 var $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0;
 var $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0;
 var $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0;
 var $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0;
 var $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0;
 var $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0;
 var $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0;
 var $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0;
 var $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0;
 var $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0;
 var $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0;
 var $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0;
 var $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0;
 var $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0;
 var $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0;
 var $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0;
 var $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0;
 var $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0;
 var $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0;
 var $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0;
 var $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0;
 var $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0;
 var $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0;
 var $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0;
 var $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0;
 var $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0;
 var $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0;
 var $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0;
 var $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0;
 var $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0;
 var $832 = 0, $833 = 0, $834 = 0, $835 = 0, $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0;
 var $850 = 0, $851 = 0, $852 = 0, $853 = 0, $854 = 0, $855 = 0, $856 = 0, $857 = 0, $858 = 0, $859 = 0, $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0;
 var $869 = 0, $87 = 0, $870 = 0, $871 = 0, $872 = 0, $873 = 0, $874 = 0, $875 = 0, $876 = 0, $877 = 0, $878 = 0, $879 = 0, $88 = 0, $880 = 0, $881 = 0, $882 = 0, $883 = 0, $884 = 0, $885 = 0, $886 = 0;
 var $887 = 0, $888 = 0, $889 = 0, $89 = 0, $890 = 0, $891 = 0, $892 = 0, $893 = 0, $894 = 0, $895 = 0, $896 = 0, $897 = 0, $898 = 0, $899 = 0, $9 = 0, $90 = 0, $900 = 0, $901 = 0, $902 = 0, $903 = 0;
 var $904 = 0, $905 = 0, $906 = 0, $907 = 0, $908 = 0, $909 = 0, $91 = 0, $910 = 0, $911 = 0, $912 = 0, $913 = 0, $914 = 0, $915 = 0, $916 = 0, $917 = 0, $918 = 0, $919 = 0, $92 = 0, $920 = 0, $921 = 0;
 var $922 = 0, $923 = 0, $924 = 0, $925 = 0, $926 = 0, $927 = 0, $928 = 0, $929 = 0, $93 = 0, $930 = 0, $931 = 0, $932 = 0, $933 = 0, $934 = 0, $935 = 0, $936 = 0, $937 = 0, $938 = 0, $939 = 0, $94 = 0;
 var $940 = 0, $941 = 0, $942 = 0, $943 = 0, $944 = 0, $945 = 0, $946 = 0, $947 = 0, $948 = 0, $949 = 0, $95 = 0, $950 = 0, $951 = 0, $952 = 0, $953 = 0, $954 = 0, $955 = 0, $956 = 0, $957 = 0, $958 = 0;
 var $959 = 0, $96 = 0, $960 = 0, $961 = 0, $962 = 0, $963 = 0, $964 = 0, $965 = 0, $966 = 0, $967 = 0, $968 = 0, $969 = 0, $97 = 0, $970 = 0, $971 = 0, $972 = 0, $973 = 0, $974 = 0, $975 = 0, $976 = 0;
 var $977 = 0, $978 = 0, $979 = 0, $98 = 0, $980 = 0, $981 = 0, $982 = 0, $983 = 0, $984 = 0, $985 = 0, $986 = 0, $987 = 0, $988 = 0, $989 = 0, $99 = 0, $990 = 0, $991 = 0, $992 = 0, $993 = 0, $994 = 0;
 var $995 = 0, $996 = 0, $997 = 0, $998 = 0, $999 = 0, $div = 0, $div644 = 0, $div645 = 0, $div646 = 0, $div647 = 0, $div648 = 0, $div649 = 0, $div650 = 0, $div651 = 0, $div652 = 0, $div653 = 0, $div654 = 0, $div655 = 0, $div656 = 0, $div657 = 0;
 var $div658 = 0, $div659 = 0, $div660 = 0, $div661 = 0, $div662 = 0, $div663 = 0, $div664 = 0, $div665 = 0, $div666 = 0, $trunc = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($0)) + 36|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($0)) + 44|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ((($0)) + 40|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ((($12)) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ((($14)) + 4|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ((($0)) + 63|0);
 $18 = HEAP8[$17>>0]|0;
 $19 = $18&255;
 $20 = ((($10)) + 9|0);
 $21 = HEAP8[$20>>0]|0;
 $22 = $21&255;
 $23 = ($4|0)==(0);
 if ($23) {
  return;
 }
 $24 = ((($0)) + 20|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = HEAP32[$0>>2]|0;
 $27 = (($2) + 3)|0;
 $28 = (($27|0) / 4)&-1;
 $trunc = $2&255;
 $29 = ((($10)) + 28|0);
 $30 = ((($10)) + 32|0);
 $31 = ((($10)) + 29|0);
 $32 = ((($10)) + 33|0);
 $33 = ((($10)) + 30|0);
 $34 = ((($10)) + 34|0);
 $35 = ((($10)) + 31|0);
 $36 = ((($10)) + 35|0);
 $37 = ((($10)) + 12|0);
 $38 = ((($10)) + 16|0);
 $39 = ((($10)) + 20|0);
 $40 = ((($10)) + 24|0);
 $$0610671 = $26;$$0611670 = $25;$$in = $4;
 L4: while(1) {
  $41 = (($$in) + -1)|0;
  $trunc$clear = $trunc & 3;
  switch ($trunc$clear<<24>>24) {
  case 0:  {
   $$0632 = $28;$$1 = $$0610671;$$1612 = $$0611670;
   label = 4;
   break;
  }
  case 3:  {
   $$1633 = $28;$$2 = $$0610671;$$2613 = $$0611670;
   label = 15;
   break;
  }
  case 2:  {
   $$2634 = $28;$$3 = $$0610671;$$3614 = $$0611670;
   label = 26;
   break;
  }
  case 1:  {
   $$3635 = $28;$$4 = $$0610671;$$4615 = $$0611670;
   label = 37;
   break;
  }
  default: {
   label = 48;
   break L4;
  }
  }
  while(1) {
   if ((label|0) == 4) {
    label = 0;
    $42 = HEAP8[$$1>>0]|0;
    $43 = $42&255;
    $44 = (($16) + ($43<<2)|0);
    $45 = HEAP8[$44>>0]|0;
    $46 = $45&255;
    $47 = (((($16) + ($43<<2)|0)) + 1|0);
    $48 = HEAP8[$47>>0]|0;
    $49 = $48&255;
    $50 = (((($16) + ($43<<2)|0)) + 2|0);
    $51 = HEAP8[$50>>0]|0;
    $52 = $51&255;
    switch ($21<<24>>24) {
    case 1:  {
     $53 = HEAP8[$$1612>>0]|0;
     $54 = $53&255;
     $55 = HEAP8[$29>>0]|0;
     $56 = $55&255;
     $57 = (79212 + ($56<<2)|0);
     $58 = HEAP32[$57>>2]|0;
     $59 = HEAP32[$37>>2]|0;
     $60 = $59 & $54;
     $61 = HEAP8[$30>>0]|0;
     $62 = $61&255;
     $63 = $60 >>> $62;
     $64 = (($58) + ($63)|0);
     $65 = HEAP8[$64>>0]|0;
     $66 = HEAP8[$31>>0]|0;
     $67 = $66&255;
     $68 = (79212 + ($67<<2)|0);
     $69 = HEAP32[$68>>2]|0;
     $70 = HEAP32[$38>>2]|0;
     $71 = $70 & $54;
     $72 = HEAP8[$32>>0]|0;
     $73 = $72&255;
     $74 = $71 >>> $73;
     $75 = (($69) + ($74)|0);
     $76 = HEAP8[$75>>0]|0;
     $77 = HEAP8[$33>>0]|0;
     $78 = $77&255;
     $79 = (79212 + ($78<<2)|0);
     $80 = HEAP32[$79>>2]|0;
     $81 = HEAP32[$39>>2]|0;
     $82 = $81 & $54;
     $83 = HEAP8[$34>>0]|0;
     $84 = $83&255;
     $85 = $82 >>> $84;
     $86 = (($80) + ($85)|0);
     $87 = HEAP8[$86>>0]|0;
     $88 = HEAP8[$35>>0]|0;
     $89 = $88&255;
     $90 = (79212 + ($89<<2)|0);
     $91 = HEAP32[$90>>2]|0;
     $92 = HEAP32[$40>>2]|0;
     $93 = $92 & $54;
     $94 = HEAP8[$36>>0]|0;
     $95 = $94&255;
     $96 = $93 >>> $95;
     $97 = (($91) + ($96)|0);
     $98 = HEAP8[$97>>0]|0;
     $$0616$shrunk = $65;$$0620$shrunk = $76;$$0624$shrunk = $87;$$0628$shrunk = $98;
     break;
    }
    case 2:  {
     $99 = HEAP16[$$1612>>1]|0;
     $100 = $99&65535;
     $101 = HEAP8[$29>>0]|0;
     $102 = $101&255;
     $103 = (79212 + ($102<<2)|0);
     $104 = HEAP32[$103>>2]|0;
     $105 = HEAP32[$37>>2]|0;
     $106 = $105 & $100;
     $107 = HEAP8[$30>>0]|0;
     $108 = $107&255;
     $109 = $106 >>> $108;
     $110 = (($104) + ($109)|0);
     $111 = HEAP8[$110>>0]|0;
     $112 = HEAP8[$31>>0]|0;
     $113 = $112&255;
     $114 = (79212 + ($113<<2)|0);
     $115 = HEAP32[$114>>2]|0;
     $116 = HEAP32[$38>>2]|0;
     $117 = $116 & $100;
     $118 = HEAP8[$32>>0]|0;
     $119 = $118&255;
     $120 = $117 >>> $119;
     $121 = (($115) + ($120)|0);
     $122 = HEAP8[$121>>0]|0;
     $123 = HEAP8[$33>>0]|0;
     $124 = $123&255;
     $125 = (79212 + ($124<<2)|0);
     $126 = HEAP32[$125>>2]|0;
     $127 = HEAP32[$39>>2]|0;
     $128 = $127 & $100;
     $129 = HEAP8[$34>>0]|0;
     $130 = $129&255;
     $131 = $128 >>> $130;
     $132 = (($126) + ($131)|0);
     $133 = HEAP8[$132>>0]|0;
     $134 = HEAP8[$35>>0]|0;
     $135 = $134&255;
     $136 = (79212 + ($135<<2)|0);
     $137 = HEAP32[$136>>2]|0;
     $138 = HEAP32[$40>>2]|0;
     $139 = $138 & $100;
     $140 = HEAP8[$36>>0]|0;
     $141 = $140&255;
     $142 = $139 >>> $141;
     $143 = (($137) + ($142)|0);
     $144 = HEAP8[$143>>0]|0;
     $$0616$shrunk = $111;$$0620$shrunk = $122;$$0624$shrunk = $133;$$0628$shrunk = $144;
     break;
    }
    case 3:  {
     $145 = HEAP8[$30>>0]|0;
     $div658 = ($145&255) >>> 3;
     $146 = $div658&255;
     $147 = (($$1612) + ($146)|0);
     $148 = HEAP8[$147>>0]|0;
     $149 = HEAP8[$32>>0]|0;
     $div659 = ($149&255) >>> 3;
     $150 = $div659&255;
     $151 = (($$1612) + ($150)|0);
     $152 = HEAP8[$151>>0]|0;
     $153 = HEAP8[$34>>0]|0;
     $div660 = ($153&255) >>> 3;
     $154 = $div660&255;
     $155 = (($$1612) + ($154)|0);
     $156 = HEAP8[$155>>0]|0;
     $$0616$shrunk = $148;$$0620$shrunk = $152;$$0624$shrunk = $156;$$0628$shrunk = -1;
     break;
    }
    case 4:  {
     $157 = HEAP32[$$1612>>2]|0;
     $158 = HEAP8[$29>>0]|0;
     $159 = $158&255;
     $160 = (79212 + ($159<<2)|0);
     $161 = HEAP32[$160>>2]|0;
     $162 = HEAP32[$37>>2]|0;
     $163 = $162 & $157;
     $164 = HEAP8[$30>>0]|0;
     $165 = $164&255;
     $166 = $163 >>> $165;
     $167 = (($161) + ($166)|0);
     $168 = HEAP8[$167>>0]|0;
     $169 = HEAP8[$31>>0]|0;
     $170 = $169&255;
     $171 = (79212 + ($170<<2)|0);
     $172 = HEAP32[$171>>2]|0;
     $173 = HEAP32[$38>>2]|0;
     $174 = $173 & $157;
     $175 = HEAP8[$32>>0]|0;
     $176 = $175&255;
     $177 = $174 >>> $176;
     $178 = (($172) + ($177)|0);
     $179 = HEAP8[$178>>0]|0;
     $180 = HEAP8[$33>>0]|0;
     $181 = $180&255;
     $182 = (79212 + ($181<<2)|0);
     $183 = HEAP32[$182>>2]|0;
     $184 = HEAP32[$39>>2]|0;
     $185 = $184 & $157;
     $186 = HEAP8[$34>>0]|0;
     $187 = $186&255;
     $188 = $185 >>> $187;
     $189 = (($183) + ($188)|0);
     $190 = HEAP8[$189>>0]|0;
     $191 = HEAP8[$35>>0]|0;
     $192 = $191&255;
     $193 = (79212 + ($192<<2)|0);
     $194 = HEAP32[$193>>2]|0;
     $195 = HEAP32[$40>>2]|0;
     $196 = $195 & $157;
     $197 = HEAP8[$36>>0]|0;
     $198 = $197&255;
     $199 = $196 >>> $198;
     $200 = (($194) + ($199)|0);
     $201 = HEAP8[$200>>0]|0;
     $$0616$shrunk = $168;$$0620$shrunk = $179;$$0624$shrunk = $190;$$0628$shrunk = $201;
     break;
    }
    default: {
     $$0616$shrunk = 0;$$0620$shrunk = 0;$$0624$shrunk = 0;$$0628$shrunk = 0;
    }
    }
    $$0616 = $$0616$shrunk&255;
    $$0620 = $$0620$shrunk&255;
    $$0624 = $$0624$shrunk&255;
    $$0628 = $$0628$shrunk&255;
    $202 = (($46) - ($$0616))|0;
    $203 = Math_imul($202, $19)|0;
    $204 = (($203>>>0) / 255)&-1;
    $205 = (($204) + ($$0616))|0;
    $206 = (($49) - ($$0620))|0;
    $207 = Math_imul($206, $19)|0;
    $208 = (($207>>>0) / 255)&-1;
    $209 = (($208) + ($$0620))|0;
    $210 = (($52) - ($$0624))|0;
    $211 = Math_imul($210, $19)|0;
    $212 = (($211>>>0) / 255)&-1;
    $213 = (($212) + ($$0624))|0;
    $214 = (($$0628) + ($19))|0;
    $215 = Math_imul($$0628, $19)|0;
    $216 = (($215>>>0) / 255)&-1;
    $217 = (($214) - ($216))|0;
    switch ($21<<24>>24) {
    case 1:  {
     $218 = HEAP8[$29>>0]|0;
     $219 = $218&255;
     $220 = $205 >>> $219;
     $221 = HEAP8[$30>>0]|0;
     $222 = $221&255;
     $223 = $220 << $222;
     $224 = HEAP8[$31>>0]|0;
     $225 = $224&255;
     $226 = $209 >>> $225;
     $227 = HEAP8[$32>>0]|0;
     $228 = $227&255;
     $229 = $226 << $228;
     $230 = $229 | $223;
     $231 = HEAP8[$33>>0]|0;
     $232 = $231&255;
     $233 = $213 >>> $232;
     $234 = HEAP8[$34>>0]|0;
     $235 = $234&255;
     $236 = $233 << $235;
     $237 = $230 | $236;
     $238 = HEAP8[$35>>0]|0;
     $239 = $238&255;
     $240 = $217 >>> $239;
     $241 = HEAP8[$36>>0]|0;
     $242 = $241&255;
     $243 = $240 << $242;
     $244 = $237 | $243;
     $245 = $244&255;
     HEAP8[$$1612>>0] = $245;
     break;
    }
    case 2:  {
     $246 = HEAP8[$29>>0]|0;
     $247 = $246&255;
     $248 = $205 >>> $247;
     $249 = HEAP8[$30>>0]|0;
     $250 = $249&255;
     $251 = $248 << $250;
     $252 = HEAP8[$31>>0]|0;
     $253 = $252&255;
     $254 = $209 >>> $253;
     $255 = HEAP8[$32>>0]|0;
     $256 = $255&255;
     $257 = $254 << $256;
     $258 = $257 | $251;
     $259 = HEAP8[$33>>0]|0;
     $260 = $259&255;
     $261 = $213 >>> $260;
     $262 = HEAP8[$34>>0]|0;
     $263 = $262&255;
     $264 = $261 << $263;
     $265 = $258 | $264;
     $266 = HEAP8[$35>>0]|0;
     $267 = $266&255;
     $268 = $217 >>> $267;
     $269 = HEAP8[$36>>0]|0;
     $270 = $269&255;
     $271 = $268 << $270;
     $272 = $265 | $271;
     $273 = $272&65535;
     HEAP16[$$1612>>1] = $273;
     break;
    }
    case 3:  {
     $274 = $205&255;
     $275 = HEAP8[$30>>0]|0;
     $div655 = ($275&255) >>> 3;
     $276 = $div655&255;
     $277 = (($$1612) + ($276)|0);
     HEAP8[$277>>0] = $274;
     $278 = $209&255;
     $279 = HEAP8[$32>>0]|0;
     $div656 = ($279&255) >>> 3;
     $280 = $div656&255;
     $281 = (($$1612) + ($280)|0);
     HEAP8[$281>>0] = $278;
     $282 = $213&255;
     $283 = HEAP8[$34>>0]|0;
     $div657 = ($283&255) >>> 3;
     $284 = $div657&255;
     $285 = (($$1612) + ($284)|0);
     HEAP8[$285>>0] = $282;
     break;
    }
    case 4:  {
     $286 = HEAP8[$29>>0]|0;
     $287 = $286&255;
     $288 = $205 >>> $287;
     $289 = HEAP8[$30>>0]|0;
     $290 = $289&255;
     $291 = $288 << $290;
     $292 = HEAP8[$31>>0]|0;
     $293 = $292&255;
     $294 = $209 >>> $293;
     $295 = HEAP8[$32>>0]|0;
     $296 = $295&255;
     $297 = $294 << $296;
     $298 = $297 | $291;
     $299 = HEAP8[$33>>0]|0;
     $300 = $299&255;
     $301 = $213 >>> $300;
     $302 = HEAP8[$34>>0]|0;
     $303 = $302&255;
     $304 = $301 << $303;
     $305 = $298 | $304;
     $306 = HEAP8[$35>>0]|0;
     $307 = $306&255;
     $308 = $217 >>> $307;
     $309 = HEAP8[$36>>0]|0;
     $310 = $309&255;
     $311 = $308 << $310;
     $312 = $305 | $311;
     HEAP32[$$1612>>2] = $312;
     break;
    }
    default: {
    }
    }
    $313 = ((($$1)) + 1|0);
    $314 = (($$1612) + ($22)|0);
    $$1633 = $$0632;$$2 = $313;$$2613 = $314;
    label = 15;
    continue;
   }
   else if ((label|0) == 15) {
    label = 0;
    $315 = HEAP8[$$2>>0]|0;
    $316 = $315&255;
    $317 = (($16) + ($316<<2)|0);
    $318 = HEAP8[$317>>0]|0;
    $319 = $318&255;
    $320 = (((($16) + ($316<<2)|0)) + 1|0);
    $321 = HEAP8[$320>>0]|0;
    $322 = $321&255;
    $323 = (((($16) + ($316<<2)|0)) + 2|0);
    $324 = HEAP8[$323>>0]|0;
    $325 = $324&255;
    switch ($21<<24>>24) {
    case 1:  {
     $326 = HEAP8[$$2613>>0]|0;
     $327 = $326&255;
     $328 = HEAP8[$29>>0]|0;
     $329 = $328&255;
     $330 = (79212 + ($329<<2)|0);
     $331 = HEAP32[$330>>2]|0;
     $332 = HEAP32[$37>>2]|0;
     $333 = $332 & $327;
     $334 = HEAP8[$30>>0]|0;
     $335 = $334&255;
     $336 = $333 >>> $335;
     $337 = (($331) + ($336)|0);
     $338 = HEAP8[$337>>0]|0;
     $339 = HEAP8[$31>>0]|0;
     $340 = $339&255;
     $341 = (79212 + ($340<<2)|0);
     $342 = HEAP32[$341>>2]|0;
     $343 = HEAP32[$38>>2]|0;
     $344 = $343 & $327;
     $345 = HEAP8[$32>>0]|0;
     $346 = $345&255;
     $347 = $344 >>> $346;
     $348 = (($342) + ($347)|0);
     $349 = HEAP8[$348>>0]|0;
     $350 = HEAP8[$33>>0]|0;
     $351 = $350&255;
     $352 = (79212 + ($351<<2)|0);
     $353 = HEAP32[$352>>2]|0;
     $354 = HEAP32[$39>>2]|0;
     $355 = $354 & $327;
     $356 = HEAP8[$34>>0]|0;
     $357 = $356&255;
     $358 = $355 >>> $357;
     $359 = (($353) + ($358)|0);
     $360 = HEAP8[$359>>0]|0;
     $361 = HEAP8[$35>>0]|0;
     $362 = $361&255;
     $363 = (79212 + ($362<<2)|0);
     $364 = HEAP32[$363>>2]|0;
     $365 = HEAP32[$40>>2]|0;
     $366 = $365 & $327;
     $367 = HEAP8[$36>>0]|0;
     $368 = $367&255;
     $369 = $366 >>> $368;
     $370 = (($364) + ($369)|0);
     $371 = HEAP8[$370>>0]|0;
     $$1617$shrunk = $338;$$1621$shrunk = $349;$$1625$shrunk = $360;$$1629$shrunk = $371;
     break;
    }
    case 2:  {
     $372 = HEAP16[$$2613>>1]|0;
     $373 = $372&65535;
     $374 = HEAP8[$29>>0]|0;
     $375 = $374&255;
     $376 = (79212 + ($375<<2)|0);
     $377 = HEAP32[$376>>2]|0;
     $378 = HEAP32[$37>>2]|0;
     $379 = $378 & $373;
     $380 = HEAP8[$30>>0]|0;
     $381 = $380&255;
     $382 = $379 >>> $381;
     $383 = (($377) + ($382)|0);
     $384 = HEAP8[$383>>0]|0;
     $385 = HEAP8[$31>>0]|0;
     $386 = $385&255;
     $387 = (79212 + ($386<<2)|0);
     $388 = HEAP32[$387>>2]|0;
     $389 = HEAP32[$38>>2]|0;
     $390 = $389 & $373;
     $391 = HEAP8[$32>>0]|0;
     $392 = $391&255;
     $393 = $390 >>> $392;
     $394 = (($388) + ($393)|0);
     $395 = HEAP8[$394>>0]|0;
     $396 = HEAP8[$33>>0]|0;
     $397 = $396&255;
     $398 = (79212 + ($397<<2)|0);
     $399 = HEAP32[$398>>2]|0;
     $400 = HEAP32[$39>>2]|0;
     $401 = $400 & $373;
     $402 = HEAP8[$34>>0]|0;
     $403 = $402&255;
     $404 = $401 >>> $403;
     $405 = (($399) + ($404)|0);
     $406 = HEAP8[$405>>0]|0;
     $407 = HEAP8[$35>>0]|0;
     $408 = $407&255;
     $409 = (79212 + ($408<<2)|0);
     $410 = HEAP32[$409>>2]|0;
     $411 = HEAP32[$40>>2]|0;
     $412 = $411 & $373;
     $413 = HEAP8[$36>>0]|0;
     $414 = $413&255;
     $415 = $412 >>> $414;
     $416 = (($410) + ($415)|0);
     $417 = HEAP8[$416>>0]|0;
     $$1617$shrunk = $384;$$1621$shrunk = $395;$$1625$shrunk = $406;$$1629$shrunk = $417;
     break;
    }
    case 3:  {
     $418 = HEAP8[$30>>0]|0;
     $div652 = ($418&255) >>> 3;
     $419 = $div652&255;
     $420 = (($$2613) + ($419)|0);
     $421 = HEAP8[$420>>0]|0;
     $422 = HEAP8[$32>>0]|0;
     $div653 = ($422&255) >>> 3;
     $423 = $div653&255;
     $424 = (($$2613) + ($423)|0);
     $425 = HEAP8[$424>>0]|0;
     $426 = HEAP8[$34>>0]|0;
     $div654 = ($426&255) >>> 3;
     $427 = $div654&255;
     $428 = (($$2613) + ($427)|0);
     $429 = HEAP8[$428>>0]|0;
     $$1617$shrunk = $421;$$1621$shrunk = $425;$$1625$shrunk = $429;$$1629$shrunk = -1;
     break;
    }
    case 4:  {
     $430 = HEAP32[$$2613>>2]|0;
     $431 = HEAP8[$29>>0]|0;
     $432 = $431&255;
     $433 = (79212 + ($432<<2)|0);
     $434 = HEAP32[$433>>2]|0;
     $435 = HEAP32[$37>>2]|0;
     $436 = $435 & $430;
     $437 = HEAP8[$30>>0]|0;
     $438 = $437&255;
     $439 = $436 >>> $438;
     $440 = (($434) + ($439)|0);
     $441 = HEAP8[$440>>0]|0;
     $442 = HEAP8[$31>>0]|0;
     $443 = $442&255;
     $444 = (79212 + ($443<<2)|0);
     $445 = HEAP32[$444>>2]|0;
     $446 = HEAP32[$38>>2]|0;
     $447 = $446 & $430;
     $448 = HEAP8[$32>>0]|0;
     $449 = $448&255;
     $450 = $447 >>> $449;
     $451 = (($445) + ($450)|0);
     $452 = HEAP8[$451>>0]|0;
     $453 = HEAP8[$33>>0]|0;
     $454 = $453&255;
     $455 = (79212 + ($454<<2)|0);
     $456 = HEAP32[$455>>2]|0;
     $457 = HEAP32[$39>>2]|0;
     $458 = $457 & $430;
     $459 = HEAP8[$34>>0]|0;
     $460 = $459&255;
     $461 = $458 >>> $460;
     $462 = (($456) + ($461)|0);
     $463 = HEAP8[$462>>0]|0;
     $464 = HEAP8[$35>>0]|0;
     $465 = $464&255;
     $466 = (79212 + ($465<<2)|0);
     $467 = HEAP32[$466>>2]|0;
     $468 = HEAP32[$40>>2]|0;
     $469 = $468 & $430;
     $470 = HEAP8[$36>>0]|0;
     $471 = $470&255;
     $472 = $469 >>> $471;
     $473 = (($467) + ($472)|0);
     $474 = HEAP8[$473>>0]|0;
     $$1617$shrunk = $441;$$1621$shrunk = $452;$$1625$shrunk = $463;$$1629$shrunk = $474;
     break;
    }
    default: {
     $$1617$shrunk = 0;$$1621$shrunk = 0;$$1625$shrunk = 0;$$1629$shrunk = 0;
    }
    }
    $$1617 = $$1617$shrunk&255;
    $$1621 = $$1621$shrunk&255;
    $$1625 = $$1625$shrunk&255;
    $$1629 = $$1629$shrunk&255;
    $475 = (($319) - ($$1617))|0;
    $476 = Math_imul($475, $19)|0;
    $477 = (($476>>>0) / 255)&-1;
    $478 = (($477) + ($$1617))|0;
    $479 = (($322) - ($$1621))|0;
    $480 = Math_imul($479, $19)|0;
    $481 = (($480>>>0) / 255)&-1;
    $482 = (($481) + ($$1621))|0;
    $483 = (($325) - ($$1625))|0;
    $484 = Math_imul($483, $19)|0;
    $485 = (($484>>>0) / 255)&-1;
    $486 = (($485) + ($$1625))|0;
    $487 = (($$1629) + ($19))|0;
    $488 = Math_imul($$1629, $19)|0;
    $489 = (($488>>>0) / 255)&-1;
    $490 = (($487) - ($489))|0;
    switch ($21<<24>>24) {
    case 1:  {
     $491 = HEAP8[$29>>0]|0;
     $492 = $491&255;
     $493 = $478 >>> $492;
     $494 = HEAP8[$30>>0]|0;
     $495 = $494&255;
     $496 = $493 << $495;
     $497 = HEAP8[$31>>0]|0;
     $498 = $497&255;
     $499 = $482 >>> $498;
     $500 = HEAP8[$32>>0]|0;
     $501 = $500&255;
     $502 = $499 << $501;
     $503 = $502 | $496;
     $504 = HEAP8[$33>>0]|0;
     $505 = $504&255;
     $506 = $486 >>> $505;
     $507 = HEAP8[$34>>0]|0;
     $508 = $507&255;
     $509 = $506 << $508;
     $510 = $503 | $509;
     $511 = HEAP8[$35>>0]|0;
     $512 = $511&255;
     $513 = $490 >>> $512;
     $514 = HEAP8[$36>>0]|0;
     $515 = $514&255;
     $516 = $513 << $515;
     $517 = $510 | $516;
     $518 = $517&255;
     HEAP8[$$2613>>0] = $518;
     break;
    }
    case 2:  {
     $519 = HEAP8[$29>>0]|0;
     $520 = $519&255;
     $521 = $478 >>> $520;
     $522 = HEAP8[$30>>0]|0;
     $523 = $522&255;
     $524 = $521 << $523;
     $525 = HEAP8[$31>>0]|0;
     $526 = $525&255;
     $527 = $482 >>> $526;
     $528 = HEAP8[$32>>0]|0;
     $529 = $528&255;
     $530 = $527 << $529;
     $531 = $530 | $524;
     $532 = HEAP8[$33>>0]|0;
     $533 = $532&255;
     $534 = $486 >>> $533;
     $535 = HEAP8[$34>>0]|0;
     $536 = $535&255;
     $537 = $534 << $536;
     $538 = $531 | $537;
     $539 = HEAP8[$35>>0]|0;
     $540 = $539&255;
     $541 = $490 >>> $540;
     $542 = HEAP8[$36>>0]|0;
     $543 = $542&255;
     $544 = $541 << $543;
     $545 = $538 | $544;
     $546 = $545&65535;
     HEAP16[$$2613>>1] = $546;
     break;
    }
    case 3:  {
     $547 = $478&255;
     $548 = HEAP8[$30>>0]|0;
     $div649 = ($548&255) >>> 3;
     $549 = $div649&255;
     $550 = (($$2613) + ($549)|0);
     HEAP8[$550>>0] = $547;
     $551 = $482&255;
     $552 = HEAP8[$32>>0]|0;
     $div650 = ($552&255) >>> 3;
     $553 = $div650&255;
     $554 = (($$2613) + ($553)|0);
     HEAP8[$554>>0] = $551;
     $555 = $486&255;
     $556 = HEAP8[$34>>0]|0;
     $div651 = ($556&255) >>> 3;
     $557 = $div651&255;
     $558 = (($$2613) + ($557)|0);
     HEAP8[$558>>0] = $555;
     break;
    }
    case 4:  {
     $559 = HEAP8[$29>>0]|0;
     $560 = $559&255;
     $561 = $478 >>> $560;
     $562 = HEAP8[$30>>0]|0;
     $563 = $562&255;
     $564 = $561 << $563;
     $565 = HEAP8[$31>>0]|0;
     $566 = $565&255;
     $567 = $482 >>> $566;
     $568 = HEAP8[$32>>0]|0;
     $569 = $568&255;
     $570 = $567 << $569;
     $571 = $570 | $564;
     $572 = HEAP8[$33>>0]|0;
     $573 = $572&255;
     $574 = $486 >>> $573;
     $575 = HEAP8[$34>>0]|0;
     $576 = $575&255;
     $577 = $574 << $576;
     $578 = $571 | $577;
     $579 = HEAP8[$35>>0]|0;
     $580 = $579&255;
     $581 = $490 >>> $580;
     $582 = HEAP8[$36>>0]|0;
     $583 = $582&255;
     $584 = $581 << $583;
     $585 = $578 | $584;
     HEAP32[$$2613>>2] = $585;
     break;
    }
    default: {
    }
    }
    $586 = ((($$2)) + 1|0);
    $587 = (($$2613) + ($22)|0);
    $$2634 = $$1633;$$3 = $586;$$3614 = $587;
    label = 26;
    continue;
   }
   else if ((label|0) == 26) {
    label = 0;
    $588 = HEAP8[$$3>>0]|0;
    $589 = $588&255;
    $590 = (($16) + ($589<<2)|0);
    $591 = HEAP8[$590>>0]|0;
    $592 = $591&255;
    $593 = (((($16) + ($589<<2)|0)) + 1|0);
    $594 = HEAP8[$593>>0]|0;
    $595 = $594&255;
    $596 = (((($16) + ($589<<2)|0)) + 2|0);
    $597 = HEAP8[$596>>0]|0;
    $598 = $597&255;
    switch ($21<<24>>24) {
    case 1:  {
     $599 = HEAP8[$$3614>>0]|0;
     $600 = $599&255;
     $601 = HEAP8[$29>>0]|0;
     $602 = $601&255;
     $603 = (79212 + ($602<<2)|0);
     $604 = HEAP32[$603>>2]|0;
     $605 = HEAP32[$37>>2]|0;
     $606 = $605 & $600;
     $607 = HEAP8[$30>>0]|0;
     $608 = $607&255;
     $609 = $606 >>> $608;
     $610 = (($604) + ($609)|0);
     $611 = HEAP8[$610>>0]|0;
     $612 = HEAP8[$31>>0]|0;
     $613 = $612&255;
     $614 = (79212 + ($613<<2)|0);
     $615 = HEAP32[$614>>2]|0;
     $616 = HEAP32[$38>>2]|0;
     $617 = $616 & $600;
     $618 = HEAP8[$32>>0]|0;
     $619 = $618&255;
     $620 = $617 >>> $619;
     $621 = (($615) + ($620)|0);
     $622 = HEAP8[$621>>0]|0;
     $623 = HEAP8[$33>>0]|0;
     $624 = $623&255;
     $625 = (79212 + ($624<<2)|0);
     $626 = HEAP32[$625>>2]|0;
     $627 = HEAP32[$39>>2]|0;
     $628 = $627 & $600;
     $629 = HEAP8[$34>>0]|0;
     $630 = $629&255;
     $631 = $628 >>> $630;
     $632 = (($626) + ($631)|0);
     $633 = HEAP8[$632>>0]|0;
     $634 = HEAP8[$35>>0]|0;
     $635 = $634&255;
     $636 = (79212 + ($635<<2)|0);
     $637 = HEAP32[$636>>2]|0;
     $638 = HEAP32[$40>>2]|0;
     $639 = $638 & $600;
     $640 = HEAP8[$36>>0]|0;
     $641 = $640&255;
     $642 = $639 >>> $641;
     $643 = (($637) + ($642)|0);
     $644 = HEAP8[$643>>0]|0;
     $$2618$shrunk = $611;$$2622$shrunk = $622;$$2626$shrunk = $633;$$2630$shrunk = $644;
     break;
    }
    case 2:  {
     $645 = HEAP16[$$3614>>1]|0;
     $646 = $645&65535;
     $647 = HEAP8[$29>>0]|0;
     $648 = $647&255;
     $649 = (79212 + ($648<<2)|0);
     $650 = HEAP32[$649>>2]|0;
     $651 = HEAP32[$37>>2]|0;
     $652 = $651 & $646;
     $653 = HEAP8[$30>>0]|0;
     $654 = $653&255;
     $655 = $652 >>> $654;
     $656 = (($650) + ($655)|0);
     $657 = HEAP8[$656>>0]|0;
     $658 = HEAP8[$31>>0]|0;
     $659 = $658&255;
     $660 = (79212 + ($659<<2)|0);
     $661 = HEAP32[$660>>2]|0;
     $662 = HEAP32[$38>>2]|0;
     $663 = $662 & $646;
     $664 = HEAP8[$32>>0]|0;
     $665 = $664&255;
     $666 = $663 >>> $665;
     $667 = (($661) + ($666)|0);
     $668 = HEAP8[$667>>0]|0;
     $669 = HEAP8[$33>>0]|0;
     $670 = $669&255;
     $671 = (79212 + ($670<<2)|0);
     $672 = HEAP32[$671>>2]|0;
     $673 = HEAP32[$39>>2]|0;
     $674 = $673 & $646;
     $675 = HEAP8[$34>>0]|0;
     $676 = $675&255;
     $677 = $674 >>> $676;
     $678 = (($672) + ($677)|0);
     $679 = HEAP8[$678>>0]|0;
     $680 = HEAP8[$35>>0]|0;
     $681 = $680&255;
     $682 = (79212 + ($681<<2)|0);
     $683 = HEAP32[$682>>2]|0;
     $684 = HEAP32[$40>>2]|0;
     $685 = $684 & $646;
     $686 = HEAP8[$36>>0]|0;
     $687 = $686&255;
     $688 = $685 >>> $687;
     $689 = (($683) + ($688)|0);
     $690 = HEAP8[$689>>0]|0;
     $$2618$shrunk = $657;$$2622$shrunk = $668;$$2626$shrunk = $679;$$2630$shrunk = $690;
     break;
    }
    case 3:  {
     $691 = HEAP8[$30>>0]|0;
     $div646 = ($691&255) >>> 3;
     $692 = $div646&255;
     $693 = (($$3614) + ($692)|0);
     $694 = HEAP8[$693>>0]|0;
     $695 = HEAP8[$32>>0]|0;
     $div647 = ($695&255) >>> 3;
     $696 = $div647&255;
     $697 = (($$3614) + ($696)|0);
     $698 = HEAP8[$697>>0]|0;
     $699 = HEAP8[$34>>0]|0;
     $div648 = ($699&255) >>> 3;
     $700 = $div648&255;
     $701 = (($$3614) + ($700)|0);
     $702 = HEAP8[$701>>0]|0;
     $$2618$shrunk = $694;$$2622$shrunk = $698;$$2626$shrunk = $702;$$2630$shrunk = -1;
     break;
    }
    case 4:  {
     $703 = HEAP32[$$3614>>2]|0;
     $704 = HEAP8[$29>>0]|0;
     $705 = $704&255;
     $706 = (79212 + ($705<<2)|0);
     $707 = HEAP32[$706>>2]|0;
     $708 = HEAP32[$37>>2]|0;
     $709 = $708 & $703;
     $710 = HEAP8[$30>>0]|0;
     $711 = $710&255;
     $712 = $709 >>> $711;
     $713 = (($707) + ($712)|0);
     $714 = HEAP8[$713>>0]|0;
     $715 = HEAP8[$31>>0]|0;
     $716 = $715&255;
     $717 = (79212 + ($716<<2)|0);
     $718 = HEAP32[$717>>2]|0;
     $719 = HEAP32[$38>>2]|0;
     $720 = $719 & $703;
     $721 = HEAP8[$32>>0]|0;
     $722 = $721&255;
     $723 = $720 >>> $722;
     $724 = (($718) + ($723)|0);
     $725 = HEAP8[$724>>0]|0;
     $726 = HEAP8[$33>>0]|0;
     $727 = $726&255;
     $728 = (79212 + ($727<<2)|0);
     $729 = HEAP32[$728>>2]|0;
     $730 = HEAP32[$39>>2]|0;
     $731 = $730 & $703;
     $732 = HEAP8[$34>>0]|0;
     $733 = $732&255;
     $734 = $731 >>> $733;
     $735 = (($729) + ($734)|0);
     $736 = HEAP8[$735>>0]|0;
     $737 = HEAP8[$35>>0]|0;
     $738 = $737&255;
     $739 = (79212 + ($738<<2)|0);
     $740 = HEAP32[$739>>2]|0;
     $741 = HEAP32[$40>>2]|0;
     $742 = $741 & $703;
     $743 = HEAP8[$36>>0]|0;
     $744 = $743&255;
     $745 = $742 >>> $744;
     $746 = (($740) + ($745)|0);
     $747 = HEAP8[$746>>0]|0;
     $$2618$shrunk = $714;$$2622$shrunk = $725;$$2626$shrunk = $736;$$2630$shrunk = $747;
     break;
    }
    default: {
     $$2618$shrunk = 0;$$2622$shrunk = 0;$$2626$shrunk = 0;$$2630$shrunk = 0;
    }
    }
    $$2618 = $$2618$shrunk&255;
    $$2622 = $$2622$shrunk&255;
    $$2626 = $$2626$shrunk&255;
    $$2630 = $$2630$shrunk&255;
    $748 = (($592) - ($$2618))|0;
    $749 = Math_imul($748, $19)|0;
    $750 = (($749>>>0) / 255)&-1;
    $751 = (($750) + ($$2618))|0;
    $752 = (($595) - ($$2622))|0;
    $753 = Math_imul($752, $19)|0;
    $754 = (($753>>>0) / 255)&-1;
    $755 = (($754) + ($$2622))|0;
    $756 = (($598) - ($$2626))|0;
    $757 = Math_imul($756, $19)|0;
    $758 = (($757>>>0) / 255)&-1;
    $759 = (($758) + ($$2626))|0;
    $760 = (($$2630) + ($19))|0;
    $761 = Math_imul($$2630, $19)|0;
    $762 = (($761>>>0) / 255)&-1;
    $763 = (($760) - ($762))|0;
    switch ($21<<24>>24) {
    case 1:  {
     $764 = HEAP8[$29>>0]|0;
     $765 = $764&255;
     $766 = $751 >>> $765;
     $767 = HEAP8[$30>>0]|0;
     $768 = $767&255;
     $769 = $766 << $768;
     $770 = HEAP8[$31>>0]|0;
     $771 = $770&255;
     $772 = $755 >>> $771;
     $773 = HEAP8[$32>>0]|0;
     $774 = $773&255;
     $775 = $772 << $774;
     $776 = $775 | $769;
     $777 = HEAP8[$33>>0]|0;
     $778 = $777&255;
     $779 = $759 >>> $778;
     $780 = HEAP8[$34>>0]|0;
     $781 = $780&255;
     $782 = $779 << $781;
     $783 = $776 | $782;
     $784 = HEAP8[$35>>0]|0;
     $785 = $784&255;
     $786 = $763 >>> $785;
     $787 = HEAP8[$36>>0]|0;
     $788 = $787&255;
     $789 = $786 << $788;
     $790 = $783 | $789;
     $791 = $790&255;
     HEAP8[$$3614>>0] = $791;
     break;
    }
    case 2:  {
     $792 = HEAP8[$29>>0]|0;
     $793 = $792&255;
     $794 = $751 >>> $793;
     $795 = HEAP8[$30>>0]|0;
     $796 = $795&255;
     $797 = $794 << $796;
     $798 = HEAP8[$31>>0]|0;
     $799 = $798&255;
     $800 = $755 >>> $799;
     $801 = HEAP8[$32>>0]|0;
     $802 = $801&255;
     $803 = $800 << $802;
     $804 = $803 | $797;
     $805 = HEAP8[$33>>0]|0;
     $806 = $805&255;
     $807 = $759 >>> $806;
     $808 = HEAP8[$34>>0]|0;
     $809 = $808&255;
     $810 = $807 << $809;
     $811 = $804 | $810;
     $812 = HEAP8[$35>>0]|0;
     $813 = $812&255;
     $814 = $763 >>> $813;
     $815 = HEAP8[$36>>0]|0;
     $816 = $815&255;
     $817 = $814 << $816;
     $818 = $811 | $817;
     $819 = $818&65535;
     HEAP16[$$3614>>1] = $819;
     break;
    }
    case 3:  {
     $820 = $751&255;
     $821 = HEAP8[$30>>0]|0;
     $div = ($821&255) >>> 3;
     $822 = $div&255;
     $823 = (($$3614) + ($822)|0);
     HEAP8[$823>>0] = $820;
     $824 = $755&255;
     $825 = HEAP8[$32>>0]|0;
     $div644 = ($825&255) >>> 3;
     $826 = $div644&255;
     $827 = (($$3614) + ($826)|0);
     HEAP8[$827>>0] = $824;
     $828 = $759&255;
     $829 = HEAP8[$34>>0]|0;
     $div645 = ($829&255) >>> 3;
     $830 = $div645&255;
     $831 = (($$3614) + ($830)|0);
     HEAP8[$831>>0] = $828;
     break;
    }
    case 4:  {
     $832 = HEAP8[$29>>0]|0;
     $833 = $832&255;
     $834 = $751 >>> $833;
     $835 = HEAP8[$30>>0]|0;
     $836 = $835&255;
     $837 = $834 << $836;
     $838 = HEAP8[$31>>0]|0;
     $839 = $838&255;
     $840 = $755 >>> $839;
     $841 = HEAP8[$32>>0]|0;
     $842 = $841&255;
     $843 = $840 << $842;
     $844 = $843 | $837;
     $845 = HEAP8[$33>>0]|0;
     $846 = $845&255;
     $847 = $759 >>> $846;
     $848 = HEAP8[$34>>0]|0;
     $849 = $848&255;
     $850 = $847 << $849;
     $851 = $844 | $850;
     $852 = HEAP8[$35>>0]|0;
     $853 = $852&255;
     $854 = $763 >>> $853;
     $855 = HEAP8[$36>>0]|0;
     $856 = $855&255;
     $857 = $854 << $856;
     $858 = $851 | $857;
     HEAP32[$$3614>>2] = $858;
     break;
    }
    default: {
    }
    }
    $859 = ((($$3)) + 1|0);
    $860 = (($$3614) + ($22)|0);
    $$3635 = $$2634;$$4 = $859;$$4615 = $860;
    label = 37;
    continue;
   }
   else if ((label|0) == 37) {
    label = 0;
    $861 = HEAP8[$$4>>0]|0;
    $862 = $861&255;
    $863 = (($16) + ($862<<2)|0);
    $864 = HEAP8[$863>>0]|0;
    $865 = $864&255;
    $866 = (((($16) + ($862<<2)|0)) + 1|0);
    $867 = HEAP8[$866>>0]|0;
    $868 = $867&255;
    $869 = (((($16) + ($862<<2)|0)) + 2|0);
    $870 = HEAP8[$869>>0]|0;
    $871 = $870&255;
    switch ($21<<24>>24) {
    case 1:  {
     $872 = HEAP8[$$4615>>0]|0;
     $873 = $872&255;
     $874 = HEAP8[$29>>0]|0;
     $875 = $874&255;
     $876 = (79212 + ($875<<2)|0);
     $877 = HEAP32[$876>>2]|0;
     $878 = HEAP32[$37>>2]|0;
     $879 = $878 & $873;
     $880 = HEAP8[$30>>0]|0;
     $881 = $880&255;
     $882 = $879 >>> $881;
     $883 = (($877) + ($882)|0);
     $884 = HEAP8[$883>>0]|0;
     $885 = HEAP8[$31>>0]|0;
     $886 = $885&255;
     $887 = (79212 + ($886<<2)|0);
     $888 = HEAP32[$887>>2]|0;
     $889 = HEAP32[$38>>2]|0;
     $890 = $889 & $873;
     $891 = HEAP8[$32>>0]|0;
     $892 = $891&255;
     $893 = $890 >>> $892;
     $894 = (($888) + ($893)|0);
     $895 = HEAP8[$894>>0]|0;
     $896 = HEAP8[$33>>0]|0;
     $897 = $896&255;
     $898 = (79212 + ($897<<2)|0);
     $899 = HEAP32[$898>>2]|0;
     $900 = HEAP32[$39>>2]|0;
     $901 = $900 & $873;
     $902 = HEAP8[$34>>0]|0;
     $903 = $902&255;
     $904 = $901 >>> $903;
     $905 = (($899) + ($904)|0);
     $906 = HEAP8[$905>>0]|0;
     $907 = HEAP8[$35>>0]|0;
     $908 = $907&255;
     $909 = (79212 + ($908<<2)|0);
     $910 = HEAP32[$909>>2]|0;
     $911 = HEAP32[$40>>2]|0;
     $912 = $911 & $873;
     $913 = HEAP8[$36>>0]|0;
     $914 = $913&255;
     $915 = $912 >>> $914;
     $916 = (($910) + ($915)|0);
     $917 = HEAP8[$916>>0]|0;
     $$3619$shrunk = $884;$$3623$shrunk = $895;$$3627$shrunk = $906;$$3631$shrunk = $917;
     break;
    }
    case 2:  {
     $918 = HEAP16[$$4615>>1]|0;
     $919 = $918&65535;
     $920 = HEAP8[$29>>0]|0;
     $921 = $920&255;
     $922 = (79212 + ($921<<2)|0);
     $923 = HEAP32[$922>>2]|0;
     $924 = HEAP32[$37>>2]|0;
     $925 = $924 & $919;
     $926 = HEAP8[$30>>0]|0;
     $927 = $926&255;
     $928 = $925 >>> $927;
     $929 = (($923) + ($928)|0);
     $930 = HEAP8[$929>>0]|0;
     $931 = HEAP8[$31>>0]|0;
     $932 = $931&255;
     $933 = (79212 + ($932<<2)|0);
     $934 = HEAP32[$933>>2]|0;
     $935 = HEAP32[$38>>2]|0;
     $936 = $935 & $919;
     $937 = HEAP8[$32>>0]|0;
     $938 = $937&255;
     $939 = $936 >>> $938;
     $940 = (($934) + ($939)|0);
     $941 = HEAP8[$940>>0]|0;
     $942 = HEAP8[$33>>0]|0;
     $943 = $942&255;
     $944 = (79212 + ($943<<2)|0);
     $945 = HEAP32[$944>>2]|0;
     $946 = HEAP32[$39>>2]|0;
     $947 = $946 & $919;
     $948 = HEAP8[$34>>0]|0;
     $949 = $948&255;
     $950 = $947 >>> $949;
     $951 = (($945) + ($950)|0);
     $952 = HEAP8[$951>>0]|0;
     $953 = HEAP8[$35>>0]|0;
     $954 = $953&255;
     $955 = (79212 + ($954<<2)|0);
     $956 = HEAP32[$955>>2]|0;
     $957 = HEAP32[$40>>2]|0;
     $958 = $957 & $919;
     $959 = HEAP8[$36>>0]|0;
     $960 = $959&255;
     $961 = $958 >>> $960;
     $962 = (($956) + ($961)|0);
     $963 = HEAP8[$962>>0]|0;
     $$3619$shrunk = $930;$$3623$shrunk = $941;$$3627$shrunk = $952;$$3631$shrunk = $963;
     break;
    }
    case 3:  {
     $964 = HEAP8[$30>>0]|0;
     $div664 = ($964&255) >>> 3;
     $965 = $div664&255;
     $966 = (($$4615) + ($965)|0);
     $967 = HEAP8[$966>>0]|0;
     $968 = HEAP8[$32>>0]|0;
     $div665 = ($968&255) >>> 3;
     $969 = $div665&255;
     $970 = (($$4615) + ($969)|0);
     $971 = HEAP8[$970>>0]|0;
     $972 = HEAP8[$34>>0]|0;
     $div666 = ($972&255) >>> 3;
     $973 = $div666&255;
     $974 = (($$4615) + ($973)|0);
     $975 = HEAP8[$974>>0]|0;
     $$3619$shrunk = $967;$$3623$shrunk = $971;$$3627$shrunk = $975;$$3631$shrunk = -1;
     break;
    }
    case 4:  {
     $976 = HEAP32[$$4615>>2]|0;
     $977 = HEAP8[$29>>0]|0;
     $978 = $977&255;
     $979 = (79212 + ($978<<2)|0);
     $980 = HEAP32[$979>>2]|0;
     $981 = HEAP32[$37>>2]|0;
     $982 = $981 & $976;
     $983 = HEAP8[$30>>0]|0;
     $984 = $983&255;
     $985 = $982 >>> $984;
     $986 = (($980) + ($985)|0);
     $987 = HEAP8[$986>>0]|0;
     $988 = HEAP8[$31>>0]|0;
     $989 = $988&255;
     $990 = (79212 + ($989<<2)|0);
     $991 = HEAP32[$990>>2]|0;
     $992 = HEAP32[$38>>2]|0;
     $993 = $992 & $976;
     $994 = HEAP8[$32>>0]|0;
     $995 = $994&255;
     $996 = $993 >>> $995;
     $997 = (($991) + ($996)|0);
     $998 = HEAP8[$997>>0]|0;
     $999 = HEAP8[$33>>0]|0;
     $1000 = $999&255;
     $1001 = (79212 + ($1000<<2)|0);
     $1002 = HEAP32[$1001>>2]|0;
     $1003 = HEAP32[$39>>2]|0;
     $1004 = $1003 & $976;
     $1005 = HEAP8[$34>>0]|0;
     $1006 = $1005&255;
     $1007 = $1004 >>> $1006;
     $1008 = (($1002) + ($1007)|0);
     $1009 = HEAP8[$1008>>0]|0;
     $1010 = HEAP8[$35>>0]|0;
     $1011 = $1010&255;
     $1012 = (79212 + ($1011<<2)|0);
     $1013 = HEAP32[$1012>>2]|0;
     $1014 = HEAP32[$40>>2]|0;
     $1015 = $1014 & $976;
     $1016 = HEAP8[$36>>0]|0;
     $1017 = $1016&255;
     $1018 = $1015 >>> $1017;
     $1019 = (($1013) + ($1018)|0);
     $1020 = HEAP8[$1019>>0]|0;
     $$3619$shrunk = $987;$$3623$shrunk = $998;$$3627$shrunk = $1009;$$3631$shrunk = $1020;
     break;
    }
    default: {
     $$3619$shrunk = 0;$$3623$shrunk = 0;$$3627$shrunk = 0;$$3631$shrunk = 0;
    }
    }
    $$3619 = $$3619$shrunk&255;
    $$3623 = $$3623$shrunk&255;
    $$3627 = $$3627$shrunk&255;
    $$3631 = $$3631$shrunk&255;
    $1021 = (($865) - ($$3619))|0;
    $1022 = Math_imul($1021, $19)|0;
    $1023 = (($1022>>>0) / 255)&-1;
    $1024 = (($1023) + ($$3619))|0;
    $1025 = (($868) - ($$3623))|0;
    $1026 = Math_imul($1025, $19)|0;
    $1027 = (($1026>>>0) / 255)&-1;
    $1028 = (($1027) + ($$3623))|0;
    $1029 = (($871) - ($$3627))|0;
    $1030 = Math_imul($1029, $19)|0;
    $1031 = (($1030>>>0) / 255)&-1;
    $1032 = (($1031) + ($$3627))|0;
    $1033 = (($$3631) + ($19))|0;
    $1034 = Math_imul($$3631, $19)|0;
    $1035 = (($1034>>>0) / 255)&-1;
    $1036 = (($1033) - ($1035))|0;
    switch ($21<<24>>24) {
    case 1:  {
     $1037 = HEAP8[$29>>0]|0;
     $1038 = $1037&255;
     $1039 = $1024 >>> $1038;
     $1040 = HEAP8[$30>>0]|0;
     $1041 = $1040&255;
     $1042 = $1039 << $1041;
     $1043 = HEAP8[$31>>0]|0;
     $1044 = $1043&255;
     $1045 = $1028 >>> $1044;
     $1046 = HEAP8[$32>>0]|0;
     $1047 = $1046&255;
     $1048 = $1045 << $1047;
     $1049 = $1048 | $1042;
     $1050 = HEAP8[$33>>0]|0;
     $1051 = $1050&255;
     $1052 = $1032 >>> $1051;
     $1053 = HEAP8[$34>>0]|0;
     $1054 = $1053&255;
     $1055 = $1052 << $1054;
     $1056 = $1049 | $1055;
     $1057 = HEAP8[$35>>0]|0;
     $1058 = $1057&255;
     $1059 = $1036 >>> $1058;
     $1060 = HEAP8[$36>>0]|0;
     $1061 = $1060&255;
     $1062 = $1059 << $1061;
     $1063 = $1056 | $1062;
     $1064 = $1063&255;
     HEAP8[$$4615>>0] = $1064;
     break;
    }
    case 2:  {
     $1065 = HEAP8[$29>>0]|0;
     $1066 = $1065&255;
     $1067 = $1024 >>> $1066;
     $1068 = HEAP8[$30>>0]|0;
     $1069 = $1068&255;
     $1070 = $1067 << $1069;
     $1071 = HEAP8[$31>>0]|0;
     $1072 = $1071&255;
     $1073 = $1028 >>> $1072;
     $1074 = HEAP8[$32>>0]|0;
     $1075 = $1074&255;
     $1076 = $1073 << $1075;
     $1077 = $1076 | $1070;
     $1078 = HEAP8[$33>>0]|0;
     $1079 = $1078&255;
     $1080 = $1032 >>> $1079;
     $1081 = HEAP8[$34>>0]|0;
     $1082 = $1081&255;
     $1083 = $1080 << $1082;
     $1084 = $1077 | $1083;
     $1085 = HEAP8[$35>>0]|0;
     $1086 = $1085&255;
     $1087 = $1036 >>> $1086;
     $1088 = HEAP8[$36>>0]|0;
     $1089 = $1088&255;
     $1090 = $1087 << $1089;
     $1091 = $1084 | $1090;
     $1092 = $1091&65535;
     HEAP16[$$4615>>1] = $1092;
     break;
    }
    case 3:  {
     $1093 = $1024&255;
     $1094 = HEAP8[$30>>0]|0;
     $div661 = ($1094&255) >>> 3;
     $1095 = $div661&255;
     $1096 = (($$4615) + ($1095)|0);
     HEAP8[$1096>>0] = $1093;
     $1097 = $1028&255;
     $1098 = HEAP8[$32>>0]|0;
     $div662 = ($1098&255) >>> 3;
     $1099 = $div662&255;
     $1100 = (($$4615) + ($1099)|0);
     HEAP8[$1100>>0] = $1097;
     $1101 = $1032&255;
     $1102 = HEAP8[$34>>0]|0;
     $div663 = ($1102&255) >>> 3;
     $1103 = $div663&255;
     $1104 = (($$4615) + ($1103)|0);
     HEAP8[$1104>>0] = $1101;
     break;
    }
    case 4:  {
     $1105 = HEAP8[$29>>0]|0;
     $1106 = $1105&255;
     $1107 = $1024 >>> $1106;
     $1108 = HEAP8[$30>>0]|0;
     $1109 = $1108&255;
     $1110 = $1107 << $1109;
     $1111 = HEAP8[$31>>0]|0;
     $1112 = $1111&255;
     $1113 = $1028 >>> $1112;
     $1114 = HEAP8[$32>>0]|0;
     $1115 = $1114&255;
     $1116 = $1113 << $1115;
     $1117 = $1116 | $1110;
     $1118 = HEAP8[$33>>0]|0;
     $1119 = $1118&255;
     $1120 = $1032 >>> $1119;
     $1121 = HEAP8[$34>>0]|0;
     $1122 = $1121&255;
     $1123 = $1120 << $1122;
     $1124 = $1117 | $1123;
     $1125 = HEAP8[$35>>0]|0;
     $1126 = $1125&255;
     $1127 = $1036 >>> $1126;
     $1128 = HEAP8[$36>>0]|0;
     $1129 = $1128&255;
     $1130 = $1127 << $1129;
     $1131 = $1124 | $1130;
     HEAP32[$$4615>>2] = $1131;
     break;
    }
    default: {
    }
    }
    $1132 = ((($$4)) + 1|0);
    $1133 = (($$4615) + ($22)|0);
    $1134 = (($$3635) + -1)|0;
    $1135 = ($$3635|0)>(1);
    if ($1135) {
     $$0632 = $1134;$$1 = $1132;$$1612 = $1133;
     label = 4;
     continue;
    } else {
     break;
    }
   }
  }
  $1136 = (($1132) + ($6)|0);
  $1137 = (($1133) + ($8)|0);
  $1138 = ($41|0)==(0);
  if ($1138) {
   label = 50;
   break;
  } else {
   $$0610671 = $1136;$$0611670 = $1137;$$in = $41;
  }
 }
 if ((label|0) == 48) {
  // unreachable;
 }
 else if ((label|0) == 50) {
  return;
 }
}
function _Blit1toNAlphaKey($0) {
 $0 = $0|0;
 var $$011851306 = 0, $$011861305 = 0, $$01195 = 0, $$01195$shrunk = 0, $$01203 = 0, $$01203$shrunk = 0, $$01211 = 0, $$01211$shrunk = 0, $$01219 = 0, $$01219$shrunk = 0, $$01227 = 0, $$1 = 0, $$11187 = 0, $$11196 = 0, $$11196$shrunk = 0, $$11204 = 0, $$11204$shrunk = 0, $$11212 = 0, $$11212$shrunk = 0, $$11220 = 0;
 var $$11220$shrunk = 0, $$11228 = 0, $$2 = 0, $$21188 = 0, $$21197 = 0, $$21197$shrunk = 0, $$21205 = 0, $$21205$shrunk = 0, $$21213 = 0, $$21213$shrunk = 0, $$21221 = 0, $$21221$shrunk = 0, $$21229 = 0, $$3 = 0, $$31189 = 0, $$31198 = 0, $$31198$shrunk = 0, $$31206 = 0, $$31206$shrunk = 0, $$31214 = 0;
 var $$31214$shrunk = 0, $$31222 = 0, $$31222$shrunk = 0, $$31230 = 0, $$4 = 0, $$41190 = 0, $$41199 = 0, $$41199$shrunk = 0, $$41207 = 0, $$41207$shrunk = 0, $$41215 = 0, $$41215$shrunk = 0, $$41223 = 0, $$41223$shrunk = 0, $$41231 = 0, $$5 = 0, $$51191 = 0, $$51200 = 0, $$51200$shrunk = 0, $$51208 = 0;
 var $$51208$shrunk = 0, $$51216 = 0, $$51216$shrunk = 0, $$51224 = 0, $$51224$shrunk = 0, $$51232 = 0, $$6 = 0, $$61192 = 0, $$61201 = 0, $$61201$shrunk = 0, $$61209 = 0, $$61209$shrunk = 0, $$61217 = 0, $$61217$shrunk = 0, $$61225 = 0, $$61225$shrunk = 0, $$61233 = 0, $$7 = 0, $$71193 = 0, $$71202 = 0;
 var $$71202$shrunk = 0, $$71210 = 0, $$71210$shrunk = 0, $$71218 = 0, $$71218$shrunk = 0, $$71226 = 0, $$71226$shrunk = 0, $$71234 = 0, $$8 = 0, $$81194 = 0, $$in = 0, $1 = 0, $10 = 0, $100 = 0, $1000 = 0, $1001 = 0, $1002 = 0, $1003 = 0, $1004 = 0, $1005 = 0;
 var $1006 = 0, $1007 = 0, $1008 = 0, $1009 = 0, $101 = 0, $1010 = 0, $1011 = 0, $1012 = 0, $1013 = 0, $1014 = 0, $1015 = 0, $1016 = 0, $1017 = 0, $1018 = 0, $1019 = 0, $102 = 0, $1020 = 0, $1021 = 0, $1022 = 0, $1023 = 0;
 var $1024 = 0, $1025 = 0, $1026 = 0, $1027 = 0, $1028 = 0, $1029 = 0, $103 = 0, $1030 = 0, $1031 = 0, $1032 = 0, $1033 = 0, $1034 = 0, $1035 = 0, $1036 = 0, $1037 = 0, $1038 = 0, $1039 = 0, $104 = 0, $1040 = 0, $1041 = 0;
 var $1042 = 0, $1043 = 0, $1044 = 0, $1045 = 0, $1046 = 0, $1047 = 0, $1048 = 0, $1049 = 0, $105 = 0, $1050 = 0, $1051 = 0, $1052 = 0, $1053 = 0, $1054 = 0, $1055 = 0, $1056 = 0, $1057 = 0, $1058 = 0, $1059 = 0, $106 = 0;
 var $1060 = 0, $1061 = 0, $1062 = 0, $1063 = 0, $1064 = 0, $1065 = 0, $1066 = 0, $1067 = 0, $1068 = 0, $1069 = 0, $107 = 0, $1070 = 0, $1071 = 0, $1072 = 0, $1073 = 0, $1074 = 0, $1075 = 0, $1076 = 0, $1077 = 0, $1078 = 0;
 var $1079 = 0, $108 = 0, $1080 = 0, $1081 = 0, $1082 = 0, $1083 = 0, $1084 = 0, $1085 = 0, $1086 = 0, $1087 = 0, $1088 = 0, $1089 = 0, $109 = 0, $1090 = 0, $1091 = 0, $1092 = 0, $1093 = 0, $1094 = 0, $1095 = 0, $1096 = 0;
 var $1097 = 0, $1098 = 0, $1099 = 0, $11 = 0, $110 = 0, $1100 = 0, $1101 = 0, $1102 = 0, $1103 = 0, $1104 = 0, $1105 = 0, $1106 = 0, $1107 = 0, $1108 = 0, $1109 = 0, $111 = 0, $1110 = 0, $1111 = 0, $1112 = 0, $1113 = 0;
 var $1114 = 0, $1115 = 0, $1116 = 0, $1117 = 0, $1118 = 0, $1119 = 0, $112 = 0, $1120 = 0, $1121 = 0, $1122 = 0, $1123 = 0, $1124 = 0, $1125 = 0, $1126 = 0, $1127 = 0, $1128 = 0, $1129 = 0, $113 = 0, $1130 = 0, $1131 = 0;
 var $1132 = 0, $1133 = 0, $1134 = 0, $1135 = 0, $1136 = 0, $1137 = 0, $1138 = 0, $1139 = 0, $114 = 0, $1140 = 0, $1141 = 0, $1142 = 0, $1143 = 0, $1144 = 0, $1145 = 0, $1146 = 0, $1147 = 0, $1148 = 0, $1149 = 0, $115 = 0;
 var $1150 = 0, $1151 = 0, $1152 = 0, $1153 = 0, $1154 = 0, $1155 = 0, $1156 = 0, $1157 = 0, $1158 = 0, $1159 = 0, $116 = 0, $1160 = 0, $1161 = 0, $1162 = 0, $1163 = 0, $1164 = 0, $1165 = 0, $1166 = 0, $1167 = 0, $1168 = 0;
 var $1169 = 0, $117 = 0, $1170 = 0, $1171 = 0, $1172 = 0, $1173 = 0, $1174 = 0, $1175 = 0, $1176 = 0, $1177 = 0, $1178 = 0, $1179 = 0, $118 = 0, $1180 = 0, $1181 = 0, $1182 = 0, $1183 = 0, $1184 = 0, $1185 = 0, $1186 = 0;
 var $1187 = 0, $1188 = 0, $1189 = 0, $119 = 0, $1190 = 0, $1191 = 0, $1192 = 0, $1193 = 0, $1194 = 0, $1195 = 0, $1196 = 0, $1197 = 0, $1198 = 0, $1199 = 0, $12 = 0, $120 = 0, $1200 = 0, $1201 = 0, $1202 = 0, $1203 = 0;
 var $1204 = 0, $1205 = 0, $1206 = 0, $1207 = 0, $1208 = 0, $1209 = 0, $121 = 0, $1210 = 0, $1211 = 0, $1212 = 0, $1213 = 0, $1214 = 0, $1215 = 0, $1216 = 0, $1217 = 0, $1218 = 0, $1219 = 0, $122 = 0, $1220 = 0, $1221 = 0;
 var $1222 = 0, $1223 = 0, $1224 = 0, $1225 = 0, $1226 = 0, $1227 = 0, $1228 = 0, $1229 = 0, $123 = 0, $1230 = 0, $1231 = 0, $1232 = 0, $1233 = 0, $1234 = 0, $1235 = 0, $1236 = 0, $1237 = 0, $1238 = 0, $1239 = 0, $124 = 0;
 var $1240 = 0, $1241 = 0, $1242 = 0, $1243 = 0, $1244 = 0, $1245 = 0, $1246 = 0, $1247 = 0, $1248 = 0, $1249 = 0, $125 = 0, $1250 = 0, $1251 = 0, $1252 = 0, $1253 = 0, $1254 = 0, $1255 = 0, $1256 = 0, $1257 = 0, $1258 = 0;
 var $1259 = 0, $126 = 0, $1260 = 0, $1261 = 0, $1262 = 0, $1263 = 0, $1264 = 0, $1265 = 0, $1266 = 0, $1267 = 0, $1268 = 0, $1269 = 0, $127 = 0, $1270 = 0, $1271 = 0, $1272 = 0, $1273 = 0, $1274 = 0, $1275 = 0, $1276 = 0;
 var $1277 = 0, $1278 = 0, $1279 = 0, $128 = 0, $1280 = 0, $1281 = 0, $1282 = 0, $1283 = 0, $1284 = 0, $1285 = 0, $1286 = 0, $1287 = 0, $1288 = 0, $1289 = 0, $129 = 0, $1290 = 0, $1291 = 0, $1292 = 0, $1293 = 0, $1294 = 0;
 var $1295 = 0, $1296 = 0, $1297 = 0, $1298 = 0, $1299 = 0, $13 = 0, $130 = 0, $1300 = 0, $1301 = 0, $1302 = 0, $1303 = 0, $1304 = 0, $1305 = 0, $1306 = 0, $1307 = 0, $1308 = 0, $1309 = 0, $131 = 0, $1310 = 0, $1311 = 0;
 var $1312 = 0, $1313 = 0, $1314 = 0, $1315 = 0, $1316 = 0, $1317 = 0, $1318 = 0, $1319 = 0, $132 = 0, $1320 = 0, $1321 = 0, $1322 = 0, $1323 = 0, $1324 = 0, $1325 = 0, $1326 = 0, $1327 = 0, $1328 = 0, $1329 = 0, $133 = 0;
 var $1330 = 0, $1331 = 0, $1332 = 0, $1333 = 0, $1334 = 0, $1335 = 0, $1336 = 0, $1337 = 0, $1338 = 0, $1339 = 0, $134 = 0, $1340 = 0, $1341 = 0, $1342 = 0, $1343 = 0, $1344 = 0, $1345 = 0, $1346 = 0, $1347 = 0, $1348 = 0;
 var $1349 = 0, $135 = 0, $1350 = 0, $1351 = 0, $1352 = 0, $1353 = 0, $1354 = 0, $1355 = 0, $1356 = 0, $1357 = 0, $1358 = 0, $1359 = 0, $136 = 0, $1360 = 0, $1361 = 0, $1362 = 0, $1363 = 0, $1364 = 0, $1365 = 0, $1366 = 0;
 var $1367 = 0, $1368 = 0, $1369 = 0, $137 = 0, $1370 = 0, $1371 = 0, $1372 = 0, $1373 = 0, $1374 = 0, $1375 = 0, $1376 = 0, $1377 = 0, $1378 = 0, $1379 = 0, $138 = 0, $1380 = 0, $1381 = 0, $1382 = 0, $1383 = 0, $1384 = 0;
 var $1385 = 0, $1386 = 0, $1387 = 0, $1388 = 0, $1389 = 0, $139 = 0, $1390 = 0, $1391 = 0, $1392 = 0, $1393 = 0, $1394 = 0, $1395 = 0, $1396 = 0, $1397 = 0, $1398 = 0, $1399 = 0, $14 = 0, $140 = 0, $1400 = 0, $1401 = 0;
 var $1402 = 0, $1403 = 0, $1404 = 0, $1405 = 0, $1406 = 0, $1407 = 0, $1408 = 0, $1409 = 0, $141 = 0, $1410 = 0, $1411 = 0, $1412 = 0, $1413 = 0, $1414 = 0, $1415 = 0, $1416 = 0, $1417 = 0, $1418 = 0, $1419 = 0, $142 = 0;
 var $1420 = 0, $1421 = 0, $1422 = 0, $1423 = 0, $1424 = 0, $1425 = 0, $1426 = 0, $1427 = 0, $1428 = 0, $1429 = 0, $143 = 0, $1430 = 0, $1431 = 0, $1432 = 0, $1433 = 0, $1434 = 0, $1435 = 0, $1436 = 0, $1437 = 0, $1438 = 0;
 var $1439 = 0, $144 = 0, $1440 = 0, $1441 = 0, $1442 = 0, $1443 = 0, $1444 = 0, $1445 = 0, $1446 = 0, $1447 = 0, $1448 = 0, $1449 = 0, $145 = 0, $1450 = 0, $1451 = 0, $1452 = 0, $1453 = 0, $1454 = 0, $1455 = 0, $1456 = 0;
 var $1457 = 0, $1458 = 0, $1459 = 0, $146 = 0, $1460 = 0, $1461 = 0, $1462 = 0, $1463 = 0, $1464 = 0, $1465 = 0, $1466 = 0, $1467 = 0, $1468 = 0, $1469 = 0, $147 = 0, $1470 = 0, $1471 = 0, $1472 = 0, $1473 = 0, $1474 = 0;
 var $1475 = 0, $1476 = 0, $1477 = 0, $1478 = 0, $1479 = 0, $148 = 0, $1480 = 0, $1481 = 0, $1482 = 0, $1483 = 0, $1484 = 0, $1485 = 0, $1486 = 0, $1487 = 0, $1488 = 0, $1489 = 0, $149 = 0, $1490 = 0, $1491 = 0, $1492 = 0;
 var $1493 = 0, $1494 = 0, $1495 = 0, $1496 = 0, $1497 = 0, $1498 = 0, $1499 = 0, $15 = 0, $150 = 0, $1500 = 0, $1501 = 0, $1502 = 0, $1503 = 0, $1504 = 0, $1505 = 0, $1506 = 0, $1507 = 0, $1508 = 0, $1509 = 0, $151 = 0;
 var $1510 = 0, $1511 = 0, $1512 = 0, $1513 = 0, $1514 = 0, $1515 = 0, $1516 = 0, $1517 = 0, $1518 = 0, $1519 = 0, $152 = 0, $1520 = 0, $1521 = 0, $1522 = 0, $1523 = 0, $1524 = 0, $1525 = 0, $1526 = 0, $1527 = 0, $1528 = 0;
 var $1529 = 0, $153 = 0, $1530 = 0, $1531 = 0, $1532 = 0, $1533 = 0, $1534 = 0, $1535 = 0, $1536 = 0, $1537 = 0, $1538 = 0, $1539 = 0, $154 = 0, $1540 = 0, $1541 = 0, $1542 = 0, $1543 = 0, $1544 = 0, $1545 = 0, $1546 = 0;
 var $1547 = 0, $1548 = 0, $1549 = 0, $155 = 0, $1550 = 0, $1551 = 0, $1552 = 0, $1553 = 0, $1554 = 0, $1555 = 0, $1556 = 0, $1557 = 0, $1558 = 0, $1559 = 0, $156 = 0, $1560 = 0, $1561 = 0, $1562 = 0, $1563 = 0, $1564 = 0;
 var $1565 = 0, $1566 = 0, $1567 = 0, $1568 = 0, $1569 = 0, $157 = 0, $1570 = 0, $1571 = 0, $1572 = 0, $1573 = 0, $1574 = 0, $1575 = 0, $1576 = 0, $1577 = 0, $1578 = 0, $1579 = 0, $158 = 0, $1580 = 0, $1581 = 0, $1582 = 0;
 var $1583 = 0, $1584 = 0, $1585 = 0, $1586 = 0, $1587 = 0, $1588 = 0, $1589 = 0, $159 = 0, $1590 = 0, $1591 = 0, $1592 = 0, $1593 = 0, $1594 = 0, $1595 = 0, $1596 = 0, $1597 = 0, $1598 = 0, $1599 = 0, $16 = 0, $160 = 0;
 var $1600 = 0, $1601 = 0, $1602 = 0, $1603 = 0, $1604 = 0, $1605 = 0, $1606 = 0, $1607 = 0, $1608 = 0, $1609 = 0, $161 = 0, $1610 = 0, $1611 = 0, $1612 = 0, $1613 = 0, $1614 = 0, $1615 = 0, $1616 = 0, $1617 = 0, $1618 = 0;
 var $1619 = 0, $162 = 0, $1620 = 0, $1621 = 0, $1622 = 0, $1623 = 0, $1624 = 0, $1625 = 0, $1626 = 0, $1627 = 0, $1628 = 0, $1629 = 0, $163 = 0, $1630 = 0, $1631 = 0, $1632 = 0, $1633 = 0, $1634 = 0, $1635 = 0, $1636 = 0;
 var $1637 = 0, $1638 = 0, $1639 = 0, $164 = 0, $1640 = 0, $1641 = 0, $1642 = 0, $1643 = 0, $1644 = 0, $1645 = 0, $1646 = 0, $1647 = 0, $1648 = 0, $1649 = 0, $165 = 0, $1650 = 0, $1651 = 0, $1652 = 0, $1653 = 0, $1654 = 0;
 var $1655 = 0, $1656 = 0, $1657 = 0, $1658 = 0, $1659 = 0, $166 = 0, $1660 = 0, $1661 = 0, $1662 = 0, $1663 = 0, $1664 = 0, $1665 = 0, $1666 = 0, $1667 = 0, $1668 = 0, $1669 = 0, $167 = 0, $1670 = 0, $1671 = 0, $1672 = 0;
 var $1673 = 0, $1674 = 0, $1675 = 0, $1676 = 0, $1677 = 0, $1678 = 0, $1679 = 0, $168 = 0, $1680 = 0, $1681 = 0, $1682 = 0, $1683 = 0, $1684 = 0, $1685 = 0, $1686 = 0, $1687 = 0, $1688 = 0, $1689 = 0, $169 = 0, $1690 = 0;
 var $1691 = 0, $1692 = 0, $1693 = 0, $1694 = 0, $1695 = 0, $1696 = 0, $1697 = 0, $1698 = 0, $1699 = 0, $17 = 0, $170 = 0, $1700 = 0, $1701 = 0, $1702 = 0, $1703 = 0, $1704 = 0, $1705 = 0, $1706 = 0, $1707 = 0, $1708 = 0;
 var $1709 = 0, $171 = 0, $1710 = 0, $1711 = 0, $1712 = 0, $1713 = 0, $1714 = 0, $1715 = 0, $1716 = 0, $1717 = 0, $1718 = 0, $1719 = 0, $172 = 0, $1720 = 0, $1721 = 0, $1722 = 0, $1723 = 0, $1724 = 0, $1725 = 0, $1726 = 0;
 var $1727 = 0, $1728 = 0, $1729 = 0, $173 = 0, $1730 = 0, $1731 = 0, $1732 = 0, $1733 = 0, $1734 = 0, $1735 = 0, $1736 = 0, $1737 = 0, $1738 = 0, $1739 = 0, $174 = 0, $1740 = 0, $1741 = 0, $1742 = 0, $1743 = 0, $1744 = 0;
 var $1745 = 0, $1746 = 0, $1747 = 0, $1748 = 0, $1749 = 0, $175 = 0, $1750 = 0, $1751 = 0, $1752 = 0, $1753 = 0, $1754 = 0, $1755 = 0, $1756 = 0, $1757 = 0, $1758 = 0, $1759 = 0, $176 = 0, $1760 = 0, $1761 = 0, $1762 = 0;
 var $1763 = 0, $1764 = 0, $1765 = 0, $1766 = 0, $1767 = 0, $1768 = 0, $1769 = 0, $177 = 0, $1770 = 0, $1771 = 0, $1772 = 0, $1773 = 0, $1774 = 0, $1775 = 0, $1776 = 0, $1777 = 0, $1778 = 0, $1779 = 0, $178 = 0, $1780 = 0;
 var $1781 = 0, $1782 = 0, $1783 = 0, $1784 = 0, $1785 = 0, $1786 = 0, $1787 = 0, $1788 = 0, $1789 = 0, $179 = 0, $1790 = 0, $1791 = 0, $1792 = 0, $1793 = 0, $1794 = 0, $1795 = 0, $1796 = 0, $1797 = 0, $1798 = 0, $1799 = 0;
 var $18 = 0, $180 = 0, $1800 = 0, $1801 = 0, $1802 = 0, $1803 = 0, $1804 = 0, $1805 = 0, $1806 = 0, $1807 = 0, $1808 = 0, $1809 = 0, $181 = 0, $1810 = 0, $1811 = 0, $1812 = 0, $1813 = 0, $1814 = 0, $1815 = 0, $1816 = 0;
 var $1817 = 0, $1818 = 0, $1819 = 0, $182 = 0, $1820 = 0, $1821 = 0, $1822 = 0, $1823 = 0, $1824 = 0, $1825 = 0, $1826 = 0, $1827 = 0, $1828 = 0, $1829 = 0, $183 = 0, $1830 = 0, $1831 = 0, $1832 = 0, $1833 = 0, $1834 = 0;
 var $1835 = 0, $1836 = 0, $1837 = 0, $1838 = 0, $1839 = 0, $184 = 0, $1840 = 0, $1841 = 0, $1842 = 0, $1843 = 0, $1844 = 0, $1845 = 0, $1846 = 0, $1847 = 0, $1848 = 0, $1849 = 0, $185 = 0, $1850 = 0, $1851 = 0, $1852 = 0;
 var $1853 = 0, $1854 = 0, $1855 = 0, $1856 = 0, $1857 = 0, $1858 = 0, $1859 = 0, $186 = 0, $1860 = 0, $1861 = 0, $1862 = 0, $1863 = 0, $1864 = 0, $1865 = 0, $1866 = 0, $1867 = 0, $1868 = 0, $1869 = 0, $187 = 0, $1870 = 0;
 var $1871 = 0, $1872 = 0, $1873 = 0, $1874 = 0, $1875 = 0, $1876 = 0, $1877 = 0, $1878 = 0, $1879 = 0, $188 = 0, $1880 = 0, $1881 = 0, $1882 = 0, $1883 = 0, $1884 = 0, $1885 = 0, $1886 = 0, $1887 = 0, $1888 = 0, $1889 = 0;
 var $189 = 0, $1890 = 0, $1891 = 0, $1892 = 0, $1893 = 0, $1894 = 0, $1895 = 0, $1896 = 0, $1897 = 0, $1898 = 0, $1899 = 0, $19 = 0, $190 = 0, $1900 = 0, $1901 = 0, $1902 = 0, $1903 = 0, $1904 = 0, $1905 = 0, $1906 = 0;
 var $1907 = 0, $1908 = 0, $1909 = 0, $191 = 0, $1910 = 0, $1911 = 0, $1912 = 0, $1913 = 0, $1914 = 0, $1915 = 0, $1916 = 0, $1917 = 0, $1918 = 0, $1919 = 0, $192 = 0, $1920 = 0, $1921 = 0, $1922 = 0, $1923 = 0, $1924 = 0;
 var $1925 = 0, $1926 = 0, $1927 = 0, $1928 = 0, $1929 = 0, $193 = 0, $1930 = 0, $1931 = 0, $1932 = 0, $1933 = 0, $1934 = 0, $1935 = 0, $1936 = 0, $1937 = 0, $1938 = 0, $1939 = 0, $194 = 0, $1940 = 0, $1941 = 0, $1942 = 0;
 var $1943 = 0, $1944 = 0, $1945 = 0, $1946 = 0, $1947 = 0, $1948 = 0, $1949 = 0, $195 = 0, $1950 = 0, $1951 = 0, $1952 = 0, $1953 = 0, $1954 = 0, $1955 = 0, $1956 = 0, $1957 = 0, $1958 = 0, $1959 = 0, $196 = 0, $1960 = 0;
 var $1961 = 0, $1962 = 0, $1963 = 0, $1964 = 0, $1965 = 0, $1966 = 0, $1967 = 0, $1968 = 0, $1969 = 0, $197 = 0, $1970 = 0, $1971 = 0, $1972 = 0, $1973 = 0, $1974 = 0, $1975 = 0, $1976 = 0, $1977 = 0, $1978 = 0, $1979 = 0;
 var $198 = 0, $1980 = 0, $1981 = 0, $1982 = 0, $1983 = 0, $1984 = 0, $1985 = 0, $1986 = 0, $1987 = 0, $1988 = 0, $1989 = 0, $199 = 0, $1990 = 0, $1991 = 0, $1992 = 0, $1993 = 0, $1994 = 0, $1995 = 0, $1996 = 0, $1997 = 0;
 var $1998 = 0, $1999 = 0, $2 = 0, $20 = 0, $200 = 0, $2000 = 0, $2001 = 0, $2002 = 0, $2003 = 0, $2004 = 0, $2005 = 0, $2006 = 0, $2007 = 0, $2008 = 0, $2009 = 0, $201 = 0, $2010 = 0, $2011 = 0, $2012 = 0, $2013 = 0;
 var $2014 = 0, $2015 = 0, $2016 = 0, $2017 = 0, $2018 = 0, $2019 = 0, $202 = 0, $2020 = 0, $2021 = 0, $2022 = 0, $2023 = 0, $2024 = 0, $2025 = 0, $2026 = 0, $2027 = 0, $2028 = 0, $2029 = 0, $203 = 0, $2030 = 0, $2031 = 0;
 var $2032 = 0, $2033 = 0, $2034 = 0, $2035 = 0, $2036 = 0, $2037 = 0, $2038 = 0, $2039 = 0, $204 = 0, $2040 = 0, $2041 = 0, $2042 = 0, $2043 = 0, $2044 = 0, $2045 = 0, $2046 = 0, $2047 = 0, $2048 = 0, $2049 = 0, $205 = 0;
 var $2050 = 0, $2051 = 0, $2052 = 0, $2053 = 0, $2054 = 0, $2055 = 0, $2056 = 0, $2057 = 0, $2058 = 0, $2059 = 0, $206 = 0, $2060 = 0, $2061 = 0, $2062 = 0, $2063 = 0, $2064 = 0, $2065 = 0, $2066 = 0, $2067 = 0, $2068 = 0;
 var $2069 = 0, $207 = 0, $2070 = 0, $2071 = 0, $2072 = 0, $2073 = 0, $2074 = 0, $2075 = 0, $2076 = 0, $2077 = 0, $2078 = 0, $2079 = 0, $208 = 0, $2080 = 0, $2081 = 0, $2082 = 0, $2083 = 0, $2084 = 0, $2085 = 0, $2086 = 0;
 var $2087 = 0, $2088 = 0, $2089 = 0, $209 = 0, $2090 = 0, $2091 = 0, $2092 = 0, $2093 = 0, $2094 = 0, $2095 = 0, $2096 = 0, $2097 = 0, $2098 = 0, $2099 = 0, $21 = 0, $210 = 0, $2100 = 0, $2101 = 0, $2102 = 0, $2103 = 0;
 var $2104 = 0, $2105 = 0, $2106 = 0, $2107 = 0, $2108 = 0, $2109 = 0, $211 = 0, $2110 = 0, $2111 = 0, $2112 = 0, $2113 = 0, $2114 = 0, $2115 = 0, $2116 = 0, $2117 = 0, $2118 = 0, $2119 = 0, $212 = 0, $2120 = 0, $2121 = 0;
 var $2122 = 0, $2123 = 0, $2124 = 0, $2125 = 0, $2126 = 0, $2127 = 0, $2128 = 0, $2129 = 0, $213 = 0, $2130 = 0, $2131 = 0, $2132 = 0, $2133 = 0, $2134 = 0, $2135 = 0, $2136 = 0, $2137 = 0, $2138 = 0, $2139 = 0, $214 = 0;
 var $2140 = 0, $2141 = 0, $2142 = 0, $2143 = 0, $2144 = 0, $2145 = 0, $2146 = 0, $2147 = 0, $2148 = 0, $2149 = 0, $215 = 0, $2150 = 0, $2151 = 0, $2152 = 0, $2153 = 0, $2154 = 0, $2155 = 0, $2156 = 0, $2157 = 0, $2158 = 0;
 var $2159 = 0, $216 = 0, $2160 = 0, $2161 = 0, $2162 = 0, $2163 = 0, $2164 = 0, $2165 = 0, $2166 = 0, $2167 = 0, $2168 = 0, $2169 = 0, $217 = 0, $2170 = 0, $2171 = 0, $2172 = 0, $2173 = 0, $2174 = 0, $2175 = 0, $2176 = 0;
 var $2177 = 0, $2178 = 0, $2179 = 0, $218 = 0, $2180 = 0, $2181 = 0, $2182 = 0, $2183 = 0, $2184 = 0, $2185 = 0, $2186 = 0, $2187 = 0, $2188 = 0, $2189 = 0, $219 = 0, $2190 = 0, $2191 = 0, $2192 = 0, $2193 = 0, $2194 = 0;
 var $2195 = 0, $2196 = 0, $2197 = 0, $2198 = 0, $2199 = 0, $22 = 0, $220 = 0, $2200 = 0, $2201 = 0, $2202 = 0, $2203 = 0, $2204 = 0, $2205 = 0, $2206 = 0, $2207 = 0, $2208 = 0, $2209 = 0, $221 = 0, $2210 = 0, $2211 = 0;
 var $2212 = 0, $2213 = 0, $2214 = 0, $2215 = 0, $2216 = 0, $2217 = 0, $2218 = 0, $2219 = 0, $222 = 0, $2220 = 0, $2221 = 0, $2222 = 0, $2223 = 0, $2224 = 0, $2225 = 0, $2226 = 0, $2227 = 0, $2228 = 0, $2229 = 0, $223 = 0;
 var $2230 = 0, $2231 = 0, $2232 = 0, $2233 = 0, $2234 = 0, $2235 = 0, $2236 = 0, $2237 = 0, $2238 = 0, $2239 = 0, $224 = 0, $2240 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0;
 var $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0;
 var $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0;
 var $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0;
 var $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0;
 var $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0;
 var $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0;
 var $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0;
 var $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0;
 var $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0;
 var $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0;
 var $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0;
 var $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0;
 var $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0;
 var $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0;
 var $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0;
 var $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0;
 var $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0;
 var $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0;
 var $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0;
 var $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0;
 var $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0;
 var $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0;
 var $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0;
 var $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0;
 var $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0;
 var $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0;
 var $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0;
 var $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0;
 var $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0;
 var $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0;
 var $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0;
 var $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0;
 var $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0;
 var $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = 0, $834 = 0, $835 = 0, $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0;
 var $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0, $850 = 0, $851 = 0, $852 = 0, $853 = 0, $854 = 0, $855 = 0, $856 = 0, $857 = 0, $858 = 0, $859 = 0, $86 = 0, $860 = 0, $861 = 0, $862 = 0;
 var $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0, $869 = 0, $87 = 0, $870 = 0, $871 = 0, $872 = 0, $873 = 0, $874 = 0, $875 = 0, $876 = 0, $877 = 0, $878 = 0, $879 = 0, $88 = 0, $880 = 0;
 var $881 = 0, $882 = 0, $883 = 0, $884 = 0, $885 = 0, $886 = 0, $887 = 0, $888 = 0, $889 = 0, $89 = 0, $890 = 0, $891 = 0, $892 = 0, $893 = 0, $894 = 0, $895 = 0, $896 = 0, $897 = 0, $898 = 0, $899 = 0;
 var $9 = 0, $90 = 0, $900 = 0, $901 = 0, $902 = 0, $903 = 0, $904 = 0, $905 = 0, $906 = 0, $907 = 0, $908 = 0, $909 = 0, $91 = 0, $910 = 0, $911 = 0, $912 = 0, $913 = 0, $914 = 0, $915 = 0, $916 = 0;
 var $917 = 0, $918 = 0, $919 = 0, $92 = 0, $920 = 0, $921 = 0, $922 = 0, $923 = 0, $924 = 0, $925 = 0, $926 = 0, $927 = 0, $928 = 0, $929 = 0, $93 = 0, $930 = 0, $931 = 0, $932 = 0, $933 = 0, $934 = 0;
 var $935 = 0, $936 = 0, $937 = 0, $938 = 0, $939 = 0, $94 = 0, $940 = 0, $941 = 0, $942 = 0, $943 = 0, $944 = 0, $945 = 0, $946 = 0, $947 = 0, $948 = 0, $949 = 0, $95 = 0, $950 = 0, $951 = 0, $952 = 0;
 var $953 = 0, $954 = 0, $955 = 0, $956 = 0, $957 = 0, $958 = 0, $959 = 0, $96 = 0, $960 = 0, $961 = 0, $962 = 0, $963 = 0, $964 = 0, $965 = 0, $966 = 0, $967 = 0, $968 = 0, $969 = 0, $97 = 0, $970 = 0;
 var $971 = 0, $972 = 0, $973 = 0, $974 = 0, $975 = 0, $976 = 0, $977 = 0, $978 = 0, $979 = 0, $98 = 0, $980 = 0, $981 = 0, $982 = 0, $983 = 0, $984 = 0, $985 = 0, $986 = 0, $987 = 0, $988 = 0, $989 = 0;
 var $99 = 0, $990 = 0, $991 = 0, $992 = 0, $993 = 0, $994 = 0, $995 = 0, $996 = 0, $997 = 0, $998 = 0, $999 = 0, $div = 0, $div1237 = 0, $div1238 = 0, $div1239 = 0, $div1240 = 0, $div1241 = 0, $div1244 = 0, $div1245 = 0, $div1246 = 0;
 var $div1247 = 0, $div1248 = 0, $div1249 = 0, $div1252 = 0, $div1253 = 0, $div1254 = 0, $div1255 = 0, $div1256 = 0, $div1257 = 0, $div1260 = 0, $div1261 = 0, $div1262 = 0, $div1263 = 0, $div1264 = 0, $div1265 = 0, $div1268 = 0, $div1269 = 0, $div1270 = 0, $div1271 = 0, $div1272 = 0;
 var $div1273 = 0, $div1276 = 0, $div1277 = 0, $div1278 = 0, $div1279 = 0, $div1280 = 0, $div1281 = 0, $div1284 = 0, $div1285 = 0, $div1286 = 0, $div1287 = 0, $div1288 = 0, $div1289 = 0, $div1292 = 0, $div1293 = 0, $div1294 = 0, $div1295 = 0, $div1296 = 0, $div1297 = 0, $trunc = 0;
 var $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($0)) + 36|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($0)) + 44|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ((($0)) + 40|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ((($12)) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ((($14)) + 4|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ((($0)) + 56|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ((($0)) + 63|0);
 $20 = HEAP8[$19>>0]|0;
 $21 = $20&255;
 $22 = ((($10)) + 9|0);
 $23 = HEAP8[$22>>0]|0;
 $24 = $23&255;
 $25 = ($4|0)==(0);
 if ($25) {
  return;
 }
 $26 = ((($0)) + 20|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = HEAP32[$0>>2]|0;
 $29 = (($2) + 7)|0;
 $30 = (($29|0) / 8)&-1;
 $trunc = $2&255;
 $31 = ((($10)) + 28|0);
 $32 = ((($10)) + 32|0);
 $33 = ((($10)) + 29|0);
 $34 = ((($10)) + 33|0);
 $35 = ((($10)) + 30|0);
 $36 = ((($10)) + 34|0);
 $37 = ((($10)) + 31|0);
 $38 = ((($10)) + 35|0);
 $39 = ((($10)) + 12|0);
 $40 = ((($10)) + 16|0);
 $41 = ((($10)) + 20|0);
 $42 = ((($10)) + 24|0);
 $$011851306 = $28;$$011861305 = $27;$$in = $4;
 L4: while(1) {
  $43 = (($$in) + -1)|0;
  $trunc$clear = $trunc & 7;
  switch ($trunc$clear<<24>>24) {
  case 0:  {
   $$01227 = $30;$$1 = $$011851306;$$11187 = $$011861305;
   label = 4;
   break;
  }
  case 7:  {
   $$11228 = $30;$$2 = $$011851306;$$21188 = $$011861305;
   label = 16;
   break;
  }
  case 6:  {
   $$21229 = $30;$$3 = $$011851306;$$31189 = $$011861305;
   label = 28;
   break;
  }
  case 5:  {
   $$31230 = $30;$$4 = $$011851306;$$41190 = $$011861305;
   label = 40;
   break;
  }
  case 4:  {
   $$41231 = $30;$$5 = $$011851306;$$51191 = $$011861305;
   label = 52;
   break;
  }
  case 3:  {
   $$51232 = $30;$$6 = $$011851306;$$61192 = $$011861305;
   label = 64;
   break;
  }
  case 2:  {
   $$61233 = $30;$$7 = $$011851306;$$71193 = $$011861305;
   label = 76;
   break;
  }
  case 1:  {
   $$71234 = $30;$$8 = $$011851306;$$81194 = $$011861305;
   label = 88;
   break;
  }
  default: {
   label = 100;
   break L4;
  }
  }
  while(1) {
   if ((label|0) == 4) {
    label = 0;
    $44 = HEAP8[$$1>>0]|0;
    $45 = $44&255;
    $46 = ($45|0)==($18|0);
    L9: do {
     if (!($46)) {
      $47 = (($16) + ($45<<2)|0);
      $48 = HEAP8[$47>>0]|0;
      $49 = $48&255;
      $50 = (((($16) + ($45<<2)|0)) + 1|0);
      $51 = HEAP8[$50>>0]|0;
      $52 = $51&255;
      $53 = (((($16) + ($45<<2)|0)) + 2|0);
      $54 = HEAP8[$53>>0]|0;
      $55 = $54&255;
      switch ($23<<24>>24) {
      case 1:  {
       $56 = HEAP8[$$11187>>0]|0;
       $57 = $56&255;
       $58 = HEAP8[$31>>0]|0;
       $59 = $58&255;
       $60 = (79212 + ($59<<2)|0);
       $61 = HEAP32[$60>>2]|0;
       $62 = HEAP32[$39>>2]|0;
       $63 = $62 & $57;
       $64 = HEAP8[$32>>0]|0;
       $65 = $64&255;
       $66 = $63 >>> $65;
       $67 = (($61) + ($66)|0);
       $68 = HEAP8[$67>>0]|0;
       $69 = HEAP8[$33>>0]|0;
       $70 = $69&255;
       $71 = (79212 + ($70<<2)|0);
       $72 = HEAP32[$71>>2]|0;
       $73 = HEAP32[$40>>2]|0;
       $74 = $73 & $57;
       $75 = HEAP8[$34>>0]|0;
       $76 = $75&255;
       $77 = $74 >>> $76;
       $78 = (($72) + ($77)|0);
       $79 = HEAP8[$78>>0]|0;
       $80 = HEAP8[$35>>0]|0;
       $81 = $80&255;
       $82 = (79212 + ($81<<2)|0);
       $83 = HEAP32[$82>>2]|0;
       $84 = HEAP32[$41>>2]|0;
       $85 = $84 & $57;
       $86 = HEAP8[$36>>0]|0;
       $87 = $86&255;
       $88 = $85 >>> $87;
       $89 = (($83) + ($88)|0);
       $90 = HEAP8[$89>>0]|0;
       $91 = HEAP8[$37>>0]|0;
       $92 = $91&255;
       $93 = (79212 + ($92<<2)|0);
       $94 = HEAP32[$93>>2]|0;
       $95 = HEAP32[$42>>2]|0;
       $96 = $95 & $57;
       $97 = HEAP8[$38>>0]|0;
       $98 = $97&255;
       $99 = $96 >>> $98;
       $100 = (($94) + ($99)|0);
       $101 = HEAP8[$100>>0]|0;
       $$01195$shrunk = $68;$$01203$shrunk = $79;$$01211$shrunk = $90;$$01219$shrunk = $101;
       break;
      }
      case 2:  {
       $102 = HEAP16[$$11187>>1]|0;
       $103 = $102&65535;
       $104 = HEAP8[$31>>0]|0;
       $105 = $104&255;
       $106 = (79212 + ($105<<2)|0);
       $107 = HEAP32[$106>>2]|0;
       $108 = HEAP32[$39>>2]|0;
       $109 = $108 & $103;
       $110 = HEAP8[$32>>0]|0;
       $111 = $110&255;
       $112 = $109 >>> $111;
       $113 = (($107) + ($112)|0);
       $114 = HEAP8[$113>>0]|0;
       $115 = HEAP8[$33>>0]|0;
       $116 = $115&255;
       $117 = (79212 + ($116<<2)|0);
       $118 = HEAP32[$117>>2]|0;
       $119 = HEAP32[$40>>2]|0;
       $120 = $119 & $103;
       $121 = HEAP8[$34>>0]|0;
       $122 = $121&255;
       $123 = $120 >>> $122;
       $124 = (($118) + ($123)|0);
       $125 = HEAP8[$124>>0]|0;
       $126 = HEAP8[$35>>0]|0;
       $127 = $126&255;
       $128 = (79212 + ($127<<2)|0);
       $129 = HEAP32[$128>>2]|0;
       $130 = HEAP32[$41>>2]|0;
       $131 = $130 & $103;
       $132 = HEAP8[$36>>0]|0;
       $133 = $132&255;
       $134 = $131 >>> $133;
       $135 = (($129) + ($134)|0);
       $136 = HEAP8[$135>>0]|0;
       $137 = HEAP8[$37>>0]|0;
       $138 = $137&255;
       $139 = (79212 + ($138<<2)|0);
       $140 = HEAP32[$139>>2]|0;
       $141 = HEAP32[$42>>2]|0;
       $142 = $141 & $103;
       $143 = HEAP8[$38>>0]|0;
       $144 = $143&255;
       $145 = $142 >>> $144;
       $146 = (($140) + ($145)|0);
       $147 = HEAP8[$146>>0]|0;
       $$01195$shrunk = $114;$$01203$shrunk = $125;$$01211$shrunk = $136;$$01219$shrunk = $147;
       break;
      }
      case 3:  {
       $148 = HEAP8[$32>>0]|0;
       $div1287 = ($148&255) >>> 3;
       $149 = $div1287&255;
       $150 = (($$11187) + ($149)|0);
       $151 = HEAP8[$150>>0]|0;
       $152 = HEAP8[$34>>0]|0;
       $div1288 = ($152&255) >>> 3;
       $153 = $div1288&255;
       $154 = (($$11187) + ($153)|0);
       $155 = HEAP8[$154>>0]|0;
       $156 = HEAP8[$36>>0]|0;
       $div1289 = ($156&255) >>> 3;
       $157 = $div1289&255;
       $158 = (($$11187) + ($157)|0);
       $159 = HEAP8[$158>>0]|0;
       $$01195$shrunk = $151;$$01203$shrunk = $155;$$01211$shrunk = $159;$$01219$shrunk = -1;
       break;
      }
      case 4:  {
       $160 = HEAP32[$$11187>>2]|0;
       $161 = HEAP8[$31>>0]|0;
       $162 = $161&255;
       $163 = (79212 + ($162<<2)|0);
       $164 = HEAP32[$163>>2]|0;
       $165 = HEAP32[$39>>2]|0;
       $166 = $165 & $160;
       $167 = HEAP8[$32>>0]|0;
       $168 = $167&255;
       $169 = $166 >>> $168;
       $170 = (($164) + ($169)|0);
       $171 = HEAP8[$170>>0]|0;
       $172 = HEAP8[$33>>0]|0;
       $173 = $172&255;
       $174 = (79212 + ($173<<2)|0);
       $175 = HEAP32[$174>>2]|0;
       $176 = HEAP32[$40>>2]|0;
       $177 = $176 & $160;
       $178 = HEAP8[$34>>0]|0;
       $179 = $178&255;
       $180 = $177 >>> $179;
       $181 = (($175) + ($180)|0);
       $182 = HEAP8[$181>>0]|0;
       $183 = HEAP8[$35>>0]|0;
       $184 = $183&255;
       $185 = (79212 + ($184<<2)|0);
       $186 = HEAP32[$185>>2]|0;
       $187 = HEAP32[$41>>2]|0;
       $188 = $187 & $160;
       $189 = HEAP8[$36>>0]|0;
       $190 = $189&255;
       $191 = $188 >>> $190;
       $192 = (($186) + ($191)|0);
       $193 = HEAP8[$192>>0]|0;
       $194 = HEAP8[$37>>0]|0;
       $195 = $194&255;
       $196 = (79212 + ($195<<2)|0);
       $197 = HEAP32[$196>>2]|0;
       $198 = HEAP32[$42>>2]|0;
       $199 = $198 & $160;
       $200 = HEAP8[$38>>0]|0;
       $201 = $200&255;
       $202 = $199 >>> $201;
       $203 = (($197) + ($202)|0);
       $204 = HEAP8[$203>>0]|0;
       $$01195$shrunk = $171;$$01203$shrunk = $182;$$01211$shrunk = $193;$$01219$shrunk = $204;
       break;
      }
      default: {
       $$01195$shrunk = 0;$$01203$shrunk = 0;$$01211$shrunk = 0;$$01219$shrunk = 0;
      }
      }
      $$01195 = $$01195$shrunk&255;
      $$01203 = $$01203$shrunk&255;
      $$01211 = $$01211$shrunk&255;
      $$01219 = $$01219$shrunk&255;
      $205 = (($49) - ($$01195))|0;
      $206 = Math_imul($205, $21)|0;
      $207 = (($206>>>0) / 255)&-1;
      $208 = (($207) + ($$01195))|0;
      $209 = (($52) - ($$01203))|0;
      $210 = Math_imul($209, $21)|0;
      $211 = (($210>>>0) / 255)&-1;
      $212 = (($211) + ($$01203))|0;
      $213 = (($55) - ($$01211))|0;
      $214 = Math_imul($213, $21)|0;
      $215 = (($214>>>0) / 255)&-1;
      $216 = (($215) + ($$01211))|0;
      $217 = (($$01219) + ($21))|0;
      $218 = Math_imul($$01219, $21)|0;
      $219 = (($218>>>0) / 255)&-1;
      $220 = (($217) - ($219))|0;
      switch ($23<<24>>24) {
      case 1:  {
       $221 = HEAP8[$31>>0]|0;
       $222 = $221&255;
       $223 = $208 >>> $222;
       $224 = HEAP8[$32>>0]|0;
       $225 = $224&255;
       $226 = $223 << $225;
       $227 = HEAP8[$33>>0]|0;
       $228 = $227&255;
       $229 = $212 >>> $228;
       $230 = HEAP8[$34>>0]|0;
       $231 = $230&255;
       $232 = $229 << $231;
       $233 = $232 | $226;
       $234 = HEAP8[$35>>0]|0;
       $235 = $234&255;
       $236 = $216 >>> $235;
       $237 = HEAP8[$36>>0]|0;
       $238 = $237&255;
       $239 = $236 << $238;
       $240 = $233 | $239;
       $241 = HEAP8[$37>>0]|0;
       $242 = $241&255;
       $243 = $220 >>> $242;
       $244 = HEAP8[$38>>0]|0;
       $245 = $244&255;
       $246 = $243 << $245;
       $247 = $240 | $246;
       $248 = $247&255;
       HEAP8[$$11187>>0] = $248;
       break L9;
       break;
      }
      case 2:  {
       $249 = HEAP8[$31>>0]|0;
       $250 = $249&255;
       $251 = $208 >>> $250;
       $252 = HEAP8[$32>>0]|0;
       $253 = $252&255;
       $254 = $251 << $253;
       $255 = HEAP8[$33>>0]|0;
       $256 = $255&255;
       $257 = $212 >>> $256;
       $258 = HEAP8[$34>>0]|0;
       $259 = $258&255;
       $260 = $257 << $259;
       $261 = $260 | $254;
       $262 = HEAP8[$35>>0]|0;
       $263 = $262&255;
       $264 = $216 >>> $263;
       $265 = HEAP8[$36>>0]|0;
       $266 = $265&255;
       $267 = $264 << $266;
       $268 = $261 | $267;
       $269 = HEAP8[$37>>0]|0;
       $270 = $269&255;
       $271 = $220 >>> $270;
       $272 = HEAP8[$38>>0]|0;
       $273 = $272&255;
       $274 = $271 << $273;
       $275 = $268 | $274;
       $276 = $275&65535;
       HEAP16[$$11187>>1] = $276;
       break L9;
       break;
      }
      case 3:  {
       $277 = $208&255;
       $278 = HEAP8[$32>>0]|0;
       $div1284 = ($278&255) >>> 3;
       $279 = $div1284&255;
       $280 = (($$11187) + ($279)|0);
       HEAP8[$280>>0] = $277;
       $281 = $212&255;
       $282 = HEAP8[$34>>0]|0;
       $div1285 = ($282&255) >>> 3;
       $283 = $div1285&255;
       $284 = (($$11187) + ($283)|0);
       HEAP8[$284>>0] = $281;
       $285 = $216&255;
       $286 = HEAP8[$36>>0]|0;
       $div1286 = ($286&255) >>> 3;
       $287 = $div1286&255;
       $288 = (($$11187) + ($287)|0);
       HEAP8[$288>>0] = $285;
       break L9;
       break;
      }
      case 4:  {
       $289 = HEAP8[$31>>0]|0;
       $290 = $289&255;
       $291 = $208 >>> $290;
       $292 = HEAP8[$32>>0]|0;
       $293 = $292&255;
       $294 = $291 << $293;
       $295 = HEAP8[$33>>0]|0;
       $296 = $295&255;
       $297 = $212 >>> $296;
       $298 = HEAP8[$34>>0]|0;
       $299 = $298&255;
       $300 = $297 << $299;
       $301 = $300 | $294;
       $302 = HEAP8[$35>>0]|0;
       $303 = $302&255;
       $304 = $216 >>> $303;
       $305 = HEAP8[$36>>0]|0;
       $306 = $305&255;
       $307 = $304 << $306;
       $308 = $301 | $307;
       $309 = HEAP8[$37>>0]|0;
       $310 = $309&255;
       $311 = $220 >>> $310;
       $312 = HEAP8[$38>>0]|0;
       $313 = $312&255;
       $314 = $311 << $313;
       $315 = $308 | $314;
       HEAP32[$$11187>>2] = $315;
       break L9;
       break;
      }
      default: {
       break L9;
      }
      }
     }
    } while(0);
    $316 = ((($$1)) + 1|0);
    $317 = (($$11187) + ($24)|0);
    $$11228 = $$01227;$$2 = $316;$$21188 = $317;
    label = 16;
    continue;
   }
   else if ((label|0) == 16) {
    label = 0;
    $318 = HEAP8[$$2>>0]|0;
    $319 = $318&255;
    $320 = ($319|0)==($18|0);
    L24: do {
     if (!($320)) {
      $321 = (($16) + ($319<<2)|0);
      $322 = HEAP8[$321>>0]|0;
      $323 = $322&255;
      $324 = (((($16) + ($319<<2)|0)) + 1|0);
      $325 = HEAP8[$324>>0]|0;
      $326 = $325&255;
      $327 = (((($16) + ($319<<2)|0)) + 2|0);
      $328 = HEAP8[$327>>0]|0;
      $329 = $328&255;
      switch ($23<<24>>24) {
      case 1:  {
       $330 = HEAP8[$$21188>>0]|0;
       $331 = $330&255;
       $332 = HEAP8[$31>>0]|0;
       $333 = $332&255;
       $334 = (79212 + ($333<<2)|0);
       $335 = HEAP32[$334>>2]|0;
       $336 = HEAP32[$39>>2]|0;
       $337 = $336 & $331;
       $338 = HEAP8[$32>>0]|0;
       $339 = $338&255;
       $340 = $337 >>> $339;
       $341 = (($335) + ($340)|0);
       $342 = HEAP8[$341>>0]|0;
       $343 = HEAP8[$33>>0]|0;
       $344 = $343&255;
       $345 = (79212 + ($344<<2)|0);
       $346 = HEAP32[$345>>2]|0;
       $347 = HEAP32[$40>>2]|0;
       $348 = $347 & $331;
       $349 = HEAP8[$34>>0]|0;
       $350 = $349&255;
       $351 = $348 >>> $350;
       $352 = (($346) + ($351)|0);
       $353 = HEAP8[$352>>0]|0;
       $354 = HEAP8[$35>>0]|0;
       $355 = $354&255;
       $356 = (79212 + ($355<<2)|0);
       $357 = HEAP32[$356>>2]|0;
       $358 = HEAP32[$41>>2]|0;
       $359 = $358 & $331;
       $360 = HEAP8[$36>>0]|0;
       $361 = $360&255;
       $362 = $359 >>> $361;
       $363 = (($357) + ($362)|0);
       $364 = HEAP8[$363>>0]|0;
       $365 = HEAP8[$37>>0]|0;
       $366 = $365&255;
       $367 = (79212 + ($366<<2)|0);
       $368 = HEAP32[$367>>2]|0;
       $369 = HEAP32[$42>>2]|0;
       $370 = $369 & $331;
       $371 = HEAP8[$38>>0]|0;
       $372 = $371&255;
       $373 = $370 >>> $372;
       $374 = (($368) + ($373)|0);
       $375 = HEAP8[$374>>0]|0;
       $$11196$shrunk = $342;$$11204$shrunk = $353;$$11212$shrunk = $364;$$11220$shrunk = $375;
       break;
      }
      case 2:  {
       $376 = HEAP16[$$21188>>1]|0;
       $377 = $376&65535;
       $378 = HEAP8[$31>>0]|0;
       $379 = $378&255;
       $380 = (79212 + ($379<<2)|0);
       $381 = HEAP32[$380>>2]|0;
       $382 = HEAP32[$39>>2]|0;
       $383 = $382 & $377;
       $384 = HEAP8[$32>>0]|0;
       $385 = $384&255;
       $386 = $383 >>> $385;
       $387 = (($381) + ($386)|0);
       $388 = HEAP8[$387>>0]|0;
       $389 = HEAP8[$33>>0]|0;
       $390 = $389&255;
       $391 = (79212 + ($390<<2)|0);
       $392 = HEAP32[$391>>2]|0;
       $393 = HEAP32[$40>>2]|0;
       $394 = $393 & $377;
       $395 = HEAP8[$34>>0]|0;
       $396 = $395&255;
       $397 = $394 >>> $396;
       $398 = (($392) + ($397)|0);
       $399 = HEAP8[$398>>0]|0;
       $400 = HEAP8[$35>>0]|0;
       $401 = $400&255;
       $402 = (79212 + ($401<<2)|0);
       $403 = HEAP32[$402>>2]|0;
       $404 = HEAP32[$41>>2]|0;
       $405 = $404 & $377;
       $406 = HEAP8[$36>>0]|0;
       $407 = $406&255;
       $408 = $405 >>> $407;
       $409 = (($403) + ($408)|0);
       $410 = HEAP8[$409>>0]|0;
       $411 = HEAP8[$37>>0]|0;
       $412 = $411&255;
       $413 = (79212 + ($412<<2)|0);
       $414 = HEAP32[$413>>2]|0;
       $415 = HEAP32[$42>>2]|0;
       $416 = $415 & $377;
       $417 = HEAP8[$38>>0]|0;
       $418 = $417&255;
       $419 = $416 >>> $418;
       $420 = (($414) + ($419)|0);
       $421 = HEAP8[$420>>0]|0;
       $$11196$shrunk = $388;$$11204$shrunk = $399;$$11212$shrunk = $410;$$11220$shrunk = $421;
       break;
      }
      case 3:  {
       $422 = HEAP8[$32>>0]|0;
       $div1279 = ($422&255) >>> 3;
       $423 = $div1279&255;
       $424 = (($$21188) + ($423)|0);
       $425 = HEAP8[$424>>0]|0;
       $426 = HEAP8[$34>>0]|0;
       $div1280 = ($426&255) >>> 3;
       $427 = $div1280&255;
       $428 = (($$21188) + ($427)|0);
       $429 = HEAP8[$428>>0]|0;
       $430 = HEAP8[$36>>0]|0;
       $div1281 = ($430&255) >>> 3;
       $431 = $div1281&255;
       $432 = (($$21188) + ($431)|0);
       $433 = HEAP8[$432>>0]|0;
       $$11196$shrunk = $425;$$11204$shrunk = $429;$$11212$shrunk = $433;$$11220$shrunk = -1;
       break;
      }
      case 4:  {
       $434 = HEAP32[$$21188>>2]|0;
       $435 = HEAP8[$31>>0]|0;
       $436 = $435&255;
       $437 = (79212 + ($436<<2)|0);
       $438 = HEAP32[$437>>2]|0;
       $439 = HEAP32[$39>>2]|0;
       $440 = $439 & $434;
       $441 = HEAP8[$32>>0]|0;
       $442 = $441&255;
       $443 = $440 >>> $442;
       $444 = (($438) + ($443)|0);
       $445 = HEAP8[$444>>0]|0;
       $446 = HEAP8[$33>>0]|0;
       $447 = $446&255;
       $448 = (79212 + ($447<<2)|0);
       $449 = HEAP32[$448>>2]|0;
       $450 = HEAP32[$40>>2]|0;
       $451 = $450 & $434;
       $452 = HEAP8[$34>>0]|0;
       $453 = $452&255;
       $454 = $451 >>> $453;
       $455 = (($449) + ($454)|0);
       $456 = HEAP8[$455>>0]|0;
       $457 = HEAP8[$35>>0]|0;
       $458 = $457&255;
       $459 = (79212 + ($458<<2)|0);
       $460 = HEAP32[$459>>2]|0;
       $461 = HEAP32[$41>>2]|0;
       $462 = $461 & $434;
       $463 = HEAP8[$36>>0]|0;
       $464 = $463&255;
       $465 = $462 >>> $464;
       $466 = (($460) + ($465)|0);
       $467 = HEAP8[$466>>0]|0;
       $468 = HEAP8[$37>>0]|0;
       $469 = $468&255;
       $470 = (79212 + ($469<<2)|0);
       $471 = HEAP32[$470>>2]|0;
       $472 = HEAP32[$42>>2]|0;
       $473 = $472 & $434;
       $474 = HEAP8[$38>>0]|0;
       $475 = $474&255;
       $476 = $473 >>> $475;
       $477 = (($471) + ($476)|0);
       $478 = HEAP8[$477>>0]|0;
       $$11196$shrunk = $445;$$11204$shrunk = $456;$$11212$shrunk = $467;$$11220$shrunk = $478;
       break;
      }
      default: {
       $$11196$shrunk = 0;$$11204$shrunk = 0;$$11212$shrunk = 0;$$11220$shrunk = 0;
      }
      }
      $$11196 = $$11196$shrunk&255;
      $$11204 = $$11204$shrunk&255;
      $$11212 = $$11212$shrunk&255;
      $$11220 = $$11220$shrunk&255;
      $479 = (($323) - ($$11196))|0;
      $480 = Math_imul($479, $21)|0;
      $481 = (($480>>>0) / 255)&-1;
      $482 = (($481) + ($$11196))|0;
      $483 = (($326) - ($$11204))|0;
      $484 = Math_imul($483, $21)|0;
      $485 = (($484>>>0) / 255)&-1;
      $486 = (($485) + ($$11204))|0;
      $487 = (($329) - ($$11212))|0;
      $488 = Math_imul($487, $21)|0;
      $489 = (($488>>>0) / 255)&-1;
      $490 = (($489) + ($$11212))|0;
      $491 = (($$11220) + ($21))|0;
      $492 = Math_imul($$11220, $21)|0;
      $493 = (($492>>>0) / 255)&-1;
      $494 = (($491) - ($493))|0;
      switch ($23<<24>>24) {
      case 1:  {
       $495 = HEAP8[$31>>0]|0;
       $496 = $495&255;
       $497 = $482 >>> $496;
       $498 = HEAP8[$32>>0]|0;
       $499 = $498&255;
       $500 = $497 << $499;
       $501 = HEAP8[$33>>0]|0;
       $502 = $501&255;
       $503 = $486 >>> $502;
       $504 = HEAP8[$34>>0]|0;
       $505 = $504&255;
       $506 = $503 << $505;
       $507 = $506 | $500;
       $508 = HEAP8[$35>>0]|0;
       $509 = $508&255;
       $510 = $490 >>> $509;
       $511 = HEAP8[$36>>0]|0;
       $512 = $511&255;
       $513 = $510 << $512;
       $514 = $507 | $513;
       $515 = HEAP8[$37>>0]|0;
       $516 = $515&255;
       $517 = $494 >>> $516;
       $518 = HEAP8[$38>>0]|0;
       $519 = $518&255;
       $520 = $517 << $519;
       $521 = $514 | $520;
       $522 = $521&255;
       HEAP8[$$21188>>0] = $522;
       break L24;
       break;
      }
      case 2:  {
       $523 = HEAP8[$31>>0]|0;
       $524 = $523&255;
       $525 = $482 >>> $524;
       $526 = HEAP8[$32>>0]|0;
       $527 = $526&255;
       $528 = $525 << $527;
       $529 = HEAP8[$33>>0]|0;
       $530 = $529&255;
       $531 = $486 >>> $530;
       $532 = HEAP8[$34>>0]|0;
       $533 = $532&255;
       $534 = $531 << $533;
       $535 = $534 | $528;
       $536 = HEAP8[$35>>0]|0;
       $537 = $536&255;
       $538 = $490 >>> $537;
       $539 = HEAP8[$36>>0]|0;
       $540 = $539&255;
       $541 = $538 << $540;
       $542 = $535 | $541;
       $543 = HEAP8[$37>>0]|0;
       $544 = $543&255;
       $545 = $494 >>> $544;
       $546 = HEAP8[$38>>0]|0;
       $547 = $546&255;
       $548 = $545 << $547;
       $549 = $542 | $548;
       $550 = $549&65535;
       HEAP16[$$21188>>1] = $550;
       break L24;
       break;
      }
      case 3:  {
       $551 = $482&255;
       $552 = HEAP8[$32>>0]|0;
       $div1276 = ($552&255) >>> 3;
       $553 = $div1276&255;
       $554 = (($$21188) + ($553)|0);
       HEAP8[$554>>0] = $551;
       $555 = $486&255;
       $556 = HEAP8[$34>>0]|0;
       $div1277 = ($556&255) >>> 3;
       $557 = $div1277&255;
       $558 = (($$21188) + ($557)|0);
       HEAP8[$558>>0] = $555;
       $559 = $490&255;
       $560 = HEAP8[$36>>0]|0;
       $div1278 = ($560&255) >>> 3;
       $561 = $div1278&255;
       $562 = (($$21188) + ($561)|0);
       HEAP8[$562>>0] = $559;
       break L24;
       break;
      }
      case 4:  {
       $563 = HEAP8[$31>>0]|0;
       $564 = $563&255;
       $565 = $482 >>> $564;
       $566 = HEAP8[$32>>0]|0;
       $567 = $566&255;
       $568 = $565 << $567;
       $569 = HEAP8[$33>>0]|0;
       $570 = $569&255;
       $571 = $486 >>> $570;
       $572 = HEAP8[$34>>0]|0;
       $573 = $572&255;
       $574 = $571 << $573;
       $575 = $574 | $568;
       $576 = HEAP8[$35>>0]|0;
       $577 = $576&255;
       $578 = $490 >>> $577;
       $579 = HEAP8[$36>>0]|0;
       $580 = $579&255;
       $581 = $578 << $580;
       $582 = $575 | $581;
       $583 = HEAP8[$37>>0]|0;
       $584 = $583&255;
       $585 = $494 >>> $584;
       $586 = HEAP8[$38>>0]|0;
       $587 = $586&255;
       $588 = $585 << $587;
       $589 = $582 | $588;
       HEAP32[$$21188>>2] = $589;
       break L24;
       break;
      }
      default: {
       break L24;
      }
      }
     }
    } while(0);
    $590 = ((($$2)) + 1|0);
    $591 = (($$21188) + ($24)|0);
    $$21229 = $$11228;$$3 = $590;$$31189 = $591;
    label = 28;
    continue;
   }
   else if ((label|0) == 28) {
    label = 0;
    $592 = HEAP8[$$3>>0]|0;
    $593 = $592&255;
    $594 = ($593|0)==($18|0);
    L39: do {
     if (!($594)) {
      $595 = (($16) + ($593<<2)|0);
      $596 = HEAP8[$595>>0]|0;
      $597 = $596&255;
      $598 = (((($16) + ($593<<2)|0)) + 1|0);
      $599 = HEAP8[$598>>0]|0;
      $600 = $599&255;
      $601 = (((($16) + ($593<<2)|0)) + 2|0);
      $602 = HEAP8[$601>>0]|0;
      $603 = $602&255;
      switch ($23<<24>>24) {
      case 1:  {
       $604 = HEAP8[$$31189>>0]|0;
       $605 = $604&255;
       $606 = HEAP8[$31>>0]|0;
       $607 = $606&255;
       $608 = (79212 + ($607<<2)|0);
       $609 = HEAP32[$608>>2]|0;
       $610 = HEAP32[$39>>2]|0;
       $611 = $610 & $605;
       $612 = HEAP8[$32>>0]|0;
       $613 = $612&255;
       $614 = $611 >>> $613;
       $615 = (($609) + ($614)|0);
       $616 = HEAP8[$615>>0]|0;
       $617 = HEAP8[$33>>0]|0;
       $618 = $617&255;
       $619 = (79212 + ($618<<2)|0);
       $620 = HEAP32[$619>>2]|0;
       $621 = HEAP32[$40>>2]|0;
       $622 = $621 & $605;
       $623 = HEAP8[$34>>0]|0;
       $624 = $623&255;
       $625 = $622 >>> $624;
       $626 = (($620) + ($625)|0);
       $627 = HEAP8[$626>>0]|0;
       $628 = HEAP8[$35>>0]|0;
       $629 = $628&255;
       $630 = (79212 + ($629<<2)|0);
       $631 = HEAP32[$630>>2]|0;
       $632 = HEAP32[$41>>2]|0;
       $633 = $632 & $605;
       $634 = HEAP8[$36>>0]|0;
       $635 = $634&255;
       $636 = $633 >>> $635;
       $637 = (($631) + ($636)|0);
       $638 = HEAP8[$637>>0]|0;
       $639 = HEAP8[$37>>0]|0;
       $640 = $639&255;
       $641 = (79212 + ($640<<2)|0);
       $642 = HEAP32[$641>>2]|0;
       $643 = HEAP32[$42>>2]|0;
       $644 = $643 & $605;
       $645 = HEAP8[$38>>0]|0;
       $646 = $645&255;
       $647 = $644 >>> $646;
       $648 = (($642) + ($647)|0);
       $649 = HEAP8[$648>>0]|0;
       $$21197$shrunk = $616;$$21205$shrunk = $627;$$21213$shrunk = $638;$$21221$shrunk = $649;
       break;
      }
      case 2:  {
       $650 = HEAP16[$$31189>>1]|0;
       $651 = $650&65535;
       $652 = HEAP8[$31>>0]|0;
       $653 = $652&255;
       $654 = (79212 + ($653<<2)|0);
       $655 = HEAP32[$654>>2]|0;
       $656 = HEAP32[$39>>2]|0;
       $657 = $656 & $651;
       $658 = HEAP8[$32>>0]|0;
       $659 = $658&255;
       $660 = $657 >>> $659;
       $661 = (($655) + ($660)|0);
       $662 = HEAP8[$661>>0]|0;
       $663 = HEAP8[$33>>0]|0;
       $664 = $663&255;
       $665 = (79212 + ($664<<2)|0);
       $666 = HEAP32[$665>>2]|0;
       $667 = HEAP32[$40>>2]|0;
       $668 = $667 & $651;
       $669 = HEAP8[$34>>0]|0;
       $670 = $669&255;
       $671 = $668 >>> $670;
       $672 = (($666) + ($671)|0);
       $673 = HEAP8[$672>>0]|0;
       $674 = HEAP8[$35>>0]|0;
       $675 = $674&255;
       $676 = (79212 + ($675<<2)|0);
       $677 = HEAP32[$676>>2]|0;
       $678 = HEAP32[$41>>2]|0;
       $679 = $678 & $651;
       $680 = HEAP8[$36>>0]|0;
       $681 = $680&255;
       $682 = $679 >>> $681;
       $683 = (($677) + ($682)|0);
       $684 = HEAP8[$683>>0]|0;
       $685 = HEAP8[$37>>0]|0;
       $686 = $685&255;
       $687 = (79212 + ($686<<2)|0);
       $688 = HEAP32[$687>>2]|0;
       $689 = HEAP32[$42>>2]|0;
       $690 = $689 & $651;
       $691 = HEAP8[$38>>0]|0;
       $692 = $691&255;
       $693 = $690 >>> $692;
       $694 = (($688) + ($693)|0);
       $695 = HEAP8[$694>>0]|0;
       $$21197$shrunk = $662;$$21205$shrunk = $673;$$21213$shrunk = $684;$$21221$shrunk = $695;
       break;
      }
      case 3:  {
       $696 = HEAP8[$32>>0]|0;
       $div1271 = ($696&255) >>> 3;
       $697 = $div1271&255;
       $698 = (($$31189) + ($697)|0);
       $699 = HEAP8[$698>>0]|0;
       $700 = HEAP8[$34>>0]|0;
       $div1272 = ($700&255) >>> 3;
       $701 = $div1272&255;
       $702 = (($$31189) + ($701)|0);
       $703 = HEAP8[$702>>0]|0;
       $704 = HEAP8[$36>>0]|0;
       $div1273 = ($704&255) >>> 3;
       $705 = $div1273&255;
       $706 = (($$31189) + ($705)|0);
       $707 = HEAP8[$706>>0]|0;
       $$21197$shrunk = $699;$$21205$shrunk = $703;$$21213$shrunk = $707;$$21221$shrunk = -1;
       break;
      }
      case 4:  {
       $708 = HEAP32[$$31189>>2]|0;
       $709 = HEAP8[$31>>0]|0;
       $710 = $709&255;
       $711 = (79212 + ($710<<2)|0);
       $712 = HEAP32[$711>>2]|0;
       $713 = HEAP32[$39>>2]|0;
       $714 = $713 & $708;
       $715 = HEAP8[$32>>0]|0;
       $716 = $715&255;
       $717 = $714 >>> $716;
       $718 = (($712) + ($717)|0);
       $719 = HEAP8[$718>>0]|0;
       $720 = HEAP8[$33>>0]|0;
       $721 = $720&255;
       $722 = (79212 + ($721<<2)|0);
       $723 = HEAP32[$722>>2]|0;
       $724 = HEAP32[$40>>2]|0;
       $725 = $724 & $708;
       $726 = HEAP8[$34>>0]|0;
       $727 = $726&255;
       $728 = $725 >>> $727;
       $729 = (($723) + ($728)|0);
       $730 = HEAP8[$729>>0]|0;
       $731 = HEAP8[$35>>0]|0;
       $732 = $731&255;
       $733 = (79212 + ($732<<2)|0);
       $734 = HEAP32[$733>>2]|0;
       $735 = HEAP32[$41>>2]|0;
       $736 = $735 & $708;
       $737 = HEAP8[$36>>0]|0;
       $738 = $737&255;
       $739 = $736 >>> $738;
       $740 = (($734) + ($739)|0);
       $741 = HEAP8[$740>>0]|0;
       $742 = HEAP8[$37>>0]|0;
       $743 = $742&255;
       $744 = (79212 + ($743<<2)|0);
       $745 = HEAP32[$744>>2]|0;
       $746 = HEAP32[$42>>2]|0;
       $747 = $746 & $708;
       $748 = HEAP8[$38>>0]|0;
       $749 = $748&255;
       $750 = $747 >>> $749;
       $751 = (($745) + ($750)|0);
       $752 = HEAP8[$751>>0]|0;
       $$21197$shrunk = $719;$$21205$shrunk = $730;$$21213$shrunk = $741;$$21221$shrunk = $752;
       break;
      }
      default: {
       $$21197$shrunk = 0;$$21205$shrunk = 0;$$21213$shrunk = 0;$$21221$shrunk = 0;
      }
      }
      $$21197 = $$21197$shrunk&255;
      $$21205 = $$21205$shrunk&255;
      $$21213 = $$21213$shrunk&255;
      $$21221 = $$21221$shrunk&255;
      $753 = (($597) - ($$21197))|0;
      $754 = Math_imul($753, $21)|0;
      $755 = (($754>>>0) / 255)&-1;
      $756 = (($755) + ($$21197))|0;
      $757 = (($600) - ($$21205))|0;
      $758 = Math_imul($757, $21)|0;
      $759 = (($758>>>0) / 255)&-1;
      $760 = (($759) + ($$21205))|0;
      $761 = (($603) - ($$21213))|0;
      $762 = Math_imul($761, $21)|0;
      $763 = (($762>>>0) / 255)&-1;
      $764 = (($763) + ($$21213))|0;
      $765 = (($$21221) + ($21))|0;
      $766 = Math_imul($$21221, $21)|0;
      $767 = (($766>>>0) / 255)&-1;
      $768 = (($765) - ($767))|0;
      switch ($23<<24>>24) {
      case 1:  {
       $769 = HEAP8[$31>>0]|0;
       $770 = $769&255;
       $771 = $756 >>> $770;
       $772 = HEAP8[$32>>0]|0;
       $773 = $772&255;
       $774 = $771 << $773;
       $775 = HEAP8[$33>>0]|0;
       $776 = $775&255;
       $777 = $760 >>> $776;
       $778 = HEAP8[$34>>0]|0;
       $779 = $778&255;
       $780 = $777 << $779;
       $781 = $780 | $774;
       $782 = HEAP8[$35>>0]|0;
       $783 = $782&255;
       $784 = $764 >>> $783;
       $785 = HEAP8[$36>>0]|0;
       $786 = $785&255;
       $787 = $784 << $786;
       $788 = $781 | $787;
       $789 = HEAP8[$37>>0]|0;
       $790 = $789&255;
       $791 = $768 >>> $790;
       $792 = HEAP8[$38>>0]|0;
       $793 = $792&255;
       $794 = $791 << $793;
       $795 = $788 | $794;
       $796 = $795&255;
       HEAP8[$$31189>>0] = $796;
       break L39;
       break;
      }
      case 2:  {
       $797 = HEAP8[$31>>0]|0;
       $798 = $797&255;
       $799 = $756 >>> $798;
       $800 = HEAP8[$32>>0]|0;
       $801 = $800&255;
       $802 = $799 << $801;
       $803 = HEAP8[$33>>0]|0;
       $804 = $803&255;
       $805 = $760 >>> $804;
       $806 = HEAP8[$34>>0]|0;
       $807 = $806&255;
       $808 = $805 << $807;
       $809 = $808 | $802;
       $810 = HEAP8[$35>>0]|0;
       $811 = $810&255;
       $812 = $764 >>> $811;
       $813 = HEAP8[$36>>0]|0;
       $814 = $813&255;
       $815 = $812 << $814;
       $816 = $809 | $815;
       $817 = HEAP8[$37>>0]|0;
       $818 = $817&255;
       $819 = $768 >>> $818;
       $820 = HEAP8[$38>>0]|0;
       $821 = $820&255;
       $822 = $819 << $821;
       $823 = $816 | $822;
       $824 = $823&65535;
       HEAP16[$$31189>>1] = $824;
       break L39;
       break;
      }
      case 3:  {
       $825 = $756&255;
       $826 = HEAP8[$32>>0]|0;
       $div1268 = ($826&255) >>> 3;
       $827 = $div1268&255;
       $828 = (($$31189) + ($827)|0);
       HEAP8[$828>>0] = $825;
       $829 = $760&255;
       $830 = HEAP8[$34>>0]|0;
       $div1269 = ($830&255) >>> 3;
       $831 = $div1269&255;
       $832 = (($$31189) + ($831)|0);
       HEAP8[$832>>0] = $829;
       $833 = $764&255;
       $834 = HEAP8[$36>>0]|0;
       $div1270 = ($834&255) >>> 3;
       $835 = $div1270&255;
       $836 = (($$31189) + ($835)|0);
       HEAP8[$836>>0] = $833;
       break L39;
       break;
      }
      case 4:  {
       $837 = HEAP8[$31>>0]|0;
       $838 = $837&255;
       $839 = $756 >>> $838;
       $840 = HEAP8[$32>>0]|0;
       $841 = $840&255;
       $842 = $839 << $841;
       $843 = HEAP8[$33>>0]|0;
       $844 = $843&255;
       $845 = $760 >>> $844;
       $846 = HEAP8[$34>>0]|0;
       $847 = $846&255;
       $848 = $845 << $847;
       $849 = $848 | $842;
       $850 = HEAP8[$35>>0]|0;
       $851 = $850&255;
       $852 = $764 >>> $851;
       $853 = HEAP8[$36>>0]|0;
       $854 = $853&255;
       $855 = $852 << $854;
       $856 = $849 | $855;
       $857 = HEAP8[$37>>0]|0;
       $858 = $857&255;
       $859 = $768 >>> $858;
       $860 = HEAP8[$38>>0]|0;
       $861 = $860&255;
       $862 = $859 << $861;
       $863 = $856 | $862;
       HEAP32[$$31189>>2] = $863;
       break L39;
       break;
      }
      default: {
       break L39;
      }
      }
     }
    } while(0);
    $864 = ((($$3)) + 1|0);
    $865 = (($$31189) + ($24)|0);
    $$31230 = $$21229;$$4 = $864;$$41190 = $865;
    label = 40;
    continue;
   }
   else if ((label|0) == 40) {
    label = 0;
    $866 = HEAP8[$$4>>0]|0;
    $867 = $866&255;
    $868 = ($867|0)==($18|0);
    L54: do {
     if (!($868)) {
      $869 = (($16) + ($867<<2)|0);
      $870 = HEAP8[$869>>0]|0;
      $871 = $870&255;
      $872 = (((($16) + ($867<<2)|0)) + 1|0);
      $873 = HEAP8[$872>>0]|0;
      $874 = $873&255;
      $875 = (((($16) + ($867<<2)|0)) + 2|0);
      $876 = HEAP8[$875>>0]|0;
      $877 = $876&255;
      switch ($23<<24>>24) {
      case 1:  {
       $878 = HEAP8[$$41190>>0]|0;
       $879 = $878&255;
       $880 = HEAP8[$31>>0]|0;
       $881 = $880&255;
       $882 = (79212 + ($881<<2)|0);
       $883 = HEAP32[$882>>2]|0;
       $884 = HEAP32[$39>>2]|0;
       $885 = $884 & $879;
       $886 = HEAP8[$32>>0]|0;
       $887 = $886&255;
       $888 = $885 >>> $887;
       $889 = (($883) + ($888)|0);
       $890 = HEAP8[$889>>0]|0;
       $891 = HEAP8[$33>>0]|0;
       $892 = $891&255;
       $893 = (79212 + ($892<<2)|0);
       $894 = HEAP32[$893>>2]|0;
       $895 = HEAP32[$40>>2]|0;
       $896 = $895 & $879;
       $897 = HEAP8[$34>>0]|0;
       $898 = $897&255;
       $899 = $896 >>> $898;
       $900 = (($894) + ($899)|0);
       $901 = HEAP8[$900>>0]|0;
       $902 = HEAP8[$35>>0]|0;
       $903 = $902&255;
       $904 = (79212 + ($903<<2)|0);
       $905 = HEAP32[$904>>2]|0;
       $906 = HEAP32[$41>>2]|0;
       $907 = $906 & $879;
       $908 = HEAP8[$36>>0]|0;
       $909 = $908&255;
       $910 = $907 >>> $909;
       $911 = (($905) + ($910)|0);
       $912 = HEAP8[$911>>0]|0;
       $913 = HEAP8[$37>>0]|0;
       $914 = $913&255;
       $915 = (79212 + ($914<<2)|0);
       $916 = HEAP32[$915>>2]|0;
       $917 = HEAP32[$42>>2]|0;
       $918 = $917 & $879;
       $919 = HEAP8[$38>>0]|0;
       $920 = $919&255;
       $921 = $918 >>> $920;
       $922 = (($916) + ($921)|0);
       $923 = HEAP8[$922>>0]|0;
       $$31198$shrunk = $890;$$31206$shrunk = $901;$$31214$shrunk = $912;$$31222$shrunk = $923;
       break;
      }
      case 2:  {
       $924 = HEAP16[$$41190>>1]|0;
       $925 = $924&65535;
       $926 = HEAP8[$31>>0]|0;
       $927 = $926&255;
       $928 = (79212 + ($927<<2)|0);
       $929 = HEAP32[$928>>2]|0;
       $930 = HEAP32[$39>>2]|0;
       $931 = $930 & $925;
       $932 = HEAP8[$32>>0]|0;
       $933 = $932&255;
       $934 = $931 >>> $933;
       $935 = (($929) + ($934)|0);
       $936 = HEAP8[$935>>0]|0;
       $937 = HEAP8[$33>>0]|0;
       $938 = $937&255;
       $939 = (79212 + ($938<<2)|0);
       $940 = HEAP32[$939>>2]|0;
       $941 = HEAP32[$40>>2]|0;
       $942 = $941 & $925;
       $943 = HEAP8[$34>>0]|0;
       $944 = $943&255;
       $945 = $942 >>> $944;
       $946 = (($940) + ($945)|0);
       $947 = HEAP8[$946>>0]|0;
       $948 = HEAP8[$35>>0]|0;
       $949 = $948&255;
       $950 = (79212 + ($949<<2)|0);
       $951 = HEAP32[$950>>2]|0;
       $952 = HEAP32[$41>>2]|0;
       $953 = $952 & $925;
       $954 = HEAP8[$36>>0]|0;
       $955 = $954&255;
       $956 = $953 >>> $955;
       $957 = (($951) + ($956)|0);
       $958 = HEAP8[$957>>0]|0;
       $959 = HEAP8[$37>>0]|0;
       $960 = $959&255;
       $961 = (79212 + ($960<<2)|0);
       $962 = HEAP32[$961>>2]|0;
       $963 = HEAP32[$42>>2]|0;
       $964 = $963 & $925;
       $965 = HEAP8[$38>>0]|0;
       $966 = $965&255;
       $967 = $964 >>> $966;
       $968 = (($962) + ($967)|0);
       $969 = HEAP8[$968>>0]|0;
       $$31198$shrunk = $936;$$31206$shrunk = $947;$$31214$shrunk = $958;$$31222$shrunk = $969;
       break;
      }
      case 3:  {
       $970 = HEAP8[$32>>0]|0;
       $div1263 = ($970&255) >>> 3;
       $971 = $div1263&255;
       $972 = (($$41190) + ($971)|0);
       $973 = HEAP8[$972>>0]|0;
       $974 = HEAP8[$34>>0]|0;
       $div1264 = ($974&255) >>> 3;
       $975 = $div1264&255;
       $976 = (($$41190) + ($975)|0);
       $977 = HEAP8[$976>>0]|0;
       $978 = HEAP8[$36>>0]|0;
       $div1265 = ($978&255) >>> 3;
       $979 = $div1265&255;
       $980 = (($$41190) + ($979)|0);
       $981 = HEAP8[$980>>0]|0;
       $$31198$shrunk = $973;$$31206$shrunk = $977;$$31214$shrunk = $981;$$31222$shrunk = -1;
       break;
      }
      case 4:  {
       $982 = HEAP32[$$41190>>2]|0;
       $983 = HEAP8[$31>>0]|0;
       $984 = $983&255;
       $985 = (79212 + ($984<<2)|0);
       $986 = HEAP32[$985>>2]|0;
       $987 = HEAP32[$39>>2]|0;
       $988 = $987 & $982;
       $989 = HEAP8[$32>>0]|0;
       $990 = $989&255;
       $991 = $988 >>> $990;
       $992 = (($986) + ($991)|0);
       $993 = HEAP8[$992>>0]|0;
       $994 = HEAP8[$33>>0]|0;
       $995 = $994&255;
       $996 = (79212 + ($995<<2)|0);
       $997 = HEAP32[$996>>2]|0;
       $998 = HEAP32[$40>>2]|0;
       $999 = $998 & $982;
       $1000 = HEAP8[$34>>0]|0;
       $1001 = $1000&255;
       $1002 = $999 >>> $1001;
       $1003 = (($997) + ($1002)|0);
       $1004 = HEAP8[$1003>>0]|0;
       $1005 = HEAP8[$35>>0]|0;
       $1006 = $1005&255;
       $1007 = (79212 + ($1006<<2)|0);
       $1008 = HEAP32[$1007>>2]|0;
       $1009 = HEAP32[$41>>2]|0;
       $1010 = $1009 & $982;
       $1011 = HEAP8[$36>>0]|0;
       $1012 = $1011&255;
       $1013 = $1010 >>> $1012;
       $1014 = (($1008) + ($1013)|0);
       $1015 = HEAP8[$1014>>0]|0;
       $1016 = HEAP8[$37>>0]|0;
       $1017 = $1016&255;
       $1018 = (79212 + ($1017<<2)|0);
       $1019 = HEAP32[$1018>>2]|0;
       $1020 = HEAP32[$42>>2]|0;
       $1021 = $1020 & $982;
       $1022 = HEAP8[$38>>0]|0;
       $1023 = $1022&255;
       $1024 = $1021 >>> $1023;
       $1025 = (($1019) + ($1024)|0);
       $1026 = HEAP8[$1025>>0]|0;
       $$31198$shrunk = $993;$$31206$shrunk = $1004;$$31214$shrunk = $1015;$$31222$shrunk = $1026;
       break;
      }
      default: {
       $$31198$shrunk = 0;$$31206$shrunk = 0;$$31214$shrunk = 0;$$31222$shrunk = 0;
      }
      }
      $$31198 = $$31198$shrunk&255;
      $$31206 = $$31206$shrunk&255;
      $$31214 = $$31214$shrunk&255;
      $$31222 = $$31222$shrunk&255;
      $1027 = (($871) - ($$31198))|0;
      $1028 = Math_imul($1027, $21)|0;
      $1029 = (($1028>>>0) / 255)&-1;
      $1030 = (($1029) + ($$31198))|0;
      $1031 = (($874) - ($$31206))|0;
      $1032 = Math_imul($1031, $21)|0;
      $1033 = (($1032>>>0) / 255)&-1;
      $1034 = (($1033) + ($$31206))|0;
      $1035 = (($877) - ($$31214))|0;
      $1036 = Math_imul($1035, $21)|0;
      $1037 = (($1036>>>0) / 255)&-1;
      $1038 = (($1037) + ($$31214))|0;
      $1039 = (($$31222) + ($21))|0;
      $1040 = Math_imul($$31222, $21)|0;
      $1041 = (($1040>>>0) / 255)&-1;
      $1042 = (($1039) - ($1041))|0;
      switch ($23<<24>>24) {
      case 1:  {
       $1043 = HEAP8[$31>>0]|0;
       $1044 = $1043&255;
       $1045 = $1030 >>> $1044;
       $1046 = HEAP8[$32>>0]|0;
       $1047 = $1046&255;
       $1048 = $1045 << $1047;
       $1049 = HEAP8[$33>>0]|0;
       $1050 = $1049&255;
       $1051 = $1034 >>> $1050;
       $1052 = HEAP8[$34>>0]|0;
       $1053 = $1052&255;
       $1054 = $1051 << $1053;
       $1055 = $1054 | $1048;
       $1056 = HEAP8[$35>>0]|0;
       $1057 = $1056&255;
       $1058 = $1038 >>> $1057;
       $1059 = HEAP8[$36>>0]|0;
       $1060 = $1059&255;
       $1061 = $1058 << $1060;
       $1062 = $1055 | $1061;
       $1063 = HEAP8[$37>>0]|0;
       $1064 = $1063&255;
       $1065 = $1042 >>> $1064;
       $1066 = HEAP8[$38>>0]|0;
       $1067 = $1066&255;
       $1068 = $1065 << $1067;
       $1069 = $1062 | $1068;
       $1070 = $1069&255;
       HEAP8[$$41190>>0] = $1070;
       break L54;
       break;
      }
      case 2:  {
       $1071 = HEAP8[$31>>0]|0;
       $1072 = $1071&255;
       $1073 = $1030 >>> $1072;
       $1074 = HEAP8[$32>>0]|0;
       $1075 = $1074&255;
       $1076 = $1073 << $1075;
       $1077 = HEAP8[$33>>0]|0;
       $1078 = $1077&255;
       $1079 = $1034 >>> $1078;
       $1080 = HEAP8[$34>>0]|0;
       $1081 = $1080&255;
       $1082 = $1079 << $1081;
       $1083 = $1082 | $1076;
       $1084 = HEAP8[$35>>0]|0;
       $1085 = $1084&255;
       $1086 = $1038 >>> $1085;
       $1087 = HEAP8[$36>>0]|0;
       $1088 = $1087&255;
       $1089 = $1086 << $1088;
       $1090 = $1083 | $1089;
       $1091 = HEAP8[$37>>0]|0;
       $1092 = $1091&255;
       $1093 = $1042 >>> $1092;
       $1094 = HEAP8[$38>>0]|0;
       $1095 = $1094&255;
       $1096 = $1093 << $1095;
       $1097 = $1090 | $1096;
       $1098 = $1097&65535;
       HEAP16[$$41190>>1] = $1098;
       break L54;
       break;
      }
      case 3:  {
       $1099 = $1030&255;
       $1100 = HEAP8[$32>>0]|0;
       $div1260 = ($1100&255) >>> 3;
       $1101 = $div1260&255;
       $1102 = (($$41190) + ($1101)|0);
       HEAP8[$1102>>0] = $1099;
       $1103 = $1034&255;
       $1104 = HEAP8[$34>>0]|0;
       $div1261 = ($1104&255) >>> 3;
       $1105 = $div1261&255;
       $1106 = (($$41190) + ($1105)|0);
       HEAP8[$1106>>0] = $1103;
       $1107 = $1038&255;
       $1108 = HEAP8[$36>>0]|0;
       $div1262 = ($1108&255) >>> 3;
       $1109 = $div1262&255;
       $1110 = (($$41190) + ($1109)|0);
       HEAP8[$1110>>0] = $1107;
       break L54;
       break;
      }
      case 4:  {
       $1111 = HEAP8[$31>>0]|0;
       $1112 = $1111&255;
       $1113 = $1030 >>> $1112;
       $1114 = HEAP8[$32>>0]|0;
       $1115 = $1114&255;
       $1116 = $1113 << $1115;
       $1117 = HEAP8[$33>>0]|0;
       $1118 = $1117&255;
       $1119 = $1034 >>> $1118;
       $1120 = HEAP8[$34>>0]|0;
       $1121 = $1120&255;
       $1122 = $1119 << $1121;
       $1123 = $1122 | $1116;
       $1124 = HEAP8[$35>>0]|0;
       $1125 = $1124&255;
       $1126 = $1038 >>> $1125;
       $1127 = HEAP8[$36>>0]|0;
       $1128 = $1127&255;
       $1129 = $1126 << $1128;
       $1130 = $1123 | $1129;
       $1131 = HEAP8[$37>>0]|0;
       $1132 = $1131&255;
       $1133 = $1042 >>> $1132;
       $1134 = HEAP8[$38>>0]|0;
       $1135 = $1134&255;
       $1136 = $1133 << $1135;
       $1137 = $1130 | $1136;
       HEAP32[$$41190>>2] = $1137;
       break L54;
       break;
      }
      default: {
       break L54;
      }
      }
     }
    } while(0);
    $1138 = ((($$4)) + 1|0);
    $1139 = (($$41190) + ($24)|0);
    $$41231 = $$31230;$$5 = $1138;$$51191 = $1139;
    label = 52;
    continue;
   }
   else if ((label|0) == 52) {
    label = 0;
    $1140 = HEAP8[$$5>>0]|0;
    $1141 = $1140&255;
    $1142 = ($1141|0)==($18|0);
    L69: do {
     if (!($1142)) {
      $1143 = (($16) + ($1141<<2)|0);
      $1144 = HEAP8[$1143>>0]|0;
      $1145 = $1144&255;
      $1146 = (((($16) + ($1141<<2)|0)) + 1|0);
      $1147 = HEAP8[$1146>>0]|0;
      $1148 = $1147&255;
      $1149 = (((($16) + ($1141<<2)|0)) + 2|0);
      $1150 = HEAP8[$1149>>0]|0;
      $1151 = $1150&255;
      switch ($23<<24>>24) {
      case 1:  {
       $1152 = HEAP8[$$51191>>0]|0;
       $1153 = $1152&255;
       $1154 = HEAP8[$31>>0]|0;
       $1155 = $1154&255;
       $1156 = (79212 + ($1155<<2)|0);
       $1157 = HEAP32[$1156>>2]|0;
       $1158 = HEAP32[$39>>2]|0;
       $1159 = $1158 & $1153;
       $1160 = HEAP8[$32>>0]|0;
       $1161 = $1160&255;
       $1162 = $1159 >>> $1161;
       $1163 = (($1157) + ($1162)|0);
       $1164 = HEAP8[$1163>>0]|0;
       $1165 = HEAP8[$33>>0]|0;
       $1166 = $1165&255;
       $1167 = (79212 + ($1166<<2)|0);
       $1168 = HEAP32[$1167>>2]|0;
       $1169 = HEAP32[$40>>2]|0;
       $1170 = $1169 & $1153;
       $1171 = HEAP8[$34>>0]|0;
       $1172 = $1171&255;
       $1173 = $1170 >>> $1172;
       $1174 = (($1168) + ($1173)|0);
       $1175 = HEAP8[$1174>>0]|0;
       $1176 = HEAP8[$35>>0]|0;
       $1177 = $1176&255;
       $1178 = (79212 + ($1177<<2)|0);
       $1179 = HEAP32[$1178>>2]|0;
       $1180 = HEAP32[$41>>2]|0;
       $1181 = $1180 & $1153;
       $1182 = HEAP8[$36>>0]|0;
       $1183 = $1182&255;
       $1184 = $1181 >>> $1183;
       $1185 = (($1179) + ($1184)|0);
       $1186 = HEAP8[$1185>>0]|0;
       $1187 = HEAP8[$37>>0]|0;
       $1188 = $1187&255;
       $1189 = (79212 + ($1188<<2)|0);
       $1190 = HEAP32[$1189>>2]|0;
       $1191 = HEAP32[$42>>2]|0;
       $1192 = $1191 & $1153;
       $1193 = HEAP8[$38>>0]|0;
       $1194 = $1193&255;
       $1195 = $1192 >>> $1194;
       $1196 = (($1190) + ($1195)|0);
       $1197 = HEAP8[$1196>>0]|0;
       $$41199$shrunk = $1164;$$41207$shrunk = $1175;$$41215$shrunk = $1186;$$41223$shrunk = $1197;
       break;
      }
      case 2:  {
       $1198 = HEAP16[$$51191>>1]|0;
       $1199 = $1198&65535;
       $1200 = HEAP8[$31>>0]|0;
       $1201 = $1200&255;
       $1202 = (79212 + ($1201<<2)|0);
       $1203 = HEAP32[$1202>>2]|0;
       $1204 = HEAP32[$39>>2]|0;
       $1205 = $1204 & $1199;
       $1206 = HEAP8[$32>>0]|0;
       $1207 = $1206&255;
       $1208 = $1205 >>> $1207;
       $1209 = (($1203) + ($1208)|0);
       $1210 = HEAP8[$1209>>0]|0;
       $1211 = HEAP8[$33>>0]|0;
       $1212 = $1211&255;
       $1213 = (79212 + ($1212<<2)|0);
       $1214 = HEAP32[$1213>>2]|0;
       $1215 = HEAP32[$40>>2]|0;
       $1216 = $1215 & $1199;
       $1217 = HEAP8[$34>>0]|0;
       $1218 = $1217&255;
       $1219 = $1216 >>> $1218;
       $1220 = (($1214) + ($1219)|0);
       $1221 = HEAP8[$1220>>0]|0;
       $1222 = HEAP8[$35>>0]|0;
       $1223 = $1222&255;
       $1224 = (79212 + ($1223<<2)|0);
       $1225 = HEAP32[$1224>>2]|0;
       $1226 = HEAP32[$41>>2]|0;
       $1227 = $1226 & $1199;
       $1228 = HEAP8[$36>>0]|0;
       $1229 = $1228&255;
       $1230 = $1227 >>> $1229;
       $1231 = (($1225) + ($1230)|0);
       $1232 = HEAP8[$1231>>0]|0;
       $1233 = HEAP8[$37>>0]|0;
       $1234 = $1233&255;
       $1235 = (79212 + ($1234<<2)|0);
       $1236 = HEAP32[$1235>>2]|0;
       $1237 = HEAP32[$42>>2]|0;
       $1238 = $1237 & $1199;
       $1239 = HEAP8[$38>>0]|0;
       $1240 = $1239&255;
       $1241 = $1238 >>> $1240;
       $1242 = (($1236) + ($1241)|0);
       $1243 = HEAP8[$1242>>0]|0;
       $$41199$shrunk = $1210;$$41207$shrunk = $1221;$$41215$shrunk = $1232;$$41223$shrunk = $1243;
       break;
      }
      case 3:  {
       $1244 = HEAP8[$32>>0]|0;
       $div1255 = ($1244&255) >>> 3;
       $1245 = $div1255&255;
       $1246 = (($$51191) + ($1245)|0);
       $1247 = HEAP8[$1246>>0]|0;
       $1248 = HEAP8[$34>>0]|0;
       $div1256 = ($1248&255) >>> 3;
       $1249 = $div1256&255;
       $1250 = (($$51191) + ($1249)|0);
       $1251 = HEAP8[$1250>>0]|0;
       $1252 = HEAP8[$36>>0]|0;
       $div1257 = ($1252&255) >>> 3;
       $1253 = $div1257&255;
       $1254 = (($$51191) + ($1253)|0);
       $1255 = HEAP8[$1254>>0]|0;
       $$41199$shrunk = $1247;$$41207$shrunk = $1251;$$41215$shrunk = $1255;$$41223$shrunk = -1;
       break;
      }
      case 4:  {
       $1256 = HEAP32[$$51191>>2]|0;
       $1257 = HEAP8[$31>>0]|0;
       $1258 = $1257&255;
       $1259 = (79212 + ($1258<<2)|0);
       $1260 = HEAP32[$1259>>2]|0;
       $1261 = HEAP32[$39>>2]|0;
       $1262 = $1261 & $1256;
       $1263 = HEAP8[$32>>0]|0;
       $1264 = $1263&255;
       $1265 = $1262 >>> $1264;
       $1266 = (($1260) + ($1265)|0);
       $1267 = HEAP8[$1266>>0]|0;
       $1268 = HEAP8[$33>>0]|0;
       $1269 = $1268&255;
       $1270 = (79212 + ($1269<<2)|0);
       $1271 = HEAP32[$1270>>2]|0;
       $1272 = HEAP32[$40>>2]|0;
       $1273 = $1272 & $1256;
       $1274 = HEAP8[$34>>0]|0;
       $1275 = $1274&255;
       $1276 = $1273 >>> $1275;
       $1277 = (($1271) + ($1276)|0);
       $1278 = HEAP8[$1277>>0]|0;
       $1279 = HEAP8[$35>>0]|0;
       $1280 = $1279&255;
       $1281 = (79212 + ($1280<<2)|0);
       $1282 = HEAP32[$1281>>2]|0;
       $1283 = HEAP32[$41>>2]|0;
       $1284 = $1283 & $1256;
       $1285 = HEAP8[$36>>0]|0;
       $1286 = $1285&255;
       $1287 = $1284 >>> $1286;
       $1288 = (($1282) + ($1287)|0);
       $1289 = HEAP8[$1288>>0]|0;
       $1290 = HEAP8[$37>>0]|0;
       $1291 = $1290&255;
       $1292 = (79212 + ($1291<<2)|0);
       $1293 = HEAP32[$1292>>2]|0;
       $1294 = HEAP32[$42>>2]|0;
       $1295 = $1294 & $1256;
       $1296 = HEAP8[$38>>0]|0;
       $1297 = $1296&255;
       $1298 = $1295 >>> $1297;
       $1299 = (($1293) + ($1298)|0);
       $1300 = HEAP8[$1299>>0]|0;
       $$41199$shrunk = $1267;$$41207$shrunk = $1278;$$41215$shrunk = $1289;$$41223$shrunk = $1300;
       break;
      }
      default: {
       $$41199$shrunk = 0;$$41207$shrunk = 0;$$41215$shrunk = 0;$$41223$shrunk = 0;
      }
      }
      $$41199 = $$41199$shrunk&255;
      $$41207 = $$41207$shrunk&255;
      $$41215 = $$41215$shrunk&255;
      $$41223 = $$41223$shrunk&255;
      $1301 = (($1145) - ($$41199))|0;
      $1302 = Math_imul($1301, $21)|0;
      $1303 = (($1302>>>0) / 255)&-1;
      $1304 = (($1303) + ($$41199))|0;
      $1305 = (($1148) - ($$41207))|0;
      $1306 = Math_imul($1305, $21)|0;
      $1307 = (($1306>>>0) / 255)&-1;
      $1308 = (($1307) + ($$41207))|0;
      $1309 = (($1151) - ($$41215))|0;
      $1310 = Math_imul($1309, $21)|0;
      $1311 = (($1310>>>0) / 255)&-1;
      $1312 = (($1311) + ($$41215))|0;
      $1313 = (($$41223) + ($21))|0;
      $1314 = Math_imul($$41223, $21)|0;
      $1315 = (($1314>>>0) / 255)&-1;
      $1316 = (($1313) - ($1315))|0;
      switch ($23<<24>>24) {
      case 1:  {
       $1317 = HEAP8[$31>>0]|0;
       $1318 = $1317&255;
       $1319 = $1304 >>> $1318;
       $1320 = HEAP8[$32>>0]|0;
       $1321 = $1320&255;
       $1322 = $1319 << $1321;
       $1323 = HEAP8[$33>>0]|0;
       $1324 = $1323&255;
       $1325 = $1308 >>> $1324;
       $1326 = HEAP8[$34>>0]|0;
       $1327 = $1326&255;
       $1328 = $1325 << $1327;
       $1329 = $1328 | $1322;
       $1330 = HEAP8[$35>>0]|0;
       $1331 = $1330&255;
       $1332 = $1312 >>> $1331;
       $1333 = HEAP8[$36>>0]|0;
       $1334 = $1333&255;
       $1335 = $1332 << $1334;
       $1336 = $1329 | $1335;
       $1337 = HEAP8[$37>>0]|0;
       $1338 = $1337&255;
       $1339 = $1316 >>> $1338;
       $1340 = HEAP8[$38>>0]|0;
       $1341 = $1340&255;
       $1342 = $1339 << $1341;
       $1343 = $1336 | $1342;
       $1344 = $1343&255;
       HEAP8[$$51191>>0] = $1344;
       break L69;
       break;
      }
      case 2:  {
       $1345 = HEAP8[$31>>0]|0;
       $1346 = $1345&255;
       $1347 = $1304 >>> $1346;
       $1348 = HEAP8[$32>>0]|0;
       $1349 = $1348&255;
       $1350 = $1347 << $1349;
       $1351 = HEAP8[$33>>0]|0;
       $1352 = $1351&255;
       $1353 = $1308 >>> $1352;
       $1354 = HEAP8[$34>>0]|0;
       $1355 = $1354&255;
       $1356 = $1353 << $1355;
       $1357 = $1356 | $1350;
       $1358 = HEAP8[$35>>0]|0;
       $1359 = $1358&255;
       $1360 = $1312 >>> $1359;
       $1361 = HEAP8[$36>>0]|0;
       $1362 = $1361&255;
       $1363 = $1360 << $1362;
       $1364 = $1357 | $1363;
       $1365 = HEAP8[$37>>0]|0;
       $1366 = $1365&255;
       $1367 = $1316 >>> $1366;
       $1368 = HEAP8[$38>>0]|0;
       $1369 = $1368&255;
       $1370 = $1367 << $1369;
       $1371 = $1364 | $1370;
       $1372 = $1371&65535;
       HEAP16[$$51191>>1] = $1372;
       break L69;
       break;
      }
      case 3:  {
       $1373 = $1304&255;
       $1374 = HEAP8[$32>>0]|0;
       $div1252 = ($1374&255) >>> 3;
       $1375 = $div1252&255;
       $1376 = (($$51191) + ($1375)|0);
       HEAP8[$1376>>0] = $1373;
       $1377 = $1308&255;
       $1378 = HEAP8[$34>>0]|0;
       $div1253 = ($1378&255) >>> 3;
       $1379 = $div1253&255;
       $1380 = (($$51191) + ($1379)|0);
       HEAP8[$1380>>0] = $1377;
       $1381 = $1312&255;
       $1382 = HEAP8[$36>>0]|0;
       $div1254 = ($1382&255) >>> 3;
       $1383 = $div1254&255;
       $1384 = (($$51191) + ($1383)|0);
       HEAP8[$1384>>0] = $1381;
       break L69;
       break;
      }
      case 4:  {
       $1385 = HEAP8[$31>>0]|0;
       $1386 = $1385&255;
       $1387 = $1304 >>> $1386;
       $1388 = HEAP8[$32>>0]|0;
       $1389 = $1388&255;
       $1390 = $1387 << $1389;
       $1391 = HEAP8[$33>>0]|0;
       $1392 = $1391&255;
       $1393 = $1308 >>> $1392;
       $1394 = HEAP8[$34>>0]|0;
       $1395 = $1394&255;
       $1396 = $1393 << $1395;
       $1397 = $1396 | $1390;
       $1398 = HEAP8[$35>>0]|0;
       $1399 = $1398&255;
       $1400 = $1312 >>> $1399;
       $1401 = HEAP8[$36>>0]|0;
       $1402 = $1401&255;
       $1403 = $1400 << $1402;
       $1404 = $1397 | $1403;
       $1405 = HEAP8[$37>>0]|0;
       $1406 = $1405&255;
       $1407 = $1316 >>> $1406;
       $1408 = HEAP8[$38>>0]|0;
       $1409 = $1408&255;
       $1410 = $1407 << $1409;
       $1411 = $1404 | $1410;
       HEAP32[$$51191>>2] = $1411;
       break L69;
       break;
      }
      default: {
       break L69;
      }
      }
     }
    } while(0);
    $1412 = ((($$5)) + 1|0);
    $1413 = (($$51191) + ($24)|0);
    $$51232 = $$41231;$$6 = $1412;$$61192 = $1413;
    label = 64;
    continue;
   }
   else if ((label|0) == 64) {
    label = 0;
    $1414 = HEAP8[$$6>>0]|0;
    $1415 = $1414&255;
    $1416 = ($1415|0)==($18|0);
    L84: do {
     if (!($1416)) {
      $1417 = (($16) + ($1415<<2)|0);
      $1418 = HEAP8[$1417>>0]|0;
      $1419 = $1418&255;
      $1420 = (((($16) + ($1415<<2)|0)) + 1|0);
      $1421 = HEAP8[$1420>>0]|0;
      $1422 = $1421&255;
      $1423 = (((($16) + ($1415<<2)|0)) + 2|0);
      $1424 = HEAP8[$1423>>0]|0;
      $1425 = $1424&255;
      switch ($23<<24>>24) {
      case 1:  {
       $1426 = HEAP8[$$61192>>0]|0;
       $1427 = $1426&255;
       $1428 = HEAP8[$31>>0]|0;
       $1429 = $1428&255;
       $1430 = (79212 + ($1429<<2)|0);
       $1431 = HEAP32[$1430>>2]|0;
       $1432 = HEAP32[$39>>2]|0;
       $1433 = $1432 & $1427;
       $1434 = HEAP8[$32>>0]|0;
       $1435 = $1434&255;
       $1436 = $1433 >>> $1435;
       $1437 = (($1431) + ($1436)|0);
       $1438 = HEAP8[$1437>>0]|0;
       $1439 = HEAP8[$33>>0]|0;
       $1440 = $1439&255;
       $1441 = (79212 + ($1440<<2)|0);
       $1442 = HEAP32[$1441>>2]|0;
       $1443 = HEAP32[$40>>2]|0;
       $1444 = $1443 & $1427;
       $1445 = HEAP8[$34>>0]|0;
       $1446 = $1445&255;
       $1447 = $1444 >>> $1446;
       $1448 = (($1442) + ($1447)|0);
       $1449 = HEAP8[$1448>>0]|0;
       $1450 = HEAP8[$35>>0]|0;
       $1451 = $1450&255;
       $1452 = (79212 + ($1451<<2)|0);
       $1453 = HEAP32[$1452>>2]|0;
       $1454 = HEAP32[$41>>2]|0;
       $1455 = $1454 & $1427;
       $1456 = HEAP8[$36>>0]|0;
       $1457 = $1456&255;
       $1458 = $1455 >>> $1457;
       $1459 = (($1453) + ($1458)|0);
       $1460 = HEAP8[$1459>>0]|0;
       $1461 = HEAP8[$37>>0]|0;
       $1462 = $1461&255;
       $1463 = (79212 + ($1462<<2)|0);
       $1464 = HEAP32[$1463>>2]|0;
       $1465 = HEAP32[$42>>2]|0;
       $1466 = $1465 & $1427;
       $1467 = HEAP8[$38>>0]|0;
       $1468 = $1467&255;
       $1469 = $1466 >>> $1468;
       $1470 = (($1464) + ($1469)|0);
       $1471 = HEAP8[$1470>>0]|0;
       $$51200$shrunk = $1438;$$51208$shrunk = $1449;$$51216$shrunk = $1460;$$51224$shrunk = $1471;
       break;
      }
      case 2:  {
       $1472 = HEAP16[$$61192>>1]|0;
       $1473 = $1472&65535;
       $1474 = HEAP8[$31>>0]|0;
       $1475 = $1474&255;
       $1476 = (79212 + ($1475<<2)|0);
       $1477 = HEAP32[$1476>>2]|0;
       $1478 = HEAP32[$39>>2]|0;
       $1479 = $1478 & $1473;
       $1480 = HEAP8[$32>>0]|0;
       $1481 = $1480&255;
       $1482 = $1479 >>> $1481;
       $1483 = (($1477) + ($1482)|0);
       $1484 = HEAP8[$1483>>0]|0;
       $1485 = HEAP8[$33>>0]|0;
       $1486 = $1485&255;
       $1487 = (79212 + ($1486<<2)|0);
       $1488 = HEAP32[$1487>>2]|0;
       $1489 = HEAP32[$40>>2]|0;
       $1490 = $1489 & $1473;
       $1491 = HEAP8[$34>>0]|0;
       $1492 = $1491&255;
       $1493 = $1490 >>> $1492;
       $1494 = (($1488) + ($1493)|0);
       $1495 = HEAP8[$1494>>0]|0;
       $1496 = HEAP8[$35>>0]|0;
       $1497 = $1496&255;
       $1498 = (79212 + ($1497<<2)|0);
       $1499 = HEAP32[$1498>>2]|0;
       $1500 = HEAP32[$41>>2]|0;
       $1501 = $1500 & $1473;
       $1502 = HEAP8[$36>>0]|0;
       $1503 = $1502&255;
       $1504 = $1501 >>> $1503;
       $1505 = (($1499) + ($1504)|0);
       $1506 = HEAP8[$1505>>0]|0;
       $1507 = HEAP8[$37>>0]|0;
       $1508 = $1507&255;
       $1509 = (79212 + ($1508<<2)|0);
       $1510 = HEAP32[$1509>>2]|0;
       $1511 = HEAP32[$42>>2]|0;
       $1512 = $1511 & $1473;
       $1513 = HEAP8[$38>>0]|0;
       $1514 = $1513&255;
       $1515 = $1512 >>> $1514;
       $1516 = (($1510) + ($1515)|0);
       $1517 = HEAP8[$1516>>0]|0;
       $$51200$shrunk = $1484;$$51208$shrunk = $1495;$$51216$shrunk = $1506;$$51224$shrunk = $1517;
       break;
      }
      case 3:  {
       $1518 = HEAP8[$32>>0]|0;
       $div1247 = ($1518&255) >>> 3;
       $1519 = $div1247&255;
       $1520 = (($$61192) + ($1519)|0);
       $1521 = HEAP8[$1520>>0]|0;
       $1522 = HEAP8[$34>>0]|0;
       $div1248 = ($1522&255) >>> 3;
       $1523 = $div1248&255;
       $1524 = (($$61192) + ($1523)|0);
       $1525 = HEAP8[$1524>>0]|0;
       $1526 = HEAP8[$36>>0]|0;
       $div1249 = ($1526&255) >>> 3;
       $1527 = $div1249&255;
       $1528 = (($$61192) + ($1527)|0);
       $1529 = HEAP8[$1528>>0]|0;
       $$51200$shrunk = $1521;$$51208$shrunk = $1525;$$51216$shrunk = $1529;$$51224$shrunk = -1;
       break;
      }
      case 4:  {
       $1530 = HEAP32[$$61192>>2]|0;
       $1531 = HEAP8[$31>>0]|0;
       $1532 = $1531&255;
       $1533 = (79212 + ($1532<<2)|0);
       $1534 = HEAP32[$1533>>2]|0;
       $1535 = HEAP32[$39>>2]|0;
       $1536 = $1535 & $1530;
       $1537 = HEAP8[$32>>0]|0;
       $1538 = $1537&255;
       $1539 = $1536 >>> $1538;
       $1540 = (($1534) + ($1539)|0);
       $1541 = HEAP8[$1540>>0]|0;
       $1542 = HEAP8[$33>>0]|0;
       $1543 = $1542&255;
       $1544 = (79212 + ($1543<<2)|0);
       $1545 = HEAP32[$1544>>2]|0;
       $1546 = HEAP32[$40>>2]|0;
       $1547 = $1546 & $1530;
       $1548 = HEAP8[$34>>0]|0;
       $1549 = $1548&255;
       $1550 = $1547 >>> $1549;
       $1551 = (($1545) + ($1550)|0);
       $1552 = HEAP8[$1551>>0]|0;
       $1553 = HEAP8[$35>>0]|0;
       $1554 = $1553&255;
       $1555 = (79212 + ($1554<<2)|0);
       $1556 = HEAP32[$1555>>2]|0;
       $1557 = HEAP32[$41>>2]|0;
       $1558 = $1557 & $1530;
       $1559 = HEAP8[$36>>0]|0;
       $1560 = $1559&255;
       $1561 = $1558 >>> $1560;
       $1562 = (($1556) + ($1561)|0);
       $1563 = HEAP8[$1562>>0]|0;
       $1564 = HEAP8[$37>>0]|0;
       $1565 = $1564&255;
       $1566 = (79212 + ($1565<<2)|0);
       $1567 = HEAP32[$1566>>2]|0;
       $1568 = HEAP32[$42>>2]|0;
       $1569 = $1568 & $1530;
       $1570 = HEAP8[$38>>0]|0;
       $1571 = $1570&255;
       $1572 = $1569 >>> $1571;
       $1573 = (($1567) + ($1572)|0);
       $1574 = HEAP8[$1573>>0]|0;
       $$51200$shrunk = $1541;$$51208$shrunk = $1552;$$51216$shrunk = $1563;$$51224$shrunk = $1574;
       break;
      }
      default: {
       $$51200$shrunk = 0;$$51208$shrunk = 0;$$51216$shrunk = 0;$$51224$shrunk = 0;
      }
      }
      $$51200 = $$51200$shrunk&255;
      $$51208 = $$51208$shrunk&255;
      $$51216 = $$51216$shrunk&255;
      $$51224 = $$51224$shrunk&255;
      $1575 = (($1419) - ($$51200))|0;
      $1576 = Math_imul($1575, $21)|0;
      $1577 = (($1576>>>0) / 255)&-1;
      $1578 = (($1577) + ($$51200))|0;
      $1579 = (($1422) - ($$51208))|0;
      $1580 = Math_imul($1579, $21)|0;
      $1581 = (($1580>>>0) / 255)&-1;
      $1582 = (($1581) + ($$51208))|0;
      $1583 = (($1425) - ($$51216))|0;
      $1584 = Math_imul($1583, $21)|0;
      $1585 = (($1584>>>0) / 255)&-1;
      $1586 = (($1585) + ($$51216))|0;
      $1587 = (($$51224) + ($21))|0;
      $1588 = Math_imul($$51224, $21)|0;
      $1589 = (($1588>>>0) / 255)&-1;
      $1590 = (($1587) - ($1589))|0;
      switch ($23<<24>>24) {
      case 1:  {
       $1591 = HEAP8[$31>>0]|0;
       $1592 = $1591&255;
       $1593 = $1578 >>> $1592;
       $1594 = HEAP8[$32>>0]|0;
       $1595 = $1594&255;
       $1596 = $1593 << $1595;
       $1597 = HEAP8[$33>>0]|0;
       $1598 = $1597&255;
       $1599 = $1582 >>> $1598;
       $1600 = HEAP8[$34>>0]|0;
       $1601 = $1600&255;
       $1602 = $1599 << $1601;
       $1603 = $1602 | $1596;
       $1604 = HEAP8[$35>>0]|0;
       $1605 = $1604&255;
       $1606 = $1586 >>> $1605;
       $1607 = HEAP8[$36>>0]|0;
       $1608 = $1607&255;
       $1609 = $1606 << $1608;
       $1610 = $1603 | $1609;
       $1611 = HEAP8[$37>>0]|0;
       $1612 = $1611&255;
       $1613 = $1590 >>> $1612;
       $1614 = HEAP8[$38>>0]|0;
       $1615 = $1614&255;
       $1616 = $1613 << $1615;
       $1617 = $1610 | $1616;
       $1618 = $1617&255;
       HEAP8[$$61192>>0] = $1618;
       break L84;
       break;
      }
      case 2:  {
       $1619 = HEAP8[$31>>0]|0;
       $1620 = $1619&255;
       $1621 = $1578 >>> $1620;
       $1622 = HEAP8[$32>>0]|0;
       $1623 = $1622&255;
       $1624 = $1621 << $1623;
       $1625 = HEAP8[$33>>0]|0;
       $1626 = $1625&255;
       $1627 = $1582 >>> $1626;
       $1628 = HEAP8[$34>>0]|0;
       $1629 = $1628&255;
       $1630 = $1627 << $1629;
       $1631 = $1630 | $1624;
       $1632 = HEAP8[$35>>0]|0;
       $1633 = $1632&255;
       $1634 = $1586 >>> $1633;
       $1635 = HEAP8[$36>>0]|0;
       $1636 = $1635&255;
       $1637 = $1634 << $1636;
       $1638 = $1631 | $1637;
       $1639 = HEAP8[$37>>0]|0;
       $1640 = $1639&255;
       $1641 = $1590 >>> $1640;
       $1642 = HEAP8[$38>>0]|0;
       $1643 = $1642&255;
       $1644 = $1641 << $1643;
       $1645 = $1638 | $1644;
       $1646 = $1645&65535;
       HEAP16[$$61192>>1] = $1646;
       break L84;
       break;
      }
      case 3:  {
       $1647 = $1578&255;
       $1648 = HEAP8[$32>>0]|0;
       $div1244 = ($1648&255) >>> 3;
       $1649 = $div1244&255;
       $1650 = (($$61192) + ($1649)|0);
       HEAP8[$1650>>0] = $1647;
       $1651 = $1582&255;
       $1652 = HEAP8[$34>>0]|0;
       $div1245 = ($1652&255) >>> 3;
       $1653 = $div1245&255;
       $1654 = (($$61192) + ($1653)|0);
       HEAP8[$1654>>0] = $1651;
       $1655 = $1586&255;
       $1656 = HEAP8[$36>>0]|0;
       $div1246 = ($1656&255) >>> 3;
       $1657 = $div1246&255;
       $1658 = (($$61192) + ($1657)|0);
       HEAP8[$1658>>0] = $1655;
       break L84;
       break;
      }
      case 4:  {
       $1659 = HEAP8[$31>>0]|0;
       $1660 = $1659&255;
       $1661 = $1578 >>> $1660;
       $1662 = HEAP8[$32>>0]|0;
       $1663 = $1662&255;
       $1664 = $1661 << $1663;
       $1665 = HEAP8[$33>>0]|0;
       $1666 = $1665&255;
       $1667 = $1582 >>> $1666;
       $1668 = HEAP8[$34>>0]|0;
       $1669 = $1668&255;
       $1670 = $1667 << $1669;
       $1671 = $1670 | $1664;
       $1672 = HEAP8[$35>>0]|0;
       $1673 = $1672&255;
       $1674 = $1586 >>> $1673;
       $1675 = HEAP8[$36>>0]|0;
       $1676 = $1675&255;
       $1677 = $1674 << $1676;
       $1678 = $1671 | $1677;
       $1679 = HEAP8[$37>>0]|0;
       $1680 = $1679&255;
       $1681 = $1590 >>> $1680;
       $1682 = HEAP8[$38>>0]|0;
       $1683 = $1682&255;
       $1684 = $1681 << $1683;
       $1685 = $1678 | $1684;
       HEAP32[$$61192>>2] = $1685;
       break L84;
       break;
      }
      default: {
       break L84;
      }
      }
     }
    } while(0);
    $1686 = ((($$6)) + 1|0);
    $1687 = (($$61192) + ($24)|0);
    $$61233 = $$51232;$$7 = $1686;$$71193 = $1687;
    label = 76;
    continue;
   }
   else if ((label|0) == 76) {
    label = 0;
    $1688 = HEAP8[$$7>>0]|0;
    $1689 = $1688&255;
    $1690 = ($1689|0)==($18|0);
    L99: do {
     if (!($1690)) {
      $1691 = (($16) + ($1689<<2)|0);
      $1692 = HEAP8[$1691>>0]|0;
      $1693 = $1692&255;
      $1694 = (((($16) + ($1689<<2)|0)) + 1|0);
      $1695 = HEAP8[$1694>>0]|0;
      $1696 = $1695&255;
      $1697 = (((($16) + ($1689<<2)|0)) + 2|0);
      $1698 = HEAP8[$1697>>0]|0;
      $1699 = $1698&255;
      switch ($23<<24>>24) {
      case 1:  {
       $1700 = HEAP8[$$71193>>0]|0;
       $1701 = $1700&255;
       $1702 = HEAP8[$31>>0]|0;
       $1703 = $1702&255;
       $1704 = (79212 + ($1703<<2)|0);
       $1705 = HEAP32[$1704>>2]|0;
       $1706 = HEAP32[$39>>2]|0;
       $1707 = $1706 & $1701;
       $1708 = HEAP8[$32>>0]|0;
       $1709 = $1708&255;
       $1710 = $1707 >>> $1709;
       $1711 = (($1705) + ($1710)|0);
       $1712 = HEAP8[$1711>>0]|0;
       $1713 = HEAP8[$33>>0]|0;
       $1714 = $1713&255;
       $1715 = (79212 + ($1714<<2)|0);
       $1716 = HEAP32[$1715>>2]|0;
       $1717 = HEAP32[$40>>2]|0;
       $1718 = $1717 & $1701;
       $1719 = HEAP8[$34>>0]|0;
       $1720 = $1719&255;
       $1721 = $1718 >>> $1720;
       $1722 = (($1716) + ($1721)|0);
       $1723 = HEAP8[$1722>>0]|0;
       $1724 = HEAP8[$35>>0]|0;
       $1725 = $1724&255;
       $1726 = (79212 + ($1725<<2)|0);
       $1727 = HEAP32[$1726>>2]|0;
       $1728 = HEAP32[$41>>2]|0;
       $1729 = $1728 & $1701;
       $1730 = HEAP8[$36>>0]|0;
       $1731 = $1730&255;
       $1732 = $1729 >>> $1731;
       $1733 = (($1727) + ($1732)|0);
       $1734 = HEAP8[$1733>>0]|0;
       $1735 = HEAP8[$37>>0]|0;
       $1736 = $1735&255;
       $1737 = (79212 + ($1736<<2)|0);
       $1738 = HEAP32[$1737>>2]|0;
       $1739 = HEAP32[$42>>2]|0;
       $1740 = $1739 & $1701;
       $1741 = HEAP8[$38>>0]|0;
       $1742 = $1741&255;
       $1743 = $1740 >>> $1742;
       $1744 = (($1738) + ($1743)|0);
       $1745 = HEAP8[$1744>>0]|0;
       $$61201$shrunk = $1712;$$61209$shrunk = $1723;$$61217$shrunk = $1734;$$61225$shrunk = $1745;
       break;
      }
      case 2:  {
       $1746 = HEAP16[$$71193>>1]|0;
       $1747 = $1746&65535;
       $1748 = HEAP8[$31>>0]|0;
       $1749 = $1748&255;
       $1750 = (79212 + ($1749<<2)|0);
       $1751 = HEAP32[$1750>>2]|0;
       $1752 = HEAP32[$39>>2]|0;
       $1753 = $1752 & $1747;
       $1754 = HEAP8[$32>>0]|0;
       $1755 = $1754&255;
       $1756 = $1753 >>> $1755;
       $1757 = (($1751) + ($1756)|0);
       $1758 = HEAP8[$1757>>0]|0;
       $1759 = HEAP8[$33>>0]|0;
       $1760 = $1759&255;
       $1761 = (79212 + ($1760<<2)|0);
       $1762 = HEAP32[$1761>>2]|0;
       $1763 = HEAP32[$40>>2]|0;
       $1764 = $1763 & $1747;
       $1765 = HEAP8[$34>>0]|0;
       $1766 = $1765&255;
       $1767 = $1764 >>> $1766;
       $1768 = (($1762) + ($1767)|0);
       $1769 = HEAP8[$1768>>0]|0;
       $1770 = HEAP8[$35>>0]|0;
       $1771 = $1770&255;
       $1772 = (79212 + ($1771<<2)|0);
       $1773 = HEAP32[$1772>>2]|0;
       $1774 = HEAP32[$41>>2]|0;
       $1775 = $1774 & $1747;
       $1776 = HEAP8[$36>>0]|0;
       $1777 = $1776&255;
       $1778 = $1775 >>> $1777;
       $1779 = (($1773) + ($1778)|0);
       $1780 = HEAP8[$1779>>0]|0;
       $1781 = HEAP8[$37>>0]|0;
       $1782 = $1781&255;
       $1783 = (79212 + ($1782<<2)|0);
       $1784 = HEAP32[$1783>>2]|0;
       $1785 = HEAP32[$42>>2]|0;
       $1786 = $1785 & $1747;
       $1787 = HEAP8[$38>>0]|0;
       $1788 = $1787&255;
       $1789 = $1786 >>> $1788;
       $1790 = (($1784) + ($1789)|0);
       $1791 = HEAP8[$1790>>0]|0;
       $$61201$shrunk = $1758;$$61209$shrunk = $1769;$$61217$shrunk = $1780;$$61225$shrunk = $1791;
       break;
      }
      case 3:  {
       $1792 = HEAP8[$32>>0]|0;
       $div1239 = ($1792&255) >>> 3;
       $1793 = $div1239&255;
       $1794 = (($$71193) + ($1793)|0);
       $1795 = HEAP8[$1794>>0]|0;
       $1796 = HEAP8[$34>>0]|0;
       $div1240 = ($1796&255) >>> 3;
       $1797 = $div1240&255;
       $1798 = (($$71193) + ($1797)|0);
       $1799 = HEAP8[$1798>>0]|0;
       $1800 = HEAP8[$36>>0]|0;
       $div1241 = ($1800&255) >>> 3;
       $1801 = $div1241&255;
       $1802 = (($$71193) + ($1801)|0);
       $1803 = HEAP8[$1802>>0]|0;
       $$61201$shrunk = $1795;$$61209$shrunk = $1799;$$61217$shrunk = $1803;$$61225$shrunk = -1;
       break;
      }
      case 4:  {
       $1804 = HEAP32[$$71193>>2]|0;
       $1805 = HEAP8[$31>>0]|0;
       $1806 = $1805&255;
       $1807 = (79212 + ($1806<<2)|0);
       $1808 = HEAP32[$1807>>2]|0;
       $1809 = HEAP32[$39>>2]|0;
       $1810 = $1809 & $1804;
       $1811 = HEAP8[$32>>0]|0;
       $1812 = $1811&255;
       $1813 = $1810 >>> $1812;
       $1814 = (($1808) + ($1813)|0);
       $1815 = HEAP8[$1814>>0]|0;
       $1816 = HEAP8[$33>>0]|0;
       $1817 = $1816&255;
       $1818 = (79212 + ($1817<<2)|0);
       $1819 = HEAP32[$1818>>2]|0;
       $1820 = HEAP32[$40>>2]|0;
       $1821 = $1820 & $1804;
       $1822 = HEAP8[$34>>0]|0;
       $1823 = $1822&255;
       $1824 = $1821 >>> $1823;
       $1825 = (($1819) + ($1824)|0);
       $1826 = HEAP8[$1825>>0]|0;
       $1827 = HEAP8[$35>>0]|0;
       $1828 = $1827&255;
       $1829 = (79212 + ($1828<<2)|0);
       $1830 = HEAP32[$1829>>2]|0;
       $1831 = HEAP32[$41>>2]|0;
       $1832 = $1831 & $1804;
       $1833 = HEAP8[$36>>0]|0;
       $1834 = $1833&255;
       $1835 = $1832 >>> $1834;
       $1836 = (($1830) + ($1835)|0);
       $1837 = HEAP8[$1836>>0]|0;
       $1838 = HEAP8[$37>>0]|0;
       $1839 = $1838&255;
       $1840 = (79212 + ($1839<<2)|0);
       $1841 = HEAP32[$1840>>2]|0;
       $1842 = HEAP32[$42>>2]|0;
       $1843 = $1842 & $1804;
       $1844 = HEAP8[$38>>0]|0;
       $1845 = $1844&255;
       $1846 = $1843 >>> $1845;
       $1847 = (($1841) + ($1846)|0);
       $1848 = HEAP8[$1847>>0]|0;
       $$61201$shrunk = $1815;$$61209$shrunk = $1826;$$61217$shrunk = $1837;$$61225$shrunk = $1848;
       break;
      }
      default: {
       $$61201$shrunk = 0;$$61209$shrunk = 0;$$61217$shrunk = 0;$$61225$shrunk = 0;
      }
      }
      $$61201 = $$61201$shrunk&255;
      $$61209 = $$61209$shrunk&255;
      $$61217 = $$61217$shrunk&255;
      $$61225 = $$61225$shrunk&255;
      $1849 = (($1693) - ($$61201))|0;
      $1850 = Math_imul($1849, $21)|0;
      $1851 = (($1850>>>0) / 255)&-1;
      $1852 = (($1851) + ($$61201))|0;
      $1853 = (($1696) - ($$61209))|0;
      $1854 = Math_imul($1853, $21)|0;
      $1855 = (($1854>>>0) / 255)&-1;
      $1856 = (($1855) + ($$61209))|0;
      $1857 = (($1699) - ($$61217))|0;
      $1858 = Math_imul($1857, $21)|0;
      $1859 = (($1858>>>0) / 255)&-1;
      $1860 = (($1859) + ($$61217))|0;
      $1861 = (($$61225) + ($21))|0;
      $1862 = Math_imul($$61225, $21)|0;
      $1863 = (($1862>>>0) / 255)&-1;
      $1864 = (($1861) - ($1863))|0;
      switch ($23<<24>>24) {
      case 1:  {
       $1865 = HEAP8[$31>>0]|0;
       $1866 = $1865&255;
       $1867 = $1852 >>> $1866;
       $1868 = HEAP8[$32>>0]|0;
       $1869 = $1868&255;
       $1870 = $1867 << $1869;
       $1871 = HEAP8[$33>>0]|0;
       $1872 = $1871&255;
       $1873 = $1856 >>> $1872;
       $1874 = HEAP8[$34>>0]|0;
       $1875 = $1874&255;
       $1876 = $1873 << $1875;
       $1877 = $1876 | $1870;
       $1878 = HEAP8[$35>>0]|0;
       $1879 = $1878&255;
       $1880 = $1860 >>> $1879;
       $1881 = HEAP8[$36>>0]|0;
       $1882 = $1881&255;
       $1883 = $1880 << $1882;
       $1884 = $1877 | $1883;
       $1885 = HEAP8[$37>>0]|0;
       $1886 = $1885&255;
       $1887 = $1864 >>> $1886;
       $1888 = HEAP8[$38>>0]|0;
       $1889 = $1888&255;
       $1890 = $1887 << $1889;
       $1891 = $1884 | $1890;
       $1892 = $1891&255;
       HEAP8[$$71193>>0] = $1892;
       break L99;
       break;
      }
      case 2:  {
       $1893 = HEAP8[$31>>0]|0;
       $1894 = $1893&255;
       $1895 = $1852 >>> $1894;
       $1896 = HEAP8[$32>>0]|0;
       $1897 = $1896&255;
       $1898 = $1895 << $1897;
       $1899 = HEAP8[$33>>0]|0;
       $1900 = $1899&255;
       $1901 = $1856 >>> $1900;
       $1902 = HEAP8[$34>>0]|0;
       $1903 = $1902&255;
       $1904 = $1901 << $1903;
       $1905 = $1904 | $1898;
       $1906 = HEAP8[$35>>0]|0;
       $1907 = $1906&255;
       $1908 = $1860 >>> $1907;
       $1909 = HEAP8[$36>>0]|0;
       $1910 = $1909&255;
       $1911 = $1908 << $1910;
       $1912 = $1905 | $1911;
       $1913 = HEAP8[$37>>0]|0;
       $1914 = $1913&255;
       $1915 = $1864 >>> $1914;
       $1916 = HEAP8[$38>>0]|0;
       $1917 = $1916&255;
       $1918 = $1915 << $1917;
       $1919 = $1912 | $1918;
       $1920 = $1919&65535;
       HEAP16[$$71193>>1] = $1920;
       break L99;
       break;
      }
      case 3:  {
       $1921 = $1852&255;
       $1922 = HEAP8[$32>>0]|0;
       $div = ($1922&255) >>> 3;
       $1923 = $div&255;
       $1924 = (($$71193) + ($1923)|0);
       HEAP8[$1924>>0] = $1921;
       $1925 = $1856&255;
       $1926 = HEAP8[$34>>0]|0;
       $div1237 = ($1926&255) >>> 3;
       $1927 = $div1237&255;
       $1928 = (($$71193) + ($1927)|0);
       HEAP8[$1928>>0] = $1925;
       $1929 = $1860&255;
       $1930 = HEAP8[$36>>0]|0;
       $div1238 = ($1930&255) >>> 3;
       $1931 = $div1238&255;
       $1932 = (($$71193) + ($1931)|0);
       HEAP8[$1932>>0] = $1929;
       break L99;
       break;
      }
      case 4:  {
       $1933 = HEAP8[$31>>0]|0;
       $1934 = $1933&255;
       $1935 = $1852 >>> $1934;
       $1936 = HEAP8[$32>>0]|0;
       $1937 = $1936&255;
       $1938 = $1935 << $1937;
       $1939 = HEAP8[$33>>0]|0;
       $1940 = $1939&255;
       $1941 = $1856 >>> $1940;
       $1942 = HEAP8[$34>>0]|0;
       $1943 = $1942&255;
       $1944 = $1941 << $1943;
       $1945 = $1944 | $1938;
       $1946 = HEAP8[$35>>0]|0;
       $1947 = $1946&255;
       $1948 = $1860 >>> $1947;
       $1949 = HEAP8[$36>>0]|0;
       $1950 = $1949&255;
       $1951 = $1948 << $1950;
       $1952 = $1945 | $1951;
       $1953 = HEAP8[$37>>0]|0;
       $1954 = $1953&255;
       $1955 = $1864 >>> $1954;
       $1956 = HEAP8[$38>>0]|0;
       $1957 = $1956&255;
       $1958 = $1955 << $1957;
       $1959 = $1952 | $1958;
       HEAP32[$$71193>>2] = $1959;
       break L99;
       break;
      }
      default: {
       break L99;
      }
      }
     }
    } while(0);
    $1960 = ((($$7)) + 1|0);
    $1961 = (($$71193) + ($24)|0);
    $$71234 = $$61233;$$8 = $1960;$$81194 = $1961;
    label = 88;
    continue;
   }
   else if ((label|0) == 88) {
    label = 0;
    $1962 = HEAP8[$$8>>0]|0;
    $1963 = $1962&255;
    $1964 = ($1963|0)==($18|0);
    L114: do {
     if (!($1964)) {
      $1965 = (($16) + ($1963<<2)|0);
      $1966 = HEAP8[$1965>>0]|0;
      $1967 = $1966&255;
      $1968 = (((($16) + ($1963<<2)|0)) + 1|0);
      $1969 = HEAP8[$1968>>0]|0;
      $1970 = $1969&255;
      $1971 = (((($16) + ($1963<<2)|0)) + 2|0);
      $1972 = HEAP8[$1971>>0]|0;
      $1973 = $1972&255;
      switch ($23<<24>>24) {
      case 1:  {
       $1974 = HEAP8[$$81194>>0]|0;
       $1975 = $1974&255;
       $1976 = HEAP8[$31>>0]|0;
       $1977 = $1976&255;
       $1978 = (79212 + ($1977<<2)|0);
       $1979 = HEAP32[$1978>>2]|0;
       $1980 = HEAP32[$39>>2]|0;
       $1981 = $1980 & $1975;
       $1982 = HEAP8[$32>>0]|0;
       $1983 = $1982&255;
       $1984 = $1981 >>> $1983;
       $1985 = (($1979) + ($1984)|0);
       $1986 = HEAP8[$1985>>0]|0;
       $1987 = HEAP8[$33>>0]|0;
       $1988 = $1987&255;
       $1989 = (79212 + ($1988<<2)|0);
       $1990 = HEAP32[$1989>>2]|0;
       $1991 = HEAP32[$40>>2]|0;
       $1992 = $1991 & $1975;
       $1993 = HEAP8[$34>>0]|0;
       $1994 = $1993&255;
       $1995 = $1992 >>> $1994;
       $1996 = (($1990) + ($1995)|0);
       $1997 = HEAP8[$1996>>0]|0;
       $1998 = HEAP8[$35>>0]|0;
       $1999 = $1998&255;
       $2000 = (79212 + ($1999<<2)|0);
       $2001 = HEAP32[$2000>>2]|0;
       $2002 = HEAP32[$41>>2]|0;
       $2003 = $2002 & $1975;
       $2004 = HEAP8[$36>>0]|0;
       $2005 = $2004&255;
       $2006 = $2003 >>> $2005;
       $2007 = (($2001) + ($2006)|0);
       $2008 = HEAP8[$2007>>0]|0;
       $2009 = HEAP8[$37>>0]|0;
       $2010 = $2009&255;
       $2011 = (79212 + ($2010<<2)|0);
       $2012 = HEAP32[$2011>>2]|0;
       $2013 = HEAP32[$42>>2]|0;
       $2014 = $2013 & $1975;
       $2015 = HEAP8[$38>>0]|0;
       $2016 = $2015&255;
       $2017 = $2014 >>> $2016;
       $2018 = (($2012) + ($2017)|0);
       $2019 = HEAP8[$2018>>0]|0;
       $$71202$shrunk = $1986;$$71210$shrunk = $1997;$$71218$shrunk = $2008;$$71226$shrunk = $2019;
       break;
      }
      case 2:  {
       $2020 = HEAP16[$$81194>>1]|0;
       $2021 = $2020&65535;
       $2022 = HEAP8[$31>>0]|0;
       $2023 = $2022&255;
       $2024 = (79212 + ($2023<<2)|0);
       $2025 = HEAP32[$2024>>2]|0;
       $2026 = HEAP32[$39>>2]|0;
       $2027 = $2026 & $2021;
       $2028 = HEAP8[$32>>0]|0;
       $2029 = $2028&255;
       $2030 = $2027 >>> $2029;
       $2031 = (($2025) + ($2030)|0);
       $2032 = HEAP8[$2031>>0]|0;
       $2033 = HEAP8[$33>>0]|0;
       $2034 = $2033&255;
       $2035 = (79212 + ($2034<<2)|0);
       $2036 = HEAP32[$2035>>2]|0;
       $2037 = HEAP32[$40>>2]|0;
       $2038 = $2037 & $2021;
       $2039 = HEAP8[$34>>0]|0;
       $2040 = $2039&255;
       $2041 = $2038 >>> $2040;
       $2042 = (($2036) + ($2041)|0);
       $2043 = HEAP8[$2042>>0]|0;
       $2044 = HEAP8[$35>>0]|0;
       $2045 = $2044&255;
       $2046 = (79212 + ($2045<<2)|0);
       $2047 = HEAP32[$2046>>2]|0;
       $2048 = HEAP32[$41>>2]|0;
       $2049 = $2048 & $2021;
       $2050 = HEAP8[$36>>0]|0;
       $2051 = $2050&255;
       $2052 = $2049 >>> $2051;
       $2053 = (($2047) + ($2052)|0);
       $2054 = HEAP8[$2053>>0]|0;
       $2055 = HEAP8[$37>>0]|0;
       $2056 = $2055&255;
       $2057 = (79212 + ($2056<<2)|0);
       $2058 = HEAP32[$2057>>2]|0;
       $2059 = HEAP32[$42>>2]|0;
       $2060 = $2059 & $2021;
       $2061 = HEAP8[$38>>0]|0;
       $2062 = $2061&255;
       $2063 = $2060 >>> $2062;
       $2064 = (($2058) + ($2063)|0);
       $2065 = HEAP8[$2064>>0]|0;
       $$71202$shrunk = $2032;$$71210$shrunk = $2043;$$71218$shrunk = $2054;$$71226$shrunk = $2065;
       break;
      }
      case 3:  {
       $2066 = HEAP8[$32>>0]|0;
       $div1295 = ($2066&255) >>> 3;
       $2067 = $div1295&255;
       $2068 = (($$81194) + ($2067)|0);
       $2069 = HEAP8[$2068>>0]|0;
       $2070 = HEAP8[$34>>0]|0;
       $div1296 = ($2070&255) >>> 3;
       $2071 = $div1296&255;
       $2072 = (($$81194) + ($2071)|0);
       $2073 = HEAP8[$2072>>0]|0;
       $2074 = HEAP8[$36>>0]|0;
       $div1297 = ($2074&255) >>> 3;
       $2075 = $div1297&255;
       $2076 = (($$81194) + ($2075)|0);
       $2077 = HEAP8[$2076>>0]|0;
       $$71202$shrunk = $2069;$$71210$shrunk = $2073;$$71218$shrunk = $2077;$$71226$shrunk = -1;
       break;
      }
      case 4:  {
       $2078 = HEAP32[$$81194>>2]|0;
       $2079 = HEAP8[$31>>0]|0;
       $2080 = $2079&255;
       $2081 = (79212 + ($2080<<2)|0);
       $2082 = HEAP32[$2081>>2]|0;
       $2083 = HEAP32[$39>>2]|0;
       $2084 = $2083 & $2078;
       $2085 = HEAP8[$32>>0]|0;
       $2086 = $2085&255;
       $2087 = $2084 >>> $2086;
       $2088 = (($2082) + ($2087)|0);
       $2089 = HEAP8[$2088>>0]|0;
       $2090 = HEAP8[$33>>0]|0;
       $2091 = $2090&255;
       $2092 = (79212 + ($2091<<2)|0);
       $2093 = HEAP32[$2092>>2]|0;
       $2094 = HEAP32[$40>>2]|0;
       $2095 = $2094 & $2078;
       $2096 = HEAP8[$34>>0]|0;
       $2097 = $2096&255;
       $2098 = $2095 >>> $2097;
       $2099 = (($2093) + ($2098)|0);
       $2100 = HEAP8[$2099>>0]|0;
       $2101 = HEAP8[$35>>0]|0;
       $2102 = $2101&255;
       $2103 = (79212 + ($2102<<2)|0);
       $2104 = HEAP32[$2103>>2]|0;
       $2105 = HEAP32[$41>>2]|0;
       $2106 = $2105 & $2078;
       $2107 = HEAP8[$36>>0]|0;
       $2108 = $2107&255;
       $2109 = $2106 >>> $2108;
       $2110 = (($2104) + ($2109)|0);
       $2111 = HEAP8[$2110>>0]|0;
       $2112 = HEAP8[$37>>0]|0;
       $2113 = $2112&255;
       $2114 = (79212 + ($2113<<2)|0);
       $2115 = HEAP32[$2114>>2]|0;
       $2116 = HEAP32[$42>>2]|0;
       $2117 = $2116 & $2078;
       $2118 = HEAP8[$38>>0]|0;
       $2119 = $2118&255;
       $2120 = $2117 >>> $2119;
       $2121 = (($2115) + ($2120)|0);
       $2122 = HEAP8[$2121>>0]|0;
       $$71202$shrunk = $2089;$$71210$shrunk = $2100;$$71218$shrunk = $2111;$$71226$shrunk = $2122;
       break;
      }
      default: {
       $$71202$shrunk = 0;$$71210$shrunk = 0;$$71218$shrunk = 0;$$71226$shrunk = 0;
      }
      }
      $$71202 = $$71202$shrunk&255;
      $$71210 = $$71210$shrunk&255;
      $$71218 = $$71218$shrunk&255;
      $$71226 = $$71226$shrunk&255;
      $2123 = (($1967) - ($$71202))|0;
      $2124 = Math_imul($2123, $21)|0;
      $2125 = (($2124>>>0) / 255)&-1;
      $2126 = (($2125) + ($$71202))|0;
      $2127 = (($1970) - ($$71210))|0;
      $2128 = Math_imul($2127, $21)|0;
      $2129 = (($2128>>>0) / 255)&-1;
      $2130 = (($2129) + ($$71210))|0;
      $2131 = (($1973) - ($$71218))|0;
      $2132 = Math_imul($2131, $21)|0;
      $2133 = (($2132>>>0) / 255)&-1;
      $2134 = (($2133) + ($$71218))|0;
      $2135 = (($$71226) + ($21))|0;
      $2136 = Math_imul($$71226, $21)|0;
      $2137 = (($2136>>>0) / 255)&-1;
      $2138 = (($2135) - ($2137))|0;
      switch ($23<<24>>24) {
      case 1:  {
       $2139 = HEAP8[$31>>0]|0;
       $2140 = $2139&255;
       $2141 = $2126 >>> $2140;
       $2142 = HEAP8[$32>>0]|0;
       $2143 = $2142&255;
       $2144 = $2141 << $2143;
       $2145 = HEAP8[$33>>0]|0;
       $2146 = $2145&255;
       $2147 = $2130 >>> $2146;
       $2148 = HEAP8[$34>>0]|0;
       $2149 = $2148&255;
       $2150 = $2147 << $2149;
       $2151 = $2150 | $2144;
       $2152 = HEAP8[$35>>0]|0;
       $2153 = $2152&255;
       $2154 = $2134 >>> $2153;
       $2155 = HEAP8[$36>>0]|0;
       $2156 = $2155&255;
       $2157 = $2154 << $2156;
       $2158 = $2151 | $2157;
       $2159 = HEAP8[$37>>0]|0;
       $2160 = $2159&255;
       $2161 = $2138 >>> $2160;
       $2162 = HEAP8[$38>>0]|0;
       $2163 = $2162&255;
       $2164 = $2161 << $2163;
       $2165 = $2158 | $2164;
       $2166 = $2165&255;
       HEAP8[$$81194>>0] = $2166;
       break L114;
       break;
      }
      case 2:  {
       $2167 = HEAP8[$31>>0]|0;
       $2168 = $2167&255;
       $2169 = $2126 >>> $2168;
       $2170 = HEAP8[$32>>0]|0;
       $2171 = $2170&255;
       $2172 = $2169 << $2171;
       $2173 = HEAP8[$33>>0]|0;
       $2174 = $2173&255;
       $2175 = $2130 >>> $2174;
       $2176 = HEAP8[$34>>0]|0;
       $2177 = $2176&255;
       $2178 = $2175 << $2177;
       $2179 = $2178 | $2172;
       $2180 = HEAP8[$35>>0]|0;
       $2181 = $2180&255;
       $2182 = $2134 >>> $2181;
       $2183 = HEAP8[$36>>0]|0;
       $2184 = $2183&255;
       $2185 = $2182 << $2184;
       $2186 = $2179 | $2185;
       $2187 = HEAP8[$37>>0]|0;
       $2188 = $2187&255;
       $2189 = $2138 >>> $2188;
       $2190 = HEAP8[$38>>0]|0;
       $2191 = $2190&255;
       $2192 = $2189 << $2191;
       $2193 = $2186 | $2192;
       $2194 = $2193&65535;
       HEAP16[$$81194>>1] = $2194;
       break L114;
       break;
      }
      case 3:  {
       $2195 = $2126&255;
       $2196 = HEAP8[$32>>0]|0;
       $div1292 = ($2196&255) >>> 3;
       $2197 = $div1292&255;
       $2198 = (($$81194) + ($2197)|0);
       HEAP8[$2198>>0] = $2195;
       $2199 = $2130&255;
       $2200 = HEAP8[$34>>0]|0;
       $div1293 = ($2200&255) >>> 3;
       $2201 = $div1293&255;
       $2202 = (($$81194) + ($2201)|0);
       HEAP8[$2202>>0] = $2199;
       $2203 = $2134&255;
       $2204 = HEAP8[$36>>0]|0;
       $div1294 = ($2204&255) >>> 3;
       $2205 = $div1294&255;
       $2206 = (($$81194) + ($2205)|0);
       HEAP8[$2206>>0] = $2203;
       break L114;
       break;
      }
      case 4:  {
       $2207 = HEAP8[$31>>0]|0;
       $2208 = $2207&255;
       $2209 = $2126 >>> $2208;
       $2210 = HEAP8[$32>>0]|0;
       $2211 = $2210&255;
       $2212 = $2209 << $2211;
       $2213 = HEAP8[$33>>0]|0;
       $2214 = $2213&255;
       $2215 = $2130 >>> $2214;
       $2216 = HEAP8[$34>>0]|0;
       $2217 = $2216&255;
       $2218 = $2215 << $2217;
       $2219 = $2218 | $2212;
       $2220 = HEAP8[$35>>0]|0;
       $2221 = $2220&255;
       $2222 = $2134 >>> $2221;
       $2223 = HEAP8[$36>>0]|0;
       $2224 = $2223&255;
       $2225 = $2222 << $2224;
       $2226 = $2219 | $2225;
       $2227 = HEAP8[$37>>0]|0;
       $2228 = $2227&255;
       $2229 = $2138 >>> $2228;
       $2230 = HEAP8[$38>>0]|0;
       $2231 = $2230&255;
       $2232 = $2229 << $2231;
       $2233 = $2226 | $2232;
       HEAP32[$$81194>>2] = $2233;
       break L114;
       break;
      }
      default: {
       break L114;
      }
      }
     }
    } while(0);
    $2234 = ((($$8)) + 1|0);
    $2235 = (($$81194) + ($24)|0);
    $2236 = (($$71234) + -1)|0;
    $2237 = ($$71234|0)>(1);
    if ($2237) {
     $$01227 = $2236;$$1 = $2234;$$11187 = $2235;
     label = 4;
     continue;
    } else {
     break;
    }
   }
  }
  $2238 = (($2234) + ($6)|0);
  $2239 = (($2235) + ($8)|0);
  $2240 = ($43|0)==(0);
  if ($2240) {
   label = 102;
   break;
  } else {
   $$011851306 = $2238;$$011861305 = $2239;$$in = $43;
  }
 }
 if ((label|0) == 100) {
  // unreachable;
 }
 else if ((label|0) == 102) {
  return;
 }
}
function _Blit1to1Key($0) {
 $0 = $0|0;
 var $$0$us = 0, $$0147$us = 0, $$0157189 = 0, $$0157189$us = 0, $$0165188 = 0, $$0165188$us = 0, $$1 = 0, $$10$us = 0, $$10175$us = 0, $$11 = 0, $$11176 = 0, $$1148 = 0, $$1158$us = 0, $$1166$us = 0, $$12 = 0, $$12177 = 0, $$13 = 0, $$13178 = 0, $$14 = 0, $$14179 = 0;
 var $$15 = 0, $$15180 = 0, $$16 = 0, $$16181 = 0, $$17 = 0, $$17182 = 0, $$2 = 0, $$2149 = 0, $$2159 = 0, $$2167 = 0, $$3 = 0, $$3150 = 0, $$3160 = 0, $$3168 = 0, $$4 = 0, $$4151 = 0, $$4161 = 0, $$4169 = 0, $$5 = 0, $$5152 = 0;
 var $$5162 = 0, $$5170 = 0, $$6 = 0, $$6153 = 0, $$6163 = 0, $$6171 = 0, $$7 = 0, $$7154 = 0, $$7164 = 0, $$7172 = 0, $$8 = 0, $$8173 = 0, $$9174186 = 0, $$9174186$us = 0, $$9187 = 0, $$9187$us = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0;
 var $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0;
 var $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0;
 var $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0;
 var $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0;
 var $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0;
 var $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0;
 var $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0;
 var $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $trunc = 0, $trunc$clear = 0, $trunc$clear2 = 0, $trunc183 = 0, $trunc183$clear = 0, $trunc183$clear1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$0>>2]|0;
 $6 = ((($0)) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($0)) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($0)) + 36|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($0)) + 48|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($0)) + 56|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($13|0)==(0|0);
 $17 = (($4) + -1)|0;
 $18 = ($4|0)==(0);
 if ($16) {
  if ($18) {
   return;
  }
  $85 = (($2) + 7)|0;
  $86 = (($85|0) / 8)&-1;
  $trunc = $2&255;
  $trunc$clear = $trunc & 7;
  $87 = ($trunc$clear<<24>>24)==(0);
  if ($87) {
   $$9174186$us = $9;$$9187$us = $5;$133 = $17;
   while(1) {
    $$0$us = $86;$$10$us = $$9187$us;$$10175$us = $$9174186$us;
    while(1) {
     $88 = HEAP8[$$10$us>>0]|0;
     $89 = $88&255;
     $90 = ($89|0)==($15|0);
     if (!($90)) {
      HEAP8[$$10175$us>>0] = $88;
     }
     $91 = ((($$10$us)) + 1|0);
     $92 = HEAP8[$91>>0]|0;
     $93 = $92&255;
     $94 = ($93|0)==($15|0);
     if (!($94)) {
      $95 = ((($$10175$us)) + 1|0);
      HEAP8[$95>>0] = $92;
     }
     $96 = ((($$10$us)) + 2|0);
     $97 = HEAP8[$96>>0]|0;
     $98 = $97&255;
     $99 = ($98|0)==($15|0);
     if (!($99)) {
      $100 = ((($$10175$us)) + 2|0);
      HEAP8[$100>>0] = $97;
     }
     $101 = ((($$10$us)) + 3|0);
     $102 = HEAP8[$101>>0]|0;
     $103 = $102&255;
     $104 = ($103|0)==($15|0);
     if (!($104)) {
      $105 = ((($$10175$us)) + 3|0);
      HEAP8[$105>>0] = $102;
     }
     $106 = ((($$10$us)) + 4|0);
     $107 = HEAP8[$106>>0]|0;
     $108 = $107&255;
     $109 = ($108|0)==($15|0);
     if (!($109)) {
      $110 = ((($$10175$us)) + 4|0);
      HEAP8[$110>>0] = $107;
     }
     $111 = ((($$10$us)) + 5|0);
     $112 = HEAP8[$111>>0]|0;
     $113 = $112&255;
     $114 = ($113|0)==($15|0);
     if (!($114)) {
      $115 = ((($$10175$us)) + 5|0);
      HEAP8[$115>>0] = $112;
     }
     $116 = ((($$10$us)) + 6|0);
     $117 = HEAP8[$116>>0]|0;
     $118 = $117&255;
     $119 = ($118|0)==($15|0);
     if (!($119)) {
      $120 = ((($$10175$us)) + 6|0);
      HEAP8[$120>>0] = $117;
     }
     $121 = ((($$10$us)) + 7|0);
     $122 = HEAP8[$121>>0]|0;
     $123 = $122&255;
     $124 = ($123|0)==($15|0);
     if (!($124)) {
      $125 = ((($$10175$us)) + 7|0);
      HEAP8[$125>>0] = $122;
     }
     $126 = ((($$10175$us)) + 8|0);
     $127 = ((($$10$us)) + 8|0);
     $128 = (($$0$us) + -1)|0;
     $129 = ($$0$us|0)>(1);
     if ($129) {
      $$0$us = $128;$$10$us = $127;$$10175$us = $126;
     } else {
      break;
     }
    }
    $130 = (($127) + ($7)|0);
    $131 = (($126) + ($11)|0);
    $132 = (($133) + -1)|0;
    $134 = ($133|0)==(0);
    if ($134) {
     break;
    } else {
     $$9174186$us = $131;$$9187$us = $130;$133 = $132;
    }
   }
   return;
  } else {
   $$9174186 = $9;$$9187 = $5;$243 = $17;
  }
  L37: while(1) {
   $trunc$clear2 = $trunc & 7;
   switch ($trunc$clear2<<24>>24) {
   case 1:  {
    $$17 = $$9187;$$17182 = $$9174186;$$7 = $86;
    label = 93;
    break;
   }
   case 7:  {
    $$1 = $86;$$11 = $$9187;$$11176 = $$9174186;
    label = 75;
    break;
   }
   case 6:  {
    $$12 = $$9187;$$12177 = $$9174186;$$2 = $86;
    label = 78;
    break;
   }
   case 5:  {
    $$13 = $$9187;$$13178 = $$9174186;$$3 = $86;
    label = 81;
    break;
   }
   case 4:  {
    $$14 = $$9187;$$14179 = $$9174186;$$4 = $86;
    label = 84;
    break;
   }
   case 3:  {
    $$15 = $$9187;$$15180 = $$9174186;$$5 = $86;
    label = 87;
    break;
   }
   case 2:  {
    $$16 = $$9187;$$16181 = $$9174186;$$6 = $86;
    label = 90;
    break;
   }
   default: {
    label = 96;
    break L37;
   }
   }
   while(1) {
    if ((label|0) == 75) {
     label = 0;
     $205 = HEAP8[$$11>>0]|0;
     $206 = $205&255;
     $207 = ($206|0)==($15|0);
     if (!($207)) {
      HEAP8[$$11176>>0] = $205;
     }
     $208 = ((($$11176)) + 1|0);
     $209 = ((($$11)) + 1|0);
     $$12 = $209;$$12177 = $208;$$2 = $$1;
     label = 78;
     continue;
    }
    else if ((label|0) == 78) {
     label = 0;
     $210 = HEAP8[$$12>>0]|0;
     $211 = $210&255;
     $212 = ($211|0)==($15|0);
     if (!($212)) {
      HEAP8[$$12177>>0] = $210;
     }
     $213 = ((($$12177)) + 1|0);
     $214 = ((($$12)) + 1|0);
     $$13 = $214;$$13178 = $213;$$3 = $$2;
     label = 81;
     continue;
    }
    else if ((label|0) == 81) {
     label = 0;
     $215 = HEAP8[$$13>>0]|0;
     $216 = $215&255;
     $217 = ($216|0)==($15|0);
     if (!($217)) {
      HEAP8[$$13178>>0] = $215;
     }
     $218 = ((($$13178)) + 1|0);
     $219 = ((($$13)) + 1|0);
     $$14 = $219;$$14179 = $218;$$4 = $$3;
     label = 84;
     continue;
    }
    else if ((label|0) == 84) {
     label = 0;
     $220 = HEAP8[$$14>>0]|0;
     $221 = $220&255;
     $222 = ($221|0)==($15|0);
     if (!($222)) {
      HEAP8[$$14179>>0] = $220;
     }
     $223 = ((($$14179)) + 1|0);
     $224 = ((($$14)) + 1|0);
     $$15 = $224;$$15180 = $223;$$5 = $$4;
     label = 87;
     continue;
    }
    else if ((label|0) == 87) {
     label = 0;
     $225 = HEAP8[$$15>>0]|0;
     $226 = $225&255;
     $227 = ($226|0)==($15|0);
     if (!($227)) {
      HEAP8[$$15180>>0] = $225;
     }
     $228 = ((($$15180)) + 1|0);
     $229 = ((($$15)) + 1|0);
     $$16 = $229;$$16181 = $228;$$6 = $$5;
     label = 90;
     continue;
    }
    else if ((label|0) == 90) {
     label = 0;
     $230 = HEAP8[$$16>>0]|0;
     $231 = $230&255;
     $232 = ($231|0)==($15|0);
     if (!($232)) {
      HEAP8[$$16181>>0] = $230;
     }
     $233 = ((($$16181)) + 1|0);
     $234 = ((($$16)) + 1|0);
     $$17 = $234;$$17182 = $233;$$7 = $$6;
     label = 93;
     continue;
    }
    else if ((label|0) == 93) {
     label = 0;
     $235 = HEAP8[$$17>>0]|0;
     $236 = $235&255;
     $237 = ($236|0)==($15|0);
     if (!($237)) {
      HEAP8[$$17182>>0] = $235;
     }
     $202 = ((($$17182)) + 1|0);
     $199 = ((($$17)) + 1|0);
     $238 = (($$7) + -1)|0;
     $239 = ($$7|0)>(1);
     if (!($239)) {
      break;
     }
     $198 = HEAP8[$199>>0]|0;
     $200 = $198&255;
     $201 = ($200|0)==($15|0);
     if (!($201)) {
      HEAP8[$202>>0] = $198;
     }
     $203 = ((($$17182)) + 2|0);
     $204 = ((($$17)) + 2|0);
     $$1 = $238;$$11 = $204;$$11176 = $203;
     label = 75;
     continue;
    }
   }
   $240 = (($199) + ($7)|0);
   $241 = (($202) + ($11)|0);
   $242 = (($243) + -1)|0;
   $244 = ($243|0)==(0);
   if ($244) {
    label = 98;
    break;
   } else {
    $$9174186 = $241;$$9187 = $240;$243 = $242;
   }
  }
  if ((label|0) == 96) {
   // unreachable;
  }
  else if ((label|0) == 98) {
   return;
  }
 } else {
  if ($18) {
   return;
  }
  $19 = (($2) + 7)|0;
  $20 = (($19|0) / 8)&-1;
  $trunc183 = $2&255;
  $trunc183$clear = $trunc183 & 7;
  $21 = ($trunc183$clear<<24>>24)==(0);
  if ($21) {
   $$0157189$us = $5;$$0165188$us = $9;$83 = $17;
   while(1) {
    $$0147$us = $20;$$1158$us = $$0157189$us;$$1166$us = $$0165188$us;
    while(1) {
     $22 = HEAP8[$$1158$us>>0]|0;
     $23 = $22&255;
     $24 = ($23|0)==($15|0);
     if (!($24)) {
      $25 = (($13) + ($23)|0);
      $26 = HEAP8[$25>>0]|0;
      HEAP8[$$1166$us>>0] = $26;
     }
     $27 = ((($$1158$us)) + 1|0);
     $28 = HEAP8[$27>>0]|0;
     $29 = $28&255;
     $30 = ($29|0)==($15|0);
     if (!($30)) {
      $31 = ((($$1166$us)) + 1|0);
      $32 = (($13) + ($29)|0);
      $33 = HEAP8[$32>>0]|0;
      HEAP8[$31>>0] = $33;
     }
     $34 = ((($$1158$us)) + 2|0);
     $35 = HEAP8[$34>>0]|0;
     $36 = $35&255;
     $37 = ($36|0)==($15|0);
     if (!($37)) {
      $38 = ((($$1166$us)) + 2|0);
      $39 = (($13) + ($36)|0);
      $40 = HEAP8[$39>>0]|0;
      HEAP8[$38>>0] = $40;
     }
     $41 = ((($$1158$us)) + 3|0);
     $42 = HEAP8[$41>>0]|0;
     $43 = $42&255;
     $44 = ($43|0)==($15|0);
     if (!($44)) {
      $45 = ((($$1166$us)) + 3|0);
      $46 = (($13) + ($43)|0);
      $47 = HEAP8[$46>>0]|0;
      HEAP8[$45>>0] = $47;
     }
     $48 = ((($$1158$us)) + 4|0);
     $49 = HEAP8[$48>>0]|0;
     $50 = $49&255;
     $51 = ($50|0)==($15|0);
     if (!($51)) {
      $52 = ((($$1166$us)) + 4|0);
      $53 = (($13) + ($50)|0);
      $54 = HEAP8[$53>>0]|0;
      HEAP8[$52>>0] = $54;
     }
     $55 = ((($$1158$us)) + 5|0);
     $56 = HEAP8[$55>>0]|0;
     $57 = $56&255;
     $58 = ($57|0)==($15|0);
     if (!($58)) {
      $59 = ((($$1166$us)) + 5|0);
      $60 = (($13) + ($57)|0);
      $61 = HEAP8[$60>>0]|0;
      HEAP8[$59>>0] = $61;
     }
     $62 = ((($$1158$us)) + 6|0);
     $63 = HEAP8[$62>>0]|0;
     $64 = $63&255;
     $65 = ($64|0)==($15|0);
     if (!($65)) {
      $66 = ((($$1166$us)) + 6|0);
      $67 = (($13) + ($64)|0);
      $68 = HEAP8[$67>>0]|0;
      HEAP8[$66>>0] = $68;
     }
     $69 = ((($$1158$us)) + 7|0);
     $70 = HEAP8[$69>>0]|0;
     $71 = $70&255;
     $72 = ($71|0)==($15|0);
     if (!($72)) {
      $73 = ((($$1166$us)) + 7|0);
      $74 = (($13) + ($71)|0);
      $75 = HEAP8[$74>>0]|0;
      HEAP8[$73>>0] = $75;
     }
     $76 = ((($$1166$us)) + 8|0);
     $77 = ((($$1158$us)) + 8|0);
     $78 = (($$0147$us) + -1)|0;
     $79 = ($$0147$us|0)>(1);
     if ($79) {
      $$0147$us = $78;$$1158$us = $77;$$1166$us = $76;
     } else {
      break;
     }
    }
    $80 = (($77) + ($7)|0);
    $81 = (($76) + ($11)|0);
    $82 = (($83) + -1)|0;
    $84 = ($83|0)==(0);
    if ($84) {
     break;
    } else {
     $$0157189$us = $80;$$0165188$us = $81;$83 = $82;
    }
   }
   return;
  } else {
   $$0157189 = $5;$$0165188 = $9;$196 = $17;
  }
  L112: while(1) {
   $trunc183$clear1 = $trunc183 & 7;
   switch ($trunc183$clear1<<24>>24) {
   case 1:  {
    $$7154 = $20;$$8 = $$0157189;$$8173 = $$0165188;
    label = 66;
    break;
   }
   case 7:  {
    $$1148 = $20;$$2159 = $$0157189;$$2167 = $$0165188;
    label = 48;
    break;
   }
   case 6:  {
    $$2149 = $20;$$3160 = $$0157189;$$3168 = $$0165188;
    label = 51;
    break;
   }
   case 5:  {
    $$3150 = $20;$$4161 = $$0157189;$$4169 = $$0165188;
    label = 54;
    break;
   }
   case 4:  {
    $$4151 = $20;$$5162 = $$0157189;$$5170 = $$0165188;
    label = 57;
    break;
   }
   case 3:  {
    $$5152 = $20;$$6163 = $$0157189;$$6171 = $$0165188;
    label = 60;
    break;
   }
   case 2:  {
    $$6153 = $20;$$7164 = $$0157189;$$7172 = $$0165188;
    label = 63;
    break;
   }
   default: {
    label = 69;
    break L112;
   }
   }
   while(1) {
    if ((label|0) == 48) {
     label = 0;
     $144 = HEAP8[$$2159>>0]|0;
     $145 = $144&255;
     $146 = ($145|0)==($15|0);
     if (!($146)) {
      $147 = (($13) + ($145)|0);
      $148 = HEAP8[$147>>0]|0;
      HEAP8[$$2167>>0] = $148;
     }
     $149 = ((($$2167)) + 1|0);
     $150 = ((($$2159)) + 1|0);
     $$2149 = $$1148;$$3160 = $150;$$3168 = $149;
     label = 51;
     continue;
    }
    else if ((label|0) == 51) {
     label = 0;
     $151 = HEAP8[$$3160>>0]|0;
     $152 = $151&255;
     $153 = ($152|0)==($15|0);
     if (!($153)) {
      $154 = (($13) + ($152)|0);
      $155 = HEAP8[$154>>0]|0;
      HEAP8[$$3168>>0] = $155;
     }
     $156 = ((($$3168)) + 1|0);
     $157 = ((($$3160)) + 1|0);
     $$3150 = $$2149;$$4161 = $157;$$4169 = $156;
     label = 54;
     continue;
    }
    else if ((label|0) == 54) {
     label = 0;
     $158 = HEAP8[$$4161>>0]|0;
     $159 = $158&255;
     $160 = ($159|0)==($15|0);
     if (!($160)) {
      $161 = (($13) + ($159)|0);
      $162 = HEAP8[$161>>0]|0;
      HEAP8[$$4169>>0] = $162;
     }
     $163 = ((($$4169)) + 1|0);
     $164 = ((($$4161)) + 1|0);
     $$4151 = $$3150;$$5162 = $164;$$5170 = $163;
     label = 57;
     continue;
    }
    else if ((label|0) == 57) {
     label = 0;
     $165 = HEAP8[$$5162>>0]|0;
     $166 = $165&255;
     $167 = ($166|0)==($15|0);
     if (!($167)) {
      $168 = (($13) + ($166)|0);
      $169 = HEAP8[$168>>0]|0;
      HEAP8[$$5170>>0] = $169;
     }
     $170 = ((($$5170)) + 1|0);
     $171 = ((($$5162)) + 1|0);
     $$5152 = $$4151;$$6163 = $171;$$6171 = $170;
     label = 60;
     continue;
    }
    else if ((label|0) == 60) {
     label = 0;
     $172 = HEAP8[$$6163>>0]|0;
     $173 = $172&255;
     $174 = ($173|0)==($15|0);
     if (!($174)) {
      $175 = (($13) + ($173)|0);
      $176 = HEAP8[$175>>0]|0;
      HEAP8[$$6171>>0] = $176;
     }
     $177 = ((($$6171)) + 1|0);
     $178 = ((($$6163)) + 1|0);
     $$6153 = $$5152;$$7164 = $178;$$7172 = $177;
     label = 63;
     continue;
    }
    else if ((label|0) == 63) {
     label = 0;
     $179 = HEAP8[$$7164>>0]|0;
     $180 = $179&255;
     $181 = ($180|0)==($15|0);
     if (!($181)) {
      $182 = (($13) + ($180)|0);
      $183 = HEAP8[$182>>0]|0;
      HEAP8[$$7172>>0] = $183;
     }
     $184 = ((($$7172)) + 1|0);
     $185 = ((($$7164)) + 1|0);
     $$7154 = $$6153;$$8 = $185;$$8173 = $184;
     label = 66;
     continue;
    }
    else if ((label|0) == 66) {
     label = 0;
     $186 = HEAP8[$$8>>0]|0;
     $187 = $186&255;
     $188 = ($187|0)==($15|0);
     if (!($188)) {
      $189 = (($13) + ($187)|0);
      $190 = HEAP8[$189>>0]|0;
      HEAP8[$$8173>>0] = $190;
     }
     $141 = ((($$8173)) + 1|0);
     $136 = ((($$8)) + 1|0);
     $191 = (($$7154) + -1)|0;
     $192 = ($$7154|0)>(1);
     if (!($192)) {
      break;
     }
     $135 = HEAP8[$136>>0]|0;
     $137 = $135&255;
     $138 = ($137|0)==($15|0);
     if (!($138)) {
      $139 = (($13) + ($137)|0);
      $140 = HEAP8[$139>>0]|0;
      HEAP8[$141>>0] = $140;
     }
     $142 = ((($$8173)) + 2|0);
     $143 = ((($$8)) + 2|0);
     $$1148 = $191;$$2159 = $143;$$2167 = $142;
     label = 48;
     continue;
    }
   }
   $193 = (($136) + ($7)|0);
   $194 = (($141) + ($11)|0);
   $195 = (($196) + -1)|0;
   $197 = ($196|0)==(0);
   if ($197) {
    label = 98;
    break;
   } else {
    $$0157189 = $193;$$0165188 = $194;$196 = $195;
   }
  }
  if ((label|0) == 69) {
   // unreachable;
  }
  else if ((label|0) == 98) {
   return;
  }
 }
}
function _Blit1to2Key($0) {
 $0 = $0|0;
 var $$0$us = 0, $$090108 = 0, $$090108$us = 0, $$098107 = 0, $$098107$us = 0, $$1 = 0, $$191$us = 0, $$199$us = 0, $$2 = 0, $$2100 = 0, $$292 = 0, $$3 = 0, $$3101 = 0, $$393 = 0, $$4 = 0, $$4102 = 0, $$494 = 0, $$5 = 0, $$5103 = 0, $$595 = 0;
 var $$6 = 0, $$6104 = 0, $$696 = 0, $$7 = 0, $$7105 = 0, $$797 = 0, $$8 = 0, $$8106 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $trunc = 0, $trunc$clear = 0, $trunc$clear1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$0>>2]|0;
 $6 = ((($0)) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($0)) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($0)) + 36|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($0)) + 48|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($0)) + 56|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($11|0) / 2)&-1;
 $17 = (($4) + -1)|0;
 $18 = ($4|0)==(0);
 if ($18) {
  return;
 }
 $19 = (($2) + 7)|0;
 $20 = (($19|0) / 8)&-1;
 $trunc = $2&255;
 $trunc$clear = $trunc & 7;
 $21 = ($trunc$clear<<24>>24)==(0);
 if ($21) {
  $$090108$us = $5;$$098107$us = $9;$83 = $17;
  while(1) {
   $$0$us = $20;$$191$us = $$090108$us;$$199$us = $$098107$us;
   while(1) {
    $22 = HEAP8[$$191$us>>0]|0;
    $23 = $22&255;
    $24 = ($23|0)==($15|0);
    if (!($24)) {
     $25 = (($13) + ($23<<1)|0);
     $26 = HEAP16[$25>>1]|0;
     HEAP16[$$199$us>>1] = $26;
    }
    $27 = ((($$191$us)) + 1|0);
    $28 = HEAP8[$27>>0]|0;
    $29 = $28&255;
    $30 = ($29|0)==($15|0);
    if (!($30)) {
     $31 = ((($$199$us)) + 2|0);
     $32 = (($13) + ($29<<1)|0);
     $33 = HEAP16[$32>>1]|0;
     HEAP16[$31>>1] = $33;
    }
    $34 = ((($$191$us)) + 2|0);
    $35 = HEAP8[$34>>0]|0;
    $36 = $35&255;
    $37 = ($36|0)==($15|0);
    if (!($37)) {
     $38 = ((($$199$us)) + 4|0);
     $39 = (($13) + ($36<<1)|0);
     $40 = HEAP16[$39>>1]|0;
     HEAP16[$38>>1] = $40;
    }
    $41 = ((($$191$us)) + 3|0);
    $42 = HEAP8[$41>>0]|0;
    $43 = $42&255;
    $44 = ($43|0)==($15|0);
    if (!($44)) {
     $45 = ((($$199$us)) + 6|0);
     $46 = (($13) + ($43<<1)|0);
     $47 = HEAP16[$46>>1]|0;
     HEAP16[$45>>1] = $47;
    }
    $48 = ((($$191$us)) + 4|0);
    $49 = HEAP8[$48>>0]|0;
    $50 = $49&255;
    $51 = ($50|0)==($15|0);
    if (!($51)) {
     $52 = ((($$199$us)) + 8|0);
     $53 = (($13) + ($50<<1)|0);
     $54 = HEAP16[$53>>1]|0;
     HEAP16[$52>>1] = $54;
    }
    $55 = ((($$191$us)) + 5|0);
    $56 = HEAP8[$55>>0]|0;
    $57 = $56&255;
    $58 = ($57|0)==($15|0);
    if (!($58)) {
     $59 = ((($$199$us)) + 10|0);
     $60 = (($13) + ($57<<1)|0);
     $61 = HEAP16[$60>>1]|0;
     HEAP16[$59>>1] = $61;
    }
    $62 = ((($$191$us)) + 6|0);
    $63 = HEAP8[$62>>0]|0;
    $64 = $63&255;
    $65 = ($64|0)==($15|0);
    if (!($65)) {
     $66 = ((($$199$us)) + 12|0);
     $67 = (($13) + ($64<<1)|0);
     $68 = HEAP16[$67>>1]|0;
     HEAP16[$66>>1] = $68;
    }
    $69 = ((($$191$us)) + 7|0);
    $70 = HEAP8[$69>>0]|0;
    $71 = $70&255;
    $72 = ($71|0)==($15|0);
    if (!($72)) {
     $73 = ((($$199$us)) + 14|0);
     $74 = (($13) + ($71<<1)|0);
     $75 = HEAP16[$74>>1]|0;
     HEAP16[$73>>1] = $75;
    }
    $76 = ((($$191$us)) + 8|0);
    $77 = ((($$199$us)) + 16|0);
    $78 = (($$0$us) + -1)|0;
    $79 = ($$0$us|0)>(1);
    if ($79) {
     $$0$us = $78;$$191$us = $76;$$199$us = $77;
    } else {
     break;
    }
   }
   $80 = (($76) + ($7)|0);
   $81 = (($77) + ($16<<1)|0);
   $82 = (($83) + -1)|0;
   $84 = ($83|0)==(0);
   if ($84) {
    break;
   } else {
    $$090108$us = $80;$$098107$us = $81;$83 = $82;
   }
  }
  return;
 } else {
  $$090108 = $5;$$098107 = $9;$146 = $17;
 }
 L35: while(1) {
  $trunc$clear1 = $trunc & 7;
  switch ($trunc$clear1<<24>>24) {
  case 1:  {
   $$7 = $20;$$8 = $$090108;$$8106 = $$098107;
   label = 44;
   break;
  }
  case 7:  {
   $$1 = $20;$$2100 = $$098107;$$292 = $$090108;
   label = 26;
   break;
  }
  case 6:  {
   $$2 = $20;$$3101 = $$098107;$$393 = $$090108;
   label = 29;
   break;
  }
  case 5:  {
   $$3 = $20;$$4102 = $$098107;$$494 = $$090108;
   label = 32;
   break;
  }
  case 4:  {
   $$4 = $20;$$5103 = $$098107;$$595 = $$090108;
   label = 35;
   break;
  }
  case 3:  {
   $$5 = $20;$$6104 = $$098107;$$696 = $$090108;
   label = 38;
   break;
  }
  case 2:  {
   $$6 = $20;$$7105 = $$098107;$$797 = $$090108;
   label = 41;
   break;
  }
  default: {
   label = 47;
   break L35;
  }
  }
  while(1) {
   if ((label|0) == 26) {
    label = 0;
    $94 = HEAP8[$$292>>0]|0;
    $95 = $94&255;
    $96 = ($95|0)==($15|0);
    if (!($96)) {
     $97 = (($13) + ($95<<1)|0);
     $98 = HEAP16[$97>>1]|0;
     HEAP16[$$2100>>1] = $98;
    }
    $99 = ((($$292)) + 1|0);
    $100 = ((($$2100)) + 2|0);
    $$2 = $$1;$$3101 = $100;$$393 = $99;
    label = 29;
    continue;
   }
   else if ((label|0) == 29) {
    label = 0;
    $101 = HEAP8[$$393>>0]|0;
    $102 = $101&255;
    $103 = ($102|0)==($15|0);
    if (!($103)) {
     $104 = (($13) + ($102<<1)|0);
     $105 = HEAP16[$104>>1]|0;
     HEAP16[$$3101>>1] = $105;
    }
    $106 = ((($$393)) + 1|0);
    $107 = ((($$3101)) + 2|0);
    $$3 = $$2;$$4102 = $107;$$494 = $106;
    label = 32;
    continue;
   }
   else if ((label|0) == 32) {
    label = 0;
    $108 = HEAP8[$$494>>0]|0;
    $109 = $108&255;
    $110 = ($109|0)==($15|0);
    if (!($110)) {
     $111 = (($13) + ($109<<1)|0);
     $112 = HEAP16[$111>>1]|0;
     HEAP16[$$4102>>1] = $112;
    }
    $113 = ((($$494)) + 1|0);
    $114 = ((($$4102)) + 2|0);
    $$4 = $$3;$$5103 = $114;$$595 = $113;
    label = 35;
    continue;
   }
   else if ((label|0) == 35) {
    label = 0;
    $115 = HEAP8[$$595>>0]|0;
    $116 = $115&255;
    $117 = ($116|0)==($15|0);
    if (!($117)) {
     $118 = (($13) + ($116<<1)|0);
     $119 = HEAP16[$118>>1]|0;
     HEAP16[$$5103>>1] = $119;
    }
    $120 = ((($$595)) + 1|0);
    $121 = ((($$5103)) + 2|0);
    $$5 = $$4;$$6104 = $121;$$696 = $120;
    label = 38;
    continue;
   }
   else if ((label|0) == 38) {
    label = 0;
    $122 = HEAP8[$$696>>0]|0;
    $123 = $122&255;
    $124 = ($123|0)==($15|0);
    if (!($124)) {
     $125 = (($13) + ($123<<1)|0);
     $126 = HEAP16[$125>>1]|0;
     HEAP16[$$6104>>1] = $126;
    }
    $127 = ((($$696)) + 1|0);
    $128 = ((($$6104)) + 2|0);
    $$6 = $$5;$$7105 = $128;$$797 = $127;
    label = 41;
    continue;
   }
   else if ((label|0) == 41) {
    label = 0;
    $129 = HEAP8[$$797>>0]|0;
    $130 = $129&255;
    $131 = ($130|0)==($15|0);
    if (!($131)) {
     $132 = (($13) + ($130<<1)|0);
     $133 = HEAP16[$132>>1]|0;
     HEAP16[$$7105>>1] = $133;
    }
    $134 = ((($$797)) + 1|0);
    $135 = ((($$7105)) + 2|0);
    $$7 = $$6;$$8 = $134;$$8106 = $135;
    label = 44;
    continue;
   }
   else if ((label|0) == 44) {
    label = 0;
    $136 = HEAP8[$$8>>0]|0;
    $137 = $136&255;
    $138 = ($137|0)==($15|0);
    if (!($138)) {
     $139 = (($13) + ($137<<1)|0);
     $140 = HEAP16[$139>>1]|0;
     HEAP16[$$8106>>1] = $140;
    }
    $86 = ((($$8)) + 1|0);
    $91 = ((($$8106)) + 2|0);
    $141 = (($$7) + -1)|0;
    $142 = ($$7|0)>(1);
    if (!($142)) {
     break;
    }
    $85 = HEAP8[$86>>0]|0;
    $87 = $85&255;
    $88 = ($87|0)==($15|0);
    if (!($88)) {
     $89 = (($13) + ($87<<1)|0);
     $90 = HEAP16[$89>>1]|0;
     HEAP16[$91>>1] = $90;
    }
    $92 = ((($$8)) + 2|0);
    $93 = ((($$8106)) + 4|0);
    $$1 = $141;$$2100 = $93;$$292 = $92;
    label = 26;
    continue;
   }
  }
  $143 = (($86) + ($7)|0);
  $144 = (($91) + ($16<<1)|0);
  $145 = (($146) + -1)|0;
  $147 = ($146|0)==(0);
  if ($147) {
   label = 49;
   break;
  } else {
   $$090108 = $143;$$098107 = $144;$146 = $145;
  }
 }
 if ((label|0) == 47) {
  // unreachable;
 }
 else if ((label|0) == 49) {
  return;
 }
}
function _Blit1to3Key($0) {
 $0 = $0|0;
 var $$0 = 0, $$0147165 = 0, $$0155164 = 0, $$1 = 0, $$1148 = 0, $$1156 = 0, $$2 = 0, $$2149 = 0, $$2157 = 0, $$3 = 0, $$3150 = 0, $$3158 = 0, $$4 = 0, $$4151 = 0, $$4159 = 0, $$5 = 0, $$5152 = 0, $$5160 = 0, $$6 = 0, $$6153 = 0;
 var $$6161 = 0, $$7 = 0, $$7154 = 0, $$7162 = 0, $$8 = 0, $$8163 = 0, $$in = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $trunc = 0;
 var $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($0)) + 36|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($0)) + 48|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ((($0)) + 56|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($4|0)==(0);
 if ($13) {
  return;
 }
 $14 = ((($0)) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP32[$0>>2]|0;
 $17 = (($2) + 7)|0;
 $18 = (($17|0) / 8)&-1;
 $trunc = $2&255;
 $$0147165 = $16;$$0155164 = $15;$$in = $4;
 L4: while(1) {
  $19 = (($$in) + -1)|0;
  $trunc$clear = $trunc & 7;
  switch ($trunc$clear<<24>>24) {
  case 0:  {
   $$0 = $18;$$1148 = $$0147165;$$1156 = $$0155164;
   label = 4;
   break;
  }
  case 7:  {
   $$1 = $18;$$2149 = $$0147165;$$2157 = $$0155164;
   label = 7;
   break;
  }
  case 6:  {
   $$2 = $18;$$3150 = $$0147165;$$3158 = $$0155164;
   label = 10;
   break;
  }
  case 5:  {
   $$3 = $18;$$4151 = $$0147165;$$4159 = $$0155164;
   label = 13;
   break;
  }
  case 4:  {
   $$4 = $18;$$5152 = $$0147165;$$5160 = $$0155164;
   label = 16;
   break;
  }
  case 3:  {
   $$5 = $18;$$6153 = $$0147165;$$6161 = $$0155164;
   label = 19;
   break;
  }
  case 2:  {
   $$6 = $18;$$7154 = $$0147165;$$7162 = $$0155164;
   label = 22;
   break;
  }
  case 1:  {
   $$7 = $18;$$8 = $$0147165;$$8163 = $$0155164;
   label = 25;
   break;
  }
  default: {
   label = 28;
   break L4;
  }
  }
  while(1) {
   if ((label|0) == 4) {
    label = 0;
    $20 = HEAP8[$$1148>>0]|0;
    $21 = $20&255;
    $22 = ($21|0)==($12|0);
    if (!($22)) {
     $23 = $21 << 2;
     $24 = $23 | 1;
     $25 = (($10) + ($23)|0);
     $26 = HEAP8[$25>>0]|0;
     HEAP8[$$1156>>0] = $26;
     $27 = (($24) + 1)|0;
     $28 = (($10) + ($24)|0);
     $29 = HEAP8[$28>>0]|0;
     $30 = ((($$1156)) + 1|0);
     HEAP8[$30>>0] = $29;
     $31 = (($10) + ($27)|0);
     $32 = HEAP8[$31>>0]|0;
     $33 = ((($$1156)) + 2|0);
     HEAP8[$33>>0] = $32;
    }
    $34 = ((($$1148)) + 1|0);
    $35 = ((($$1156)) + 3|0);
    $$1 = $$0;$$2149 = $34;$$2157 = $35;
    label = 7;
    continue;
   }
   else if ((label|0) == 7) {
    label = 0;
    $36 = HEAP8[$$2149>>0]|0;
    $37 = $36&255;
    $38 = ($37|0)==($12|0);
    if (!($38)) {
     $39 = $37 << 2;
     $40 = $39 | 1;
     $41 = (($10) + ($39)|0);
     $42 = HEAP8[$41>>0]|0;
     HEAP8[$$2157>>0] = $42;
     $43 = (($40) + 1)|0;
     $44 = (($10) + ($40)|0);
     $45 = HEAP8[$44>>0]|0;
     $46 = ((($$2157)) + 1|0);
     HEAP8[$46>>0] = $45;
     $47 = (($10) + ($43)|0);
     $48 = HEAP8[$47>>0]|0;
     $49 = ((($$2157)) + 2|0);
     HEAP8[$49>>0] = $48;
    }
    $50 = ((($$2149)) + 1|0);
    $51 = ((($$2157)) + 3|0);
    $$2 = $$1;$$3150 = $50;$$3158 = $51;
    label = 10;
    continue;
   }
   else if ((label|0) == 10) {
    label = 0;
    $52 = HEAP8[$$3150>>0]|0;
    $53 = $52&255;
    $54 = ($53|0)==($12|0);
    if (!($54)) {
     $55 = $53 << 2;
     $56 = $55 | 1;
     $57 = (($10) + ($55)|0);
     $58 = HEAP8[$57>>0]|0;
     HEAP8[$$3158>>0] = $58;
     $59 = (($56) + 1)|0;
     $60 = (($10) + ($56)|0);
     $61 = HEAP8[$60>>0]|0;
     $62 = ((($$3158)) + 1|0);
     HEAP8[$62>>0] = $61;
     $63 = (($10) + ($59)|0);
     $64 = HEAP8[$63>>0]|0;
     $65 = ((($$3158)) + 2|0);
     HEAP8[$65>>0] = $64;
    }
    $66 = ((($$3150)) + 1|0);
    $67 = ((($$3158)) + 3|0);
    $$3 = $$2;$$4151 = $66;$$4159 = $67;
    label = 13;
    continue;
   }
   else if ((label|0) == 13) {
    label = 0;
    $68 = HEAP8[$$4151>>0]|0;
    $69 = $68&255;
    $70 = ($69|0)==($12|0);
    if (!($70)) {
     $71 = $69 << 2;
     $72 = $71 | 1;
     $73 = (($10) + ($71)|0);
     $74 = HEAP8[$73>>0]|0;
     HEAP8[$$4159>>0] = $74;
     $75 = (($72) + 1)|0;
     $76 = (($10) + ($72)|0);
     $77 = HEAP8[$76>>0]|0;
     $78 = ((($$4159)) + 1|0);
     HEAP8[$78>>0] = $77;
     $79 = (($10) + ($75)|0);
     $80 = HEAP8[$79>>0]|0;
     $81 = ((($$4159)) + 2|0);
     HEAP8[$81>>0] = $80;
    }
    $82 = ((($$4151)) + 1|0);
    $83 = ((($$4159)) + 3|0);
    $$4 = $$3;$$5152 = $82;$$5160 = $83;
    label = 16;
    continue;
   }
   else if ((label|0) == 16) {
    label = 0;
    $84 = HEAP8[$$5152>>0]|0;
    $85 = $84&255;
    $86 = ($85|0)==($12|0);
    if (!($86)) {
     $87 = $85 << 2;
     $88 = $87 | 1;
     $89 = (($10) + ($87)|0);
     $90 = HEAP8[$89>>0]|0;
     HEAP8[$$5160>>0] = $90;
     $91 = (($88) + 1)|0;
     $92 = (($10) + ($88)|0);
     $93 = HEAP8[$92>>0]|0;
     $94 = ((($$5160)) + 1|0);
     HEAP8[$94>>0] = $93;
     $95 = (($10) + ($91)|0);
     $96 = HEAP8[$95>>0]|0;
     $97 = ((($$5160)) + 2|0);
     HEAP8[$97>>0] = $96;
    }
    $98 = ((($$5152)) + 1|0);
    $99 = ((($$5160)) + 3|0);
    $$5 = $$4;$$6153 = $98;$$6161 = $99;
    label = 19;
    continue;
   }
   else if ((label|0) == 19) {
    label = 0;
    $100 = HEAP8[$$6153>>0]|0;
    $101 = $100&255;
    $102 = ($101|0)==($12|0);
    if (!($102)) {
     $103 = $101 << 2;
     $104 = $103 | 1;
     $105 = (($10) + ($103)|0);
     $106 = HEAP8[$105>>0]|0;
     HEAP8[$$6161>>0] = $106;
     $107 = (($104) + 1)|0;
     $108 = (($10) + ($104)|0);
     $109 = HEAP8[$108>>0]|0;
     $110 = ((($$6161)) + 1|0);
     HEAP8[$110>>0] = $109;
     $111 = (($10) + ($107)|0);
     $112 = HEAP8[$111>>0]|0;
     $113 = ((($$6161)) + 2|0);
     HEAP8[$113>>0] = $112;
    }
    $114 = ((($$6153)) + 1|0);
    $115 = ((($$6161)) + 3|0);
    $$6 = $$5;$$7154 = $114;$$7162 = $115;
    label = 22;
    continue;
   }
   else if ((label|0) == 22) {
    label = 0;
    $116 = HEAP8[$$7154>>0]|0;
    $117 = $116&255;
    $118 = ($117|0)==($12|0);
    if (!($118)) {
     $119 = $117 << 2;
     $120 = $119 | 1;
     $121 = (($10) + ($119)|0);
     $122 = HEAP8[$121>>0]|0;
     HEAP8[$$7162>>0] = $122;
     $123 = (($120) + 1)|0;
     $124 = (($10) + ($120)|0);
     $125 = HEAP8[$124>>0]|0;
     $126 = ((($$7162)) + 1|0);
     HEAP8[$126>>0] = $125;
     $127 = (($10) + ($123)|0);
     $128 = HEAP8[$127>>0]|0;
     $129 = ((($$7162)) + 2|0);
     HEAP8[$129>>0] = $128;
    }
    $130 = ((($$7154)) + 1|0);
    $131 = ((($$7162)) + 3|0);
    $$7 = $$6;$$8 = $130;$$8163 = $131;
    label = 25;
    continue;
   }
   else if ((label|0) == 25) {
    label = 0;
    $132 = HEAP8[$$8>>0]|0;
    $133 = $132&255;
    $134 = ($133|0)==($12|0);
    if (!($134)) {
     $135 = $133 << 2;
     $136 = $135 | 1;
     $137 = (($10) + ($135)|0);
     $138 = HEAP8[$137>>0]|0;
     HEAP8[$$8163>>0] = $138;
     $139 = (($136) + 1)|0;
     $140 = (($10) + ($136)|0);
     $141 = HEAP8[$140>>0]|0;
     $142 = ((($$8163)) + 1|0);
     HEAP8[$142>>0] = $141;
     $143 = (($10) + ($139)|0);
     $144 = HEAP8[$143>>0]|0;
     $145 = ((($$8163)) + 2|0);
     HEAP8[$145>>0] = $144;
    }
    $146 = ((($$8)) + 1|0);
    $147 = ((($$8163)) + 3|0);
    $148 = (($$7) + -1)|0;
    $149 = ($$7|0)>(1);
    if ($149) {
     $$0 = $148;$$1148 = $146;$$1156 = $147;
     label = 4;
     continue;
    } else {
     break;
    }
   }
  }
  $150 = (($146) + ($6)|0);
  $151 = (($147) + ($8)|0);
  $152 = ($19|0)==(0);
  if ($152) {
   label = 30;
   break;
  } else {
   $$0147165 = $150;$$0155164 = $151;$$in = $19;
  }
 }
 if ((label|0) == 28) {
  // unreachable;
 }
 else if ((label|0) == 30) {
  return;
 }
}
function _Blit1to4Key($0) {
 $0 = $0|0;
 var $$0$us = 0, $$090108 = 0, $$090108$us = 0, $$098107 = 0, $$098107$us = 0, $$1 = 0, $$191$us = 0, $$199$us = 0, $$2 = 0, $$2100 = 0, $$292 = 0, $$3 = 0, $$3101 = 0, $$393 = 0, $$4 = 0, $$4102 = 0, $$494 = 0, $$5 = 0, $$5103 = 0, $$595 = 0;
 var $$6 = 0, $$6104 = 0, $$696 = 0, $$7 = 0, $$7105 = 0, $$797 = 0, $$8 = 0, $$8106 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $trunc = 0, $trunc$clear = 0, $trunc$clear1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$0>>2]|0;
 $6 = ((($0)) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($0)) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($0)) + 36|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($0)) + 48|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($0)) + 56|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($11|0) / 4)&-1;
 $17 = (($4) + -1)|0;
 $18 = ($4|0)==(0);
 if ($18) {
  return;
 }
 $19 = (($2) + 7)|0;
 $20 = (($19|0) / 8)&-1;
 $trunc = $2&255;
 $trunc$clear = $trunc & 7;
 $21 = ($trunc$clear<<24>>24)==(0);
 if ($21) {
  $$090108$us = $5;$$098107$us = $9;$83 = $17;
  while(1) {
   $$0$us = $20;$$191$us = $$090108$us;$$199$us = $$098107$us;
   while(1) {
    $22 = HEAP8[$$191$us>>0]|0;
    $23 = $22&255;
    $24 = ($23|0)==($15|0);
    if (!($24)) {
     $25 = (($13) + ($23<<2)|0);
     $26 = HEAP32[$25>>2]|0;
     HEAP32[$$199$us>>2] = $26;
    }
    $27 = ((($$191$us)) + 1|0);
    $28 = HEAP8[$27>>0]|0;
    $29 = $28&255;
    $30 = ($29|0)==($15|0);
    if (!($30)) {
     $31 = ((($$199$us)) + 4|0);
     $32 = (($13) + ($29<<2)|0);
     $33 = HEAP32[$32>>2]|0;
     HEAP32[$31>>2] = $33;
    }
    $34 = ((($$191$us)) + 2|0);
    $35 = HEAP8[$34>>0]|0;
    $36 = $35&255;
    $37 = ($36|0)==($15|0);
    if (!($37)) {
     $38 = ((($$199$us)) + 8|0);
     $39 = (($13) + ($36<<2)|0);
     $40 = HEAP32[$39>>2]|0;
     HEAP32[$38>>2] = $40;
    }
    $41 = ((($$191$us)) + 3|0);
    $42 = HEAP8[$41>>0]|0;
    $43 = $42&255;
    $44 = ($43|0)==($15|0);
    if (!($44)) {
     $45 = ((($$199$us)) + 12|0);
     $46 = (($13) + ($43<<2)|0);
     $47 = HEAP32[$46>>2]|0;
     HEAP32[$45>>2] = $47;
    }
    $48 = ((($$191$us)) + 4|0);
    $49 = HEAP8[$48>>0]|0;
    $50 = $49&255;
    $51 = ($50|0)==($15|0);
    if (!($51)) {
     $52 = ((($$199$us)) + 16|0);
     $53 = (($13) + ($50<<2)|0);
     $54 = HEAP32[$53>>2]|0;
     HEAP32[$52>>2] = $54;
    }
    $55 = ((($$191$us)) + 5|0);
    $56 = HEAP8[$55>>0]|0;
    $57 = $56&255;
    $58 = ($57|0)==($15|0);
    if (!($58)) {
     $59 = ((($$199$us)) + 20|0);
     $60 = (($13) + ($57<<2)|0);
     $61 = HEAP32[$60>>2]|0;
     HEAP32[$59>>2] = $61;
    }
    $62 = ((($$191$us)) + 6|0);
    $63 = HEAP8[$62>>0]|0;
    $64 = $63&255;
    $65 = ($64|0)==($15|0);
    if (!($65)) {
     $66 = ((($$199$us)) + 24|0);
     $67 = (($13) + ($64<<2)|0);
     $68 = HEAP32[$67>>2]|0;
     HEAP32[$66>>2] = $68;
    }
    $69 = ((($$191$us)) + 7|0);
    $70 = HEAP8[$69>>0]|0;
    $71 = $70&255;
    $72 = ($71|0)==($15|0);
    if (!($72)) {
     $73 = ((($$199$us)) + 28|0);
     $74 = (($13) + ($71<<2)|0);
     $75 = HEAP32[$74>>2]|0;
     HEAP32[$73>>2] = $75;
    }
    $76 = ((($$191$us)) + 8|0);
    $77 = ((($$199$us)) + 32|0);
    $78 = (($$0$us) + -1)|0;
    $79 = ($$0$us|0)>(1);
    if ($79) {
     $$0$us = $78;$$191$us = $76;$$199$us = $77;
    } else {
     break;
    }
   }
   $80 = (($76) + ($7)|0);
   $81 = (($77) + ($16<<2)|0);
   $82 = (($83) + -1)|0;
   $84 = ($83|0)==(0);
   if ($84) {
    break;
   } else {
    $$090108$us = $80;$$098107$us = $81;$83 = $82;
   }
  }
  return;
 } else {
  $$090108 = $5;$$098107 = $9;$146 = $17;
 }
 L35: while(1) {
  $trunc$clear1 = $trunc & 7;
  switch ($trunc$clear1<<24>>24) {
  case 1:  {
   $$7 = $20;$$8 = $$090108;$$8106 = $$098107;
   label = 44;
   break;
  }
  case 7:  {
   $$1 = $20;$$2100 = $$098107;$$292 = $$090108;
   label = 26;
   break;
  }
  case 6:  {
   $$2 = $20;$$3101 = $$098107;$$393 = $$090108;
   label = 29;
   break;
  }
  case 5:  {
   $$3 = $20;$$4102 = $$098107;$$494 = $$090108;
   label = 32;
   break;
  }
  case 4:  {
   $$4 = $20;$$5103 = $$098107;$$595 = $$090108;
   label = 35;
   break;
  }
  case 3:  {
   $$5 = $20;$$6104 = $$098107;$$696 = $$090108;
   label = 38;
   break;
  }
  case 2:  {
   $$6 = $20;$$7105 = $$098107;$$797 = $$090108;
   label = 41;
   break;
  }
  default: {
   label = 47;
   break L35;
  }
  }
  while(1) {
   if ((label|0) == 26) {
    label = 0;
    $94 = HEAP8[$$292>>0]|0;
    $95 = $94&255;
    $96 = ($95|0)==($15|0);
    if (!($96)) {
     $97 = (($13) + ($95<<2)|0);
     $98 = HEAP32[$97>>2]|0;
     HEAP32[$$2100>>2] = $98;
    }
    $99 = ((($$292)) + 1|0);
    $100 = ((($$2100)) + 4|0);
    $$2 = $$1;$$3101 = $100;$$393 = $99;
    label = 29;
    continue;
   }
   else if ((label|0) == 29) {
    label = 0;
    $101 = HEAP8[$$393>>0]|0;
    $102 = $101&255;
    $103 = ($102|0)==($15|0);
    if (!($103)) {
     $104 = (($13) + ($102<<2)|0);
     $105 = HEAP32[$104>>2]|0;
     HEAP32[$$3101>>2] = $105;
    }
    $106 = ((($$393)) + 1|0);
    $107 = ((($$3101)) + 4|0);
    $$3 = $$2;$$4102 = $107;$$494 = $106;
    label = 32;
    continue;
   }
   else if ((label|0) == 32) {
    label = 0;
    $108 = HEAP8[$$494>>0]|0;
    $109 = $108&255;
    $110 = ($109|0)==($15|0);
    if (!($110)) {
     $111 = (($13) + ($109<<2)|0);
     $112 = HEAP32[$111>>2]|0;
     HEAP32[$$4102>>2] = $112;
    }
    $113 = ((($$494)) + 1|0);
    $114 = ((($$4102)) + 4|0);
    $$4 = $$3;$$5103 = $114;$$595 = $113;
    label = 35;
    continue;
   }
   else if ((label|0) == 35) {
    label = 0;
    $115 = HEAP8[$$595>>0]|0;
    $116 = $115&255;
    $117 = ($116|0)==($15|0);
    if (!($117)) {
     $118 = (($13) + ($116<<2)|0);
     $119 = HEAP32[$118>>2]|0;
     HEAP32[$$5103>>2] = $119;
    }
    $120 = ((($$595)) + 1|0);
    $121 = ((($$5103)) + 4|0);
    $$5 = $$4;$$6104 = $121;$$696 = $120;
    label = 38;
    continue;
   }
   else if ((label|0) == 38) {
    label = 0;
    $122 = HEAP8[$$696>>0]|0;
    $123 = $122&255;
    $124 = ($123|0)==($15|0);
    if (!($124)) {
     $125 = (($13) + ($123<<2)|0);
     $126 = HEAP32[$125>>2]|0;
     HEAP32[$$6104>>2] = $126;
    }
    $127 = ((($$696)) + 1|0);
    $128 = ((($$6104)) + 4|0);
    $$6 = $$5;$$7105 = $128;$$797 = $127;
    label = 41;
    continue;
   }
   else if ((label|0) == 41) {
    label = 0;
    $129 = HEAP8[$$797>>0]|0;
    $130 = $129&255;
    $131 = ($130|0)==($15|0);
    if (!($131)) {
     $132 = (($13) + ($130<<2)|0);
     $133 = HEAP32[$132>>2]|0;
     HEAP32[$$7105>>2] = $133;
    }
    $134 = ((($$797)) + 1|0);
    $135 = ((($$7105)) + 4|0);
    $$7 = $$6;$$8 = $134;$$8106 = $135;
    label = 44;
    continue;
   }
   else if ((label|0) == 44) {
    label = 0;
    $136 = HEAP8[$$8>>0]|0;
    $137 = $136&255;
    $138 = ($137|0)==($15|0);
    if (!($138)) {
     $139 = (($13) + ($137<<2)|0);
     $140 = HEAP32[$139>>2]|0;
     HEAP32[$$8106>>2] = $140;
    }
    $86 = ((($$8)) + 1|0);
    $91 = ((($$8106)) + 4|0);
    $141 = (($$7) + -1)|0;
    $142 = ($$7|0)>(1);
    if (!($142)) {
     break;
    }
    $85 = HEAP8[$86>>0]|0;
    $87 = $85&255;
    $88 = ($87|0)==($15|0);
    if (!($88)) {
     $89 = (($13) + ($87<<2)|0);
     $90 = HEAP32[$89>>2]|0;
     HEAP32[$91>>2] = $90;
    }
    $92 = ((($$8)) + 2|0);
    $93 = ((($$8106)) + 8|0);
    $$1 = $141;$$2100 = $93;$$292 = $92;
    label = 26;
    continue;
   }
  }
  $143 = (($86) + ($7)|0);
  $144 = (($91) + ($16<<2)|0);
  $145 = (($146) + -1)|0;
  $147 = ($146|0)==(0);
  if ($147) {
   label = 49;
   break;
  } else {
   $$090108 = $143;$$098107 = $144;$146 = $145;
  }
 }
 if ((label|0) == 47) {
  // unreachable;
 }
 else if ((label|0) == 49) {
  return;
 }
}
function _Blit1to1($0) {
 $0 = $0|0;
 var $$0$us = 0, $$07088 = 0, $$07088$us = 0, $$07088$us90 = 0, $$07887 = 0, $$07887$us = 0, $$07887$us91 = 0, $$1$us97 = 0, $$171$us = 0, $$179$us = 0, $$2 = 0, $$272$us96 = 0, $$280$us95 = 0, $$3 = 0, $$373 = 0, $$381 = 0, $$4 = 0, $$474 = 0, $$482 = 0, $$5 = 0;
 var $$575 = 0, $$583 = 0, $$6 = 0, $$676 = 0, $$684 = 0, $$7 = 0, $$777 = 0, $$785 = 0, $$8 = 0, $$886 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0;
 var $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0;
 var $180 = 0, $181 = 0, $182 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $trunc = 0, $trunc$clear = 0, $trunc$clear1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$0>>2]|0;
 $6 = ((($0)) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($0)) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($0)) + 36|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($0)) + 48|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($4) + -1)|0;
 $15 = ($4|0)==(0);
 if ($15) {
  return;
 }
 $16 = (($2) + 7)|0;
 $17 = (($16|0) / 8)&-1;
 $trunc = $2&255;
 $trunc$clear = $trunc & 7;
 switch ($trunc$clear<<24>>24) {
 case 0:  {
  $$07088$us = $5;$$07887$us = $9;$71 = $14;
  while(1) {
   $$0$us = $17;$$171$us = $$07088$us;$$179$us = $$07887$us;
   while(1) {
    $18 = HEAP8[$$171$us>>0]|0;
    $19 = $18&255;
    $20 = (($13) + ($19)|0);
    $21 = HEAP8[$20>>0]|0;
    HEAP8[$$179$us>>0] = $21;
    $22 = ((($$179$us)) + 1|0);
    $23 = ((($$171$us)) + 1|0);
    $24 = HEAP8[$23>>0]|0;
    $25 = $24&255;
    $26 = (($13) + ($25)|0);
    $27 = HEAP8[$26>>0]|0;
    HEAP8[$22>>0] = $27;
    $28 = ((($$179$us)) + 2|0);
    $29 = ((($$171$us)) + 2|0);
    $30 = HEAP8[$29>>0]|0;
    $31 = $30&255;
    $32 = (($13) + ($31)|0);
    $33 = HEAP8[$32>>0]|0;
    HEAP8[$28>>0] = $33;
    $34 = ((($$179$us)) + 3|0);
    $35 = ((($$171$us)) + 3|0);
    $36 = HEAP8[$35>>0]|0;
    $37 = $36&255;
    $38 = (($13) + ($37)|0);
    $39 = HEAP8[$38>>0]|0;
    HEAP8[$34>>0] = $39;
    $40 = ((($$179$us)) + 4|0);
    $41 = ((($$171$us)) + 4|0);
    $42 = HEAP8[$41>>0]|0;
    $43 = $42&255;
    $44 = (($13) + ($43)|0);
    $45 = HEAP8[$44>>0]|0;
    HEAP8[$40>>0] = $45;
    $46 = ((($$179$us)) + 5|0);
    $47 = ((($$171$us)) + 5|0);
    $48 = HEAP8[$47>>0]|0;
    $49 = $48&255;
    $50 = (($13) + ($49)|0);
    $51 = HEAP8[$50>>0]|0;
    HEAP8[$46>>0] = $51;
    $52 = ((($$179$us)) + 6|0);
    $53 = ((($$171$us)) + 6|0);
    $54 = HEAP8[$53>>0]|0;
    $55 = $54&255;
    $56 = (($13) + ($55)|0);
    $57 = HEAP8[$56>>0]|0;
    HEAP8[$52>>0] = $57;
    $58 = ((($$179$us)) + 7|0);
    $59 = ((($$171$us)) + 7|0);
    $60 = HEAP8[$59>>0]|0;
    $61 = $60&255;
    $62 = (($13) + ($61)|0);
    $63 = HEAP8[$62>>0]|0;
    HEAP8[$58>>0] = $63;
    $64 = ((($$179$us)) + 8|0);
    $65 = ((($$171$us)) + 8|0);
    $66 = (($$0$us) + -1)|0;
    $67 = ($$0$us|0)>(1);
    if ($67) {
     $$0$us = $66;$$171$us = $65;$$179$us = $64;
    } else {
     break;
    }
   }
   $68 = (($65) + ($7)|0);
   $69 = (($64) + ($11)|0);
   $70 = (($71) + -1)|0;
   $72 = ($71|0)==(0);
   if ($72) {
    break;
   } else {
    $$07088$us = $68;$$07887$us = $69;$71 = $70;
   }
  }
  return;
  break;
 }
 case 7:  {
  $$07088$us90 = $5;$$07887$us91 = $9;$126 = $14;
  while(1) {
   $$1$us97 = $17;$$272$us96 = $$07088$us90;$$280$us95 = $$07887$us91;
   while(1) {
    $82 = HEAP8[$$272$us96>>0]|0;
    $83 = $82&255;
    $84 = (($13) + ($83)|0);
    $85 = HEAP8[$84>>0]|0;
    HEAP8[$$280$us95>>0] = $85;
    $86 = ((($$280$us95)) + 1|0);
    $87 = ((($$272$us96)) + 1|0);
    $88 = HEAP8[$87>>0]|0;
    $89 = $88&255;
    $90 = (($13) + ($89)|0);
    $91 = HEAP8[$90>>0]|0;
    HEAP8[$86>>0] = $91;
    $92 = ((($$280$us95)) + 2|0);
    $93 = ((($$272$us96)) + 2|0);
    $94 = HEAP8[$93>>0]|0;
    $95 = $94&255;
    $96 = (($13) + ($95)|0);
    $97 = HEAP8[$96>>0]|0;
    HEAP8[$92>>0] = $97;
    $98 = ((($$280$us95)) + 3|0);
    $99 = ((($$272$us96)) + 3|0);
    $100 = HEAP8[$99>>0]|0;
    $101 = $100&255;
    $102 = (($13) + ($101)|0);
    $103 = HEAP8[$102>>0]|0;
    HEAP8[$98>>0] = $103;
    $104 = ((($$280$us95)) + 4|0);
    $105 = ((($$272$us96)) + 4|0);
    $106 = HEAP8[$105>>0]|0;
    $107 = $106&255;
    $108 = (($13) + ($107)|0);
    $109 = HEAP8[$108>>0]|0;
    HEAP8[$104>>0] = $109;
    $110 = ((($$280$us95)) + 5|0);
    $111 = ((($$272$us96)) + 5|0);
    $112 = HEAP8[$111>>0]|0;
    $113 = $112&255;
    $114 = (($13) + ($113)|0);
    $115 = HEAP8[$114>>0]|0;
    HEAP8[$110>>0] = $115;
    $116 = ((($$280$us95)) + 6|0);
    $117 = ((($$272$us96)) + 6|0);
    $118 = HEAP8[$117>>0]|0;
    $119 = $118&255;
    $120 = (($13) + ($119)|0);
    $121 = HEAP8[$120>>0]|0;
    HEAP8[$116>>0] = $121;
    $79 = ((($$280$us95)) + 7|0);
    $75 = ((($$272$us96)) + 7|0);
    $122 = ($$1$us97|0)>(1);
    if (!($122)) {
     break;
    }
    $73 = (($$1$us97) + -1)|0;
    $74 = HEAP8[$75>>0]|0;
    $76 = $74&255;
    $77 = (($13) + ($76)|0);
    $78 = HEAP8[$77>>0]|0;
    HEAP8[$79>>0] = $78;
    $80 = ((($$280$us95)) + 8|0);
    $81 = ((($$272$us96)) + 8|0);
    $$1$us97 = $73;$$272$us96 = $81;$$280$us95 = $80;
   }
   $123 = (($75) + ($7)|0);
   $124 = (($79) + ($11)|0);
   $125 = (($126) + -1)|0;
   $127 = ($126|0)==(0);
   if ($127) {
    break;
   } else {
    $$07088$us90 = $123;$$07887$us91 = $124;$126 = $125;
   }
  }
  return;
  break;
 }
 default: {
  $$07088 = $5;$$07887 = $9;$181 = $14;
  L5: while(1) {
   $trunc$clear1 = $trunc & 7;
   switch ($trunc$clear1<<24>>24) {
   case 1:  {
    $$7 = $17;$$8 = $$07088;$$886 = $$07887;
    label = 17;
    break;
   }
   case 2:  {
    $$6 = $17;$$777 = $$07088;$$785 = $$07887;
    label = 16;
    break;
   }
   case 6:  {
    $$2 = $17;$$373 = $$07088;$$381 = $$07887;
    label = 12;
    break;
   }
   case 5:  {
    $$3 = $17;$$474 = $$07088;$$482 = $$07887;
    label = 13;
    break;
   }
   case 4:  {
    $$4 = $17;$$575 = $$07088;$$583 = $$07887;
    label = 14;
    break;
   }
   case 3:  {
    $$5 = $17;$$676 = $$07088;$$684 = $$07887;
    label = 15;
    break;
   }
   default: {
    label = 18;
    break L5;
   }
   }
   while(1) {
    if ((label|0) == 12) {
     label = 0;
     $143 = HEAP8[$$373>>0]|0;
     $144 = $143&255;
     $145 = (($13) + ($144)|0);
     $146 = HEAP8[$145>>0]|0;
     HEAP8[$$381>>0] = $146;
     $147 = ((($$381)) + 1|0);
     $148 = ((($$373)) + 1|0);
     $$3 = $$2;$$474 = $148;$$482 = $147;
     label = 13;
     continue;
    }
    else if ((label|0) == 13) {
     label = 0;
     $149 = HEAP8[$$474>>0]|0;
     $150 = $149&255;
     $151 = (($13) + ($150)|0);
     $152 = HEAP8[$151>>0]|0;
     HEAP8[$$482>>0] = $152;
     $153 = ((($$482)) + 1|0);
     $154 = ((($$474)) + 1|0);
     $$4 = $$3;$$575 = $154;$$583 = $153;
     label = 14;
     continue;
    }
    else if ((label|0) == 14) {
     label = 0;
     $155 = HEAP8[$$575>>0]|0;
     $156 = $155&255;
     $157 = (($13) + ($156)|0);
     $158 = HEAP8[$157>>0]|0;
     HEAP8[$$583>>0] = $158;
     $159 = ((($$583)) + 1|0);
     $160 = ((($$575)) + 1|0);
     $$5 = $$4;$$676 = $160;$$684 = $159;
     label = 15;
     continue;
    }
    else if ((label|0) == 15) {
     label = 0;
     $161 = HEAP8[$$676>>0]|0;
     $162 = $161&255;
     $163 = (($13) + ($162)|0);
     $164 = HEAP8[$163>>0]|0;
     HEAP8[$$684>>0] = $164;
     $165 = ((($$684)) + 1|0);
     $166 = ((($$676)) + 1|0);
     $$6 = $$5;$$777 = $166;$$785 = $165;
     label = 16;
     continue;
    }
    else if ((label|0) == 16) {
     label = 0;
     $167 = HEAP8[$$777>>0]|0;
     $168 = $167&255;
     $169 = (($13) + ($168)|0);
     $170 = HEAP8[$169>>0]|0;
     HEAP8[$$785>>0] = $170;
     $171 = ((($$785)) + 1|0);
     $172 = ((($$777)) + 1|0);
     $$7 = $$6;$$8 = $172;$$886 = $171;
     label = 17;
     continue;
    }
    else if ((label|0) == 17) {
     label = 0;
     $173 = HEAP8[$$8>>0]|0;
     $174 = $173&255;
     $175 = (($13) + ($174)|0);
     $176 = HEAP8[$175>>0]|0;
     HEAP8[$$886>>0] = $176;
     $134 = ((($$886)) + 1|0);
     $130 = ((($$8)) + 1|0);
     $177 = ($$7|0)>(1);
     if (!($177)) {
      break;
     }
     $128 = (($$7) + -1)|0;
     $129 = HEAP8[$130>>0]|0;
     $131 = $129&255;
     $132 = (($13) + ($131)|0);
     $133 = HEAP8[$132>>0]|0;
     HEAP8[$134>>0] = $133;
     $135 = ((($$886)) + 2|0);
     $136 = ((($$8)) + 2|0);
     $137 = HEAP8[$136>>0]|0;
     $138 = $137&255;
     $139 = (($13) + ($138)|0);
     $140 = HEAP8[$139>>0]|0;
     HEAP8[$135>>0] = $140;
     $141 = ((($$886)) + 3|0);
     $142 = ((($$8)) + 3|0);
     $$2 = $128;$$373 = $142;$$381 = $141;
     label = 12;
     continue;
    }
   }
   $178 = (($130) + ($7)|0);
   $179 = (($134) + ($11)|0);
   $180 = (($181) + -1)|0;
   $182 = ($181|0)==(0);
   if ($182) {
    label = 20;
    break;
   } else {
    $$07088 = $178;$$07887 = $179;$181 = $180;
   }
  }
  if ((label|0) == 18) {
   // unreachable;
  }
  else if ((label|0) == 20) {
   return;
  }
 }
 }
}
function _Blit1to2($0) {
 $0 = $0|0;
 var $$0$us = 0, $$06280 = 0, $$06280$us = 0, $$07079 = 0, $$07079$us = 0, $$1 = 0, $$163$us = 0, $$171$us = 0, $$2 = 0, $$264 = 0, $$272 = 0, $$3 = 0, $$365 = 0, $$373 = 0, $$4 = 0, $$466 = 0, $$474 = 0, $$5 = 0, $$567 = 0, $$575 = 0;
 var $$6 = 0, $$668 = 0, $$676 = 0, $$7 = 0, $$769 = 0, $$777 = 0, $$8 = 0, $$878 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $trunc = 0, $trunc$clear = 0, $trunc$clear1 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$0>>2]|0;
 $6 = ((($0)) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($0)) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($0)) + 36|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($0)) + 48|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($4) + -1)|0;
 $15 = ($4|0)==(0);
 if ($15) {
  return;
 }
 $16 = (($2) + 7)|0;
 $17 = (($16|0) / 8)&-1;
 $trunc = $2&255;
 $trunc$clear = $trunc & 7;
 $18 = ($trunc$clear<<24>>24)==(0);
 if ($18) {
  $$06280$us = $5;$$07079$us = $9;$72 = $14;
  while(1) {
   $$0$us = $17;$$163$us = $$06280$us;$$171$us = $$07079$us;
   while(1) {
    $19 = ((($$163$us)) + 1|0);
    $20 = HEAP8[$$163$us>>0]|0;
    $21 = $20&255;
    $22 = (($13) + ($21<<1)|0);
    $23 = HEAP16[$22>>1]|0;
    HEAP16[$$171$us>>1] = $23;
    $24 = ((($$171$us)) + 2|0);
    $25 = ((($$163$us)) + 2|0);
    $26 = HEAP8[$19>>0]|0;
    $27 = $26&255;
    $28 = (($13) + ($27<<1)|0);
    $29 = HEAP16[$28>>1]|0;
    HEAP16[$24>>1] = $29;
    $30 = ((($$171$us)) + 4|0);
    $31 = ((($$163$us)) + 3|0);
    $32 = HEAP8[$25>>0]|0;
    $33 = $32&255;
    $34 = (($13) + ($33<<1)|0);
    $35 = HEAP16[$34>>1]|0;
    HEAP16[$30>>1] = $35;
    $36 = ((($$171$us)) + 6|0);
    $37 = ((($$163$us)) + 4|0);
    $38 = HEAP8[$31>>0]|0;
    $39 = $38&255;
    $40 = (($13) + ($39<<1)|0);
    $41 = HEAP16[$40>>1]|0;
    HEAP16[$36>>1] = $41;
    $42 = ((($$171$us)) + 8|0);
    $43 = ((($$163$us)) + 5|0);
    $44 = HEAP8[$37>>0]|0;
    $45 = $44&255;
    $46 = (($13) + ($45<<1)|0);
    $47 = HEAP16[$46>>1]|0;
    HEAP16[$42>>1] = $47;
    $48 = ((($$171$us)) + 10|0);
    $49 = ((($$163$us)) + 6|0);
    $50 = HEAP8[$43>>0]|0;
    $51 = $50&255;
    $52 = (($13) + ($51<<1)|0);
    $53 = HEAP16[$52>>1]|0;
    HEAP16[$48>>1] = $53;
    $54 = ((($$171$us)) + 12|0);
    $55 = ((($$163$us)) + 7|0);
    $56 = HEAP8[$49>>0]|0;
    $57 = $56&255;
    $58 = (($13) + ($57<<1)|0);
    $59 = HEAP16[$58>>1]|0;
    HEAP16[$54>>1] = $59;
    $60 = ((($$171$us)) + 14|0);
    $61 = ((($$163$us)) + 8|0);
    $62 = HEAP8[$55>>0]|0;
    $63 = $62&255;
    $64 = (($13) + ($63<<1)|0);
    $65 = HEAP16[$64>>1]|0;
    HEAP16[$60>>1] = $65;
    $66 = ((($$171$us)) + 16|0);
    $67 = (($$0$us) + -1)|0;
    $68 = ($$0$us|0)>(1);
    if ($68) {
     $$0$us = $67;$$163$us = $61;$$171$us = $66;
    } else {
     break;
    }
   }
   $69 = (($61) + ($7)|0);
   $70 = (($66) + ($11)|0);
   $71 = (($72) + -1)|0;
   $73 = ($72|0)==(0);
   if ($73) {
    break;
   } else {
    $$06280$us = $69;$$07079$us = $70;$72 = $71;
   }
  }
  return;
 } else {
  $$06280 = $5;$$07079 = $9;$127 = $14;
 }
 L11: while(1) {
  $trunc$clear1 = $trunc & 7;
  switch ($trunc$clear1<<24>>24) {
  case 1:  {
   $$7 = $17;$$8 = $$06280;$$878 = $$07079;
   label = 14;
   break;
  }
  case 7:  {
   $$1 = $17;$$264 = $$06280;$$272 = $$07079;
   label = 8;
   break;
  }
  case 6:  {
   $$2 = $17;$$365 = $$06280;$$373 = $$07079;
   label = 9;
   break;
  }
  case 5:  {
   $$3 = $17;$$466 = $$06280;$$474 = $$07079;
   label = 10;
   break;
  }
  case 4:  {
   $$4 = $17;$$567 = $$06280;$$575 = $$07079;
   label = 11;
   break;
  }
  case 3:  {
   $$5 = $17;$$668 = $$06280;$$676 = $$07079;
   label = 12;
   break;
  }
  case 2:  {
   $$6 = $17;$$769 = $$06280;$$777 = $$07079;
   label = 13;
   break;
  }
  default: {
   label = 15;
   break L11;
  }
  }
  while(1) {
   if ((label|0) == 8) {
    label = 0;
    $83 = ((($$264)) + 1|0);
    $84 = HEAP8[$$264>>0]|0;
    $85 = $84&255;
    $86 = (($13) + ($85<<1)|0);
    $87 = HEAP16[$86>>1]|0;
    HEAP16[$$272>>1] = $87;
    $88 = ((($$272)) + 2|0);
    $$2 = $$1;$$365 = $83;$$373 = $88;
    label = 9;
    continue;
   }
   else if ((label|0) == 9) {
    label = 0;
    $89 = ((($$365)) + 1|0);
    $90 = HEAP8[$$365>>0]|0;
    $91 = $90&255;
    $92 = (($13) + ($91<<1)|0);
    $93 = HEAP16[$92>>1]|0;
    HEAP16[$$373>>1] = $93;
    $94 = ((($$373)) + 2|0);
    $$3 = $$2;$$466 = $89;$$474 = $94;
    label = 10;
    continue;
   }
   else if ((label|0) == 10) {
    label = 0;
    $95 = ((($$466)) + 1|0);
    $96 = HEAP8[$$466>>0]|0;
    $97 = $96&255;
    $98 = (($13) + ($97<<1)|0);
    $99 = HEAP16[$98>>1]|0;
    HEAP16[$$474>>1] = $99;
    $100 = ((($$474)) + 2|0);
    $$4 = $$3;$$567 = $95;$$575 = $100;
    label = 11;
    continue;
   }
   else if ((label|0) == 11) {
    label = 0;
    $101 = ((($$567)) + 1|0);
    $102 = HEAP8[$$567>>0]|0;
    $103 = $102&255;
    $104 = (($13) + ($103<<1)|0);
    $105 = HEAP16[$104>>1]|0;
    HEAP16[$$575>>1] = $105;
    $106 = ((($$575)) + 2|0);
    $$5 = $$4;$$668 = $101;$$676 = $106;
    label = 12;
    continue;
   }
   else if ((label|0) == 12) {
    label = 0;
    $107 = ((($$668)) + 1|0);
    $108 = HEAP8[$$668>>0]|0;
    $109 = $108&255;
    $110 = (($13) + ($109<<1)|0);
    $111 = HEAP16[$110>>1]|0;
    HEAP16[$$676>>1] = $111;
    $112 = ((($$676)) + 2|0);
    $$6 = $$5;$$769 = $107;$$777 = $112;
    label = 13;
    continue;
   }
   else if ((label|0) == 13) {
    label = 0;
    $113 = ((($$769)) + 1|0);
    $114 = HEAP8[$$769>>0]|0;
    $115 = $114&255;
    $116 = (($13) + ($115<<1)|0);
    $117 = HEAP16[$116>>1]|0;
    HEAP16[$$777>>1] = $117;
    $118 = ((($$777)) + 2|0);
    $$7 = $$6;$$8 = $113;$$878 = $118;
    label = 14;
    continue;
   }
   else if ((label|0) == 14) {
    label = 0;
    $77 = ((($$8)) + 1|0);
    $119 = HEAP8[$$8>>0]|0;
    $120 = $119&255;
    $121 = (($13) + ($120<<1)|0);
    $122 = HEAP16[$121>>1]|0;
    HEAP16[$$878>>1] = $122;
    $81 = ((($$878)) + 2|0);
    $123 = ($$7|0)>(1);
    if (!($123)) {
     break;
    }
    $74 = (($$7) + -1)|0;
    $75 = ((($$8)) + 2|0);
    $76 = HEAP8[$77>>0]|0;
    $78 = $76&255;
    $79 = (($13) + ($78<<1)|0);
    $80 = HEAP16[$79>>1]|0;
    HEAP16[$81>>1] = $80;
    $82 = ((($$878)) + 4|0);
    $$1 = $74;$$264 = $75;$$272 = $82;
    label = 8;
    continue;
   }
  }
  $124 = (($77) + ($7)|0);
  $125 = (($81) + ($11)|0);
  $126 = (($127) + -1)|0;
  $128 = ($127|0)==(0);
  if ($128) {
   label = 17;
   break;
  } else {
   $$06280 = $124;$$07079 = $125;$127 = $126;
  }
 }
 if ((label|0) == 15) {
  // unreachable;
 }
 else if ((label|0) == 17) {
  return;
 }
}
function _Blit1to3($0) {
 $0 = $0|0;
 var $$0 = 0, $$0128146 = 0, $$0136145 = 0, $$1 = 0, $$1129 = 0, $$1137 = 0, $$2 = 0, $$2130 = 0, $$2138 = 0, $$3 = 0, $$3131 = 0, $$3139 = 0, $$4 = 0, $$4132 = 0, $$4140 = 0, $$5 = 0, $$5133 = 0, $$5141 = 0, $$6 = 0, $$6134 = 0;
 var $$6142 = 0, $$7 = 0, $$7135 = 0, $$7143 = 0, $$8 = 0, $$8144 = 0, $$in = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $trunc = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($0)) + 36|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($0)) + 48|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($4|0)==(0);
 if ($11) {
  return;
 }
 $12 = ((($0)) + 20|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = HEAP32[$0>>2]|0;
 $15 = (($2) + 7)|0;
 $16 = (($15|0) / 8)&-1;
 $trunc = $2&255;
 $$0128146 = $13;$$0136145 = $14;$$in = $4;
 L4: while(1) {
  $17 = (($$in) + -1)|0;
  $trunc$clear = $trunc & 7;
  switch ($trunc$clear<<24>>24) {
  case 0:  {
   $$0 = $16;$$1129 = $$0128146;$$1137 = $$0136145;
   label = 4;
   break;
  }
  case 7:  {
   $$1 = $16;$$2130 = $$0128146;$$2138 = $$0136145;
   label = 5;
   break;
  }
  case 6:  {
   $$2 = $16;$$3131 = $$0128146;$$3139 = $$0136145;
   label = 6;
   break;
  }
  case 5:  {
   $$3 = $16;$$4132 = $$0128146;$$4140 = $$0136145;
   label = 7;
   break;
  }
  case 4:  {
   $$4 = $16;$$5133 = $$0128146;$$5141 = $$0136145;
   label = 8;
   break;
  }
  case 3:  {
   $$5 = $16;$$6134 = $$0128146;$$6142 = $$0136145;
   label = 9;
   break;
  }
  case 2:  {
   $$6 = $16;$$7135 = $$0128146;$$7143 = $$0136145;
   label = 10;
   break;
  }
  case 1:  {
   $$7 = $16;$$8 = $$0128146;$$8144 = $$0136145;
   label = 11;
   break;
  }
  default: {
   label = 12;
   break L4;
  }
  }
  while(1) {
   if ((label|0) == 4) {
    label = 0;
    $18 = HEAP8[$$1137>>0]|0;
    $19 = $18&255;
    $20 = $19 << 2;
    $21 = $20 | 1;
    $22 = (($10) + ($20)|0);
    $23 = HEAP8[$22>>0]|0;
    HEAP8[$$1129>>0] = $23;
    $24 = (($21) + 1)|0;
    $25 = (($10) + ($21)|0);
    $26 = HEAP8[$25>>0]|0;
    $27 = ((($$1129)) + 1|0);
    HEAP8[$27>>0] = $26;
    $28 = (($10) + ($24)|0);
    $29 = HEAP8[$28>>0]|0;
    $30 = ((($$1129)) + 2|0);
    HEAP8[$30>>0] = $29;
    $31 = ((($$1137)) + 1|0);
    $32 = ((($$1129)) + 3|0);
    $$1 = $$0;$$2130 = $32;$$2138 = $31;
    label = 5;
    continue;
   }
   else if ((label|0) == 5) {
    label = 0;
    $33 = HEAP8[$$2138>>0]|0;
    $34 = $33&255;
    $35 = $34 << 2;
    $36 = $35 | 1;
    $37 = (($10) + ($35)|0);
    $38 = HEAP8[$37>>0]|0;
    HEAP8[$$2130>>0] = $38;
    $39 = (($36) + 1)|0;
    $40 = (($10) + ($36)|0);
    $41 = HEAP8[$40>>0]|0;
    $42 = ((($$2130)) + 1|0);
    HEAP8[$42>>0] = $41;
    $43 = (($10) + ($39)|0);
    $44 = HEAP8[$43>>0]|0;
    $45 = ((($$2130)) + 2|0);
    HEAP8[$45>>0] = $44;
    $46 = ((($$2138)) + 1|0);
    $47 = ((($$2130)) + 3|0);
    $$2 = $$1;$$3131 = $47;$$3139 = $46;
    label = 6;
    continue;
   }
   else if ((label|0) == 6) {
    label = 0;
    $48 = HEAP8[$$3139>>0]|0;
    $49 = $48&255;
    $50 = $49 << 2;
    $51 = $50 | 1;
    $52 = (($10) + ($50)|0);
    $53 = HEAP8[$52>>0]|0;
    HEAP8[$$3131>>0] = $53;
    $54 = (($51) + 1)|0;
    $55 = (($10) + ($51)|0);
    $56 = HEAP8[$55>>0]|0;
    $57 = ((($$3131)) + 1|0);
    HEAP8[$57>>0] = $56;
    $58 = (($10) + ($54)|0);
    $59 = HEAP8[$58>>0]|0;
    $60 = ((($$3131)) + 2|0);
    HEAP8[$60>>0] = $59;
    $61 = ((($$3139)) + 1|0);
    $62 = ((($$3131)) + 3|0);
    $$3 = $$2;$$4132 = $62;$$4140 = $61;
    label = 7;
    continue;
   }
   else if ((label|0) == 7) {
    label = 0;
    $63 = HEAP8[$$4140>>0]|0;
    $64 = $63&255;
    $65 = $64 << 2;
    $66 = $65 | 1;
    $67 = (($10) + ($65)|0);
    $68 = HEAP8[$67>>0]|0;
    HEAP8[$$4132>>0] = $68;
    $69 = (($66) + 1)|0;
    $70 = (($10) + ($66)|0);
    $71 = HEAP8[$70>>0]|0;
    $72 = ((($$4132)) + 1|0);
    HEAP8[$72>>0] = $71;
    $73 = (($10) + ($69)|0);
    $74 = HEAP8[$73>>0]|0;
    $75 = ((($$4132)) + 2|0);
    HEAP8[$75>>0] = $74;
    $76 = ((($$4140)) + 1|0);
    $77 = ((($$4132)) + 3|0);
    $$4 = $$3;$$5133 = $77;$$5141 = $76;
    label = 8;
    continue;
   }
   else if ((label|0) == 8) {
    label = 0;
    $78 = HEAP8[$$5141>>0]|0;
    $79 = $78&255;
    $80 = $79 << 2;
    $81 = $80 | 1;
    $82 = (($10) + ($80)|0);
    $83 = HEAP8[$82>>0]|0;
    HEAP8[$$5133>>0] = $83;
    $84 = (($81) + 1)|0;
    $85 = (($10) + ($81)|0);
    $86 = HEAP8[$85>>0]|0;
    $87 = ((($$5133)) + 1|0);
    HEAP8[$87>>0] = $86;
    $88 = (($10) + ($84)|0);
    $89 = HEAP8[$88>>0]|0;
    $90 = ((($$5133)) + 2|0);
    HEAP8[$90>>0] = $89;
    $91 = ((($$5141)) + 1|0);
    $92 = ((($$5133)) + 3|0);
    $$5 = $$4;$$6134 = $92;$$6142 = $91;
    label = 9;
    continue;
   }
   else if ((label|0) == 9) {
    label = 0;
    $93 = HEAP8[$$6142>>0]|0;
    $94 = $93&255;
    $95 = $94 << 2;
    $96 = $95 | 1;
    $97 = (($10) + ($95)|0);
    $98 = HEAP8[$97>>0]|0;
    HEAP8[$$6134>>0] = $98;
    $99 = (($96) + 1)|0;
    $100 = (($10) + ($96)|0);
    $101 = HEAP8[$100>>0]|0;
    $102 = ((($$6134)) + 1|0);
    HEAP8[$102>>0] = $101;
    $103 = (($10) + ($99)|0);
    $104 = HEAP8[$103>>0]|0;
    $105 = ((($$6134)) + 2|0);
    HEAP8[$105>>0] = $104;
    $106 = ((($$6142)) + 1|0);
    $107 = ((($$6134)) + 3|0);
    $$6 = $$5;$$7135 = $107;$$7143 = $106;
    label = 10;
    continue;
   }
   else if ((label|0) == 10) {
    label = 0;
    $108 = HEAP8[$$7143>>0]|0;
    $109 = $108&255;
    $110 = $109 << 2;
    $111 = $110 | 1;
    $112 = (($10) + ($110)|0);
    $113 = HEAP8[$112>>0]|0;
    HEAP8[$$7135>>0] = $113;
    $114 = (($111) + 1)|0;
    $115 = (($10) + ($111)|0);
    $116 = HEAP8[$115>>0]|0;
    $117 = ((($$7135)) + 1|0);
    HEAP8[$117>>0] = $116;
    $118 = (($10) + ($114)|0);
    $119 = HEAP8[$118>>0]|0;
    $120 = ((($$7135)) + 2|0);
    HEAP8[$120>>0] = $119;
    $121 = ((($$7143)) + 1|0);
    $122 = ((($$7135)) + 3|0);
    $$7 = $$6;$$8 = $122;$$8144 = $121;
    label = 11;
    continue;
   }
   else if ((label|0) == 11) {
    label = 0;
    $123 = HEAP8[$$8144>>0]|0;
    $124 = $123&255;
    $125 = $124 << 2;
    $126 = $125 | 1;
    $127 = (($10) + ($125)|0);
    $128 = HEAP8[$127>>0]|0;
    HEAP8[$$8>>0] = $128;
    $129 = (($126) + 1)|0;
    $130 = (($10) + ($126)|0);
    $131 = HEAP8[$130>>0]|0;
    $132 = ((($$8)) + 1|0);
    HEAP8[$132>>0] = $131;
    $133 = (($10) + ($129)|0);
    $134 = HEAP8[$133>>0]|0;
    $135 = ((($$8)) + 2|0);
    HEAP8[$135>>0] = $134;
    $136 = ((($$8144)) + 1|0);
    $137 = ((($$8)) + 3|0);
    $138 = (($$7) + -1)|0;
    $139 = ($$7|0)>(1);
    if ($139) {
     $$0 = $138;$$1129 = $137;$$1137 = $136;
     label = 4;
     continue;
    } else {
     break;
    }
   }
  }
  $140 = (($136) + ($6)|0);
  $141 = (($137) + ($8)|0);
  $142 = ($17|0)==(0);
  if ($142) {
   label = 14;
   break;
  } else {
   $$0128146 = $141;$$0136145 = $140;$$in = $17;
  }
 }
 if ((label|0) == 12) {
  // unreachable;
 }
 else if ((label|0) == 14) {
  return;
 }
}
function _Blit1to4($0) {
 $0 = $0|0;
 var $$0$us = 0, $$05472 = 0, $$05472$us = 0, $$06271 = 0, $$06271$us = 0, $$1 = 0, $$155$us = 0, $$163$us = 0, $$2 = 0, $$256 = 0, $$264 = 0, $$3 = 0, $$357 = 0, $$365 = 0, $$4 = 0, $$458 = 0, $$466 = 0, $$5 = 0, $$559 = 0, $$567 = 0;
 var $$6 = 0, $$660 = 0, $$668 = 0, $$7 = 0, $$761 = 0, $$769 = 0, $$8 = 0, $$870 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $trunc = 0, $trunc$clear = 0, $trunc$clear1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$0>>2]|0;
 $6 = ((($0)) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($0)) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($0)) + 36|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($11|0) / 4)&-1;
 $13 = ((($0)) + 48|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($4) + -1)|0;
 $16 = ($4|0)==(0);
 if ($16) {
  return;
 }
 $17 = (($2) + 7)|0;
 $18 = (($17|0) / 8)&-1;
 $trunc = $2&255;
 $trunc$clear = $trunc & 7;
 $19 = ($trunc$clear<<24>>24)==(0);
 if ($19) {
  $$05472$us = $5;$$06271$us = $9;$73 = $15;
  while(1) {
   $$0$us = $18;$$155$us = $$05472$us;$$163$us = $$06271$us;
   while(1) {
    $20 = ((($$155$us)) + 1|0);
    $21 = HEAP8[$$155$us>>0]|0;
    $22 = $21&255;
    $23 = (($14) + ($22<<2)|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = ((($$163$us)) + 4|0);
    HEAP32[$$163$us>>2] = $24;
    $26 = ((($$155$us)) + 2|0);
    $27 = HEAP8[$20>>0]|0;
    $28 = $27&255;
    $29 = (($14) + ($28<<2)|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = ((($$163$us)) + 8|0);
    HEAP32[$25>>2] = $30;
    $32 = ((($$155$us)) + 3|0);
    $33 = HEAP8[$26>>0]|0;
    $34 = $33&255;
    $35 = (($14) + ($34<<2)|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = ((($$163$us)) + 12|0);
    HEAP32[$31>>2] = $36;
    $38 = ((($$155$us)) + 4|0);
    $39 = HEAP8[$32>>0]|0;
    $40 = $39&255;
    $41 = (($14) + ($40<<2)|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = ((($$163$us)) + 16|0);
    HEAP32[$37>>2] = $42;
    $44 = ((($$155$us)) + 5|0);
    $45 = HEAP8[$38>>0]|0;
    $46 = $45&255;
    $47 = (($14) + ($46<<2)|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = ((($$163$us)) + 20|0);
    HEAP32[$43>>2] = $48;
    $50 = ((($$155$us)) + 6|0);
    $51 = HEAP8[$44>>0]|0;
    $52 = $51&255;
    $53 = (($14) + ($52<<2)|0);
    $54 = HEAP32[$53>>2]|0;
    $55 = ((($$163$us)) + 24|0);
    HEAP32[$49>>2] = $54;
    $56 = ((($$155$us)) + 7|0);
    $57 = HEAP8[$50>>0]|0;
    $58 = $57&255;
    $59 = (($14) + ($58<<2)|0);
    $60 = HEAP32[$59>>2]|0;
    $61 = ((($$163$us)) + 28|0);
    HEAP32[$55>>2] = $60;
    $62 = ((($$155$us)) + 8|0);
    $63 = HEAP8[$56>>0]|0;
    $64 = $63&255;
    $65 = (($14) + ($64<<2)|0);
    $66 = HEAP32[$65>>2]|0;
    $67 = ((($$163$us)) + 32|0);
    HEAP32[$61>>2] = $66;
    $68 = (($$0$us) + -1)|0;
    $69 = ($$0$us|0)>(1);
    if ($69) {
     $$0$us = $68;$$155$us = $62;$$163$us = $67;
    } else {
     break;
    }
   }
   $70 = (($62) + ($7)|0);
   $71 = (($67) + ($12<<2)|0);
   $72 = (($73) + -1)|0;
   $74 = ($73|0)==(0);
   if ($74) {
    break;
   } else {
    $$05472$us = $70;$$06271$us = $71;$73 = $72;
   }
  }
  return;
 } else {
  $$05472 = $5;$$06271 = $9;$128 = $15;
 }
 L11: while(1) {
  $trunc$clear1 = $trunc & 7;
  switch ($trunc$clear1<<24>>24) {
  case 1:  {
   $$7 = $18;$$8 = $$05472;$$870 = $$06271;
   label = 14;
   break;
  }
  case 7:  {
   $$1 = $18;$$256 = $$05472;$$264 = $$06271;
   label = 8;
   break;
  }
  case 6:  {
   $$2 = $18;$$357 = $$05472;$$365 = $$06271;
   label = 9;
   break;
  }
  case 5:  {
   $$3 = $18;$$458 = $$05472;$$466 = $$06271;
   label = 10;
   break;
  }
  case 4:  {
   $$4 = $18;$$559 = $$05472;$$567 = $$06271;
   label = 11;
   break;
  }
  case 3:  {
   $$5 = $18;$$660 = $$05472;$$668 = $$06271;
   label = 12;
   break;
  }
  case 2:  {
   $$6 = $18;$$761 = $$05472;$$769 = $$06271;
   label = 13;
   break;
  }
  default: {
   label = 15;
   break L11;
  }
  }
  while(1) {
   if ((label|0) == 8) {
    label = 0;
    $84 = ((($$256)) + 1|0);
    $85 = HEAP8[$$256>>0]|0;
    $86 = $85&255;
    $87 = (($14) + ($86<<2)|0);
    $88 = HEAP32[$87>>2]|0;
    $89 = ((($$264)) + 4|0);
    HEAP32[$$264>>2] = $88;
    $$2 = $$1;$$357 = $84;$$365 = $89;
    label = 9;
    continue;
   }
   else if ((label|0) == 9) {
    label = 0;
    $90 = ((($$357)) + 1|0);
    $91 = HEAP8[$$357>>0]|0;
    $92 = $91&255;
    $93 = (($14) + ($92<<2)|0);
    $94 = HEAP32[$93>>2]|0;
    $95 = ((($$365)) + 4|0);
    HEAP32[$$365>>2] = $94;
    $$3 = $$2;$$458 = $90;$$466 = $95;
    label = 10;
    continue;
   }
   else if ((label|0) == 10) {
    label = 0;
    $96 = ((($$458)) + 1|0);
    $97 = HEAP8[$$458>>0]|0;
    $98 = $97&255;
    $99 = (($14) + ($98<<2)|0);
    $100 = HEAP32[$99>>2]|0;
    $101 = ((($$466)) + 4|0);
    HEAP32[$$466>>2] = $100;
    $$4 = $$3;$$559 = $96;$$567 = $101;
    label = 11;
    continue;
   }
   else if ((label|0) == 11) {
    label = 0;
    $102 = ((($$559)) + 1|0);
    $103 = HEAP8[$$559>>0]|0;
    $104 = $103&255;
    $105 = (($14) + ($104<<2)|0);
    $106 = HEAP32[$105>>2]|0;
    $107 = ((($$567)) + 4|0);
    HEAP32[$$567>>2] = $106;
    $$5 = $$4;$$660 = $102;$$668 = $107;
    label = 12;
    continue;
   }
   else if ((label|0) == 12) {
    label = 0;
    $108 = ((($$660)) + 1|0);
    $109 = HEAP8[$$660>>0]|0;
    $110 = $109&255;
    $111 = (($14) + ($110<<2)|0);
    $112 = HEAP32[$111>>2]|0;
    $113 = ((($$668)) + 4|0);
    HEAP32[$$668>>2] = $112;
    $$6 = $$5;$$761 = $108;$$769 = $113;
    label = 13;
    continue;
   }
   else if ((label|0) == 13) {
    label = 0;
    $114 = ((($$761)) + 1|0);
    $115 = HEAP8[$$761>>0]|0;
    $116 = $115&255;
    $117 = (($14) + ($116<<2)|0);
    $118 = HEAP32[$117>>2]|0;
    $119 = ((($$769)) + 4|0);
    HEAP32[$$769>>2] = $118;
    $$7 = $$6;$$8 = $114;$$870 = $119;
    label = 14;
    continue;
   }
   else if ((label|0) == 14) {
    label = 0;
    $78 = ((($$8)) + 1|0);
    $120 = HEAP8[$$8>>0]|0;
    $121 = $120&255;
    $122 = (($14) + ($121<<2)|0);
    $123 = HEAP32[$122>>2]|0;
    $83 = ((($$870)) + 4|0);
    HEAP32[$$870>>2] = $123;
    $124 = ($$7|0)>(1);
    if (!($124)) {
     break;
    }
    $75 = (($$7) + -1)|0;
    $76 = ((($$8)) + 2|0);
    $77 = HEAP8[$78>>0]|0;
    $79 = $77&255;
    $80 = (($14) + ($79<<2)|0);
    $81 = HEAP32[$80>>2]|0;
    $82 = ((($$870)) + 8|0);
    HEAP32[$83>>2] = $81;
    $$1 = $75;$$256 = $76;$$264 = $82;
    label = 8;
    continue;
   }
  }
  $125 = (($78) + ($7)|0);
  $126 = (($83) + ($12<<2)|0);
  $127 = (($128) + -1)|0;
  $129 = ($128|0)==(0);
  if ($129) {
   label = 17;
   break;
  } else {
   $$05472 = $125;$$06271 = $126;$128 = $127;
  }
 }
 if ((label|0) == 15) {
  // unreachable;
 }
 else if ((label|0) == 17) {
  return;
 }
}
function _BlitBtoNAlpha($0) {
 $0 = $0|0;
 var $$0199221 = 0, $$0200220 = 0, $$0202216 = 0, $$0204215 = 0, $$0205 = 0, $$0205$shrunk = 0, $$0206 = 0, $$0206$shrunk = 0, $$0207 = 0, $$0207$shrunk = 0, $$0208 = 0, $$0208$shrunk = 0, $$1$lcssa = 0, $$1201$lcssa = 0, $$1201217 = 0, $$1203 = 0, $$1218 = 0, $$2 = 0, $$in = 0, $$neg = 0;
 var $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0;
 var $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0;
 var $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0;
 var $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0;
 var $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0;
 var $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0;
 var $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0;
 var $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0;
 var $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0;
 var $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0;
 var $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0;
 var $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0;
 var $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $div = 0, $div209 = 0, $div210 = 0, $div211 = 0, $div212 = 0, $div213 = 0, $exitcond = 0, $scevgep = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($0)) + 36|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($0)) + 40|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ((($10)) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ((($12)) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ((($0)) + 44|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ((($0)) + 63|0);
 $18 = HEAP8[$17>>0]|0;
 $19 = $18&255;
 $20 = ((($16)) + 9|0);
 $21 = HEAP8[$20>>0]|0;
 $22 = $21&255;
 $23 = (($2) + 7)|0;
 $$neg = (($23|0) / -8)&-1;
 $24 = (($$neg) + ($2))|0;
 $25 = (($24) + ($6))|0;
 $26 = ($4|0)==(0);
 if ($26) {
  return;
 }
 $27 = ((($0)) + 20|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = HEAP32[$0>>2]|0;
 $30 = ($2|0)>(0);
 $31 = ((($16)) + 28|0);
 $32 = ((($16)) + 32|0);
 $33 = ((($16)) + 29|0);
 $34 = ((($16)) + 33|0);
 $35 = ((($16)) + 30|0);
 $36 = ((($16)) + 34|0);
 $37 = ((($16)) + 31|0);
 $38 = ((($16)) + 35|0);
 $39 = ((($16)) + 12|0);
 $40 = ((($16)) + 16|0);
 $41 = ((($16)) + 20|0);
 $42 = ((($16)) + 24|0);
 $43 = Math_imul($2, $22)|0;
 $$0199221 = $29;$$0200220 = $28;$$in = $4;
 while(1) {
  $44 = (($$in) + -1)|0;
  if ($30) {
   $$0202216 = 0;$$0204215 = 0;$$1201217 = $$0200220;$$1218 = $$0199221;
   while(1) {
    $45 = $$0204215 & 7;
    $46 = ($45|0)==(0);
    if ($46) {
     $47 = ((($$1218)) + 1|0);
     $48 = HEAP8[$$1218>>0]|0;
     $$1203 = $48;$$2 = $47;
    } else {
     $$1203 = $$0202216;$$2 = $$1218;
    }
    $49 = $$1203&255;
    $50 = ($$1203&255) >>> 7;
    $51 = $50&255;
    $52 = (($14) + ($51<<2)|0);
    $53 = HEAP8[$52>>0]|0;
    $54 = $53&255;
    $55 = (((($14) + ($51<<2)|0)) + 1|0);
    $56 = HEAP8[$55>>0]|0;
    $57 = $56&255;
    $58 = (((($14) + ($51<<2)|0)) + 2|0);
    $59 = HEAP8[$58>>0]|0;
    $60 = $59&255;
    switch ($21<<24>>24) {
    case 1:  {
     $61 = HEAP8[$$1201217>>0]|0;
     $62 = $61&255;
     $63 = HEAP8[$31>>0]|0;
     $64 = $63&255;
     $65 = (79212 + ($64<<2)|0);
     $66 = HEAP32[$65>>2]|0;
     $67 = HEAP32[$39>>2]|0;
     $68 = $67 & $62;
     $69 = HEAP8[$32>>0]|0;
     $70 = $69&255;
     $71 = $68 >>> $70;
     $72 = (($66) + ($71)|0);
     $73 = HEAP8[$72>>0]|0;
     $74 = HEAP8[$33>>0]|0;
     $75 = $74&255;
     $76 = (79212 + ($75<<2)|0);
     $77 = HEAP32[$76>>2]|0;
     $78 = HEAP32[$40>>2]|0;
     $79 = $78 & $62;
     $80 = HEAP8[$34>>0]|0;
     $81 = $80&255;
     $82 = $79 >>> $81;
     $83 = (($77) + ($82)|0);
     $84 = HEAP8[$83>>0]|0;
     $85 = HEAP8[$35>>0]|0;
     $86 = $85&255;
     $87 = (79212 + ($86<<2)|0);
     $88 = HEAP32[$87>>2]|0;
     $89 = HEAP32[$41>>2]|0;
     $90 = $89 & $62;
     $91 = HEAP8[$36>>0]|0;
     $92 = $91&255;
     $93 = $90 >>> $92;
     $94 = (($88) + ($93)|0);
     $95 = HEAP8[$94>>0]|0;
     $96 = HEAP8[$37>>0]|0;
     $97 = $96&255;
     $98 = (79212 + ($97<<2)|0);
     $99 = HEAP32[$98>>2]|0;
     $100 = HEAP32[$42>>2]|0;
     $101 = $100 & $62;
     $102 = HEAP8[$38>>0]|0;
     $103 = $102&255;
     $104 = $101 >>> $103;
     $105 = (($99) + ($104)|0);
     $106 = HEAP8[$105>>0]|0;
     $$0205$shrunk = $106;$$0206$shrunk = $95;$$0207$shrunk = $84;$$0208$shrunk = $73;
     break;
    }
    case 2:  {
     $107 = HEAP16[$$1201217>>1]|0;
     $108 = $107&65535;
     $109 = HEAP8[$31>>0]|0;
     $110 = $109&255;
     $111 = (79212 + ($110<<2)|0);
     $112 = HEAP32[$111>>2]|0;
     $113 = HEAP32[$39>>2]|0;
     $114 = $113 & $108;
     $115 = HEAP8[$32>>0]|0;
     $116 = $115&255;
     $117 = $114 >>> $116;
     $118 = (($112) + ($117)|0);
     $119 = HEAP8[$118>>0]|0;
     $120 = HEAP8[$33>>0]|0;
     $121 = $120&255;
     $122 = (79212 + ($121<<2)|0);
     $123 = HEAP32[$122>>2]|0;
     $124 = HEAP32[$40>>2]|0;
     $125 = $124 & $108;
     $126 = HEAP8[$34>>0]|0;
     $127 = $126&255;
     $128 = $125 >>> $127;
     $129 = (($123) + ($128)|0);
     $130 = HEAP8[$129>>0]|0;
     $131 = HEAP8[$35>>0]|0;
     $132 = $131&255;
     $133 = (79212 + ($132<<2)|0);
     $134 = HEAP32[$133>>2]|0;
     $135 = HEAP32[$41>>2]|0;
     $136 = $135 & $108;
     $137 = HEAP8[$36>>0]|0;
     $138 = $137&255;
     $139 = $136 >>> $138;
     $140 = (($134) + ($139)|0);
     $141 = HEAP8[$140>>0]|0;
     $142 = HEAP8[$37>>0]|0;
     $143 = $142&255;
     $144 = (79212 + ($143<<2)|0);
     $145 = HEAP32[$144>>2]|0;
     $146 = HEAP32[$42>>2]|0;
     $147 = $146 & $108;
     $148 = HEAP8[$38>>0]|0;
     $149 = $148&255;
     $150 = $147 >>> $149;
     $151 = (($145) + ($150)|0);
     $152 = HEAP8[$151>>0]|0;
     $$0205$shrunk = $152;$$0206$shrunk = $141;$$0207$shrunk = $130;$$0208$shrunk = $119;
     break;
    }
    case 3:  {
     $153 = HEAP8[$32>>0]|0;
     $div211 = ($153&255) >>> 3;
     $154 = $div211&255;
     $155 = (($$1201217) + ($154)|0);
     $156 = HEAP8[$155>>0]|0;
     $157 = HEAP8[$34>>0]|0;
     $div212 = ($157&255) >>> 3;
     $158 = $div212&255;
     $159 = (($$1201217) + ($158)|0);
     $160 = HEAP8[$159>>0]|0;
     $161 = HEAP8[$36>>0]|0;
     $div213 = ($161&255) >>> 3;
     $162 = $div213&255;
     $163 = (($$1201217) + ($162)|0);
     $164 = HEAP8[$163>>0]|0;
     $$0205$shrunk = -1;$$0206$shrunk = $164;$$0207$shrunk = $160;$$0208$shrunk = $156;
     break;
    }
    case 4:  {
     $165 = HEAP32[$$1201217>>2]|0;
     $166 = HEAP8[$31>>0]|0;
     $167 = $166&255;
     $168 = (79212 + ($167<<2)|0);
     $169 = HEAP32[$168>>2]|0;
     $170 = HEAP32[$39>>2]|0;
     $171 = $170 & $165;
     $172 = HEAP8[$32>>0]|0;
     $173 = $172&255;
     $174 = $171 >>> $173;
     $175 = (($169) + ($174)|0);
     $176 = HEAP8[$175>>0]|0;
     $177 = HEAP8[$33>>0]|0;
     $178 = $177&255;
     $179 = (79212 + ($178<<2)|0);
     $180 = HEAP32[$179>>2]|0;
     $181 = HEAP32[$40>>2]|0;
     $182 = $181 & $165;
     $183 = HEAP8[$34>>0]|0;
     $184 = $183&255;
     $185 = $182 >>> $184;
     $186 = (($180) + ($185)|0);
     $187 = HEAP8[$186>>0]|0;
     $188 = HEAP8[$35>>0]|0;
     $189 = $188&255;
     $190 = (79212 + ($189<<2)|0);
     $191 = HEAP32[$190>>2]|0;
     $192 = HEAP32[$41>>2]|0;
     $193 = $192 & $165;
     $194 = HEAP8[$36>>0]|0;
     $195 = $194&255;
     $196 = $193 >>> $195;
     $197 = (($191) + ($196)|0);
     $198 = HEAP8[$197>>0]|0;
     $199 = HEAP8[$37>>0]|0;
     $200 = $199&255;
     $201 = (79212 + ($200<<2)|0);
     $202 = HEAP32[$201>>2]|0;
     $203 = HEAP32[$42>>2]|0;
     $204 = $203 & $165;
     $205 = HEAP8[$38>>0]|0;
     $206 = $205&255;
     $207 = $204 >>> $206;
     $208 = (($202) + ($207)|0);
     $209 = HEAP8[$208>>0]|0;
     $$0205$shrunk = $209;$$0206$shrunk = $198;$$0207$shrunk = $187;$$0208$shrunk = $176;
     break;
    }
    default: {
     $$0205$shrunk = 0;$$0206$shrunk = 0;$$0207$shrunk = 0;$$0208$shrunk = 0;
    }
    }
    $$0205 = $$0205$shrunk&255;
    $$0206 = $$0206$shrunk&255;
    $$0207 = $$0207$shrunk&255;
    $$0208 = $$0208$shrunk&255;
    $210 = (($54) - ($$0208))|0;
    $211 = Math_imul($210, $19)|0;
    $212 = (($211>>>0) / 255)&-1;
    $213 = (($212) + ($$0208))|0;
    $214 = (($57) - ($$0207))|0;
    $215 = Math_imul($214, $19)|0;
    $216 = (($215>>>0) / 255)&-1;
    $217 = (($216) + ($$0207))|0;
    $218 = (($60) - ($$0206))|0;
    $219 = Math_imul($218, $19)|0;
    $220 = (($219>>>0) / 255)&-1;
    $221 = (($220) + ($$0206))|0;
    $222 = (($$0205) + ($19))|0;
    $223 = Math_imul($$0205, $19)|0;
    $224 = (($223>>>0) / 255)&-1;
    $225 = (($222) - ($224))|0;
    switch ($21<<24>>24) {
    case 1:  {
     $226 = HEAP8[$31>>0]|0;
     $227 = $226&255;
     $228 = $213 >>> $227;
     $229 = HEAP8[$32>>0]|0;
     $230 = $229&255;
     $231 = $228 << $230;
     $232 = HEAP8[$33>>0]|0;
     $233 = $232&255;
     $234 = $217 >>> $233;
     $235 = HEAP8[$34>>0]|0;
     $236 = $235&255;
     $237 = $234 << $236;
     $238 = $237 | $231;
     $239 = HEAP8[$35>>0]|0;
     $240 = $239&255;
     $241 = $221 >>> $240;
     $242 = HEAP8[$36>>0]|0;
     $243 = $242&255;
     $244 = $241 << $243;
     $245 = $238 | $244;
     $246 = HEAP8[$37>>0]|0;
     $247 = $246&255;
     $248 = $225 >>> $247;
     $249 = HEAP8[$38>>0]|0;
     $250 = $249&255;
     $251 = $248 << $250;
     $252 = $245 | $251;
     $253 = $252&255;
     HEAP8[$$1201217>>0] = $253;
     break;
    }
    case 2:  {
     $254 = HEAP8[$31>>0]|0;
     $255 = $254&255;
     $256 = $213 >>> $255;
     $257 = HEAP8[$32>>0]|0;
     $258 = $257&255;
     $259 = $256 << $258;
     $260 = HEAP8[$33>>0]|0;
     $261 = $260&255;
     $262 = $217 >>> $261;
     $263 = HEAP8[$34>>0]|0;
     $264 = $263&255;
     $265 = $262 << $264;
     $266 = $265 | $259;
     $267 = HEAP8[$35>>0]|0;
     $268 = $267&255;
     $269 = $221 >>> $268;
     $270 = HEAP8[$36>>0]|0;
     $271 = $270&255;
     $272 = $269 << $271;
     $273 = $266 | $272;
     $274 = HEAP8[$37>>0]|0;
     $275 = $274&255;
     $276 = $225 >>> $275;
     $277 = HEAP8[$38>>0]|0;
     $278 = $277&255;
     $279 = $276 << $278;
     $280 = $273 | $279;
     $281 = $280&65535;
     HEAP16[$$1201217>>1] = $281;
     break;
    }
    case 3:  {
     $282 = $213&255;
     $283 = HEAP8[$32>>0]|0;
     $div = ($283&255) >>> 3;
     $284 = $div&255;
     $285 = (($$1201217) + ($284)|0);
     HEAP8[$285>>0] = $282;
     $286 = $217&255;
     $287 = HEAP8[$34>>0]|0;
     $div209 = ($287&255) >>> 3;
     $288 = $div209&255;
     $289 = (($$1201217) + ($288)|0);
     HEAP8[$289>>0] = $286;
     $290 = $221&255;
     $291 = HEAP8[$36>>0]|0;
     $div210 = ($291&255) >>> 3;
     $292 = $div210&255;
     $293 = (($$1201217) + ($292)|0);
     HEAP8[$293>>0] = $290;
     break;
    }
    case 4:  {
     $294 = HEAP8[$31>>0]|0;
     $295 = $294&255;
     $296 = $213 >>> $295;
     $297 = HEAP8[$32>>0]|0;
     $298 = $297&255;
     $299 = $296 << $298;
     $300 = HEAP8[$33>>0]|0;
     $301 = $300&255;
     $302 = $217 >>> $301;
     $303 = HEAP8[$34>>0]|0;
     $304 = $303&255;
     $305 = $302 << $304;
     $306 = $305 | $299;
     $307 = HEAP8[$35>>0]|0;
     $308 = $307&255;
     $309 = $221 >>> $308;
     $310 = HEAP8[$36>>0]|0;
     $311 = $310&255;
     $312 = $309 << $311;
     $313 = $306 | $312;
     $314 = HEAP8[$37>>0]|0;
     $315 = $314&255;
     $316 = $225 >>> $315;
     $317 = HEAP8[$38>>0]|0;
     $318 = $317&255;
     $319 = $316 << $318;
     $320 = $313 | $319;
     HEAP32[$$1201217>>2] = $320;
     break;
    }
    default: {
    }
    }
    $321 = $49 << 1;
    $322 = $321&255;
    $323 = (($$1201217) + ($22)|0);
    $324 = (($$0204215) + 1)|0;
    $exitcond = ($324|0)==($2|0);
    if ($exitcond) {
     break;
    } else {
     $$0202216 = $322;$$0204215 = $324;$$1201217 = $323;$$1218 = $$2;
    }
   }
   $scevgep = (($$0200220) + ($43)|0);
   $$1$lcssa = $$2;$$1201$lcssa = $scevgep;
  } else {
   $$1$lcssa = $$0199221;$$1201$lcssa = $$0200220;
  }
  $325 = (($$1$lcssa) + ($25)|0);
  $326 = (($$1201$lcssa) + ($8)|0);
  $327 = ($44|0)==(0);
  if ($327) {
   break;
  } else {
   $$0199221 = $325;$$0200220 = $326;$$in = $44;
  }
 }
 return;
}
function _BlitBtoNAlphaKey($0) {
 $0 = $0|0;
 var $$0207230 = 0, $$0208229 = 0, $$0210224 = 0, $$0212223 = 0, $$0213 = 0, $$0213$shrunk = 0, $$0214 = 0, $$0214$shrunk = 0, $$0215 = 0, $$0215$shrunk = 0, $$0216 = 0, $$0216$shrunk = 0, $$1$lcssa = 0, $$1209$lcssa = 0, $$1209225 = 0, $$1211 = 0, $$1227 = 0, $$2 = 0, $$in = 0, $$neg = 0;
 var $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0;
 var $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0;
 var $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0;
 var $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0;
 var $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0;
 var $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0;
 var $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0;
 var $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0;
 var $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0;
 var $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0;
 var $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0;
 var $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0;
 var $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $div = 0, $div217 = 0, $div218 = 0, $div219 = 0, $div220 = 0, $div221 = 0, $exitcond = 0, $scevgep = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($0)) + 36|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($0)) + 40|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ((($0)) + 44|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ((($10)) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ((($14)) + 4|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ((($0)) + 63|0);
 $18 = HEAP8[$17>>0]|0;
 $19 = $18&255;
 $20 = ((($0)) + 56|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ((($12)) + 9|0);
 $23 = HEAP8[$22>>0]|0;
 $24 = $23&255;
 $25 = (($2) + 7)|0;
 $$neg = (($25|0) / -8)&-1;
 $26 = (($$neg) + ($2))|0;
 $27 = (($26) + ($6))|0;
 $28 = ($4|0)==(0);
 if ($28) {
  return;
 }
 $29 = ((($0)) + 20|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = HEAP32[$0>>2]|0;
 $32 = ($2|0)>(0);
 $33 = ((($12)) + 28|0);
 $34 = ((($12)) + 32|0);
 $35 = ((($12)) + 29|0);
 $36 = ((($12)) + 33|0);
 $37 = ((($12)) + 30|0);
 $38 = ((($12)) + 34|0);
 $39 = ((($12)) + 31|0);
 $40 = ((($12)) + 35|0);
 $41 = ((($12)) + 12|0);
 $42 = ((($12)) + 16|0);
 $43 = ((($12)) + 20|0);
 $44 = ((($12)) + 24|0);
 $45 = Math_imul($2, $24)|0;
 $$0207230 = $31;$$0208229 = $30;$$in = $4;
 while(1) {
  $46 = (($$in) + -1)|0;
  if ($32) {
   $$0210224 = 0;$$0212223 = 0;$$1209225 = $$0208229;$$1227 = $$0207230;
   while(1) {
    $47 = $$0212223 & 7;
    $48 = ($47|0)==(0);
    if ($48) {
     $49 = ((($$1227)) + 1|0);
     $50 = HEAP8[$$1227>>0]|0;
     $$1211 = $50;$$2 = $49;
    } else {
     $$1211 = $$0210224;$$2 = $$1227;
    }
    $51 = $$1211&255;
    $52 = ($$1211&255) >>> 7;
    $53 = $52&255;
    $54 = ($53|0)==($21|0);
    L12: do {
     if (!($54)) {
      $55 = (($16) + ($53<<2)|0);
      $56 = HEAP8[$55>>0]|0;
      $57 = $56&255;
      $58 = (((($16) + ($53<<2)|0)) + 1|0);
      $59 = HEAP8[$58>>0]|0;
      $60 = $59&255;
      $61 = (((($16) + ($53<<2)|0)) + 2|0);
      $62 = HEAP8[$61>>0]|0;
      $63 = $62&255;
      switch ($23<<24>>24) {
      case 1:  {
       $64 = HEAP8[$$1209225>>0]|0;
       $65 = $64&255;
       $66 = HEAP8[$33>>0]|0;
       $67 = $66&255;
       $68 = (79212 + ($67<<2)|0);
       $69 = HEAP32[$68>>2]|0;
       $70 = HEAP32[$41>>2]|0;
       $71 = $70 & $65;
       $72 = HEAP8[$34>>0]|0;
       $73 = $72&255;
       $74 = $71 >>> $73;
       $75 = (($69) + ($74)|0);
       $76 = HEAP8[$75>>0]|0;
       $77 = HEAP8[$35>>0]|0;
       $78 = $77&255;
       $79 = (79212 + ($78<<2)|0);
       $80 = HEAP32[$79>>2]|0;
       $81 = HEAP32[$42>>2]|0;
       $82 = $81 & $65;
       $83 = HEAP8[$36>>0]|0;
       $84 = $83&255;
       $85 = $82 >>> $84;
       $86 = (($80) + ($85)|0);
       $87 = HEAP8[$86>>0]|0;
       $88 = HEAP8[$37>>0]|0;
       $89 = $88&255;
       $90 = (79212 + ($89<<2)|0);
       $91 = HEAP32[$90>>2]|0;
       $92 = HEAP32[$43>>2]|0;
       $93 = $92 & $65;
       $94 = HEAP8[$38>>0]|0;
       $95 = $94&255;
       $96 = $93 >>> $95;
       $97 = (($91) + ($96)|0);
       $98 = HEAP8[$97>>0]|0;
       $99 = HEAP8[$39>>0]|0;
       $100 = $99&255;
       $101 = (79212 + ($100<<2)|0);
       $102 = HEAP32[$101>>2]|0;
       $103 = HEAP32[$44>>2]|0;
       $104 = $103 & $65;
       $105 = HEAP8[$40>>0]|0;
       $106 = $105&255;
       $107 = $104 >>> $106;
       $108 = (($102) + ($107)|0);
       $109 = HEAP8[$108>>0]|0;
       $$0213$shrunk = $109;$$0214$shrunk = $98;$$0215$shrunk = $87;$$0216$shrunk = $76;
       break;
      }
      case 2:  {
       $110 = HEAP16[$$1209225>>1]|0;
       $111 = $110&65535;
       $112 = HEAP8[$33>>0]|0;
       $113 = $112&255;
       $114 = (79212 + ($113<<2)|0);
       $115 = HEAP32[$114>>2]|0;
       $116 = HEAP32[$41>>2]|0;
       $117 = $116 & $111;
       $118 = HEAP8[$34>>0]|0;
       $119 = $118&255;
       $120 = $117 >>> $119;
       $121 = (($115) + ($120)|0);
       $122 = HEAP8[$121>>0]|0;
       $123 = HEAP8[$35>>0]|0;
       $124 = $123&255;
       $125 = (79212 + ($124<<2)|0);
       $126 = HEAP32[$125>>2]|0;
       $127 = HEAP32[$42>>2]|0;
       $128 = $127 & $111;
       $129 = HEAP8[$36>>0]|0;
       $130 = $129&255;
       $131 = $128 >>> $130;
       $132 = (($126) + ($131)|0);
       $133 = HEAP8[$132>>0]|0;
       $134 = HEAP8[$37>>0]|0;
       $135 = $134&255;
       $136 = (79212 + ($135<<2)|0);
       $137 = HEAP32[$136>>2]|0;
       $138 = HEAP32[$43>>2]|0;
       $139 = $138 & $111;
       $140 = HEAP8[$38>>0]|0;
       $141 = $140&255;
       $142 = $139 >>> $141;
       $143 = (($137) + ($142)|0);
       $144 = HEAP8[$143>>0]|0;
       $145 = HEAP8[$39>>0]|0;
       $146 = $145&255;
       $147 = (79212 + ($146<<2)|0);
       $148 = HEAP32[$147>>2]|0;
       $149 = HEAP32[$44>>2]|0;
       $150 = $149 & $111;
       $151 = HEAP8[$40>>0]|0;
       $152 = $151&255;
       $153 = $150 >>> $152;
       $154 = (($148) + ($153)|0);
       $155 = HEAP8[$154>>0]|0;
       $$0213$shrunk = $155;$$0214$shrunk = $144;$$0215$shrunk = $133;$$0216$shrunk = $122;
       break;
      }
      case 3:  {
       $156 = HEAP8[$34>>0]|0;
       $div219 = ($156&255) >>> 3;
       $157 = $div219&255;
       $158 = (($$1209225) + ($157)|0);
       $159 = HEAP8[$158>>0]|0;
       $160 = HEAP8[$36>>0]|0;
       $div220 = ($160&255) >>> 3;
       $161 = $div220&255;
       $162 = (($$1209225) + ($161)|0);
       $163 = HEAP8[$162>>0]|0;
       $164 = HEAP8[$38>>0]|0;
       $div221 = ($164&255) >>> 3;
       $165 = $div221&255;
       $166 = (($$1209225) + ($165)|0);
       $167 = HEAP8[$166>>0]|0;
       $$0213$shrunk = -1;$$0214$shrunk = $167;$$0215$shrunk = $163;$$0216$shrunk = $159;
       break;
      }
      case 4:  {
       $168 = HEAP32[$$1209225>>2]|0;
       $169 = HEAP8[$33>>0]|0;
       $170 = $169&255;
       $171 = (79212 + ($170<<2)|0);
       $172 = HEAP32[$171>>2]|0;
       $173 = HEAP32[$41>>2]|0;
       $174 = $173 & $168;
       $175 = HEAP8[$34>>0]|0;
       $176 = $175&255;
       $177 = $174 >>> $176;
       $178 = (($172) + ($177)|0);
       $179 = HEAP8[$178>>0]|0;
       $180 = HEAP8[$35>>0]|0;
       $181 = $180&255;
       $182 = (79212 + ($181<<2)|0);
       $183 = HEAP32[$182>>2]|0;
       $184 = HEAP32[$42>>2]|0;
       $185 = $184 & $168;
       $186 = HEAP8[$36>>0]|0;
       $187 = $186&255;
       $188 = $185 >>> $187;
       $189 = (($183) + ($188)|0);
       $190 = HEAP8[$189>>0]|0;
       $191 = HEAP8[$37>>0]|0;
       $192 = $191&255;
       $193 = (79212 + ($192<<2)|0);
       $194 = HEAP32[$193>>2]|0;
       $195 = HEAP32[$43>>2]|0;
       $196 = $195 & $168;
       $197 = HEAP8[$38>>0]|0;
       $198 = $197&255;
       $199 = $196 >>> $198;
       $200 = (($194) + ($199)|0);
       $201 = HEAP8[$200>>0]|0;
       $202 = HEAP8[$39>>0]|0;
       $203 = $202&255;
       $204 = (79212 + ($203<<2)|0);
       $205 = HEAP32[$204>>2]|0;
       $206 = HEAP32[$44>>2]|0;
       $207 = $206 & $168;
       $208 = HEAP8[$40>>0]|0;
       $209 = $208&255;
       $210 = $207 >>> $209;
       $211 = (($205) + ($210)|0);
       $212 = HEAP8[$211>>0]|0;
       $$0213$shrunk = $212;$$0214$shrunk = $201;$$0215$shrunk = $190;$$0216$shrunk = $179;
       break;
      }
      default: {
       $$0213$shrunk = 0;$$0214$shrunk = 0;$$0215$shrunk = 0;$$0216$shrunk = 0;
      }
      }
      $$0213 = $$0213$shrunk&255;
      $$0214 = $$0214$shrunk&255;
      $$0215 = $$0215$shrunk&255;
      $$0216 = $$0216$shrunk&255;
      $213 = (($57) - ($$0216))|0;
      $214 = Math_imul($213, $19)|0;
      $215 = (($214>>>0) / 255)&-1;
      $216 = (($215) + ($$0216))|0;
      $217 = (($60) - ($$0215))|0;
      $218 = Math_imul($217, $19)|0;
      $219 = (($218>>>0) / 255)&-1;
      $220 = (($219) + ($$0215))|0;
      $221 = (($63) - ($$0214))|0;
      $222 = Math_imul($221, $19)|0;
      $223 = (($222>>>0) / 255)&-1;
      $224 = (($223) + ($$0214))|0;
      $225 = (($$0213) + ($19))|0;
      $226 = Math_imul($$0213, $19)|0;
      $227 = (($226>>>0) / 255)&-1;
      $228 = (($225) - ($227))|0;
      switch ($23<<24>>24) {
      case 1:  {
       $229 = HEAP8[$33>>0]|0;
       $230 = $229&255;
       $231 = $216 >>> $230;
       $232 = HEAP8[$34>>0]|0;
       $233 = $232&255;
       $234 = $231 << $233;
       $235 = HEAP8[$35>>0]|0;
       $236 = $235&255;
       $237 = $220 >>> $236;
       $238 = HEAP8[$36>>0]|0;
       $239 = $238&255;
       $240 = $237 << $239;
       $241 = $240 | $234;
       $242 = HEAP8[$37>>0]|0;
       $243 = $242&255;
       $244 = $224 >>> $243;
       $245 = HEAP8[$38>>0]|0;
       $246 = $245&255;
       $247 = $244 << $246;
       $248 = $241 | $247;
       $249 = HEAP8[$39>>0]|0;
       $250 = $249&255;
       $251 = $228 >>> $250;
       $252 = HEAP8[$40>>0]|0;
       $253 = $252&255;
       $254 = $251 << $253;
       $255 = $248 | $254;
       $256 = $255&255;
       HEAP8[$$1209225>>0] = $256;
       break L12;
       break;
      }
      case 2:  {
       $257 = HEAP8[$33>>0]|0;
       $258 = $257&255;
       $259 = $216 >>> $258;
       $260 = HEAP8[$34>>0]|0;
       $261 = $260&255;
       $262 = $259 << $261;
       $263 = HEAP8[$35>>0]|0;
       $264 = $263&255;
       $265 = $220 >>> $264;
       $266 = HEAP8[$36>>0]|0;
       $267 = $266&255;
       $268 = $265 << $267;
       $269 = $268 | $262;
       $270 = HEAP8[$37>>0]|0;
       $271 = $270&255;
       $272 = $224 >>> $271;
       $273 = HEAP8[$38>>0]|0;
       $274 = $273&255;
       $275 = $272 << $274;
       $276 = $269 | $275;
       $277 = HEAP8[$39>>0]|0;
       $278 = $277&255;
       $279 = $228 >>> $278;
       $280 = HEAP8[$40>>0]|0;
       $281 = $280&255;
       $282 = $279 << $281;
       $283 = $276 | $282;
       $284 = $283&65535;
       HEAP16[$$1209225>>1] = $284;
       break L12;
       break;
      }
      case 3:  {
       $285 = $216&255;
       $286 = HEAP8[$34>>0]|0;
       $div = ($286&255) >>> 3;
       $287 = $div&255;
       $288 = (($$1209225) + ($287)|0);
       HEAP8[$288>>0] = $285;
       $289 = $220&255;
       $290 = HEAP8[$36>>0]|0;
       $div217 = ($290&255) >>> 3;
       $291 = $div217&255;
       $292 = (($$1209225) + ($291)|0);
       HEAP8[$292>>0] = $289;
       $293 = $224&255;
       $294 = HEAP8[$38>>0]|0;
       $div218 = ($294&255) >>> 3;
       $295 = $div218&255;
       $296 = (($$1209225) + ($295)|0);
       HEAP8[$296>>0] = $293;
       break L12;
       break;
      }
      case 4:  {
       $297 = HEAP8[$33>>0]|0;
       $298 = $297&255;
       $299 = $216 >>> $298;
       $300 = HEAP8[$34>>0]|0;
       $301 = $300&255;
       $302 = $299 << $301;
       $303 = HEAP8[$35>>0]|0;
       $304 = $303&255;
       $305 = $220 >>> $304;
       $306 = HEAP8[$36>>0]|0;
       $307 = $306&255;
       $308 = $305 << $307;
       $309 = $308 | $302;
       $310 = HEAP8[$37>>0]|0;
       $311 = $310&255;
       $312 = $224 >>> $311;
       $313 = HEAP8[$38>>0]|0;
       $314 = $313&255;
       $315 = $312 << $314;
       $316 = $309 | $315;
       $317 = HEAP8[$39>>0]|0;
       $318 = $317&255;
       $319 = $228 >>> $318;
       $320 = HEAP8[$40>>0]|0;
       $321 = $320&255;
       $322 = $319 << $321;
       $323 = $316 | $322;
       HEAP32[$$1209225>>2] = $323;
       break L12;
       break;
      }
      default: {
       break L12;
      }
      }
     }
    } while(0);
    $324 = $51 << 1;
    $325 = $324&255;
    $326 = (($$1209225) + ($24)|0);
    $327 = (($$0212223) + 1)|0;
    $exitcond = ($327|0)==($2|0);
    if ($exitcond) {
     break;
    } else {
     $$0210224 = $325;$$0212223 = $327;$$1209225 = $326;$$1227 = $$2;
    }
   }
   $scevgep = (($$0208229) + ($45)|0);
   $$1$lcssa = $$2;$$1209$lcssa = $scevgep;
  } else {
   $$1$lcssa = $$0207230;$$1209$lcssa = $$0208229;
  }
  $328 = (($$1$lcssa) + ($27)|0);
  $329 = (($$1209$lcssa) + ($8)|0);
  $330 = ($46|0)==(0);
  if ($330) {
   break;
  } else {
   $$0207230 = $328;$$0208229 = $329;$$in = $46;
  }
 }
 return;
}
function _BlitBto1Key($0) {
 $0 = $0|0;
 var $$06382$us = 0, $$06595$us = 0, $$06788$us = 0, $$06987$us = 0, $$07194$us = 0, $$164$us = 0, $$16689$us = 0, $$168$us = 0, $$17080$us = 0, $$17286$us = 0, $$2$us = 0, $$27384$us = 0, $$37479$us = 0, $$385$us = 0, $$481$us = 0, $$5$us = 0, $$not103 = 0, $1 = 0, $10 = 0, $11 = 0;
 var $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $exitcond101 = 0, $or$cond104 = 0, $scevgep = 0, $scevgep100 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$0>>2]|0;
 $6 = ((($0)) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($0)) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($0)) + 36|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($0)) + 56|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($0)) + 48|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($2) + 7)|0;
 $17 = (($16|0) / 8)&-1;
 $18 = (($2) - ($17))|0;
 $19 = (($9) + ($18))|0;
 $20 = ($15|0)==(0|0);
 $21 = (($4) + -1)|0;
 $$not103 = ($4|0)!=(0);
 $22 = ($2|0)>(0);
 $or$cond104 = $$not103 & $22;
 if ($20) {
  if ($or$cond104) {
   $$27384$us = $7;$$385$us = $5;$57 = $21;
  } else {
   return;
  }
  while(1) {
   $$06382$us = 0;$$17080$us = 0;$$37479$us = $$27384$us;$$481$us = $$385$us;
   while(1) {
    $42 = $$17080$us & 7;
    $43 = ($42|0)==(0);
    if ($43) {
     $44 = ((($$481$us)) + 1|0);
     $45 = HEAP8[$$481$us>>0]|0;
     $$164$us = $45;$$5$us = $44;
    } else {
     $$164$us = $$06382$us;$$5$us = $$481$us;
    }
    $46 = $$164$us&255;
    $47 = ($$164$us&255) >>> 7;
    $48 = $47&255;
    $49 = ($48|0)==($13|0);
    if (!($49)) {
     HEAP8[$$37479$us>>0] = $47;
    }
    $50 = ((($$37479$us)) + 1|0);
    $51 = $46 << 1;
    $52 = $51&255;
    $53 = (($$17080$us) + 1)|0;
    $exitcond = ($53|0)==($2|0);
    if ($exitcond) {
     break;
    } else {
     $$06382$us = $52;$$17080$us = $53;$$37479$us = $50;$$481$us = $$5$us;
    }
   }
   $scevgep = (($$27384$us) + ($2)|0);
   $54 = (($$5$us) + ($19)|0);
   $55 = (($scevgep) + ($11)|0);
   $56 = (($57) + -1)|0;
   $58 = ($57|0)==(0);
   if ($58) {
    break;
   } else {
    $$27384$us = $55;$$385$us = $54;$57 = $56;
   }
  }
  return;
 } else {
  if ($or$cond104) {
   $$06595$us = $5;$$07194$us = $7;$40 = $21;
  } else {
   return;
  }
  while(1) {
   $$06788$us = 0;$$06987$us = 0;$$16689$us = $$06595$us;$$17286$us = $$07194$us;
   while(1) {
    $23 = $$06987$us & 7;
    $24 = ($23|0)==(0);
    if ($24) {
     $25 = ((($$16689$us)) + 1|0);
     $26 = HEAP8[$$16689$us>>0]|0;
     $$168$us = $26;$$2$us = $25;
    } else {
     $$168$us = $$06788$us;$$2$us = $$16689$us;
    }
    $27 = $$168$us&255;
    $28 = ($$168$us&255) >>> 7;
    $29 = $28&255;
    $30 = ($29|0)==($13|0);
    if (!($30)) {
     $31 = (($15) + ($29)|0);
     $32 = HEAP8[$31>>0]|0;
     HEAP8[$$17286$us>>0] = $32;
    }
    $33 = ((($$17286$us)) + 1|0);
    $34 = $27 << 1;
    $35 = $34&255;
    $36 = (($$06987$us) + 1)|0;
    $exitcond101 = ($36|0)==($2|0);
    if ($exitcond101) {
     break;
    } else {
     $$06788$us = $35;$$06987$us = $36;$$16689$us = $$2$us;$$17286$us = $33;
    }
   }
   $scevgep100 = (($$07194$us) + ($2)|0);
   $37 = (($$2$us) + ($19)|0);
   $38 = (($scevgep100) + ($11)|0);
   $39 = (($40) + -1)|0;
   $41 = ($40|0)==(0);
   if ($41) {
    break;
   } else {
    $$06595$us = $37;$$07194$us = $38;$40 = $39;
   }
  }
  return;
 }
}
function _BlitBto2Key($0) {
 $0 = $0|0;
 var $$04655$us = 0, $$04754$us = 0, $$04858$us = 0, $$05057$us = 0, $$1$us = 0, $$14953$us = 0, $$15152$us = 0, $$2$us = 0, $$in = 0, $$neg = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $or$cond = 0, $scevgep = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($0)) + 36|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($0)) + 56|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ((($0)) + 48|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($2) + 7)|0;
 $$neg = (($13|0) / -8)&-1;
 $14 = (($$neg) + ($2))|0;
 $15 = (($14) + ($6))|0;
 $16 = (($8|0) / 2)&-1;
 $17 = ($4|0)!=(0);
 $18 = ($2|0)>(0);
 $or$cond = $17 & $18;
 if (!($or$cond)) {
  return;
 }
 $19 = HEAP32[$0>>2]|0;
 $20 = ((($0)) + 20|0);
 $21 = HEAP32[$20>>2]|0;
 $$04858$us = $19;$$05057$us = $21;$$in = $4;
 while(1) {
  $22 = (($$in) + -1)|0;
  $$04655$us = 0;$$04754$us = 0;$$14953$us = $$04858$us;$$15152$us = $$05057$us;
  while(1) {
   $23 = $$04754$us & 7;
   $24 = ($23|0)==(0);
   if ($24) {
    $25 = ((($$14953$us)) + 1|0);
    $26 = HEAP8[$$14953$us>>0]|0;
    $$1$us = $26;$$2$us = $25;
   } else {
    $$1$us = $$04655$us;$$2$us = $$14953$us;
   }
   $27 = $$1$us&255;
   $28 = ($$1$us&255) >>> 7;
   $29 = $28&255;
   $30 = ($29|0)==($10|0);
   if (!($30)) {
    $31 = (($12) + ($29<<1)|0);
    $32 = HEAP16[$31>>1]|0;
    HEAP16[$$15152$us>>1] = $32;
   }
   $33 = $27 << 1;
   $34 = $33&255;
   $35 = ((($$15152$us)) + 2|0);
   $36 = (($$04754$us) + 1)|0;
   $exitcond = ($36|0)==($2|0);
   if ($exitcond) {
    break;
   } else {
    $$04655$us = $34;$$04754$us = $36;$$14953$us = $$2$us;$$15152$us = $35;
   }
  }
  $scevgep = (($$05057$us) + ($2<<1)|0);
  $37 = (($$2$us) + ($15)|0);
  $38 = (($scevgep) + ($16<<1)|0);
  $39 = ($22|0)==(0);
  if ($39) {
   break;
  } else {
   $$04858$us = $37;$$05057$us = $38;$$in = $22;
  }
 }
 return;
}
function _BlitBto3Key($0) {
 $0 = $0|0;
 var $$04554$us = 0, $$04653$us = 0, $$04757$us = 0, $$04956$us = 0, $$1$us = 0, $$14852$us = 0, $$15051$us = 0, $$2$us = 0, $$in = 0, $$neg = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $or$cond = 0, $scevgep = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($0)) + 36|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($0)) + 56|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ((($0)) + 48|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($2) + 7)|0;
 $$neg = (($13|0) / -8)&-1;
 $14 = (($$neg) + ($2))|0;
 $15 = (($14) + ($6))|0;
 $16 = ($4|0)!=(0);
 $17 = ($2|0)>(0);
 $or$cond = $16 & $17;
 if (!($or$cond)) {
  return;
 }
 $18 = HEAP32[$0>>2]|0;
 $19 = ((($0)) + 20|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($2*3)|0;
 $$04757$us = $18;$$04956$us = $20;$$in = $4;
 while(1) {
  $22 = (($$in) + -1)|0;
  $$04554$us = 0;$$04653$us = 0;$$14852$us = $$04757$us;$$15051$us = $$04956$us;
  while(1) {
   $23 = $$04653$us & 7;
   $24 = ($23|0)==(0);
   if ($24) {
    $25 = ((($$14852$us)) + 1|0);
    $26 = HEAP8[$$14852$us>>0]|0;
    $$1$us = $26;$$2$us = $25;
   } else {
    $$1$us = $$04554$us;$$2$us = $$14852$us;
   }
   $27 = $$1$us&255;
   $28 = ($$1$us&255) >>> 7;
   $29 = $28&255;
   $30 = ($29|0)==($10|0);
   if (!($30)) {
    $31 = ($28 << 2)&255;
    $32 = $31&255;
    $33 = (($12) + ($32)|0);
    (_SDL_memcpy($$15051$us,$33,3)|0);
   }
   $34 = $27 << 1;
   $35 = $34&255;
   $36 = ((($$15051$us)) + 3|0);
   $37 = (($$04653$us) + 1)|0;
   $exitcond = ($37|0)==($2|0);
   if ($exitcond) {
    break;
   } else {
    $$04554$us = $35;$$04653$us = $37;$$14852$us = $$2$us;$$15051$us = $36;
   }
  }
  $scevgep = (($$04956$us) + ($21)|0);
  $38 = (($$2$us) + ($15)|0);
  $39 = (($scevgep) + ($8)|0);
  $40 = ($22|0)==(0);
  if ($40) {
   break;
  } else {
   $$04757$us = $38;$$04956$us = $39;$$in = $22;
  }
 }
 return;
}
function _BlitBto4Key($0) {
 $0 = $0|0;
 var $$04655$us = 0, $$04754$us = 0, $$04858$us = 0, $$05057$us = 0, $$1$us = 0, $$14953$us = 0, $$15152$us = 0, $$2$us = 0, $$in = 0, $$neg = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $or$cond = 0, $scevgep = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($0)) + 36|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($0)) + 56|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ((($0)) + 48|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($2) + 7)|0;
 $$neg = (($13|0) / -8)&-1;
 $14 = (($$neg) + ($2))|0;
 $15 = (($14) + ($6))|0;
 $16 = (($8|0) / 4)&-1;
 $17 = ($4|0)!=(0);
 $18 = ($2|0)>(0);
 $or$cond = $17 & $18;
 if (!($or$cond)) {
  return;
 }
 $19 = HEAP32[$0>>2]|0;
 $20 = ((($0)) + 20|0);
 $21 = HEAP32[$20>>2]|0;
 $$04858$us = $19;$$05057$us = $21;$$in = $4;
 while(1) {
  $22 = (($$in) + -1)|0;
  $$04655$us = 0;$$04754$us = 0;$$14953$us = $$04858$us;$$15152$us = $$05057$us;
  while(1) {
   $23 = $$04754$us & 7;
   $24 = ($23|0)==(0);
   if ($24) {
    $25 = ((($$14953$us)) + 1|0);
    $26 = HEAP8[$$14953$us>>0]|0;
    $$1$us = $26;$$2$us = $25;
   } else {
    $$1$us = $$04655$us;$$2$us = $$14953$us;
   }
   $27 = $$1$us&255;
   $28 = ($$1$us&255) >>> 7;
   $29 = $28&255;
   $30 = ($29|0)==($10|0);
   if (!($30)) {
    $31 = (($12) + ($29<<2)|0);
    $32 = HEAP32[$31>>2]|0;
    HEAP32[$$15152$us>>2] = $32;
   }
   $33 = $27 << 1;
   $34 = $33&255;
   $35 = ((($$15152$us)) + 4|0);
   $36 = (($$04754$us) + 1)|0;
   $exitcond = ($36|0)==($2|0);
   if ($exitcond) {
    break;
   } else {
    $$04655$us = $34;$$04754$us = $36;$$14953$us = $$2$us;$$15152$us = $35;
   }
  }
  $scevgep = (($$05057$us) + ($2<<2)|0);
  $37 = (($$2$us) + ($15)|0);
  $38 = (($scevgep) + ($16<<2)|0);
  $39 = ($22|0)==(0);
  if ($39) {
   break;
  } else {
   $$04858$us = $37;$$05057$us = $38;$$in = $22;
  }
 }
 return;
}
function _BlitBto1($0) {
 $0 = $0|0;
 var $$05674$us = 0, $$06081$us = 0, $$06288$us = 0, $$06487$us = 0, $$082$us = 0, $$157$us = 0, $$161$us = 0, $$16380$us = 0, $$16579$us = 0, $$175$us = 0, $$2$us = 0, $$26677$us = 0, $$36772$us = 0, $$378$us = 0, $$473$us = 0, $$5$us = 0, $$not96 = 0, $1 = 0, $10 = 0, $11 = 0;
 var $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $exitcond94 = 0, $or$cond97 = 0, $scevgep = 0, $scevgep93 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$0>>2]|0;
 $6 = ((($0)) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($0)) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($0)) + 36|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($0)) + 48|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($2) + 7)|0;
 $15 = (($14|0) / 8)&-1;
 $16 = (($2) - ($15))|0;
 $17 = (($7) + ($16))|0;
 $18 = ($13|0)==(0|0);
 $19 = (($4) + -1)|0;
 $$not96 = ($4|0)!=(0);
 $20 = ($2|0)>(0);
 $or$cond97 = $$not96 & $20;
 if ($18) {
  if ($or$cond97) {
   $$26677$us = $9;$$378$us = $5;$52 = $19;
  } else {
   return;
  }
  while(1) {
   $$05674$us = 0;$$175$us = 0;$$36772$us = $$26677$us;$$473$us = $$378$us;
   while(1) {
    $39 = $$175$us & 7;
    $40 = ($39|0)==(0);
    if ($40) {
     $41 = ((($$473$us)) + 1|0);
     $42 = HEAP8[$$473$us>>0]|0;
     $$157$us = $42;$$5$us = $41;
    } else {
     $$157$us = $$05674$us;$$5$us = $$473$us;
    }
    $43 = $$157$us&255;
    $44 = ($$157$us&255) >>> 7;
    HEAP8[$$36772$us>>0] = $44;
    $45 = ((($$36772$us)) + 1|0);
    $46 = $43 << 1;
    $47 = $46&255;
    $48 = (($$175$us) + 1)|0;
    $exitcond = ($48|0)==($2|0);
    if ($exitcond) {
     break;
    } else {
     $$05674$us = $47;$$175$us = $48;$$36772$us = $45;$$473$us = $$5$us;
    }
   }
   $scevgep = (($$26677$us) + ($2)|0);
   $49 = (($$5$us) + ($17)|0);
   $50 = (($scevgep) + ($11)|0);
   $51 = (($52) + -1)|0;
   $53 = ($52|0)==(0);
   if ($53) {
    break;
   } else {
    $$26677$us = $50;$$378$us = $49;$52 = $51;
   }
  }
  return;
 } else {
  if ($or$cond97) {
   $$06288$us = $5;$$06487$us = $9;$37 = $19;
  } else {
   return;
  }
  while(1) {
   $$06081$us = 0;$$082$us = 0;$$16380$us = $$06288$us;$$16579$us = $$06487$us;
   while(1) {
    $21 = $$082$us & 7;
    $22 = ($21|0)==(0);
    if ($22) {
     $23 = ((($$16380$us)) + 1|0);
     $24 = HEAP8[$$16380$us>>0]|0;
     $$161$us = $24;$$2$us = $23;
    } else {
     $$161$us = $$06081$us;$$2$us = $$16380$us;
    }
    $25 = $$161$us&255;
    $26 = ($$161$us&255) >>> 7;
    $27 = $26&255;
    $28 = (($13) + ($27)|0);
    $29 = HEAP8[$28>>0]|0;
    HEAP8[$$16579$us>>0] = $29;
    $30 = ((($$16579$us)) + 1|0);
    $31 = $25 << 1;
    $32 = $31&255;
    $33 = (($$082$us) + 1)|0;
    $exitcond94 = ($33|0)==($2|0);
    if ($exitcond94) {
     break;
    } else {
     $$06081$us = $32;$$082$us = $33;$$16380$us = $$2$us;$$16579$us = $30;
    }
   }
   $scevgep93 = (($$06487$us) + ($2)|0);
   $34 = (($$2$us) + ($17)|0);
   $35 = (($scevgep93) + ($11)|0);
   $36 = (($37) + -1)|0;
   $38 = ($37|0)==(0);
   if ($38) {
    break;
   } else {
    $$06288$us = $34;$$06487$us = $35;$37 = $36;
   }
  }
  return;
 }
}
function _BlitBto2($0) {
 $0 = $0|0;
 var $$04048$us = 0, $$04252$us = 0, $$04451$us = 0, $$049$us = 0, $$1$us = 0, $$14347$us = 0, $$14546$us = 0, $$2$us = 0, $$in = 0, $$neg = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $or$cond = 0, $scevgep = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($0)) + 36|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8|0) / 2)&-1;
 $10 = ((($0)) + 48|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($2) + 7)|0;
 $$neg = (($12|0) / -8)&-1;
 $13 = (($$neg) + ($2))|0;
 $14 = (($13) + ($6))|0;
 $15 = ($4|0)!=(0);
 $16 = ($2|0)>(0);
 $or$cond = $15 & $16;
 if (!($or$cond)) {
  return;
 }
 $17 = ((($0)) + 20|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = HEAP32[$0>>2]|0;
 $$04252$us = $18;$$04451$us = $19;$$in = $4;
 while(1) {
  $20 = (($$in) + -1)|0;
  $$04048$us = 0;$$049$us = 0;$$14347$us = $$04252$us;$$14546$us = $$04451$us;
  while(1) {
   $21 = $$049$us & 7;
   $22 = ($21|0)==(0);
   if ($22) {
    $23 = ((($$14546$us)) + 1|0);
    $24 = HEAP8[$$14546$us>>0]|0;
    $$1$us = $24;$$2$us = $23;
   } else {
    $$1$us = $$04048$us;$$2$us = $$14546$us;
   }
   $25 = $$1$us&255;
   $26 = ($$1$us&255) >>> 7;
   $27 = $26&255;
   $28 = (($11) + ($27<<1)|0);
   $29 = HEAP16[$28>>1]|0;
   HEAP16[$$14347$us>>1] = $29;
   $30 = $25 << 1;
   $31 = $30&255;
   $32 = ((($$14347$us)) + 2|0);
   $33 = (($$049$us) + 1)|0;
   $exitcond = ($33|0)==($2|0);
   if ($exitcond) {
    break;
   } else {
    $$04048$us = $31;$$049$us = $33;$$14347$us = $32;$$14546$us = $$2$us;
   }
  }
  $scevgep = (($$04252$us) + ($2<<1)|0);
  $34 = (($$2$us) + ($14)|0);
  $35 = (($scevgep) + ($9<<1)|0);
  $36 = ($20|0)==(0);
  if ($36) {
   break;
  } else {
   $$04252$us = $35;$$04451$us = $34;$$in = $20;
  }
 }
 return;
}
function _BlitBto3($0) {
 $0 = $0|0;
 var $$04957$us = 0, $$05161$us = 0, $$05360$us = 0, $$058$us = 0, $$1$us = 0, $$15256$us = 0, $$15455$us = 0, $$2$us = 0, $$in = 0, $$neg = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $or$cond = 0, $scevgep = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($0)) + 36|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($0)) + 48|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($2) + 7)|0;
 $$neg = (($11|0) / -8)&-1;
 $12 = (($$neg) + ($2))|0;
 $13 = (($12) + ($6))|0;
 $14 = ($4|0)!=(0);
 $15 = ($2|0)>(0);
 $or$cond = $14 & $15;
 if (!($or$cond)) {
  return;
 }
 $16 = ((($0)) + 20|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = HEAP32[$0>>2]|0;
 $19 = ($2*3)|0;
 $$05161$us = $17;$$05360$us = $18;$$in = $4;
 while(1) {
  $20 = (($$in) + -1)|0;
  $$04957$us = 0;$$058$us = 0;$$15256$us = $$05161$us;$$15455$us = $$05360$us;
  while(1) {
   $21 = $$058$us & 7;
   $22 = ($21|0)==(0);
   if ($22) {
    $23 = ((($$15455$us)) + 1|0);
    $24 = HEAP8[$$15455$us>>0]|0;
    $$1$us = $24;$$2$us = $23;
   } else {
    $$1$us = $$04957$us;$$2$us = $$15455$us;
   }
   $25 = $$1$us&255;
   $26 = ($$1$us&255) >>> 7;
   $27 = ($26 << 2)&255;
   $28 = $27&255;
   $29 = $28 | 1;
   $30 = (($10) + ($28)|0);
   $31 = HEAP8[$30>>0]|0;
   HEAP8[$$15256$us>>0] = $31;
   $32 = (($29) + 1)|0;
   $33 = (($10) + ($29)|0);
   $34 = HEAP8[$33>>0]|0;
   $35 = ((($$15256$us)) + 1|0);
   HEAP8[$35>>0] = $34;
   $36 = (($10) + ($32)|0);
   $37 = HEAP8[$36>>0]|0;
   $38 = ((($$15256$us)) + 2|0);
   HEAP8[$38>>0] = $37;
   $39 = $25 << 1;
   $40 = $39&255;
   $41 = ((($$15256$us)) + 3|0);
   $42 = (($$058$us) + 1)|0;
   $exitcond = ($42|0)==($2|0);
   if ($exitcond) {
    break;
   } else {
    $$04957$us = $40;$$058$us = $42;$$15256$us = $41;$$15455$us = $$2$us;
   }
  }
  $scevgep = (($$05161$us) + ($19)|0);
  $43 = (($$2$us) + ($13)|0);
  $44 = (($scevgep) + ($8)|0);
  $45 = ($20|0)==(0);
  if ($45) {
   break;
  } else {
   $$05161$us = $44;$$05360$us = $43;$$in = $20;
  }
 }
 return;
}
function _BlitBto4($0) {
 $0 = $0|0;
 var $$04049$us = 0, $$04148$us = 0, $$04252$us = 0, $$04451$us = 0, $$1$us = 0, $$14347$us = 0, $$14546$us = 0, $$2$us = 0, $$in = 0, $$neg = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $or$cond = 0, $scevgep = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($0)) + 36|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8|0) / 4)&-1;
 $10 = ((($0)) + 48|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($2) + 7)|0;
 $$neg = (($12|0) / -8)&-1;
 $13 = (($$neg) + ($2))|0;
 $14 = (($13) + ($6))|0;
 $15 = ($4|0)!=(0);
 $16 = ($2|0)>(0);
 $or$cond = $15 & $16;
 if (!($or$cond)) {
  return;
 }
 $17 = HEAP32[$0>>2]|0;
 $18 = ((($0)) + 20|0);
 $19 = HEAP32[$18>>2]|0;
 $$04252$us = $17;$$04451$us = $19;$$in = $4;
 while(1) {
  $20 = (($$in) + -1)|0;
  $$04049$us = 0;$$04148$us = 0;$$14347$us = $$04252$us;$$14546$us = $$04451$us;
  while(1) {
   $21 = $$04148$us & 7;
   $22 = ($21|0)==(0);
   if ($22) {
    $23 = ((($$14347$us)) + 1|0);
    $24 = HEAP8[$$14347$us>>0]|0;
    $$1$us = $24;$$2$us = $23;
   } else {
    $$1$us = $$04049$us;$$2$us = $$14347$us;
   }
   $25 = $$1$us&255;
   $26 = ($$1$us&255) >>> 7;
   $27 = $26&255;
   $28 = (($11) + ($27<<2)|0);
   $29 = HEAP32[$28>>2]|0;
   HEAP32[$$14546$us>>2] = $29;
   $30 = $25 << 1;
   $31 = $30&255;
   $32 = ((($$14546$us)) + 4|0);
   $33 = (($$04148$us) + 1)|0;
   $exitcond = ($33|0)==($2|0);
   if ($exitcond) {
    break;
   } else {
    $$04049$us = $31;$$04148$us = $33;$$14347$us = $$2$us;$$14546$us = $32;
   }
  }
  $scevgep = (($$04451$us) + ($2<<2)|0);
  $34 = (($$2$us) + ($14)|0);
  $35 = (($scevgep) + ($9<<2)|0);
  $36 = ($20|0)==(0);
  if ($36) {
   break;
  } else {
   $$04252$us = $34;$$04451$us = $35;$$in = $20;
  }
 }
 return;
}
function _SDL_realloc($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_realloc($0,$1)|0);
 return ($2|0);
}
function _copy_transl_565($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$04548 = 0, $$04647 = 0, $$049 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $8 = 0, $9 = 0, $exitcond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = ($2|0)>(0);
 if (!($5)) {
  $74 = $2 << 2;
  return ($74|0);
 }
 $6 = ((($3)) + 12|0);
 $7 = ((($3)) + 32|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = $8&255;
 $10 = ((($3)) + 16|0);
 $11 = ((($3)) + 33|0);
 $12 = HEAP8[$11>>0]|0;
 $13 = $12&255;
 $14 = ((($3)) + 20|0);
 $15 = ((($3)) + 34|0);
 $16 = HEAP8[$15>>0]|0;
 $17 = $16&255;
 $18 = ((($3)) + 24|0);
 $19 = ((($3)) + 35|0);
 $20 = HEAP8[$19>>0]|0;
 $21 = $20&255;
 $22 = ((($4)) + 28|0);
 $23 = HEAP8[$22>>0]|0;
 $24 = $23&255;
 $25 = ((($4)) + 32|0);
 $26 = HEAP8[$25>>0]|0;
 $27 = $26&255;
 $28 = ((($4)) + 29|0);
 $29 = HEAP8[$28>>0]|0;
 $30 = $29&255;
 $31 = ((($4)) + 33|0);
 $32 = HEAP8[$31>>0]|0;
 $33 = $32&255;
 $34 = ((($4)) + 30|0);
 $35 = HEAP8[$34>>0]|0;
 $36 = $35&255;
 $37 = ((($4)) + 34|0);
 $38 = HEAP8[$37>>0]|0;
 $39 = $38&255;
 $40 = ((($4)) + 24|0);
 $$04548 = 0;$$04647 = $0;$$049 = $1;
 while(1) {
  $41 = HEAP32[$$049>>2]|0;
  $42 = HEAP32[$6>>2]|0;
  $43 = $42 & $41;
  $44 = $43 >>> $9;
  $45 = HEAP32[$10>>2]|0;
  $46 = $45 & $41;
  $47 = $46 >>> $13;
  $48 = HEAP32[$14>>2]|0;
  $49 = $48 & $41;
  $50 = $49 >>> $17;
  $51 = HEAP32[$18>>2]|0;
  $52 = $51 & $41;
  $53 = $52 >>> $21;
  $54 = $44 >>> $24;
  $55 = $54 << $27;
  $56 = $47 >>> $30;
  $57 = $56 << $33;
  $58 = $57 | $55;
  $59 = $50 >>> $36;
  $60 = $59 << $39;
  $61 = HEAP32[$40>>2]|0;
  $62 = $58 | $61;
  $63 = $62 | $60;
  $64 = $63 << 16;
  $65 = $64 & 132120576;
  $66 = $63 & 63519;
  $67 = $53 << 2;
  $68 = $67 & 2016;
  $69 = $66 | $68;
  $70 = $69 | $65;
  HEAP32[$$04647>>2] = $70;
  $71 = ((($$049)) + 4|0);
  $72 = ((($$04647)) + 4|0);
  $73 = (($$04548) + 1)|0;
  $exitcond = ($73|0)==($2|0);
  if ($exitcond) {
   break;
  } else {
   $$04548 = $73;$$04647 = $72;$$049 = $71;
  }
 }
 $74 = $2 << 2;
 return ($74|0);
}
function _copy_transl_555($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$04548 = 0, $$04647 = 0, $$049 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $8 = 0, $9 = 0, $exitcond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = ($2|0)>(0);
 if (!($5)) {
  $74 = $2 << 2;
  return ($74|0);
 }
 $6 = ((($3)) + 12|0);
 $7 = ((($3)) + 32|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = $8&255;
 $10 = ((($3)) + 16|0);
 $11 = ((($3)) + 33|0);
 $12 = HEAP8[$11>>0]|0;
 $13 = $12&255;
 $14 = ((($3)) + 20|0);
 $15 = ((($3)) + 34|0);
 $16 = HEAP8[$15>>0]|0;
 $17 = $16&255;
 $18 = ((($3)) + 24|0);
 $19 = ((($3)) + 35|0);
 $20 = HEAP8[$19>>0]|0;
 $21 = $20&255;
 $22 = ((($4)) + 28|0);
 $23 = HEAP8[$22>>0]|0;
 $24 = $23&255;
 $25 = ((($4)) + 32|0);
 $26 = HEAP8[$25>>0]|0;
 $27 = $26&255;
 $28 = ((($4)) + 29|0);
 $29 = HEAP8[$28>>0]|0;
 $30 = $29&255;
 $31 = ((($4)) + 33|0);
 $32 = HEAP8[$31>>0]|0;
 $33 = $32&255;
 $34 = ((($4)) + 30|0);
 $35 = HEAP8[$34>>0]|0;
 $36 = $35&255;
 $37 = ((($4)) + 34|0);
 $38 = HEAP8[$37>>0]|0;
 $39 = $38&255;
 $40 = ((($4)) + 24|0);
 $$04548 = 0;$$04647 = $0;$$049 = $1;
 while(1) {
  $41 = HEAP32[$$049>>2]|0;
  $42 = HEAP32[$6>>2]|0;
  $43 = $42 & $41;
  $44 = $43 >>> $9;
  $45 = HEAP32[$10>>2]|0;
  $46 = $45 & $41;
  $47 = $46 >>> $13;
  $48 = HEAP32[$14>>2]|0;
  $49 = $48 & $41;
  $50 = $49 >>> $17;
  $51 = HEAP32[$18>>2]|0;
  $52 = $51 & $41;
  $53 = $52 >>> $21;
  $54 = $44 >>> $24;
  $55 = $54 << $27;
  $56 = $47 >>> $30;
  $57 = $56 << $33;
  $58 = $57 | $55;
  $59 = $50 >>> $36;
  $60 = $59 << $39;
  $61 = HEAP32[$40>>2]|0;
  $62 = $58 | $61;
  $63 = $62 | $60;
  $64 = $63 << 16;
  $65 = $64 & 65011712;
  $66 = $63 & 64543;
  $67 = $53 << 2;
  $68 = $67 & 992;
  $69 = $66 | $68;
  $70 = $69 | $65;
  HEAP32[$$04647>>2] = $70;
  $71 = ((($$049)) + 4|0);
  $72 = ((($$04647)) + 4|0);
  $73 = (($$04548) + 1)|0;
  $exitcond = ($73|0)==($2|0);
  if ($exitcond) {
   break;
  } else {
   $$04548 = $73;$$04647 = $72;$$049 = $71;
  }
 }
 $74 = $2 << 2;
 return ($74|0);
}
function _copy_32($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$04043 = 0, $$04142 = 0, $$044 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = ($2|0)>(0);
 if (!($5)) {
  $66 = $2 << 2;
  return ($66|0);
 }
 $6 = ((($3)) + 12|0);
 $7 = ((($3)) + 32|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = $8&255;
 $10 = ((($3)) + 16|0);
 $11 = ((($3)) + 33|0);
 $12 = HEAP8[$11>>0]|0;
 $13 = $12&255;
 $14 = ((($3)) + 20|0);
 $15 = ((($3)) + 34|0);
 $16 = HEAP8[$15>>0]|0;
 $17 = $16&255;
 $18 = ((($3)) + 24|0);
 $19 = ((($3)) + 35|0);
 $20 = HEAP8[$19>>0]|0;
 $21 = $20&255;
 $22 = ((($4)) + 28|0);
 $23 = HEAP8[$22>>0]|0;
 $24 = $23&255;
 $25 = ((($4)) + 32|0);
 $26 = HEAP8[$25>>0]|0;
 $27 = $26&255;
 $28 = ((($4)) + 29|0);
 $29 = HEAP8[$28>>0]|0;
 $30 = $29&255;
 $31 = ((($4)) + 33|0);
 $32 = HEAP8[$31>>0]|0;
 $33 = $32&255;
 $34 = ((($4)) + 30|0);
 $35 = HEAP8[$34>>0]|0;
 $36 = $35&255;
 $37 = ((($4)) + 34|0);
 $38 = HEAP8[$37>>0]|0;
 $39 = $38&255;
 $$04043 = 0;$$04142 = $0;$$044 = $1;
 while(1) {
  $40 = HEAP32[$$044>>2]|0;
  $41 = HEAP32[$6>>2]|0;
  $42 = $41 & $40;
  $43 = $42 >>> $9;
  $44 = HEAP32[$10>>2]|0;
  $45 = $44 & $40;
  $46 = $45 >>> $13;
  $47 = HEAP32[$14>>2]|0;
  $48 = $47 & $40;
  $49 = $48 >>> $17;
  $50 = HEAP32[$18>>2]|0;
  $51 = $50 & $40;
  $52 = $51 >>> $21;
  $53 = $43 >>> $24;
  $54 = $53 << $27;
  $55 = $46 >>> $30;
  $56 = $55 << $33;
  $57 = $49 >>> $36;
  $58 = $57 << $39;
  $59 = $52 << 24;
  $60 = $54 | $59;
  $61 = $60 | $56;
  $62 = $61 | $58;
  HEAP32[$$04142>>2] = $62;
  $63 = ((($$04142)) + 4|0);
  $64 = ((($$044)) + 4|0);
  $65 = (($$04043) + 1)|0;
  $exitcond = ($65|0)==($2|0);
  if ($exitcond) {
   break;
  } else {
   $$04043 = $65;$$04142 = $63;$$044 = $64;
  }
 }
 $66 = $2 << 2;
 return ($66|0);
}
function _copy_opaque_16($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$03841 = 0, $$03940 = 0, $$042 = 0, $$phi$trans$insert = 0, $$phi$trans$insert43 = 0, $$phi$trans$insert48 = 0, $$phi$trans$insert49 = 0, $$phi$trans$insert54 = 0, $$phi$trans$insert55 = 0, $$pre = 0, $$pre44 = 0, $$pre45 = 0, $$pre46 = 0, $$pre47 = 0, $$pre50 = 0, $$pre51 = 0, $$pre52 = 0, $$pre53 = 0, $$pre56 = 0, $$pre57 = 0;
 var $$pre58 = 0, $$pre59 = 0, $$pre60 = 0, $$pre61 = 0, $$pre62 = 0, $$pre63 = 0, $$pre64 = 0, $$pre65 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = ($2|0)>(0);
 if (!($5)) {
  $60 = $2 << 1;
  return ($60|0);
 }
 $6 = ((($3)) + 28|0);
 $7 = ((($3)) + 12|0);
 $8 = ((($3)) + 32|0);
 $9 = ((($3)) + 29|0);
 $10 = ((($3)) + 16|0);
 $11 = ((($3)) + 33|0);
 $12 = ((($3)) + 30|0);
 $13 = ((($3)) + 20|0);
 $14 = ((($3)) + 34|0);
 $15 = ((($4)) + 28|0);
 $16 = ((($4)) + 32|0);
 $17 = ((($4)) + 29|0);
 $18 = ((($4)) + 33|0);
 $19 = ((($4)) + 30|0);
 $20 = ((($4)) + 34|0);
 $21 = ((($4)) + 24|0);
 $$pre = HEAP8[$6>>0]|0;
 $$phi$trans$insert = $$pre&255;
 $$phi$trans$insert43 = (79212 + ($$phi$trans$insert<<2)|0);
 $$pre44 = HEAP32[$$phi$trans$insert43>>2]|0;
 $$pre45 = HEAP32[$7>>2]|0;
 $$pre46 = HEAP8[$8>>0]|0;
 $$pre47 = HEAP8[$9>>0]|0;
 $$phi$trans$insert48 = $$pre47&255;
 $$phi$trans$insert49 = (79212 + ($$phi$trans$insert48<<2)|0);
 $$pre50 = HEAP32[$$phi$trans$insert49>>2]|0;
 $$pre51 = HEAP32[$10>>2]|0;
 $$pre52 = HEAP8[$11>>0]|0;
 $$pre53 = HEAP8[$12>>0]|0;
 $$phi$trans$insert54 = $$pre53&255;
 $$phi$trans$insert55 = (79212 + ($$phi$trans$insert54<<2)|0);
 $$pre56 = HEAP32[$$phi$trans$insert55>>2]|0;
 $$pre57 = HEAP32[$13>>2]|0;
 $$pre58 = HEAP8[$14>>0]|0;
 $$pre59 = HEAP8[$15>>0]|0;
 $$pre60 = HEAP8[$16>>0]|0;
 $$pre61 = HEAP8[$17>>0]|0;
 $$pre62 = HEAP8[$18>>0]|0;
 $$pre63 = HEAP8[$19>>0]|0;
 $$pre64 = HEAP8[$20>>0]|0;
 $$pre65 = HEAP32[$21>>2]|0;
 $22 = $$pre46&255;
 $23 = $$pre52&255;
 $24 = $$pre58&255;
 $25 = $$pre59&255;
 $26 = $$pre60&255;
 $27 = $$pre61&255;
 $28 = $$pre62&255;
 $29 = $$pre63&255;
 $30 = $$pre64&255;
 $$03841 = 0;$$03940 = $0;$$042 = $1;
 while(1) {
  $31 = HEAP32[$$042>>2]|0;
  $32 = $$pre45 & $31;
  $33 = $32 >>> $22;
  $34 = (($$pre44) + ($33)|0);
  $35 = HEAP8[$34>>0]|0;
  $36 = $35&255;
  $37 = $$pre51 & $31;
  $38 = $37 >>> $23;
  $39 = (($$pre50) + ($38)|0);
  $40 = HEAP8[$39>>0]|0;
  $41 = $40&255;
  $42 = $$pre57 & $31;
  $43 = $42 >>> $24;
  $44 = (($$pre56) + ($43)|0);
  $45 = HEAP8[$44>>0]|0;
  $46 = $45&255;
  $47 = $36 >>> $25;
  $48 = $47 << $26;
  $49 = $41 >>> $27;
  $50 = $49 << $28;
  $51 = $50 | $48;
  $52 = $46 >>> $29;
  $53 = $52 << $30;
  $54 = $51 | $$pre65;
  $55 = $54 | $53;
  $56 = $55&65535;
  HEAP16[$$03940>>1] = $56;
  $57 = ((($$042)) + 4|0);
  $58 = ((($$03940)) + 2|0);
  $59 = (($$03841) + 1)|0;
  $exitcond = ($59|0)==($2|0);
  if ($exitcond) {
   break;
  } else {
   $$03841 = $59;$$03940 = $58;$$042 = $57;
  }
 }
 $60 = $2 << 1;
 return ($60|0);
}
function _SDL_RLEAlphaBlit($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$$i = 0, $$0 = 0, $$0$i = 0, $$0334 = 0, $$0335 = 0, $$0354 = 0, $$0356 = 0, $$0363453 = 0, $$0364452 = 0, $$0365 = 0, $$0366 = 0, $$0371 = 0, $$0376 = 0, $$0377443 = 0, $$0378442 = 0, $$0379 = 0, $$0380 = 0, $$0385446 = 0, $$0386445 = 0, $$0403$i = 0;
 var $$0409$i = 0, $$0410$i = 0, $$0416497$i = 0, $$0437$i = 0, $$0442494$i = 0, $$0443$i = 0, $$0444$i = 0, $$0445$i = 0, $$0453495$i = 0, $$1 = 0, $$1$i = 0, $$11$i = 0, $$12$i = 0, $$12$ph = 0, $$13 = 0, $$1355 = 0, $$1357 = 0, $$1367 = 0, $$1372 = 0, $$1381 = 0;
 var $$14 = 0, $$14$i = 0, $$1411$i = 0, $$1418$i = 0, $$1429$i = 0, $$1433$i = 0, $$1436$i = 0, $$1438$i = 0, $$1446$i = 0, $$1452$i = 0, $$1456$i = 0, $$15 = 0, $$15$i = 0, $$16$i = 0, $$17 = 0, $$18$i = 0, $$18444 = 0, $$19 = 0, $$19$i = 0, $$2 = 0;
 var $$2$i = 0, $$21 = 0, $$22 = 0, $$23 = 0, $$2337 = 0, $$2405$i = 0, $$25 = 0, $$26447 = 0, $$27 = 0, $$29 = 0, $$30 = 0, $$31 = 0, $$33 = 0, $$3359 = 0, $$3369 = 0, $$3374 = 0, $$3383 = 0, $$3413$i = 0, $$3440$i = 0, $$34454 = 0;
 var $$3448$i = 0, $$35 = 0, $$4 = 0, $$4$i = 0, $$4339 = 0, $$4360 = 0, $$4370 = 0, $$4375 = 0, $$4384 = 0, $$4407$i = 0, $$4414$i = 0, $$4441$i = 0, $$4449$i = 0, $$457$i = 0, $$458$i = 0, $$459$i = 0, $$460$i = 0, $$461$i = 0, $$462$i = 0, $$463$i = 0;
 var $$464$i = 0, $$465$i = 0, $$466$i = 0, $$467$i = 0, $$5 = 0, $$5$i = 0, $$5361 = 0, $$6 = 0, $$7 = 0, $$7$i = 0, $$8$i = 0, $$9$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0;
 var $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0;
 var $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0;
 var $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0;
 var $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0;
 var $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0;
 var $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0;
 var $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0;
 var $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0;
 var $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0;
 var $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0;
 var $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0;
 var $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0;
 var $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0;
 var $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0;
 var $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0;
 var $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0;
 var $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0;
 var $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0;
 var $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0;
 var $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0;
 var $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $exitcond479 = 0, $exitcond482 = 0, $scevgep476 = 0, $scevgep478 = 0, $scevgep481 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ((($0)) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($2)) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$2>>2]|0;
 $9 = $8 & 2;
 $10 = ($9|0)==(0);
 if (!($10)) {
  $11 = (_SDL_LockSurface($2)|0);
  $12 = ($11|0)<(0);
  if ($12) {
   $$0 = -1;
   return ($$0|0);
  }
 }
 $13 = HEAP32[$3>>2]|0;
 $14 = ((($3)) + 4|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ((($2)) + 20|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ((($2)) + 16|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = Math_imul($19, $15)|0;
 $21 = (($17) + ($20)|0);
 $22 = ((($7)) + 9|0);
 $23 = HEAP8[$22>>0]|0;
 $24 = $23&255;
 $25 = Math_imul($24, $13)|0;
 $26 = (($21) + ($25)|0);
 $27 = ((($0)) + 52|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = ((($28)) + 12|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ((($30)) + 28|0);
 $32 = ((($1)) + 4|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ($33|0)==(0);
 L5: do {
  if ($34) {
   $$12$ph = $31;
   label = 20;
  } else {
   $35 = ($23<<24>>24)==(2);
   if ($35) {
    $$0334 = $31;$$0354 = $33;
   } else {
    $65 = $33 << 1;
    $$1355 = $65;$$5 = $31;
    while(1) {
     $$4360 = 0;$$6 = $$5;
     while(1) {
      $66 = HEAP16[$$6>>1]|0;
      $67 = $66&65535;
      $68 = (($67) + ($$4360))|0;
      $69 = ((($$6)) + 2|0);
      $70 = HEAP16[$69>>1]|0;
      $71 = $70&65535;
      $72 = ((($$6)) + 4|0);
      $73 = ($70<<16>>16)==(0);
      if ($73) {
       $77 = ($68|0)==(0);
       if ($77) {
        break L5;
       } else {
        $$5361 = $68;$$7 = $72;
       }
      } else {
       $74 = $71 << 2;
       $75 = (($72) + ($74)|0);
       $76 = (($68) + ($71))|0;
       $$5361 = $76;$$7 = $75;
      }
      $78 = ($$5361|0)<($5|0);
      if ($78) {
       $$4360 = $$5361;$$6 = $$7;
      } else {
       break;
      }
     }
     $79 = (($$1355) + -1)|0;
     $80 = ($79|0)==(0);
     if ($80) {
      $$12$ph = $$7;
      label = 20;
      break L5;
     } else {
      $$1355 = $79;$$5 = $$7;
     }
    }
   }
   while(1) {
    $$0356 = 0;$$1 = $$0334;
    while(1) {
     $36 = HEAP8[$$1>>0]|0;
     $37 = $36&255;
     $38 = (($37) + ($$0356))|0;
     $39 = ((($$1)) + 1|0);
     $40 = HEAP8[$39>>0]|0;
     $41 = $40&255;
     $42 = ((($$1)) + 2|0);
     $43 = ($40<<24>>24)==(0);
     if ($43) {
      $47 = ($38|0)==(0);
      if ($47) {
       break L5;
      } else {
       $$1357 = $38;$$2 = $42;
      }
     } else {
      $44 = $41 << 1;
      $45 = (($42) + ($44)|0);
      $46 = (($38) + ($41))|0;
      $$1357 = $46;$$2 = $45;
     }
     $48 = ($$1357|0)<($5|0);
     if ($48) {
      $$0356 = $$1357;$$1 = $$2;
     } else {
      break;
     }
    }
    $49 = $$2;
    $50 = $49 & 2;
    $51 = (($$2) + ($50)|0);
    $$3359 = 0;$$4 = $51;
    while(1) {
     $52 = HEAP16[$$4>>1]|0;
     $53 = $52&65535;
     $54 = (($53) + ($$3359))|0;
     $55 = ((($$4)) + 2|0);
     $56 = HEAP16[$55>>1]|0;
     $57 = $56&65535;
     $58 = $57 << 2;
     $59 = (($58) + 4)|0;
     $60 = (($$4) + ($59)|0);
     $61 = (($54) + ($57))|0;
     $62 = ($61|0)<($5|0);
     if ($62) {
      $$3359 = $61;$$4 = $60;
     } else {
      break;
     }
    }
    $63 = (($$0354) + -1)|0;
    $64 = ($63|0)==(0);
    if ($64) {
     $$12$ph = $60;
     label = 20;
     break;
    } else {
     $$0334 = $60;$$0354 = $63;
    }
   }
  }
 } while(0);
 L30: do {
  if ((label|0) == 20) {
   $81 = HEAP32[$1>>2]|0;
   $82 = ($81|0)==(0);
   if ($82) {
    $83 = ((($1)) + 8|0);
    $84 = HEAP32[$83>>2]|0;
    $85 = HEAP32[$4>>2]|0;
    $86 = ($84|0)==($85|0);
    if ($86) {
     switch ($23<<24>>24) {
     case 2:  {
      break;
     }
     case 4:  {
      $465 = ((($1)) + 12|0);
      $466 = HEAP32[$465>>2]|0;
      $$0376 = $466;$$29 = $$12$ph;$$4339 = $26;
      while(1) {
       $$0371 = 0;$$30 = $$29;
       while(1) {
        $467 = HEAP16[$$30>>1]|0;
        $468 = $467&65535;
        $469 = (($468) + ($$0371))|0;
        $470 = ((($$30)) + 2|0);
        $471 = HEAP16[$470>>1]|0;
        $472 = $471&65535;
        $473 = ((($$30)) + 4|0);
        $474 = ($471<<16>>16)==(0);
        if ($474) {
         $480 = ($469|0)==(0);
         if ($480) {
          break L30;
         } else {
          $$1372 = $469;$$31 = $473;
         }
        } else {
         $475 = $469 << 2;
         $476 = (($$4339) + ($475)|0);
         $477 = $472 << 2;
         (_SDL_memcpy($476,$473,$477)|0);
         $478 = (($473) + ($477)|0);
         $479 = (($469) + ($472))|0;
         $$1372 = $479;$$31 = $478;
        }
        $481 = ($$1372|0)<($5|0);
        if ($481) {
         $$0371 = $$1372;$$30 = $$31;
        } else {
         break;
        }
       }
       $$33 = $$31;$$3374 = 0;
       while(1) {
        $482 = HEAP16[$$33>>1]|0;
        $483 = $482&65535;
        $484 = (($483) + ($$3374))|0;
        $485 = ((($$33)) + 2|0);
        $486 = HEAP16[$485>>1]|0;
        $487 = $486&65535;
        $488 = ((($$33)) + 4|0);
        $489 = ($486<<16>>16)==(0);
        if ($489) {
         $$35 = $488;$$4375 = $484;
        } else {
         $490 = (($$4339) + ($484<<2)|0);
         $491 = $487 << 2;
         $$0363453 = 0;$$0364452 = $490;$$34454 = $488;
         while(1) {
          $492 = HEAP32[$$34454>>2]|0;
          $493 = HEAP32[$$0364452>>2]|0;
          $494 = $492 >>> 24;
          $495 = $492 & 16711935;
          $496 = $493 & 16711935;
          $497 = (($495) - ($496))|0;
          $498 = Math_imul($497, $494)|0;
          $499 = $498 >>> 8;
          $500 = (($499) + ($496))|0;
          $501 = $500 & 16711935;
          $502 = $492 & 65280;
          $503 = $493 & 65280;
          $504 = (($502) - ($503))|0;
          $505 = Math_imul($504, $494)|0;
          $506 = $505 >>> 8;
          $507 = (($506) + ($503))|0;
          $508 = $507 & 65280;
          $509 = $508 | $501;
          $510 = $509 | -16777216;
          HEAP32[$$0364452>>2] = $510;
          $511 = ((($$34454)) + 4|0);
          $512 = ((($$0364452)) + 4|0);
          $513 = (($$0363453) + 1)|0;
          $exitcond482 = ($513|0)==($487|0);
          if ($exitcond482) {
           break;
          } else {
           $$0363453 = $513;$$0364452 = $512;$$34454 = $511;
          }
         }
         $scevgep481 = (($488) + ($491)|0);
         $514 = (($484) + ($487))|0;
         $$35 = $scevgep481;$$4375 = $514;
        }
        $515 = ($$4375|0)<($5|0);
        if ($515) {
         $$33 = $$35;$$3374 = $$4375;
        } else {
         break;
        }
       }
       $516 = HEAP32[$18>>2]|0;
       $517 = (($$4339) + ($516)|0);
       $518 = (($$0376) + -1)|0;
       $519 = ($518|0)==(0);
       if ($519) {
        break L30;
       } else {
        $$0376 = $518;$$29 = $$35;$$4339 = $517;
       }
      }
      break;
     }
     default: {
      break L30;
     }
     }
     $344 = ((($7)) + 16|0);
     $345 = HEAP32[$344>>2]|0;
     $346 = ($345|0)==(2016);
     if (!($346)) {
      $347 = ((($7)) + 12|0);
      $348 = HEAP32[$347>>2]|0;
      $349 = ($348|0)==(2016);
      if (!($349)) {
       $350 = ((($7)) + 20|0);
       $351 = HEAP32[$350>>2]|0;
       $352 = ($351|0)==(2016);
       if (!($352)) {
        $409 = ((($1)) + 12|0);
        $410 = HEAP32[$409>>2]|0;
        $$0379 = $410;$$21 = $$12$ph;$$2337 = $26;
        while(1) {
         $$0380 = 0;$$22 = $$21;
         while(1) {
          $411 = HEAP8[$$22>>0]|0;
          $412 = $411&255;
          $413 = (($412) + ($$0380))|0;
          $414 = ((($$22)) + 1|0);
          $415 = HEAP8[$414>>0]|0;
          $416 = $415&255;
          $417 = ((($$22)) + 2|0);
          $418 = ($415<<24>>24)==(0);
          if ($418) {
           $424 = ($413|0)==(0);
           if ($424) {
            break L30;
           } else {
            $$1381 = $413;$$23 = $417;
           }
          } else {
           $419 = $413 << 1;
           $420 = (($$2337) + ($419)|0);
           $421 = $416 << 1;
           (_SDL_memcpy($420,$417,$421)|0);
           $422 = (($417) + ($421)|0);
           $423 = (($413) + ($416))|0;
           $$1381 = $423;$$23 = $422;
          }
          $425 = ($$1381|0)<($5|0);
          if ($425) {
           $$0380 = $$1381;$$22 = $$23;
          } else {
           break;
          }
         }
         $426 = $$23;
         $427 = $426 & 2;
         $428 = (($$23) + ($427)|0);
         $$25 = $428;$$3383 = 0;
         while(1) {
          $429 = HEAP16[$$25>>1]|0;
          $430 = $429&65535;
          $431 = (($430) + ($$3383))|0;
          $432 = ((($$25)) + 2|0);
          $433 = HEAP16[$432>>1]|0;
          $434 = $433&65535;
          $435 = ((($$25)) + 4|0);
          $436 = ($433<<16>>16)==(0);
          if ($436) {
           $$27 = $435;$$4384 = $431;
          } else {
           $437 = (($$2337) + ($431<<1)|0);
           $438 = $434 << 2;
           $$0385446 = 0;$$0386445 = $437;$$26447 = $435;
           while(1) {
            $439 = HEAP32[$$26447>>2]|0;
            $440 = HEAP16[$$0386445>>1]|0;
            $441 = $440&65535;
            $442 = $439 >>> 5;
            $443 = $442 & 31;
            $444 = $439 & 65043487;
            $445 = $441 << 16;
            $446 = $445 | $441;
            $447 = $446 & 65043487;
            $448 = (($444) - ($447))|0;
            $449 = Math_imul($448, $443)|0;
            $450 = $449 >>> 5;
            $451 = (($450) + ($447))|0;
            $452 = $451 & 65043487;
            $453 = $452 >>> 16;
            $454 = $453 | $452;
            $455 = $454&65535;
            HEAP16[$$0386445>>1] = $455;
            $456 = ((($$26447)) + 4|0);
            $457 = ((($$0386445)) + 2|0);
            $458 = (($$0385446) + 1)|0;
            $exitcond479 = ($458|0)==($434|0);
            if ($exitcond479) {
             break;
            } else {
             $$0385446 = $458;$$0386445 = $457;$$26447 = $456;
            }
           }
           $scevgep478 = (($435) + ($438)|0);
           $459 = (($431) + ($434))|0;
           $$27 = $scevgep478;$$4384 = $459;
          }
          $460 = ($$4384|0)<($5|0);
          if ($460) {
           $$25 = $$27;$$3383 = $$4384;
          } else {
           break;
          }
         }
         $461 = HEAP32[$18>>2]|0;
         $462 = (($$2337) + ($461)|0);
         $463 = (($$0379) + -1)|0;
         $464 = ($463|0)==(0);
         if ($464) {
          break L30;
         } else {
          $$0379 = $463;$$21 = $$27;$$2337 = $462;
         }
        }
       }
      }
     }
     $353 = ((($1)) + 12|0);
     $354 = HEAP32[$353>>2]|0;
     $$0335 = $26;$$0365 = $354;$$13 = $$12$ph;
     while(1) {
      $$0366 = 0;$$14 = $$13;
      while(1) {
       $355 = HEAP8[$$14>>0]|0;
       $356 = $355&255;
       $357 = (($356) + ($$0366))|0;
       $358 = ((($$14)) + 1|0);
       $359 = HEAP8[$358>>0]|0;
       $360 = $359&255;
       $361 = ((($$14)) + 2|0);
       $362 = ($359<<24>>24)==(0);
       if ($362) {
        $368 = ($357|0)==(0);
        if ($368) {
         break L30;
        } else {
         $$1367 = $357;$$15 = $361;
        }
       } else {
        $363 = $357 << 1;
        $364 = (($$0335) + ($363)|0);
        $365 = $360 << 1;
        (_SDL_memcpy($364,$361,$365)|0);
        $366 = (($361) + ($365)|0);
        $367 = (($357) + ($360))|0;
        $$1367 = $367;$$15 = $366;
       }
       $369 = ($$1367|0)<($5|0);
       if ($369) {
        $$0366 = $$1367;$$14 = $$15;
       } else {
        break;
       }
      }
      $370 = $$15;
      $371 = $370 & 2;
      $372 = (($$15) + ($371)|0);
      $$17 = $372;$$3369 = 0;
      while(1) {
       $373 = HEAP16[$$17>>1]|0;
       $374 = $373&65535;
       $375 = (($374) + ($$3369))|0;
       $376 = ((($$17)) + 2|0);
       $377 = HEAP16[$376>>1]|0;
       $378 = $377&65535;
       $379 = ((($$17)) + 4|0);
       $380 = ($377<<16>>16)==(0);
       if ($380) {
        $$19 = $379;$$4370 = $375;
       } else {
        $381 = (($$0335) + ($375<<1)|0);
        $382 = $378 << 2;
        $$0377443 = $381;$$0378442 = 0;$$18444 = $379;
        while(1) {
         $383 = HEAP32[$$18444>>2]|0;
         $384 = HEAP16[$$0377443>>1]|0;
         $385 = $384&65535;
         $386 = $383 >>> 5;
         $387 = $386 & 31;
         $388 = $383 & 132184095;
         $389 = $385 << 16;
         $390 = $389 | $385;
         $391 = $390 & 132184095;
         $392 = (($388) - ($391))|0;
         $393 = Math_imul($392, $387)|0;
         $394 = $393 >>> 5;
         $395 = (($394) + ($391))|0;
         $396 = $395 & 132184095;
         $397 = $396 >>> 16;
         $398 = $397 | $396;
         $399 = $398&65535;
         HEAP16[$$0377443>>1] = $399;
         $400 = ((($$18444)) + 4|0);
         $401 = ((($$0377443)) + 2|0);
         $402 = (($$0378442) + 1)|0;
         $exitcond = ($402|0)==($378|0);
         if ($exitcond) {
          break;
         } else {
          $$0377443 = $401;$$0378442 = $402;$$18444 = $400;
         }
        }
        $scevgep476 = (($379) + ($382)|0);
        $403 = (($375) + ($378))|0;
        $$19 = $scevgep476;$$4370 = $403;
       }
       $404 = ($$4370|0)<($5|0);
       if ($404) {
        $$17 = $$19;$$3369 = $$4370;
       } else {
        break;
       }
      }
      $405 = HEAP32[$18>>2]|0;
      $406 = (($$0335) + ($405)|0);
      $407 = (($$0365) + -1)|0;
      $408 = ($407|0)==(0);
      if ($408) {
       break L30;
      } else {
       $$0335 = $406;$$0365 = $407;$$13 = $$19;
      }
     }
    }
   }
   $87 = HEAP32[$6>>2]|0;
   $88 = ((($87)) + 9|0);
   $89 = HEAP8[$88>>0]|0;
   switch ($89<<24>>24) {
   case 2:  {
    break;
   }
   case 4:  {
    $263 = ((($1)) + 12|0);
    $264 = HEAP32[$263>>2]|0;
    $265 = ((($1)) + 8|0);
    $266 = HEAP32[$265>>2]|0;
    $267 = (($266) + ($81))|0;
    $268 = $81 << 2;
    $269 = (0 - ($268))|0;
    $270 = (($26) + ($269)|0);
    $$0444$i = $264;$$14$i = $$12$ph;$$4407$i = $270;
    while(1) {
     $$0437$i = 0;$$15$i = $$14$i;
     while(1) {
      $271 = HEAP16[$$15$i>>1]|0;
      $272 = $271&65535;
      $273 = (($272) + ($$0437$i))|0;
      $274 = ((($$15$i)) + 2|0);
      $275 = HEAP16[$274>>1]|0;
      $276 = $275&65535;
      $277 = ((($$15$i)) + 4|0);
      $278 = ($275<<16>>16)==(0);
      if ($278) {
       $294 = ($273|0)==(0);
       if ($294) {
        break L30;
       } else {
        $$1438$i = $273;$$16$i = $277;
       }
      } else {
       $279 = (($81) - ($273))|0;
       $280 = ($279|0)>(0);
       $$464$i = $280 ? $81 : $273;
       $281 = $280 ? $279 : 0;
       $$465$i = (($276) - ($281))|0;
       $282 = (($267) - ($$464$i))|0;
       $283 = ($$465$i|0)>($282|0);
       $$1433$i = $283 ? $282 : $$465$i;
       $284 = ($$1433$i|0)>(0);
       if ($284) {
        $285 = $$464$i << 2;
        $286 = (($$4407$i) + ($285)|0);
        $287 = (($$464$i) - ($273))|0;
        $288 = $287 << 2;
        $289 = (($277) + ($288)|0);
        $290 = $$1433$i << 2;
        (_SDL_memcpy($286,$289,$290)|0);
       }
       $291 = $276 << 2;
       $292 = (($277) + ($291)|0);
       $293 = (($273) + ($276))|0;
       $$1438$i = $293;$$16$i = $292;
      }
      $295 = ($$1438$i|0)<($5|0);
      if ($295) {
       $$0437$i = $$1438$i;$$15$i = $$16$i;
      } else {
       break;
      }
     }
     $$18$i = $$16$i;$$3440$i = 0;
     while(1) {
      $296 = HEAP16[$$18$i>>1]|0;
      $297 = $296&65535;
      $298 = (($297) + ($$3440$i))|0;
      $299 = ((($$18$i)) + 2|0);
      $300 = HEAP16[$299>>1]|0;
      $301 = $300&65535;
      $302 = ((($$18$i)) + 4|0);
      $303 = ($300<<16>>16)==(0);
      if ($303) {
       $$19$i = $302;$$4441$i = $298;
      } else {
       $304 = (($81) - ($298))|0;
       $305 = ($304|0)>(0);
       $$466$i = $305 ? $81 : $298;
       $306 = $305 ? $304 : 0;
       $$467$i = (($301) - ($306))|0;
       $307 = (($267) - ($$466$i))|0;
       $308 = ($$467$i|0)>($307|0);
       $$1429$i = $308 ? $307 : $$467$i;
       $309 = ($$1429$i|0)>(0);
       if ($309) {
        $310 = (($$4407$i) + ($$466$i<<2)|0);
        $311 = (($$466$i) - ($298))|0;
        $312 = (($302) + ($311<<2)|0);
        $$0416497$i = 0;
        while(1) {
         $313 = (($312) + ($$0416497$i<<2)|0);
         $314 = HEAP32[$313>>2]|0;
         $315 = (($310) + ($$0416497$i<<2)|0);
         $316 = HEAP32[$315>>2]|0;
         $317 = $314 >>> 24;
         $318 = $314 & 16711935;
         $319 = $316 & 16711935;
         $320 = (($318) - ($319))|0;
         $321 = Math_imul($320, $317)|0;
         $322 = $321 >>> 8;
         $323 = (($322) + ($319))|0;
         $324 = $323 & 16711935;
         $325 = $314 & 65280;
         $326 = $316 & 65280;
         $327 = (($325) - ($326))|0;
         $328 = Math_imul($327, $317)|0;
         $329 = $328 >>> 8;
         $330 = (($329) + ($326))|0;
         $331 = $330 & 65280;
         $332 = $324 | $331;
         $333 = $332 | -16777216;
         HEAP32[$315>>2] = $333;
         $334 = (($$0416497$i) + 1)|0;
         $335 = ($334|0)<($$1429$i|0);
         if ($335) {
          $$0416497$i = $334;
         } else {
          break;
         }
        }
       }
       $336 = $301 << 2;
       $337 = (($302) + ($336)|0);
       $338 = (($298) + ($301))|0;
       $$19$i = $337;$$4441$i = $338;
      }
      $339 = ($$4441$i|0)<($5|0);
      if ($339) {
       $$18$i = $$19$i;$$3440$i = $$4441$i;
      } else {
       break;
      }
     }
     $340 = HEAP32[$18>>2]|0;
     $341 = (($$4407$i) + ($340)|0);
     $342 = (($$0444$i) + -1)|0;
     $343 = ($342|0)==(0);
     if ($343) {
      break L30;
     } else {
      $$0444$i = $342;$$14$i = $$19$i;$$4407$i = $341;
     }
    }
    break;
   }
   default: {
    break L30;
   }
   }
   $90 = ((($87)) + 16|0);
   $91 = HEAP32[$90>>2]|0;
   $92 = ($91|0)==(2016);
   if (!($92)) {
    $93 = ((($87)) + 12|0);
    $94 = HEAP32[$93>>2]|0;
    $95 = ($94|0)==(2016);
    if (!($95)) {
     $96 = ((($87)) + 20|0);
     $97 = HEAP32[$96>>2]|0;
     $98 = ($97|0)==(2016);
     if (!($98)) {
      $181 = ((($1)) + 12|0);
      $182 = HEAP32[$181>>2]|0;
      $183 = ((($1)) + 8|0);
      $184 = HEAP32[$183>>2]|0;
      $185 = (($184) + ($81))|0;
      $186 = $81 << 1;
      $187 = (0 - ($186))|0;
      $188 = (($26) + ($187)|0);
      $$0443$i = $182;$$2405$i = $188;$$7$i = $$12$ph;
      while(1) {
       $$0445$i = 0;$$8$i = $$7$i;
       while(1) {
        $189 = HEAP8[$$8$i>>0]|0;
        $190 = $189&255;
        $191 = (($190) + ($$0445$i))|0;
        $192 = ((($$8$i)) + 1|0);
        $193 = HEAP8[$192>>0]|0;
        $194 = $193&255;
        $195 = ((($$8$i)) + 2|0);
        $196 = ($193<<24>>24)==(0);
        if ($196) {
         $212 = ($191|0)==(0);
         if ($212) {
          break L30;
         } else {
          $$1446$i = $191;$$9$i = $195;
         }
        } else {
         $197 = (($81) - ($191))|0;
         $198 = ($197|0)>(0);
         $199 = $198 ? $197 : 0;
         $$460$i = (($194) - ($199))|0;
         $$461$i = $198 ? $81 : $191;
         $200 = (($185) - ($$461$i))|0;
         $201 = ($$460$i|0)>($200|0);
         $$1452$i = $201 ? $200 : $$460$i;
         $202 = ($$1452$i|0)>(0);
         if ($202) {
          $203 = $$461$i << 1;
          $204 = (($$2405$i) + ($203)|0);
          $205 = (($$461$i) - ($191))|0;
          $206 = $205 << 1;
          $207 = (($195) + ($206)|0);
          $208 = $$1452$i << 1;
          (_SDL_memcpy($204,$207,$208)|0);
         }
         $209 = $194 << 1;
         $210 = (($195) + ($209)|0);
         $211 = (($191) + ($194))|0;
         $$1446$i = $211;$$9$i = $210;
        }
        $213 = ($$1446$i|0)<($5|0);
        if ($213) {
         $$0445$i = $$1446$i;$$8$i = $$9$i;
        } else {
         break;
        }
       }
       $214 = $$9$i;
       $215 = $214 & 2;
       $216 = (($$9$i) + ($215)|0);
       $$11$i = $216;$$3448$i = 0;
       while(1) {
        $217 = HEAP16[$$11$i>>1]|0;
        $218 = $217&65535;
        $219 = (($218) + ($$3448$i))|0;
        $220 = ((($$11$i)) + 2|0);
        $221 = HEAP16[$220>>1]|0;
        $222 = $221&65535;
        $223 = ((($$11$i)) + 4|0);
        $224 = ($221<<16>>16)==(0);
        if ($224) {
         $$12$i = $223;$$4449$i = $219;
        } else {
         $225 = (($81) - ($219))|0;
         $226 = ($225|0)>(0);
         $227 = $226 ? $225 : 0;
         $$462$i = (($222) - ($227))|0;
         $$463$i = $226 ? $81 : $219;
         $228 = (($185) - ($$463$i))|0;
         $229 = ($$462$i|0)>($228|0);
         $$1456$i = $229 ? $228 : $$462$i;
         $230 = ($$1456$i|0)>(0);
         if ($230) {
          $231 = (($$2405$i) + ($$463$i<<1)|0);
          $232 = (($$463$i) - ($219))|0;
          $233 = (($223) + ($232<<2)|0);
          $$0453495$i = 0;
          while(1) {
           $234 = (($233) + ($$0453495$i<<2)|0);
           $235 = HEAP32[$234>>2]|0;
           $236 = (($231) + ($$0453495$i<<1)|0);
           $237 = HEAP16[$236>>1]|0;
           $238 = $237&65535;
           $239 = $235 >>> 5;
           $240 = $239 & 31;
           $241 = $235 & 65043487;
           $242 = $238 << 16;
           $243 = $242 | $238;
           $244 = $243 & 65043487;
           $245 = (($241) - ($244))|0;
           $246 = Math_imul($245, $240)|0;
           $247 = $246 >>> 5;
           $248 = (($247) + ($244))|0;
           $249 = $248 & 65043487;
           $250 = $249 >>> 16;
           $251 = $250 | $249;
           $252 = $251&65535;
           HEAP16[$236>>1] = $252;
           $253 = (($$0453495$i) + 1)|0;
           $254 = ($253|0)<($$1456$i|0);
           if ($254) {
            $$0453495$i = $253;
           } else {
            break;
           }
          }
         }
         $255 = $222 << 2;
         $256 = (($223) + ($255)|0);
         $257 = (($219) + ($222))|0;
         $$12$i = $256;$$4449$i = $257;
        }
        $258 = ($$4449$i|0)<($5|0);
        if ($258) {
         $$11$i = $$12$i;$$3448$i = $$4449$i;
        } else {
         break;
        }
       }
       $259 = HEAP32[$18>>2]|0;
       $260 = (($$2405$i) + ($259)|0);
       $261 = (($$0443$i) + -1)|0;
       $262 = ($261|0)==(0);
       if ($262) {
        break L30;
       } else {
        $$0443$i = $261;$$2405$i = $260;$$7$i = $$12$i;
       }
      }
     }
    }
   }
   $99 = ((($1)) + 12|0);
   $100 = HEAP32[$99>>2]|0;
   $101 = ((($1)) + 8|0);
   $102 = HEAP32[$101>>2]|0;
   $103 = (($102) + ($81))|0;
   $104 = $81 << 1;
   $105 = (0 - ($104))|0;
   $106 = (($26) + ($105)|0);
   $$0$i = $$12$ph;$$0403$i = $106;$$0409$i = $100;
   while(1) {
    $$0410$i = 0;$$1$i = $$0$i;
    while(1) {
     $107 = HEAP8[$$1$i>>0]|0;
     $108 = $107&255;
     $109 = (($108) + ($$0410$i))|0;
     $110 = ((($$1$i)) + 1|0);
     $111 = HEAP8[$110>>0]|0;
     $112 = $111&255;
     $113 = ((($$1$i)) + 2|0);
     $114 = ($111<<24>>24)==(0);
     if ($114) {
      $130 = ($109|0)==(0);
      if ($130) {
       break L30;
      } else {
       $$1411$i = $109;$$2$i = $113;
      }
     } else {
      $115 = (($81) - ($109))|0;
      $116 = ($115|0)>(0);
      $117 = $116 ? $115 : 0;
      $$$i = (($112) - ($117))|0;
      $$457$i = $116 ? $81 : $109;
      $118 = (($103) - ($$457$i))|0;
      $119 = ($$$i|0)>($118|0);
      $$1418$i = $119 ? $118 : $$$i;
      $120 = ($$1418$i|0)>(0);
      if ($120) {
       $121 = $$457$i << 1;
       $122 = (($$0403$i) + ($121)|0);
       $123 = (($$457$i) - ($109))|0;
       $124 = $123 << 1;
       $125 = (($113) + ($124)|0);
       $126 = $$1418$i << 1;
       (_SDL_memcpy($122,$125,$126)|0);
      }
      $127 = $112 << 1;
      $128 = (($113) + ($127)|0);
      $129 = (($109) + ($112))|0;
      $$1411$i = $129;$$2$i = $128;
     }
     $131 = ($$1411$i|0)<($5|0);
     if ($131) {
      $$0410$i = $$1411$i;$$1$i = $$2$i;
     } else {
      break;
     }
    }
    $132 = $$2$i;
    $133 = $132 & 2;
    $134 = (($$2$i) + ($133)|0);
    $$3413$i = 0;$$4$i = $134;
    while(1) {
     $135 = HEAP16[$$4$i>>1]|0;
     $136 = $135&65535;
     $137 = (($136) + ($$3413$i))|0;
     $138 = ((($$4$i)) + 2|0);
     $139 = HEAP16[$138>>1]|0;
     $140 = $139&65535;
     $141 = ((($$4$i)) + 4|0);
     $142 = ($139<<16>>16)==(0);
     if ($142) {
      $$4414$i = $137;$$5$i = $141;
     } else {
      $143 = (($81) - ($137))|0;
      $144 = ($143|0)>(0);
      $145 = $144 ? $143 : 0;
      $$458$i = (($140) - ($145))|0;
      $$459$i = $144 ? $81 : $137;
      $146 = (($103) - ($$459$i))|0;
      $147 = ($$458$i|0)>($146|0);
      $$1436$i = $147 ? $146 : $$458$i;
      $148 = ($$1436$i|0)>(0);
      if ($148) {
       $149 = (($$0403$i) + ($$459$i<<1)|0);
       $150 = (($$459$i) - ($137))|0;
       $151 = (($141) + ($150<<2)|0);
       $$0442494$i = 0;
       while(1) {
        $152 = (($151) + ($$0442494$i<<2)|0);
        $153 = HEAP32[$152>>2]|0;
        $154 = (($149) + ($$0442494$i<<1)|0);
        $155 = HEAP16[$154>>1]|0;
        $156 = $155&65535;
        $157 = $153 >>> 5;
        $158 = $157 & 31;
        $159 = $153 & 132184095;
        $160 = $156 << 16;
        $161 = $160 | $156;
        $162 = $161 & 132184095;
        $163 = (($159) - ($162))|0;
        $164 = Math_imul($163, $158)|0;
        $165 = $164 >>> 5;
        $166 = (($165) + ($162))|0;
        $167 = $166 & 132184095;
        $168 = $167 >>> 16;
        $169 = $168 | $167;
        $170 = $169&65535;
        HEAP16[$154>>1] = $170;
        $171 = (($$0442494$i) + 1)|0;
        $172 = ($171|0)<($$1436$i|0);
        if ($172) {
         $$0442494$i = $171;
        } else {
         break;
        }
       }
      }
      $173 = $140 << 2;
      $174 = (($141) + ($173)|0);
      $175 = (($137) + ($140))|0;
      $$4414$i = $175;$$5$i = $174;
     }
     $176 = ($$4414$i|0)<($5|0);
     if ($176) {
      $$3413$i = $$4414$i;$$4$i = $$5$i;
     } else {
      break;
     }
    }
    $177 = HEAP32[$18>>2]|0;
    $178 = (($$0403$i) + ($177)|0);
    $179 = (($$0409$i) + -1)|0;
    $180 = ($179|0)==(0);
    if ($180) {
     break;
    } else {
     $$0$i = $$5$i;$$0403$i = $178;$$0409$i = $179;
    }
   }
  }
 } while(0);
 $520 = HEAP32[$2>>2]|0;
 $521 = $520 & 2;
 $522 = ($521|0)==(0);
 if ($522) {
  $$0 = 0;
  return ($$0|0);
 }
 _SDL_UnlockSurface($2);
 $$0 = 0;
 return ($$0|0);
}
function _SDL_RLEBlit($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$$01326$i = 0, $$$01364$i = 0, $$$01368$i = 0, $$$01385$i = 0, $$$01397$i = 0, $$$01401$i = 0, $$$01421$i = 0, $$$01423$i = 0, $$$01447$i = 0, $$$01462$i = 0, $$$01466$i = 0, $$$01489$i = 0, $$$01497$i = 0, $$0 = 0, $$0$i = 0, $$0$ph$i = 0, $$01016 = 0, $$01028 = 0, $$01044$ph = 0, $$01047 = 0;
 var $$010511305 = 0, $$010521304 = 0, $$010531303 = 0, $$01054$ph = 0, $$01057 = 0, $$01061$ph = 0, $$01064 = 0, $$01068$ph = 0, $$01071 = 0, $$01075$ph = 0, $$010781299 = 0, $$010791298 = 0, $$010801297 = 0, $$01081 = 0, $$01085 = 0, $$01089$ph = 0, $$01092$ph = 0, $$01095 = 0, $$010991296 = 0, $$011001295 = 0;
 var $$011011294 = 0, $$011021317 = 0, $$01104 = 0, $$01108$ph = 0, $$011111316 = 0, $$011131315 = 0, $$01115$ph = 0, $$01118 = 0, $$011221328 = 0, $$011231327 = 0, $$011241326 = 0, $$01125$ph = 0, $$011281352 = 0, $$011291351 = 0, $$011301350 = 0, $$01131 = 0, $$01135 = 0, $$01139$ph = 0, $$011421334 = 0, $$011441333 = 0;
 var $$011461332 = 0, $$01148$ph = 0, $$01151 = 0, $$011551346 = 0, $$011561345 = 0, $$011571344 = 0, $$011581311 = 0, $$011591310 = 0, $$011601309 = 0, $$01161$ph = 0, $$01164 = 0, $$01279$ph$i = 0, $$01318$ph$i = 0, $$01321$i = 0, $$01325$i = 0, $$01326$i = 0, $$01328$i = 0, $$01354$ph$i = 0, $$013571631$i = 0, $$013581630$i = 0;
 var $$013591629$i = 0, $$01360$i = 0, $$01364$i = 0, $$01366$i = 0, $$01367$i = 0, $$01368$i = 0, $$01370$ph$i = 0, $$01373$i = 0, $$01377$ph$i = 0, $$01380$i = 0, $$01384$i = 0, $$01385$i = 0, $$01387$ph$i = 0, $$013901627$i = 0, $$013911626$i = 0, $$013921625$i = 0, $$01393$i = 0, $$01397$i = 0, $$01399$i = 0, $$01400$i = 0;
 var $$01401$i = 0, $$01403$ph$i = 0, $$01406$i = 0, $$01410$ph$i = 0, $$01413$i = 0, $$01417$i = 0, $$014181624$i = 0, $$014191623$i = 0, $$014201622$i = 0, $$01421$i = 0, $$01423$i = 0, $$01425$i = 0, $$014261639$i = 0, $$014281638$i = 0, $$014301637$i = 0, $$01432$i = 0, $$01436$ph$i = 0, $$01439$ph$i = 0, $$01442$i = 0, $$01446$i = 0;
 var $$01447$i = 0, $$014491649$i = 0, $$014501648$i = 0, $$014511647$i = 0, $$01452$ph$i = 0, $$014551671$i = 0, $$014561670$i = 0, $$014571669$i = 0, $$01458$i = 0, $$01462$i = 0, $$01464$i = 0, $$01465$i = 0, $$01466$i = 0, $$014681654$i = 0, $$01470$i = 0, $$01474$ph$i = 0, $$014771653$i = 0, $$014791652$i = 0, $$01481$ph$i = 0, $$01484$i = 0;
 var $$01488$i = 0, $$01489$i = 0, $$014911666$i = 0, $$014921665$i = 0, $$014931635$i = 0, $$014941634$i = 0, $$014951633$i = 0, $$014961664$i = 0, $$01497$i = 0, $$01499$i = 0, $$01500$ph$i = 0, $$01503$i = 0, $$0958$ph = 0, $$0959 = 0, $$0998 = 0, $$1$i = 0, $$10$i = 0, $$101026 = 0, $$101038 = 0, $$101338$i = 0;
 var $$10969 = 0, $$11017 = 0, $$11029 = 0, $$11048 = 0, $$11058 = 0, $$11065 = 0, $$11072 = 0, $$11082 = 0, $$11086 = 0, $$11096 = 0, $$111027 = 0, $$11103$lcssa = 0, $$11103$ph = 0, $$111031321 = 0, $$111039 = 0, $$11105 = 0, $$11112$lcssa = 0, $$11112$ph = 0, $$111121320 = 0, $$11114$lcssa = 0;
 var $$11114$ph = 0, $$111141319 = 0, $$11119 = 0, $$11132 = 0, $$11136 = 0, $$11143$lcssa = 0, $$11143$ph = 0, $$111431338 = 0, $$11145$lcssa = 0, $$11145$ph = 0, $$111451337 = 0, $$11147$lcssa = 0, $$11147$ph = 0, $$111471336 = 0, $$11152 = 0, $$11165 = 0, $$11322$i = 0, $$11361$i = 0, $$11374$i = 0, $$11381$i = 0;
 var $$11394$i = 0, $$11407$i = 0, $$11414$i = 0, $$11427$lcssa$i = 0, $$11427$ph$i = 0, $$114271643$i = 0, $$11429$lcssa$i = 0, $$11429$ph$i = 0, $$114291642$i = 0, $$11431$lcssa$i = 0, $$11431$ph$i = 0, $$114311641$i = 0, $$11433$i = 0, $$11443$i = 0, $$11459$i = 0, $$11469$lcssa$i = 0, $$11469$ph$i = 0, $$114691658$i = 0, $$11471$i = 0, $$11478$lcssa$i = 0;
 var $$11478$ph$i = 0, $$114781657$i = 0, $$11480$lcssa$i = 0, $$11480$ph$i = 0, $$114801656$i = 0, $$11485$i = 0, $$11504$i = 0, $$11970 = 0, $$12$i = 0, $$12$ph = 0, $$12$ph$i = 0, $$121040 = 0, $$121291$ph$i = 0, $$121340$i = 0, $$13$i = 0, $$131041 = 0, $$13972 = 0, $$139721176 = 0, $$141042 = 0, $$141342$i = 0;
 var $$14973 = 0, $$14973$ph = 0, $$15$i = 0, $$15$ph = 0, $$15$ph$i = 0, $$151043 = 0, $$151294$ph$i = 0, $$15974 = 0, $$16$i = 0, $$161344$i = 0, $$17976 = 0, $$17976$ph = 0, $$18$i = 0, $$18$ph = 0, $$18$ph$i = 0, $$181297$ph$i = 0, $$181346$i = 0, $$18977 = 0, $$19$i = 0, $$1960 = 0;
 var $$1999 = 0, $$201348$i = 0, $$20979 = 0, $$20979$ph = 0, $$21$i = 0, $$21$ph = 0, $$21$ph$i = 0, $$21000 = 0, $$21018 = 0, $$21030 = 0, $$211300$ph$i = 0, $$21330$i = 0, $$21980 = 0, $$22$i = 0, $$221350$i = 0, $$23982 = 0, $$23982$ph = 0, $$24$i = 0, $$24$ph = 0, $$24$ph$i = 0;
 var $$241303$ph$i = 0, $$24983 = 0, $$25$i = 0, $$26985 = 0, $$26985$ph = 0, $$27$i = 0, $$27$ph = 0, $$27$ph$i = 0, $$271306$ph$i = 0, $$27986 = 0, $$28$i = 0, $$2961 = 0, $$29988 = 0, $$29988$ph = 0, $$3$i = 0, $$3$ph = 0, $$3$ph$i = 0, $$30$i = 0, $$30$ph = 0, $$30$ph$i = 0;
 var $$301309$ph$i = 0, $$30989 = 0, $$31$i = 0, $$31001 = 0, $$31019 = 0, $$31031 = 0, $$31282$ph$i = 0, $$32991 = 0, $$32991$ph = 0, $$33$i = 0, $$33$ph = 0, $$33$ph$i = 0, $$331312$ph$i = 0, $$33992 = 0, $$34$i = 0, $$35994 = 0, $$35994$ph = 0, $$36$i = 0, $$36$ph = 0, $$36$ph$i = 0;
 var $$361315$ph$i = 0, $$36995 = 0, $$37$i = 0, $$38997 = 0, $$38997$ph = 0, $$39 = 0, $$3962 = 0, $$4$i = 0, $$41 = 0, $$41$ph = 0, $$41002 = 0, $$41020 = 0, $$41032 = 0, $$41332$i = 0, $$42 = 0, $$44 = 0, $$44$ph = 0, $$45 = 0, $$47 = 0, $$47$ph = 0;
 var $$48 = 0, $$4963 = 0, $$50 = 0, $$50$ph = 0, $$51 = 0, $$51021 = 0, $$51033 = 0, $$5964 = 0, $$6$i = 0, $$6$ph = 0, $$6$ph$i = 0, $$61022 = 0, $$61034 = 0, $$61285$ph$i = 0, $$61334$i = 0, $$6965 = 0, $$7$i = 0, $$71023 = 0, $$71035 = 0, $$7966 = 0;
 var $$81024 = 0, $$81036 = 0, $$81336$i = 0, $$8967 = 0, $$9$i = 0, $$9$ph = 0, $$9$ph$i = 0, $$91025 = 0, $$91037 = 0, $$91288$ph$i = 0, $$9968 = 0, $$phi$trans$insert = 0, $$phi$trans$insert1439 = 0, $$phi$trans$insert1443 = 0, $$phi$trans$insert1444 = 0, $$phi$trans$insert1448 = 0, $$phi$trans$insert1449 = 0, $$phi$trans$insert1454 = 0, $$phi$trans$insert1455 = 0, $$phi$trans$insert1459 = 0;
 var $$phi$trans$insert1460 = 0, $$phi$trans$insert1464 = 0, $$phi$trans$insert1465 = 0, $$pre = 0, $$pre1440 = 0, $$pre1441 = 0, $$pre1442 = 0, $$pre1445 = 0, $$pre1446 = 0, $$pre1447 = 0, $$pre1450 = 0, $$pre1451 = 0, $$pre1452 = 0, $$pre1453 = 0, $$pre1456 = 0, $$pre1457 = 0, $$pre1458 = 0, $$pre1461 = 0, $$pre1462 = 0, $$pre1463 = 0;
 var $$pre1466 = 0, $$pre1467 = 0, $10 = 0, $100 = 0, $1000 = 0, $1001 = 0, $1002 = 0, $1003 = 0, $1004 = 0, $1005 = 0, $1006 = 0, $1007 = 0, $1008 = 0, $1009 = 0, $101 = 0, $1010 = 0, $1011 = 0, $1012 = 0, $1013 = 0, $1014 = 0;
 var $1015 = 0, $1016 = 0, $1017 = 0, $1018 = 0, $1019 = 0, $102 = 0, $1020 = 0, $1021 = 0, $1022 = 0, $1023 = 0, $1024 = 0, $1025 = 0, $1026 = 0, $1027 = 0, $1028 = 0, $1029 = 0, $103 = 0, $1030 = 0, $1031 = 0, $1032 = 0;
 var $1033 = 0, $1034 = 0, $1035 = 0, $1036 = 0, $1037 = 0, $1038 = 0, $1039 = 0, $104 = 0, $1040 = 0, $1041 = 0, $1042 = 0, $1043 = 0, $1044 = 0, $1045 = 0, $1046 = 0, $1047 = 0, $1048 = 0, $1049 = 0, $105 = 0, $1050 = 0;
 var $1051 = 0, $1052 = 0, $1053 = 0, $1054 = 0, $1055 = 0, $1056 = 0, $1057 = 0, $1058 = 0, $1059 = 0, $106 = 0, $1060 = 0, $1061 = 0, $1062 = 0, $1063 = 0, $1064 = 0, $1065 = 0, $1066 = 0, $1067 = 0, $1068 = 0, $1069 = 0;
 var $107 = 0, $1070 = 0, $1071 = 0, $1072 = 0, $1073 = 0, $1074 = 0, $1075 = 0, $1076 = 0, $1077 = 0, $1078 = 0, $1079 = 0, $108 = 0, $1080 = 0, $1081 = 0, $1082 = 0, $1083 = 0, $1084 = 0, $1085 = 0, $1086 = 0, $1087 = 0;
 var $1088 = 0, $1089 = 0, $109 = 0, $1090 = 0, $1091 = 0, $1092 = 0, $1093 = 0, $1094 = 0, $1095 = 0, $1096 = 0, $1097 = 0, $1098 = 0, $1099 = 0, $11 = 0, $110 = 0, $1100 = 0, $1101 = 0, $1102 = 0, $1103 = 0, $1104 = 0;
 var $1105 = 0, $1106 = 0, $1107 = 0, $1108 = 0, $1109 = 0, $111 = 0, $1110 = 0, $1111 = 0, $1112 = 0, $1113 = 0, $1114 = 0, $1115 = 0, $1116 = 0, $1117 = 0, $1118 = 0, $1119 = 0, $112 = 0, $1120 = 0, $1121 = 0, $1122 = 0;
 var $1123 = 0, $1124 = 0, $1125 = 0, $1126 = 0, $1127 = 0, $1128 = 0, $1129 = 0, $113 = 0, $1130 = 0, $1131 = 0, $1132 = 0, $1133 = 0, $1134 = 0, $1135 = 0, $1136 = 0, $1137 = 0, $1138 = 0, $1139 = 0, $114 = 0, $1140 = 0;
 var $1141 = 0, $1142 = 0, $1143 = 0, $1144 = 0, $1145 = 0, $1146 = 0, $1147 = 0, $1148 = 0, $1149 = 0, $115 = 0, $1150 = 0, $1151 = 0, $1152 = 0, $1153 = 0, $1154 = 0, $1155 = 0, $1156 = 0, $1157 = 0, $1158 = 0, $1159 = 0;
 var $116 = 0, $1160 = 0, $1161 = 0, $1162 = 0, $1163 = 0, $1164 = 0, $1165 = 0, $1166 = 0, $1167 = 0, $1168 = 0, $1169 = 0, $117 = 0, $1170 = 0, $1171 = 0, $1172 = 0, $1173 = 0, $1174 = 0, $1175 = 0, $1176 = 0, $1177 = 0;
 var $1178 = 0, $1179 = 0, $118 = 0, $1180 = 0, $1181 = 0, $1182 = 0, $1183 = 0, $1184 = 0, $1185 = 0, $1186 = 0, $1187 = 0, $1188 = 0, $1189 = 0, $119 = 0, $1190 = 0, $1191 = 0, $1192 = 0, $1193 = 0, $1194 = 0, $1195 = 0;
 var $1196 = 0, $1197 = 0, $1198 = 0, $1199 = 0, $12 = 0, $120 = 0, $1200 = 0, $1201 = 0, $1202 = 0, $1203 = 0, $1204 = 0, $1205 = 0, $1206 = 0, $1207 = 0, $1208 = 0, $1209 = 0, $121 = 0, $1210 = 0, $1211 = 0, $1212 = 0;
 var $1213 = 0, $1214 = 0, $1215 = 0, $1216 = 0, $1217 = 0, $1218 = 0, $1219 = 0, $122 = 0, $1220 = 0, $1221 = 0, $1222 = 0, $1223 = 0, $1224 = 0, $1225 = 0, $1226 = 0, $1227 = 0, $1228 = 0, $1229 = 0, $123 = 0, $1230 = 0;
 var $1231 = 0, $1232 = 0, $1233 = 0, $1234 = 0, $1235 = 0, $1236 = 0, $1237 = 0, $1238 = 0, $1239 = 0, $124 = 0, $1240 = 0, $1241 = 0, $1242 = 0, $1243 = 0, $1244 = 0, $1245 = 0, $1246 = 0, $1247 = 0, $1248 = 0, $1249 = 0;
 var $125 = 0, $1250 = 0, $1251 = 0, $1252 = 0, $1253 = 0, $1254 = 0, $1255 = 0, $1256 = 0, $1257 = 0, $1258 = 0, $1259 = 0, $126 = 0, $1260 = 0, $1261 = 0, $1262 = 0, $1263 = 0, $1264 = 0, $1265 = 0, $1266 = 0, $1267 = 0;
 var $1268 = 0, $1269 = 0, $127 = 0, $1270 = 0, $1271 = 0, $1272 = 0, $1273 = 0, $1274 = 0, $1275 = 0, $1276 = 0, $1277 = 0, $1278 = 0, $1279 = 0, $128 = 0, $1280 = 0, $1281 = 0, $1282 = 0, $1283 = 0, $1284 = 0, $1285 = 0;
 var $1286 = 0, $1287 = 0, $1288 = 0, $1289 = 0, $129 = 0, $1290 = 0, $1291 = 0, $1292 = 0, $1293 = 0, $1294 = 0, $1295 = 0, $1296 = 0, $1297 = 0, $1298 = 0, $1299 = 0, $13 = 0, $130 = 0, $1300 = 0, $1301 = 0, $1302 = 0;
 var $1303 = 0, $1304 = 0, $1305 = 0, $1306 = 0, $1307 = 0, $1308 = 0, $1309 = 0, $131 = 0, $1310 = 0, $1311 = 0, $1312 = 0, $1313 = 0, $1314 = 0, $1315 = 0, $1316 = 0, $1317 = 0, $1318 = 0, $1319 = 0, $132 = 0, $1320 = 0;
 var $1321 = 0, $1322 = 0, $1323 = 0, $1324 = 0, $1325 = 0, $1326 = 0, $1327 = 0, $1328 = 0, $1329 = 0, $133 = 0, $1330 = 0, $1331 = 0, $1332 = 0, $1333 = 0, $1334 = 0, $1335 = 0, $1336 = 0, $1337 = 0, $1338 = 0, $1339 = 0;
 var $134 = 0, $1340 = 0, $1341 = 0, $1342 = 0, $1343 = 0, $1344 = 0, $1345 = 0, $1346 = 0, $1347 = 0, $1348 = 0, $1349 = 0, $135 = 0, $1350 = 0, $1351 = 0, $1352 = 0, $1353 = 0, $1354 = 0, $1355 = 0, $1356 = 0, $1357 = 0;
 var $1358 = 0, $1359 = 0, $136 = 0, $1360 = 0, $1361 = 0, $1362 = 0, $1363 = 0, $1364 = 0, $1365 = 0, $1366 = 0, $1367 = 0, $1368 = 0, $1369 = 0, $137 = 0, $1370 = 0, $1371 = 0, $1372 = 0, $1373 = 0, $1374 = 0, $1375 = 0;
 var $1376 = 0, $1377 = 0, $1378 = 0, $1379 = 0, $138 = 0, $1380 = 0, $1381 = 0, $1382 = 0, $1383 = 0, $1384 = 0, $1385 = 0, $1386 = 0, $1387 = 0, $1388 = 0, $1389 = 0, $139 = 0, $1390 = 0, $1391 = 0, $1392 = 0, $1393 = 0;
 var $1394 = 0, $1395 = 0, $1396 = 0, $1397 = 0, $1398 = 0, $1399 = 0, $14 = 0, $140 = 0, $1400 = 0, $1401 = 0, $1402 = 0, $1403 = 0, $1404 = 0, $1405 = 0, $1406 = 0, $1407 = 0, $1408 = 0, $1409 = 0, $141 = 0, $1410 = 0;
 var $1411 = 0, $1412 = 0, $1413 = 0, $1414 = 0, $1415 = 0, $1416 = 0, $1417 = 0, $1418 = 0, $1419 = 0, $142 = 0, $1420 = 0, $1421 = 0, $1422 = 0, $1423 = 0, $1424 = 0, $1425 = 0, $1426 = 0, $1427 = 0, $1428 = 0, $1429 = 0;
 var $143 = 0, $1430 = 0, $1431 = 0, $1432 = 0, $1433 = 0, $1434 = 0, $1435 = 0, $1436 = 0, $1437 = 0, $1438 = 0, $1439 = 0, $144 = 0, $1440 = 0, $1441 = 0, $1442 = 0, $1443 = 0, $1444 = 0, $1445 = 0, $1446 = 0, $1447 = 0;
 var $1448 = 0, $1449 = 0, $145 = 0, $1450 = 0, $1451 = 0, $1452 = 0, $1453 = 0, $1454 = 0, $1455 = 0, $1456 = 0, $1457 = 0, $1458 = 0, $1459 = 0, $146 = 0, $1460 = 0, $1461 = 0, $1462 = 0, $1463 = 0, $1464 = 0, $1465 = 0;
 var $1466 = 0, $1467 = 0, $1468 = 0, $1469 = 0, $147 = 0, $1470 = 0, $1471 = 0, $1472 = 0, $1473 = 0, $1474 = 0, $1475 = 0, $1476 = 0, $1477 = 0, $1478 = 0, $1479 = 0, $148 = 0, $1480 = 0, $1481 = 0, $1482 = 0, $1483 = 0;
 var $1484 = 0, $1485 = 0, $1486 = 0, $1487 = 0, $1488 = 0, $1489 = 0, $149 = 0, $1490 = 0, $1491 = 0, $1492 = 0, $1493 = 0, $1494 = 0, $1495 = 0, $1496 = 0, $1497 = 0, $1498 = 0, $1499 = 0, $15 = 0, $150 = 0, $1500 = 0;
 var $1501 = 0, $1502 = 0, $1503 = 0, $1504 = 0, $1505 = 0, $1506 = 0, $1507 = 0, $1508 = 0, $1509 = 0, $151 = 0, $1510 = 0, $1511 = 0, $1512 = 0, $1513 = 0, $1514 = 0, $1515 = 0, $1516 = 0, $1517 = 0, $1518 = 0, $1519 = 0;
 var $152 = 0, $1520 = 0, $1521 = 0, $1522 = 0, $1523 = 0, $1524 = 0, $1525 = 0, $1526 = 0, $1527 = 0, $1528 = 0, $1529 = 0, $153 = 0, $1530 = 0, $1531 = 0, $1532 = 0, $1533 = 0, $1534 = 0, $1535 = 0, $1536 = 0, $1537 = 0;
 var $1538 = 0, $1539 = 0, $154 = 0, $1540 = 0, $1541 = 0, $1542 = 0, $1543 = 0, $1544 = 0, $1545 = 0, $1546 = 0, $1547 = 0, $1548 = 0, $1549 = 0, $155 = 0, $1550 = 0, $1551 = 0, $1552 = 0, $1553 = 0, $1554 = 0, $1555 = 0;
 var $1556 = 0, $1557 = 0, $1558 = 0, $1559 = 0, $156 = 0, $1560 = 0, $1561 = 0, $1562 = 0, $1563 = 0, $1564 = 0, $1565 = 0, $1566 = 0, $1567 = 0, $1568 = 0, $1569 = 0, $157 = 0, $1570 = 0, $1571 = 0, $1572 = 0, $1573 = 0;
 var $1574 = 0, $1575 = 0, $1576 = 0, $1577 = 0, $1578 = 0, $1579 = 0, $158 = 0, $1580 = 0, $1581 = 0, $1582 = 0, $1583 = 0, $1584 = 0, $1585 = 0, $1586 = 0, $1587 = 0, $1588 = 0, $1589 = 0, $159 = 0, $1590 = 0, $1591 = 0;
 var $1592 = 0, $1593 = 0, $1594 = 0, $1595 = 0, $1596 = 0, $1597 = 0, $1598 = 0, $1599 = 0, $16 = 0, $160 = 0, $1600 = 0, $1601 = 0, $1602 = 0, $1603 = 0, $1604 = 0, $1605 = 0, $1606 = 0, $1607 = 0, $1608 = 0, $1609 = 0;
 var $161 = 0, $1610 = 0, $1611 = 0, $1612 = 0, $1613 = 0, $1614 = 0, $1615 = 0, $1616 = 0, $1617 = 0, $1618 = 0, $1619 = 0, $162 = 0, $1620 = 0, $1621 = 0, $1622 = 0, $1623 = 0, $1624 = 0, $1625 = 0, $1626 = 0, $1627 = 0;
 var $1628 = 0, $1629 = 0, $163 = 0, $1630 = 0, $1631 = 0, $1632 = 0, $1633 = 0, $1634 = 0, $1635 = 0, $1636 = 0, $1637 = 0, $1638 = 0, $1639 = 0, $164 = 0, $1640 = 0, $1641 = 0, $1642 = 0, $1643 = 0, $1644 = 0, $1645 = 0;
 var $1646 = 0, $1647 = 0, $1648 = 0, $1649 = 0, $165 = 0, $1650 = 0, $1651 = 0, $1652 = 0, $1653 = 0, $1654 = 0, $1655 = 0, $1656 = 0, $1657 = 0, $1658 = 0, $1659 = 0, $166 = 0, $1660 = 0, $1661 = 0, $1662 = 0, $1663 = 0;
 var $1664 = 0, $1665 = 0, $1666 = 0, $1667 = 0, $1668 = 0, $1669 = 0, $167 = 0, $1670 = 0, $1671 = 0, $1672 = 0, $1673 = 0, $1674 = 0, $1675 = 0, $1676 = 0, $1677 = 0, $1678 = 0, $1679 = 0, $168 = 0, $1680 = 0, $1681 = 0;
 var $1682 = 0, $1683 = 0, $1684 = 0, $1685 = 0, $1686 = 0, $1687 = 0, $1688 = 0, $1689 = 0, $169 = 0, $1690 = 0, $1691 = 0, $1692 = 0, $1693 = 0, $1694 = 0, $1695 = 0, $1696 = 0, $1697 = 0, $1698 = 0, $1699 = 0, $17 = 0;
 var $170 = 0, $1700 = 0, $1701 = 0, $1702 = 0, $1703 = 0, $1704 = 0, $1705 = 0, $1706 = 0, $1707 = 0, $1708 = 0, $1709 = 0, $171 = 0, $1710 = 0, $1711 = 0, $1712 = 0, $1713 = 0, $1714 = 0, $1715 = 0, $1716 = 0, $1717 = 0;
 var $1718 = 0, $1719 = 0, $172 = 0, $1720 = 0, $1721 = 0, $1722 = 0, $1723 = 0, $1724 = 0, $1725 = 0, $1726 = 0, $1727 = 0, $1728 = 0, $1729 = 0, $173 = 0, $1730 = 0, $1731 = 0, $1732 = 0, $1733 = 0, $1734 = 0, $1735 = 0;
 var $1736 = 0, $1737 = 0, $1738 = 0, $1739 = 0, $174 = 0, $1740 = 0, $1741 = 0, $1742 = 0, $1743 = 0, $1744 = 0, $1745 = 0, $1746 = 0, $1747 = 0, $1748 = 0, $1749 = 0, $175 = 0, $1750 = 0, $1751 = 0, $1752 = 0, $1753 = 0;
 var $1754 = 0, $1755 = 0, $1756 = 0, $1757 = 0, $1758 = 0, $1759 = 0, $176 = 0, $1760 = 0, $1761 = 0, $1762 = 0, $1763 = 0, $1764 = 0, $1765 = 0, $1766 = 0, $1767 = 0, $1768 = 0, $1769 = 0, $177 = 0, $1770 = 0, $1771 = 0;
 var $1772 = 0, $1773 = 0, $1774 = 0, $1775 = 0, $1776 = 0, $1777 = 0, $1778 = 0, $1779 = 0, $178 = 0, $1780 = 0, $1781 = 0, $1782 = 0, $1783 = 0, $1784 = 0, $1785 = 0, $1786 = 0, $1787 = 0, $1788 = 0, $1789 = 0, $179 = 0;
 var $1790 = 0, $1791 = 0, $1792 = 0, $1793 = 0, $1794 = 0, $1795 = 0, $1796 = 0, $1797 = 0, $1798 = 0, $1799 = 0, $18 = 0, $180 = 0, $1800 = 0, $1801 = 0, $1802 = 0, $1803 = 0, $1804 = 0, $1805 = 0, $1806 = 0, $1807 = 0;
 var $1808 = 0, $1809 = 0, $181 = 0, $1810 = 0, $1811 = 0, $1812 = 0, $1813 = 0, $1814 = 0, $1815 = 0, $1816 = 0, $1817 = 0, $1818 = 0, $1819 = 0, $182 = 0, $1820 = 0, $1821 = 0, $1822 = 0, $1823 = 0, $1824 = 0, $1825 = 0;
 var $1826 = 0, $1827 = 0, $1828 = 0, $1829 = 0, $183 = 0, $1830 = 0, $1831 = 0, $1832 = 0, $1833 = 0, $1834 = 0, $1835 = 0, $1836 = 0, $1837 = 0, $1838 = 0, $1839 = 0, $184 = 0, $1840 = 0, $1841 = 0, $1842 = 0, $1843 = 0;
 var $1844 = 0, $1845 = 0, $1846 = 0, $1847 = 0, $1848 = 0, $1849 = 0, $185 = 0, $1850 = 0, $1851 = 0, $1852 = 0, $1853 = 0, $1854 = 0, $1855 = 0, $1856 = 0, $1857 = 0, $1858 = 0, $1859 = 0, $186 = 0, $1860 = 0, $1861 = 0;
 var $1862 = 0, $1863 = 0, $1864 = 0, $1865 = 0, $1866 = 0, $1867 = 0, $1868 = 0, $1869 = 0, $187 = 0, $1870 = 0, $1871 = 0, $1872 = 0, $1873 = 0, $1874 = 0, $1875 = 0, $1876 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0;
 var $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0;
 var $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0;
 var $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0;
 var $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0;
 var $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0;
 var $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $30 = 0;
 var $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0;
 var $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0;
 var $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0;
 var $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0;
 var $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0;
 var $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0;
 var $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0;
 var $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0;
 var $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0;
 var $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0;
 var $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0;
 var $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0;
 var $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0;
 var $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0;
 var $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0;
 var $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0;
 var $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0;
 var $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0;
 var $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0;
 var $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0;
 var $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0;
 var $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0;
 var $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0;
 var $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0;
 var $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0;
 var $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0;
 var $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0;
 var $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0;
 var $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0;
 var $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = 0, $834 = 0, $835 = 0, $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = 0;
 var $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0, $850 = 0, $851 = 0, $852 = 0, $853 = 0, $854 = 0, $855 = 0, $856 = 0, $857 = 0, $858 = 0, $859 = 0;
 var $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0, $869 = 0, $87 = 0, $870 = 0, $871 = 0, $872 = 0, $873 = 0, $874 = 0, $875 = 0, $876 = 0, $877 = 0;
 var $878 = 0, $879 = 0, $88 = 0, $880 = 0, $881 = 0, $882 = 0, $883 = 0, $884 = 0, $885 = 0, $886 = 0, $887 = 0, $888 = 0, $889 = 0, $89 = 0, $890 = 0, $891 = 0, $892 = 0, $893 = 0, $894 = 0, $895 = 0;
 var $896 = 0, $897 = 0, $898 = 0, $899 = 0, $9 = 0, $90 = 0, $900 = 0, $901 = 0, $902 = 0, $903 = 0, $904 = 0, $905 = 0, $906 = 0, $907 = 0, $908 = 0, $909 = 0, $91 = 0, $910 = 0, $911 = 0, $912 = 0;
 var $913 = 0, $914 = 0, $915 = 0, $916 = 0, $917 = 0, $918 = 0, $919 = 0, $92 = 0, $920 = 0, $921 = 0, $922 = 0, $923 = 0, $924 = 0, $925 = 0, $926 = 0, $927 = 0, $928 = 0, $929 = 0, $93 = 0, $930 = 0;
 var $931 = 0, $932 = 0, $933 = 0, $934 = 0, $935 = 0, $936 = 0, $937 = 0, $938 = 0, $939 = 0, $94 = 0, $940 = 0, $941 = 0, $942 = 0, $943 = 0, $944 = 0, $945 = 0, $946 = 0, $947 = 0, $948 = 0, $949 = 0;
 var $95 = 0, $950 = 0, $951 = 0, $952 = 0, $953 = 0, $954 = 0, $955 = 0, $956 = 0, $957 = 0, $958 = 0, $959 = 0, $96 = 0, $960 = 0, $961 = 0, $962 = 0, $963 = 0, $964 = 0, $965 = 0, $966 = 0, $967 = 0;
 var $968 = 0, $969 = 0, $97 = 0, $970 = 0, $971 = 0, $972 = 0, $973 = 0, $974 = 0, $975 = 0, $976 = 0, $977 = 0, $978 = 0, $979 = 0, $98 = 0, $980 = 0, $981 = 0, $982 = 0, $983 = 0, $984 = 0, $985 = 0;
 var $986 = 0, $987 = 0, $988 = 0, $989 = 0, $99 = 0, $990 = 0, $991 = 0, $992 = 0, $993 = 0, $994 = 0, $995 = 0, $996 = 0, $997 = 0, $998 = 0, $999 = 0, $exitcond = 0, $exitcond1426 = 0, $exitcond1427 = 0, $exitcond1428 = 0, $exitcond1432 = 0;
 var $exitcond1437 = 0, $exitcond1438 = 0, $or$cond = 0, $or$cond$i = 0, $or$cond1171 = 0, $or$cond1172 = 0, $or$cond1173 = 0, $or$cond1174 = 0, $or$cond1175 = 0, $or$cond1520$i = 0, $or$cond1521$i = 0, $or$cond1522$i = 0, $or$cond1523$i = 0, $or$cond1524$i = 0, $scevgep = 0, $scevgep$i = 0, $scevgep1429 = 0, $scevgep1430 = 0, $scevgep1431 = 0, $scevgep1433 = 0;
 var $scevgep1434 = 0, $scevgep1435 = 0, $scevgep1436 = 0, $scevgep1704$i = 0, $scevgep1705$i = 0, $scevgep1706$i = 0, $scevgep1707$i = 0, $scevgep1708$i = 0, $scevgep1709$i = 0, $scevgep1710$i = 0, $switch$i = 0, $switch$split12D = 0, $switch$split2D = 0, $switch1$i = 0, $switch10$i = 0, $switch11$i = 0, $switch2$i = 0, $switch3$i = 0, $switch4$i = 0, $switch5$i = 0;
 var $switch6$i = 0, $switch7$i = 0, $switch8$i = 0, $switch9$i = 0, $trunc = 0, $trunc$clear = 0, $trunc$i = 0, $trunc$i$clear = 0, $trunc1168 = 0, $trunc1168$clear = 0, $trunc1169 = 0, $trunc1169$clear = 0, $trunc1170 = 0, $trunc1170$clear = 0, $trunc1507$i = 0, $trunc1507$i$clear = 0, $trunc1508$i = 0, $trunc1508$i$clear = 0, $trunc1509$i = 0, $trunc1509$i$clear = 0;
 var $trunc1510$i = 0, $trunc1510$i$clear = 0, $trunc1511$i = 0, $trunc1511$i$clear = 0, $trunc1513$i = 0, $trunc1513$i$clear = 0, $trunc1514$i = 0, $trunc1514$i$clear = 0, $trunc1516$i = 0, $trunc1516$i$clear = 0, $trunc1517$i = 0, $trunc1517$i$clear = 0, $trunc1518$i = 0, $trunc1518$i$clear = 0, $trunc1519$i = 0, $trunc1519$i$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ((($0)) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$2>>2]|0;
 $7 = $6 & 2;
 $8 = ($7|0)==(0);
 if (!($8)) {
  $9 = (_SDL_LockSurface($2)|0);
  $10 = ($9|0)<(0);
  if ($10) {
   $$0 = -1;
   return ($$0|0);
  }
 }
 $11 = HEAP32[$3>>2]|0;
 $12 = ((($3)) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($2)) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ((($2)) + 16|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = Math_imul($17, $13)|0;
 $19 = (($15) + ($18)|0);
 $20 = ((($0)) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ((($21)) + 9|0);
 $23 = HEAP8[$22>>0]|0;
 $24 = $23&255;
 $25 = Math_imul($24, $11)|0;
 $26 = (($19) + ($25)|0);
 $27 = ((($0)) + 52|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = ((($28)) + 12|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ((($1)) + 4|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = ($32|0)==(0);
 L5: do {
  if ($33) {
   $$139721176 = $30;
   label = 34;
  } else {
   L7: do {
    switch ($23<<24>>24) {
    case 1:  {
     $$01016 = $32;$$01028 = 0;$$0959 = $30;
     while(1) {
      $34 = HEAP8[$$0959>>0]|0;
      $35 = $34&255;
      $36 = (($35) + ($$01028))|0;
      $37 = ((($$0959)) + 1|0);
      $38 = HEAP8[$37>>0]|0;
      $39 = $38&255;
      $40 = ((($$0959)) + 2|0);
      $41 = ($38<<24>>24)==(0);
      if ($41) {
       $44 = ($36|0)==(0);
       if ($44) {
        $$0998 = 5;$$21018 = $$01016;$$2961 = $40;$$31031 = 0;
       } else {
        $$11029 = $36;$$1960 = $40;
        label = 8;
       }
      } else {
       $42 = (($40) + ($39)|0);
       $43 = (($36) + ($39))|0;
       $$11029 = $43;$$1960 = $42;
       label = 8;
      }
      do {
       if ((label|0) == 8) {
        label = 0;
        $45 = ($$11029|0)==($5|0);
        if ($45) {
         $46 = (($$01016) + -1)|0;
         $47 = ($46|0)==(0);
         if ($47) {
          $$0998 = 3;$$21018 = 0;$$2961 = $$1960;$$31031 = 0;
          break;
         } else {
          $$11017 = $46;$$21030 = 0;
         }
        } else {
         $$11017 = $$01016;$$21030 = $$11029;
        }
        $$0998 = 0;$$21018 = $$11017;$$2961 = $$1960;$$31031 = $$21030;
       }
      } while(0);
      $trunc1170 = $$0998&255;
      $trunc1170$clear = $trunc1170 & 7;
      switch ($trunc1170$clear<<24>>24) {
      case 3:  {
       $$139721176 = $$2961;
       label = 34;
       break L5;
       break;
      }
      case 0:  {
       $$01016 = $$21018;$$01028 = $$31031;$$0959 = $$2961;
       break;
      }
      default: {
       $$13972 = $$2961;$$41002 = $$0998;
       break L7;
      }
      }
     }
     break;
    }
    case 2:  {
     $$31019 = $32;$$3962 = $30;$$41032 = 0;
     while(1) {
      $48 = HEAP8[$$3962>>0]|0;
      $49 = $48&255;
      $50 = (($49) + ($$41032))|0;
      $51 = ((($$3962)) + 1|0);
      $52 = HEAP8[$51>>0]|0;
      $53 = $52&255;
      $54 = ((($$3962)) + 2|0);
      $55 = ($52<<24>>24)==(0);
      if ($55) {
       $59 = ($50|0)==(0);
       if ($59) {
        $$1999 = 5;$$51021 = $$31019;$$5964 = $54;$$71035 = 0;
       } else {
        $$4963 = $54;$$51033 = $50;
        label = 15;
       }
      } else {
       $56 = $53 << 1;
       $57 = (($54) + ($56)|0);
       $58 = (($50) + ($53))|0;
       $$4963 = $57;$$51033 = $58;
       label = 15;
      }
      do {
       if ((label|0) == 15) {
        label = 0;
        $60 = ($$51033|0)==($5|0);
        if ($60) {
         $61 = (($$31019) + -1)|0;
         $62 = ($61|0)==(0);
         if ($62) {
          $$1999 = 6;$$51021 = 0;$$5964 = $$4963;$$71035 = 0;
          break;
         } else {
          $$41020 = $61;$$61034 = 0;
         }
        } else {
         $$41020 = $$31019;$$61034 = $$51033;
        }
        $$1999 = 0;$$51021 = $$41020;$$5964 = $$4963;$$71035 = $$61034;
       }
      } while(0);
      $trunc1169 = $$1999&255;
      $trunc1169$clear = $trunc1169 & 7;
      switch ($trunc1169$clear<<24>>24) {
      case 6:  {
       $$139721176 = $$5964;
       label = 34;
       break L5;
       break;
      }
      case 0:  {
       $$31019 = $$51021;$$3962 = $$5964;$$41032 = $$71035;
       break;
      }
      default: {
       $$13972 = $$5964;$$41002 = $$1999;
       break L7;
      }
      }
     }
     break;
    }
    case 3:  {
     $$61022 = $32;$$6965 = $30;$$81036 = 0;
     while(1) {
      $63 = HEAP8[$$6965>>0]|0;
      $64 = $63&255;
      $65 = (($64) + ($$81036))|0;
      $66 = ((($$6965)) + 1|0);
      $67 = HEAP8[$66>>0]|0;
      $68 = $67&255;
      $69 = ((($$6965)) + 2|0);
      $70 = ($67<<24>>24)==(0);
      if ($70) {
       $74 = ($65|0)==(0);
       if ($74) {
        $$111039 = 0;$$21000 = 5;$$81024 = $$61022;$$8967 = $69;
       } else {
        $$7966 = $69;$$91037 = $65;
        label = 22;
       }
      } else {
       $71 = ($68*3)|0;
       $72 = (($69) + ($71)|0);
       $73 = (($65) + ($68))|0;
       $$7966 = $72;$$91037 = $73;
       label = 22;
      }
      do {
       if ((label|0) == 22) {
        label = 0;
        $75 = ($$91037|0)==($5|0);
        if ($75) {
         $76 = (($$61022) + -1)|0;
         $77 = ($76|0)==(0);
         if ($77) {
          $$111039 = 0;$$21000 = 8;$$81024 = 0;$$8967 = $$7966;
          break;
         } else {
          $$101038 = 0;$$71023 = $76;
         }
        } else {
         $$101038 = $$91037;$$71023 = $$61022;
        }
        $$111039 = $$101038;$$21000 = 0;$$81024 = $$71023;$$8967 = $$7966;
       }
      } while(0);
      $trunc1168 = $$21000&255;
      $trunc1168$clear = $trunc1168 & 15;
      switch ($trunc1168$clear<<24>>24) {
      case 8:  {
       $$139721176 = $$8967;
       label = 34;
       break L5;
       break;
      }
      case 0:  {
       $$61022 = $$81024;$$6965 = $$8967;$$81036 = $$111039;
       break;
      }
      default: {
       $$13972 = $$8967;$$41002 = $$21000;
       break L7;
      }
      }
     }
     break;
    }
    case 4:  {
     $$121040 = 0;$$91025 = $32;$$9968 = $30;
     while(1) {
      $78 = HEAP16[$$9968>>1]|0;
      $79 = $78&65535;
      $80 = (($79) + ($$121040))|0;
      $81 = ((($$9968)) + 2|0);
      $82 = HEAP16[$81>>1]|0;
      $83 = $82&65535;
      $84 = ((($$9968)) + 4|0);
      $85 = ($82<<16>>16)==(0);
      if ($85) {
       $89 = ($80|0)==(0);
       if ($89) {
        $$111027 = $$91025;$$11970 = $84;$$151043 = 0;$$31001 = 5;
       } else {
        $$10969 = $84;$$131041 = $80;
        label = 29;
       }
      } else {
       $86 = $83 << 2;
       $87 = (($84) + ($86)|0);
       $88 = (($80) + ($83))|0;
       $$10969 = $87;$$131041 = $88;
       label = 29;
      }
      do {
       if ((label|0) == 29) {
        label = 0;
        $90 = ($$131041|0)==($5|0);
        if ($90) {
         $91 = (($$91025) + -1)|0;
         $92 = ($91|0)==(0);
         if ($92) {
          $$111027 = 0;$$11970 = $$10969;$$151043 = 0;$$31001 = 10;
          break;
         } else {
          $$101026 = $91;$$141042 = 0;
         }
        } else {
         $$101026 = $$91025;$$141042 = $$131041;
        }
        $$111027 = $$101026;$$11970 = $$10969;$$151043 = $$141042;$$31001 = 0;
       }
      } while(0);
      $trunc = $$31001&255;
      $trunc$clear = $trunc & 15;
      switch ($trunc$clear<<24>>24) {
      case 10:  {
       $$139721176 = $$11970;
       label = 34;
       break L5;
       break;
      }
      case 0:  {
       $$121040 = $$151043;$$91025 = $$111027;$$9968 = $$11970;
       break;
      }
      default: {
       $$13972 = $$11970;$$41002 = $$31001;
       break L7;
      }
      }
     }
     break;
    }
    default: {
     $$139721176 = $30;
     label = 34;
     break L5;
    }
    }
   } while(0);
   switch ($$41002|0) {
   case 0:  {
    $$139721176 = $$13972;
    label = 34;
    break L5;
    break;
   }
   case 5:  {
    break L5;
    break;
   }
   default: {
    $$0 = 0;
   }
   }
   return ($$0|0);
  }
 } while(0);
 L54: do {
  if ((label|0) == 34) {
   $93 = ((($28)) + 79|0);
   $94 = HEAP8[$93>>0]|0;
   $95 = $94&255;
   $96 = HEAP32[$1>>2]|0;
   $97 = ($96|0)==(0);
   if ($97) {
    $98 = ((($1)) + 8|0);
    $99 = HEAP32[$98>>2]|0;
    $100 = HEAP32[$4>>2]|0;
    $101 = ($99|0)==($100|0);
    if ($101) {
     $1077 = ($94<<24>>24)==(-1);
     if ($1077) {
      switch ($23<<24>>24) {
      case 1:  {
       $1078 = ((($1)) + 12|0);
       $1079 = HEAP32[$1078>>2]|0;
       $$01044$ph = $1079;$$0958$ph = $26;$$14973$ph = $$139721176;
       while(1) {
        $$01047 = 0;$$14973 = $$14973$ph;
        while(1) {
         $1080 = HEAP8[$$14973>>0]|0;
         $1081 = $1080&255;
         $1082 = (($1081) + ($$01047))|0;
         $1083 = ((($$14973)) + 1|0);
         $1084 = HEAP8[$1083>>0]|0;
         $1085 = $1084&255;
         $1086 = ((($$14973)) + 2|0);
         $1087 = ($1084<<24>>24)==(0);
         if ($1087) {
          $1091 = ($1082|0)==(0);
          if ($1091) {
           break L54;
          } else {
           $$11048 = $1082;$$15974 = $1086;
          }
         } else {
          $1088 = (($$0958$ph) + ($1082)|0);
          (_SDL_memcpy($1088,$1086,$1085)|0);
          $1089 = (($1086) + ($1085)|0);
          $1090 = (($1082) + ($1085))|0;
          $$11048 = $1090;$$15974 = $1089;
         }
         $1092 = ($$11048|0)==($5|0);
         if ($1092) {
          break;
         } else {
          $$01047 = $$11048;$$14973 = $$15974;
         }
        }
        $1093 = HEAP32[$16>>2]|0;
        $1094 = (($$0958$ph) + ($1093)|0);
        $1095 = (($$01044$ph) + -1)|0;
        $1096 = ($1095|0)==(0);
        if ($1096) {
         break L54;
        } else {
         $$01044$ph = $1095;$$0958$ph = $1094;$$14973$ph = $$15974;
        }
       }
       break;
      }
      case 2:  {
       $1097 = ((($1)) + 12|0);
       $1098 = HEAP32[$1097>>2]|0;
       $$01054$ph = $1098;$$17976$ph = $$139721176;$$3$ph = $26;
       while(1) {
        $$01064 = 0;$$17976 = $$17976$ph;
        while(1) {
         $1099 = HEAP8[$$17976>>0]|0;
         $1100 = $1099&255;
         $1101 = (($1100) + ($$01064))|0;
         $1102 = ((($$17976)) + 1|0);
         $1103 = HEAP8[$1102>>0]|0;
         $1104 = $1103&255;
         $1105 = ((($$17976)) + 2|0);
         $1106 = ($1103<<24>>24)==(0);
         if ($1106) {
          $1112 = ($1101|0)==(0);
          if ($1112) {
           break L54;
          } else {
           $$11065 = $1101;$$18977 = $1105;
          }
         } else {
          $1107 = $1101 << 1;
          $1108 = (($$3$ph) + ($1107)|0);
          $1109 = $1104 << 1;
          (_SDL_memcpy($1108,$1105,$1109)|0);
          $1110 = (($1105) + ($1109)|0);
          $1111 = (($1101) + ($1104))|0;
          $$11065 = $1111;$$18977 = $1110;
         }
         $1113 = ($$11065|0)==($5|0);
         if ($1113) {
          break;
         } else {
          $$01064 = $$11065;$$17976 = $$18977;
         }
        }
        $1114 = HEAP32[$16>>2]|0;
        $1115 = (($$3$ph) + ($1114)|0);
        $1116 = (($$01054$ph) + -1)|0;
        $1117 = ($1116|0)==(0);
        if ($1117) {
         break L54;
        } else {
         $$01054$ph = $1116;$$17976$ph = $$18977;$$3$ph = $1115;
        }
       }
       break;
      }
      case 3:  {
       $1118 = ((($1)) + 12|0);
       $1119 = HEAP32[$1118>>2]|0;
       $$01068$ph = $1119;$$20979$ph = $$139721176;$$6$ph = $26;
       while(1) {
        $$01071 = 0;$$20979 = $$20979$ph;
        while(1) {
         $1120 = HEAP8[$$20979>>0]|0;
         $1121 = $1120&255;
         $1122 = (($1121) + ($$01071))|0;
         $1123 = ((($$20979)) + 1|0);
         $1124 = HEAP8[$1123>>0]|0;
         $1125 = $1124&255;
         $1126 = ((($$20979)) + 2|0);
         $1127 = ($1124<<24>>24)==(0);
         if ($1127) {
          $1133 = ($1122|0)==(0);
          if ($1133) {
           break L54;
          } else {
           $$11072 = $1122;$$21980 = $1126;
          }
         } else {
          $1128 = ($1122*3)|0;
          $1129 = (($$6$ph) + ($1128)|0);
          $1130 = ($1125*3)|0;
          (_SDL_memcpy($1129,$1126,$1130)|0);
          $1131 = (($1126) + ($1130)|0);
          $1132 = (($1122) + ($1125))|0;
          $$11072 = $1132;$$21980 = $1131;
         }
         $1134 = ($$11072|0)==($5|0);
         if ($1134) {
          break;
         } else {
          $$01071 = $$11072;$$20979 = $$21980;
         }
        }
        $1135 = HEAP32[$16>>2]|0;
        $1136 = (($$6$ph) + ($1135)|0);
        $1137 = (($$01068$ph) + -1)|0;
        $1138 = ($1137|0)==(0);
        if ($1138) {
         break L54;
        } else {
         $$01068$ph = $1137;$$20979$ph = $$21980;$$6$ph = $1136;
        }
       }
       break;
      }
      case 4:  {
       $1139 = ((($1)) + 12|0);
       $1140 = HEAP32[$1139>>2]|0;
       $$01075$ph = $1140;$$23982$ph = $$139721176;$$9$ph = $26;
       while(1) {
        $$01081 = 0;$$23982 = $$23982$ph;
        while(1) {
         $1141 = HEAP16[$$23982>>1]|0;
         $1142 = $1141&65535;
         $1143 = (($1142) + ($$01081))|0;
         $1144 = ((($$23982)) + 2|0);
         $1145 = HEAP16[$1144>>1]|0;
         $1146 = $1145&65535;
         $1147 = ((($$23982)) + 4|0);
         $1148 = ($1145<<16>>16)==(0);
         if ($1148) {
          $1154 = ($1143|0)==(0);
          if ($1154) {
           break L54;
          } else {
           $$11082 = $1143;$$24983 = $1147;
          }
         } else {
          $1149 = $1143 << 2;
          $1150 = (($$9$ph) + ($1149)|0);
          $1151 = $1146 << 2;
          (_SDL_memcpy($1150,$1147,$1151)|0);
          $1152 = (($1147) + ($1151)|0);
          $1153 = (($1143) + ($1146))|0;
          $$11082 = $1153;$$24983 = $1152;
         }
         $1155 = ($$11082|0)==($5|0);
         if ($1155) {
          break;
         } else {
          $$01081 = $$11082;$$23982 = $$24983;
         }
        }
        $1156 = HEAP32[$16>>2]|0;
        $1157 = (($$9$ph) + ($1156)|0);
        $1158 = (($$01075$ph) + -1)|0;
        $1159 = ($1158|0)==(0);
        if ($1159) {
         break L54;
        } else {
         $$01075$ph = $1158;$$23982$ph = $$24983;$$9$ph = $1157;
        }
       }
       break;
      }
      default: {
       break L54;
      }
      }
     }
     switch ($23<<24>>24) {
     case 4:  {
      $1683 = ((($21)) + 12|0);
      $1684 = HEAP32[$1683>>2]|0;
      $1685 = ((($21)) + 16|0);
      $1686 = HEAP32[$1685>>2]|0;
      $1687 = $1686 | $1684;
      $1688 = ((($21)) + 20|0);
      $1689 = HEAP32[$1688>>2]|0;
      $1690 = $1687 | $1689;
      $1691 = ($1690|0)==(16777215);
      if ($1691) {
       $1692 = ($1686|0)==(65280);
       $1693 = ($1684|0)==(65280);
       $or$cond1174 = $1693 | $1692;
       $1694 = ($1689|0)==(65280);
       $or$cond1175 = $or$cond1174 | $1694;
       if ($or$cond1175) {
        $1695 = ($94<<24>>24)==(-128);
        $1696 = ((($1)) + 12|0);
        $1697 = HEAP32[$1696>>2]|0;
        if ($1695) {
         $$01108$ph = $1697;$$30$ph = $26;$$44$ph = $$139721176;
         while(1) {
          $$01104 = 0;$$44 = $$44$ph;
          while(1) {
           $1698 = HEAP16[$$44>>1]|0;
           $1699 = $1698&65535;
           $1700 = (($1699) + ($$01104))|0;
           $1701 = ((($$44)) + 2|0);
           $1702 = HEAP16[$1701>>1]|0;
           $1703 = $1702&65535;
           $1704 = ((($$44)) + 4|0);
           $1705 = ($1702<<16>>16)==(0);
           if ($1705) {
            $1723 = ($1700|0)==(0);
            if ($1723) {
             break L54;
            } else {
             $$11105 = $1700;$$45 = $1704;
            }
           } else {
            $1706 = $1700 << 2;
            $1707 = (($$30$ph) + ($1706)|0);
            $$010991296 = $1707;$$011001295 = $1704;$$011011294 = 0;
            while(1) {
             $1708 = ((($$011001295)) + 4|0);
             $1709 = HEAP32[$$011001295>>2]|0;
             $1710 = HEAP32[$$010991296>>2]|0;
             $1711 = $1709 & 16711422;
             $1712 = $1710 & 16711422;
             $1713 = (($1712) + ($1711))|0;
             $1714 = $1713 >>> 1;
             $1715 = $1709 & 65793;
             $1716 = $1715 & $1710;
             $1717 = (($1714) + ($1716))|0;
             $1718 = ((($$010991296)) + 4|0);
             HEAP32[$$010991296>>2] = $1717;
             $1719 = (($$011011294) + 1)|0;
             $exitcond = ($1719|0)==($1703|0);
             if ($exitcond) {
              break;
             } else {
              $$010991296 = $1718;$$011001295 = $1708;$$011011294 = $1719;
             }
            }
            $1720 = $1703 << 2;
            $1721 = (($1704) + ($1720)|0);
            $1722 = (($1700) + ($1703))|0;
            $$11105 = $1722;$$45 = $1721;
           }
           $1724 = ($$11105|0)==($5|0);
           if ($1724) {
            break;
           } else {
            $$01104 = $$11105;$$44 = $$45;
           }
          }
          $1725 = HEAP32[$16>>2]|0;
          $1726 = (($$30$ph) + ($1725)|0);
          $1727 = (($$01108$ph) + -1)|0;
          $1728 = ($1727|0)==(0);
          if ($1728) {
           break L54;
          } else {
           $$01108$ph = $1727;$$30$ph = $1726;$$44$ph = $$45;
          }
         }
        } else {
         $$01089$ph = $1697;$$33$ph = $26;$$47$ph = $$139721176;
         while(1) {
          $$01085 = 0;$$47 = $$47$ph;
          while(1) {
           $1729 = HEAP16[$$47>>1]|0;
           $1730 = $1729&65535;
           $1731 = (($1730) + ($$01085))|0;
           $1732 = ((($$47)) + 2|0);
           $1733 = HEAP16[$1732>>1]|0;
           $1734 = $1733&65535;
           $1735 = ((($$47)) + 4|0);
           $1736 = ($1733<<16>>16)==(0);
           if ($1736) {
            $1762 = ($1731|0)==(0);
            if ($1762) {
             break L54;
            } else {
             $$11086 = $1731;$$48 = $1735;
            }
           } else {
            $1737 = $1731 << 2;
            $1738 = (($$33$ph) + ($1737)|0);
            $$010781299 = $1738;$$010791298 = $1735;$$010801297 = 0;
            while(1) {
             $1739 = ((($$010791298)) + 4|0);
             $1740 = HEAP32[$$010791298>>2]|0;
             $1741 = HEAP32[$$010781299>>2]|0;
             $1742 = $1740 & 16711935;
             $1743 = $1741 & 16711935;
             $1744 = (($1742) - ($1743))|0;
             $1745 = Math_imul($1744, $95)|0;
             $1746 = $1745 >>> 8;
             $1747 = (($1746) + ($1743))|0;
             $1748 = $1747 & 16711935;
             $1749 = $1740 & 65280;
             $1750 = $1741 & 65280;
             $1751 = (($1749) - ($1750))|0;
             $1752 = Math_imul($1751, $95)|0;
             $1753 = $1752 >>> 8;
             $1754 = (($1753) + ($1750))|0;
             $1755 = $1754 & 65280;
             $1756 = $1748 | $1755;
             $1757 = ((($$010781299)) + 4|0);
             HEAP32[$$010781299>>2] = $1756;
             $1758 = (($$010801297) + 1)|0;
             $exitcond1426 = ($1758|0)==($1734|0);
             if ($exitcond1426) {
              break;
             } else {
              $$010781299 = $1757;$$010791298 = $1739;$$010801297 = $1758;
             }
            }
            $1759 = $1734 << 2;
            $1760 = (($1735) + ($1759)|0);
            $1761 = (($1731) + ($1734))|0;
            $$11086 = $1761;$$48 = $1760;
           }
           $1763 = ($$11086|0)==($5|0);
           if ($1763) {
            break;
           } else {
            $$01085 = $$11086;$$47 = $$48;
           }
          }
          $1764 = HEAP32[$16>>2]|0;
          $1765 = (($$33$ph) + ($1764)|0);
          $1766 = (($$01089$ph) + -1)|0;
          $1767 = ($1766|0)==(0);
          if ($1767) {
           break L54;
          } else {
           $$01089$ph = $1766;$$33$ph = $1765;$$47$ph = $$48;
          }
         }
        }
       }
      }
      $1768 = ((($1)) + 12|0);
      $1769 = HEAP32[$1768>>2]|0;
      $1770 = ((($21)) + 28|0);
      $1771 = ((($21)) + 32|0);
      $1772 = ((($21)) + 29|0);
      $1773 = ((($21)) + 33|0);
      $1774 = ((($21)) + 30|0);
      $1775 = ((($21)) + 34|0);
      $1776 = ((($21)) + 24|0);
      $$01061$ph = $1769;$$36$ph = $26;$$50$ph = $$139721176;
      while(1) {
       $$01057 = 0;$$50 = $$50$ph;
       while(1) {
        $1777 = HEAP16[$$50>>1]|0;
        $1778 = $1777&65535;
        $1779 = (($1778) + ($$01057))|0;
        $1780 = ((($$50)) + 2|0);
        $1781 = HEAP16[$1780>>1]|0;
        $1782 = $1781&65535;
        $1783 = ((($$50)) + 4|0);
        $1784 = ($1781<<16>>16)==(0);
        if ($1784) {
         $1868 = ($1779|0)==(0);
         if ($1868) {
          break L54;
         } else {
          $$11058 = $1779;$$51 = $1783;
         }
        } else {
         $1785 = $1779 << 2;
         $1786 = (($$36$ph) + ($1785)|0);
         $$010511305 = $1786;$$010521304 = $1783;$$010531303 = 0;
         while(1) {
          $1787 = HEAP32[$$010521304>>2]|0;
          $1788 = HEAP32[$$010511305>>2]|0;
          $1789 = HEAP8[$1770>>0]|0;
          $1790 = $1789&255;
          $1791 = (79212 + ($1790<<2)|0);
          $1792 = HEAP32[$1791>>2]|0;
          $1793 = HEAP32[$1683>>2]|0;
          $1794 = $1793 & $1787;
          $1795 = HEAP8[$1771>>0]|0;
          $1796 = $1795&255;
          $1797 = $1794 >>> $1796;
          $1798 = (($1792) + ($1797)|0);
          $1799 = HEAP8[$1798>>0]|0;
          $1800 = $1799&255;
          $1801 = HEAP8[$1772>>0]|0;
          $1802 = $1801&255;
          $1803 = (79212 + ($1802<<2)|0);
          $1804 = HEAP32[$1803>>2]|0;
          $1805 = HEAP32[$1685>>2]|0;
          $1806 = $1805 & $1787;
          $1807 = HEAP8[$1773>>0]|0;
          $1808 = $1807&255;
          $1809 = $1806 >>> $1808;
          $1810 = (($1804) + ($1809)|0);
          $1811 = HEAP8[$1810>>0]|0;
          $1812 = $1811&255;
          $1813 = HEAP8[$1774>>0]|0;
          $1814 = $1813&255;
          $1815 = (79212 + ($1814<<2)|0);
          $1816 = HEAP32[$1815>>2]|0;
          $1817 = HEAP32[$1688>>2]|0;
          $1818 = $1817 & $1787;
          $1819 = HEAP8[$1775>>0]|0;
          $1820 = $1819&255;
          $1821 = $1818 >>> $1820;
          $1822 = (($1816) + ($1821)|0);
          $1823 = HEAP8[$1822>>0]|0;
          $1824 = $1823&255;
          $1825 = $1793 & $1788;
          $1826 = $1825 >>> $1796;
          $1827 = (($1792) + ($1826)|0);
          $1828 = HEAP8[$1827>>0]|0;
          $1829 = $1828&255;
          $1830 = $1805 & $1788;
          $1831 = $1830 >>> $1808;
          $1832 = (($1804) + ($1831)|0);
          $1833 = HEAP8[$1832>>0]|0;
          $1834 = $1833&255;
          $1835 = $1817 & $1788;
          $1836 = $1835 >>> $1820;
          $1837 = (($1816) + ($1836)|0);
          $1838 = HEAP8[$1837>>0]|0;
          $1839 = $1838&255;
          $1840 = (($1800) - ($1829))|0;
          $1841 = Math_imul($1840, $95)|0;
          $1842 = $1841 >>> 8;
          $1843 = (($1842) + ($1829))|0;
          $1844 = (($1812) - ($1834))|0;
          $1845 = Math_imul($1844, $95)|0;
          $1846 = $1845 >>> 8;
          $1847 = (($1846) + ($1834))|0;
          $1848 = (($1824) - ($1839))|0;
          $1849 = Math_imul($1848, $95)|0;
          $1850 = $1849 >>> 8;
          $1851 = (($1850) + ($1839))|0;
          $1852 = $1843 >>> $1790;
          $1853 = $1852 << $1796;
          $1854 = $1847 >>> $1802;
          $1855 = $1854 << $1808;
          $1856 = $1851 >>> $1814;
          $1857 = $1856 << $1820;
          $1858 = HEAP32[$1776>>2]|0;
          $1859 = $1853 | $1858;
          $1860 = $1859 | $1855;
          $1861 = $1860 | $1857;
          HEAP32[$$010511305>>2] = $1861;
          $1862 = ((($$010521304)) + 4|0);
          $1863 = ((($$010511305)) + 4|0);
          $1864 = (($$010531303) + 1)|0;
          $exitcond1427 = ($1864|0)==($1782|0);
          if ($exitcond1427) {
           break;
          } else {
           $$010511305 = $1863;$$010521304 = $1862;$$010531303 = $1864;
          }
         }
         $1865 = $1782 << 2;
         $1866 = (($1783) + ($1865)|0);
         $1867 = (($1779) + ($1782))|0;
         $$11058 = $1867;$$51 = $1866;
        }
        $1869 = ($$11058|0)==($5|0);
        if ($1869) {
         break;
        } else {
         $$01057 = $$11058;$$50 = $$51;
        }
       }
       $1870 = HEAP32[$16>>2]|0;
       $1871 = (($$36$ph) + ($1870)|0);
       $1872 = (($$01061$ph) + -1)|0;
       $1873 = ($1872|0)==(0);
       if ($1873) {
        break L54;
       } else {
        $$01061$ph = $1872;$$36$ph = $1871;$$50$ph = $$51;
       }
      }
      break;
     }
     case 2:  {
      $1160 = ((($21)) + 12|0);
      $1161 = HEAP32[$1160>>2]|0;
      $1162 = ((($21)) + 16|0);
      $1163 = HEAP32[$1162>>2]|0;
      $1164 = $1163 | $1161;
      $1165 = ((($21)) + 20|0);
      $1166 = HEAP32[$1165>>2]|0;
      $1167 = $1164 | $1166;
      $switch$split12D = ($1167|0)<(65535);
      L147: do {
       if ($switch$split12D) {
        switch ($1167|0) {
        case 32767:  {
         break;
        }
        default: {
         break L147;
        }
        }
        $1305 = ($1163|0)==(992);
        $1306 = ($1161|0)==(992);
        $or$cond1172 = $1306 | $1305;
        $1307 = ($1166|0)==(992);
        $or$cond1173 = $or$cond1172 | $1307;
        if ($or$cond1173) {
         $1308 = ($94<<24>>24)==(-128);
         $1309 = ((($1)) + 12|0);
         $1310 = HEAP32[$1309>>2]|0;
         if ($1308) {
          $$01125$ph = $1310;$$18$ph = $26;$$32991$ph = $$139721176;
         } else {
          $1311 = $95 >>> 3;
          $$01148$ph = $1310;$$21$ph = $26;$$35994$ph = $$139721176;
          while(1) {
           $$01151 = 0;$$35994 = $$35994$ph;
           while(1) {
            $1403 = HEAP8[$$35994>>0]|0;
            $1404 = $1403&255;
            $1405 = (($1404) + ($$01151))|0;
            $1406 = ((($$35994)) + 1|0);
            $1407 = HEAP8[$1406>>0]|0;
            $1408 = $1407&255;
            $1409 = ((($$35994)) + 2|0);
            $1410 = ($1407<<24>>24)==(0);
            if ($1410) {
             $1437 = ($1405|0)==(0);
             if ($1437) {
              break L54;
             } else {
              $$11152 = $1405;$$36995 = $1409;
             }
            } else {
             $1411 = $1405 << 1;
             $1412 = (($$21$ph) + ($1411)|0);
             $$011551346 = 0;$$011561345 = $1409;$$011571344 = $1412;
             while(1) {
              $1413 = ((($$011561345)) + 2|0);
              $1414 = HEAP16[$$011561345>>1]|0;
              $1415 = $1414&65535;
              $1416 = HEAP16[$$011571344>>1]|0;
              $1417 = $1416&65535;
              $1418 = $1415 << 16;
              $1419 = $1418 | $1415;
              $1420 = $1419 & 65043487;
              $1421 = $1417 << 16;
              $1422 = $1421 | $1417;
              $1423 = $1422 & 65043487;
              $1424 = (($1420) - ($1423))|0;
              $1425 = Math_imul($1424, $1311)|0;
              $1426 = $1425 >>> 5;
              $1427 = (($1426) + ($1423))|0;
              $1428 = $1427 & 65043487;
              $1429 = $1428 >>> 16;
              $1430 = $1429 | $1428;
              $1431 = $1430&65535;
              $1432 = ((($$011571344)) + 2|0);
              HEAP16[$$011571344>>1] = $1431;
              $1433 = (($$011551346) + 1)|0;
              $exitcond1437 = ($1433|0)==($1408|0);
              if ($exitcond1437) {
               break;
              } else {
               $$011551346 = $1433;$$011561345 = $1413;$$011571344 = $1432;
              }
             }
             $1434 = $1408 << 1;
             $1435 = (($1409) + ($1434)|0);
             $1436 = (($1405) + ($1408))|0;
             $$11152 = $1436;$$36995 = $1435;
            }
            $1438 = ($$11152|0)==($5|0);
            if ($1438) {
             break;
            } else {
             $$01151 = $$11152;$$35994 = $$36995;
            }
           }
           $1439 = (($$21$ph) + ($17)|0);
           $1440 = (($$01148$ph) + -1)|0;
           $1441 = ($1440|0)==(0);
           if ($1441) {
            break L54;
           } else {
            $$01148$ph = $1440;$$21$ph = $1439;$$35994$ph = $$36995;
           }
          }
         }
         while(1) {
          $$01131 = 0;$$32991 = $$32991$ph;
          while(1) {
           $1312 = HEAP8[$$32991>>0]|0;
           $1313 = $1312&255;
           $1314 = (($1313) + ($$01131))|0;
           $1315 = ((($$32991)) + 1|0);
           $1316 = HEAP8[$1315>>0]|0;
           $1317 = $1316&255;
           $1318 = ((($$32991)) + 2|0);
           $1319 = ($1316<<24>>24)==(0);
           if ($1319) {
            $1397 = ($1314|0)==(0);
            if ($1397) {
             break L54;
            } else {
             $$11132 = $1314;$$33992 = $1318;
            }
           } else {
            $1320 = $1314 << 1;
            $1321 = (($$18$ph) + ($1320)|0);
            $1322 = $1318;
            $1323 = $1321;
            $1324 = $1323 ^ $1322;
            $1325 = $1324 & 3;
            $1326 = ($1325|0)==(0);
            do {
             if ($1326) {
              $1344 = $1322 & 3;
              $1345 = ($1344|0)==(0);
              if ($1345) {
               $$11143$ph = $1317;$$11145$ph = $1318;$$11147$ph = $1321;
              } else {
               $1346 = ((($$32991)) + 4|0);
               $1347 = HEAP16[$1318>>1]|0;
               $1348 = HEAP16[$1321>>1]|0;
               $1349 = $1347 & -1058;
               $1350 = $1349&65535;
               $1351 = $1348 & -1058;
               $1352 = $1351&65535;
               $1353 = (($1352) + ($1350))|0;
               $1354 = $1353 >>> 1;
               $1355 = $1347 & 1057;
               $1356 = $1355 & $1348;
               $1357 = $1356&65535;
               $1358 = (($1354) + ($1357))|0;
               $1359 = $1358&65535;
               $1360 = ((($1321)) + 2|0);
               HEAP16[$1321>>1] = $1359;
               $1361 = (($1317) + -1)|0;
               $$11143$ph = $1361;$$11145$ph = $1346;$$11147$ph = $1360;
              }
              $1362 = ($$11143$ph>>>0)>(1);
              if ($1362) {
               $1363 = (($$11143$ph) + -2)|0;
               $1364 = $1363 & -2;
               $scevgep1435 = ((($$11147$ph)) + 4|0);
               $scevgep1436 = (($scevgep1435) + ($1364<<1)|0);
               $$111431338 = $$11143$ph;$$111451337 = $$11145$ph;$$111471336 = $$11147$ph;
               while(1) {
                $1365 = HEAP32[$$111451337>>2]|0;
                $1366 = HEAP32[$$111471336>>2]|0;
                $1367 = $1365 >>> 1;
                $1368 = $1367 & 2112847343;
                $1369 = $1366 >>> 1;
                $1370 = $1369 & 2112847343;
                $1371 = (($1370) + ($1368))|0;
                $1372 = $1365 & 69272609;
                $1373 = $1372 & $1366;
                $1374 = (($1371) + ($1373))|0;
                HEAP32[$$111471336>>2] = $1374;
                $1375 = ((($$111451337)) + 4|0);
                $1376 = ((($$111471336)) + 4|0);
                $1377 = (($$111431338) + -2)|0;
                $1378 = ($1377>>>0)>(1);
                if ($1378) {
                 $$111431338 = $1377;$$111451337 = $1375;$$111471336 = $1376;
                } else {
                 break;
                }
               }
               $scevgep1433 = ((($$11145$ph)) + 4|0);
               $scevgep1434 = (($scevgep1433) + ($1364<<1)|0);
               $1379 = (($1363) - ($1364))|0;
               $$11143$lcssa = $1379;$$11145$lcssa = $scevgep1434;$$11147$lcssa = $scevgep1436;
              } else {
               $$11143$lcssa = $$11143$ph;$$11145$lcssa = $$11145$ph;$$11147$lcssa = $$11147$ph;
              }
              $1380 = ($$11143$lcssa|0)==(0);
              if ($1380) {
               break;
              }
              $1381 = HEAP16[$$11145$lcssa>>1]|0;
              $1382 = HEAP16[$$11147$lcssa>>1]|0;
              $1383 = $1381 & -1058;
              $1384 = $1383&65535;
              $1385 = $1382 & -1058;
              $1386 = $1385&65535;
              $1387 = (($1386) + ($1384))|0;
              $1388 = $1387 >>> 1;
              $1389 = $1381 & 1057;
              $1390 = $1389 & $1382;
              $1391 = $1390&65535;
              $1392 = (($1388) + ($1391))|0;
              $1393 = $1392&65535;
              HEAP16[$$11147$lcssa>>1] = $1393;
             } else {
              $$011421334 = $1317;$$011441333 = $1318;$$011461332 = $1321;
              while(1) {
               $1327 = (($$011421334) + -1)|0;
               $1328 = ((($$011441333)) + 2|0);
               $1329 = HEAP16[$$011441333>>1]|0;
               $1330 = HEAP16[$$011461332>>1]|0;
               $1331 = $1329 & -1058;
               $1332 = $1331&65535;
               $1333 = $1330 & -1058;
               $1334 = $1333&65535;
               $1335 = (($1334) + ($1332))|0;
               $1336 = $1335 >>> 1;
               $1337 = $1329 & 1057;
               $1338 = $1337 & $1330;
               $1339 = $1338&65535;
               $1340 = (($1336) + ($1339))|0;
               $1341 = $1340&65535;
               $1342 = ((($$011461332)) + 2|0);
               HEAP16[$$011461332>>1] = $1341;
               $1343 = ($1327|0)==(0);
               if ($1343) {
                break;
               } else {
                $$011421334 = $1327;$$011441333 = $1328;$$011461332 = $1342;
               }
              }
             }
            } while(0);
            $1394 = $1317 << 1;
            $1395 = (($1318) + ($1394)|0);
            $1396 = (($1314) + ($1317))|0;
            $$11132 = $1396;$$33992 = $1395;
           }
           $1398 = ($$11132|0)==($5|0);
           if ($1398) {
            break;
           } else {
            $$01131 = $$11132;$$32991 = $$33992;
           }
          }
          $1399 = HEAP32[$16>>2]|0;
          $1400 = (($$18$ph) + ($1399)|0);
          $1401 = (($$01125$ph) + -1)|0;
          $1402 = ($1401|0)==(0);
          if ($1402) {
           break L54;
          } else {
           $$01125$ph = $1401;$$18$ph = $1400;$$32991$ph = $$33992;
          }
         }
        }
       } else {
        switch ($1167|0) {
        case 65535:  {
         break;
        }
        default: {
         break L147;
        }
        }
        $1168 = ($1163|0)==(2016);
        $1169 = ($1161|0)==(2016);
        $or$cond = $1169 | $1168;
        $1170 = ($1166|0)==(2016);
        $or$cond1171 = $or$cond | $1170;
        if ($or$cond1171) {
         $1171 = ($94<<24>>24)==(-128);
         $1172 = ((($1)) + 12|0);
         $1173 = HEAP32[$1172>>2]|0;
         if ($1171) {
          $$01092$ph = $1173;$$12$ph = $26;$$26985$ph = $$139721176;
         } else {
          $1174 = $95 >>> 3;
          $$01115$ph = $1173;$$15$ph = $26;$$29988$ph = $$139721176;
          while(1) {
           $$01118 = 0;$$29988 = $$29988$ph;
           while(1) {
            $1266 = HEAP8[$$29988>>0]|0;
            $1267 = $1266&255;
            $1268 = (($1267) + ($$01118))|0;
            $1269 = ((($$29988)) + 1|0);
            $1270 = HEAP8[$1269>>0]|0;
            $1271 = $1270&255;
            $1272 = ((($$29988)) + 2|0);
            $1273 = ($1270<<24>>24)==(0);
            if ($1273) {
             $1300 = ($1268|0)==(0);
             if ($1300) {
              break L54;
             } else {
              $$11119 = $1268;$$30989 = $1272;
             }
            } else {
             $1274 = $1268 << 1;
             $1275 = (($$15$ph) + ($1274)|0);
             $$011221328 = 0;$$011231327 = $1272;$$011241326 = $1275;
             while(1) {
              $1276 = ((($$011231327)) + 2|0);
              $1277 = HEAP16[$$011231327>>1]|0;
              $1278 = $1277&65535;
              $1279 = HEAP16[$$011241326>>1]|0;
              $1280 = $1279&65535;
              $1281 = $1278 << 16;
              $1282 = $1281 | $1278;
              $1283 = $1282 & 132184095;
              $1284 = $1280 << 16;
              $1285 = $1284 | $1280;
              $1286 = $1285 & 132184095;
              $1287 = (($1283) - ($1286))|0;
              $1288 = Math_imul($1287, $1174)|0;
              $1289 = $1288 >>> 5;
              $1290 = (($1289) + ($1286))|0;
              $1291 = $1290 & 132184095;
              $1292 = $1291 >>> 16;
              $1293 = $1292 | $1291;
              $1294 = $1293&65535;
              $1295 = ((($$011241326)) + 2|0);
              HEAP16[$$011241326>>1] = $1294;
              $1296 = (($$011221328) + 1)|0;
              $exitcond1432 = ($1296|0)==($1271|0);
              if ($exitcond1432) {
               break;
              } else {
               $$011221328 = $1296;$$011231327 = $1276;$$011241326 = $1295;
              }
             }
             $1297 = $1271 << 1;
             $1298 = (($1272) + ($1297)|0);
             $1299 = (($1268) + ($1271))|0;
             $$11119 = $1299;$$30989 = $1298;
            }
            $1301 = ($$11119|0)==($5|0);
            if ($1301) {
             break;
            } else {
             $$01118 = $$11119;$$29988 = $$30989;
            }
           }
           $1302 = (($$15$ph) + ($17)|0);
           $1303 = (($$01115$ph) + -1)|0;
           $1304 = ($1303|0)==(0);
           if ($1304) {
            break L54;
           } else {
            $$01115$ph = $1303;$$15$ph = $1302;$$29988$ph = $$30989;
           }
          }
         }
         while(1) {
          $$01095 = 0;$$26985 = $$26985$ph;
          while(1) {
           $1175 = HEAP8[$$26985>>0]|0;
           $1176 = $1175&255;
           $1177 = (($1176) + ($$01095))|0;
           $1178 = ((($$26985)) + 1|0);
           $1179 = HEAP8[$1178>>0]|0;
           $1180 = $1179&255;
           $1181 = ((($$26985)) + 2|0);
           $1182 = ($1179<<24>>24)==(0);
           if ($1182) {
            $1260 = ($1177|0)==(0);
            if ($1260) {
             break L54;
            } else {
             $$11096 = $1177;$$27986 = $1181;
            }
           } else {
            $1183 = $1177 << 1;
            $1184 = (($$12$ph) + ($1183)|0);
            $1185 = $1181;
            $1186 = $1184;
            $1187 = $1186 ^ $1185;
            $1188 = $1187 & 3;
            $1189 = ($1188|0)==(0);
            do {
             if ($1189) {
              $1207 = $1185 & 3;
              $1208 = ($1207|0)==(0);
              if ($1208) {
               $$11103$ph = $1180;$$11112$ph = $1181;$$11114$ph = $1184;
              } else {
               $1209 = ((($$26985)) + 4|0);
               $1210 = HEAP16[$1181>>1]|0;
               $1211 = HEAP16[$1184>>1]|0;
               $1212 = $1210 & -2082;
               $1213 = $1212&65535;
               $1214 = $1211 & -2082;
               $1215 = $1214&65535;
               $1216 = (($1215) + ($1213))|0;
               $1217 = $1216 >>> 1;
               $1218 = $1210 & 2081;
               $1219 = $1218 & $1211;
               $1220 = $1219&65535;
               $1221 = (($1217) + ($1220))|0;
               $1222 = $1221&65535;
               $1223 = ((($1184)) + 2|0);
               HEAP16[$1184>>1] = $1222;
               $1224 = (($1180) + -1)|0;
               $$11103$ph = $1224;$$11112$ph = $1209;$$11114$ph = $1223;
              }
              $1225 = ($$11103$ph>>>0)>(1);
              if ($1225) {
               $1226 = (($$11103$ph) + -2)|0;
               $1227 = $1226 & -2;
               $scevgep1430 = ((($$11114$ph)) + 4|0);
               $scevgep1431 = (($scevgep1430) + ($1227<<1)|0);
               $$111031321 = $$11103$ph;$$111121320 = $$11112$ph;$$111141319 = $$11114$ph;
               while(1) {
                $1228 = HEAP32[$$111121320>>2]|0;
                $1229 = HEAP32[$$111141319>>2]|0;
                $1230 = $1228 >>> 1;
                $1231 = $1230 & 2079292399;
                $1232 = $1229 >>> 1;
                $1233 = $1232 & 2079292399;
                $1234 = (($1233) + ($1231))|0;
                $1235 = $1228 & 136382497;
                $1236 = $1235 & $1229;
                $1237 = (($1234) + ($1236))|0;
                HEAP32[$$111141319>>2] = $1237;
                $1238 = ((($$111121320)) + 4|0);
                $1239 = ((($$111141319)) + 4|0);
                $1240 = (($$111031321) + -2)|0;
                $1241 = ($1240>>>0)>(1);
                if ($1241) {
                 $$111031321 = $1240;$$111121320 = $1238;$$111141319 = $1239;
                } else {
                 break;
                }
               }
               $scevgep = ((($$11112$ph)) + 4|0);
               $scevgep1429 = (($scevgep) + ($1227<<1)|0);
               $1242 = (($1226) - ($1227))|0;
               $$11103$lcssa = $1242;$$11112$lcssa = $scevgep1429;$$11114$lcssa = $scevgep1431;
              } else {
               $$11103$lcssa = $$11103$ph;$$11112$lcssa = $$11112$ph;$$11114$lcssa = $$11114$ph;
              }
              $1243 = ($$11103$lcssa|0)==(0);
              if ($1243) {
               break;
              }
              $1244 = HEAP16[$$11112$lcssa>>1]|0;
              $1245 = HEAP16[$$11114$lcssa>>1]|0;
              $1246 = $1244 & -2082;
              $1247 = $1246&65535;
              $1248 = $1245 & -2082;
              $1249 = $1248&65535;
              $1250 = (($1249) + ($1247))|0;
              $1251 = $1250 >>> 1;
              $1252 = $1244 & 2081;
              $1253 = $1252 & $1245;
              $1254 = $1253&65535;
              $1255 = (($1251) + ($1254))|0;
              $1256 = $1255&65535;
              HEAP16[$$11114$lcssa>>1] = $1256;
             } else {
              $$011021317 = $1180;$$011111316 = $1181;$$011131315 = $1184;
              while(1) {
               $1190 = (($$011021317) + -1)|0;
               $1191 = ((($$011111316)) + 2|0);
               $1192 = HEAP16[$$011111316>>1]|0;
               $1193 = HEAP16[$$011131315>>1]|0;
               $1194 = $1192 & -2082;
               $1195 = $1194&65535;
               $1196 = $1193 & -2082;
               $1197 = $1196&65535;
               $1198 = (($1197) + ($1195))|0;
               $1199 = $1198 >>> 1;
               $1200 = $1192 & 2081;
               $1201 = $1200 & $1193;
               $1202 = $1201&65535;
               $1203 = (($1199) + ($1202))|0;
               $1204 = $1203&65535;
               $1205 = ((($$011131315)) + 2|0);
               HEAP16[$$011131315>>1] = $1204;
               $1206 = ($1190|0)==(0);
               if ($1206) {
                break;
               } else {
                $$011021317 = $1190;$$011111316 = $1191;$$011131315 = $1205;
               }
              }
             }
            } while(0);
            $1257 = $1180 << 1;
            $1258 = (($1181) + ($1257)|0);
            $1259 = (($1177) + ($1180))|0;
            $$11096 = $1259;$$27986 = $1258;
           }
           $1261 = ($$11096|0)==($5|0);
           if ($1261) {
            break;
           } else {
            $$01095 = $$11096;$$26985 = $$27986;
           }
          }
          $1262 = HEAP32[$16>>2]|0;
          $1263 = (($$12$ph) + ($1262)|0);
          $1264 = (($$01092$ph) + -1)|0;
          $1265 = ($1264|0)==(0);
          if ($1265) {
           break L54;
          } else {
           $$01092$ph = $1264;$$12$ph = $1263;$$26985$ph = $$27986;
          }
         }
        }
       }
      } while(0);
      $1442 = ((($1)) + 12|0);
      $1443 = HEAP32[$1442>>2]|0;
      $1444 = ((($21)) + 28|0);
      $1445 = ((($21)) + 32|0);
      $1446 = ((($21)) + 29|0);
      $1447 = ((($21)) + 33|0);
      $1448 = ((($21)) + 30|0);
      $1449 = ((($21)) + 34|0);
      $1450 = ((($21)) + 24|0);
      $$01161$ph = $1443;$$24$ph = $26;$$38997$ph = $$139721176;
      while(1) {
       $$01164 = 0;$$38997 = $$38997$ph;
       while(1) {
        $1451 = HEAP8[$$38997>>0]|0;
        $1452 = $1451&255;
        $1453 = (($1452) + ($$01164))|0;
        $1454 = ((($$38997)) + 1|0);
        $1455 = HEAP8[$1454>>0]|0;
        $1456 = $1455&255;
        $1457 = ((($$38997)) + 2|0);
        $1458 = ($1455<<24>>24)==(0);
        if ($1458) {
         $1542 = ($1453|0)==(0);
         if ($1542) {
          break L54;
         } else {
          $$11165 = $1453;$$39 = $1457;
         }
        } else {
         $1459 = $1453 << 1;
         $1460 = (($$24$ph) + ($1459)|0);
         $$011581311 = $1460;$$011591310 = $1457;$$011601309 = 0;
         while(1) {
          $1461 = HEAP16[$$011591310>>1]|0;
          $1462 = $1461&65535;
          $1463 = HEAP16[$$011581311>>1]|0;
          $1464 = $1463&65535;
          $1465 = HEAP8[$1444>>0]|0;
          $1466 = $1465&255;
          $1467 = (79212 + ($1466<<2)|0);
          $1468 = HEAP32[$1467>>2]|0;
          $1469 = $1161 & $1462;
          $1470 = HEAP8[$1445>>0]|0;
          $1471 = $1470&255;
          $1472 = $1469 >>> $1471;
          $1473 = (($1468) + ($1472)|0);
          $1474 = HEAP8[$1473>>0]|0;
          $1475 = $1474&255;
          $1476 = HEAP8[$1446>>0]|0;
          $1477 = $1476&255;
          $1478 = (79212 + ($1477<<2)|0);
          $1479 = HEAP32[$1478>>2]|0;
          $1480 = $1163 & $1462;
          $1481 = HEAP8[$1447>>0]|0;
          $1482 = $1481&255;
          $1483 = $1480 >>> $1482;
          $1484 = (($1479) + ($1483)|0);
          $1485 = HEAP8[$1484>>0]|0;
          $1486 = $1485&255;
          $1487 = HEAP8[$1448>>0]|0;
          $1488 = $1487&255;
          $1489 = (79212 + ($1488<<2)|0);
          $1490 = HEAP32[$1489>>2]|0;
          $1491 = $1166 & $1462;
          $1492 = HEAP8[$1449>>0]|0;
          $1493 = $1492&255;
          $1494 = $1491 >>> $1493;
          $1495 = (($1490) + ($1494)|0);
          $1496 = HEAP8[$1495>>0]|0;
          $1497 = $1496&255;
          $1498 = $1161 & $1464;
          $1499 = $1498 >>> $1471;
          $1500 = (($1468) + ($1499)|0);
          $1501 = HEAP8[$1500>>0]|0;
          $1502 = $1501&255;
          $1503 = $1163 & $1464;
          $1504 = $1503 >>> $1482;
          $1505 = (($1479) + ($1504)|0);
          $1506 = HEAP8[$1505>>0]|0;
          $1507 = $1506&255;
          $1508 = $1166 & $1464;
          $1509 = $1508 >>> $1493;
          $1510 = (($1490) + ($1509)|0);
          $1511 = HEAP8[$1510>>0]|0;
          $1512 = $1511&255;
          $1513 = (($1475) - ($1502))|0;
          $1514 = Math_imul($1513, $95)|0;
          $1515 = $1514 >>> 8;
          $1516 = (($1515) + ($1502))|0;
          $1517 = (($1486) - ($1507))|0;
          $1518 = Math_imul($1517, $95)|0;
          $1519 = $1518 >>> 8;
          $1520 = (($1519) + ($1507))|0;
          $1521 = (($1497) - ($1512))|0;
          $1522 = Math_imul($1521, $95)|0;
          $1523 = $1522 >>> 8;
          $1524 = (($1523) + ($1512))|0;
          $1525 = $1516 >>> $1466;
          $1526 = $1525 << $1471;
          $1527 = $1520 >>> $1477;
          $1528 = $1527 << $1482;
          $1529 = $1524 >>> $1488;
          $1530 = $1529 << $1493;
          $1531 = HEAP32[$1450>>2]|0;
          $1532 = $1526 | $1531;
          $1533 = $1532 | $1528;
          $1534 = $1533 | $1530;
          $1535 = $1534&65535;
          HEAP16[$$011581311>>1] = $1535;
          $1536 = ((($$011591310)) + 2|0);
          $1537 = ((($$011581311)) + 2|0);
          $1538 = (($$011601309) + 1)|0;
          $exitcond1428 = ($1538|0)==($1456|0);
          if ($exitcond1428) {
           break;
          } else {
           $$011581311 = $1537;$$011591310 = $1536;$$011601309 = $1538;
          }
         }
         $1539 = $1456 << 1;
         $1540 = (($1457) + ($1539)|0);
         $1541 = (($1453) + ($1456))|0;
         $$11165 = $1541;$$39 = $1540;
        }
        $1543 = ($$11165|0)==($5|0);
        if ($1543) {
         break;
        } else {
         $$01164 = $$11165;$$38997 = $$39;
        }
       }
       $1544 = (($$24$ph) + ($17)|0);
       $1545 = (($$01161$ph) + -1)|0;
       $1546 = ($1545|0)==(0);
       if ($1546) {
        break L54;
       } else {
        $$01161$ph = $1545;$$24$ph = $1544;$$38997$ph = $$39;
       }
      }
      break;
     }
     case 3:  {
      $1547 = ((($1)) + 12|0);
      $1548 = HEAP32[$1547>>2]|0;
      $1549 = ((($21)) + 28|0);
      $1550 = ((($21)) + 12|0);
      $1551 = ((($21)) + 32|0);
      $1552 = ((($21)) + 29|0);
      $1553 = ((($21)) + 16|0);
      $1554 = ((($21)) + 33|0);
      $1555 = ((($21)) + 30|0);
      $1556 = ((($21)) + 20|0);
      $1557 = ((($21)) + 34|0);
      $1558 = ((($21)) + 24|0);
      $$01139$ph = $1548;$$27$ph = $26;$$41$ph = $$139721176;
      while(1) {
       $$01135 = 0;$$41 = $$41$ph;
       while(1) {
        $1559 = HEAP8[$$41>>0]|0;
        $1560 = $1559&255;
        $1561 = (($1560) + ($$01135))|0;
        $1562 = ((($$41)) + 1|0);
        $1563 = HEAP8[$1562>>0]|0;
        $1564 = $1563&255;
        $1565 = ((($$41)) + 2|0);
        $1566 = ($1563<<24>>24)==(0);
        if ($1566) {
         $1677 = ($1561|0)==(0);
         if ($1677) {
          break L54;
         } else {
          $$11136 = $1561;$$42 = $1565;
         }
        } else {
         $1567 = ($1561*3)|0;
         $1568 = (($$27$ph) + ($1567)|0);
         $$011281352 = $1568;$$011291351 = $1565;$$011301350 = 0;
         while(1) {
          $1569 = ((($$011291351)) + 2|0);
          $1570 = HEAP8[$1569>>0]|0;
          $1571 = $1570&255;
          $1572 = $1571 << 16;
          $1573 = ((($$011291351)) + 1|0);
          $1574 = HEAP8[$1573>>0]|0;
          $1575 = $1574&255;
          $1576 = $1575 << 8;
          $1577 = $1576 | $1572;
          $1578 = HEAP8[$$011291351>>0]|0;
          $1579 = $1578&255;
          $1580 = $1577 | $1579;
          $1581 = ((($$011281352)) + 2|0);
          $1582 = HEAP8[$1581>>0]|0;
          $1583 = $1582&255;
          $1584 = $1583 << 16;
          $1585 = ((($$011281352)) + 1|0);
          $1586 = HEAP8[$1585>>0]|0;
          $1587 = $1586&255;
          $1588 = $1587 << 8;
          $1589 = $1588 | $1584;
          $1590 = HEAP8[$$011281352>>0]|0;
          $1591 = $1590&255;
          $1592 = $1589 | $1591;
          $1593 = HEAP8[$1549>>0]|0;
          $1594 = $1593&255;
          $1595 = (79212 + ($1594<<2)|0);
          $1596 = HEAP32[$1595>>2]|0;
          $1597 = HEAP32[$1550>>2]|0;
          $1598 = $1597 & $1580;
          $1599 = HEAP8[$1551>>0]|0;
          $1600 = $1599&255;
          $1601 = $1598 >>> $1600;
          $1602 = (($1596) + ($1601)|0);
          $1603 = HEAP8[$1602>>0]|0;
          $1604 = $1603&255;
          $1605 = HEAP8[$1552>>0]|0;
          $1606 = $1605&255;
          $1607 = (79212 + ($1606<<2)|0);
          $1608 = HEAP32[$1607>>2]|0;
          $1609 = HEAP32[$1553>>2]|0;
          $1610 = $1609 & $1580;
          $1611 = HEAP8[$1554>>0]|0;
          $1612 = $1611&255;
          $1613 = $1610 >>> $1612;
          $1614 = (($1608) + ($1613)|0);
          $1615 = HEAP8[$1614>>0]|0;
          $1616 = $1615&255;
          $1617 = HEAP8[$1555>>0]|0;
          $1618 = $1617&255;
          $1619 = (79212 + ($1618<<2)|0);
          $1620 = HEAP32[$1619>>2]|0;
          $1621 = HEAP32[$1556>>2]|0;
          $1622 = $1621 & $1580;
          $1623 = HEAP8[$1557>>0]|0;
          $1624 = $1623&255;
          $1625 = $1622 >>> $1624;
          $1626 = (($1620) + ($1625)|0);
          $1627 = HEAP8[$1626>>0]|0;
          $1628 = $1627&255;
          $1629 = $1592 & $1597;
          $1630 = $1629 >>> $1600;
          $1631 = (($1596) + ($1630)|0);
          $1632 = HEAP8[$1631>>0]|0;
          $1633 = $1632&255;
          $1634 = $1609 & $1592;
          $1635 = $1634 >>> $1612;
          $1636 = (($1608) + ($1635)|0);
          $1637 = HEAP8[$1636>>0]|0;
          $1638 = $1637&255;
          $1639 = $1621 & $1592;
          $1640 = $1639 >>> $1624;
          $1641 = (($1620) + ($1640)|0);
          $1642 = HEAP8[$1641>>0]|0;
          $1643 = $1642&255;
          $1644 = (($1604) - ($1633))|0;
          $1645 = Math_imul($1644, $95)|0;
          $1646 = $1645 >>> 8;
          $1647 = (($1646) + ($1633))|0;
          $1648 = (($1616) - ($1638))|0;
          $1649 = Math_imul($1648, $95)|0;
          $1650 = $1649 >>> 8;
          $1651 = (($1650) + ($1638))|0;
          $1652 = (($1628) - ($1643))|0;
          $1653 = Math_imul($1652, $95)|0;
          $1654 = $1653 >>> 8;
          $1655 = (($1654) + ($1643))|0;
          $1656 = $1647 >>> $1594;
          $1657 = $1656 << $1600;
          $1658 = $1651 >>> $1606;
          $1659 = $1658 << $1612;
          $1660 = $1655 >>> $1618;
          $1661 = $1660 << $1624;
          $1662 = HEAP32[$1558>>2]|0;
          $1663 = $1657 | $1662;
          $1664 = $1663 | $1659;
          $1665 = $1664 | $1661;
          $1666 = $1665&255;
          HEAP8[$$011281352>>0] = $1666;
          $1667 = $1665 >>> 8;
          $1668 = $1667&255;
          HEAP8[$1585>>0] = $1668;
          $1669 = $1665 >>> 16;
          $1670 = $1669&255;
          HEAP8[$1581>>0] = $1670;
          $1671 = ((($$011291351)) + 3|0);
          $1672 = ((($$011281352)) + 3|0);
          $1673 = (($$011301350) + 1)|0;
          $exitcond1438 = ($1673|0)==($1564|0);
          if ($exitcond1438) {
           break;
          } else {
           $$011281352 = $1672;$$011291351 = $1671;$$011301350 = $1673;
          }
         }
         $1674 = ($1564*3)|0;
         $1675 = (($1565) + ($1674)|0);
         $1676 = (($1561) + ($1564))|0;
         $$11136 = $1676;$$42 = $1675;
        }
        $1678 = ($$11136|0)==($5|0);
        if ($1678) {
         break;
        } else {
         $$01135 = $$11136;$$41 = $$42;
        }
       }
       $1679 = HEAP32[$16>>2]|0;
       $1680 = (($$27$ph) + ($1679)|0);
       $1681 = (($$01139$ph) + -1)|0;
       $1682 = ($1681|0)==(0);
       if ($1682) {
        break L54;
       } else {
        $$01139$ph = $1681;$$27$ph = $1680;$$41$ph = $$42;
       }
      }
      break;
     }
     default: {
      break L54;
     }
     }
    }
   }
   $102 = ((($2)) + 4|0);
   $103 = HEAP32[$102>>2]|0;
   $104 = ($94<<24>>24)==(-1);
   $105 = ((($103)) + 9|0);
   $106 = HEAP8[$105>>0]|0;
   if ($104) {
    switch ($106<<24>>24) {
    case 1:  {
     $107 = ((($1)) + 12|0);
     $108 = HEAP32[$107>>2]|0;
     $109 = ((($1)) + 8|0);
     $110 = HEAP32[$109>>2]|0;
     $111 = (($110) + ($96))|0;
     $112 = (0 - ($96))|0;
     $113 = (($26) + ($112)|0);
     $$0$ph$i = $$139721176;$$01279$ph$i = $113;$$01318$ph$i = $108;
     while(1) {
      $$0$i = $$0$ph$i;$$01321$i = 0;
      L263: while(1) {
       $114 = HEAP8[$$0$i>>0]|0;
       $115 = $114&255;
       $116 = (($115) + ($$01321$i))|0;
       $117 = ((($$0$i)) + 1|0);
       $118 = HEAP8[$117>>0]|0;
       $119 = $118&255;
       $120 = ((($$0$i)) + 2|0);
       $121 = ($118<<24>>24)==(0);
       if ($121) {
        $134 = ($116|0)==(0);
        if ($134) {
         break L54;
        } else {
         $$1$i = $120;$$11322$i = $116;
        }
       } else {
        $122 = ($116|0)<($111|0);
        L268: do {
         if ($122) {
          $123 = (($96) - ($116))|0;
          $124 = ($123|0)>(0);
          if ($124) {
           $125 = (($119) - ($123))|0;
           $126 = ($125|0)<(1);
           if ($126) {
            $$01328$i = 9;
           } else {
            $$01325$i = $123;$$01326$i = $125;
            label = 44;
           }
          } else {
           $$01325$i = 0;$$01326$i = $119;
           label = 44;
          }
          if ((label|0) == 44) {
           label = 0;
           $127 = (($$01325$i) + ($116))|0;
           $128 = (($111) - ($127))|0;
           $129 = ($$01326$i|0)>($128|0);
           $$$01326$i = $129 ? $128 : $$01326$i;
           $130 = (($$01279$ph$i) + ($127)|0);
           $131 = (($120) + ($$01325$i)|0);
           (_SDL_memcpy($130,$131,$$$01326$i)|0);
           $$01328$i = 0;
          }
          $trunc1519$i = $$01328$i&255;
          $trunc1519$i$clear = $trunc1519$i & 15;
          switch ($trunc1519$i$clear<<24>>24) {
          case 9: case 0:  {
           break L268;
           break;
          }
          default: {
          }
          }
          $switch$i = ($$01328$i|0)==(0);
          if ($switch$i) {
           $$0$i = $120;$$01321$i = $116;
           continue L263;
          } else {
           break L54;
          }
         }
        } while(0);
        $132 = (($120) + ($119)|0);
        $133 = (($116) + ($119))|0;
        $$1$i = $132;$$11322$i = $133;
       }
       $135 = ($$11322$i|0)==($5|0);
       if ($135) {
        break;
       } else {
        $$0$i = $$1$i;$$01321$i = $$11322$i;
       }
      }
      $136 = HEAP32[$16>>2]|0;
      $137 = (($$01279$ph$i) + ($136)|0);
      $138 = (($$01318$ph$i) + -1)|0;
      $139 = ($138|0)==(0);
      if ($139) {
       break L54;
      } else {
       $$0$ph$i = $$1$i;$$01279$ph$i = $137;$$01318$ph$i = $138;
      }
     }
     break;
    }
    case 2:  {
     $140 = ((($1)) + 12|0);
     $141 = HEAP32[$140>>2]|0;
     $142 = ((($1)) + 8|0);
     $143 = HEAP32[$142>>2]|0;
     $144 = (($143) + ($96))|0;
     $145 = $96 << 1;
     $146 = (0 - ($145))|0;
     $147 = (($26) + ($146)|0);
     $$01354$ph$i = $141;$$3$ph$i = $$139721176;$$31282$ph$i = $147;
     while(1) {
      $$01360$i = 0;$$3$i = $$3$ph$i;
      L282: while(1) {
       $148 = HEAP8[$$3$i>>0]|0;
       $149 = $148&255;
       $150 = (($149) + ($$01360$i))|0;
       $151 = ((($$3$i)) + 1|0);
       $152 = HEAP8[$151>>0]|0;
       $153 = $152&255;
       $154 = ((($$3$i)) + 2|0);
       $155 = ($152<<24>>24)==(0);
       if ($155) {
        $172 = ($150|0)==(0);
        if ($172) {
         break L54;
        } else {
         $$11361$i = $150;$$4$i = $154;
        }
       } else {
        $156 = ($150|0)<($144|0);
        L287: do {
         if ($156) {
          $157 = (($96) - ($150))|0;
          $158 = ($157|0)>(0);
          if ($158) {
           $159 = (($153) - ($157))|0;
           $160 = ($159|0)<(1);
           if ($160) {
            $$21330$i = 14;
           } else {
            $$01367$i = $157;$$01368$i = $159;
            label = 57;
           }
          } else {
           $$01367$i = 0;$$01368$i = $153;
           label = 57;
          }
          if ((label|0) == 57) {
           label = 0;
           $161 = (($$01367$i) + ($150))|0;
           $162 = (($144) - ($161))|0;
           $163 = ($$01368$i|0)>($162|0);
           $$$01368$i = $163 ? $162 : $$01368$i;
           $164 = $161 << 1;
           $165 = (($$31282$ph$i) + ($164)|0);
           $166 = $$01367$i << 1;
           $167 = (($154) + ($166)|0);
           $168 = $$$01368$i << 1;
           (_SDL_memcpy($165,$167,$168)|0);
           $$21330$i = 0;
          }
          $trunc1518$i = $$21330$i&255;
          $trunc1518$i$clear = $trunc1518$i & 15;
          switch ($trunc1518$i$clear<<24>>24) {
          case 14: case 0:  {
           break L287;
           break;
          }
          default: {
          }
          }
          $switch1$i = ($$21330$i|0)==(0);
          if ($switch1$i) {
           $$01360$i = $150;$$3$i = $154;
           continue L282;
          } else {
           break L54;
          }
         }
        } while(0);
        $169 = $153 << 1;
        $170 = (($154) + ($169)|0);
        $171 = (($150) + ($153))|0;
        $$11361$i = $171;$$4$i = $170;
       }
       $173 = ($$11361$i|0)==($5|0);
       if ($173) {
        break;
       } else {
        $$01360$i = $$11361$i;$$3$i = $$4$i;
       }
      }
      $174 = HEAP32[$16>>2]|0;
      $175 = (($$31282$ph$i) + ($174)|0);
      $176 = (($$01354$ph$i) + -1)|0;
      $177 = ($176|0)==(0);
      if ($177) {
       break L54;
      } else {
       $$01354$ph$i = $176;$$3$ph$i = $$4$i;$$31282$ph$i = $175;
      }
     }
     break;
    }
    case 3:  {
     $178 = ((($1)) + 12|0);
     $179 = HEAP32[$178>>2]|0;
     $180 = ((($1)) + 8|0);
     $181 = HEAP32[$180>>2]|0;
     $182 = (($181) + ($96))|0;
     $183 = Math_imul($96, -3)|0;
     $184 = (($26) + ($183)|0);
     $$01370$ph$i = $179;$$6$ph$i = $$139721176;$$61285$ph$i = $184;
     while(1) {
      $$01380$i = 0;$$6$i = $$6$ph$i;
      L301: while(1) {
       $185 = HEAP8[$$6$i>>0]|0;
       $186 = $185&255;
       $187 = (($186) + ($$01380$i))|0;
       $188 = ((($$6$i)) + 1|0);
       $189 = HEAP8[$188>>0]|0;
       $190 = $189&255;
       $191 = ((($$6$i)) + 2|0);
       $192 = ($189<<24>>24)==(0);
       if ($192) {
        $209 = ($187|0)==(0);
        if ($209) {
         break L54;
        } else {
         $$11381$i = $187;$$7$i = $191;
        }
       } else {
        $193 = ($187|0)<($182|0);
        L306: do {
         if ($193) {
          $194 = (($96) - ($187))|0;
          $195 = ($194|0)>(0);
          if ($195) {
           $196 = (($190) - ($194))|0;
           $197 = ($196|0)<(1);
           if ($197) {
            $$41332$i = 19;
           } else {
            $$01384$i = $194;$$01385$i = $196;
            label = 70;
           }
          } else {
           $$01384$i = 0;$$01385$i = $190;
           label = 70;
          }
          if ((label|0) == 70) {
           label = 0;
           $198 = (($$01384$i) + ($187))|0;
           $199 = (($182) - ($198))|0;
           $200 = ($$01385$i|0)>($199|0);
           $$$01385$i = $200 ? $199 : $$01385$i;
           $201 = ($198*3)|0;
           $202 = (($$61285$ph$i) + ($201)|0);
           $203 = ($$01384$i*3)|0;
           $204 = (($191) + ($203)|0);
           $205 = ($$$01385$i*3)|0;
           (_SDL_memcpy($202,$204,$205)|0);
           $$41332$i = 0;
          }
          $trunc1517$i = $$41332$i&255;
          $trunc1517$i$clear = $trunc1517$i & 31;
          switch ($trunc1517$i$clear<<24>>24) {
          case 19: case 0:  {
           break L306;
           break;
          }
          default: {
          }
          }
          $switch2$i = ($$41332$i|0)==(0);
          if ($switch2$i) {
           $$01380$i = $187;$$6$i = $191;
           continue L301;
          } else {
           break L54;
          }
         }
        } while(0);
        $206 = ($190*3)|0;
        $207 = (($191) + ($206)|0);
        $208 = (($187) + ($190))|0;
        $$11381$i = $208;$$7$i = $207;
       }
       $210 = ($$11381$i|0)==($5|0);
       if ($210) {
        break;
       } else {
        $$01380$i = $$11381$i;$$6$i = $$7$i;
       }
      }
      $211 = HEAP32[$16>>2]|0;
      $212 = (($$61285$ph$i) + ($211)|0);
      $213 = (($$01370$ph$i) + -1)|0;
      $214 = ($213|0)==(0);
      if ($214) {
       break L54;
      } else {
       $$01370$ph$i = $213;$$6$ph$i = $$7$i;$$61285$ph$i = $212;
      }
     }
     break;
    }
    case 4:  {
     $215 = ((($1)) + 12|0);
     $216 = HEAP32[$215>>2]|0;
     $217 = ((($1)) + 8|0);
     $218 = HEAP32[$217>>2]|0;
     $219 = (($218) + ($96))|0;
     $220 = $96 << 2;
     $221 = (0 - ($220))|0;
     $222 = (($26) + ($221)|0);
     $$01387$ph$i = $216;$$9$ph$i = $$139721176;$$91288$ph$i = $222;
     while(1) {
      $$01393$i = 0;$$9$i = $$9$ph$i;
      L320: while(1) {
       $223 = HEAP16[$$9$i>>1]|0;
       $224 = $223&65535;
       $225 = (($224) + ($$01393$i))|0;
       $226 = ((($$9$i)) + 2|0);
       $227 = HEAP16[$226>>1]|0;
       $228 = $227&65535;
       $229 = ((($$9$i)) + 4|0);
       $230 = ($227<<16>>16)==(0);
       if ($230) {
        $247 = ($225|0)==(0);
        if ($247) {
         break L54;
        } else {
         $$10$i = $229;$$11394$i = $225;
        }
       } else {
        $231 = ($225|0)<($219|0);
        L325: do {
         if ($231) {
          $232 = (($96) - ($225))|0;
          $233 = ($232|0)>(0);
          if ($233) {
           $234 = (($228) - ($232))|0;
           $235 = ($234|0)<(1);
           if ($235) {
            $$61334$i = 24;
           } else {
            $$01400$i = $232;$$01401$i = $234;
            label = 83;
           }
          } else {
           $$01400$i = 0;$$01401$i = $228;
           label = 83;
          }
          if ((label|0) == 83) {
           label = 0;
           $236 = (($$01400$i) + ($225))|0;
           $237 = (($219) - ($236))|0;
           $238 = ($$01401$i|0)>($237|0);
           $$$01401$i = $238 ? $237 : $$01401$i;
           $239 = $236 << 2;
           $240 = (($$91288$ph$i) + ($239)|0);
           $241 = $$01400$i << 2;
           $242 = (($229) + ($241)|0);
           $243 = $$$01401$i << 2;
           (_SDL_memcpy($240,$242,$243)|0);
           $$61334$i = 0;
          }
          $trunc1516$i = $$61334$i&255;
          $trunc1516$i$clear = $trunc1516$i & 31;
          switch ($trunc1516$i$clear<<24>>24) {
          case 24: case 0:  {
           break L325;
           break;
          }
          default: {
          }
          }
          $switch3$i = ($$61334$i|0)==(0);
          if ($switch3$i) {
           $$01393$i = $225;$$9$i = $229;
           continue L320;
          } else {
           break L54;
          }
         }
        } while(0);
        $244 = $228 << 2;
        $245 = (($229) + ($244)|0);
        $246 = (($225) + ($228))|0;
        $$10$i = $245;$$11394$i = $246;
       }
       $248 = ($$11394$i|0)==($5|0);
       if ($248) {
        break;
       } else {
        $$01393$i = $$11394$i;$$9$i = $$10$i;
       }
      }
      $249 = HEAP32[$16>>2]|0;
      $250 = (($$91288$ph$i) + ($249)|0);
      $251 = (($$01387$ph$i) + -1)|0;
      $252 = ($251|0)==(0);
      if ($252) {
       break L54;
      } else {
       $$01387$ph$i = $251;$$9$ph$i = $$10$i;$$91288$ph$i = $250;
      }
     }
     break;
    }
    default: {
     break L54;
    }
    }
   }
   switch ($106<<24>>24) {
   case 4:  {
    $853 = ((($103)) + 12|0);
    $854 = HEAP32[$853>>2]|0;
    $855 = ((($103)) + 16|0);
    $856 = HEAP32[$855>>2]|0;
    $857 = $856 | $854;
    $858 = ((($103)) + 20|0);
    $859 = HEAP32[$858>>2]|0;
    $860 = $857 | $859;
    $861 = ($860|0)==(16777215);
    if ($861) {
     $862 = ($856|0)==(65280);
     $863 = ($854|0)==(65280);
     $or$cond1523$i = $863 | $862;
     $864 = ($859|0)==(65280);
     $or$cond1524$i = $or$cond1523$i | $864;
     if ($or$cond1524$i) {
      $865 = ($94<<24>>24)==(-128);
      $866 = ((($1)) + 8|0);
      $867 = HEAP32[$866>>2]|0;
      $868 = ((($1)) + 12|0);
      $869 = HEAP32[$868>>2]|0;
      $870 = $96 << 2;
      $871 = (0 - ($870))|0;
      $872 = (($96) + ($867))|0;
      $873 = (($26) + ($871)|0);
      if ($865) {
       $$01436$ph$i = $869;$$30$ph$i = $$139721176;$$301309$ph$i = $873;
       while(1) {
        $$01432$i = 0;$$30$i = $$30$ph$i;
        L345: while(1) {
         $874 = HEAP16[$$30$i>>1]|0;
         $875 = $874&65535;
         $876 = (($875) + ($$01432$i))|0;
         $877 = ((($$30$i)) + 2|0);
         $878 = HEAP16[$877>>1]|0;
         $879 = $878&65535;
         $880 = ((($$30$i)) + 4|0);
         $881 = ($878<<16>>16)==(0);
         if ($881) {
          $911 = ($876|0)==(0);
          if ($911) {
           break L54;
          } else {
           $$11433$i = $876;$$31$i = $880;
          }
         } else {
          $882 = ($876|0)<($872|0);
          L350: do {
           if ($882) {
            $883 = (($96) - ($876))|0;
            $884 = ($883|0)>(0);
            if ($884) {
             $885 = (($879) - ($883))|0;
             $886 = ($885|0)<(1);
             if ($886) {
              $$201348$i = 108;
             } else {
              $$01423$i = $885;$$01425$i = $883;
              label = 208;
             }
            } else {
             $$01423$i = $879;$$01425$i = 0;
             label = 208;
            }
            if ((label|0) == 208) {
             label = 0;
             $887 = (($$01425$i) + ($876))|0;
             $888 = (($872) - ($887))|0;
             $889 = ($$01423$i|0)>($888|0);
             $$$01423$i = $889 ? $888 : $$01423$i;
             $890 = ($$$01423$i|0)>(0);
             if ($890) {
              $891 = $887 << 2;
              $892 = (($$301309$ph$i) + ($891)|0);
              $893 = $$01425$i << 2;
              $894 = (($880) + ($893)|0);
              $$014181624$i = $892;$$014191623$i = $894;$$014201622$i = 0;
              while(1) {
               $895 = ((($$014191623$i)) + 4|0);
               $896 = HEAP32[$$014191623$i>>2]|0;
               $897 = HEAP32[$$014181624$i>>2]|0;
               $898 = $896 & 16711422;
               $899 = $897 & 16711422;
               $900 = (($899) + ($898))|0;
               $901 = $900 >>> 1;
               $902 = $896 & 65793;
               $903 = $902 & $897;
               $904 = (($901) + ($903))|0;
               $905 = ((($$014181624$i)) + 4|0);
               HEAP32[$$014181624$i>>2] = $904;
               $906 = (($$014201622$i) + 1)|0;
               $907 = ($906|0)<($$$01423$i|0);
               if ($907) {
                $$014181624$i = $905;$$014191623$i = $895;$$014201622$i = $906;
               } else {
                $$201348$i = 0;
                break;
               }
              }
             } else {
              $$201348$i = 0;
             }
            }
            $trunc1514$i = $$201348$i&255;
            $trunc1514$i$clear = $trunc1514$i & 127;
            switch ($trunc1514$i$clear<<24>>24) {
            case 108: case 0:  {
             break L350;
             break;
            }
            default: {
            }
            }
            $switch10$i = ($$201348$i|0)==(0);
            if ($switch10$i) {
             $$01432$i = $876;$$30$i = $880;
             continue L345;
            } else {
             break L54;
            }
           }
          } while(0);
          $908 = $879 << 2;
          $909 = (($880) + ($908)|0);
          $910 = (($876) + ($879))|0;
          $$11433$i = $910;$$31$i = $909;
         }
         $912 = ($$11433$i|0)==($5|0);
         if ($912) {
          break;
         } else {
          $$01432$i = $$11433$i;$$30$i = $$31$i;
         }
        }
        $913 = HEAP32[$16>>2]|0;
        $914 = (($$301309$ph$i) + ($913)|0);
        $915 = (($$01436$ph$i) + -1)|0;
        $916 = ($915|0)==(0);
        if ($916) {
         break L54;
        } else {
         $$01436$ph$i = $915;$$30$ph$i = $$31$i;$$301309$ph$i = $914;
        }
       }
      } else {
       $$01410$ph$i = $869;$$33$ph$i = $$139721176;$$331312$ph$i = $873;
       while(1) {
        $$01406$i = 0;$$33$i = $$33$ph$i;
        L366: while(1) {
         $917 = HEAP16[$$33$i>>1]|0;
         $918 = $917&65535;
         $919 = (($918) + ($$01406$i))|0;
         $920 = ((($$33$i)) + 2|0);
         $921 = HEAP16[$920>>1]|0;
         $922 = $921&65535;
         $923 = ((($$33$i)) + 4|0);
         $924 = ($921<<16>>16)==(0);
         if ($924) {
          $962 = ($919|0)==(0);
          if ($962) {
           break L54;
          } else {
           $$11407$i = $919;$$34$i = $923;
          }
         } else {
          $925 = ($919|0)<($872|0);
          L371: do {
           if ($925) {
            $926 = (($96) - ($919))|0;
            $927 = ($926|0)>(0);
            if ($927) {
             $928 = (($922) - ($926))|0;
             $929 = ($928|0)<(1);
             if ($929) {
              $$221350$i = 118;
             } else {
              $$01397$i = $928;$$01399$i = $926;
              label = 221;
             }
            } else {
             $$01397$i = $922;$$01399$i = 0;
             label = 221;
            }
            if ((label|0) == 221) {
             label = 0;
             $930 = (($$01399$i) + ($919))|0;
             $931 = (($872) - ($930))|0;
             $932 = ($$01397$i|0)>($931|0);
             $$$01397$i = $932 ? $931 : $$01397$i;
             $933 = ($$$01397$i|0)>(0);
             if ($933) {
              $934 = $930 << 2;
              $935 = (($$331312$ph$i) + ($934)|0);
              $936 = $$01399$i << 2;
              $937 = (($923) + ($936)|0);
              $$013901627$i = $935;$$013911626$i = $937;$$013921625$i = 0;
              while(1) {
               $938 = ((($$013911626$i)) + 4|0);
               $939 = HEAP32[$$013911626$i>>2]|0;
               $940 = HEAP32[$$013901627$i>>2]|0;
               $941 = $939 & 16711935;
               $942 = $940 & 16711935;
               $943 = (($941) - ($942))|0;
               $944 = Math_imul($943, $95)|0;
               $945 = $944 >>> 8;
               $946 = (($945) + ($942))|0;
               $947 = $946 & 16711935;
               $948 = $939 & 65280;
               $949 = $940 & 65280;
               $950 = (($948) - ($949))|0;
               $951 = Math_imul($950, $95)|0;
               $952 = $951 >>> 8;
               $953 = (($952) + ($949))|0;
               $954 = $953 & 65280;
               $955 = $947 | $954;
               $956 = ((($$013901627$i)) + 4|0);
               HEAP32[$$013901627$i>>2] = $955;
               $957 = (($$013921625$i) + 1)|0;
               $958 = ($957|0)<($$$01397$i|0);
               if ($958) {
                $$013901627$i = $956;$$013911626$i = $938;$$013921625$i = $957;
               } else {
                $$221350$i = 0;
                break;
               }
              }
             } else {
              $$221350$i = 0;
             }
            }
            $trunc1513$i = $$221350$i&255;
            $trunc1513$i$clear = $trunc1513$i & 127;
            switch ($trunc1513$i$clear<<24>>24) {
            case 118: case 0:  {
             break L371;
             break;
            }
            default: {
            }
            }
            $switch11$i = ($$221350$i|0)==(0);
            if ($switch11$i) {
             $$01406$i = $919;$$33$i = $923;
             continue L366;
            } else {
             break L54;
            }
           }
          } while(0);
          $959 = $922 << 2;
          $960 = (($923) + ($959)|0);
          $961 = (($919) + ($922))|0;
          $$11407$i = $961;$$34$i = $960;
         }
         $963 = ($$11407$i|0)==($5|0);
         if ($963) {
          break;
         } else {
          $$01406$i = $$11407$i;$$33$i = $$34$i;
         }
        }
        $964 = HEAP32[$16>>2]|0;
        $965 = (($$331312$ph$i) + ($964)|0);
        $966 = (($$01410$ph$i) + -1)|0;
        $967 = ($966|0)==(0);
        if ($967) {
         break L54;
        } else {
         $$01410$ph$i = $966;$$33$ph$i = $$34$i;$$331312$ph$i = $965;
        }
       }
      }
     }
    }
    $968 = ((($1)) + 12|0);
    $969 = HEAP32[$968>>2]|0;
    $970 = ((($1)) + 8|0);
    $971 = HEAP32[$970>>2]|0;
    $972 = (($971) + ($96))|0;
    $973 = $96 << 2;
    $974 = (0 - ($973))|0;
    $975 = (($26) + ($974)|0);
    $976 = ((($103)) + 28|0);
    $977 = ((($103)) + 32|0);
    $978 = ((($103)) + 29|0);
    $979 = ((($103)) + 33|0);
    $980 = ((($103)) + 30|0);
    $981 = ((($103)) + 34|0);
    $982 = ((($103)) + 24|0);
    $$01377$ph$i = $969;$$36$ph$i = $$139721176;$$361315$ph$i = $975;
    while(1) {
     $$01373$i = 0;$$36$i = $$36$ph$i;
     while(1) {
      $983 = HEAP16[$$36$i>>1]|0;
      $984 = $983&65535;
      $985 = (($984) + ($$01373$i))|0;
      $986 = ((($$36$i)) + 2|0);
      $987 = HEAP16[$986>>1]|0;
      $988 = $987&65535;
      $989 = ((($$36$i)) + 4|0);
      $990 = ($987<<16>>16)==(0);
      if ($990) {
       $1071 = ($985|0)==(0);
       if ($1071) {
        break L54;
       } else {
        $$11374$i = $985;$$37$i = $989;
       }
      } else {
       $991 = ($985|0)<($972|0);
       do {
        if ($991) {
         $992 = (($96) - ($985))|0;
         $993 = ($992|0)>(0);
         if ($993) {
          $994 = (($988) - ($992))|0;
          $995 = ($994|0)<(1);
          if ($995) {
           break;
          } else {
           $$01364$i = $994;$$01366$i = $992;
          }
         } else {
          $$01364$i = $988;$$01366$i = 0;
         }
         $996 = (($$01366$i) + ($985))|0;
         $997 = (($972) - ($996))|0;
         $998 = ($$01364$i|0)>($997|0);
         $$$01364$i = $998 ? $997 : $$01364$i;
         $999 = ($$$01364$i|0)>(0);
         if ($999) {
          $1000 = $996 << 2;
          $1001 = (($$361315$ph$i) + ($1000)|0);
          $1002 = $$01366$i << 2;
          $1003 = (($989) + ($1002)|0);
          $$pre1453 = HEAP8[$976>>0]|0;
          $$phi$trans$insert1454 = $$pre1453&255;
          $$phi$trans$insert1455 = (79212 + ($$phi$trans$insert1454<<2)|0);
          $$pre1456 = HEAP32[$$phi$trans$insert1455>>2]|0;
          $$pre1457 = HEAP8[$977>>0]|0;
          $$pre1458 = HEAP8[$978>>0]|0;
          $$phi$trans$insert1459 = $$pre1458&255;
          $$phi$trans$insert1460 = (79212 + ($$phi$trans$insert1459<<2)|0);
          $$pre1461 = HEAP32[$$phi$trans$insert1460>>2]|0;
          $$pre1462 = HEAP8[$979>>0]|0;
          $$pre1463 = HEAP8[$980>>0]|0;
          $$phi$trans$insert1464 = $$pre1463&255;
          $$phi$trans$insert1465 = (79212 + ($$phi$trans$insert1464<<2)|0);
          $$pre1466 = HEAP32[$$phi$trans$insert1465>>2]|0;
          $$pre1467 = HEAP8[$981>>0]|0;
          $1004 = $$pre1457&255;
          $1005 = $$pre1462&255;
          $1006 = $$pre1467&255;
          $$013571631$i = $1001;$$013581630$i = $1003;$$013591629$i = 0;
          while(1) {
           $1007 = HEAP32[$$013581630$i>>2]|0;
           $1008 = HEAP32[$$013571631$i>>2]|0;
           $1009 = HEAP32[$853>>2]|0;
           $1010 = $1009 & $1007;
           $1011 = $1010 >>> $1004;
           $1012 = (($$pre1456) + ($1011)|0);
           $1013 = HEAP8[$1012>>0]|0;
           $1014 = $1013&255;
           $1015 = HEAP32[$855>>2]|0;
           $1016 = $1015 & $1007;
           $1017 = $1016 >>> $1005;
           $1018 = (($$pre1461) + ($1017)|0);
           $1019 = HEAP8[$1018>>0]|0;
           $1020 = $1019&255;
           $1021 = HEAP32[$858>>2]|0;
           $1022 = $1021 & $1007;
           $1023 = $1022 >>> $1006;
           $1024 = (($$pre1466) + ($1023)|0);
           $1025 = HEAP8[$1024>>0]|0;
           $1026 = $1025&255;
           $1027 = $1009 & $1008;
           $1028 = $1027 >>> $1004;
           $1029 = (($$pre1456) + ($1028)|0);
           $1030 = HEAP8[$1029>>0]|0;
           $1031 = $1030&255;
           $1032 = $1015 & $1008;
           $1033 = $1032 >>> $1005;
           $1034 = (($$pre1461) + ($1033)|0);
           $1035 = HEAP8[$1034>>0]|0;
           $1036 = $1035&255;
           $1037 = $1021 & $1008;
           $1038 = $1037 >>> $1006;
           $1039 = (($$pre1466) + ($1038)|0);
           $1040 = HEAP8[$1039>>0]|0;
           $1041 = $1040&255;
           $1042 = (($1014) - ($1031))|0;
           $1043 = Math_imul($1042, $95)|0;
           $1044 = $1043 >>> 8;
           $1045 = (($1044) + ($1031))|0;
           $1046 = (($1020) - ($1036))|0;
           $1047 = Math_imul($1046, $95)|0;
           $1048 = $1047 >>> 8;
           $1049 = (($1048) + ($1036))|0;
           $1050 = (($1026) - ($1041))|0;
           $1051 = Math_imul($1050, $95)|0;
           $1052 = $1051 >>> 8;
           $1053 = (($1052) + ($1041))|0;
           $1054 = $1045 >>> $$phi$trans$insert1454;
           $1055 = $1054 << $1004;
           $1056 = $1049 >>> $$phi$trans$insert1459;
           $1057 = $1056 << $1005;
           $1058 = $1053 >>> $$phi$trans$insert1464;
           $1059 = $1058 << $1006;
           $1060 = HEAP32[$982>>2]|0;
           $1061 = $1055 | $1060;
           $1062 = $1061 | $1057;
           $1063 = $1062 | $1059;
           HEAP32[$$013571631$i>>2] = $1063;
           $1064 = ((($$013581630$i)) + 4|0);
           $1065 = ((($$013571631$i)) + 4|0);
           $1066 = (($$013591629$i) + 1)|0;
           $1067 = ($1066|0)<($$$01364$i|0);
           if ($1067) {
            $$013571631$i = $1065;$$013581630$i = $1064;$$013591629$i = $1066;
           } else {
            break;
           }
          }
         }
        }
       } while(0);
       $1068 = $988 << 2;
       $1069 = (($989) + ($1068)|0);
       $1070 = (($985) + ($988))|0;
       $$11374$i = $1070;$$37$i = $1069;
      }
      $1072 = ($$11374$i|0)==($5|0);
      if ($1072) {
       break;
      } else {
       $$01373$i = $$11374$i;$$36$i = $$37$i;
      }
     }
     $1073 = HEAP32[$16>>2]|0;
     $1074 = (($$361315$ph$i) + ($1073)|0);
     $1075 = (($$01377$ph$i) + -1)|0;
     $1076 = ($1075|0)==(0);
     if ($1076) {
      break;
     } else {
      $$01377$ph$i = $1075;$$36$ph$i = $$37$i;$$361315$ph$i = $1074;
     }
    }
    break;
   }
   case 2:  {
    $253 = ((($103)) + 12|0);
    $254 = HEAP32[$253>>2]|0;
    $255 = ((($103)) + 16|0);
    $256 = HEAP32[$255>>2]|0;
    $257 = $256 | $254;
    $258 = ((($103)) + 20|0);
    $259 = HEAP32[$258>>2]|0;
    $260 = $257 | $259;
    $switch$split2D = ($260|0)<(65535);
    L405: do {
     if ($switch$split2D) {
      switch ($260|0) {
      case 32767:  {
       break;
      }
      default: {
       break L405;
      }
      }
      $427 = ($256|0)==(992);
      $428 = ($254|0)==(992);
      $or$cond1521$i = $428 | $427;
      $429 = ($259|0)==(992);
      $or$cond1522$i = $or$cond1521$i | $429;
      if ($or$cond1522$i) {
       $430 = ($94<<24>>24)==(-128);
       $431 = ((($1)) + 8|0);
       $432 = HEAP32[$431>>2]|0;
       $433 = ((($1)) + 12|0);
       $434 = HEAP32[$433>>2]|0;
       $435 = $96 << 1;
       $436 = (($96) + ($432))|0;
       $437 = (0 - ($435))|0;
       $438 = (($26) + ($437)|0);
       if ($430) {
        $$01452$ph$i = $434;$$18$ph$i = $$139721176;$$181297$ph$i = $438;
       } else {
        $439 = $95 >>> 3;
        $$01481$ph$i = $434;$$21$ph$i = $$139721176;$$211300$ph$i = $438;
        while(1) {
         $$01484$i = 0;$$21$i = $$21$ph$i;
         L413: while(1) {
          $542 = HEAP8[$$21$i>>0]|0;
          $543 = $542&255;
          $544 = (($543) + ($$01484$i))|0;
          $545 = ((($$21$i)) + 1|0);
          $546 = HEAP8[$545>>0]|0;
          $547 = $546&255;
          $548 = ((($$21$i)) + 2|0);
          $549 = ($546<<24>>24)==(0);
          if ($549) {
           $588 = ($544|0)==(0);
           if ($588) {
            break L54;
           } else {
            $$11485$i = $544;$$22$i = $548;
           }
          } else {
           $550 = ($544|0)<($436|0);
           L418: do {
            if ($550) {
             $551 = (($96) - ($544))|0;
             $552 = ($551|0)>(0);
             if ($552) {
              $553 = (($547) - ($551))|0;
              $554 = ($553|0)<(1);
              if ($554) {
               $$141342$i = 78;
              } else {
               $$01488$i = $551;$$01489$i = $553;
               label = 160;
              }
             } else {
              $$01488$i = 0;$$01489$i = $547;
              label = 160;
             }
             if ((label|0) == 160) {
              label = 0;
              $555 = (($$01488$i) + ($544))|0;
              $556 = (($436) - ($555))|0;
              $557 = ($$01489$i|0)>($556|0);
              $$$01489$i = $557 ? $556 : $$01489$i;
              $558 = ($$$01489$i|0)>(0);
              if ($558) {
               $559 = $555 << 1;
               $560 = (($$211300$ph$i) + ($559)|0);
               $561 = $$01488$i << 1;
               $562 = (($548) + ($561)|0);
               $$014911666$i = 0;$$014921665$i = $562;$$014961664$i = $560;
               while(1) {
                $563 = ((($$014921665$i)) + 2|0);
                $564 = HEAP16[$$014921665$i>>1]|0;
                $565 = $564&65535;
                $566 = HEAP16[$$014961664$i>>1]|0;
                $567 = $566&65535;
                $568 = $565 << 16;
                $569 = $568 | $565;
                $570 = $569 & 65043487;
                $571 = $567 << 16;
                $572 = $571 | $567;
                $573 = $572 & 65043487;
                $574 = (($570) - ($573))|0;
                $575 = Math_imul($574, $439)|0;
                $576 = $575 >>> 5;
                $577 = (($576) + ($573))|0;
                $578 = $577 & 65043487;
                $579 = $578 >>> 16;
                $580 = $579 | $578;
                $581 = $580&65535;
                $582 = ((($$014961664$i)) + 2|0);
                HEAP16[$$014961664$i>>1] = $581;
                $583 = (($$014911666$i) + 1)|0;
                $584 = ($583|0)<($$$01489$i|0);
                if ($584) {
                 $$014911666$i = $583;$$014921665$i = $563;$$014961664$i = $582;
                } else {
                 $$141342$i = 0;
                 break;
                }
               }
              } else {
               $$141342$i = 0;
              }
             }
             $trunc1508$i = $$141342$i&255;
             $trunc1508$i$clear = $trunc1508$i & 127;
             switch ($trunc1508$i$clear<<24>>24) {
             case 78: case 0:  {
              break L418;
              break;
             }
             default: {
             }
             }
             $switch7$i = ($$141342$i|0)==(0);
             if ($switch7$i) {
              $$01484$i = $544;$$21$i = $548;
              continue L413;
             } else {
              break L54;
             }
            }
           } while(0);
           $585 = $547 << 1;
           $586 = (($548) + ($585)|0);
           $587 = (($544) + ($547))|0;
           $$11485$i = $587;$$22$i = $586;
          }
          $589 = ($$11485$i|0)==($5|0);
          if ($589) {
           break;
          } else {
           $$01484$i = $$11485$i;$$21$i = $$22$i;
          }
         }
         $590 = (($$211300$ph$i) + ($17)|0);
         $591 = (($$01481$ph$i) + -1)|0;
         $592 = ($591|0)==(0);
         if ($592) {
          break L54;
         } else {
          $$01481$ph$i = $591;$$21$ph$i = $$22$i;$$211300$ph$i = $590;
         }
        }
       }
       while(1) {
        $$01458$i = 0;$$18$i = $$18$ph$i;
        L434: while(1) {
         $440 = HEAP8[$$18$i>>0]|0;
         $441 = $440&255;
         $442 = (($441) + ($$01458$i))|0;
         $443 = ((($$18$i)) + 1|0);
         $444 = HEAP8[$443>>0]|0;
         $445 = $444&255;
         $446 = ((($$18$i)) + 2|0);
         $447 = ($444<<24>>24)==(0);
         if ($447) {
          $536 = ($442|0)==(0);
          if ($536) {
           break L54;
          } else {
           $$11459$i = $442;$$19$i = $446;
          }
         } else {
          $448 = ($442|0)<($436|0);
          L439: do {
           if ($448) {
            $449 = (($96) - ($442))|0;
            $450 = ($449|0)>(0);
            if ($450) {
             $451 = (($445) - ($449))|0;
             $452 = ($451|0)<(1);
             if ($452) {
              $$121340$i = 60;
             } else {
              $$01465$i = $449;$$01466$i = $451;
              label = 139;
             }
            } else {
             $$01465$i = 0;$$01466$i = $445;
             label = 139;
            }
            L443: do {
             if ((label|0) == 139) {
              label = 0;
              $453 = (($$01465$i) + ($442))|0;
              $454 = (($436) - ($453))|0;
              $455 = ($$01466$i|0)>($454|0);
              $$$01466$i = $455 ? $454 : $$01466$i;
              $456 = $$01465$i << 1;
              $457 = (($446) + ($456)|0);
              $458 = $453 << 1;
              $459 = (($$181297$ph$i) + ($458)|0);
              $460 = $457;
              $461 = $459;
              $462 = $461 ^ $460;
              $463 = $462 & 3;
              $464 = ($463|0)==(0);
              if (!($464)) {
               $465 = ($$$01466$i|0)==(0);
               if ($465) {
                $$121340$i = 0;
                break;
               } else {
                $$014681654$i = $$$01466$i;$$014771653$i = $457;$$014791652$i = $459;
               }
               while(1) {
                $466 = (($$014681654$i) + -1)|0;
                $467 = ((($$014771653$i)) + 2|0);
                $468 = HEAP16[$$014771653$i>>1]|0;
                $469 = HEAP16[$$014791652$i>>1]|0;
                $470 = $468 & -1058;
                $471 = $470&65535;
                $472 = $469 & -1058;
                $473 = $472&65535;
                $474 = (($473) + ($471))|0;
                $475 = $474 >>> 1;
                $476 = $468 & 1057;
                $477 = $476 & $469;
                $478 = $477&65535;
                $479 = (($475) + ($478))|0;
                $480 = $479&65535;
                $481 = ((($$014791652$i)) + 2|0);
                HEAP16[$$014791652$i>>1] = $480;
                $482 = ($466|0)==(0);
                if ($482) {
                 $$121340$i = 0;
                 break L443;
                } else {
                 $$014681654$i = $466;$$014771653$i = $467;$$014791652$i = $481;
                }
               }
              }
              $483 = $460 & 3;
              $484 = ($483|0)==(0);
              if ($484) {
               $$11469$ph$i = $$$01466$i;$$11478$ph$i = $457;$$11480$ph$i = $459;
              } else {
               $485 = ((($457)) + 2|0);
               $486 = HEAP16[$457>>1]|0;
               $487 = HEAP16[$459>>1]|0;
               $488 = $486 & -1058;
               $489 = $488&65535;
               $490 = $487 & -1058;
               $491 = $490&65535;
               $492 = (($491) + ($489))|0;
               $493 = $492 >>> 1;
               $494 = $486 & 1057;
               $495 = $494 & $487;
               $496 = $495&65535;
               $497 = (($493) + ($496))|0;
               $498 = $497&65535;
               $499 = ((($459)) + 2|0);
               HEAP16[$459>>1] = $498;
               $500 = (($$$01466$i) + -1)|0;
               $$11469$ph$i = $500;$$11478$ph$i = $485;$$11480$ph$i = $499;
              }
              $501 = ($$11469$ph$i>>>0)>(1);
              if ($501) {
               $502 = (($$11469$ph$i) + -2)|0;
               $scevgep1709$i = ((($$11480$ph$i)) + 4|0);
               $$114691658$i = $$11469$ph$i;$$114781657$i = $$11478$ph$i;$$114801656$i = $$11480$ph$i;
               while(1) {
                $503 = HEAP32[$$114781657$i>>2]|0;
                $504 = HEAP32[$$114801656$i>>2]|0;
                $505 = $503 >>> 1;
                $506 = $505 & 2112847343;
                $507 = $504 >>> 1;
                $508 = $507 & 2112847343;
                $509 = $503 & 69272609;
                $510 = $509 & $504;
                $511 = (($510) + ($506))|0;
                $512 = (($511) + ($508))|0;
                HEAP32[$$114801656$i>>2] = $512;
                $513 = ((($$114781657$i)) + 4|0);
                $514 = ((($$114801656$i)) + 4|0);
                $515 = (($$114691658$i) + -2)|0;
                $516 = ($515>>>0)>(1);
                if ($516) {
                 $$114691658$i = $515;$$114781657$i = $513;$$114801656$i = $514;
                } else {
                 break;
                }
               }
               $517 = $502 & -2;
               $scevgep1710$i = (($scevgep1709$i) + ($517<<1)|0);
               $scevgep1707$i = ((($$11478$ph$i)) + 4|0);
               $scevgep1708$i = (($scevgep1707$i) + ($517<<1)|0);
               $518 = (($502) - ($517))|0;
               $$11469$lcssa$i = $518;$$11478$lcssa$i = $scevgep1708$i;$$11480$lcssa$i = $scevgep1710$i;
              } else {
               $$11469$lcssa$i = $$11469$ph$i;$$11478$lcssa$i = $$11478$ph$i;$$11480$lcssa$i = $$11480$ph$i;
              }
              $519 = ($$11469$lcssa$i|0)==(0);
              if ($519) {
               $$121340$i = 0;
               break;
              }
              $520 = HEAP16[$$11478$lcssa$i>>1]|0;
              $521 = HEAP16[$$11480$lcssa$i>>1]|0;
              $522 = $520 & -1058;
              $523 = $522&65535;
              $524 = $521 & -1058;
              $525 = $524&65535;
              $526 = (($525) + ($523))|0;
              $527 = $526 >>> 1;
              $528 = $520 & 1057;
              $529 = $528 & $521;
              $530 = $529&65535;
              $531 = (($527) + ($530))|0;
              $532 = $531&65535;
              HEAP16[$$11480$lcssa$i>>1] = $532;
              $$121340$i = 0;
             }
            } while(0);
            $trunc1509$i = $$121340$i&255;
            $trunc1509$i$clear = $trunc1509$i & 63;
            switch ($trunc1509$i$clear<<24>>24) {
            case 60: case 0:  {
             break L439;
             break;
            }
            default: {
            }
            }
            $switch6$i = ($$121340$i|0)==(0);
            if ($switch6$i) {
             $$01458$i = $442;$$18$i = $446;
             continue L434;
            } else {
             break L54;
            }
           }
          } while(0);
          $533 = $445 << 1;
          $534 = (($446) + ($533)|0);
          $535 = (($442) + ($445))|0;
          $$11459$i = $535;$$19$i = $534;
         }
         $537 = ($$11459$i|0)==($5|0);
         if ($537) {
          break;
         } else {
          $$01458$i = $$11459$i;$$18$i = $$19$i;
         }
        }
        $538 = HEAP32[$16>>2]|0;
        $539 = (($$181297$ph$i) + ($538)|0);
        $540 = (($$01452$ph$i) + -1)|0;
        $541 = ($540|0)==(0);
        if ($541) {
         break L54;
        } else {
         $$01452$ph$i = $540;$$18$ph$i = $$19$i;$$181297$ph$i = $539;
        }
       }
      }
     } else {
      switch ($260|0) {
      case 65535:  {
       break;
      }
      default: {
       break L405;
      }
      }
      $261 = ($256|0)==(2016);
      $262 = ($254|0)==(2016);
      $or$cond$i = $262 | $261;
      $263 = ($259|0)==(2016);
      $or$cond1520$i = $or$cond$i | $263;
      if ($or$cond1520$i) {
       $264 = ($94<<24>>24)==(-128);
       $265 = ((($1)) + 8|0);
       $266 = HEAP32[$265>>2]|0;
       $267 = ((($1)) + 12|0);
       $268 = HEAP32[$267>>2]|0;
       $269 = $96 << 1;
       $270 = (($96) + ($266))|0;
       $271 = (0 - ($269))|0;
       $272 = (($26) + ($271)|0);
       if ($264) {
        $$01403$ph$i = $268;$$12$ph$i = $$139721176;$$121291$ph$i = $272;
       } else {
        $273 = $95 >>> 3;
        $$01439$ph$i = $268;$$15$ph$i = $$139721176;$$151294$ph$i = $272;
        while(1) {
         $$01442$i = 0;$$15$i = $$15$ph$i;
         L472: while(1) {
          $376 = HEAP8[$$15$i>>0]|0;
          $377 = $376&255;
          $378 = (($377) + ($$01442$i))|0;
          $379 = ((($$15$i)) + 1|0);
          $380 = HEAP8[$379>>0]|0;
          $381 = $380&255;
          $382 = ((($$15$i)) + 2|0);
          $383 = ($380<<24>>24)==(0);
          if ($383) {
           $422 = ($378|0)==(0);
           if ($422) {
            break L54;
           } else {
            $$11443$i = $378;$$16$i = $382;
           }
          } else {
           $384 = ($378|0)<($270|0);
           L477: do {
            if ($384) {
             $385 = (($96) - ($378))|0;
             $386 = ($385|0)>(0);
             if ($386) {
              $387 = (($381) - ($385))|0;
              $388 = ($387|0)<(1);
              if ($388) {
               $$101338$i = 49;
              } else {
               $$01446$i = $385;$$01447$i = $387;
               label = 121;
              }
             } else {
              $$01446$i = 0;$$01447$i = $381;
              label = 121;
             }
             if ((label|0) == 121) {
              label = 0;
              $389 = (($$01446$i) + ($378))|0;
              $390 = (($270) - ($389))|0;
              $391 = ($$01447$i|0)>($390|0);
              $$$01447$i = $391 ? $390 : $$01447$i;
              $392 = ($$$01447$i|0)>(0);
              if ($392) {
               $393 = $389 << 1;
               $394 = (($$151294$ph$i) + ($393)|0);
               $395 = $$01446$i << 1;
               $396 = (($382) + ($395)|0);
               $$014491649$i = 0;$$014501648$i = $396;$$014511647$i = $394;
               while(1) {
                $397 = ((($$014501648$i)) + 2|0);
                $398 = HEAP16[$$014501648$i>>1]|0;
                $399 = $398&65535;
                $400 = HEAP16[$$014511647$i>>1]|0;
                $401 = $400&65535;
                $402 = $399 << 16;
                $403 = $402 | $399;
                $404 = $403 & 132184095;
                $405 = $401 << 16;
                $406 = $405 | $401;
                $407 = $406 & 132184095;
                $408 = (($404) - ($407))|0;
                $409 = Math_imul($408, $273)|0;
                $410 = $409 >>> 5;
                $411 = (($410) + ($407))|0;
                $412 = $411 & 132184095;
                $413 = $412 >>> 16;
                $414 = $413 | $412;
                $415 = $414&65535;
                $416 = ((($$014511647$i)) + 2|0);
                HEAP16[$$014511647$i>>1] = $415;
                $417 = (($$014491649$i) + 1)|0;
                $418 = ($417|0)<($$$01447$i|0);
                if ($418) {
                 $$014491649$i = $417;$$014501648$i = $397;$$014511647$i = $416;
                } else {
                 $$101338$i = 0;
                 break;
                }
               }
              } else {
               $$101338$i = 0;
              }
             }
             $trunc1510$i = $$101338$i&255;
             $trunc1510$i$clear = $trunc1510$i & 63;
             switch ($trunc1510$i$clear<<24>>24) {
             case 49: case 0:  {
              break L477;
              break;
             }
             default: {
             }
             }
             $switch5$i = ($$101338$i|0)==(0);
             if ($switch5$i) {
              $$01442$i = $378;$$15$i = $382;
              continue L472;
             } else {
              break L54;
             }
            }
           } while(0);
           $419 = $381 << 1;
           $420 = (($382) + ($419)|0);
           $421 = (($378) + ($381))|0;
           $$11443$i = $421;$$16$i = $420;
          }
          $423 = ($$11443$i|0)==($5|0);
          if ($423) {
           break;
          } else {
           $$01442$i = $$11443$i;$$15$i = $$16$i;
          }
         }
         $424 = (($$151294$ph$i) + ($17)|0);
         $425 = (($$01439$ph$i) + -1)|0;
         $426 = ($425|0)==(0);
         if ($426) {
          break L54;
         } else {
          $$01439$ph$i = $425;$$15$ph$i = $$16$i;$$151294$ph$i = $424;
         }
        }
       }
       while(1) {
        $$01413$i = 0;$$12$i = $$12$ph$i;
        L493: while(1) {
         $274 = HEAP8[$$12$i>>0]|0;
         $275 = $274&255;
         $276 = (($275) + ($$01413$i))|0;
         $277 = ((($$12$i)) + 1|0);
         $278 = HEAP8[$277>>0]|0;
         $279 = $278&255;
         $280 = ((($$12$i)) + 2|0);
         $281 = ($278<<24>>24)==(0);
         if ($281) {
          $370 = ($276|0)==(0);
          if ($370) {
           break L54;
          } else {
           $$11414$i = $276;$$13$i = $280;
          }
         } else {
          $282 = ($276|0)<($270|0);
          L498: do {
           if ($282) {
            $283 = (($96) - ($276))|0;
            $284 = ($283|0)>(0);
            if ($284) {
             $285 = (($279) - ($283))|0;
             $286 = ($285|0)<(1);
             if ($286) {
              $$81336$i = 31;
             } else {
              $$01417$i = $283;$$01421$i = $285;
              label = 100;
             }
            } else {
             $$01417$i = 0;$$01421$i = $279;
             label = 100;
            }
            L502: do {
             if ((label|0) == 100) {
              label = 0;
              $287 = (($$01417$i) + ($276))|0;
              $288 = (($270) - ($287))|0;
              $289 = ($$01421$i|0)>($288|0);
              $$$01421$i = $289 ? $288 : $$01421$i;
              $290 = $$01417$i << 1;
              $291 = (($280) + ($290)|0);
              $292 = $287 << 1;
              $293 = (($$121291$ph$i) + ($292)|0);
              $294 = $291;
              $295 = $293;
              $296 = $295 ^ $294;
              $297 = $296 & 3;
              $298 = ($297|0)==(0);
              if (!($298)) {
               $299 = ($$$01421$i|0)==(0);
               if ($299) {
                $$81336$i = 0;
                break;
               } else {
                $$014261639$i = $$$01421$i;$$014281638$i = $291;$$014301637$i = $293;
               }
               while(1) {
                $300 = (($$014261639$i) + -1)|0;
                $301 = ((($$014281638$i)) + 2|0);
                $302 = HEAP16[$$014281638$i>>1]|0;
                $303 = HEAP16[$$014301637$i>>1]|0;
                $304 = $302 & -2082;
                $305 = $304&65535;
                $306 = $303 & -2082;
                $307 = $306&65535;
                $308 = (($307) + ($305))|0;
                $309 = $308 >>> 1;
                $310 = $302 & 2081;
                $311 = $310 & $303;
                $312 = $311&65535;
                $313 = (($309) + ($312))|0;
                $314 = $313&65535;
                $315 = ((($$014301637$i)) + 2|0);
                HEAP16[$$014301637$i>>1] = $314;
                $316 = ($300|0)==(0);
                if ($316) {
                 $$81336$i = 0;
                 break L502;
                } else {
                 $$014261639$i = $300;$$014281638$i = $301;$$014301637$i = $315;
                }
               }
              }
              $317 = $294 & 3;
              $318 = ($317|0)==(0);
              if ($318) {
               $$11427$ph$i = $$$01421$i;$$11429$ph$i = $291;$$11431$ph$i = $293;
              } else {
               $319 = ((($291)) + 2|0);
               $320 = HEAP16[$291>>1]|0;
               $321 = HEAP16[$293>>1]|0;
               $322 = $320 & -2082;
               $323 = $322&65535;
               $324 = $321 & -2082;
               $325 = $324&65535;
               $326 = (($325) + ($323))|0;
               $327 = $326 >>> 1;
               $328 = $320 & 2081;
               $329 = $328 & $321;
               $330 = $329&65535;
               $331 = (($327) + ($330))|0;
               $332 = $331&65535;
               $333 = ((($293)) + 2|0);
               HEAP16[$293>>1] = $332;
               $334 = (($$$01421$i) + -1)|0;
               $$11427$ph$i = $334;$$11429$ph$i = $319;$$11431$ph$i = $333;
              }
              $335 = ($$11427$ph$i>>>0)>(1);
              if ($335) {
               $336 = (($$11427$ph$i) + -2)|0;
               $scevgep1705$i = ((($$11431$ph$i)) + 4|0);
               $$114271643$i = $$11427$ph$i;$$114291642$i = $$11429$ph$i;$$114311641$i = $$11431$ph$i;
               while(1) {
                $337 = HEAP32[$$114291642$i>>2]|0;
                $338 = HEAP32[$$114311641$i>>2]|0;
                $339 = $337 >>> 1;
                $340 = $339 & 2079292399;
                $341 = $338 >>> 1;
                $342 = $341 & 2079292399;
                $343 = $337 & 136382497;
                $344 = $343 & $338;
                $345 = (($344) + ($340))|0;
                $346 = (($345) + ($342))|0;
                HEAP32[$$114311641$i>>2] = $346;
                $347 = ((($$114291642$i)) + 4|0);
                $348 = ((($$114311641$i)) + 4|0);
                $349 = (($$114271643$i) + -2)|0;
                $350 = ($349>>>0)>(1);
                if ($350) {
                 $$114271643$i = $349;$$114291642$i = $347;$$114311641$i = $348;
                } else {
                 break;
                }
               }
               $351 = $336 & -2;
               $scevgep1706$i = (($scevgep1705$i) + ($351<<1)|0);
               $scevgep$i = ((($$11429$ph$i)) + 4|0);
               $scevgep1704$i = (($scevgep$i) + ($351<<1)|0);
               $352 = (($336) - ($351))|0;
               $$11427$lcssa$i = $352;$$11429$lcssa$i = $scevgep1704$i;$$11431$lcssa$i = $scevgep1706$i;
              } else {
               $$11427$lcssa$i = $$11427$ph$i;$$11429$lcssa$i = $$11429$ph$i;$$11431$lcssa$i = $$11431$ph$i;
              }
              $353 = ($$11427$lcssa$i|0)==(0);
              if ($353) {
               $$81336$i = 0;
               break;
              }
              $354 = HEAP16[$$11429$lcssa$i>>1]|0;
              $355 = HEAP16[$$11431$lcssa$i>>1]|0;
              $356 = $354 & -2082;
              $357 = $356&65535;
              $358 = $355 & -2082;
              $359 = $358&65535;
              $360 = (($359) + ($357))|0;
              $361 = $360 >>> 1;
              $362 = $354 & 2081;
              $363 = $362 & $355;
              $364 = $363&65535;
              $365 = (($361) + ($364))|0;
              $366 = $365&65535;
              HEAP16[$$11431$lcssa$i>>1] = $366;
              $$81336$i = 0;
             }
            } while(0);
            $trunc1511$i = $$81336$i&255;
            $trunc1511$i$clear = $trunc1511$i & 31;
            switch ($trunc1511$i$clear<<24>>24) {
            case 31: case 0:  {
             break L498;
             break;
            }
            default: {
            }
            }
            $switch4$i = ($$81336$i|0)==(0);
            if ($switch4$i) {
             $$01413$i = $276;$$12$i = $280;
             continue L493;
            } else {
             break L54;
            }
           }
          } while(0);
          $367 = $279 << 1;
          $368 = (($280) + ($367)|0);
          $369 = (($276) + ($279))|0;
          $$11414$i = $369;$$13$i = $368;
         }
         $371 = ($$11414$i|0)==($5|0);
         if ($371) {
          break;
         } else {
          $$01413$i = $$11414$i;$$12$i = $$13$i;
         }
        }
        $372 = HEAP32[$16>>2]|0;
        $373 = (($$121291$ph$i) + ($372)|0);
        $374 = (($$01403$ph$i) + -1)|0;
        $375 = ($374|0)==(0);
        if ($375) {
         break L54;
        } else {
         $$01403$ph$i = $374;$$12$ph$i = $$13$i;$$121291$ph$i = $373;
        }
       }
      }
     }
    } while(0);
    $593 = ((($1)) + 12|0);
    $594 = HEAP32[$593>>2]|0;
    $595 = ((($1)) + 8|0);
    $596 = HEAP32[$595>>2]|0;
    $597 = (($596) + ($96))|0;
    $598 = $96 << 1;
    $599 = (0 - ($598))|0;
    $600 = (($26) + ($599)|0);
    $601 = ((($103)) + 28|0);
    $602 = ((($103)) + 32|0);
    $603 = ((($103)) + 29|0);
    $604 = ((($103)) + 33|0);
    $605 = ((($103)) + 30|0);
    $606 = ((($103)) + 34|0);
    $607 = ((($103)) + 24|0);
    $$01500$ph$i = $594;$$24$ph$i = $$139721176;$$241303$ph$i = $600;
    while(1) {
     $$01503$i = 0;$$24$i = $$24$ph$i;
     L527: while(1) {
      $608 = HEAP8[$$24$i>>0]|0;
      $609 = $608&255;
      $610 = (($609) + ($$01503$i))|0;
      $611 = ((($$24$i)) + 1|0);
      $612 = HEAP8[$611>>0]|0;
      $613 = $612&255;
      $614 = ((($$24$i)) + 2|0);
      $615 = ($612<<24>>24)==(0);
      if ($615) {
       $695 = ($610|0)==(0);
       if ($695) {
        break L54;
       } else {
        $$11504$i = $610;$$25$i = $614;
       }
      } else {
       $616 = ($610|0)<($597|0);
       L532: do {
        if ($616) {
         $617 = (($96) - ($610))|0;
         $618 = ($617|0)>(0);
         if ($618) {
          $619 = (($613) - ($617))|0;
          $620 = ($619|0)<(1);
          if ($620) {
           $$161344$i = 88;
          } else {
           $$01497$i = $619;$$01499$i = $617;
           label = 176;
          }
         } else {
          $$01497$i = $613;$$01499$i = 0;
          label = 176;
         }
         if ((label|0) == 176) {
          label = 0;
          $621 = (($$01499$i) + ($610))|0;
          $622 = (($597) - ($621))|0;
          $623 = ($$01497$i|0)>($622|0);
          $$$01497$i = $623 ? $622 : $$01497$i;
          $624 = ($$$01497$i|0)>(0);
          if ($624) {
           $625 = $621 << 1;
           $626 = (($$241303$ph$i) + ($625)|0);
           $627 = $$01499$i << 1;
           $628 = (($614) + ($627)|0);
           $$pre = HEAP8[$601>>0]|0;
           $$phi$trans$insert = $$pre&255;
           $$phi$trans$insert1439 = (79212 + ($$phi$trans$insert<<2)|0);
           $$pre1440 = HEAP32[$$phi$trans$insert1439>>2]|0;
           $$pre1441 = HEAP8[$602>>0]|0;
           $$pre1442 = HEAP8[$603>>0]|0;
           $$phi$trans$insert1443 = $$pre1442&255;
           $$phi$trans$insert1444 = (79212 + ($$phi$trans$insert1443<<2)|0);
           $$pre1445 = HEAP32[$$phi$trans$insert1444>>2]|0;
           $$pre1446 = HEAP8[$604>>0]|0;
           $$pre1447 = HEAP8[$605>>0]|0;
           $$phi$trans$insert1448 = $$pre1447&255;
           $$phi$trans$insert1449 = (79212 + ($$phi$trans$insert1448<<2)|0);
           $$pre1450 = HEAP32[$$phi$trans$insert1449>>2]|0;
           $$pre1451 = HEAP8[$606>>0]|0;
           $$pre1452 = HEAP32[$607>>2]|0;
           $629 = $$pre1441&255;
           $630 = $$pre1446&255;
           $631 = $$pre1451&255;
           $$014931635$i = $626;$$014941634$i = $628;$$014951633$i = 0;
           while(1) {
            $632 = HEAP16[$$014941634$i>>1]|0;
            $633 = $632&65535;
            $634 = HEAP16[$$014931635$i>>1]|0;
            $635 = $634&65535;
            $636 = $633 & $254;
            $637 = $636 >>> $629;
            $638 = (($$pre1440) + ($637)|0);
            $639 = HEAP8[$638>>0]|0;
            $640 = $639&255;
            $641 = $633 & $256;
            $642 = $641 >>> $630;
            $643 = (($$pre1445) + ($642)|0);
            $644 = HEAP8[$643>>0]|0;
            $645 = $644&255;
            $646 = $633 & $259;
            $647 = $646 >>> $631;
            $648 = (($$pre1450) + ($647)|0);
            $649 = HEAP8[$648>>0]|0;
            $650 = $649&255;
            $651 = $635 & $254;
            $652 = $651 >>> $629;
            $653 = (($$pre1440) + ($652)|0);
            $654 = HEAP8[$653>>0]|0;
            $655 = $654&255;
            $656 = $635 & $256;
            $657 = $656 >>> $630;
            $658 = (($$pre1445) + ($657)|0);
            $659 = HEAP8[$658>>0]|0;
            $660 = $659&255;
            $661 = $635 & $259;
            $662 = $661 >>> $631;
            $663 = (($$pre1450) + ($662)|0);
            $664 = HEAP8[$663>>0]|0;
            $665 = $664&255;
            $666 = (($640) - ($655))|0;
            $667 = Math_imul($666, $95)|0;
            $668 = $667 >>> 8;
            $669 = (($668) + ($655))|0;
            $670 = (($645) - ($660))|0;
            $671 = Math_imul($670, $95)|0;
            $672 = $671 >>> 8;
            $673 = (($672) + ($660))|0;
            $674 = (($650) - ($665))|0;
            $675 = Math_imul($674, $95)|0;
            $676 = $675 >>> 8;
            $677 = (($676) + ($665))|0;
            $678 = $669 >>> $$phi$trans$insert;
            $679 = $678 << $629;
            $680 = $673 >>> $$phi$trans$insert1443;
            $681 = $680 << $630;
            $682 = $677 >>> $$phi$trans$insert1448;
            $683 = $682 << $631;
            $684 = $679 | $$pre1452;
            $685 = $684 | $681;
            $686 = $685 | $683;
            $687 = $686&65535;
            HEAP16[$$014931635$i>>1] = $687;
            $688 = ((($$014941634$i)) + 2|0);
            $689 = ((($$014931635$i)) + 2|0);
            $690 = (($$014951633$i) + 1)|0;
            $691 = ($690|0)<($$$01497$i|0);
            if ($691) {
             $$014931635$i = $689;$$014941634$i = $688;$$014951633$i = $690;
            } else {
             $$161344$i = 0;
             break;
            }
           }
          } else {
           $$161344$i = 0;
          }
         }
         $trunc1507$i = $$161344$i&255;
         $trunc1507$i$clear = $trunc1507$i & 127;
         switch ($trunc1507$i$clear<<24>>24) {
         case 88: case 0:  {
          break L532;
          break;
         }
         default: {
         }
         }
         $switch8$i = ($$161344$i|0)==(0);
         if ($switch8$i) {
          $$01503$i = $610;$$24$i = $614;
          continue L527;
         } else {
          break L54;
         }
        }
       } while(0);
       $692 = $613 << 1;
       $693 = (($614) + ($692)|0);
       $694 = (($610) + ($613))|0;
       $$11504$i = $694;$$25$i = $693;
      }
      $696 = ($$11504$i|0)==($5|0);
      if ($696) {
       break;
      } else {
       $$01503$i = $$11504$i;$$24$i = $$25$i;
      }
     }
     $697 = (($$241303$ph$i) + ($17)|0);
     $698 = (($$01500$ph$i) + -1)|0;
     $699 = ($698|0)==(0);
     if ($699) {
      break;
     } else {
      $$01500$ph$i = $698;$$24$ph$i = $$25$i;$$241303$ph$i = $697;
     }
    }
    break;
   }
   case 3:  {
    $700 = ((($1)) + 12|0);
    $701 = HEAP32[$700>>2]|0;
    $702 = ((($1)) + 8|0);
    $703 = HEAP32[$702>>2]|0;
    $704 = (($703) + ($96))|0;
    $705 = Math_imul($96, -3)|0;
    $706 = (($26) + ($705)|0);
    $707 = ((($103)) + 28|0);
    $708 = ((($103)) + 12|0);
    $709 = ((($103)) + 32|0);
    $710 = ((($103)) + 29|0);
    $711 = ((($103)) + 16|0);
    $712 = ((($103)) + 33|0);
    $713 = ((($103)) + 30|0);
    $714 = ((($103)) + 20|0);
    $715 = ((($103)) + 34|0);
    $716 = ((($103)) + 24|0);
    $$01474$ph$i = $701;$$27$ph$i = $$139721176;$$271306$ph$i = $706;
    while(1) {
     $$01470$i = 0;$$27$i = $$27$ph$i;
     L549: while(1) {
      $717 = HEAP8[$$27$i>>0]|0;
      $718 = $717&255;
      $719 = (($718) + ($$01470$i))|0;
      $720 = ((($$27$i)) + 1|0);
      $721 = HEAP8[$720>>0]|0;
      $722 = $721&255;
      $723 = ((($$27$i)) + 2|0);
      $724 = ($721<<24>>24)==(0);
      if ($724) {
       $847 = ($719|0)==(0);
       if ($847) {
        break L54;
       } else {
        $$11471$i = $719;$$28$i = $723;
       }
      } else {
       $725 = ($719|0)<($704|0);
       L554: do {
        if ($725) {
         $726 = (($96) - ($719))|0;
         $727 = ($726|0)>(0);
         if ($727) {
          $728 = (($722) - ($726))|0;
          $729 = ($728|0)<(1);
          if ($729) {
           $$181346$i = 98;
          } else {
           $$01462$i = $728;$$01464$i = $726;
           label = 191;
          }
         } else {
          $$01462$i = $722;$$01464$i = 0;
          label = 191;
         }
         if ((label|0) == 191) {
          label = 0;
          $730 = (($$01464$i) + ($719))|0;
          $731 = (($704) - ($730))|0;
          $732 = ($$01462$i|0)>($731|0);
          $$$01462$i = $732 ? $731 : $$01462$i;
          $733 = ($$$01462$i|0)>(0);
          if ($733) {
           $734 = ($730*3)|0;
           $735 = (($$271306$ph$i) + ($734)|0);
           $736 = ($$01464$i*3)|0;
           $737 = (($723) + ($736)|0);
           $$014551671$i = $735;$$014561670$i = $737;$$014571669$i = 0;
           while(1) {
            $738 = ((($$014561670$i)) + 2|0);
            $739 = HEAP8[$738>>0]|0;
            $740 = $739&255;
            $741 = $740 << 16;
            $742 = ((($$014561670$i)) + 1|0);
            $743 = HEAP8[$742>>0]|0;
            $744 = $743&255;
            $745 = $744 << 8;
            $746 = $745 | $741;
            $747 = HEAP8[$$014561670$i>>0]|0;
            $748 = $747&255;
            $749 = $746 | $748;
            $750 = ((($$014551671$i)) + 2|0);
            $751 = HEAP8[$750>>0]|0;
            $752 = $751&255;
            $753 = $752 << 16;
            $754 = ((($$014551671$i)) + 1|0);
            $755 = HEAP8[$754>>0]|0;
            $756 = $755&255;
            $757 = $756 << 8;
            $758 = $757 | $753;
            $759 = HEAP8[$$014551671$i>>0]|0;
            $760 = $759&255;
            $761 = $758 | $760;
            $762 = HEAP8[$707>>0]|0;
            $763 = $762&255;
            $764 = (79212 + ($763<<2)|0);
            $765 = HEAP32[$764>>2]|0;
            $766 = HEAP32[$708>>2]|0;
            $767 = $766 & $749;
            $768 = HEAP8[$709>>0]|0;
            $769 = $768&255;
            $770 = $767 >>> $769;
            $771 = (($765) + ($770)|0);
            $772 = HEAP8[$771>>0]|0;
            $773 = $772&255;
            $774 = HEAP8[$710>>0]|0;
            $775 = $774&255;
            $776 = (79212 + ($775<<2)|0);
            $777 = HEAP32[$776>>2]|0;
            $778 = HEAP32[$711>>2]|0;
            $779 = $778 & $749;
            $780 = HEAP8[$712>>0]|0;
            $781 = $780&255;
            $782 = $779 >>> $781;
            $783 = (($777) + ($782)|0);
            $784 = HEAP8[$783>>0]|0;
            $785 = $784&255;
            $786 = HEAP8[$713>>0]|0;
            $787 = $786&255;
            $788 = (79212 + ($787<<2)|0);
            $789 = HEAP32[$788>>2]|0;
            $790 = HEAP32[$714>>2]|0;
            $791 = $790 & $749;
            $792 = HEAP8[$715>>0]|0;
            $793 = $792&255;
            $794 = $791 >>> $793;
            $795 = (($789) + ($794)|0);
            $796 = HEAP8[$795>>0]|0;
            $797 = $796&255;
            $798 = $761 & $766;
            $799 = $798 >>> $769;
            $800 = (($765) + ($799)|0);
            $801 = HEAP8[$800>>0]|0;
            $802 = $801&255;
            $803 = $778 & $761;
            $804 = $803 >>> $781;
            $805 = (($777) + ($804)|0);
            $806 = HEAP8[$805>>0]|0;
            $807 = $806&255;
            $808 = $790 & $761;
            $809 = $808 >>> $793;
            $810 = (($789) + ($809)|0);
            $811 = HEAP8[$810>>0]|0;
            $812 = $811&255;
            $813 = (($773) - ($802))|0;
            $814 = Math_imul($813, $95)|0;
            $815 = $814 >>> 8;
            $816 = (($815) + ($802))|0;
            $817 = (($785) - ($807))|0;
            $818 = Math_imul($817, $95)|0;
            $819 = $818 >>> 8;
            $820 = (($819) + ($807))|0;
            $821 = (($797) - ($812))|0;
            $822 = Math_imul($821, $95)|0;
            $823 = $822 >>> 8;
            $824 = (($823) + ($812))|0;
            $825 = $816 >>> $763;
            $826 = $825 << $769;
            $827 = $820 >>> $775;
            $828 = $827 << $781;
            $829 = $824 >>> $787;
            $830 = $829 << $793;
            $831 = HEAP32[$716>>2]|0;
            $832 = $826 | $831;
            $833 = $832 | $828;
            $834 = $833 | $830;
            $835 = $834&255;
            HEAP8[$$014551671$i>>0] = $835;
            $836 = $834 >>> 8;
            $837 = $836&255;
            HEAP8[$754>>0] = $837;
            $838 = $834 >>> 16;
            $839 = $838&255;
            HEAP8[$750>>0] = $839;
            $840 = ((($$014561670$i)) + 3|0);
            $841 = ((($$014551671$i)) + 3|0);
            $842 = (($$014571669$i) + 1)|0;
            $843 = ($842|0)<($$$01462$i|0);
            if ($843) {
             $$014551671$i = $841;$$014561670$i = $840;$$014571669$i = $842;
            } else {
             $$181346$i = 0;
             break;
            }
           }
          } else {
           $$181346$i = 0;
          }
         }
         $trunc$i = $$181346$i&255;
         $trunc$i$clear = $trunc$i & 127;
         switch ($trunc$i$clear<<24>>24) {
         case 98: case 0:  {
          break L554;
          break;
         }
         default: {
         }
         }
         $switch9$i = ($$181346$i|0)==(0);
         if ($switch9$i) {
          $$01470$i = $719;$$27$i = $723;
          continue L549;
         } else {
          break L54;
         }
        }
       } while(0);
       $844 = ($722*3)|0;
       $845 = (($723) + ($844)|0);
       $846 = (($719) + ($722))|0;
       $$11471$i = $846;$$28$i = $845;
      }
      $848 = ($$11471$i|0)==($5|0);
      if ($848) {
       break;
      } else {
       $$01470$i = $$11471$i;$$27$i = $$28$i;
      }
     }
     $849 = HEAP32[$16>>2]|0;
     $850 = (($$271306$ph$i) + ($849)|0);
     $851 = (($$01474$ph$i) + -1)|0;
     $852 = ($851|0)==(0);
     if ($852) {
      break;
     } else {
      $$01474$ph$i = $851;$$27$ph$i = $$28$i;$$271306$ph$i = $850;
     }
    }
    break;
   }
   default: {
    break L54;
   }
   }
  }
 } while(0);
 $1874 = HEAP32[$2>>2]|0;
 $1875 = $1874 & 2;
 $1876 = ($1875|0)==(0);
 if ($1876) {
  $$0 = 0;
  return ($$0|0);
 }
 _SDL_UnlockSurface($2);
 $$0 = 0;
 return ($$0|0);
}
function _SDL_LockSurface($0) {
 $0 = $0|0;
 var $$pre = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  $4 = HEAP32[$0>>2]|0;
  $5 = $4 & 2;
  $6 = ($5|0)==(0);
  if ($6) {
   $10 = 0;
  } else {
   _SDL_UnRLESurface($0,1);
   $7 = HEAP32[$0>>2]|0;
   $8 = $7 | 2;
   HEAP32[$0>>2] = $8;
   $$pre = HEAP32[$1>>2]|0;
   $10 = $$pre;
  }
 } else {
  $10 = $2;
 }
 $9 = (($10) + 1)|0;
 HEAP32[$1>>2] = $9;
 return 0;
}
function _SDL_UnlockSurface($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  return;
 }
 $4 = (($2) + -1)|0;
 HEAP32[$1>>2] = $4;
 $5 = ($2|0)>(1);
 if ($5) {
  return;
 }
 $6 = HEAP32[$0>>2]|0;
 $7 = $6 & 2;
 $8 = ($7|0)==(0);
 if ($8) {
  return;
 }
 $9 = $6 & -3;
 HEAP32[$0>>2] = $9;
 (_SDL_RLESurface($0)|0);
 return;
}
function _getpix_8($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP8[$0>>0]|0;
 $2 = $1&255;
 return ($2|0);
}
function _getpix_16($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP16[$0>>1]|0;
 $2 = $1&65535;
 return ($2|0);
}
function _getpix_24($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP8[$0>>0]|0;
 $2 = $1&255;
 $3 = ((($0)) + 1|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = $5 << 8;
 $7 = $6 | $2;
 $8 = ((($0)) + 2|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = $9&255;
 $11 = $10 << 16;
 $12 = $7 | $11;
 return ($12|0);
}
function _getpix_32($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 return ($1|0);
}
function _SDL_memcmp($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (_memcmp($0,$1,$2)|0);
 return ($3|0);
}
function _SDL_SetPixelFormatPalette($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $2 = ($0|0)==(0|0);
 if ($2) {
  $3 = (_SDL_SetError(176317,$vararg_buffer)|0);
  $$0 = $3;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = ($1|0)!=(0|0);
 if ($4) {
  $5 = HEAP32[$1>>2]|0;
  $6 = ((($0)) + 8|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = $7&255;
  $9 = 1 << $8;
  $10 = ($5|0)==($9|0);
  if (!($10)) {
   $11 = (_SDL_SetError(176364,$vararg_buffer1)|0);
   $$0 = $11;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $12 = ((($0)) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==($1|0);
 if ($14) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $15 = ($13|0)==(0|0);
 if (!($15)) {
  $16 = ((($13)) + 12|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = (($17) + -1)|0;
  HEAP32[$16>>2] = $18;
  $19 = ($17|0)>(1);
  if (!($19)) {
   $20 = ((($13)) + 4|0);
   $21 = HEAP32[$20>>2]|0;
   _SDL_free($21);
   _SDL_free($13);
  }
 }
 HEAP32[$12>>2] = $1;
 if (!($4)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $22 = ((($1)) + 12|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($23) + 1)|0;
 HEAP32[$22>>2] = $24;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _SDL_FreeFormat($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $1 = ($0|0)==(0|0);
 if ($1) {
  HEAP32[$vararg_buffer>>2] = 176310;
  (_SDL_SetError(194740,$vararg_buffer)|0);
  STACKTOP = sp;return;
 }
 $2 = ((($0)) + 36|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + -1)|0;
 HEAP32[$2>>2] = $4;
 $5 = ($3|0)>(1);
 if ($5) {
  STACKTOP = sp;return;
 }
 $6 = HEAP32[52377]|0;
 $7 = ($6|0)==($0|0);
 L8: do {
  if ($7) {
   $8 = ((($0)) + 40|0);
   $9 = HEAP32[$8>>2]|0;
   HEAP32[52377] = $9;
  } else {
   $10 = ($6|0)==(0|0);
   if (!($10)) {
    $$0 = $6;
    while(1) {
     $11 = ((($$0)) + 40|0);
     $12 = HEAP32[$11>>2]|0;
     $13 = ($12|0)==(0|0);
     if ($13) {
      break L8;
     }
     $14 = ($12|0)==($0|0);
     if ($14) {
      break;
     } else {
      $$0 = $12;
     }
    }
    $15 = ((($0)) + 40|0);
    $16 = HEAP32[$15>>2]|0;
    HEAP32[$11>>2] = $16;
   }
  }
 } while(0);
 $17 = ((($0)) + 4|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ($18|0)==(0|0);
 if (!($19)) {
  $20 = ((($18)) + 12|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = (($21) + -1)|0;
  HEAP32[$20>>2] = $22;
  $23 = ($21|0)>(1);
  if (!($23)) {
   $24 = ((($18)) + 4|0);
   $25 = HEAP32[$24>>2]|0;
   _SDL_free($25);
   _SDL_free($18);
  }
 }
 _SDL_free($0);
 STACKTOP = sp;return;
}
function _SDL_FreeBlitMap($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ($0|0)==(0|0);
 if ($1) {
  return;
 }
 $2 = HEAP32[$0>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = ((($2)) + 56|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($5) + -1)|0;
  HEAP32[$4>>2] = $6;
  $7 = ($5|0)<(2);
  if ($7) {
   _SDL_FreeSurface($2);
  }
 }
 HEAP32[$0>>2] = 0;
 $8 = ((($0)) + 84|0);
 HEAP32[$8>>2] = 0;
 $9 = ((($0)) + 80|0);
 HEAP32[$9>>2] = 0;
 $10 = ((($0)) + 64|0);
 $11 = HEAP32[$10>>2]|0;
 _SDL_free($11);
 HEAP32[$10>>2] = 0;
 _SDL_free($0);
 return;
}
function _SDL_FillRect($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$0$i$us$i = 0, $$0$i$us$i51 = 0, $$0$i$us11$i = 0, $$0$us$i = 0, $$0$us$i48 = 0, $$01720$i = 0, $$018$i$us$i = 0, $$018$i$us$i50 = 0, $$018$i$us10$i = 0, $$01822$i = 0, $$019$us$i = 0, $$021$i = 0, $$02223$i = 0, $$02223$us$i = 0, $$031$us$i = 0, $$03638$i$us69 = 0, $$03638$i$us73 = 0, $$03638$i$us78 = 0, $$03638$us$i = 0;
 var $$041 = 0, $$056$i = 0, $$056$i$us = 0, $$056$us21$i = 0, $$056$us21$i$us = 0, $$056$us9$i = 0, $$07$i = 0, $$07$i$us = 0, $$07$us20$i = 0, $$07$us20$i$us = 0, $$07$us8$i = 0, $$1$i$us$i = 0, $$1$i$us$i53 = 0, $$1$us$i = 0, $$119$i$us$i = 0, $$119$i$us$i52 = 0, $$119$i$us24$i84 = 0, $$132$us$i = 0, $$2$i$us$i = 0, $$2$i$us$i55 = 0;
 var $$2$us$i = 0, $$220$i$i142 = 0, $$220$i$us$i = 0, $$220$i$us$i54 = 0, $$233$us$i = 0, $$3$i$us$i = 0, $$3$i$us$i57 = 0, $$321$i$i$us143 = 0, $$321$i$us$i = 0, $$321$i$us$i56 = 0, $$4$us$i = 0, $$5$us$i = 0, $$in$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0;
 var $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0;
 var $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0;
 var $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0;
 var $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond$i = 0, $trunc$i = 0, $trunc$i$clear = 0, $trunc$i$i = 0, $trunc$i$i$clear = 0, $trunc$i$us$i = 0, $trunc$i$us$i$clear = 0, $trunc$i$us$i49 = 0, $trunc$i$us$i49$clear = 0, $trunc$us$i = 0;
 var $trunc$us$i$clear = 0, $trunc37$us$i = 0, $trunc37$us$i$clear = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $vararg_buffer3 = sp + 16|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $3 = sp + 24|0;
 $4 = ($0|0)==(0|0);
 if ($4) {
  $5 = (_SDL_SetError(183547,$vararg_buffer)|0);
  $$0 = $5;
  STACKTOP = sp;return ($$0|0);
 }
 $6 = ((($0)) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($7)) + 8|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = ($9&255)<(8);
 if ($10) {
  $11 = (_SDL_SetError(176439,$vararg_buffer1)|0);
  $$0 = $11;
  STACKTOP = sp;return ($$0|0);
 }
 $12 = ($1|0)==(0|0);
 $13 = ((($0)) + 36|0);
 if ($12) {
  $16 = ((($0)) + 44|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = ($17|0)<(1);
  if ($18) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $19 = ((($0)) + 48|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = ($20|0)<(1);
  if ($21) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  } else {
   $$041 = $13;
  }
 } else {
  $14 = (_SDL_IntersectRect($1,$13,$3)|0);
  $15 = ($14|0)==(0);
  if ($15) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  } else {
   $$041 = $3;
  }
 }
 $22 = ((($0)) + 20|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)==(0|0);
 if ($24) {
  $25 = (_SDL_SetError(176482,$vararg_buffer3)|0);
  $$0 = $25;
  STACKTOP = sp;return ($$0|0);
 }
 $26 = ((($$041)) + 4|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ((($0)) + 16|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = Math_imul($29, $27)|0;
 $31 = (($23) + ($30)|0);
 $32 = HEAP32[$$041>>2]|0;
 $33 = HEAP32[$6>>2]|0;
 $34 = ((($33)) + 9|0);
 $35 = HEAP8[$34>>0]|0;
 $36 = $35&255;
 $37 = Math_imul($36, $32)|0;
 $38 = (($31) + ($37)|0);
 switch ($35<<24>>24) {
 case 1:  {
  $39 = $2 << 8;
  $40 = $39 | $2;
  $41 = $40 << 16;
  $42 = $41 | $40;
  $43 = ((($$041)) + 8|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = ((($$041)) + 12|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = (($46) + -1)|0;
  $48 = ($46|0)==(0);
  if ($48) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $49 = ($44|0)>(3);
  $50 = $2&255;
  $51 = (($44) + -1)|0;
  if ($49) {
   $$03638$us$i = $38;$97 = $47;
  } else {
   $52 = $44 & 3;
   $53 = ($52|0)==(0);
   $54 = $44 & -4;
   if ($53) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $trunc$i = $44&255;
   $trunc$i$clear = $trunc$i & 3;
   switch ($trunc$i$clear<<24>>24) {
   case 3:  {
    $$03638$i$us69 = $38;$60 = $47;
    while(1) {
     $55 = (($$03638$i$us69) + ($54)|0);
     $56 = ((($55)) + 1|0);
     HEAP8[$55>>0] = $50;
     $57 = ((($56)) + 1|0);
     HEAP8[$56>>0] = $50;
     HEAP8[$57>>0] = $50;
     $58 = (($$03638$i$us69) + ($29)|0);
     $59 = (($60) + -1)|0;
     $61 = ($60|0)==(0);
     if ($61) {
      $$0 = 0;
      break;
     } else {
      $$03638$i$us69 = $58;$60 = $59;
     }
    }
    STACKTOP = sp;return ($$0|0);
    break;
   }
   case 2:  {
    $$03638$i$us73 = $38;$66 = $47;
    while(1) {
     $62 = (($$03638$i$us73) + ($54)|0);
     $63 = ((($62)) + 1|0);
     HEAP8[$62>>0] = $50;
     HEAP8[$63>>0] = $50;
     $64 = (($$03638$i$us73) + ($29)|0);
     $65 = (($66) + -1)|0;
     $67 = ($66|0)==(0);
     if ($67) {
      $$0 = 0;
      break;
     } else {
      $$03638$i$us73 = $64;$66 = $65;
     }
    }
    STACKTOP = sp;return ($$0|0);
    break;
   }
   case 1:  {
    $$03638$i$us78 = $38;$71 = $47;
    while(1) {
     $68 = (($$03638$i$us78) + ($54)|0);
     HEAP8[$68>>0] = $50;
     $69 = (($$03638$i$us78) + ($29)|0);
     $70 = (($71) + -1)|0;
     $72 = ($71|0)==(0);
     if ($72) {
      $$0 = 0;
      break;
     } else {
      $$03638$i$us78 = $69;$71 = $70;
     }
    }
    STACKTOP = sp;return ($$0|0);
    break;
   }
   default: {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   }
  }
  L43: while(1) {
   $73 = $$03638$us$i;
   $trunc37$us$i = $73&255;
   $trunc37$us$i$clear = $trunc37$us$i & 3;
   switch ($trunc37$us$i$clear<<24>>24) {
   case 1:  {
    $74 = ((($$03638$us$i)) + 1|0);
    HEAP8[$$03638$us$i>>0] = $50;
    $$0$us$i48 = $74;$$031$us$i = $51;
    label = 21;
    break;
   }
   case 2:  {
    $$0$us$i48 = $$03638$us$i;$$031$us$i = $44;
    label = 21;
    break;
   }
   case 3:  {
    $$1$us$i = $$03638$us$i;$$132$us$i = $44;
    label = 22;
    break;
   }
   default: {
    $$2$us$i = $$03638$us$i;$$233$us$i = $44;
   }
   }
   if ((label|0) == 21) {
    label = 0;
    $75 = ((($$0$us$i48)) + 1|0);
    HEAP8[$$0$us$i48>>0] = $50;
    $76 = (($$031$us$i) + -1)|0;
    $$1$us$i = $75;$$132$us$i = $76;
    label = 22;
   }
   if ((label|0) == 22) {
    label = 0;
    $77 = ((($$1$us$i)) + 1|0);
    HEAP8[$$1$us$i>>0] = $50;
    $78 = (($$132$us$i) + -1)|0;
    $$2$us$i = $77;$$233$us$i = $78;
   }
   $79 = $$233$us$i >> 2;
   $80 = (($79) + 3)|0;
   $81 = $80 >>> 2;
   $82 = ($79|0)==(0);
   if (!($82)) {
    $trunc$i$us$i49 = $79&255;
    $trunc$i$us$i49$clear = $trunc$i$us$i49 & 3;
    switch ($trunc$i$us$i49$clear<<24>>24) {
    case 0:  {
     $$0$i$us$i51 = $81;$$018$i$us$i50 = $$2$us$i;
     label = 25;
     break;
    }
    case 3:  {
     $$1$i$us$i53 = $81;$$119$i$us$i52 = $$2$us$i;
     label = 26;
     break;
    }
    case 2:  {
     $$2$i$us$i55 = $81;$$220$i$us$i54 = $$2$us$i;
     label = 27;
     break;
    }
    case 1:  {
     $$3$i$us$i57 = $81;$$321$i$us$i56 = $$2$us$i;
     label = 28;
     break;
    }
    default: {
     label = 35;
     break L43;
    }
    }
    while(1) {
     if ((label|0) == 25) {
      label = 0;
      $83 = ((($$018$i$us$i50)) + 4|0);
      HEAP32[$$018$i$us$i50>>2] = $42;
      $$1$i$us$i53 = $$0$i$us$i51;$$119$i$us$i52 = $83;
      label = 26;
      continue;
     }
     else if ((label|0) == 26) {
      label = 0;
      $84 = ((($$119$i$us$i52)) + 4|0);
      HEAP32[$$119$i$us$i52>>2] = $42;
      $$2$i$us$i55 = $$1$i$us$i53;$$220$i$us$i54 = $84;
      label = 27;
      continue;
     }
     else if ((label|0) == 27) {
      label = 0;
      $85 = ((($$220$i$us$i54)) + 4|0);
      HEAP32[$$220$i$us$i54>>2] = $42;
      $$3$i$us$i57 = $$2$i$us$i55;$$321$i$us$i56 = $85;
      label = 28;
      continue;
     }
     else if ((label|0) == 28) {
      label = 0;
      $86 = ((($$321$i$us$i56)) + 4|0);
      HEAP32[$$321$i$us$i56>>2] = $42;
      $87 = (($$3$i$us$i57) + -1)|0;
      $88 = ($87|0)==(0);
      if ($88) {
       break;
      } else {
       $$0$i$us$i51 = $87;$$018$i$us$i50 = $86;
       label = 25;
       continue;
      }
     }
    }
   }
   $89 = $$233$us$i & 3;
   $90 = ($89|0)==(0);
   L61: do {
    if (!($90)) {
     $91 = $$233$us$i & -4;
     $92 = (($$2$us$i) + ($91)|0);
     $trunc$us$i = $$233$us$i&255;
     $trunc$us$i$clear = $trunc$us$i & 3;
     switch ($trunc$us$i$clear<<24>>24) {
     case 3:  {
      $93 = ((($92)) + 1|0);
      HEAP8[$92>>0] = $50;
      $$4$us$i = $93;
      label = 32;
      break;
     }
     case 2:  {
      $$4$us$i = $92;
      label = 32;
      break;
     }
     case 1:  {
      $$5$us$i = $92;
      break;
     }
     default: {
      break L61;
     }
     }
     if ((label|0) == 32) {
      label = 0;
      $94 = ((($$4$us$i)) + 1|0);
      HEAP8[$$4$us$i>>0] = $50;
      $$5$us$i = $94;
     }
     HEAP8[$$5$us$i>>0] = $50;
    }
   } while(0);
   $95 = (($$03638$us$i) + ($29)|0);
   $96 = (($97) + -1)|0;
   $98 = ($97|0)==(0);
   if ($98) {
    $$0 = 0;
    label = 75;
    break;
   } else {
    $$03638$us$i = $95;$97 = $96;
   }
  }
  if ((label|0) == 35) {
   // unreachable;
  }
  else if ((label|0) == 75) {
   STACKTOP = sp;return ($$0|0);
  }
  break;
 }
 case 2:  {
  $99 = $2 << 16;
  $100 = $99 | $2;
  $101 = ((($$041)) + 8|0);
  $102 = HEAP32[$101>>2]|0;
  $103 = ((($$041)) + 12|0);
  $104 = HEAP32[$103>>2]|0;
  $105 = (($104) + -1)|0;
  $106 = ($104|0)==(0);
  if ($106) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $107 = ($102|0)>(1);
  $108 = (($102) + -1)|0;
  $109 = $2&65535;
  if ($107) {
   $$02223$us$i = $38;$132 = $105;
  } else {
   $110 = $102 & 1;
   $111 = ($110|0)==(0);
   if ($111) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   } else {
    $$02223$i = $38;$137 = $105;
   }
   while(1) {
    $134 = (($$02223$i) + ($108<<1)|0);
    HEAP16[$134>>1] = $109;
    $135 = (($$02223$i) + ($29)|0);
    $136 = (($137) + -1)|0;
    $138 = ($137|0)==(0);
    if ($138) {
     $$0 = 0;
     break;
    } else {
     $$02223$i = $135;$137 = $136;
    }
   }
   STACKTOP = sp;return ($$0|0);
  }
  L83: while(1) {
   $112 = $$02223$us$i;
   $113 = $112 & 2;
   $114 = ($113|0)==(0);
   $115 = ((($$02223$us$i)) + 2|0);
   if ($114) {
    $$0$us$i = $$02223$us$i;$$019$us$i = $102;$219 = $$02223$us$i;
   } else {
    HEAP16[$$02223$us$i>>1] = $109;
    $$0$us$i = $115;$$019$us$i = $108;$219 = $115;
   }
   $116 = $$019$us$i >> 1;
   $117 = (($116) + 3)|0;
   $118 = $117 >>> 2;
   $119 = ($116|0)==(0);
   if (!($119)) {
    $trunc$i$us$i = $116&255;
    $trunc$i$us$i$clear = $trunc$i$us$i & 3;
    switch ($trunc$i$us$i$clear<<24>>24) {
    case 0:  {
     $$0$i$us$i = $118;$$018$i$us$i = $219;
     label = 43;
     break;
    }
    case 3:  {
     $$1$i$us$i = $118;$$119$i$us$i = $219;
     label = 44;
     break;
    }
    case 2:  {
     $$2$i$us$i = $118;$$220$i$us$i = $219;
     label = 45;
     break;
    }
    case 1:  {
     $$3$i$us$i = $118;$$321$i$us$i = $219;
     label = 46;
     break;
    }
    default: {
     label = 50;
     break L83;
    }
    }
    while(1) {
     if ((label|0) == 43) {
      label = 0;
      $120 = ((($$018$i$us$i)) + 4|0);
      HEAP32[$$018$i$us$i>>2] = $100;
      $$1$i$us$i = $$0$i$us$i;$$119$i$us$i = $120;
      label = 44;
      continue;
     }
     else if ((label|0) == 44) {
      label = 0;
      $121 = ((($$119$i$us$i)) + 4|0);
      HEAP32[$$119$i$us$i>>2] = $100;
      $$2$i$us$i = $$1$i$us$i;$$220$i$us$i = $121;
      label = 45;
      continue;
     }
     else if ((label|0) == 45) {
      label = 0;
      $122 = ((($$220$i$us$i)) + 4|0);
      HEAP32[$$220$i$us$i>>2] = $100;
      $$3$i$us$i = $$2$i$us$i;$$321$i$us$i = $122;
      label = 46;
      continue;
     }
     else if ((label|0) == 46) {
      label = 0;
      $123 = ((($$321$i$us$i)) + 4|0);
      HEAP32[$$321$i$us$i>>2] = $100;
      $124 = (($$3$i$us$i) + -1)|0;
      $125 = ($124|0)==(0);
      if ($125) {
       break;
      } else {
       $$0$i$us$i = $124;$$018$i$us$i = $123;
       label = 43;
       continue;
      }
     }
    }
   }
   $126 = $$019$us$i & 1;
   $127 = ($126|0)==(0);
   if (!($127)) {
    $128 = (($$019$us$i) + -1)|0;
    $129 = (($$0$us$i) + ($128<<1)|0);
    HEAP16[$129>>1] = $109;
   }
   $130 = (($$02223$us$i) + ($29)|0);
   $131 = (($132) + -1)|0;
   $133 = ($132|0)==(0);
   if ($133) {
    $$0 = 0;
    label = 75;
    break;
   } else {
    $$02223$us$i = $130;$132 = $131;
   }
  }
  if ((label|0) == 50) {
   // unreachable;
  }
  else if ((label|0) == 75) {
   STACKTOP = sp;return ($$0|0);
  }
  break;
 }
 case 3:  {
  $139 = ((($$041)) + 8|0);
  $140 = HEAP32[$139>>2]|0;
  $141 = ((($$041)) + 12|0);
  $142 = HEAP32[$141>>2]|0;
  $143 = $2&255;
  $144 = $2 >>> 8;
  $145 = $144&255;
  $146 = $2 >>> 16;
  $147 = $146&255;
  $148 = ($142|0)==(0);
  $149 = ($140|0)==(0);
  $or$cond$i = $149 | $148;
  if ($or$cond$i) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  } else {
   $$01822$i = $38;$$in$i = $142;
  }
  while(1) {
   $$01720$i = $140;$$021$i = $$01822$i;
   while(1) {
    $150 = (($$01720$i) + -1)|0;
    $151 = ((($$021$i)) + 1|0);
    HEAP8[$$021$i>>0] = $143;
    $152 = ((($$021$i)) + 2|0);
    HEAP8[$151>>0] = $145;
    $153 = ((($$021$i)) + 3|0);
    HEAP8[$152>>0] = $147;
    $154 = ($150|0)==(0);
    if ($154) {
     break;
    } else {
     $$01720$i = $150;$$021$i = $153;
    }
   }
   $155 = (($$in$i) + -1)|0;
   $156 = (($$01822$i) + ($29)|0);
   $157 = ($155|0)==(0);
   if ($157) {
    $$0 = 0;
    break;
   } else {
    $$01822$i = $156;$$in$i = $155;
   }
  }
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 4:  {
  $158 = ((($$041)) + 8|0);
  $159 = HEAP32[$158>>2]|0;
  $160 = ((($$041)) + 12|0);
  $161 = HEAP32[$160>>2]|0;
  $162 = ($161|0)==(0);
  if ($162) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $163 = (($159) + 3)|0;
  $164 = $163 >>> 2;
  $165 = ($159|0)==(0);
  if ($165) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $trunc$i$i = $159&255;
  $trunc$i$i$clear = $trunc$i$i & 3;
  switch ($trunc$i$i$clear<<24>>24) {
  case 0:  {
   $$056$us9$i = $38;$$07$us8$i = $161;
   while(1) {
    $$0$i$us11$i = $164;$$018$i$us10$i = $$056$us9$i;
    while(1) {
     $187 = ((($$018$i$us10$i)) + 4|0);
     HEAP32[$$018$i$us10$i>>2] = $2;
     $188 = ((($$018$i$us10$i)) + 8|0);
     HEAP32[$187>>2] = $2;
     $189 = ((($$018$i$us10$i)) + 12|0);
     HEAP32[$188>>2] = $2;
     $190 = ((($$018$i$us10$i)) + 16|0);
     HEAP32[$189>>2] = $2;
     $191 = (($$0$i$us11$i) + -1)|0;
     $192 = ($191|0)==(0);
     if ($192) {
      break;
     } else {
      $$0$i$us11$i = $191;$$018$i$us10$i = $190;
     }
    }
    $193 = (($$07$us8$i) + -1)|0;
    $194 = (($$056$us9$i) + ($29)|0);
    $195 = ($193|0)==(0);
    if ($195) {
     $$0 = 0;
     break;
    } else {
     $$056$us9$i = $194;$$07$us8$i = $193;
    }
   }
   STACKTOP = sp;return ($$0|0);
   break;
  }
  case 3:  {
   $170 = (($164) + -1)|0;
   $171 = ($170|0)==(0);
   if ($171) {
    $$056$us21$i$us = $38;$$07$us20$i$us = $161;
    while(1) {
     $172 = ((($$056$us21$i$us)) + 4|0);
     HEAP32[$$056$us21$i$us>>2] = $2;
     $173 = ((($$056$us21$i$us)) + 8|0);
     HEAP32[$172>>2] = $2;
     HEAP32[$173>>2] = $2;
     $174 = (($$07$us20$i$us) + -1)|0;
     $175 = (($$056$us21$i$us) + ($29)|0);
     $176 = ($174|0)==(0);
     if ($176) {
      $$0 = 0;
      break;
     } else {
      $$056$us21$i$us = $175;$$07$us20$i$us = $174;
     }
    }
    STACKTOP = sp;return ($$0|0);
   } else {
    $$056$us21$i = $38;$$07$us20$i = $161;
   }
   while(1) {
    $196 = ((($$056$us21$i)) + 4|0);
    HEAP32[$$056$us21$i>>2] = $2;
    $197 = ((($$056$us21$i)) + 8|0);
    HEAP32[$196>>2] = $2;
    HEAP32[$197>>2] = $2;
    $$119$i$us24$i84 = $$056$us21$i;$203 = $170;
    while(1) {
     $198 = ((($$119$i$us24$i84)) + 12|0);
     $199 = ((($$119$i$us24$i84)) + 16|0);
     HEAP32[$198>>2] = $2;
     $200 = ((($$119$i$us24$i84)) + 20|0);
     HEAP32[$199>>2] = $2;
     $201 = ((($$119$i$us24$i84)) + 24|0);
     HEAP32[$200>>2] = $2;
     HEAP32[$201>>2] = $2;
     $202 = (($203) + -1)|0;
     $204 = ($202|0)==(0);
     if ($204) {
      break;
     } else {
      $$119$i$us24$i84 = $199;$203 = $202;
     }
    }
    $205 = (($$07$us20$i) + -1)|0;
    $206 = (($$056$us21$i) + ($29)|0);
    $207 = ($205|0)==(0);
    if ($207) {
     $$0 = 0;
     break;
    } else {
     $$056$us21$i = $206;$$07$us20$i = $205;
    }
   }
   STACKTOP = sp;return ($$0|0);
   break;
  }
  case 1:  {
   $166 = (($164) + -1)|0;
   $167 = ($166|0)==(0);
   $$056$i$us = $38;$$07$i$us = $161;
   while(1) {
    HEAP32[$$056$i$us>>2] = $2;
    if (!($167)) {
     $$321$i$i$us143 = $$056$i$us;$182 = $166;
     while(1) {
      $177 = ((($$321$i$i$us143)) + 4|0);
      $178 = ((($$321$i$i$us143)) + 8|0);
      HEAP32[$177>>2] = $2;
      $179 = ((($$321$i$i$us143)) + 12|0);
      HEAP32[$178>>2] = $2;
      $180 = ((($$321$i$i$us143)) + 16|0);
      HEAP32[$179>>2] = $2;
      HEAP32[$180>>2] = $2;
      $181 = (($182) + -1)|0;
      $183 = ($181|0)==(0);
      if ($183) {
       break;
      } else {
       $$321$i$i$us143 = $180;$182 = $181;
      }
     }
    }
    $184 = (($$07$i$us) + -1)|0;
    $185 = (($$056$i$us) + ($29)|0);
    $186 = ($184|0)==(0);
    if ($186) {
     $$0 = 0;
     break;
    } else {
     $$056$i$us = $185;$$07$i$us = $184;
    }
   }
   STACKTOP = sp;return ($$0|0);
   break;
  }
  default: {
   $168 = (($164) + -1)|0;
   $169 = ($168|0)==(0);
   $$056$i = $38;$$07$i = $161;
   while(1) {
    $208 = ((($$056$i)) + 4|0);
    HEAP32[$$056$i>>2] = $2;
    HEAP32[$208>>2] = $2;
    if (!($169)) {
     $$220$i$i142 = $$056$i;$214 = $168;
     while(1) {
      $209 = ((($$220$i$i142)) + 8|0);
      $210 = ((($$220$i$i142)) + 12|0);
      HEAP32[$209>>2] = $2;
      $211 = ((($$220$i$i142)) + 16|0);
      HEAP32[$210>>2] = $2;
      $212 = ((($$220$i$i142)) + 20|0);
      HEAP32[$211>>2] = $2;
      HEAP32[$212>>2] = $2;
      $213 = (($214) + -1)|0;
      $215 = ($213|0)==(0);
      if ($215) {
       break;
      } else {
       $$220$i$i142 = $211;$214 = $213;
      }
     }
    }
    $216 = (($$07$i) + -1)|0;
    $217 = (($$056$i) + ($29)|0);
    $218 = ($216|0)==(0);
    if ($218) {
     $$0 = 0;
     break;
    } else {
     $$056$i = $217;$$07$i = $216;
    }
   }
   STACKTOP = sp;return ($$0|0);
  }
  }
  break;
 }
 default: {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 }
 return (0)|0;
}
function _uncopy_opaque_16($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$04346 = 0, $$04445 = 0, $$047 = 0, $$phi$trans$insert = 0, $$phi$trans$insert48 = 0, $$phi$trans$insert52 = 0, $$phi$trans$insert53 = 0, $$phi$trans$insert57 = 0, $$phi$trans$insert58 = 0, $$pre = 0, $$pre49 = 0, $$pre50 = 0, $$pre51 = 0, $$pre54 = 0, $$pre55 = 0, $$pre56 = 0, $$pre59 = 0, $$pre60 = 0, $$pre61 = 0, $$pre62 = 0;
 var $$pre63 = 0, $$pre64 = 0, $$pre65 = 0, $$pre66 = 0, $$pre67 = 0, $$pre68 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $8 = 0, $9 = 0, $exitcond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = ($2|0)>(0);
 if (!($5)) {
  $72 = $2 << 1;
  return ($72|0);
 }
 $6 = ((($4)) + 24|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)!=(0);
 $9 = $8 ? 255 : 0;
 $10 = ((($3)) + 20|0);
 $11 = ((($3)) + 4|0);
 $12 = ((($3)) + 24|0);
 $13 = ((($3)) + 21|0);
 $14 = ((($3)) + 8|0);
 $15 = ((($3)) + 25|0);
 $16 = ((($3)) + 22|0);
 $17 = ((($3)) + 12|0);
 $18 = ((($3)) + 26|0);
 $19 = ((($4)) + 28|0);
 $20 = ((($4)) + 32|0);
 $21 = ((($4)) + 29|0);
 $22 = ((($4)) + 33|0);
 $23 = ((($4)) + 30|0);
 $24 = ((($4)) + 34|0);
 $25 = ((($4)) + 31|0);
 $26 = ((($4)) + 35|0);
 $$pre = HEAP8[$10>>0]|0;
 $$phi$trans$insert = $$pre&255;
 $$phi$trans$insert48 = (79212 + ($$phi$trans$insert<<2)|0);
 $$pre49 = HEAP32[$$phi$trans$insert48>>2]|0;
 $$pre50 = HEAP8[$12>>0]|0;
 $$pre51 = HEAP8[$13>>0]|0;
 $$phi$trans$insert52 = $$pre51&255;
 $$phi$trans$insert53 = (79212 + ($$phi$trans$insert52<<2)|0);
 $$pre54 = HEAP32[$$phi$trans$insert53>>2]|0;
 $$pre55 = HEAP8[$15>>0]|0;
 $$pre56 = HEAP8[$16>>0]|0;
 $$phi$trans$insert57 = $$pre56&255;
 $$phi$trans$insert58 = (79212 + ($$phi$trans$insert57<<2)|0);
 $$pre59 = HEAP32[$$phi$trans$insert58>>2]|0;
 $$pre60 = HEAP8[$18>>0]|0;
 $$pre61 = HEAP8[$19>>0]|0;
 $$pre62 = HEAP8[$20>>0]|0;
 $$pre63 = HEAP8[$21>>0]|0;
 $$pre64 = HEAP8[$22>>0]|0;
 $$pre65 = HEAP8[$23>>0]|0;
 $$pre66 = HEAP8[$24>>0]|0;
 $$pre67 = HEAP8[$25>>0]|0;
 $$pre68 = HEAP8[$26>>0]|0;
 $27 = $$pre50&255;
 $28 = $$pre55&255;
 $29 = $$pre60&255;
 $30 = $$pre61&255;
 $31 = $$pre62&255;
 $32 = $$pre63&255;
 $33 = $$pre64&255;
 $34 = $$pre65&255;
 $35 = $$pre66&255;
 $36 = $$pre67&255;
 $37 = $9 >>> $36;
 $38 = $$pre68&255;
 $39 = $37 << $38;
 $$04346 = 0;$$04445 = $1;$$047 = $0;
 while(1) {
  $40 = HEAP16[$$04445>>1]|0;
  $41 = $40&65535;
  $42 = HEAP32[$11>>2]|0;
  $43 = $41 & $42;
  $44 = $43 >>> $27;
  $45 = (($$pre49) + ($44)|0);
  $46 = HEAP8[$45>>0]|0;
  $47 = $46&255;
  $48 = HEAP32[$14>>2]|0;
  $49 = $48 & $41;
  $50 = $49 >>> $28;
  $51 = (($$pre54) + ($50)|0);
  $52 = HEAP8[$51>>0]|0;
  $53 = $52&255;
  $54 = HEAP32[$17>>2]|0;
  $55 = $54 & $41;
  $56 = $55 >>> $29;
  $57 = (($$pre59) + ($56)|0);
  $58 = HEAP8[$57>>0]|0;
  $59 = $58&255;
  $60 = $47 >>> $30;
  $61 = $60 << $31;
  $62 = $53 >>> $32;
  $63 = $62 << $33;
  $64 = $63 | $61;
  $65 = $59 >>> $34;
  $66 = $65 << $35;
  $67 = $64 | $66;
  $68 = $67 | $39;
  HEAP32[$$047>>2] = $68;
  $69 = ((($$04445)) + 2|0);
  $70 = ((($$047)) + 4|0);
  $71 = (($$04346) + 1)|0;
  $exitcond = ($71|0)==($2|0);
  if ($exitcond) {
   break;
  } else {
   $$04346 = $71;$$04445 = $69;$$047 = $70;
  }
 }
 $72 = $2 << 1;
 return ($72|0);
}
function _uncopy_32($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$04548 = 0, $$04647 = 0, $$049 = 0, $$phi$trans$insert = 0, $$phi$trans$insert50 = 0, $$phi$trans$insert54 = 0, $$phi$trans$insert55 = 0, $$phi$trans$insert59 = 0, $$phi$trans$insert60 = 0, $$pre = 0, $$pre51 = 0, $$pre52 = 0, $$pre53 = 0, $$pre56 = 0, $$pre57 = 0, $$pre58 = 0, $$pre61 = 0, $$pre62 = 0, $$pre63 = 0, $$pre64 = 0;
 var $$pre65 = 0, $$pre66 = 0, $$pre67 = 0, $$pre68 = 0, $$pre69 = 0, $$pre70 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = ($2|0)>(0);
 if (!($5)) {
  $68 = $2 << 2;
  return ($68|0);
 }
 $6 = ((($3)) + 20|0);
 $7 = ((($3)) + 4|0);
 $8 = ((($3)) + 24|0);
 $9 = ((($3)) + 21|0);
 $10 = ((($3)) + 8|0);
 $11 = ((($3)) + 25|0);
 $12 = ((($3)) + 22|0);
 $13 = ((($3)) + 12|0);
 $14 = ((($3)) + 26|0);
 $15 = ((($4)) + 28|0);
 $16 = ((($4)) + 32|0);
 $17 = ((($4)) + 29|0);
 $18 = ((($4)) + 33|0);
 $19 = ((($4)) + 30|0);
 $20 = ((($4)) + 34|0);
 $21 = ((($4)) + 31|0);
 $22 = ((($4)) + 35|0);
 $$pre = HEAP8[$6>>0]|0;
 $$phi$trans$insert = $$pre&255;
 $$phi$trans$insert50 = (79212 + ($$phi$trans$insert<<2)|0);
 $$pre51 = HEAP32[$$phi$trans$insert50>>2]|0;
 $$pre52 = HEAP8[$8>>0]|0;
 $$pre53 = HEAP8[$9>>0]|0;
 $$phi$trans$insert54 = $$pre53&255;
 $$phi$trans$insert55 = (79212 + ($$phi$trans$insert54<<2)|0);
 $$pre56 = HEAP32[$$phi$trans$insert55>>2]|0;
 $$pre57 = HEAP8[$11>>0]|0;
 $$pre58 = HEAP8[$12>>0]|0;
 $$phi$trans$insert59 = $$pre58&255;
 $$phi$trans$insert60 = (79212 + ($$phi$trans$insert59<<2)|0);
 $$pre61 = HEAP32[$$phi$trans$insert60>>2]|0;
 $$pre62 = HEAP8[$14>>0]|0;
 $$pre63 = HEAP8[$15>>0]|0;
 $$pre64 = HEAP8[$16>>0]|0;
 $$pre65 = HEAP8[$17>>0]|0;
 $$pre66 = HEAP8[$18>>0]|0;
 $$pre67 = HEAP8[$19>>0]|0;
 $$pre68 = HEAP8[$20>>0]|0;
 $$pre69 = HEAP8[$21>>0]|0;
 $$pre70 = HEAP8[$22>>0]|0;
 $23 = $$pre52&255;
 $24 = $$pre57&255;
 $25 = $$pre62&255;
 $26 = $$pre63&255;
 $27 = $$pre64&255;
 $28 = $$pre65&255;
 $29 = $$pre66&255;
 $30 = $$pre67&255;
 $31 = $$pre68&255;
 $32 = $$pre69&255;
 $33 = $$pre70&255;
 $$04548 = 0;$$04647 = $1;$$049 = $0;
 while(1) {
  $34 = ((($$04647)) + 4|0);
  $35 = HEAP32[$$04647>>2]|0;
  $36 = HEAP32[$7>>2]|0;
  $37 = $36 & $35;
  $38 = $37 >>> $23;
  $39 = (($$pre51) + ($38)|0);
  $40 = HEAP8[$39>>0]|0;
  $41 = $40&255;
  $42 = HEAP32[$10>>2]|0;
  $43 = $42 & $35;
  $44 = $43 >>> $24;
  $45 = (($$pre56) + ($44)|0);
  $46 = HEAP8[$45>>0]|0;
  $47 = $46&255;
  $48 = HEAP32[$13>>2]|0;
  $49 = $48 & $35;
  $50 = $49 >>> $25;
  $51 = (($$pre61) + ($50)|0);
  $52 = HEAP8[$51>>0]|0;
  $53 = $52&255;
  $54 = $35 >>> 24;
  $55 = $41 >>> $26;
  $56 = $55 << $27;
  $57 = $47 >>> $28;
  $58 = $57 << $29;
  $59 = $58 | $56;
  $60 = $53 >>> $30;
  $61 = $60 << $31;
  $62 = $59 | $61;
  $63 = $54 >>> $32;
  $64 = $63 << $33;
  $65 = $62 | $64;
  HEAP32[$$049>>2] = $65;
  $66 = ((($$049)) + 4|0);
  $67 = (($$04548) + 1)|0;
  $exitcond = ($67|0)==($2|0);
  if ($exitcond) {
   break;
  } else {
   $$04548 = $67;$$04647 = $34;$$049 = $66;
  }
 }
 $68 = $2 << 2;
 return ($68|0);
}
function _uncopy_transl_16($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$04750 = 0, $$04849 = 0, $$051 = 0, $$phi$trans$insert = 0, $$phi$trans$insert52 = 0, $$phi$trans$insert56 = 0, $$phi$trans$insert57 = 0, $$phi$trans$insert61 = 0, $$phi$trans$insert62 = 0, $$pre = 0, $$pre53 = 0, $$pre54 = 0, $$pre55 = 0, $$pre58 = 0, $$pre59 = 0, $$pre60 = 0, $$pre63 = 0, $$pre64 = 0, $$pre65 = 0, $$pre66 = 0;
 var $$pre67 = 0, $$pre68 = 0, $$pre69 = 0, $$pre70 = 0, $$pre71 = 0, $$pre72 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $8 = 0, $9 = 0, $exitcond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = ($2|0)>(0);
 if (!($5)) {
  $72 = $2 << 2;
  return ($72|0);
 }
 $6 = ((($3)) + 20|0);
 $7 = ((($3)) + 4|0);
 $8 = ((($3)) + 24|0);
 $9 = ((($3)) + 21|0);
 $10 = ((($3)) + 8|0);
 $11 = ((($3)) + 25|0);
 $12 = ((($3)) + 22|0);
 $13 = ((($3)) + 12|0);
 $14 = ((($3)) + 26|0);
 $15 = ((($4)) + 28|0);
 $16 = ((($4)) + 32|0);
 $17 = ((($4)) + 29|0);
 $18 = ((($4)) + 33|0);
 $19 = ((($4)) + 30|0);
 $20 = ((($4)) + 34|0);
 $21 = ((($4)) + 31|0);
 $22 = ((($4)) + 35|0);
 $$pre = HEAP8[$6>>0]|0;
 $$phi$trans$insert = $$pre&255;
 $$phi$trans$insert52 = (79212 + ($$phi$trans$insert<<2)|0);
 $$pre53 = HEAP32[$$phi$trans$insert52>>2]|0;
 $$pre54 = HEAP8[$8>>0]|0;
 $$pre55 = HEAP8[$9>>0]|0;
 $$phi$trans$insert56 = $$pre55&255;
 $$phi$trans$insert57 = (79212 + ($$phi$trans$insert56<<2)|0);
 $$pre58 = HEAP32[$$phi$trans$insert57>>2]|0;
 $$pre59 = HEAP8[$11>>0]|0;
 $$pre60 = HEAP8[$12>>0]|0;
 $$phi$trans$insert61 = $$pre60&255;
 $$phi$trans$insert62 = (79212 + ($$phi$trans$insert61<<2)|0);
 $$pre63 = HEAP32[$$phi$trans$insert62>>2]|0;
 $$pre64 = HEAP8[$14>>0]|0;
 $$pre65 = HEAP8[$15>>0]|0;
 $$pre66 = HEAP8[$16>>0]|0;
 $$pre67 = HEAP8[$17>>0]|0;
 $$pre68 = HEAP8[$18>>0]|0;
 $$pre69 = HEAP8[$19>>0]|0;
 $$pre70 = HEAP8[$20>>0]|0;
 $$pre71 = HEAP8[$21>>0]|0;
 $$pre72 = HEAP8[$22>>0]|0;
 $23 = $$pre54&255;
 $24 = $$pre59&255;
 $25 = $$pre64&255;
 $26 = $$pre65&255;
 $27 = $$pre66&255;
 $28 = $$pre67&255;
 $29 = $$pre68&255;
 $30 = $$pre69&255;
 $31 = $$pre70&255;
 $32 = $$pre71&255;
 $33 = $$pre72&255;
 $$04750 = 0;$$04849 = $1;$$051 = $0;
 while(1) {
  $34 = ((($$04849)) + 4|0);
  $35 = HEAP32[$$04849>>2]|0;
  $36 = $35 >>> 2;
  $37 = $36 & 248;
  $38 = $35 & -993;
  $39 = $35 >>> 16;
  $40 = $38 | $39;
  $41 = HEAP32[$7>>2]|0;
  $42 = $41 & $40;
  $43 = $42 >>> $23;
  $44 = (($$pre53) + ($43)|0);
  $45 = HEAP8[$44>>0]|0;
  $46 = $45&255;
  $47 = HEAP32[$10>>2]|0;
  $48 = $47 & $40;
  $49 = $48 >>> $24;
  $50 = (($$pre58) + ($49)|0);
  $51 = HEAP8[$50>>0]|0;
  $52 = $51&255;
  $53 = HEAP32[$13>>2]|0;
  $54 = $53 & $40;
  $55 = $54 >>> $25;
  $56 = (($$pre63) + ($55)|0);
  $57 = HEAP8[$56>>0]|0;
  $58 = $57&255;
  $59 = $46 >>> $26;
  $60 = $59 << $27;
  $61 = $52 >>> $28;
  $62 = $61 << $29;
  $63 = $62 | $60;
  $64 = $58 >>> $30;
  $65 = $64 << $31;
  $66 = $63 | $65;
  $67 = $37 >>> $32;
  $68 = $67 << $33;
  $69 = $66 | $68;
  HEAP32[$$051>>2] = $69;
  $70 = ((($$051)) + 4|0);
  $71 = (($$04750) + 1)|0;
  $exitcond = ($71|0)==($2|0);
  if ($exitcond) {
   break;
  } else {
   $$04750 = $71;$$04849 = $34;$$051 = $70;
  }
 }
 $72 = $2 << 2;
 return ($72|0);
}
function _SDL_IntersectRect($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$ = 0, $$0 = 0, $$051 = 0, $$1 = 0, $$52 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $notlhs = 0, $notrhs = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $vararg_buffer4 = sp + 16|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $3 = ($0|0)==(0|0);
 if ($3) {
  HEAP32[$vararg_buffer>>2] = 195914;
  (_SDL_SetError(194740,$vararg_buffer)|0);
  $$051 = 0;
  STACKTOP = sp;return ($$051|0);
 }
 $4 = ($1|0)==(0|0);
 if ($4) {
  HEAP32[$vararg_buffer1>>2] = 176524;
  (_SDL_SetError(194740,$vararg_buffer1)|0);
  $$051 = 0;
  STACKTOP = sp;return ($$051|0);
 }
 $5 = ($2|0)==(0|0);
 if ($5) {
  HEAP32[$vararg_buffer4>>2] = 176526;
  (_SDL_SetError(194740,$vararg_buffer4)|0);
  $$051 = 0;
  STACKTOP = sp;return ($$051|0);
 }
 $6 = ((($0)) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)<(1);
 if (!($8)) {
  $9 = ((($0)) + 12|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10|0)<(1);
  if (!($11)) {
   $12 = ((($1)) + 8|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = ($13|0)<(1);
   if (!($14)) {
    $15 = ((($1)) + 12|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = ($16|0)<(1);
    if (!($17)) {
     $20 = HEAP32[$0>>2]|0;
     $21 = (($7) + ($20))|0;
     $22 = HEAP32[$1>>2]|0;
     $23 = (($13) + ($22))|0;
     $24 = ($22|0)>($20|0);
     $$ = $24 ? $22 : $20;
     HEAP32[$2>>2] = $$;
     $25 = ($23|0)<($21|0);
     $$0 = $25 ? $23 : $21;
     $26 = (($$0) - ($$))|0;
     $27 = ((($2)) + 8|0);
     HEAP32[$27>>2] = $26;
     $28 = ((($0)) + 4|0);
     $29 = HEAP32[$28>>2]|0;
     $30 = (($10) + ($29))|0;
     $31 = ((($1)) + 4|0);
     $32 = HEAP32[$31>>2]|0;
     $33 = (($16) + ($32))|0;
     $34 = ($32|0)>($29|0);
     $$52 = $34 ? $32 : $29;
     $35 = ((($2)) + 4|0);
     HEAP32[$35>>2] = $$52;
     $36 = ($33|0)<($30|0);
     $$1 = $36 ? $33 : $30;
     $37 = (($$1) - ($$52))|0;
     $38 = ((($2)) + 12|0);
     HEAP32[$38>>2] = $37;
     $notlhs = ($26|0)>(0);
     $notrhs = ($37|0)>(0);
     $39 = $notlhs & $notrhs;
     $40 = $39&1;
     $$051 = $40;
     STACKTOP = sp;return ($$051|0);
    }
   }
  }
 }
 $18 = ((($2)) + 8|0);
 HEAP32[$18>>2] = 0;
 $19 = ((($2)) + 12|0);
 HEAP32[$19>>2] = 0;
 $$051 = 0;
 STACKTOP = sp;return ($$051|0);
}
function _SDL_PixelFormatEnumToMasks($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$0 = 0, $$mask101 = 0, $$not = 0, $$off = 0, $$sink = 0, $$sink5 = 0, $$sink7 = 0, $$sink9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond103 = 0;
 var $storemerge = 0, $switch = 0, $switch$split2D = 0, $trunc = 0, $trunc$clear = 0, $trunc99 = 0, $trunc99$clear = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $vararg_buffer3 = sp + 16|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $$not = ($0|0)==(0);
 $$mask101 = $0 & -268435456;
 $6 = ($$mask101|0)==(268435456);
 $or$cond103 = $$not | $6;
 L1: do {
  if ($or$cond103) {
   $7 = $0 & 255;
   $8 = ($7>>>0)<(3);
   $9 = $0 << 3;
   $10 = $9 & 2040;
   $11 = $0 >>> 8;
   $12 = $11 & 255;
   $storemerge = $8 ? $12 : $10;
   HEAP32[$1>>2] = $storemerge;
   HEAP32[$5>>2] = 0;
   HEAP32[$4>>2] = 0;
   HEAP32[$3>>2] = 0;
   HEAP32[$2>>2] = 0;
   $switch$split2D = ($0|0)<(390076419);
   L3: do {
    if ($switch$split2D) {
     switch ($0|0) {
     case 386930691:  {
      break;
     }
     default: {
      break L3;
     }
     }
     HEAP32[$2>>2] = 255;
     HEAP32[$3>>2] = 65280;
     HEAP32[$4>>2] = 16711680;
     $$0 = 1;
     break L1;
    } else {
     switch ($0|0) {
     case 390076419:  {
      break;
     }
     default: {
      break L3;
     }
     }
     HEAP32[$2>>2] = 16711680;
     HEAP32[$3>>2] = 65280;
     HEAP32[$4>>2] = 255;
     $$0 = 1;
     break L1;
    }
   } while(0);
   $13 = $0 >>> 24;
   $14 = $13 & 15;
   $$off = (($14) + -4)|0;
   $switch = ($$off>>>0)<(3);
   if ($switch) {
    $15 = $0 >>> 16;
    $trunc = $15&255;
    $trunc$clear = $trunc & 15;
    switch ($trunc$clear<<24>>24) {
    case 1:  {
     $$sink = 3;$$sink5 = 28;$$sink7 = 224;$$sink9 = 0;
     break;
    }
    case 2:  {
     $$sink = 15;$$sink5 = 240;$$sink7 = 3840;$$sink9 = 61440;
     break;
    }
    case 3:  {
     $$sink = 31;$$sink5 = 992;$$sink7 = 31744;$$sink9 = 32768;
     break;
    }
    case 4:  {
     $$sink = 1;$$sink5 = 62;$$sink7 = 1984;$$sink9 = 63488;
     break;
    }
    case 5:  {
     $$sink = 31;$$sink5 = 2016;$$sink7 = 63488;$$sink9 = 0;
     break;
    }
    case 6:  {
     $$sink = 255;$$sink5 = 65280;$$sink7 = 16711680;$$sink9 = -16777216;
     break;
    }
    case 7:  {
     $$sink = 1023;$$sink5 = 1047552;$$sink7 = 1072693248;$$sink9 = -1073741824;
     break;
    }
    case 8:  {
     $$sink = 3;$$sink5 = 4092;$$sink7 = 4190208;$$sink9 = -4194304;
     break;
    }
    default: {
     (_SDL_SetError(182955,$vararg_buffer1)|0);
     $$0 = 0;
     break L1;
    }
    }
    $16 = $0 >>> 20;
    $trunc99 = $16&255;
    $trunc99$clear = $trunc99 & 15;
    switch ($trunc99$clear<<24>>24) {
    case 1:  {
     HEAP32[$2>>2] = $$sink7;
     HEAP32[$3>>2] = $$sink5;
     HEAP32[$4>>2] = $$sink;
     $$0 = 1;
     break L1;
     break;
    }
    case 2:  {
     HEAP32[$2>>2] = $$sink9;
     HEAP32[$3>>2] = $$sink7;
     HEAP32[$4>>2] = $$sink5;
     $$0 = 1;
     break L1;
     break;
    }
    case 3:  {
     HEAP32[$5>>2] = $$sink9;
     HEAP32[$2>>2] = $$sink7;
     HEAP32[$3>>2] = $$sink5;
     HEAP32[$4>>2] = $$sink;
     $$0 = 1;
     break L1;
     break;
    }
    case 4:  {
     HEAP32[$2>>2] = $$sink9;
     HEAP32[$3>>2] = $$sink7;
     HEAP32[$4>>2] = $$sink5;
     HEAP32[$5>>2] = $$sink;
     $$0 = 1;
     break L1;
     break;
    }
    case 5:  {
     HEAP32[$4>>2] = $$sink7;
     HEAP32[$3>>2] = $$sink5;
     HEAP32[$2>>2] = $$sink;
     $$0 = 1;
     break L1;
     break;
    }
    case 6:  {
     HEAP32[$4>>2] = $$sink9;
     HEAP32[$3>>2] = $$sink7;
     HEAP32[$2>>2] = $$sink5;
     $$0 = 1;
     break L1;
     break;
    }
    case 8:  {
     HEAP32[$4>>2] = $$sink9;
     HEAP32[$3>>2] = $$sink7;
     HEAP32[$2>>2] = $$sink5;
     HEAP32[$5>>2] = $$sink;
     $$0 = 1;
     break L1;
     break;
    }
    case 7:  {
     HEAP32[$5>>2] = $$sink9;
     HEAP32[$4>>2] = $$sink7;
     HEAP32[$3>>2] = $$sink5;
     HEAP32[$2>>2] = $$sink;
     $$0 = 1;
     break L1;
     break;
    }
    default: {
     (_SDL_SetError(182955,$vararg_buffer3)|0);
     $$0 = 0;
     break L1;
    }
    }
   } else {
    $$0 = 1;
   }
  } else {
   (_SDL_SetError(176533,$vararg_buffer)|0);
   $$0 = 0;
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function _SDL_GetWindowSize($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $3 = HEAP32[52375]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  (_SDL_SetError(175439,$vararg_buffer)|0);
  STACKTOP = sp;return;
 }
 $5 = ($0|0)==(0|0);
 if (!($5)) {
  $6 = HEAP32[$0>>2]|0;
  $7 = ((($3)) + 280|0);
  $8 = ($6|0)==($7|0);
  if ($8) {
   $9 = ($1|0)==(0|0);
   if (!($9)) {
    $10 = ((($0)) + 24|0);
    $11 = HEAP32[$10>>2]|0;
    HEAP32[$1>>2] = $11;
   }
   $12 = ($2|0)==(0|0);
   if ($12) {
    STACKTOP = sp;return;
   }
   $13 = ((($0)) + 28|0);
   $14 = HEAP32[$13>>2]|0;
   HEAP32[$2>>2] = $14;
   STACKTOP = sp;return;
  }
 }
 (_SDL_SetError(195204,$vararg_buffer1)|0);
 STACKTOP = sp;return;
}
function _GLES2_SetupCopy($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$078 = 0, $$078$in = 0, $$079 = 0, $$080 = 0, $$080$in = 0, $$pre = 0, $$pre$phi82Z2D = 0, $$pre$phiZ2D = 0, $$pre81 = 0, $10 = 0, $100 = 0.0, $101 = 0.0, $102 = 0.0, $103 = 0.0, $104 = 0.0, $105 = 0.0, $106 = 0.0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0.0, $switch$split122D = 0, $switch$split152D = 0, $switch$split182D = 0;
 var $switch$split212D = 0, $switch$split242D = 0, $switch$split272D = 0, $switch$split2D = 0, $switch$split302D = 0, $switch$split32D = 0, $switch$split332D = 0, $switch$split362D = 0, $switch$split392D = 0, $switch$split422D = 0, $switch$split452D = 0, $switch$split482D = 0, $switch$split512D = 0, $switch$split542D = 0, $switch$split572D = 0, $switch$split602D = 0, $switch$split62D = 0, $switch$split92D = 0, $vararg_buffer = 0, $vararg_buffer1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $2 = ((($0)) + 320|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($1)) + 68|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($1)) + 24|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($0)) + 308|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 $11 = ((($1)) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 L1: do {
  if ($10) {
   $switch$split152D = ($12|0)<(825382478);
   L3: do {
    if ($switch$split152D) {
     $switch$split332D = ($12|0)<(374740996);
     if ($switch$split332D) {
      $switch$split512D = ($12|0)<(372645892);
      if (!($switch$split512D)) {
       switch ($12|0) {
       case 372645892:  {
        $$079 = 2;
        break L1;
        break;
       }
       default: {
        break L3;
       }
       }
      }
      switch ($12|0) {
      case 370546692:  {
       break;
      }
      default: {
       break L3;
      }
      }
      $$079 = 3;
      break L1;
     }
     $switch$split542D = ($12|0)<(376840196);
     if ($switch$split542D) {
      switch ($12|0) {
      case 374740996:  {
       break;
      }
      default: {
       break L3;
      }
      }
      $$079 = 4;
      break L1;
     } else {
      switch ($12|0) {
      case 376840196:  {
       break;
      }
      default: {
       break L3;
      }
      }
      $$079 = 1;
      break L1;
     }
    } else {
     $switch$split362D = ($12|0)<(842094169);
     if (!($switch$split362D)) {
      $switch$split602D = ($12|0)<(1448433993);
      if ($switch$split602D) {
       switch ($12|0) {
       case 842094169:  {
        break;
       }
       default: {
        break L3;
       }
       }
      } else {
       switch ($12|0) {
       case 1448433993:  {
        break;
       }
       default: {
        break L3;
       }
       }
      }
      $$079 = 5;
      break L1;
     }
     $switch$split572D = ($12|0)<(842094158);
     if ($switch$split572D) {
      switch ($12|0) {
      case 825382478:  {
       break;
      }
      default: {
       break L3;
      }
      }
      $$079 = 7;
      break L1;
     } else {
      switch ($12|0) {
      case 842094158:  {
       break;
      }
      default: {
       break L3;
      }
      }
      $$079 = 6;
      break L1;
     }
    }
   } while(0);
   $17 = (_SDL_SetError(176800,$vararg_buffer1)|0);
   $$0 = $17;
   STACKTOP = sp;return ($$0|0);
  } else {
   $13 = ((($9)) + 4|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = ($14|0)==($12|0);
   if ($15) {
    $$079 = 1;
   } else {
    $switch$split2D = ($12|0)<(825382478);
    L34: do {
     if ($switch$split2D) {
      $switch$split212D = ($12|0)<(374740996);
      if ($switch$split212D) {
       $switch$split392D = ($12|0)<(372645892);
       if (!($switch$split392D)) {
        switch ($12|0) {
        case 372645892:  {
         break;
        }
        default: {
         break L34;
        }
        }
        $switch$split32D = ($14|0)<(376840196);
        if ($switch$split32D) {
         switch ($14|0) {
         case 374740996:  {
          break;
         }
         default: {
          $$079 = 1;
          break L1;
         }
         }
        } else {
         switch ($14|0) {
         case 376840196:  {
          break;
         }
         default: {
          $$079 = 1;
          break L1;
         }
         }
        }
        $$079 = 2;
        break L1;
       }
       switch ($12|0) {
       case 370546692:  {
        break;
       }
       default: {
        break L34;
       }
       }
       $switch$split92D = ($14|0)<(374740996);
       if ($switch$split92D) {
        switch ($14|0) {
        case 372645892:  {
         break;
        }
        default: {
         $$079 = 1;
         break L1;
        }
        }
        $$079 = 4;
        break L1;
       }
       $switch$split272D = ($14|0)<(376840196);
       if ($switch$split272D) {
        switch ($14|0) {
        case 374740996:  {
         break;
        }
        default: {
         $$079 = 1;
         break L1;
        }
        }
        $$079 = 2;
        break L1;
       } else {
        switch ($14|0) {
        case 376840196:  {
         break;
        }
        default: {
         $$079 = 1;
         break L1;
        }
        }
        $$079 = 2;
        break L1;
       }
      } else {
       $switch$split422D = ($12|0)<(376840196);
       if (!($switch$split422D)) {
        switch ($12|0) {
        case 376840196:  {
         break;
        }
        default: {
         break L34;
        }
        }
        $switch$split62D = ($14|0)<(372645892);
        if ($switch$split62D) {
         switch ($14|0) {
         case 370546692:  {
          break;
         }
         default: {
          $$079 = 1;
          break L1;
         }
         }
        } else {
         switch ($14|0) {
         case 372645892:  {
          break;
         }
         default: {
          $$079 = 1;
          break L1;
         }
         }
        }
        $$079 = 2;
        break L1;
       }
       switch ($12|0) {
       case 374740996:  {
        break;
       }
       default: {
        break L34;
       }
       }
       $switch$split122D = ($14|0)<(372645892);
       if ($switch$split122D) {
        switch ($14|0) {
        case 370546692:  {
         break;
        }
        default: {
         $$079 = 1;
         break L1;
        }
        }
        $$079 = 2;
        break L1;
       }
       $switch$split302D = ($14|0)<(376840196);
       if ($switch$split302D) {
        switch ($14|0) {
        case 372645892:  {
         break;
        }
        default: {
         $$079 = 1;
         break L1;
        }
        }
        $$079 = 3;
        break L1;
       } else {
        switch ($14|0) {
        case 376840196:  {
         break;
        }
        default: {
         $$079 = 1;
         break L1;
        }
        }
        $$079 = 4;
        break L1;
       }
      }
     } else {
      $switch$split242D = ($12|0)<(842094169);
      if (!($switch$split242D)) {
       $switch$split482D = ($12|0)<(1448433993);
       if ($switch$split482D) {
        switch ($12|0) {
        case 842094169:  {
         $$079 = 5;
         break L1;
         break;
        }
        default: {
         break L34;
        }
        }
       } else {
        switch ($12|0) {
        case 1448433993:  {
         $$079 = 5;
         break L1;
         break;
        }
        default: {
         break L34;
        }
        }
       }
      }
      $switch$split452D = ($12|0)<(842094158);
      if ($switch$split452D) {
       switch ($12|0) {
       case 825382478:  {
        break;
       }
       default: {
        break L34;
       }
       }
       $$079 = 7;
       break L1;
      } else {
       switch ($12|0) {
       case 842094158:  {
        break;
       }
       default: {
        break L34;
       }
       }
       $$079 = 6;
       break L1;
      }
     }
    } while(0);
    $16 = (_SDL_SetError(176800,$vararg_buffer)|0);
    $$0 = $16;
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $18 = (_GLES2_SelectProgram($0,$$079,$7)|0);
 $19 = ($18|0)<(0);
 if ($19) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 $20 = ((($5)) + 24|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0);
 if (!($22)) {
  $23 = ((($3)) + 16|0);
  $24 = HEAP32[$23>>2]|0;
  FUNCTION_TABLE_vi[$24 & 8191](33986);
  $25 = ((($3)) + 28|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = ((($5)) + 4|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = ((($5)) + 32|0);
  $30 = HEAP32[$29>>2]|0;
  FUNCTION_TABLE_vii[$26 & 8191]($28,$30);
  $31 = HEAP32[$23>>2]|0;
  FUNCTION_TABLE_vi[$31 & 8191](33985);
  $32 = HEAP32[$25>>2]|0;
  $33 = HEAP32[$27>>2]|0;
  $34 = ((($5)) + 36|0);
  $35 = HEAP32[$34>>2]|0;
  FUNCTION_TABLE_vii[$32 & 8191]($33,$35);
  $36 = HEAP32[$23>>2]|0;
  FUNCTION_TABLE_vi[$36 & 8191](33984);
 }
 $37 = ((($5)) + 28|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = ($38|0)==(0);
 if ($39) {
  $$pre = ((($3)) + 28|0);
  $$pre81 = ((($5)) + 4|0);
  $$pre$phi82Z2D = $$pre81;$$pre$phiZ2D = $$pre;
 } else {
  $40 = ((($3)) + 16|0);
  $41 = HEAP32[$40>>2]|0;
  FUNCTION_TABLE_vi[$41 & 8191](33985);
  $42 = ((($3)) + 28|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = ((($5)) + 4|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = ((($5)) + 36|0);
  $47 = HEAP32[$46>>2]|0;
  FUNCTION_TABLE_vii[$43 & 8191]($45,$47);
  $48 = HEAP32[$40>>2]|0;
  FUNCTION_TABLE_vi[$48 & 8191](33984);
  $$pre$phi82Z2D = $44;$$pre$phiZ2D = $42;
 }
 $49 = HEAP32[$$pre$phiZ2D>>2]|0;
 $50 = HEAP32[$$pre$phi82Z2D>>2]|0;
 $51 = HEAP32[$5>>2]|0;
 FUNCTION_TABLE_vii[$49 & 8191]($50,$51);
 $52 = ((($1)) + 29|0);
 $53 = HEAP8[$52>>0]|0;
 $54 = ((($1)) + 31|0);
 $55 = HEAP8[$54>>0]|0;
 $56 = HEAP32[$8>>2]|0;
 $57 = ($56|0)==(0|0);
 L100: do {
  if ($57) {
   label = 36;
  } else {
   $58 = ((($56)) + 4|0);
   $59 = HEAP32[$58>>2]|0;
   $switch$split182D = ($59|0)<(372645892);
   if ($switch$split182D) {
    switch ($59|0) {
    case 370546692:  {
     break;
    }
    default: {
     label = 36;
     break L100;
    }
    }
   } else {
    switch ($59|0) {
    case 372645892:  {
     break;
    }
    default: {
     label = 36;
     break L100;
    }
    }
   }
   $60 = ((($1)) + 30|0);
   $61 = ((($1)) + 28|0);
   $$078$in = $61;$$080$in = $60;
  }
 } while(0);
 if ((label|0) == 36) {
  $62 = ((($1)) + 28|0);
  $63 = ((($1)) + 30|0);
  $$078$in = $63;$$080$in = $62;
 }
 $$078 = HEAP8[$$078$in>>0]|0;
 $$080 = HEAP8[$$080$in>>0]|0;
 $64 = ((($3)) + 268|0);
 $65 = HEAP32[$64>>2]|0;
 $66 = ((($65)) + 84|0);
 $67 = HEAP8[$66>>0]|0;
 $68 = ((($65)) + 85|0);
 $69 = HEAP8[$68>>0]|0;
 $70 = ((($65)) + 86|0);
 $71 = HEAP8[$70>>0]|0;
 $72 = ((($65)) + 87|0);
 $73 = HEAP8[$72>>0]|0;
 $74 = $67&255;
 $75 = $74 << 24;
 $76 = $69&255;
 $77 = $76 << 16;
 $78 = $77 | $75;
 $79 = $71&255;
 $80 = $79 << 8;
 $81 = $78 | $80;
 $82 = $73&255;
 $83 = $81 | $82;
 $84 = $$080&255;
 $85 = $84 << 24;
 $86 = $53&255;
 $87 = $86 << 16;
 $88 = $$078&255;
 $89 = $88 << 8;
 $90 = $55&255;
 $91 = $90 | $87;
 $92 = $91 | $89;
 $93 = $92 | $85;
 $94 = ($83|0)==($93|0);
 if (!($94)) {
  $95 = ((($3)) + 172|0);
  $96 = HEAP32[$95>>2]|0;
  $97 = ((($65)) + 24|0);
  $98 = HEAP32[$97>>2]|0;
  $99 = (+($$080&255));
  $100 = $99 * 0.0039215688593685627;
  $101 = (+($53&255));
  $102 = $101 * 0.0039215688593685627;
  $103 = (+($$078&255));
  $104 = $103 * 0.0039215688593685627;
  $105 = (+($55&255));
  $106 = $105 * 0.0039215688593685627;
  FUNCTION_TABLE_vidddd[$96 & 8191]($98,$100,$102,$104,$106);
  HEAP8[$66>>0] = $$080;
  HEAP8[$68>>0] = $53;
  HEAP8[$70>>0] = $$078;
  HEAP8[$72>>0] = $55;
 }
 $107 = ((($3)) + 8|0);
 $108 = HEAP32[$107>>2]|0;
 $109 = ($108|0)==($7|0);
 if (!($109)) {
  switch ($7|0) {
  case 4:  {
   $120 = ((($3)) + 80|0);
   $121 = HEAP32[$120>>2]|0;
   FUNCTION_TABLE_vi[$121 & 8191](3042);
   $122 = ((($3)) + 32|0);
   $123 = HEAP32[$122>>2]|0;
   FUNCTION_TABLE_viiii[$123 & 8191](0,768,0,1);
   break;
  }
  case 1:  {
   $112 = ((($3)) + 80|0);
   $113 = HEAP32[$112>>2]|0;
   FUNCTION_TABLE_vi[$113 & 8191](3042);
   $114 = ((($3)) + 32|0);
   $115 = HEAP32[$114>>2]|0;
   FUNCTION_TABLE_viiii[$115 & 8191](770,771,1,771);
   break;
  }
  case 2:  {
   $116 = ((($3)) + 80|0);
   $117 = HEAP32[$116>>2]|0;
   FUNCTION_TABLE_vi[$117 & 8191](3042);
   $118 = ((($3)) + 32|0);
   $119 = HEAP32[$118>>2]|0;
   FUNCTION_TABLE_viiii[$119 & 8191](770,1,0,1);
   break;
  }
  default: {
   $110 = ((($3)) + 68|0);
   $111 = HEAP32[$110>>2]|0;
   FUNCTION_TABLE_vi[$111 & 8191](3042);
  }
  }
  HEAP32[$107>>2] = $7;
 }
 $124 = ((($3)) + 12|0);
 $125 = HEAP32[$124>>2]|0;
 $126 = ($125|0)==(1);
 if ($126) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $127 = ((($3)) + 84|0);
 $128 = HEAP32[$127>>2]|0;
 FUNCTION_TABLE_vi[$128 & 8191](1);
 HEAP32[$124>>2] = 1;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _GLES2_SelectProgram($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$0$i = 0, $$0129$i$ph = 0, $$0129$i53 = 0, $$0135$i = 0, $$0136$i = 0, $$045 = 0, $$04758 = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i131$i = 0, $$pre$i48 = 0, $$pre$i50 = 0, $$pre138$i = 0, $$pre139$i = 0, $$sink$i = 0.0, $$sink130$i = 0, $$sink3$i = 0.0, $10 = 0, $100 = 0;
 var $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0;
 var $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0;
 var $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0;
 var $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0;
 var $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0;
 var $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0;
 var $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0.0, $215 = 0.0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0.0, $221 = 0.0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0;
 var $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0;
 var $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0;
 var $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0;
 var $283 = 0, $284 = 0, $285 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(80|0);
 $vararg_buffer = sp;
 $3 = sp + 8|0;
 $4 = sp + 4|0;
 $5 = ((($0)) + 320|0);
 $6 = HEAP32[$5>>2]|0;
 switch ($1|0) {
 case 0:  {
  $$045 = 1;
  label = 9;
  break;
 }
 case 1:  {
  $$045 = 2;
  label = 9;
  break;
 }
 case 2:  {
  $$045 = 3;
  label = 9;
  break;
 }
 case 3:  {
  $$045 = 5;
  label = 9;
  break;
 }
 case 4:  {
  $$045 = 4;
  label = 9;
  break;
 }
 case 5:  {
  $$045 = 6;
  label = 9;
  break;
 }
 case 6:  {
  $$045 = 7;
  label = 9;
  break;
 }
 case 7:  {
  $$045 = 8;
  label = 9;
  break;
 }
 default: {
 }
 }
 if ((label|0) == 9) {
  $7 = (_GLES2_CacheShader($0,0,$2)|0);
  $8 = ($7|0)==(0|0);
  if (!($8)) {
   $9 = (_GLES2_CacheShader($0,$$045,$2)|0);
   $10 = ($9|0)==(0|0);
   L12: do {
    if ($10) {
     $$04758 = 0;
    } else {
     $11 = ((($6)) + 268|0);
     $12 = HEAP32[$11>>2]|0;
     $13 = ($12|0)==(0|0);
     if (!($13)) {
      $14 = ((($12)) + 8|0);
      $15 = HEAP32[$14>>2]|0;
      $16 = ($15|0)==($7|0);
      if ($16) {
       $17 = ((($12)) + 12|0);
       $18 = HEAP32[$17>>2]|0;
       $19 = ($18|0)==($9|0);
       if ($19) {
        $$0 = 0;
        STACKTOP = sp;return ($$0|0);
       }
      }
     }
     $20 = HEAP32[$5>>2]|0;
     $21 = ((($20)) + 260|0);
     $$0135$i = HEAP32[$21>>2]|0;
     $22 = ($$0135$i|0)==(0|0);
     L19: do {
      if ($22) {
       label = 24;
      } else {
       $$0136$i = $$0135$i;
       while(1) {
        $23 = ((($$0136$i)) + 8|0);
        $24 = HEAP32[$23>>2]|0;
        $25 = ($24|0)==($7|0);
        if ($25) {
         $26 = ((($$0136$i)) + 12|0);
         $27 = HEAP32[$26>>2]|0;
         $28 = ($27|0)==($9|0);
         if ($28) {
          break;
         }
        }
        $29 = ((($$0136$i)) + 156|0);
        $$0$i = HEAP32[$29>>2]|0;
        $30 = ($$0$i|0)==(0|0);
        if ($30) {
         label = 24;
         break L19;
        } else {
         $$0136$i = $$0$i;
        }
       }
       $31 = ($$0135$i|0)==($$0136$i|0);
       if ($31) {
        $$0129$i53 = $$0135$i;
        break;
       }
       $32 = ((($$0136$i)) + 156|0);
       $33 = HEAP32[$32>>2]|0;
       $34 = ($33|0)==(0|0);
       $$pre139$i = ((($$0136$i)) + 152|0);
       if (!($34)) {
        $35 = HEAP32[$$pre139$i>>2]|0;
        $36 = ((($33)) + 152|0);
        HEAP32[$36>>2] = $35;
       }
       $37 = HEAP32[$$pre139$i>>2]|0;
       $38 = ($37|0)==(0|0);
       if (!($38)) {
        $39 = ((($37)) + 156|0);
        HEAP32[$39>>2] = $33;
       }
       HEAP32[$$pre139$i>>2] = 0;
       HEAP32[$32>>2] = $$0135$i;
       $40 = ((($$0135$i)) + 152|0);
       HEAP32[$40>>2] = $$0136$i;
       HEAP32[$21>>2] = $$0136$i;
       $$0129$i$ph = $$0136$i;
       label = 49;
      }
     } while(0);
     L35: do {
      if ((label|0) == 24) {
       $41 = (_SDL_calloc(1,160)|0);
       $42 = ($41|0)==(0|0);
       do {
        if ($42) {
         (_SDL_Error(0)|0);
        } else {
         $43 = ((($41)) + 8|0);
         HEAP32[$43>>2] = $7;
         $44 = ((($41)) + 12|0);
         HEAP32[$44>>2] = $9;
         $45 = ((($41)) + 4|0);
         HEAP32[$45>>2] = $2;
         $46 = ((($20)) + 48|0);
         $47 = HEAP32[$46>>2]|0;
         $48 = (FUNCTION_TABLE_i[$47 & 8191]()|0);
         HEAP32[$41>>2] = $48;
         $49 = ((($20)) + 20|0);
         $50 = HEAP32[$49>>2]|0;
         $51 = HEAP32[$7>>2]|0;
         FUNCTION_TABLE_vii[$50 & 8191]($48,$51);
         $52 = HEAP32[$49>>2]|0;
         $53 = HEAP32[$41>>2]|0;
         $54 = HEAP32[$9>>2]|0;
         FUNCTION_TABLE_vii[$52 & 8191]($53,$54);
         $55 = ((($20)) + 24|0);
         $56 = HEAP32[$55>>2]|0;
         $57 = HEAP32[$41>>2]|0;
         FUNCTION_TABLE_viii[$56 & 8191]($57,0,176827);
         $58 = HEAP32[$55>>2]|0;
         $59 = HEAP32[$41>>2]|0;
         FUNCTION_TABLE_viii[$58 & 8191]($59,1,176838);
         $60 = HEAP32[$55>>2]|0;
         $61 = HEAP32[$41>>2]|0;
         FUNCTION_TABLE_viii[$60 & 8191]($61,2,176849);
         $62 = HEAP32[$55>>2]|0;
         $63 = HEAP32[$41>>2]|0;
         FUNCTION_TABLE_viii[$62 & 8191]($63,3,176857);
         $64 = ((($20)) + 132|0);
         $65 = HEAP32[$64>>2]|0;
         $66 = HEAP32[$41>>2]|0;
         FUNCTION_TABLE_vi[$65 & 8191]($66);
         $67 = ((($20)) + 116|0);
         $68 = HEAP32[$67>>2]|0;
         $69 = HEAP32[$41>>2]|0;
         FUNCTION_TABLE_viii[$68 & 8191]($69,35714,$4);
         $70 = HEAP32[$4>>2]|0;
         $71 = ($70|0)==(0);
         $72 = HEAP32[$41>>2]|0;
         if ($71) {
          $73 = ((($20)) + 56|0);
          $74 = HEAP32[$73>>2]|0;
          FUNCTION_TABLE_vi[$74 & 8191]($72);
          _SDL_free($41);
          (_SDL_SetError(176866,$vararg_buffer)|0);
          break;
         }
         $75 = ((($20)) + 128|0);
         $76 = HEAP32[$75>>2]|0;
         $77 = (FUNCTION_TABLE_iii[$76 & 8191]($72,176896)|0);
         $78 = ((($41)) + 16|0);
         HEAP32[$78>>2] = $77;
         $79 = HEAP32[$75>>2]|0;
         $80 = HEAP32[$41>>2]|0;
         $81 = (FUNCTION_TABLE_iii[$79 & 8191]($80,176909)|0);
         $82 = ((($41)) + 36|0);
         HEAP32[$82>>2] = $81;
         $83 = HEAP32[$75>>2]|0;
         $84 = HEAP32[$41>>2]|0;
         $85 = (FUNCTION_TABLE_iii[$83 & 8191]($84,176921)|0);
         $86 = ((($41)) + 32|0);
         HEAP32[$86>>2] = $85;
         $87 = HEAP32[$75>>2]|0;
         $88 = HEAP32[$41>>2]|0;
         $89 = (FUNCTION_TABLE_iii[$87 & 8191]($88,176933)|0);
         $90 = ((($41)) + 20|0);
         HEAP32[$90>>2] = $89;
         $91 = HEAP32[$75>>2]|0;
         $92 = HEAP32[$41>>2]|0;
         $93 = (FUNCTION_TABLE_iii[$91 & 8191]($92,176943)|0);
         $94 = ((($41)) + 24|0);
         HEAP32[$94>>2] = $93;
         $95 = HEAP32[$75>>2]|0;
         $96 = HEAP32[$41>>2]|0;
         $97 = (FUNCTION_TABLE_iii[$95 & 8191]($96,176956)|0);
         $98 = ((($41)) + 28|0);
         HEAP32[$98>>2] = $97;
         $99 = ((($41)) + 80|0);
         $100 = ((($20)) + 180|0);
         $101 = $99;
         $102 = $101;
         HEAP32[$102>>2] = -1;
         $103 = (($101) + 4)|0;
         $104 = $103;
         HEAP32[$104>>2] = -1;
         $105 = HEAP32[$100>>2]|0;
         $106 = HEAP32[$41>>2]|0;
         FUNCTION_TABLE_vi[$105 & 8191]($106);
         $107 = ((($20)) + 168|0);
         $108 = HEAP32[$107>>2]|0;
         $109 = HEAP32[$82>>2]|0;
         FUNCTION_TABLE_vii[$108 & 8191]($109,2);
         $110 = HEAP32[$107>>2]|0;
         $111 = HEAP32[$86>>2]|0;
         FUNCTION_TABLE_vii[$110 & 8191]($111,1);
         $112 = HEAP32[$107>>2]|0;
         $113 = HEAP32[$90>>2]|0;
         FUNCTION_TABLE_vii[$112 & 8191]($113,0);
         $114 = ((($20)) + 176|0);
         $115 = HEAP32[$114>>2]|0;
         $116 = HEAP32[$78>>2]|0;
         $117 = ((($41)) + 88|0);
         FUNCTION_TABLE_viiii[$115 & 8191]($116,1,0,$117);
         $118 = ((($20)) + 172|0);
         $119 = HEAP32[$118>>2]|0;
         $120 = HEAP32[$94>>2]|0;
         FUNCTION_TABLE_vidddd[$119 & 8191]($120,1.0,1.0,1.0,1.0);
         $121 = HEAP32[$118>>2]|0;
         $122 = HEAP32[$98>>2]|0;
         FUNCTION_TABLE_vidddd[$121 & 8191]($122,1.0,1.0,1.0,1.0);
         $123 = HEAP32[$21>>2]|0;
         $124 = ($123|0)==(0|0);
         if ($124) {
          $127 = ((($20)) + 264|0);
          $$sink130$i = $127;
         } else {
          $125 = ((($41)) + 156|0);
          HEAP32[$125>>2] = $123;
          $126 = ((($123)) + 152|0);
          $$sink130$i = $126;
         }
         HEAP32[$$sink130$i>>2] = $41;
         HEAP32[$21>>2] = $41;
         $128 = ((($20)) + 256|0);
         $129 = HEAP32[$128>>2]|0;
         $130 = (($129) + 1)|0;
         HEAP32[$128>>2] = $130;
         $131 = ((($7)) + 12|0);
         $132 = HEAP32[$131>>2]|0;
         $133 = (($132) + 1)|0;
         HEAP32[$131>>2] = $133;
         $134 = ((($9)) + 12|0);
         $135 = HEAP32[$134>>2]|0;
         $136 = (($135) + 1)|0;
         HEAP32[$134>>2] = $136;
         $137 = ($129|0)>(7);
         if (!($137)) {
          $$0129$i$ph = $41;
          label = 49;
          break L35;
         }
         $138 = ((($20)) + 264|0);
         $139 = HEAP32[$138>>2]|0;
         $140 = ((($139)) + 8|0);
         $141 = HEAP32[$140>>2]|0;
         $142 = ((($141)) + 12|0);
         $143 = HEAP32[$142>>2]|0;
         $144 = (($143) + -1)|0;
         HEAP32[$142>>2] = $144;
         $145 = ($143|0)<(2);
         if ($145) {
          $146 = HEAP32[$5>>2]|0;
          $147 = ((($141)) + 24|0);
          $148 = HEAP32[$147>>2]|0;
          $149 = ($148|0)==(0|0);
          $$pre$i$i = ((($141)) + 20|0);
          if (!($149)) {
           $150 = HEAP32[$$pre$i$i>>2]|0;
           $151 = ((($148)) + 20|0);
           HEAP32[$151>>2] = $150;
          }
          $152 = HEAP32[$$pre$i$i>>2]|0;
          $153 = ($152|0)==(0|0);
          if (!($153)) {
           $154 = ((($152)) + 24|0);
           HEAP32[$154>>2] = $148;
          }
          $155 = ((($146)) + 252|0);
          $156 = HEAP32[$155>>2]|0;
          $157 = ($156|0)==($141|0);
          if ($157) {
           $158 = HEAP32[$147>>2]|0;
           HEAP32[$155>>2] = $158;
          }
          $159 = ((($146)) + 248|0);
          $160 = HEAP32[$159>>2]|0;
          $161 = (($160) + -1)|0;
          HEAP32[$159>>2] = $161;
          $162 = ((($146)) + 60|0);
          $163 = HEAP32[$162>>2]|0;
          $164 = HEAP32[$141>>2]|0;
          FUNCTION_TABLE_vi[$163 & 8191]($164);
          _SDL_free($141);
          $$pre$i = HEAP32[$138>>2]|0;
          $166 = $$pre$i;
         } else {
          $166 = $139;
         }
         $165 = ((($166)) + 12|0);
         $167 = HEAP32[$165>>2]|0;
         $168 = ((($167)) + 12|0);
         $169 = HEAP32[$168>>2]|0;
         $170 = (($169) + -1)|0;
         HEAP32[$168>>2] = $170;
         $171 = ($169|0)<(2);
         if ($171) {
          $172 = HEAP32[$5>>2]|0;
          $173 = ((($167)) + 24|0);
          $174 = HEAP32[$173>>2]|0;
          $175 = ($174|0)==(0|0);
          $$pre$i131$i = ((($167)) + 20|0);
          if (!($175)) {
           $176 = HEAP32[$$pre$i131$i>>2]|0;
           $177 = ((($174)) + 20|0);
           HEAP32[$177>>2] = $176;
          }
          $178 = HEAP32[$$pre$i131$i>>2]|0;
          $179 = ($178|0)==(0|0);
          if (!($179)) {
           $180 = ((($178)) + 24|0);
           HEAP32[$180>>2] = $174;
          }
          $181 = ((($172)) + 252|0);
          $182 = HEAP32[$181>>2]|0;
          $183 = ($182|0)==($167|0);
          if ($183) {
           $184 = HEAP32[$173>>2]|0;
           HEAP32[$181>>2] = $184;
          }
          $185 = ((($172)) + 248|0);
          $186 = HEAP32[$185>>2]|0;
          $187 = (($186) + -1)|0;
          HEAP32[$185>>2] = $187;
          $188 = ((($172)) + 60|0);
          $189 = HEAP32[$188>>2]|0;
          $190 = HEAP32[$167>>2]|0;
          FUNCTION_TABLE_vi[$189 & 8191]($190);
          _SDL_free($167);
          $$pre138$i = HEAP32[$138>>2]|0;
          $194 = $$pre138$i;
         } else {
          $194 = $166;
         }
         $191 = ((($20)) + 56|0);
         $192 = HEAP32[$191>>2]|0;
         $193 = HEAP32[$194>>2]|0;
         FUNCTION_TABLE_vi[$192 & 8191]($193);
         $195 = HEAP32[$138>>2]|0;
         $196 = ((($195)) + 152|0);
         $197 = HEAP32[$196>>2]|0;
         HEAP32[$138>>2] = $197;
         $198 = ((($197)) + 156|0);
         $199 = HEAP32[$198>>2]|0;
         _SDL_free($199);
         $200 = HEAP32[$138>>2]|0;
         $201 = ((($200)) + 156|0);
         HEAP32[$201>>2] = 0;
         $202 = HEAP32[$128>>2]|0;
         $203 = (($202) + -1)|0;
         HEAP32[$128>>2] = $203;
         $$0129$i$ph = $41;
         label = 49;
         break L35;
        }
       } while(0);
       $$04758 = $9;
       break L12;
      }
     } while(0);
     if ((label|0) == 49) {
      $$0129$i53 = $$0129$i$ph;
     }
     $204 = ((($6)) + 180|0);
     $205 = HEAP32[$204>>2]|0;
     $206 = HEAP32[$$0129$i53>>2]|0;
     FUNCTION_TABLE_vi[$205 & 8191]($206);
     HEAP32[$11>>2] = $$0129$i53;
     $207 = HEAP32[$5>>2]|0;
     $208 = ((($0)) + 224|0);
     $209 = HEAP32[$208>>2]|0;
     $210 = ($209|0)==(0);
     if (!($210)) {
      $211 = ((($0)) + 228|0);
      $212 = HEAP32[$211>>2]|0;
      $213 = ($212|0)==(0);
      if (!($213)) {
       $214 = (+($209|0));
       $215 = 2.0 / $214;
       HEAPF32[$3>>2] = $215;
       $216 = ((($3)) + 4|0);
       $217 = ((($0)) + 308|0);
       ;HEAP32[$216>>2]=0|0;HEAP32[$216+4>>2]=0|0;HEAP32[$216+8>>2]=0|0;HEAP32[$216+12>>2]=0|0;
       $218 = HEAP32[$217>>2]|0;
       $219 = ($218|0)!=(0|0);
       $220 = (+($212|0));
       $$sink3$i = $219 ? 2.0 : -2.0;
       $221 = $$sink3$i / $220;
       $222 = ((($3)) + 20|0);
       HEAPF32[$222>>2] = $221;
       $223 = ((($3)) + 24|0);
       $224 = ((($3)) + 48|0);
       ;HEAP32[$223>>2]=0|0;HEAP32[$223+4>>2]=0|0;HEAP32[$223+8>>2]=0|0;HEAP32[$223+12>>2]=0|0;HEAP32[$223+16>>2]=0|0;HEAP32[$223+20>>2]=0|0;
       HEAPF32[$224>>2] = -1.0;
       $225 = ((($3)) + 52|0);
       $$sink$i = $219 ? -1.0 : 1.0;
       HEAPF32[$225>>2] = $$sink$i;
       $226 = ((($3)) + 56|0);
       HEAPF32[$226>>2] = 0.0;
       $227 = ((($3)) + 60|0);
       HEAPF32[$227>>2] = 1.0;
       $228 = ((($207)) + 268|0);
       $229 = HEAP32[$228>>2]|0;
       $230 = ((($229)) + 88|0);
       $231 = (_SDL_memcmp($230,$3,64)|0);
       $232 = ($231|0)==(0);
       if (!($232)) {
        $233 = HEAP32[$228>>2]|0;
        $234 = ((($233)) + 16|0);
        $235 = HEAP32[$234>>2]|0;
        $236 = ((($207)) + 176|0);
        $237 = HEAP32[$236>>2]|0;
        FUNCTION_TABLE_viiii[$237 & 8191]($235,1,0,$3);
        $238 = HEAP32[$228>>2]|0;
        $239 = ((($238)) + 88|0);
        (_SDL_memcpy($239,$3,64)|0);
       }
      }
     }
     $$0 = 0;
     STACKTOP = sp;return ($$0|0);
    }
   } while(0);
   $240 = ((($7)) + 12|0);
   $241 = HEAP32[$240>>2]|0;
   $242 = ($241|0)<(1);
   if ($242) {
    $243 = HEAP32[$5>>2]|0;
    $244 = ((($7)) + 24|0);
    $245 = HEAP32[$244>>2]|0;
    $246 = ($245|0)==(0|0);
    $$pre$i48 = ((($7)) + 20|0);
    if (!($246)) {
     $247 = HEAP32[$$pre$i48>>2]|0;
     $248 = ((($245)) + 20|0);
     HEAP32[$248>>2] = $247;
    }
    $249 = HEAP32[$$pre$i48>>2]|0;
    $250 = ($249|0)==(0|0);
    if (!($250)) {
     $251 = ((($249)) + 24|0);
     HEAP32[$251>>2] = $245;
    }
    $252 = ((($243)) + 252|0);
    $253 = HEAP32[$252>>2]|0;
    $254 = ($253|0)==($7|0);
    if ($254) {
     $255 = HEAP32[$244>>2]|0;
     HEAP32[$252>>2] = $255;
    }
    $256 = ((($243)) + 248|0);
    $257 = HEAP32[$256>>2]|0;
    $258 = (($257) + -1)|0;
    HEAP32[$256>>2] = $258;
    $259 = ((($243)) + 60|0);
    $260 = HEAP32[$259>>2]|0;
    $261 = HEAP32[$7>>2]|0;
    FUNCTION_TABLE_vi[$260 & 8191]($261);
    _SDL_free($7);
   }
   $262 = ($$04758|0)==(0|0);
   if (!($262)) {
    $263 = ((($$04758)) + 12|0);
    $264 = HEAP32[$263>>2]|0;
    $265 = ($264|0)<(1);
    if ($265) {
     $266 = HEAP32[$5>>2]|0;
     $267 = ((($$04758)) + 24|0);
     $268 = HEAP32[$267>>2]|0;
     $269 = ($268|0)==(0|0);
     $$pre$i50 = ((($$04758)) + 20|0);
     if (!($269)) {
      $270 = HEAP32[$$pre$i50>>2]|0;
      $271 = ((($268)) + 20|0);
      HEAP32[$271>>2] = $270;
     }
     $272 = HEAP32[$$pre$i50>>2]|0;
     $273 = ($272|0)==(0|0);
     if (!($273)) {
      $274 = ((($272)) + 24|0);
      HEAP32[$274>>2] = $268;
     }
     $275 = ((($266)) + 252|0);
     $276 = HEAP32[$275>>2]|0;
     $277 = ($276|0)==($$04758|0);
     if ($277) {
      $278 = HEAP32[$267>>2]|0;
      HEAP32[$275>>2] = $278;
     }
     $279 = ((($266)) + 248|0);
     $280 = HEAP32[$279>>2]|0;
     $281 = (($280) + -1)|0;
     HEAP32[$279>>2] = $281;
     $282 = ((($266)) + 60|0);
     $283 = HEAP32[$282>>2]|0;
     $284 = HEAP32[$$04758>>2]|0;
     FUNCTION_TABLE_vi[$283 & 8191]($284);
     _SDL_free($$04758);
    }
   }
  }
 }
 $285 = ((($6)) + 268|0);
 HEAP32[$285>>2] = 0;
 $$0 = -1;
 STACKTOP = sp;return ($$0|0);
}
function _GLES2_CacheShader($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$$1$us104 = 0, $$08295$us102 = 0, $$08399$us = 0, $$084 = 0, $$08491 = 0, $$08492 = 0, $$086 = 0, $$1$lcssa$us = 0, $$alloca_mul = 0, $$not$us = 0, $$not97 = 0, $$pr = 0, $$pre = 0, $$pre114 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $8 = 0, $9 = 0, $brmerge$us = 0, $or$cond$us106 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer3 = 0, $vararg_buffer5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $vararg_buffer5 = sp + 24|0;
 $vararg_buffer3 = sp + 16|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $3 = sp + 32|0;
 $4 = sp + 28|0;
 $5 = ((($0)) + 320|0);
 $6 = HEAP32[$5>>2]|0;
 HEAP32[$3>>2] = 0;
 $7 = (_GLES2_GetShader($1,$2)|0);
 $8 = ($7|0)==(0|0);
 if ($8) {
  (_SDL_SetError(176964,$vararg_buffer)|0);
  $$086 = 0;
  STACKTOP = sp;return ($$086|0);
 }
 $9 = HEAP32[$7>>2]|0;
 $$not97 = ($9|0)<(1);
 if (!($$not97)) {
  $10 = ((($6)) + 240|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($11|0)>(0);
  $13 = ((($6)) + 244|0);
  if ($12) {
   $$08399$us = 0;
   while(1) {
    $23 = (((($7)) + 4|0) + ($$08399$us<<2)|0);
    $19 = HEAP32[$23>>2]|0;
    $24 = ($19|0)==(0|0);
    if ($24) {
     $$1$lcssa$us = 0;
    } else {
     $25 = ((($19)) + 4|0);
     $$pre = HEAP32[$25>>2]|0;
     $$pre114 = HEAP32[$13>>2]|0;
     $$08295$us102 = 0;
     while(1) {
      $16 = (($$pre114) + ($$08295$us102<<2)|0);
      $17 = HEAP32[$16>>2]|0;
      $18 = ($$pre|0)==($17|0);
      $$$1$us104 = $18 ? $19 : 0;
      $20 = (($$08295$us102) + 1)|0;
      $21 = ($20|0)<($11|0);
      $22 = ($$$1$us104|0)==(0|0);
      $or$cond$us106 = $22 & $21;
      if ($or$cond$us106) {
       $$08295$us102 = $20;
      } else {
       $$1$lcssa$us = $$$1$us104;
       break;
      }
     }
    }
    $14 = (($$08399$us) + 1)|0;
    $15 = ($$1$lcssa$us|0)!=(0|0);
    $$not$us = ($14|0)>=($9|0);
    $brmerge$us = $15 | $$not$us;
    if ($brmerge$us) {
     break;
    } else {
     $$08399$us = $14;
    }
   }
   if ($15) {
    $26 = ((($6)) + 252|0);
    $$08491 = HEAP32[$26>>2]|0;
    $27 = ($$08491|0)==(0|0);
    L16: do {
     if (!($27)) {
      $$08492 = $$08491;
      while(1) {
       $28 = ((($$08492)) + 8|0);
       $29 = HEAP32[$28>>2]|0;
       $30 = ($29|0)==($$1$lcssa$us|0);
       if ($30) {
        $$086 = $$08492;
        break;
       }
       $31 = ((($$08492)) + 24|0);
       $$084 = HEAP32[$31>>2]|0;
       $32 = ($$084|0)==(0|0);
       if ($32) {
        break L16;
       } else {
        $$08492 = $$084;
       }
      }
      STACKTOP = sp;return ($$086|0);
     }
    } while(0);
    $33 = (_SDL_calloc(1,28)|0);
    $34 = ($33|0)==(0|0);
    if ($34) {
     (_SDL_Error(0)|0);
     $$086 = 0;
     STACKTOP = sp;return ($$086|0);
    }
    $35 = ((($33)) + 4|0);
    HEAP32[$35>>2] = $1;
    $36 = ((($33)) + 8|0);
    HEAP32[$36>>2] = $$1$lcssa$us;
    $37 = ((($6)) + 52|0);
    $38 = HEAP32[$37>>2]|0;
    $39 = HEAP32[$$1$lcssa$us>>2]|0;
    $40 = (FUNCTION_TABLE_ii[$38 & 8191]($39)|0);
    HEAP32[$33>>2] = $40;
    $41 = ((($$1$lcssa$us)) + 4|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = ($42|0)==(-1);
    if ($43) {
     $50 = ((($6)) + 152|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = ((($$1$lcssa$us)) + 12|0);
     FUNCTION_TABLE_viiii[$51 & 8191]($40,1,$52,0);
     $53 = ((($6)) + 44|0);
     $54 = HEAP32[$53>>2]|0;
     $55 = HEAP32[$33>>2]|0;
     FUNCTION_TABLE_vi[$54 & 8191]($55);
     $56 = ((($6)) + 124|0);
     $57 = HEAP32[$56>>2]|0;
     $58 = HEAP32[$33>>2]|0;
     FUNCTION_TABLE_viii[$57 & 8191]($58,35713,$3);
     $$pr = HEAP32[$3>>2]|0;
     $59 = ($$pr|0)==(0);
     if ($59) {
      HEAP32[$4>>2] = 0;
      $60 = HEAP32[$56>>2]|0;
      $61 = HEAP32[$33>>2]|0;
      FUNCTION_TABLE_viii[$60 & 8191]($61,35716,$4);
      $62 = HEAP32[$4>>2]|0;
      $63 = ($62|0)>(0);
      if ($63) {
       $$alloca_mul = $62;
       $64 = STACKTOP; STACKTOP = STACKTOP + ((((1*$$alloca_mul)|0)+15)&-16)|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(((((1*$$alloca_mul)|0)+15)&-16)|0);;
       $65 = ((($6)) + 120|0);
       $66 = HEAP32[$65>>2]|0;
       $67 = HEAP32[$33>>2]|0;
       FUNCTION_TABLE_viiii[$66 & 8191]($67,$62,$4,$64);
       HEAP32[$vararg_buffer3>>2] = $64;
       (_SDL_SetError(177085,$vararg_buffer3)|0);
      } else {
       (_SDL_SetError(177115,$vararg_buffer5)|0);
      }
      $68 = ((($6)) + 60|0);
      $69 = HEAP32[$68>>2]|0;
      $70 = HEAP32[$33>>2]|0;
      FUNCTION_TABLE_vi[$69 & 8191]($70);
      _SDL_free($33);
      $$086 = 0;
      STACKTOP = sp;return ($$086|0);
     }
    } else {
     $44 = ((($6)) + 148|0);
     $45 = HEAP32[$44>>2]|0;
     $46 = ((($$1$lcssa$us)) + 12|0);
     $47 = HEAP32[$46>>2]|0;
     $48 = ((($$1$lcssa$us)) + 8|0);
     $49 = HEAP32[$48>>2]|0;
     FUNCTION_TABLE_viiiii[$45 & 8191](1,$33,$42,$47,$49);
     HEAP32[$3>>2] = 1;
    }
    $71 = HEAP32[$26>>2]|0;
    $72 = ($71|0)==(0|0);
    if (!($72)) {
     $73 = ((($33)) + 24|0);
     HEAP32[$73>>2] = $71;
     $74 = ((($71)) + 20|0);
     HEAP32[$74>>2] = $33;
    }
    HEAP32[$26>>2] = $33;
    $75 = ((($6)) + 248|0);
    $76 = HEAP32[$75>>2]|0;
    $77 = (($76) + 1)|0;
    HEAP32[$75>>2] = $77;
    $$086 = $33;
    STACKTOP = sp;return ($$086|0);
   }
  }
 }
 (_SDL_SetError(177023,$vararg_buffer1)|0);
 $$086 = 0;
 STACKTOP = sp;return ($$086|0);
}
function _GLES2_GetShader($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 L1: do {
  switch ($0|0) {
  case 0:  {
   $$0 = 88316;
   break;
  }
  case 1:  {
   switch ($1|0) {
   case 0:  {
    $$0 = 88336;
    break L1;
    break;
   }
   case 1:  {
    $$0 = 88296;
    break L1;
    break;
   }
   case 2:  {
    $$0 = 88276;
    break L1;
    break;
   }
   case 4:  {
    $$0 = 88256;
    break L1;
    break;
   }
   default: {
    $$0 = 0;
    break L1;
   }
   }
   break;
  }
  case 2:  {
   switch ($1|0) {
   case 0:  {
    $$0 = 88356;
    break L1;
    break;
   }
   case 1:  {
    $$0 = 88236;
    break L1;
    break;
   }
   case 2:  {
    $$0 = 88216;
    break L1;
    break;
   }
   case 4:  {
    $$0 = 88196;
    break L1;
    break;
   }
   default: {
    $$0 = 0;
    break L1;
   }
   }
   break;
  }
  case 3:  {
   switch ($1|0) {
   case 0:  {
    $$0 = 88376;
    break L1;
    break;
   }
   case 1:  {
    $$0 = 88176;
    break L1;
    break;
   }
   case 2:  {
    $$0 = 88156;
    break L1;
    break;
   }
   case 4:  {
    $$0 = 88136;
    break L1;
    break;
   }
   default: {
    $$0 = 0;
    break L1;
   }
   }
   break;
  }
  case 5:  {
   switch ($1|0) {
   case 0:  {
    $$0 = 88396;
    break L1;
    break;
   }
   case 1:  {
    $$0 = 88116;
    break L1;
    break;
   }
   case 2:  {
    $$0 = 88096;
    break L1;
    break;
   }
   case 4:  {
    $$0 = 88076;
    break L1;
    break;
   }
   default: {
    $$0 = 0;
    break L1;
   }
   }
   break;
  }
  case 4:  {
   switch ($1|0) {
   case 0:  {
    $$0 = 88416;
    break L1;
    break;
   }
   case 1:  {
    $$0 = 88056;
    break L1;
    break;
   }
   case 2:  {
    $$0 = 88036;
    break L1;
    break;
   }
   case 4:  {
    $$0 = 88016;
    break L1;
    break;
   }
   default: {
    $$0 = 0;
    break L1;
   }
   }
   break;
  }
  case 6:  {
   $$0 = 87996;
   break;
  }
  case 7:  {
   $$0 = 87976;
   break;
  }
  case 8:  {
   $$0 = 87956;
   break;
  }
  default: {
   $$0 = 0;
  }
  }
 } while(0);
 return ($$0|0);
}
function _GLES2_SetDrawingState($0) {
 $0 = $0|0;
 var $$0 = 0, $$045 = 0, $$045$in = 0, $$046 = 0, $$046$in = 0, $$pre$i = 0, $1 = 0, $10 = 0, $100 = 0.0, $101 = 0.0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0.0, $95 = 0.0, $96 = 0.0, $97 = 0.0, $98 = 0.0, $99 = 0.0, $switch$split2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 320|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 316|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[52374]|0;
 $6 = HEAP32[$2>>2]|0;
 $7 = ($5|0)==($6|0);
 if ($7) {
  $15 = $2;
  label = 4;
 } else {
  $8 = ((($2)) + 268|0);
  HEAP32[$8>>2] = 0;
  $9 = ((($0)) + 188|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (_SDL_GL_MakeCurrent($10,$6)|0);
  $12 = ($11|0)<(0);
  if (!($12)) {
   $13 = HEAP32[$2>>2]|0;
   HEAP32[52374] = $13;
   (_GLES2_UpdateViewport($0)|0);
   $$pre$i = HEAP32[$1>>2]|0;
   $15 = $$pre$i;
   label = 4;
  }
 }
 if ((label|0) == 4) {
  $14 = ((($15)) + 4|0);
  $16 = HEAP32[$14>>2]|0;
  $17 = ($16|0)==(0);
  if (!($17)) {
   $18 = ((($15)) + 108|0);
   while(1) {
    $19 = HEAP32[$18>>2]|0;
    $20 = (FUNCTION_TABLE_i[$19 & 8191]()|0);
    $21 = ($20|0)==(0);
    if ($21) {
     break;
    }
   }
  }
 }
 $22 = ((($2)) + 8|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)==($4|0);
 if (!($24)) {
  switch ($4|0) {
  case 4:  {
   $35 = ((($2)) + 80|0);
   $36 = HEAP32[$35>>2]|0;
   FUNCTION_TABLE_vi[$36 & 8191](3042);
   $37 = ((($2)) + 32|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_viiii[$38 & 8191](0,768,0,1);
   break;
  }
  case 1:  {
   $27 = ((($2)) + 80|0);
   $28 = HEAP32[$27>>2]|0;
   FUNCTION_TABLE_vi[$28 & 8191](3042);
   $29 = ((($2)) + 32|0);
   $30 = HEAP32[$29>>2]|0;
   FUNCTION_TABLE_viiii[$30 & 8191](770,771,1,771);
   break;
  }
  case 2:  {
   $31 = ((($2)) + 80|0);
   $32 = HEAP32[$31>>2]|0;
   FUNCTION_TABLE_vi[$32 & 8191](3042);
   $33 = ((($2)) + 32|0);
   $34 = HEAP32[$33>>2]|0;
   FUNCTION_TABLE_viiii[$34 & 8191](770,1,0,1);
   break;
  }
  default: {
   $25 = ((($2)) + 68|0);
   $26 = HEAP32[$25>>2]|0;
   FUNCTION_TABLE_vi[$26 & 8191](3042);
  }
  }
  HEAP32[$22>>2] = $4;
 }
 $39 = ((($2)) + 12|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ($40|0)==(0);
 if (!($41)) {
  $42 = ((($2)) + 72|0);
  $43 = HEAP32[$42>>2]|0;
  FUNCTION_TABLE_vi[$43 & 8191](1);
  HEAP32[$39>>2] = 0;
 }
 $44 = (_GLES2_SelectProgram($0,0,$4)|0);
 $45 = ($44|0)<(0);
 if ($45) {
  $$0 = -1;
  return ($$0|0);
 }
 $46 = ((($0)) + 313|0);
 $47 = HEAP8[$46>>0]|0;
 $48 = ((($0)) + 315|0);
 $49 = HEAP8[$48>>0]|0;
 $50 = ((($0)) + 308|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = ($51|0)==(0|0);
 L25: do {
  if ($52) {
   label = 20;
  } else {
   $53 = ((($51)) + 4|0);
   $54 = HEAP32[$53>>2]|0;
   $switch$split2D = ($54|0)<(372645892);
   if ($switch$split2D) {
    switch ($54|0) {
    case 370546692:  {
     break;
    }
    default: {
     label = 20;
     break L25;
    }
    }
   } else {
    switch ($54|0) {
    case 372645892:  {
     break;
    }
    default: {
     label = 20;
     break L25;
    }
    }
   }
   $55 = ((($0)) + 314|0);
   $56 = ((($0)) + 312|0);
   $$045$in = $56;$$046$in = $55;
  }
 } while(0);
 if ((label|0) == 20) {
  $57 = ((($0)) + 312|0);
  $58 = ((($0)) + 314|0);
  $$045$in = $58;$$046$in = $57;
 }
 $$045 = HEAP8[$$045$in>>0]|0;
 $$046 = HEAP8[$$046$in>>0]|0;
 $59 = ((($2)) + 268|0);
 $60 = HEAP32[$59>>2]|0;
 $61 = ((($60)) + 80|0);
 $62 = HEAP8[$61>>0]|0;
 $63 = ((($60)) + 81|0);
 $64 = HEAP8[$63>>0]|0;
 $65 = ((($60)) + 82|0);
 $66 = HEAP8[$65>>0]|0;
 $67 = ((($60)) + 83|0);
 $68 = HEAP8[$67>>0]|0;
 $69 = $62&255;
 $70 = $69 << 24;
 $71 = $64&255;
 $72 = $71 << 16;
 $73 = $72 | $70;
 $74 = $66&255;
 $75 = $74 << 8;
 $76 = $73 | $75;
 $77 = $68&255;
 $78 = $76 | $77;
 $79 = $$046&255;
 $80 = $79 << 24;
 $81 = $47&255;
 $82 = $81 << 16;
 $83 = $$045&255;
 $84 = $83 << 8;
 $85 = $49&255;
 $86 = $85 | $82;
 $87 = $86 | $84;
 $88 = $87 | $80;
 $89 = ($78|0)==($88|0);
 if ($89) {
  $$0 = 0;
  return ($$0|0);
 }
 $90 = ((($2)) + 172|0);
 $91 = HEAP32[$90>>2]|0;
 $92 = ((($60)) + 28|0);
 $93 = HEAP32[$92>>2]|0;
 $94 = (+($$046&255));
 $95 = $94 * 0.0039215688593685627;
 $96 = (+($47&255));
 $97 = $96 * 0.0039215688593685627;
 $98 = (+($$045&255));
 $99 = $98 * 0.0039215688593685627;
 $100 = (+($49&255));
 $101 = $100 * 0.0039215688593685627;
 FUNCTION_TABLE_vidddd[$91 & 8191]($93,$95,$97,$99,$101);
 HEAP8[$61>>0] = $$046;
 HEAP8[$63>>0] = $47;
 HEAP8[$65>>0] = $$045;
 HEAP8[$67>>0] = $49;
 $$0 = 0;
 return ($$0|0);
}
function _SDL_GL_GetDrawableSize($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $3 = HEAP32[52375]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  (_SDL_SetError(175439,$vararg_buffer)|0);
  STACKTOP = sp;return;
 }
 $5 = ($0|0)==(0|0);
 if (!($5)) {
  $6 = HEAP32[$0>>2]|0;
  $7 = ((($3)) + 280|0);
  $8 = ($6|0)==($7|0);
  if ($8) {
   $9 = ((($3)) + 184|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($10|0)==(0|0);
   if (!($11)) {
    FUNCTION_TABLE_viiii[$10 & 8191]($3,$0,$1,$2);
    STACKTOP = sp;return;
   }
   $12 = ($1|0)==(0|0);
   if (!($12)) {
    $13 = ((($0)) + 24|0);
    $14 = HEAP32[$13>>2]|0;
    HEAP32[$1>>2] = $14;
   }
   $15 = ($2|0)==(0|0);
   if ($15) {
    STACKTOP = sp;return;
   }
   $16 = ((($0)) + 28|0);
   $17 = HEAP32[$16>>2]|0;
   HEAP32[$2>>2] = $17;
   STACKTOP = sp;return;
  }
 }
 (_SDL_SetError(195204,$vararg_buffer1)|0);
 STACKTOP = sp;return;
}
function _SDL_GetHint($0) {
 $0 = $0|0;
 var $$0 = 0, $$013 = 0, $$015 = 0, $$016 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (_SDL_getenv($0)|0);
 $$015 = HEAP32[52378]|0;
 $2 = ($$015|0)==(0|0);
 if ($2) {
  $$013 = $1;
  return ($$013|0);
 } else {
  $$016 = $$015;
 }
 while(1) {
  $3 = HEAP32[$$016>>2]|0;
  $4 = (_SDL_strcmp($0,$3)|0);
  $5 = ($4|0)==(0);
  if ($5) {
   break;
  }
  $12 = ((($$016)) + 16|0);
  $$0 = HEAP32[$12>>2]|0;
  $13 = ($$0|0)==(0|0);
  if ($13) {
   $$013 = $1;
   label = 7;
   break;
  } else {
   $$016 = $$0;
  }
 }
 if ((label|0) == 7) {
  return ($$013|0);
 }
 $6 = ($1|0)==(0|0);
 if (!($6)) {
  $7 = ((($$016)) + 8|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)==(2);
  if (!($9)) {
   $$013 = $1;
   return ($$013|0);
  }
 }
 $10 = ((($$016)) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $$013 = $11;
 return ($$013|0);
}
function _SDL_strcasecmp($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_strcasecmp($0,$1)|0);
 return ($2|0);
}
function _SDL_strcmp($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_strcmp($0,$1)|0);
 return ($2|0);
}
function _SDL_strlcpy($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (_strlen($1)|0);
 $4 = ($2|0)==(0);
 $5 = (($2) + -1)|0;
 $6 = ($3>>>0)<($5>>>0);
 $7 = $6 ? $3 : $5;
 if ($4) {
  return ($3|0);
 }
 $8 = (($0) + ($7)|0);
 _memcpy(($0|0),($1|0),($7|0))|0;
 HEAP8[$8>>0] = 0;
 return ($3|0);
}
function _SDL_LogDebug($0,$1,$varargs) {
 $0 = $0|0;
 $1 = $1|0;
 $varargs = $varargs|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 HEAP32[$2>>2] = $varargs;
 _SDL_LogMessageV($0,2,$1,$2);
 STACKTOP = sp;return;
}
function _SDL_LogMessageV($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0$i = 0, $$010$i = 0, $$011$i = 0, $$08$i = 0, $$sink = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = HEAP32[22145]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $6 = ($1|0)<(0);
 $7 = ($1>>>0)>(6);
 $or$cond = $6 | $7;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 $$010$i = HEAP32[52379]|0;
 $8 = ($$010$i|0)==(0|0);
 L7: do {
  if ($8) {
   label = 7;
  } else {
   $$011$i = $$010$i;
   while(1) {
    $9 = HEAP32[$$011$i>>2]|0;
    $10 = ($9|0)==($0|0);
    if ($10) {
     break;
    }
    $12 = ((($$011$i)) + 8|0);
    $$0$i = HEAP32[$12>>2]|0;
    $13 = ($$0$i|0)==(0|0);
    if ($13) {
     label = 7;
     break L7;
    } else {
     $$011$i = $$0$i;
    }
   }
   $11 = ((($$011$i)) + 4|0);
   $$sink = $11;
   label = 10;
  }
 } while(0);
 L12: do {
  if ((label|0) == 7) {
   switch ($0|0) {
   case 8:  {
    $$08$i = 1;
    break L12;
    break;
   }
   case 0:  {
    $$sink = 88592;
    label = 10;
    break L12;
    break;
   }
   case 2:  {
    $$sink = 88584;
    label = 10;
    break L12;
    break;
   }
   default: {
    $$sink = 88588;
    label = 10;
    break L12;
   }
   }
  }
 } while(0);
 if ((label|0) == 10) {
  $14 = HEAP32[$$sink>>2]|0;
  $$08$i = $14;
 }
 $15 = ($$08$i>>>0)>($1>>>0);
 if ($15) {
  STACKTOP = sp;return;
 }
 $16 = STACKTOP; STACKTOP = STACKTOP + 4096|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(4096|0);;
 (_SDL_vsnprintf($16,4096,$2,$3)|0);
 $17 = (_SDL_strlen($16)|0);
 $18 = ($17|0)==(0);
 if (!($18)) {
  $19 = (($17) + -1)|0;
  $20 = (($16) + ($19)|0);
  $21 = HEAP8[$20>>0]|0;
  $22 = ($21<<24>>24)==(10);
  if ($22) {
   HEAP8[$20>>0] = 0;
   $23 = ($19|0)==(0);
   if (!($23)) {
    $24 = (($17) + -2)|0;
    $25 = (($16) + ($24)|0);
    $26 = HEAP8[$25>>0]|0;
    $27 = ($26<<24>>24)==(13);
    if ($27) {
     HEAP8[$25>>0] = 0;
    }
   }
  }
 }
 $28 = HEAP32[22145]|0;
 $29 = HEAP32[52380]|0;
 FUNCTION_TABLE_viiii[$28 & 8191]($29,$0,$1,$16);
 STACKTOP = sp;return;
}
function _SDL_vsnprintf($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$ = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ($2|0)==(0|0);
 $$ = $4 ? 221531 : $2;
 $5 = (_vsnprintf($0,$1,$$,$3)|0);
 return ($5|0);
}
function _SDL_LogOutput($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $4 = 0, $5 = 0, $6 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $4 = HEAP32[23152]|0;
 $5 = (88596 + ($2<<2)|0);
 $6 = HEAP32[$5>>2]|0;
 HEAP32[$vararg_buffer>>2] = $6;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $3;
 (_fprintf($4,181643,$vararg_buffer)|0);
 STACKTOP = sp;return;
}
function _SDL_snprintf($0,$1,$2,$varargs) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $varargs = $varargs|0;
 var $$$i = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 HEAP32[$3>>2] = $varargs;
 $4 = ($2|0)==(0|0);
 $$$i = $4 ? 221531 : $2;
 $5 = (_vsnprintf($0,$1,$$$i,$3)|0);
 STACKTOP = sp;return ($5|0);
}
function _SDL_TLSSet($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$034 = 0, $$1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $3 = ($0|0)==(0);
 if ($3) {
  HEAP32[$vararg_buffer>>2] = 181757;
  $4 = (_SDL_SetError(194740,$vararg_buffer)|0);
  $$1 = $4;
  STACKTOP = sp;return ($$1|0);
 }
 $5 = (_SDL_SYS_GetTLSData()|0);
 $6 = ($5|0)==(0|0);
 if ($6) {
  $16 = 0;
  label = 5;
 } else {
  $7 = HEAP32[$5>>2]|0;
  $8 = ($7>>>0)<($0>>>0);
  if ($8) {
   $16 = $7;
   label = 5;
  } else {
   $$034 = $5;
  }
 }
 if ((label|0) == 5) {
  $9 = (($0) + 4)|0;
  $10 = $0 << 3;
  $11 = (($10) + 36)|0;
  $12 = (_SDL_realloc($5,$11)|0);
  $13 = ($12|0)==(0|0);
  if ($13) {
   $14 = (_SDL_Error(0)|0);
   $$1 = $14;
   STACKTOP = sp;return ($$1|0);
  }
  HEAP32[$12>>2] = $9;
  $15 = ($9>>>0)>($16>>>0);
  if ($15) {
   $17 = $16 << 3;
   $18 = $17 | 4;
   $scevgep = (($12) + ($18)|0);
   $19 = (($9) - ($16))|0;
   $20 = $19 << 3;
   _memset(($scevgep|0),0,($20|0))|0;
  }
  $21 = (_SDL_SYS_SetTLSData($12)|0);
  $22 = ($21|0)==(0);
  if ($22) {
   $$034 = $12;
  } else {
   $$1 = -1;
   STACKTOP = sp;return ($$1|0);
  }
 }
 $23 = (($0) + -1)|0;
 $24 = (((($$034)) + 4|0) + ($23<<3)|0);
 HEAP32[$24>>2] = $1;
 $25 = (((((($$034)) + 4|0) + ($23<<3)|0)) + 4|0);
 HEAP32[$25>>2] = $2;
 $$1 = 0;
 STACKTOP = sp;return ($$1|0);
}
function _SDL_SYS_SetTLSData($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (_SDL_Generic_SetTLSData($0)|0);
 return ($1|0);
}
function _SDL_Generic_SetTLSData($0) {
 $0 = $0|0;
 var $$0 = 0, $$02631 = 0, $$02631$phi = 0, $$027 = 0, $$030 = 0, $$032 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (_SDL_ThreadID()|0);
 $$030 = HEAP32[52376]|0;
 $2 = ($$030|0)==(0|0);
 L1: do {
  if ($2) {
   label = 7;
  } else {
   $$02631 = 0;$$032 = $$030;
   while(1) {
    $3 = HEAP32[$$032>>2]|0;
    $4 = ($3|0)==($1|0);
    if ($4) {
     break;
    }
    $12 = ((($$032)) + 8|0);
    $$0 = HEAP32[$12>>2]|0;
    $13 = ($$0|0)==(0|0);
    if ($13) {
     label = 7;
     break L1;
    } else {
     $$02631$phi = $$032;$$032 = $$0;$$02631 = $$02631$phi;
    }
   }
   $5 = ($0|0)==(0|0);
   if ($5) {
    $7 = ($$02631|0)!=(0|0);
    $8 = ((($$032)) + 8|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = ((($$02631)) + 8|0);
    $11 = $7 ? $10 : 209504;
    HEAP32[$11>>2] = $9;
    _SDL_free($$032);
    break;
   } else {
    $6 = ((($$032)) + 4|0);
    HEAP32[$6>>2] = $0;
    break;
   }
  }
 } while(0);
 do {
  if ((label|0) == 7) {
   $14 = (_SDL_malloc(12)|0);
   $15 = ($14|0)==(0|0);
   if (!($15)) {
    HEAP32[$14>>2] = $1;
    $16 = ((($14)) + 4|0);
    HEAP32[$16>>2] = $0;
    $17 = HEAP32[52376]|0;
    $18 = ((($14)) + 8|0);
    HEAP32[$18>>2] = $17;
    HEAP32[52376] = $14;
    break;
   }
   $19 = (_SDL_Error(0)|0);
   $$027 = $19;
   return ($$027|0);
  }
 } while(0);
 $$027 = 0;
 return ($$027|0);
}
function _SDL_UnlockMutex($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function _SDL_GL_DeleteContext($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[52375]|0;
 $2 = ($1|0)!=(0|0);
 $3 = ($0|0)!=(0|0);
 $or$cond = $3 & $2;
 if (!($or$cond)) {
  return;
 }
 $4 = ((($1)) + 664|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (_SDL_TLSGet($5)|0);
 $7 = ($6|0)==($0|0);
 if ($7) {
  (_SDL_GL_MakeCurrent(0,0)|0);
 }
 $8 = HEAP32[52375]|0;
 $9 = ((($8)) + 200|0);
 $10 = HEAP32[$9>>2]|0;
 FUNCTION_TABLE_vii[$10 & 8191]($8,$0);
 return;
}
function _SDL_UpdateFullscreenMode($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$0$i = 0, $$0$i71 = 0, $$0$i71$us = 0, $$061 = 0, $$061$lcssa86 = 0, $$061$us = 0, $$06187 = 0, $$06188 = 0, $$06188$us = 0, $$264$ph = 0, $$5 = 0, $$70 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0;
 var $160 = 0, $161 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $not$ = 0, $or$cond = 0, $or$cond65 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer3 = 0, $vararg_buffer5 = 0;
 var $vararg_buffer7 = 0, $vararg_buffer9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(160|0);
 $vararg_buffer9 = sp + 40|0;
 $vararg_buffer7 = sp + 32|0;
 $vararg_buffer5 = sp + 24|0;
 $vararg_buffer3 = sp + 16|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $2 = sp + 140|0;
 $3 = sp + 120|0;
 $4 = sp + 116|0;
 $5 = sp + 112|0;
 $6 = sp + 92|0;
 $7 = sp + 72|0;
 $8 = sp + 68|0;
 $9 = sp + 64|0;
 $10 = sp + 44|0;
 $11 = HEAP32[52375]|0;
 $12 = ($11|0)==(0|0);
 if ($12) {
  (_SDL_SetError(175439,$vararg_buffer)|0);
  $$5 = -1;
  STACKTOP = sp;return ($$5|0);
 }
 $13 = ($0|0)==(0|0);
 if (!($13)) {
  $14 = HEAP32[$0>>2]|0;
  $15 = ((($11)) + 280|0);
  $16 = ($14|0)==($15|0);
  if ($16) {
   $17 = ((($0)) + 116|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = ($18|0)!=(0);
   $20 = ($1|0)!=(0);
   $or$cond = $20 & $19;
   if ($or$cond) {
    $$5 = 0;
    STACKTOP = sp;return ($$5|0);
   }
   $21 = (_SDL_GetWindowDisplayIndex($0)|0);
   $22 = ($21|0)>(-1);
   if ($22) {
    $23 = HEAP32[52375]|0;
    $24 = ((($23)) + 268|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = (($25) + (($21*68)|0)|0);
    $$0$i = $26;
   } else {
    $$0$i = 0;
   }
   $27 = ((($$0$i)) + 56|0);
   do {
    if ($20) {
     $28 = HEAP32[$27>>2]|0;
     $29 = ($28|0)==(0|0);
     $30 = ($28|0)==($0|0);
     $or$cond65 = $29 | $30;
     if (!($or$cond65)) {
      $31 = HEAP32[52375]|0;
      $32 = ($31|0)==(0|0);
      if ($32) {
       (_SDL_SetError(175439,$vararg_buffer3)|0);
       break;
      }
      $33 = HEAP32[$28>>2]|0;
      $34 = ((($31)) + 280|0);
      $35 = ($33|0)==($34|0);
      if (!($35)) {
       (_SDL_SetError(195204,$vararg_buffer5)|0);
       break;
      }
      $36 = ((($28)) + 48|0);
      $37 = HEAP32[$36>>2]|0;
      $38 = $37 & 64;
      $39 = ($38|0)==(0);
      if ($39) {
       (_SDL_UpdateFullscreenMode($28,0)|0);
       $40 = HEAP32[52375]|0;
       $41 = ((($40)) + 96|0);
       $42 = HEAP32[$41>>2]|0;
       $43 = ($42|0)==(0|0);
       if (!($43)) {
        FUNCTION_TABLE_vii[$42 & 8191]($40,$28);
       }
      }
     }
    }
   } while(0);
   $44 = HEAP32[$27>>2]|0;
   $45 = ($44|0)==($0|0);
   $46 = $45&1;
   $47 = ($46|0)==($1|0);
   if ($47) {
    $48 = ((($0)) + 52|0);
    $49 = HEAP32[$48>>2]|0;
    $50 = ((($0)) + 48|0);
    $51 = HEAP32[$50>>2]|0;
    $52 = $51 ^ $49;
    $53 = $52 & 4097;
    $54 = ($53|0)==(0);
    if ($54) {
     $$5 = 0;
     STACKTOP = sp;return ($$5|0);
    }
   }
   $55 = HEAP32[52375]|0;
   $56 = ((($55)) + 272|0);
   $$06187 = HEAP32[$56>>2]|0;
   $57 = ($$06187|0)==(0|0);
   L30: do {
    if (!($57)) {
     $58 = ($1|0)==(0);
     L32: do {
      if ($58) {
       $$06188$us = $$06187;
       while(1) {
        $59 = ($$06188$us|0)==($0|0);
        if (!($59)) {
         $60 = ((($$06188$us)) + 48|0);
         $61 = HEAP32[$60>>2]|0;
         $62 = $61 & 69;
         $63 = ($62|0)==(5);
         if ($63) {
          $64 = (_SDL_GetWindowDisplayIndex($$06188$us)|0);
          $65 = ($64|0)>(-1);
          if ($65) {
           $66 = HEAP32[52375]|0;
           $67 = ((($66)) + 268|0);
           $68 = HEAP32[$67>>2]|0;
           $69 = (($68) + (($64*68)|0)|0);
           $$0$i71$us = $69;
          } else {
           $$0$i71$us = 0;
          }
          $70 = ($$0$i71$us|0)==($$0$i|0);
          if ($70) {
           (_SDL_memset($10,0,20)|0);
           $71 = (_SDL_GetWindowDisplayMode($$06188$us,$10)|0);
           $72 = ($71|0)==(0);
           if ($72) {
            $$061$lcssa86 = $$06188$us;
            break L32;
           }
          }
         }
        }
        $73 = ((($$06188$us)) + 152|0);
        $$061$us = HEAP32[$73>>2]|0;
        $74 = ($$061$us|0)==(0|0);
        if ($74) {
         break L30;
        } else {
         $$06188$us = $$061$us;
        }
       }
      } else {
       $$06188 = $$06187;
       while(1) {
        $75 = ($$06188|0)==($0|0);
        if ($75) {
         label = 35;
        } else {
         $76 = ((($$06188)) + 48|0);
         $77 = HEAP32[$76>>2]|0;
         $78 = $77 & 69;
         $79 = ($78|0)==(5);
         if ($79) {
          $80 = (_SDL_GetWindowDisplayIndex($$06188)|0);
          $81 = ($80|0)>(-1);
          if ($81) {
           $82 = HEAP32[52375]|0;
           $83 = ((($82)) + 268|0);
           $84 = HEAP32[$83>>2]|0;
           $85 = (($84) + (($80*68)|0)|0);
           $$0$i71 = $85;
          } else {
           $$0$i71 = 0;
          }
          $86 = ($$0$i71|0)==($$0$i|0);
          if ($86) {
           label = 35;
          }
         }
        }
        if ((label|0) == 35) {
         label = 0;
         (_SDL_memset($10,0,20)|0);
         $87 = (_SDL_GetWindowDisplayMode($$06188,$10)|0);
         $88 = ($87|0)==(0);
         if ($88) {
          $$061$lcssa86 = $$06188;
          break L32;
         }
        }
        $134 = ((($$06188)) + 152|0);
        $$061 = HEAP32[$134>>2]|0;
        $135 = ($$061|0)==(0|0);
        if ($135) {
         break L30;
        } else {
         $$06188 = $$061;
        }
       }
      }
     } while(0);
     $89 = ((($$061$lcssa86)) + 24|0);
     $90 = HEAP32[$89>>2]|0;
     $91 = ((($10)) + 4|0);
     $92 = HEAP32[$91>>2]|0;
     $93 = ($90|0)==($92|0);
     if ($93) {
      $94 = ((($$061$lcssa86)) + 28|0);
      $95 = HEAP32[$94>>2]|0;
      $96 = ((($10)) + 8|0);
      $97 = HEAP32[$96>>2]|0;
      $not$ = ($95|0)!=($97|0);
      $$70 = $not$&1;
      $$0 = $$70;
     } else {
      $$0 = 1;
     }
     $98 = ((($0)) + 48|0);
     $99 = HEAP32[$98>>2]|0;
     $100 = $99 & 4097;
     $101 = ($100|0)==(4097);
     L60: do {
      if ($101) {
       $104 = ((($$0$i)) + 16|0);
       ;HEAP32[$6>>2]=HEAP32[$104>>2]|0;HEAP32[$6+4>>2]=HEAP32[$104+4>>2]|0;HEAP32[$6+8>>2]=HEAP32[$104+8>>2]|0;HEAP32[$6+12>>2]=HEAP32[$104+12>>2]|0;HEAP32[$6+16>>2]=HEAP32[$104+16>>2]|0;
       $105 = ((($$0$i)) + 36|0);
       ;HEAP32[$7>>2]=HEAP32[$105>>2]|0;HEAP32[$7+4>>2]=HEAP32[$105+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[$105+8>>2]|0;HEAP32[$7+12>>2]=HEAP32[$105+12>>2]|0;HEAP32[$7+16>>2]=HEAP32[$105+16>>2]|0;
       $106 = (_SDL_memcmp($6,$7,20)|0);
       $107 = ($106|0)==(0);
       do {
        if (!($107)) {
         $108 = HEAP32[52375]|0;
         $109 = ((($108)) + 28|0);
         $110 = HEAP32[$109>>2]|0;
         $111 = ($110|0)==(0|0);
         if ($111) {
          $114 = (_SDL_SetError(182140,$vararg_buffer7)|0);
          $115 = ($114|0)<(0);
          if ($115) {
           $$264$ph = -1;
           break L60;
          } else {
           label = 47;
           break L60;
          }
         }
         $112 = (FUNCTION_TABLE_iiii[$110 & 8191]($108,$$0$i,$6)|0);
         $113 = ($112|0)<(0);
         if ($113) {
          $$264$ph = -1;
          break L60;
         } else {
          ;HEAP32[$105>>2]=HEAP32[$6>>2]|0;HEAP32[$105+4>>2]=HEAP32[$6+4>>2]|0;HEAP32[$105+8>>2]=HEAP32[$6+8>>2]|0;HEAP32[$105+12>>2]=HEAP32[$6+12>>2]|0;HEAP32[$105+16>>2]=HEAP32[$6+16>>2]|0;
          break;
         }
        }
       } while(0);
       label = 47;
      } else {
       $102 = (_SDL_SetDisplayModeForDisplay($$0$i,$10)|0);
       $103 = ($102|0)<(0);
       if ($103) {
        $$264$ph = -1;
       } else {
        label = 47;
       }
      }
     } while(0);
     if ((label|0) == 47) {
      $116 = HEAP32[52375]|0;
      $117 = ((($116)) + 112|0);
      $118 = HEAP32[$117>>2]|0;
      $119 = ($118|0)==(0|0);
      if (!($119)) {
       FUNCTION_TABLE_viiii[$118 & 8191]($116,$$061$lcssa86,$$0$i,1);
      }
      HEAP32[$27>>2] = $$061$lcssa86;
      $120 = ($$0|0)==(0);
      if ($120) {
       $124 = ((($$061$lcssa86)) + 112|0);
       HEAP32[$124>>2] = 0;
       $125 = HEAP32[$89>>2]|0;
       $126 = ((($$061$lcssa86)) + 28|0);
       $127 = HEAP32[$126>>2]|0;
       (_SDL_SendWindowEvent($$061$lcssa86,6,$125,$127)|0);
      } else {
       $121 = HEAP32[$91>>2]|0;
       $122 = ((($10)) + 8|0);
       $123 = HEAP32[$122>>2]|0;
       (_SDL_SendWindowEvent($$061$lcssa86,5,$121,$123)|0);
      }
      $128 = (_SDL_GetMouseFocus()|0);
      $129 = ($128|0)==($$061$lcssa86|0);
      if ($129) {
       (_SDL_GetMouseState($4,$5)|0);
       $130 = HEAP32[$4>>2]|0;
       $131 = HEAP32[$5>>2]|0;
       _SDL_WarpMouseInWindow($$061$lcssa86,$130,$131);
      }
      $132 = HEAP32[$98>>2]|0;
      $133 = ((($0)) + 52|0);
      HEAP32[$133>>2] = $132;
      $$264$ph = 0;
     }
     $$5 = $$264$ph;
     STACKTOP = sp;return ($$5|0);
    }
   } while(0);
   $136 = ((($$0$i)) + 16|0);
   ;HEAP32[$2>>2]=HEAP32[$136>>2]|0;HEAP32[$2+4>>2]=HEAP32[$136+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$136+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$136+12>>2]|0;HEAP32[$2+16>>2]=HEAP32[$136+16>>2]|0;
   $137 = ((($$0$i)) + 36|0);
   ;HEAP32[$3>>2]=HEAP32[$137>>2]|0;HEAP32[$3+4>>2]=HEAP32[$137+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$137+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$137+12>>2]|0;HEAP32[$3+16>>2]=HEAP32[$137+16>>2]|0;
   $138 = (_SDL_memcmp($2,$3,20)|0);
   $139 = ($138|0)==(0);
   do {
    if (!($139)) {
     $140 = HEAP32[52375]|0;
     $141 = ((($140)) + 28|0);
     $142 = HEAP32[$141>>2]|0;
     $143 = ($142|0)==(0|0);
     if ($143) {
      (_SDL_SetError(182140,$vararg_buffer9)|0);
      break;
     }
     $144 = (FUNCTION_TABLE_iiii[$142 & 8191]($140,$$0$i,$2)|0);
     $145 = ($144|0)<(0);
     if (!($145)) {
      ;HEAP32[$137>>2]=HEAP32[$2>>2]|0;HEAP32[$137+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$137+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$137+12>>2]=HEAP32[$2+12>>2]|0;HEAP32[$137+16>>2]=HEAP32[$2+16>>2]|0;
     }
    }
   } while(0);
   $146 = HEAP32[52375]|0;
   $147 = ((($146)) + 112|0);
   $148 = HEAP32[$147>>2]|0;
   $149 = ($148|0)==(0|0);
   if (!($149)) {
    FUNCTION_TABLE_viiii[$148 & 8191]($146,$0,$$0$i,0);
   }
   HEAP32[$27>>2] = 0;
   $150 = ((($0)) + 112|0);
   HEAP32[$150>>2] = 0;
   $151 = ((($0)) + 24|0);
   $152 = HEAP32[$151>>2]|0;
   $153 = ((($0)) + 28|0);
   $154 = HEAP32[$153>>2]|0;
   (_SDL_SendWindowEvent($0,6,$152,$154)|0);
   $155 = (_SDL_GetMouseFocus()|0);
   $156 = ($155|0)==($0|0);
   if ($156) {
    (_SDL_GetMouseState($8,$9)|0);
    $157 = HEAP32[$8>>2]|0;
    $158 = HEAP32[$9>>2]|0;
    _SDL_WarpMouseInWindow($0,$157,$158);
   }
   $159 = ((($0)) + 48|0);
   $160 = HEAP32[$159>>2]|0;
   $161 = ((($0)) + 52|0);
   HEAP32[$161>>2] = $160;
   $$5 = 0;
   STACKTOP = sp;return ($$5|0);
  }
 }
 (_SDL_SetError(195204,$vararg_buffer1)|0);
 $$5 = -1;
 STACKTOP = sp;return ($$5|0);
}
function _SDL_SendWindowEvent($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $$074 = 0, $10 = 0, $100 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(64|0);
 $4 = sp;
 $5 = ($0|0)==(0|0);
 if ($5) {
  $$074 = 0;
  STACKTOP = sp;return ($$074|0);
 }
 L4: do {
  switch ($1<<24>>24) {
  case 1:  {
   $6 = ((($0)) + 48|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = $7 & 4;
   $9 = ($8|0)==(0);
   if ($9) {
    $10 = $7 & -13;
    $11 = $10 | 4;
    HEAP32[$6>>2] = $11;
    _SDL_OnWindowShown($0);
    break L4;
   } else {
    $$074 = 0;
    STACKTOP = sp;return ($$074|0);
   }
   break;
  }
  case 2:  {
   $12 = ((($0)) + 48|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = $13 & 4;
   $15 = ($14|0)==(0);
   if ($15) {
    $$074 = 0;
    STACKTOP = sp;return ($$074|0);
   } else {
    $16 = $13 & -13;
    $17 = $16 | 8;
    HEAP32[$12>>2] = $17;
    _SDL_OnWindowHidden($0);
    break L4;
   }
   break;
  }
  case 4:  {
   $18 = $2 & -65536;
   $19 = ($18|0)==(536805376);
   $20 = $3 & -65536;
   $21 = ($20|0)==(536805376);
   $or$cond = $19 | $21;
   if ($or$cond) {
    $$074 = 0;
    STACKTOP = sp;return ($$074|0);
   }
   $22 = ((($0)) + 48|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = $23 & 1;
   $25 = ($24|0)==(0);
   if ($25) {
    $26 = ((($0)) + 56|0);
    HEAP32[$26>>2] = $2;
    $27 = ((($0)) + 60|0);
    HEAP32[$27>>2] = $3;
   }
   $28 = ((($0)) + 16|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = ($29|0)==($2|0);
   $31 = ((($0)) + 20|0);
   if ($30) {
    $32 = HEAP32[$31>>2]|0;
    $33 = ($32|0)==($3|0);
    if ($33) {
     $$074 = 0;
     STACKTOP = sp;return ($$074|0);
    }
   }
   HEAP32[$28>>2] = $2;
   HEAP32[$31>>2] = $3;
   break;
  }
  case 5:  {
   $34 = ((($0)) + 48|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = $35 & 1;
   $37 = ($36|0)==(0);
   if ($37) {
    $38 = ((($0)) + 64|0);
    HEAP32[$38>>2] = $2;
    $39 = ((($0)) + 68|0);
    HEAP32[$39>>2] = $3;
   }
   $40 = ((($0)) + 24|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = ($41|0)==($2|0);
   $43 = ((($0)) + 28|0);
   if ($42) {
    $44 = HEAP32[$43>>2]|0;
    $45 = ($44|0)==($3|0);
    if ($45) {
     $$074 = 0;
     STACKTOP = sp;return ($$074|0);
    }
   }
   HEAP32[$40>>2] = $2;
   HEAP32[$43>>2] = $3;
   _SDL_OnWindowResized($0);
   break;
  }
  case 7:  {
   $46 = ((($0)) + 48|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = $47 & 64;
   $49 = ($48|0)==(0);
   if ($49) {
    $50 = $47 & -193;
    $51 = $50 | 64;
    HEAP32[$46>>2] = $51;
    _SDL_OnWindowMinimized($0);
    break L4;
   } else {
    $$074 = 0;
    STACKTOP = sp;return ($$074|0);
   }
   break;
  }
  case 8:  {
   $52 = ((($0)) + 48|0);
   $53 = HEAP32[$52>>2]|0;
   $54 = $53 & 128;
   $55 = ($54|0)==(0);
   if ($55) {
    $56 = $53 & -193;
    $57 = $56 | 128;
    HEAP32[$52>>2] = $57;
    break L4;
   } else {
    $$074 = 0;
    STACKTOP = sp;return ($$074|0);
   }
   break;
  }
  case 9:  {
   $58 = ((($0)) + 48|0);
   $59 = HEAP32[$58>>2]|0;
   $60 = $59 & 192;
   $61 = ($60|0)==(0);
   if ($61) {
    $$074 = 0;
    STACKTOP = sp;return ($$074|0);
   } else {
    $62 = $59 & -193;
    HEAP32[$58>>2] = $62;
    _SDL_OnWindowRestored($0);
    break L4;
   }
   break;
  }
  case 10:  {
   $63 = ((($0)) + 48|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = $64 & 1024;
   $66 = ($65|0)==(0);
   if ($66) {
    $67 = $64 | 1024;
    HEAP32[$63>>2] = $67;
    _SDL_OnWindowEnter($0);
    break L4;
   } else {
    $$074 = 0;
    STACKTOP = sp;return ($$074|0);
   }
   break;
  }
  case 11:  {
   $68 = ((($0)) + 48|0);
   $69 = HEAP32[$68>>2]|0;
   $70 = $69 & 1024;
   $71 = ($70|0)==(0);
   if ($71) {
    $$074 = 0;
    STACKTOP = sp;return ($$074|0);
   } else {
    $72 = $69 & -1025;
    HEAP32[$68>>2] = $72;
    break L4;
   }
   break;
  }
  case 12:  {
   $73 = ((($0)) + 48|0);
   $74 = HEAP32[$73>>2]|0;
   $75 = $74 & 512;
   $76 = ($75|0)==(0);
   if ($76) {
    $77 = $74 | 512;
    HEAP32[$73>>2] = $77;
    _SDL_OnWindowFocusGained($0);
    break L4;
   } else {
    $$074 = 0;
    STACKTOP = sp;return ($$074|0);
   }
   break;
  }
  case 13:  {
   $78 = ((($0)) + 48|0);
   $79 = HEAP32[$78>>2]|0;
   $80 = $79 & 512;
   $81 = ($80|0)==(0);
   if ($81) {
    $$074 = 0;
    STACKTOP = sp;return ($$074|0);
   } else {
    $82 = $79 & -513;
    HEAP32[$78>>2] = $82;
    _SDL_OnWindowFocusLost($0);
    break L4;
   }
   break;
  }
  default: {
  }
  }
 } while(0);
 $83 = (_SDL_EventState(512,-1)|0);
 $84 = ($83<<24>>24)==(1);
 if ($84) {
  HEAP32[$4>>2] = 512;
  $85 = ((($4)) + 12|0);
  HEAP8[$85>>0] = $1;
  $86 = ((($4)) + 16|0);
  HEAP32[$86>>2] = $2;
  $87 = ((($4)) + 20|0);
  HEAP32[$87>>2] = $3;
  $88 = ((($0)) + 4|0);
  $89 = HEAP32[$88>>2]|0;
  $90 = ((($4)) + 8|0);
  HEAP32[$90>>2] = $89;
  switch ($1<<24>>24) {
  case 5:  {
   _SDL_FilterEvents(4321,$4);
   break;
  }
  case 6:  {
   _SDL_FilterEvents(4322,$4);
   break;
  }
  case 4:  {
   _SDL_FilterEvents(4323,$4);
   break;
  }
  case 3:  {
   _SDL_FilterEvents(4324,$4);
   break;
  }
  default: {
  }
  }
  $91 = (_SDL_PushEvent($4)|0);
  $92 = ($91|0)>(0);
  $93 = $92&1;
  $$0 = $93;
 } else {
  $$0 = 0;
 }
 $94 = ($1<<24>>24)==(14);
 if (!($94)) {
  $$074 = $$0;
  STACKTOP = sp;return ($$074|0);
 }
 $95 = ((($0)) + 148|0);
 $96 = HEAP32[$95>>2]|0;
 $97 = ($96|0)==(0|0);
 if (!($97)) {
  $$074 = $$0;
  STACKTOP = sp;return ($$074|0);
 }
 $98 = ((($0)) + 152|0);
 $99 = HEAP32[$98>>2]|0;
 $100 = ($99|0)==(0|0);
 if (!($100)) {
  $$074 = $$0;
  STACKTOP = sp;return ($$074|0);
 }
 (_SDL_SendQuit()|0);
 $$074 = $$0;
 STACKTOP = sp;return ($$074|0);
}
function _SDL_SetWindowGrab($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i = 0, $$pre$i = 0, $$sink = 0, $$sink$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $not$or$cond18$i = 0, $not$or$cond18$i$demorgan = 0, $or$cond18$i = 0, $or$cond19$i = 0, $tmp = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $2 = HEAP32[52375]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  (_SDL_SetError(175439,$vararg_buffer)|0);
  STACKTOP = sp;return;
 }
 $4 = ($0|0)==(0|0);
 if (!($4)) {
  $5 = HEAP32[$0>>2]|0;
  $6 = ((($2)) + 280|0);
  $7 = ($5|0)==($6|0);
  if ($7) {
   $8 = ($1|0)!=(0);
   $9 = ((($0)) + 48|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = $10 & 256;
   $12 = ($11|0)!=(0);
   $tmp = $8 ^ $12;
   if (!($tmp)) {
    STACKTOP = sp;return;
   }
   $13 = $10 & -257;
   $14 = $10 | 256;
   $$sink = $8 ? $14 : $13;
   HEAP32[$9>>2] = $$sink;
   $15 = (_SDL_GetMouse()|0);
   $16 = ((($15)) + 76|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = HEAP32[$9>>2]|0;
   $19 = $18 & 256;
   $20 = $19 | $17;
   $21 = ($20|0)==(0);
   $22 = $18 & 512;
   $23 = ($22|0)==(0);
   $or$cond18$i = $23 | $21;
   $not$or$cond18$i$demorgan = $23 | $21;
   $not$or$cond18$i = $not$or$cond18$i$demorgan ^ 1;
   $$0$i = $not$or$cond18$i&1;
   $24 = HEAP32[52375]|0;
   $25 = ((($24)) + 276|0);
   $26 = HEAP32[$25>>2]|0;
   if ($or$cond18$i) {
    $35 = ($26|0)==($0|0);
    if ($35) {
     $$sink$i = 0;$37 = $24;
     label = 12;
    } else {
     $39 = $24;
    }
   } else {
    $27 = ($26|0)==(0|0);
    $28 = ($26|0)==($0|0);
    $or$cond19$i = $27 | $28;
    if ($or$cond19$i) {
     $$sink$i = $0;$37 = $24;
     label = 12;
    } else {
     $29 = ((($26)) + 48|0);
     $30 = HEAP32[$29>>2]|0;
     $31 = $30 & -257;
     HEAP32[$29>>2] = $31;
     $32 = ((($24)) + 124|0);
     $33 = HEAP32[$32>>2]|0;
     $34 = ($33|0)==(0|0);
     if ($34) {
      $$sink$i = $0;$37 = $24;
      label = 12;
     } else {
      FUNCTION_TABLE_viii[$33 & 8191]($24,$26,0);
      $$pre$i = HEAP32[52375]|0;
      $$sink$i = $0;$37 = $$pre$i;
      label = 12;
     }
    }
   }
   if ((label|0) == 12) {
    $36 = ((($37)) + 276|0);
    HEAP32[$36>>2] = $$sink$i;
    $39 = $37;
   }
   $38 = ((($39)) + 124|0);
   $40 = HEAP32[$38>>2]|0;
   $41 = ($40|0)==(0|0);
   if ($41) {
    STACKTOP = sp;return;
   }
   FUNCTION_TABLE_viii[$40 & 8191]($39,$0,$$0$i);
   STACKTOP = sp;return;
  }
 }
 (_SDL_SetError(195204,$vararg_buffer1)|0);
 STACKTOP = sp;return;
}
function _SDL_GetMouse() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (209524|0);
}
function _SDL_OnWindowShown($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 48|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 & 69;
 $4 = ($3|0)==(5);
 if (!($4)) {
  return;
 }
 (_SDL_UpdateFullscreenMode($0,1)|0);
 return;
}
function _SDL_OnWindowHidden($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (_SDL_UpdateFullscreenMode($0,0)|0);
 return;
}
function _SDL_OnWindowResized($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 112|0);
 HEAP32[$1>>2] = 0;
 $2 = ((($0)) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 (_SDL_SendWindowEvent($0,6,$3,$5)|0);
 return;
}
function _SDL_OnWindowMinimized($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (_SDL_UpdateFullscreenMode($0,0)|0);
 return;
}
function _SDL_OnWindowRestored($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 48|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 & 69;
 $4 = ($3|0)==(5);
 if (!($4)) {
  return;
 }
 (_SDL_UpdateFullscreenMode($0,1)|0);
 return;
}
function _SDL_OnWindowEnter($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[52375]|0;
 $2 = ((($1)) + 144|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  return;
 }
 FUNCTION_TABLE_vii[$3 & 8191]($1,$0);
 return;
}
function _SDL_OnWindowLeave($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function _SDL_OnWindowFocusGained($0) {
 $0 = $0|0;
 var $$0$i = 0, $$pre$i = 0, $$sink$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $not$or$cond18$i = 0, $not$or$cond18$i$demorgan = 0, $or$cond18$i = 0, $or$cond19$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (_SDL_GetMouse()|0);
 $2 = ((($0)) + 100|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = HEAP32[52375]|0;
  $6 = ((($5)) + 116|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)==(0|0);
  if (!($8)) {
   (FUNCTION_TABLE_iiii[$7 & 8191]($5,$0,$3)|0);
  }
 }
 $9 = ($1|0)==(0|0);
 if (!($9)) {
  $10 = ((($1)) + 76|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($11|0)==(0);
  if (!($12)) {
   _SDL_SetMouseFocus($0);
   $13 = ((($0)) + 24|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = (($14|0) / 2)&-1;
   $16 = ((($0)) + 28|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (($17|0) / 2)&-1;
   _SDL_WarpMouseInWindow($0,$15,$18);
  }
 }
 $19 = (_SDL_GetMouse()|0);
 $20 = ((($19)) + 76|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ((($0)) + 48|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = $23 & 256;
 $25 = $24 | $21;
 $26 = ($25|0)==(0);
 $27 = $23 & 512;
 $28 = ($27|0)==(0);
 $or$cond18$i = $28 | $26;
 $not$or$cond18$i$demorgan = $28 | $26;
 $not$or$cond18$i = $not$or$cond18$i$demorgan ^ 1;
 $$0$i = $not$or$cond18$i&1;
 $29 = HEAP32[52375]|0;
 $30 = ((($29)) + 276|0);
 $31 = HEAP32[$30>>2]|0;
 if ($or$cond18$i) {
  $40 = ($31|0)==($0|0);
  if ($40) {
   $$sink$i = 0;$42 = $29;
   label = 12;
  } else {
   $44 = $29;
  }
 } else {
  $32 = ($31|0)==(0|0);
  $33 = ($31|0)==($0|0);
  $or$cond19$i = $32 | $33;
  if ($or$cond19$i) {
   $$sink$i = $0;$42 = $29;
   label = 12;
  } else {
   $34 = ((($31)) + 48|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = $35 & -257;
   HEAP32[$34>>2] = $36;
   $37 = ((($29)) + 124|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = ($38|0)==(0|0);
   if ($39) {
    $$sink$i = $0;$42 = $29;
    label = 12;
   } else {
    FUNCTION_TABLE_viii[$38 & 8191]($29,$31,0);
    $$pre$i = HEAP32[52375]|0;
    $$sink$i = $0;$42 = $$pre$i;
    label = 12;
   }
  }
 }
 if ((label|0) == 12) {
  $41 = ((($42)) + 276|0);
  HEAP32[$41>>2] = $$sink$i;
  $44 = $42;
 }
 $43 = ((($44)) + 124|0);
 $45 = HEAP32[$43>>2]|0;
 $46 = ($45|0)==(0|0);
 if ($46) {
  return;
 }
 FUNCTION_TABLE_viii[$45 & 8191]($44,$0,$$0$i);
 return;
}
function _SDL_OnWindowFocusLost($0) {
 $0 = $0|0;
 var $$0$i = 0, $$pre$i = 0, $$sink$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $not$or$cond18$i = 0, $not$or$cond18$i$demorgan = 0, $or$cond18$i = 0, $or$cond19$i = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $1 = ((($0)) + 100|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = HEAP32[52375]|0;
  $5 = ((($4)) + 116|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==(0|0);
  if (!($7)) {
   $8 = ((($0)) + 104|0);
   $9 = HEAP32[$8>>2]|0;
   (FUNCTION_TABLE_iiii[$6 & 8191]($4,$0,$9)|0);
  }
 }
 $10 = (_SDL_GetMouse()|0);
 $11 = ((($10)) + 76|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ((($0)) + 48|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $14 & 256;
 $16 = $15 | $12;
 $17 = ($16|0)==(0);
 $18 = $14 & 512;
 $19 = ($18|0)==(0);
 $or$cond18$i = $19 | $17;
 $not$or$cond18$i$demorgan = $19 | $17;
 $not$or$cond18$i = $not$or$cond18$i$demorgan ^ 1;
 $$0$i = $not$or$cond18$i&1;
 $20 = HEAP32[52375]|0;
 $21 = ((($20)) + 276|0);
 $22 = HEAP32[$21>>2]|0;
 if ($or$cond18$i) {
  $31 = ($22|0)==($0|0);
  if ($31) {
   $$sink$i = 0;$33 = $20;
   label = 9;
  } else {
   $35 = $20;
  }
 } else {
  $23 = ($22|0)==(0|0);
  $24 = ($22|0)==($0|0);
  $or$cond19$i = $23 | $24;
  if ($or$cond19$i) {
   $$sink$i = $0;$33 = $20;
   label = 9;
  } else {
   $25 = ((($22)) + 48|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = $26 & -257;
   HEAP32[$25>>2] = $27;
   $28 = ((($20)) + 124|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = ($29|0)==(0|0);
   if ($30) {
    $$sink$i = $0;$33 = $20;
    label = 9;
   } else {
    FUNCTION_TABLE_viii[$29 & 8191]($20,$22,0);
    $$pre$i = HEAP32[52375]|0;
    $$sink$i = $0;$33 = $$pre$i;
    label = 9;
   }
  }
 }
 if ((label|0) == 9) {
  $32 = ((($33)) + 276|0);
  HEAP32[$32>>2] = $$sink$i;
  $35 = $33;
 }
 $34 = ((($35)) + 124|0);
 $36 = HEAP32[$34>>2]|0;
 $37 = ($36|0)==(0|0);
 if (!($37)) {
  FUNCTION_TABLE_viii[$36 & 8191]($35,$0,$$0$i);
 }
 $38 = HEAP32[$13>>2]|0;
 $39 = $38 & 1;
 $40 = ($39|0)==(0);
 if ($40) {
  STACKTOP = sp;return;
 }
 $41 = ((($0)) + 120|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ($42|0)==(0);
 if (!($43)) {
  STACKTOP = sp;return;
 }
 $44 = (_SDL_GetHintBoolean(183814,1)|0);
 $45 = ($44|0)==(0);
 if ($45) {
  STACKTOP = sp;return;
 }
 $46 = HEAP32[52375]|0;
 $47 = ($46|0)==(0|0);
 if ($47) {
  (_SDL_SetError(175439,$vararg_buffer)|0);
  STACKTOP = sp;return;
 }
 $48 = HEAP32[$0>>2]|0;
 $49 = ((($46)) + 280|0);
 $50 = ($48|0)==($49|0);
 if (!($50)) {
  (_SDL_SetError(195204,$vararg_buffer1)|0);
  STACKTOP = sp;return;
 }
 $51 = HEAP32[$13>>2]|0;
 $52 = $51 & 64;
 $53 = ($52|0)==(0);
 if (!($53)) {
  STACKTOP = sp;return;
 }
 (_SDL_UpdateFullscreenMode($0,0)|0);
 $54 = HEAP32[52375]|0;
 $55 = ((($54)) + 96|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = ($56|0)==(0|0);
 if ($57) {
  STACKTOP = sp;return;
 }
 FUNCTION_TABLE_vii[$56 & 8191]($54,$0);
 STACKTOP = sp;return;
}
function _SDL_EventState($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = $0 >>> 8;
 $3 = $2 & 255;
 $4 = (209640 + ($3<<2)|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  label = 3;
 } else {
  $7 = $0 >>> 5;
  $8 = $7 & 7;
  $9 = (($5) + ($8<<2)|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = $0 & 31;
  $12 = 1 << $11;
  $13 = $10 & $12;
  $14 = ($13|0)==(0);
  if ($14) {
   label = 3;
  } else {
   $$0 = 0;
  }
 }
 if ((label|0) == 3) {
  $$0 = 1;
 }
 $15 = $$0&255;
 $16 = ($15|0)==($1|0);
 if ($16) {
  return ($$0|0);
 }
 switch ($1|0) {
 case 0:  {
  if ($6) {
   $17 = (_SDL_calloc(1,32)|0);
   HEAP32[$4>>2] = $17;
   $18 = ($17|0)==(0|0);
   if ($18) {
    return ($$0|0);
   } else {
    $24 = $17;
   }
  } else {
   $24 = $5;
  }
  $19 = $0 & 31;
  $20 = 1 << $19;
  $21 = $0 >>> 5;
  $22 = $21 & 7;
  $23 = (($24) + ($22<<2)|0);
  $25 = HEAP32[$23>>2]|0;
  $26 = $25 | $20;
  HEAP32[$23>>2] = $26;
  _SDL_FlushEvents($0,$0);
  return ($$0|0);
  break;
 }
 case 1:  {
  $27 = $0 & 31;
  $28 = 1 << $27;
  $29 = $28 ^ -1;
  $30 = $0 >>> 5;
  $31 = $30 & 7;
  $32 = (($5) + ($31<<2)|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = $33 & $29;
  HEAP32[$32>>2] = $34;
  return ($$0|0);
  break;
 }
 default: {
  return ($$0|0);
 }
 }
 return (0)|0;
}
function _RemovePendingResizedEvents($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(512);
 if ($3) {
  $4 = ((($1)) + 12|0);
  $5 = HEAP8[$4>>0]|0;
  $6 = ($5<<24>>24)==(5);
  if ($6) {
   $7 = ((($1)) + 8|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ((($0)) + 8|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($8|0)==($10|0);
   if ($11) {
    $$0 = 0;
    return ($$0|0);
   }
  }
 }
 $$0 = 1;
 return ($$0|0);
}
function _SDL_FilterEvents($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$010 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[22156]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  return;
 }
 $4 = (_SDL_LockMutex($2)|0);
 $5 = ($4|0)==(0);
 if (!($5)) {
  return;
 }
 $6 = HEAP32[(88640)>>2]|0;
 $7 = ($6|0)==(0|0);
 if (!($7)) {
  $$010 = $6;
  while(1) {
   $8 = ((($$010)) + 72|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (FUNCTION_TABLE_iii[$0 & 8191]($1,$$010)|0);
   $11 = ($10|0)==(0);
   if ($11) {
    $13 = ((($$010)) + 68|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ($14|0)==(0|0);
    if (!($15)) {
     $16 = HEAP32[$8>>2]|0;
     $17 = ((($14)) + 72|0);
     HEAP32[$17>>2] = $16;
    }
    $18 = HEAP32[$8>>2]|0;
    $19 = ($18|0)==(0|0);
    if (!($19)) {
     $20 = ((($18)) + 68|0);
     HEAP32[$20>>2] = $14;
    }
    $21 = HEAP32[(88640)>>2]|0;
    $22 = ($21|0)==($$010|0);
    if ($22) {
     HEAP32[(88640)>>2] = $18;
    }
    $23 = HEAP32[(88644)>>2]|0;
    $24 = ($23|0)==($$010|0);
    if ($24) {
     $25 = HEAP32[$13>>2]|0;
     HEAP32[(88644)>>2] = $25;
    }
    $26 = HEAP32[(88648)>>2]|0;
    HEAP32[$8>>2] = $26;
    HEAP32[(88648)>>2] = $$010;
    (_SDL_AtomicAdd((88632),-1)|0);
   }
   $12 = ($9|0)==(0|0);
   if ($12) {
    break;
   } else {
    $$010 = $9;
   }
  }
 }
 return;
}
function _RemovePendingSizeChangedEvents($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(512);
 if ($3) {
  $4 = ((($1)) + 12|0);
  $5 = HEAP8[$4>>0]|0;
  $6 = ($5<<24>>24)==(6);
  if ($6) {
   $7 = ((($1)) + 8|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ((($0)) + 8|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($8|0)==($10|0);
   if ($11) {
    $$0 = 0;
    return ($$0|0);
   }
  }
 }
 $$0 = 1;
 return ($$0|0);
}
function _RemovePendingMoveEvents($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(512);
 if ($3) {
  $4 = ((($1)) + 12|0);
  $5 = HEAP8[$4>>0]|0;
  $6 = ($5<<24>>24)==(4);
  if ($6) {
   $7 = ((($1)) + 8|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ((($0)) + 8|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($8|0)==($10|0);
   if ($11) {
    $$0 = 0;
    return ($$0|0);
   }
  }
 }
 $$0 = 1;
 return ($$0|0);
}
function _RemovePendingExposedEvents($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(512);
 if ($3) {
  $4 = ((($1)) + 12|0);
  $5 = HEAP8[$4>>0]|0;
  $6 = ($5<<24>>24)==(3);
  if ($6) {
   $7 = ((($1)) + 8|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ((($0)) + 8|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($8|0)==($10|0);
   if ($11) {
    $$0 = 0;
    return ($$0|0);
   }
  }
 }
 $$0 = 1;
 return ($$0|0);
}
function _SDL_PushEvent($0) {
 $0 = $0|0;
 var $$0 = 0, $$010 = 0, $$011 = 0, $$012 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $1 = (_SDL_GetTicks()|0);
 $2 = ((($0)) + 4|0);
 HEAP32[$2>>2] = $1;
 $3 = HEAP32[52369]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = HEAP32[52370]|0;
  $6 = (FUNCTION_TABLE_iii[$3 & 8191]($5,$0)|0);
  $7 = ($6|0)==(0);
  if ($7) {
   $$010 = 0;
   return ($$010|0);
  }
 }
 $$011 = HEAP32[52666]|0;
 $8 = ($$011|0)==(0|0);
 if (!($8)) {
  $$012 = $$011;
  while(1) {
   $9 = HEAP32[$$012>>2]|0;
   $10 = ((($$012)) + 4|0);
   $11 = HEAP32[$10>>2]|0;
   (FUNCTION_TABLE_iii[$9 & 8191]($11,$0)|0);
   $12 = ((($$012)) + 8|0);
   $$0 = HEAP32[$12>>2]|0;
   $13 = ($$0|0)==(0|0);
   if ($13) {
    break;
   } else {
    $$012 = $$0;
   }
  }
 }
 $14 = (_SDL_PeepEvents($0,1,0,0,0)|0);
 $15 = ($14|0)<(1);
 if ($15) {
  $$010 = -1;
  return ($$010|0);
 }
 _SDL_GestureProcessEvent($0);
 $$010 = 1;
 return ($$010|0);
}
function _SDL_SendQuit() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[52409] = 0;
 $0 = (_SDL_SendAppEvent(256)|0);
 return ($0|0);
}
function _SDL_SendAppEvent($0) {
 $0 = $0|0;
 var $$0 = 0, $$0$i4 = 0, $$010$i = 0, $$011$i = 0, $$012$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(64|0);
 $1 = sp;
 $2 = $0 >>> 8;
 $3 = $2 & 255;
 $4 = (209640 + ($3<<2)|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = $0 >>> 5;
  $8 = $7 & 7;
  $9 = (($5) + ($8<<2)|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = $0 & 31;
  $12 = 1 << $11;
  $13 = $10 & $12;
  $14 = ($13|0)==(0);
  if (!($14)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$1>>2] = $0;
 $15 = (_SDL_GetTicks()|0);
 $16 = ((($1)) + 4|0);
 HEAP32[$16>>2] = $15;
 $17 = HEAP32[52369]|0;
 $18 = ($17|0)==(0|0);
 if ($18) {
  label = 5;
 } else {
  $19 = HEAP32[52370]|0;
  $20 = (FUNCTION_TABLE_iii[$17 & 8191]($19,$1)|0);
  $21 = ($20|0)==(0);
  if ($21) {
   $$010$i = 0;
  } else {
   label = 5;
  }
 }
 if ((label|0) == 5) {
  $$011$i = HEAP32[52666]|0;
  $22 = ($$011$i|0)==(0|0);
  if (!($22)) {
   $$012$i = $$011$i;
   while(1) {
    $23 = HEAP32[$$012$i>>2]|0;
    $24 = ((($$012$i)) + 4|0);
    $25 = HEAP32[$24>>2]|0;
    (FUNCTION_TABLE_iii[$23 & 8191]($25,$1)|0);
    $26 = ((($$012$i)) + 8|0);
    $$0$i4 = HEAP32[$26>>2]|0;
    $27 = ($$0$i4|0)==(0|0);
    if ($27) {
     break;
    } else {
     $$012$i = $$0$i4;
    }
   }
  }
  $28 = (_SDL_PeepEvents($1,1,0,0,0)|0);
  $29 = ($28|0)<(1);
  if ($29) {
   $$010$i = 0;
  } else {
   _SDL_GestureProcessEvent($1);
   $$010$i = 1;
  }
 }
 $$0 = $$010$i;
 STACKTOP = sp;return ($$0|0);
}
function _SDL_GetTicks() {
 var $$0 = 0, $$pr = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $0 = sp + 8|0;
 $1 = sp;
 $2 = HEAP32[52667]|0;
 $3 = ($2|0)==(0);
 do {
  if ($3) {
   HEAP32[52667] = 1;
   $4 = (_clock_gettime(4,(210672|0))|0);
   $5 = ($4|0)==(0);
   if ($5) {
    HEAP32[52670] = 1;
    break;
   } else {
    (_gettimeofday((210684|0),(0|0))|0);
    label = 5;
    break;
   }
  } else {
   label = 5;
  }
 } while(0);
 if ((label|0) == 5) {
  $$pr = HEAP32[52670]|0;
  $6 = ($$pr|0)==(0);
  if ($6) {
   (_gettimeofday(($1|0),(0|0))|0);
   $17 = HEAP32[$1>>2]|0;
   $18 = HEAP32[52671]|0;
   $19 = (($17) - ($18))|0;
   $20 = ($19*1000)|0;
   $21 = ((($1)) + 4|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = HEAP32[(210688)>>2]|0;
   $24 = (($22) - ($23))|0;
   $25 = (($24|0) / 1000)&-1;
   $26 = (($25) + ($20))|0;
   $$0 = $26;
   STACKTOP = sp;return ($$0|0);
  }
 }
 (_clock_gettime(4,($0|0))|0);
 $7 = HEAP32[$0>>2]|0;
 $8 = HEAP32[52668]|0;
 $9 = (($7) - ($8))|0;
 $10 = ($9*1000)|0;
 $11 = ((($0)) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = HEAP32[(210676)>>2]|0;
 $14 = (($12) - ($13))|0;
 $15 = (($14|0) / 1000000)&-1;
 $16 = (($15) + ($10))|0;
 $$0 = $16;
 STACKTOP = sp;return ($$0|0);
}
function _SDL_PeepEvents($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0 = 0, $$0$i = 0, $$026$i = 0, $$05670 = 0, $$05783 = 0, $$05869 = 0, $$1 = 0, $$159$ph$us = 0, $$159$ph117 = 0, $$3 = 0, $$in$ph$us = 0, $$in$ph116 = 0, $$in$us = 0, $$in$us$us = 0, $$pre = 0, $$sink$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $exitcond = 0, $or$cond61$us = 0, $or$cond61$us$us = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer3 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $vararg_buffer3 = sp + 16|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $5 = (_SDL_AtomicGet((88628))|0);
 $6 = ($5|0)==(0);
 if ($6) {
  $7 = ($2|0)==(0);
  if ($7) {
   $$0 = -1;
   STACKTOP = sp;return ($$0|0);
  }
  (_SDL_SetError(182046,$vararg_buffer)|0);
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 $8 = HEAP32[22156]|0;
 $9 = ($8|0)==(0|0);
 if (!($9)) {
  $10 = (_SDL_LockMutex($8)|0);
  $11 = ($10|0)==(0);
  if (!($11)) {
   $94 = (_SDL_SetError(182114,$vararg_buffer3)|0);
   $$0 = $94;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $12 = ($2|0)==(0);
 L13: do {
  if ($12) {
   $13 = ($1|0)>(0);
   if ($13) {
    $$05670 = 0;$$05869 = 0;
    while(1) {
     $14 = (($0) + (($$05670*56)|0)|0);
     $15 = (_SDL_AtomicGet((88632))|0);
     $16 = ($15|0)>(65534);
     do {
      if ($16) {
       HEAP32[$vararg_buffer1>>2] = $15;
       (_SDL_SetError(182082,$vararg_buffer1)|0);
       $$0$i = 0;
      } else {
       $17 = HEAP32[(88648)>>2]|0;
       $18 = ($17|0)==(0|0);
       if ($18) {
        $19 = (_SDL_malloc(80)|0);
        $20 = ($19|0)==(0|0);
        if ($20) {
         $$0$i = 0;
         break;
        } else {
         $$026$i = $19;
        }
       } else {
        $21 = ((($17)) + 72|0);
        $22 = HEAP32[$21>>2]|0;
        HEAP32[(88648)>>2] = $22;
        $$026$i = $17;
       }
       dest=$$026$i; src=$14; stop=dest+56|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
       $23 = HEAP32[$14>>2]|0;
       $24 = ($23|0)==(513);
       if ($24) {
        $25 = ((($$026$i)) + 56|0);
        $26 = (((($0) + (($$05670*56)|0)|0)) + 8|0);
        $27 = HEAP32[$26>>2]|0;
        ;HEAP32[$25>>2]=HEAP32[$27>>2]|0;HEAP32[$25+4>>2]=HEAP32[$27+4>>2]|0;HEAP32[$25+8>>2]=HEAP32[$27+8>>2]|0;
        $28 = ((($$026$i)) + 8|0);
        HEAP32[$28>>2] = $25;
       }
       $29 = HEAP32[(88644)>>2]|0;
       $30 = ($29|0)==(0|0);
       if ($30) {
        HEAP32[(88640)>>2] = $$026$i;
        $$sink$i = 0;
       } else {
        $31 = ((($29)) + 72|0);
        HEAP32[$31>>2] = $$026$i;
        $$sink$i = $29;
       }
       HEAP32[(88644)>>2] = $$026$i;
       $32 = ((($$026$i)) + 68|0);
       HEAP32[$32>>2] = $$sink$i;
       $33 = ((($$026$i)) + 72|0);
       HEAP32[$33>>2] = 0;
       $34 = (_SDL_AtomicAdd((88632),1)|0);
       $35 = HEAP32[(88636)>>2]|0;
       $36 = ($34|0)<($35|0);
       if ($36) {
        $$0$i = 1;
       } else {
        $37 = (($34) + 1)|0;
        HEAP32[(88636)>>2] = $37;
        $$0$i = 1;
       }
      }
     } while(0);
     $38 = (($$0$i) + ($$05869))|0;
     $39 = (($$05670) + 1)|0;
     $exitcond = ($39|0)==($1|0);
     if ($exitcond) {
      $$3 = $38;
      break;
     } else {
      $$05670 = $39;$$05869 = $38;
     }
    }
   } else {
    $$3 = 0;
   }
  } else {
   $40 = ($2|0)==(2);
   if ($40) {
    $41 = HEAP32[(88652)>>2]|0;
    $42 = ($41|0)==(0|0);
    if (!($42)) {
     $$pre = HEAP32[(88656)>>2]|0;
     $$05783 = $41;$45 = $$pre;
     while(1) {
      $43 = ((($$05783)) + 12|0);
      $44 = HEAP32[$43>>2]|0;
      HEAP32[$43>>2] = $45;
      $46 = ($44|0)==(0|0);
      $47 = $$05783;
      if ($46) {
       break;
      } else {
       $$05783 = $44;$45 = $47;
      }
     }
     HEAP32[(88656)>>2] = $$05783;
    }
    HEAP32[(88652)>>2] = 0;
   }
   $48 = HEAP32[(88640)>>2]|0;
   $49 = ($0|0)==(0|0);
   if ($49) {
    $$159$ph$us = 0;$$in$ph$us = $48;
    while(1) {
     $$in$us$us = $$in$ph$us;
     while(1) {
      $52 = ($$in$us$us|0)==(0|0);
      if ($52) {
       $$3 = $$159$ph$us;
       break L13;
      }
      $53 = ((($$in$us$us)) + 72|0);
      $54 = HEAP32[$53>>2]|0;
      $55 = HEAP32[$$in$us$us>>2]|0;
      $56 = ($55>>>0)<($3>>>0);
      $57 = ($55>>>0)>($4>>>0);
      $or$cond61$us$us = $56 | $57;
      if ($or$cond61$us$us) {
       $$in$us$us = $54;
      } else {
       break;
      }
     }
     $51 = (($$159$ph$us) + 1)|0;
     $$159$ph$us = $51;$$in$ph$us = $54;
    }
   }
   $50 = ($1|0)>(0);
   if ($50) {
    $$159$ph117 = 0;$$in$ph116 = $48;
    while(1) {
     $$in$us = $$in$ph116;
     while(1) {
      $58 = ($$in$us|0)==(0|0);
      if ($58) {
       $$3 = $$159$ph117;
       break L13;
      }
      $59 = ((($$in$us)) + 72|0);
      $60 = HEAP32[$59>>2]|0;
      $61 = HEAP32[$$in$us>>2]|0;
      $62 = ($61>>>0)<($3>>>0);
      $63 = ($61>>>0)>($4>>>0);
      $or$cond61$us = $62 | $63;
      if ($or$cond61$us) {
       $$in$us = $60;
      } else {
       break;
      }
     }
     $64 = (($0) + (($$159$ph117*56)|0)|0);
     dest=$64; src=$$in$us; stop=dest+56|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
     $65 = ($61|0)==(513);
     if ($65) {
      $66 = HEAP32[(88656)>>2]|0;
      $67 = ($66|0)==(0|0);
      if ($67) {
       $70 = (_SDL_malloc(16)|0);
       $$1 = $70;
      } else {
       $68 = ((($66)) + 12|0);
       $69 = HEAP32[$68>>2]|0;
       HEAP32[(88656)>>2] = $69;
       $$1 = $66;
      }
      $71 = ((($$in$us)) + 8|0);
      $72 = HEAP32[$71>>2]|0;
      ;HEAP32[$$1>>2]=HEAP32[$72>>2]|0;HEAP32[$$1+4>>2]=HEAP32[$72+4>>2]|0;HEAP32[$$1+8>>2]=HEAP32[$72+8>>2]|0;
      $73 = HEAP32[(88652)>>2]|0;
      $74 = ((($$1)) + 12|0);
      HEAP32[$74>>2] = $73;
      HEAP32[(88652)>>2] = $$1;
      $75 = (((($0) + (($$159$ph117*56)|0)|0)) + 8|0);
      HEAP32[$75>>2] = $$1;
     }
     if ($40) {
      $76 = ((($$in$us)) + 68|0);
      $77 = HEAP32[$76>>2]|0;
      $78 = ($77|0)==(0|0);
      if (!($78)) {
       $79 = HEAP32[$59>>2]|0;
       $80 = ((($77)) + 72|0);
       HEAP32[$80>>2] = $79;
      }
      $81 = HEAP32[$59>>2]|0;
      $82 = ($81|0)==(0|0);
      if (!($82)) {
       $83 = ((($81)) + 68|0);
       HEAP32[$83>>2] = $77;
      }
      $84 = HEAP32[(88640)>>2]|0;
      $85 = ($84|0)==($$in$us|0);
      if ($85) {
       HEAP32[(88640)>>2] = $81;
      }
      $86 = HEAP32[(88644)>>2]|0;
      $87 = ($86|0)==($$in$us|0);
      if ($87) {
       $88 = HEAP32[$76>>2]|0;
       HEAP32[(88644)>>2] = $88;
      }
      $89 = HEAP32[(88648)>>2]|0;
      HEAP32[$59>>2] = $89;
      HEAP32[(88648)>>2] = $$in$us;
      (_SDL_AtomicAdd((88632),-1)|0);
     }
     $90 = (($$159$ph117) + 1)|0;
     $91 = ($90|0)<($1|0);
     if ($91) {
      $$159$ph117 = $90;$$in$ph116 = $60;
     } else {
      $$3 = $90;
      break;
     }
    }
   } else {
    $$3 = 0;
   }
  }
 } while(0);
 $92 = HEAP32[22156]|0;
 $93 = ($92|0)==(0|0);
 if ($93) {
  $$0 = $$3;
  STACKTOP = sp;return ($$0|0);
 }
 $$0 = $$3;
 STACKTOP = sp;return ($$0|0);
}
function _SDL_GestureProcessEvent($0) {
 $0 = $0|0;
 var $$0 = 0, $$0$i = 0, $$0$lcssa$i$i = 0.0, $$0$ph72$i$i = 0.0, $$01213$i$i = 0, $$01213$i$i179 = 0, $$014$i = 0, $$014$i$i = 0, $$014$i$i178 = 0, $$014$i$ph = 0, $$015$i = 0, $$0167209 = 0, $$0168 = 0.0, $$0169 = 0.0, $$01727$i = 0.0, $$0192 = 0, $$028$i = 0, $$046$ph71$i$i = 0.0, $$04660$i$i = 0.0, $$047$lcssa$i$i = 0.0;
 var $$047$ph70$i$i = 0.0, $$04759$i$i = 0.0, $$04759$i$i$phi = 0.0, $$048$ph69$i$i = 0.0, $$04858$i$i = 0.0, $$04858$i$i$phi = 0.0, $$049$ph68$i$i = 0.0, $$04957$i$i = 0.0, $$050$ph67$i$i = 0.0, $$061$i$i = 0.0, $$07$i = 0, $$1 = 0, $$1$i = 0.0, $$lcssa$i$i = 0, $$off = 0, $$pr = 0, $$pre = 0, $$sroa$0117$0$$sroa_idx = 0, $$sroa$0117$0$copyload = 0.0, $$sroa$4$0$$sroa_idx119$pre$phiZZZZZZ2D = 0;
 var $$sroa$4$0$copyload = 0.0, $1 = 0, $10 = 0, $100 = 0.0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0.0, $146 = 0.0, $147 = 0.0, $148 = 0, $149 = 0, $15 = 0, $150 = 0.0, $151 = 0.0;
 var $152 = 0.0, $153 = 0.0, $154 = 0.0, $155 = 0.0, $156 = 0.0, $157 = 0.0, $158 = 0.0, $159 = 0, $16 = 0, $160 = 0, $161 = 0.0, $162 = 0.0, $163 = 0.0, $164 = 0.0, $165 = 0.0, $166 = 0.0, $167 = 0.0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0.0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0.0, $211 = 0, $212 = 0.0, $213 = 0.0, $214 = 0.0, $215 = 0.0, $216 = 0.0, $217 = 0, $218 = 0.0, $219 = 0.0, $22 = 0, $220 = 0.0, $221 = 0.0, $222 = 0, $223 = 0.0;
 var $224 = 0, $225 = 0.0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0.0, $238 = 0, $239 = 0, $24 = 0, $240 = 0.0, $241 = 0.0;
 var $242 = 0, $243 = 0.0, $244 = 0, $245 = 0.0, $246 = 0.0, $247 = 0.0, $248 = 0.0, $249 = 0.0, $25 = 0, $250 = 0.0, $251 = 0.0, $252 = 0.0, $253 = 0, $254 = 0.0, $255 = 0.0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0;
 var $260 = 0.0, $261 = 0.0, $262 = 0.0, $263 = 0.0, $264 = 0.0, $265 = 0, $266 = 0.0, $267 = 0.0, $268 = 0.0, $269 = 0.0, $27 = 0, $270 = 0.0, $271 = 0.0, $272 = 0.0, $273 = 0.0, $274 = 0.0, $275 = 0.0, $276 = 0.0, $277 = 0.0, $278 = 0.0;
 var $279 = 0.0, $28 = 0, $280 = 0.0, $281 = 0.0, $282 = 0.0, $283 = 0.0, $284 = 0.0, $285 = 0.0, $286 = 0.0, $287 = 0.0, $288 = 0.0, $289 = 0.0, $29 = 0, $290 = 0.0, $291 = 0.0, $292 = 0.0, $293 = 0.0, $294 = 0.0, $295 = 0.0, $296 = 0.0;
 var $297 = 0.0, $298 = 0.0, $299 = 0.0, $3 = 0, $30 = 0, $300 = 0.0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0;
 var $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0.0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0.0, $327 = 0, $328 = 0, $329 = 0.0, $33 = 0, $330 = 0.0, $331 = 0.0;
 var $332 = 0.0, $333 = 0.0, $334 = 0, $335 = 0.0, $336 = 0.0, $337 = 0.0, $338 = 0.0, $339 = 0, $34 = 0.0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0.0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0.0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0.0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i$i = 0, $exitcond$i$i180 = 0, $switch = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1264|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(1264|0);
 $vararg_buffer = sp + 224|0;
 $1 = sp + 168|0;
 $2 = sp + 744|0;
 $3 = sp + 112|0;
 $4 = sp + 56|0;
 $5 = sp;
 $6 = sp + 232|0;
 $7 = HEAP32[$0>>2]|0;
 $$off = (($7) + -1792)|0;
 $switch = ($$off>>>0)<(3);
 if (!($switch)) {
  STACKTOP = sp;return;
 }
 $8 = ((($0)) + 8|0);
 $9 = $8;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = (($9) + 4)|0;
 $13 = $12;
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP32[52371]|0;
 $16 = ($15|0)>(0);
 if (!($16)) {
  STACKTOP = sp;return;
 }
 $17 = HEAP32[52373]|0;
 $$07$i = 0;
 while(1) {
  $20 = (($17) + (($$07$i*8232)|0)|0);
  $21 = $20;
  $22 = $21;
  $23 = HEAP32[$22>>2]|0;
  $24 = (($21) + 4)|0;
  $25 = $24;
  $26 = HEAP32[$25>>2]|0;
  $27 = ($23|0)==($11|0);
  $28 = ($26|0)==($14|0);
  $29 = $27 & $28;
  $18 = (($$07$i) + 1)|0;
  if ($29) {
   break;
  }
  $19 = ($18|0)<($15|0);
  if ($19) {
   $$07$i = $18;
  } else {
   label = 52;
   break;
  }
 }
 if ((label|0) == 52) {
  STACKTOP = sp;return;
 }
 $30 = ($20|0)==(0|0);
 if ($30) {
  STACKTOP = sp;return;
 }
 $31 = ((($0)) + 24|0);
 $32 = +HEAPF32[$31>>2];
 $33 = ((($0)) + 28|0);
 $34 = +HEAPF32[$33>>2];
 switch ($7|0) {
 case 1793:  {
  $35 = (((($17) + (($$07$i*8232)|0)|0)) + 8216|0);
  $36 = HEAP16[$35>>1]|0;
  $37 = (($36) + -1)<<16>>16;
  HEAP16[$35>>1] = $37;
  $38 = (((($17) + (($$07$i*8232)|0)|0)) + 8228|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = ($39|0)==(0);
  do {
   if ($40) {
    $138 = (((($17) + (($$07$i*8232)|0)|0)) + 16|0);
    (_SDL_memset($2,0,512)|0);
    _dollarNormalize($138,$2);
    $139 = (((($17) + (($$07$i*8232)|0)|0)) + 8220|0);
    $140 = HEAP32[$139>>2]|0;
    $141 = ($140|0)>(0);
    if (!($141)) {
     break;
    }
    $142 = (((($17) + (($$07$i*8232)|0)|0)) + 8224|0);
    $$01727$i = 1.0E+4;$$0192 = -1;$$028$i = 0;
    while(1) {
     $143 = HEAP32[$142>>2]|0;
     $144 = (($143) + (($$028$i*516)|0)|0);
     $145 = (+_dollarDifference($2,$144,-0.185407355427742));
     $146 = (+_dollarDifference($2,$144,0.185407355427742));
     $147 = (+_SDL_fabs(-1.5707963267948966));
     $148 = $147 > 0.034906585039886591;
     $149 = $145 < $146;
     L25: do {
      if ($148) {
       $$0$ph72$i$i = $146;$$046$ph71$i$i = 0.185407355427742;$$047$ph70$i$i = $145;$$048$ph69$i$i = -0.185407355427742;$$049$ph68$i$i = -0.78539816339744828;$$050$ph67$i$i = 0.78539816339744828;$343 = $149;
       while(1) {
        $150 = $$050$ph67$i$i * 0.61803398899999995;
        $$04660$i$i = $$046$ph71$i$i;$$04759$i$i = $$047$ph70$i$i;$$04858$i$i = $$048$ph69$i$i;$$04957$i$i = $$049$ph68$i$i;$$061$i$i = $$0$ph72$i$i;$344 = $343;
        while(1) {
         if ($344) {
          break;
         }
         $161 = $$04858$i$i;
         $162 = $161 * 0.38196601100000005;
         $163 = $150 + $162;
         $164 = $163;
         $165 = (+_dollarDifference($2,$144,$164));
         $166 = $161 - $$050$ph67$i$i;
         $167 = (+_SDL_fabs($166));
         $168 = $167 > 0.034906585039886591;
         $169 = $$061$i$i < $165;
         if ($168) {
          $$04858$i$i$phi = $$04660$i$i;$$04759$i$i$phi = $$061$i$i;$$04660$i$i = $164;$$04957$i$i = $161;$$061$i$i = $165;$344 = $169;$$04858$i$i = $$04858$i$i$phi;$$04759$i$i = $$04759$i$i$phi;
         } else {
          $$0$lcssa$i$i = $165;$$047$lcssa$i$i = $$061$i$i;$$lcssa$i$i = $169;
          break L25;
         }
        }
        $151 = $$04660$i$i;
        $152 = $$04957$i$i * 0.61803398899999995;
        $153 = $151 * 0.38196601100000005;
        $154 = $153 + $152;
        $155 = $154;
        $156 = (+_dollarDifference($2,$144,$155));
        $157 = $$04957$i$i - $151;
        $158 = (+_SDL_fabs($157));
        $159 = $158 > 0.034906585039886591;
        $160 = $156 < $$04759$i$i;
        if ($159) {
         $$0$ph72$i$i = $$04759$i$i;$$046$ph71$i$i = $$04858$i$i;$$047$ph70$i$i = $156;$$048$ph69$i$i = $155;$$049$ph68$i$i = $$04957$i$i;$$050$ph67$i$i = $151;$343 = $160;
        } else {
         $$0$lcssa$i$i = $$04759$i$i;$$047$lcssa$i$i = $156;$$lcssa$i$i = $160;
         break;
        }
       }
      } else {
       $$0$lcssa$i$i = $146;$$047$lcssa$i$i = $145;$$lcssa$i$i = $149;
      }
     } while(0);
     $170 = $$lcssa$i$i ? $$047$lcssa$i$i : $$0$lcssa$i$i;
     $171 = $170 < $$01727$i;
     $$1 = $171 ? $$028$i : $$0192;
     $$1$i = $171 ? $170 : $$01727$i;
     $172 = (($$028$i) + 1)|0;
     $173 = HEAP32[$139>>2]|0;
     $174 = ($172|0)<($173|0);
     if ($174) {
      $$01727$i = $$1$i;$$0192 = $$1;$$028$i = $172;
     } else {
      break;
     }
    }
    $175 = ($$1|0)>(-1);
    if ($175) {
     $176 = HEAP32[$142>>2]|0;
     $177 = (((($176) + (($$1*516)|0)|0)) + 512|0);
     $178 = HEAP32[$177>>2]|0;
     HEAP32[$1>>2] = 2048;
     $179 = $20;
     $180 = $179;
     $181 = HEAP32[$180>>2]|0;
     $182 = (($179) + 4)|0;
     $183 = $182;
     $184 = HEAP32[$183>>2]|0;
     $185 = ((($1)) + 8|0);
     $186 = $185;
     $187 = $186;
     HEAP32[$187>>2] = $181;
     $188 = (($186) + 4)|0;
     $189 = $188;
     HEAP32[$189>>2] = $184;
     $190 = (((($17) + (($$07$i*8232)|0)|0)) + 8|0);
     $191 = HEAP32[$190>>2]|0;
     $192 = ((($1)) + 32|0);
     HEAP32[$192>>2] = $191;
     $193 = (((($17) + (($$07$i*8232)|0)|0)) + 12|0);
     $194 = HEAP32[$193>>2]|0;
     $195 = ((($1)) + 36|0);
     HEAP32[$195>>2] = $194;
     $196 = ((($1)) + 16|0);
     $197 = $196;
     $198 = $197;
     HEAP32[$198>>2] = $178;
     $199 = (($197) + 4)|0;
     $200 = $199;
     HEAP32[$200>>2] = 0;
     $201 = ((($1)) + 28|0);
     HEAPF32[$201>>2] = $$1$i;
     $202 = HEAP16[$35>>1]|0;
     $203 = $202&65535;
     $204 = (($203) + 1)|0;
     $205 = ((($1)) + 24|0);
     HEAP32[$205>>2] = $204;
     (_SDL_PushEvent($1)|0);
    }
   } else {
    HEAP32[$38>>2] = 0;
    $41 = (((($17) + (($$07$i*8232)|0)|0)) + 16|0);
    _dollarNormalize($41,$6);
    $42 = HEAP32[52372]|0;
    $43 = ($42|0)==(0);
    do {
     if ($43) {
      $83 = (((($17) + (($$07$i*8232)|0)|0)) + 8220|0);
      $84 = HEAP32[$83>>2]|0;
      $85 = (((($17) + (($$07$i*8232)|0)|0)) + 8224|0);
      $86 = HEAP32[$85>>2]|0;
      $87 = ($84*516)|0;
      $88 = (($87) + 516)|0;
      $89 = (_SDL_realloc($86,$88)|0);
      $90 = ($89|0)==(0|0);
      if ($90) {
       $91 = (_SDL_Error(0)|0);
       $$0 = $91;
       break;
      }
      HEAP32[$85>>2] = $89;
      $92 = (($89) + (($84*516)|0)|0);
      (_SDL_memcpy($92,$6,512)|0);
      $$01213$i$i179 = 5381;$$014$i$i178 = 0;
      while(1) {
       $93 = ($$01213$i$i179*33)|0;
       $94 = ((($89) + (($84*516)|0)|0) + ($$014$i$i178<<3)|0);
       $95 = +HEAPF32[$94>>2];
       $96 = (~~(($95))>>>0);
       $97 = (($96) + ($93))|0;
       $98 = ($97*33)|0;
       $99 = ((((($89) + (($84*516)|0)|0) + ($$014$i$i178<<3)|0)) + 4|0);
       $100 = +HEAPF32[$99>>2];
       $101 = (~~(($100))>>>0);
       $102 = (($98) + ($101))|0;
       $103 = (($$014$i$i178) + 1)|0;
       $exitcond$i$i180 = ($103|0)==(64);
       if ($exitcond$i$i180) {
        break;
       } else {
        $$01213$i$i179 = $102;$$014$i$i178 = $103;
       }
      }
      $104 = (((($89) + (($84*516)|0)|0)) + 512|0);
      HEAP32[$104>>2] = $102;
      $105 = HEAP32[$83>>2]|0;
      $106 = (($105) + 1)|0;
      HEAP32[$83>>2] = $106;
      $$0 = $84;
     } else {
      $44 = HEAP32[52371]|0;
      $45 = ($44|0)==(0);
      L45: do {
       if ($45) {
        $47 = (_SDL_SetError(181987,$vararg_buffer)|0);
        $$014$i$ph = $47;
        label = 20;
       } else {
        $46 = ($44|0)>(0);
        if ($46) {
         $$015$i = 0;
         while(1) {
          $51 = HEAP32[52373]|0;
          $52 = (((($51) + (($$015$i*8232)|0)|0)) + 8220|0);
          $53 = HEAP32[$52>>2]|0;
          $54 = (((($51) + (($$015$i*8232)|0)|0)) + 8224|0);
          $55 = HEAP32[$54>>2]|0;
          $56 = ($53*516)|0;
          $57 = (($56) + 516)|0;
          $58 = (_SDL_realloc($55,$57)|0);
          $59 = ($58|0)==(0|0);
          if ($59) {
           $60 = (_SDL_Error(0)|0);
           $$0$i = $60;
          } else {
           HEAP32[$54>>2] = $58;
           $61 = (($58) + (($53*516)|0)|0);
           (_SDL_memcpy($61,$6,512)|0);
           $$01213$i$i = 5381;$$014$i$i = 0;
           while(1) {
            $62 = ($$01213$i$i*33)|0;
            $63 = ((($58) + (($53*516)|0)|0) + ($$014$i$i<<3)|0);
            $64 = +HEAPF32[$63>>2];
            $65 = (~~(($64))>>>0);
            $66 = (($65) + ($62))|0;
            $67 = ($66*33)|0;
            $68 = ((((($58) + (($53*516)|0)|0) + ($$014$i$i<<3)|0)) + 4|0);
            $69 = +HEAPF32[$68>>2];
            $70 = (~~(($69))>>>0);
            $71 = (($67) + ($70))|0;
            $72 = (($$014$i$i) + 1)|0;
            $exitcond$i$i = ($72|0)==(64);
            if ($exitcond$i$i) {
             break;
            } else {
             $$01213$i$i = $71;$$014$i$i = $72;
            }
           }
           $73 = (((($58) + (($53*516)|0)|0)) + 512|0);
           HEAP32[$73>>2] = $71;
           $74 = HEAP32[$52>>2]|0;
           $75 = (($74) + 1)|0;
           HEAP32[$52>>2] = $75;
           $$0$i = $53;
          }
          $76 = ($$0$i|0)<(0);
          $49 = (($$015$i) + 1)|0;
          if ($76) {
           $$014$i$ph = -1;
           label = 20;
           break L45;
          }
          $48 = HEAP32[52371]|0;
          $50 = ($49|0)<($48|0);
          if ($50) {
           $$015$i = $49;
          } else {
           $$014$i = $$0$i;$77 = $48;
           break;
          }
         }
        } else {
         $$014$i$ph = -1;
         label = 20;
        }
       }
      } while(0);
      if ((label|0) == 20) {
       $$pr = HEAP32[52371]|0;
       $$014$i = $$014$i$ph;$77 = $$pr;
      }
      $78 = ($77|0)>(0);
      if ($78) {
       $79 = HEAP32[52373]|0;
       $$0167209 = 0;
       while(1) {
        $80 = (((($79) + (($$0167209*8232)|0)|0)) + 8228|0);
        HEAP32[$80>>2] = 0;
        $81 = (($$0167209) + 1)|0;
        $82 = ($81|0)<($77|0);
        if ($82) {
         $$0167209 = $81;
        } else {
         $$0 = $$014$i;
         break;
        }
       }
      } else {
       $$0 = $$014$i;
      }
     }
    } while(0);
    $107 = ($$0|0)>(-1);
    $108 = $20;
    $109 = $108;
    $110 = HEAP32[$109>>2]|0;
    $111 = (($108) + 4)|0;
    $112 = $111;
    $113 = HEAP32[$112>>2]|0;
    if ($107) {
     $114 = (((($17) + (($$07$i*8232)|0)|0)) + 8224|0);
     $115 = HEAP32[$114>>2]|0;
     $116 = (((($115) + (($$0*516)|0)|0)) + 512|0);
     $117 = HEAP32[$116>>2]|0;
     HEAP32[$4>>2] = 2049;
     $118 = ((($4)) + 8|0);
     $119 = $118;
     $120 = $119;
     HEAP32[$120>>2] = $110;
     $121 = (($119) + 4)|0;
     $122 = $121;
     HEAP32[$122>>2] = $113;
     $123 = ((($4)) + 16|0);
     $124 = $123;
     $125 = $124;
     HEAP32[$125>>2] = $117;
     $126 = (($124) + 4)|0;
     $127 = $126;
     HEAP32[$127>>2] = 0;
     (_SDL_PushEvent($4)|0);
     break;
    } else {
     HEAP32[$3>>2] = 2049;
     $128 = ((($3)) + 8|0);
     $129 = $128;
     $130 = $129;
     HEAP32[$130>>2] = $110;
     $131 = (($129) + 4)|0;
     $132 = $131;
     HEAP32[$132>>2] = $113;
     $133 = ((($3)) + 16|0);
     $134 = $133;
     $135 = $134;
     HEAP32[$135>>2] = -1;
     $136 = (($134) + 4)|0;
     $137 = $136;
     HEAP32[$137>>2] = -1;
     (_SDL_PushEvent($3)|0);
     break;
    }
   }
  } while(0);
  $206 = HEAP16[$35>>1]|0;
  $207 = ($206<<16>>16)==(0);
  if (!($207)) {
   $208 = $206&65535;
   $209 = (((($17) + (($$07$i*8232)|0)|0)) + 8|0);
   $210 = +HEAPF32[$209>>2];
   $211 = (($208) + 1)|0;
   $212 = (+($211|0));
   $213 = $212 * $210;
   $214 = $213 - $32;
   $215 = (+($206&65535));
   $216 = $214 / $215;
   HEAPF32[$209>>2] = $216;
   $217 = (((($17) + (($$07$i*8232)|0)|0)) + 12|0);
   $218 = +HEAPF32[$217>>2];
   $219 = $212 * $218;
   $220 = $219 - $34;
   $221 = $220 / $215;
   HEAPF32[$217>>2] = $221;
  }
  STACKTOP = sp;return;
  break;
 }
 case 1794:  {
  $222 = ((($0)) + 32|0);
  $223 = +HEAPF32[$222>>2];
  $224 = ((($0)) + 36|0);
  $225 = +HEAPF32[$224>>2];
  $226 = (((($17) + (($$07$i*8232)|0)|0)) + 20|0);
  $227 = HEAP32[$226>>2]|0;
  $228 = ($227|0)<(1024);
  if ($228) {
   $229 = (((($17) + (($$07$i*8232)|0)|0)) + 8|0);
   $230 = HEAP32[$229>>2]|0;
   $231 = ((((($17) + (($$07$i*8232)|0)|0)) + 24|0) + ($227<<3)|0);
   HEAP32[$231>>2] = $230;
   $232 = (((($17) + (($$07$i*8232)|0)|0)) + 12|0);
   $233 = HEAP32[$232>>2]|0;
   $234 = ((((((($17) + (($$07$i*8232)|0)|0)) + 24|0) + ($227<<3)|0)) + 4|0);
   HEAP32[$234>>2] = $233;
   $235 = HEAP32[$226>>2]|0;
   $236 = ((((($17) + (($$07$i*8232)|0)|0)) + 24|0) + ($235<<3)|0);
   $237 = +HEAPF32[$236>>2];
   $238 = (($235) + -1)|0;
   $239 = ((((($17) + (($$07$i*8232)|0)|0)) + 24|0) + ($238<<3)|0);
   $240 = +HEAPF32[$239>>2];
   $241 = $237 - $240;
   $242 = ((((((($17) + (($$07$i*8232)|0)|0)) + 24|0) + ($235<<3)|0)) + 4|0);
   $243 = +HEAPF32[$242>>2];
   $244 = ((((((($17) + (($$07$i*8232)|0)|0)) + 24|0) + ($238<<3)|0)) + 4|0);
   $245 = +HEAPF32[$244>>2];
   $246 = $243 - $245;
   $247 = $241 * $241;
   $248 = $246 * $246;
   $249 = $247 + $248;
   $250 = $249;
   $251 = (+_SDL_sqrt($250));
   $252 = $251;
   $253 = (((($17) + (($$07$i*8232)|0)|0)) + 16|0);
   $254 = +HEAPF32[$253>>2];
   $255 = $254 + $252;
   HEAPF32[$253>>2] = $255;
   $256 = HEAP32[$226>>2]|0;
   $257 = (($256) + 1)|0;
   HEAP32[$226>>2] = $257;
   $$sroa$4$0$$sroa_idx119$pre$phiZZZZZZ2D = $232;
  } else {
   $$pre = (((($17) + (($$07$i*8232)|0)|0)) + 12|0);
   $$sroa$4$0$$sroa_idx119$pre$phiZZZZZZ2D = $$pre;
  }
  $$sroa$0117$0$$sroa_idx = (((($17) + (($$07$i*8232)|0)|0)) + 8|0);
  $$sroa$0117$0$copyload = +HEAPF32[$$sroa$0117$0$$sroa_idx>>2];
  $$sroa$4$0$copyload = +HEAPF32[$$sroa$4$0$$sroa_idx119$pre$phiZZZZZZ2D>>2];
  $258 = (((($17) + (($$07$i*8232)|0)|0)) + 8216|0);
  $259 = HEAP16[$258>>1]|0;
  $260 = (+($259&65535));
  $261 = $223 / $260;
  $262 = $$sroa$0117$0$copyload + $261;
  HEAPF32[$$sroa$0117$0$$sroa_idx>>2] = $262;
  $263 = $225 / $260;
  $264 = $$sroa$4$0$copyload + $263;
  HEAPF32[$$sroa$4$0$$sroa_idx119$pre$phiZZZZZZ2D>>2] = $264;
  $265 = ($259&65535)>(1);
  if (!($265)) {
   STACKTOP = sp;return;
  }
  $266 = $34 - $225;
  $267 = $32 - $223;
  $268 = $267 - $$sroa$0117$0$copyload;
  $269 = $266 - $$sroa$4$0$copyload;
  $270 = $268 * $268;
  $271 = $269 * $269;
  $272 = $270 + $271;
  $273 = $272;
  $274 = (+_SDL_sqrt($273));
  $275 = $274;
  $276 = +HEAPF32[$$sroa$0117$0$$sroa_idx>>2];
  $277 = $32 - $276;
  $278 = +HEAPF32[$$sroa$4$0$$sroa_idx119$pre$phiZZZZZZ2D>>2];
  $279 = $34 - $278;
  $280 = $277 * $277;
  $281 = $279 * $279;
  $282 = $280 + $281;
  $283 = $282;
  $284 = (+_SDL_sqrt($283));
  $285 = $284;
  $286 = $268 / $275;
  $287 = $269 / $275;
  $288 = $277 / $285;
  $289 = $279 / $285;
  $290 = $286 * $289;
  $291 = $287 * $288;
  $292 = $290 - $291;
  $293 = $292;
  $294 = $286 * $288;
  $295 = $287 * $289;
  $296 = $294 + $295;
  $297 = $296;
  $298 = (+_SDL_atan2($293,$297));
  $299 = $298;
  $300 = $285 - $275;
  $301 = $275 == 0.0;
  $$0169 = $301 ? 0.0 : $300;
  $$0168 = $301 ? 0.0 : $299;
  HEAP32[$5>>2] = 2050;
  $302 = $20;
  $303 = $302;
  $304 = HEAP32[$303>>2]|0;
  $305 = (($302) + 4)|0;
  $306 = $305;
  $307 = HEAP32[$306>>2]|0;
  $308 = ((($5)) + 8|0);
  $309 = $308;
  $310 = $309;
  HEAP32[$310>>2] = $304;
  $311 = (($309) + 4)|0;
  $312 = $311;
  HEAP32[$312>>2] = $307;
  $313 = (((($17) + (($$07$i*8232)|0)|0)) + 8|0);
  $314 = HEAP32[$313>>2]|0;
  $315 = ((($5)) + 24|0);
  HEAP32[$315>>2] = $314;
  $316 = HEAP32[$$sroa$4$0$$sroa_idx119$pre$phiZZZZZZ2D>>2]|0;
  $317 = ((($5)) + 28|0);
  HEAP32[$317>>2] = $316;
  $318 = ((($5)) + 16|0);
  HEAPF32[$318>>2] = $$0168;
  $319 = ((($5)) + 20|0);
  HEAPF32[$319>>2] = $$0169;
  $320 = HEAP16[$258>>1]|0;
  $321 = ((($5)) + 32|0);
  HEAP16[$321>>1] = $320;
  (_SDL_PushEvent($5)|0);
  STACKTOP = sp;return;
  break;
 }
 case 1792:  {
  $322 = (((($17) + (($$07$i*8232)|0)|0)) + 8216|0);
  $323 = HEAP16[$322>>1]|0;
  $324 = (($323) + 1)<<16>>16;
  HEAP16[$322>>1] = $324;
  $325 = (((($17) + (($$07$i*8232)|0)|0)) + 8|0);
  $326 = +HEAPF32[$325>>2];
  $327 = $324&65535;
  $328 = (($327) + -1)|0;
  $329 = (+($328|0));
  $330 = $326 * $329;
  $331 = $32 + $330;
  $332 = (+($324&65535));
  $333 = $331 / $332;
  HEAPF32[$325>>2] = $333;
  $334 = (((($17) + (($$07$i*8232)|0)|0)) + 12|0);
  $335 = +HEAPF32[$334>>2];
  $336 = $335 * $329;
  $337 = $34 + $336;
  $338 = $337 / $332;
  HEAPF32[$334>>2] = $338;
  $339 = (((($17) + (($$07$i*8232)|0)|0)) + 16|0);
  HEAPF32[$339>>2] = 0.0;
  $340 = (((($17) + (($$07$i*8232)|0)|0)) + 24|0);
  HEAPF32[$340>>2] = $32;
  $341 = (((($17) + (($$07$i*8232)|0)|0)) + 28|0);
  HEAPF32[$341>>2] = $34;
  $342 = (((($17) + (($$07$i*8232)|0)|0)) + 20|0);
  HEAP32[$342>>2] = 1;
  STACKTOP = sp;return;
  break;
 }
 default: {
  STACKTOP = sp;return;
 }
 }
}
function _dollarNormalize($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$019029 = 0, $$019119 = 0.0, $$0193$lcssa39 = 0, $$019318 = 0, $$019528 = 0.0, $$01977 = 0.0, $$01996 = 0.0, $$02015 = 0.0, $$02034 = 0.0, $$119212 = 0.0, $$1194$lcssa = 0, $$119411 = 0, $$1196 = 0.0, $$1198 = 0.0, $$120 = 0, $$1200 = 0.0, $$1202 = 0.0, $$1204 = 0.0, $$28 = 0, $$33 = 0;
 var $$lcssa = 0.0, $$phi$trans$insert = 0, $$pre = 0, $$sroa$0$016 = 0.0, $$sroa$0$1$lcssa = 0.0, $$sroa$0$19 = 0.0, $$sroa$14$017 = 0.0, $$sroa$14$1$lcssa = 0.0, $$sroa$14$110 = 0.0, $10 = 0.0, $100 = 0.0, $101 = 0, $102 = 0.0, $103 = 0.0, $104 = 0.0, $105 = 0.0, $106 = 0.0, $107 = 0.0, $108 = 0.0, $109 = 0.0;
 var $11 = 0, $110 = 0.0, $111 = 0.0, $112 = 0.0, $113 = 0.0, $114 = 0.0, $115 = 0.0, $116 = 0.0, $117 = 0.0, $118 = 0.0, $119 = 0.0, $12 = 0.0, $120 = 0.0, $121 = 0.0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0.0;
 var $128 = 0.0, $129 = 0, $13 = 0, $130 = 0.0, $131 = 0.0, $132 = 0.0, $133 = 0.0, $134 = 0, $135 = 0.0, $136 = 0.0, $137 = 0.0, $138 = 0.0, $139 = 0, $14 = 0.0, $15 = 0.0, $16 = 0.0, $17 = 0.0, $18 = 0.0, $19 = 0.0, $2 = 0.0;
 var $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0, $24 = 0, $25 = 0, $26 = 0.0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0.0, $32 = 0, $33 = 0.0, $34 = 0.0, $35 = 0.0, $36 = 0, $37 = 0.0, $38 = 0;
 var $39 = 0.0, $4 = 0, $40 = 0.0, $41 = 0.0, $42 = 0.0, $43 = 0.0, $44 = 0.0, $45 = 0.0, $46 = 0.0, $47 = 0, $48 = 0.0, $49 = 0.0, $5 = 0, $50 = 0.0, $51 = 0.0, $52 = 0.0, $53 = 0.0, $54 = 0.0, $55 = 0, $56 = 0.0;
 var $57 = 0.0, $58 = 0.0, $59 = 0.0, $6 = 0.0, $60 = 0.0, $61 = 0, $62 = 0.0, $63 = 0.0, $64 = 0, $65 = 0.0, $66 = 0.0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0.0, $86 = 0.0, $87 = 0, $88 = 0.0, $89 = 0.0, $9 = 0.0, $90 = 0.0, $91 = 0.0, $92 = 0.0;
 var $93 = 0.0, $94 = 0.0, $95 = 0.0, $96 = 0.0, $97 = 0.0, $98 = 0.0, $99 = 0, $exitcond = 0, $exitcond38 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $2 = +HEAPF32[$0>>2];
 $3 = !($2 <= 0.0);
 $$phi$trans$insert = ((($0)) + 4|0);
 $$pre = HEAP32[$$phi$trans$insert>>2]|0;
 if ($3) {
  $$1196 = $2;$27 = $$pre;
  label = 4;
 } else {
  $4 = ($$pre|0)>(1);
  if ($4) {
   $$019029 = 1;$$019528 = $2;
   while(1) {
    $5 = (((($0)) + 8|0) + ($$019029<<3)|0);
    $6 = +HEAPF32[$5>>2];
    $7 = (($$019029) + -1)|0;
    $8 = (((($0)) + 8|0) + ($7<<3)|0);
    $9 = +HEAPF32[$8>>2];
    $10 = $6 - $9;
    $11 = (((((($0)) + 8|0) + ($$019029<<3)|0)) + 4|0);
    $12 = +HEAPF32[$11>>2];
    $13 = (((((($0)) + 8|0) + ($7<<3)|0)) + 4|0);
    $14 = +HEAPF32[$13>>2];
    $15 = $12 - $14;
    $16 = $10 * $10;
    $17 = $15 * $15;
    $18 = $16 + $17;
    $19 = $18;
    $20 = (+_SDL_sqrt($19));
    $21 = $20;
    $22 = $$019528 + $21;
    $23 = (($$019029) + 1)|0;
    $24 = HEAP32[$$phi$trans$insert>>2]|0;
    $25 = ($23|0)<($24|0);
    if ($25) {
     $$019029 = $23;$$019528 = $22;
    } else {
     $$1196 = $22;$27 = $24;
     label = 4;
     break;
    }
   }
  } else {
   $$0193$lcssa39 = 0;
  }
 }
 if ((label|0) == 4) {
  $26 = $$1196 / 63.0;
  $28 = ($27|0)>(1);
  if ($28) {
   $$019119 = $26;$$019318 = 0;$$120 = 1;$$sroa$0$016 = 0.0;$$sroa$14$017 = 0.0;
   while(1) {
    $29 = (($$120) + -1)|0;
    $30 = (((($0)) + 8|0) + ($29<<3)|0);
    $31 = +HEAPF32[$30>>2];
    $32 = (((($0)) + 8|0) + ($$120<<3)|0);
    $33 = +HEAPF32[$32>>2];
    $34 = $31 - $33;
    $35 = $34 * $34;
    $36 = (((((($0)) + 8|0) + ($29<<3)|0)) + 4|0);
    $37 = +HEAPF32[$36>>2];
    $38 = (((((($0)) + 8|0) + ($$120<<3)|0)) + 4|0);
    $39 = +HEAPF32[$38>>2];
    $40 = $37 - $39;
    $41 = $40 * $40;
    $42 = $35 + $41;
    $43 = $42;
    $44 = (+_SDL_sqrt($43));
    $45 = $44;
    $46 = $45 + $$019119;
    $47 = $46 > $26;
    if ($47) {
     $$119212 = $$019119;$$119411 = $$019318;$$sroa$0$19 = $$sroa$0$016;$$sroa$14$110 = $$sroa$14$017;
     while(1) {
      $48 = +HEAPF32[$30>>2];
      $49 = $26 - $$119212;
      $50 = $49 / $45;
      $51 = +HEAPF32[$32>>2];
      $52 = $51 - $48;
      $53 = $50 * $52;
      $54 = $48 + $53;
      $55 = (($1) + ($$119411<<3)|0);
      HEAPF32[$55>>2] = $54;
      $56 = +HEAPF32[$36>>2];
      $57 = +HEAPF32[$38>>2];
      $58 = $57 - $56;
      $59 = $50 * $58;
      $60 = $56 + $59;
      $61 = (((($1) + ($$119411<<3)|0)) + 4|0);
      HEAPF32[$61>>2] = $60;
      $62 = $$sroa$0$19 + $54;
      $63 = $$sroa$14$110 + $60;
      $64 = (($$119411) + 1)|0;
      $65 = $$119212 - $26;
      $66 = $45 + $65;
      $67 = $66 > $26;
      if ($67) {
       $$119212 = $65;$$119411 = $64;$$sroa$0$19 = $62;$$sroa$14$110 = $63;
      } else {
       $$1194$lcssa = $64;$$lcssa = $66;$$sroa$0$1$lcssa = $62;$$sroa$14$1$lcssa = $63;
       break;
      }
     }
    } else {
     $$1194$lcssa = $$019318;$$lcssa = $46;$$sroa$0$1$lcssa = $$sroa$0$016;$$sroa$14$1$lcssa = $$sroa$14$017;
    }
    $68 = (($$120) + 1)|0;
    $69 = HEAP32[$$phi$trans$insert>>2]|0;
    $70 = ($68|0)<($69|0);
    if ($70) {
     $$019119 = $$lcssa;$$019318 = $$1194$lcssa;$$120 = $68;$$sroa$0$016 = $$sroa$0$1$lcssa;$$sroa$14$017 = $$sroa$14$1$lcssa;
    } else {
     break;
    }
   }
   $71 = ($$1194$lcssa|0)<(63);
   if ($71) {
    $$0193$lcssa39 = $$1194$lcssa;
   } else {
    $72 = ((($1)) + 504|0);
    $73 = (($69) + -1)|0;
    $74 = (((($0)) + 8|0) + ($73<<3)|0);
    $75 = $74;
    $76 = $75;
    $77 = HEAP32[$76>>2]|0;
    $78 = (($75) + 4)|0;
    $79 = $78;
    $80 = HEAP32[$79>>2]|0;
    $81 = $72;
    $82 = $81;
    HEAP32[$82>>2] = $77;
    $83 = (($81) + 4)|0;
    $84 = $83;
    HEAP32[$84>>2] = $80;
    $85 = $$sroa$0$1$lcssa * 0.015625;
    $86 = $$sroa$14$1$lcssa * 0.015625;
    $87 = ((($1)) + 4|0);
    $88 = +HEAPF32[$87>>2];
    $89 = $86 - $88;
    $90 = $89;
    $91 = +HEAPF32[$1>>2];
    $92 = $85 - $91;
    $93 = $92;
    $94 = (+_SDL_atan2($90,$93));
    $95 = $94;
    $96 = $95;
    $97 = $85;
    $98 = $86;
    $$01977 = $85;$$01996 = $85;$$02015 = $86;$$02034 = $86;$$28 = 0;
    while(1) {
     $99 = (($1) + ($$28<<3)|0);
     $100 = +HEAPF32[$99>>2];
     $101 = (((($1) + ($$28<<3)|0)) + 4|0);
     $102 = +HEAPF32[$101>>2];
     $103 = $100 - $85;
     $104 = $103;
     $105 = (+_SDL_cos($96));
     $106 = $104 * $105;
     $107 = $102 - $86;
     $108 = $107;
     $109 = (+_SDL_sin($96));
     $110 = $108 * $109;
     $111 = $106 - $110;
     $112 = $97 + $111;
     $113 = $112;
     HEAPF32[$99>>2] = $113;
     $114 = (+_SDL_sin($96));
     $115 = $104 * $114;
     $116 = (+_SDL_cos($96));
     $117 = $108 * $116;
     $118 = $115 + $117;
     $119 = $98 + $118;
     $120 = $119;
     HEAPF32[$101>>2] = $120;
     $121 = +HEAPF32[$99>>2];
     $122 = $121 < $$01977;
     $$1198 = $122 ? $121 : $$01977;
     $123 = $121 > $$01996;
     $$1200 = $123 ? $121 : $$01996;
     $124 = $120 < $$02034;
     $$1204 = $124 ? $120 : $$02034;
     $125 = $120 > $$02015;
     $$1202 = $125 ? $120 : $$02015;
     $126 = (($$28) + 1)|0;
     $exitcond38 = ($126|0)==(64);
     if ($exitcond38) {
      break;
     } else {
      $$01977 = $$1198;$$01996 = $$1200;$$02015 = $$1202;$$02034 = $$1204;$$28 = $126;
     }
    }
    $127 = $$1200 - $$1198;
    $128 = $$1202 - $$1204;
    $$33 = 0;
    while(1) {
     $129 = (($1) + ($$33<<3)|0);
     $130 = +HEAPF32[$129>>2];
     $131 = $130 - $85;
     $132 = $131 * 256.0;
     $133 = $132 / $127;
     HEAPF32[$129>>2] = $133;
     $134 = (((($1) + ($$33<<3)|0)) + 4|0);
     $135 = +HEAPF32[$134>>2];
     $136 = $135 - $86;
     $137 = $136 * 256.0;
     $138 = $137 / $128;
     HEAPF32[$134>>2] = $138;
     $139 = (($$33) + 1)|0;
     $exitcond = ($139|0)==(64);
     if ($exitcond) {
      break;
     } else {
      $$33 = $139;
     }
    }
    STACKTOP = sp;return;
   }
  } else {
   $$0193$lcssa39 = 0;
  }
 }
 HEAP32[$vararg_buffer>>2] = $$0193$lcssa39;
 (_SDL_SetError(182023,$vararg_buffer)|0);
 STACKTOP = sp;return;
}
function _dollarDifference($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = +$2;
 var $$03031 = 0.0, $$032 = 0, $10 = 0.0, $11 = 0.0, $12 = 0.0, $13 = 0.0, $14 = 0.0, $15 = 0.0, $16 = 0.0, $17 = 0.0, $18 = 0.0, $19 = 0.0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0.0, $25 = 0.0, $26 = 0, $27 = 0.0;
 var $28 = 0.0, $29 = 0.0, $3 = 0.0, $30 = 0, $31 = 0.0, $32 = 0.0, $33 = 0.0, $34 = 0.0, $35 = 0.0, $36 = 0.0, $37 = 0.0, $38 = 0.0, $39 = 0, $4 = 0, $40 = 0.0, $5 = 0.0, $6 = 0.0, $7 = 0.0, $8 = 0.0, $9 = 0;
 var $exitcond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = $2;
 $$03031 = 0.0;$$032 = 0;
 while(1) {
  $4 = (($0) + ($$032<<3)|0);
  $5 = +HEAPF32[$4>>2];
  $6 = $5;
  $7 = (+_SDL_cos($3));
  $8 = $6 * $7;
  $9 = (((($0) + ($$032<<3)|0)) + 4|0);
  $10 = +HEAPF32[$9>>2];
  $11 = $10;
  $12 = (+_SDL_sin($3));
  $13 = $11 * $12;
  $14 = $8 - $13;
  $15 = $14;
  $16 = +HEAPF32[$4>>2];
  $17 = $16;
  $18 = (+_SDL_sin($3));
  $19 = $17 * $18;
  $20 = +HEAPF32[$9>>2];
  $21 = $20;
  $22 = (+_SDL_cos($3));
  $23 = $21 * $22;
  $24 = $19 + $23;
  $25 = $24;
  $26 = (($1) + ($$032<<3)|0);
  $27 = +HEAPF32[$26>>2];
  $28 = $15 - $27;
  $29 = $28 * $28;
  $30 = (((($1) + ($$032<<3)|0)) + 4|0);
  $31 = +HEAPF32[$30>>2];
  $32 = $25 - $31;
  $33 = $32 * $32;
  $34 = $29 + $33;
  $35 = $34;
  $36 = (+_SDL_sqrt($35));
  $37 = $36;
  $38 = $$03031 + $37;
  $39 = (($$032) + 1)|0;
  $exitcond = ($39|0)==(64);
  if ($exitcond) {
   break;
  } else {
   $$03031 = $38;$$032 = $39;
  }
 }
 $40 = $38 * 0.015625;
 return (+$40);
}
function _SDL_fabs($0) {
 $0 = +$0;
 var $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (+Math_abs((+$0)));
 return (+$1);
}
function _SDL_sqrt($0) {
 $0 = +$0;
 var $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (+Math_sqrt((+$0)));
 return (+$1);
}
function _SDL_atan2($0,$1) {
 $0 = +$0;
 $1 = +$1;
 var $2 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (+Math_atan2((+$0),(+$1)));
 return (+$2);
}
function _SDL_cos($0) {
 $0 = +$0;
 var $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (+Math_cos((+$0)));
 return (+$1);
}
function _SDL_sin($0) {
 $0 = +$0;
 var $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (+Math_sin((+$0)));
 return (+$1);
}
function _SDL_AtomicGet($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $success = 0, label = 0, sp = 0;
 sp = STACKTOP;
 while(1) {
  $1 = HEAP32[$0>>2]|0;
  $2 = HEAP32[$0>>2]|0;if (($2|0) == ($1|0)) HEAP32[$0>>2] = $1;
  $success = ($2|0)==($1|0);
  if ($success) {
   break;
  }
 }
 return ($1|0);
}
function _SDL_AtomicAdd($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;HEAP32[$0>>2] = (($2+$1)|0);
 return ($2|0);
}
function _SDL_FlushEvents($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$015 = 0, $$pre = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond14 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_SDL_AtomicGet((88628))|0);
 $3 = ($2|0)!=(0);
 $4 = HEAP32[22156]|0;
 $5 = ($4|0)!=(0|0);
 $or$cond = $3 & $5;
 if (!($or$cond)) {
  return;
 }
 $6 = (_SDL_LockMutex($4)|0);
 $7 = ($6|0)==(0);
 if (!($7)) {
  return;
 }
 $8 = HEAP32[(88640)>>2]|0;
 $9 = ($8|0)==(0|0);
 if (!($9)) {
  $$015 = $8;
  while(1) {
   $10 = ((($$015)) + 72|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = HEAP32[$$015>>2]|0;
   $13 = ($12>>>0)<($0>>>0);
   $14 = ($12>>>0)>($1>>>0);
   $or$cond14 = $13 | $14;
   $15 = $11;
   if (!($or$cond14)) {
    $17 = ((($$015)) + 68|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = ($18|0)==(0|0);
    if ($19) {
     $21 = $11;
    } else {
     $20 = ((($18)) + 72|0);
     HEAP32[$20>>2] = $15;
     $$pre = HEAP32[$10>>2]|0;
     $21 = $$pre;
    }
    $22 = ($21|0)==(0|0);
    if (!($22)) {
     $23 = ((($21)) + 68|0);
     HEAP32[$23>>2] = $18;
    }
    $24 = HEAP32[(88640)>>2]|0;
    $25 = ($24|0)==($$015|0);
    if ($25) {
     HEAP32[(88640)>>2] = $21;
    }
    $26 = HEAP32[(88644)>>2]|0;
    $27 = ($26|0)==($$015|0);
    if ($27) {
     $28 = HEAP32[$17>>2]|0;
     HEAP32[(88644)>>2] = $28;
    }
    $29 = HEAP32[(88648)>>2]|0;
    HEAP32[$10>>2] = $29;
    HEAP32[(88648)>>2] = $$015;
    (_SDL_AtomicAdd((88632),-1)|0);
   }
   $16 = ($11|0)==(0|0);
   if ($16) {
    break;
   } else {
    $$015 = $11;
   }
  }
 }
 return;
}
function _SDL_GetHintBoolean($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$ = 0, $$0 = 0, $$0$i = 0, $$013$i = 0, $$013$i6 = 0, $$015$i = 0, $$016$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $not$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_SDL_getenv($0)|0);
 $$015$i = HEAP32[52378]|0;
 $3 = ($$015$i|0)==(0|0);
 L1: do {
  if ($3) {
   $$013$i = $2;
   label = 7;
  } else {
   $$016$i = $$015$i;
   while(1) {
    $4 = HEAP32[$$016$i>>2]|0;
    $5 = (_SDL_strcmp($0,$4)|0);
    $6 = ($5|0)==(0);
    if ($6) {
     break;
    }
    $13 = ((($$016$i)) + 16|0);
    $$0$i = HEAP32[$13>>2]|0;
    $14 = ($$0$i|0)==(0|0);
    if ($14) {
     $$013$i = $2;
     label = 7;
     break L1;
    } else {
     $$016$i = $$0$i;
    }
   }
   $7 = ($2|0)==(0|0);
   if (!($7)) {
    $8 = ((($$016$i)) + 8|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = ($9|0)==(2);
    if (!($10)) {
     $$013$i6 = $2;
     break;
    }
   }
   $11 = ((($$016$i)) + 4|0);
   $12 = HEAP32[$11>>2]|0;
   $$013$i = $12;
   label = 7;
  }
 } while(0);
 if ((label|0) == 7) {
  $15 = ($$013$i|0)==(0|0);
  if ($15) {
   $$0 = $1;
   return ($$0|0);
  } else {
   $$013$i6 = $$013$i;
  }
 }
 $16 = HEAP8[$$013$i6>>0]|0;
 $17 = ($16<<24>>24)==(48);
 if ($17) {
  $$0 = 0;
  return ($$0|0);
 } else {
  $18 = (_SDL_strcasecmp($$013$i6,204742)|0);
  $not$ = ($18|0)!=(0);
  $$ = $not$&1;
  return ($$|0);
 }
 return (0)|0;
}
function _SDL_SetMouseFocus($0) {
 $0 = $0|0;
 var $$ = 0, $$pr = 0, $$sink = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $notlhs$i = 0, $notrhs$i = 0, $or$cond27$not$i = 0, $or$cond29$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[(209568)>>2]|0;
 $2 = ($1|0)==($0|0);
 if ($2) {
  return;
 }
 $3 = ($1|0)==(0|0);
 if (!($3)) {
  (_SDL_SendWindowEvent($1,11,0,0)|0);
 }
 HEAP32[(209568)>>2] = $0;
 $4 = ($0|0)==(0|0);
 if ($4) {
  $$sink = (209620);
 } else {
  (_SDL_SendWindowEvent($0,10,0,0)|0);
  $$pr = HEAP32[(209568)>>2]|0;
  $5 = ($$pr|0)==(0|0);
  $$ = $5 ? (209620) : (209624);
  $$sink = $$;
 }
 $6 = HEAP32[$$sink>>2]|0;
 $7 = HEAP32[(209628)>>2]|0;
 $notlhs$i = ($6|0)!=(0|0);
 $notrhs$i = ($7|0)!=(0);
 $or$cond27$not$i = $notlhs$i & $notrhs$i;
 $8 = HEAP32[(209600)>>2]|0;
 $9 = ($8|0)==(0);
 $or$cond29$i = $or$cond27$not$i & $9;
 $10 = HEAP32[(209532)>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($or$cond29$i) {
  if ($11) {
   return;
  }
  (FUNCTION_TABLE_ii[$10 & 8191]($6)|0);
  return;
 } else {
  if ($11) {
   return;
  }
  (FUNCTION_TABLE_ii[$10 & 8191](0)|0);
  return;
 }
}
function _SDL_WarpMouseInWindow($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$ = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $not$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($0|0)==(0|0);
 $4 = HEAP32[(209568)>>2]|0;
 $$ = $3 ? $4 : $0;
 $5 = ($$|0)==(0|0);
 if ($5) {
  return;
 }
 $6 = HEAP32[(209544)>>2]|0;
 $7 = ($6|0)==(0|0);
 if (!($7)) {
  FUNCTION_TABLE_viii[$6 & 8191]($$,$1,$2);
  return;
 }
 $8 = HEAP32[(209564)>>2]|0;
 $9 = (_SDL_UpdateMouseFocus($$,$1,$2)|0);
 $not$ = ($9|0)==(0);
 if ($not$) {
  return;
 }
 (_SDL_PrivateSendMouseMotion($$,$8,0,$1,$2)|0);
 return;
}
function _SDL_UpdateMouseFocus($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$$i = 0, $$023 = 0, $$pr$i = 0, $$sink$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $notlhs$i$i = 0;
 var $notlhs$i$i5 = 0, $notrhs$i$i = 0, $notrhs$i$i6 = 0, $or$cond = 0, $or$cond27$not$i$i = 0, $or$cond27$not$i$i7 = 0, $or$cond29$i$i = 0, $or$cond29$i$i8 = 0, $or$cond3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp + 4|0;
 $4 = sp;
 $5 = ($0|0)==(0|0);
 if (!($5)) {
  $6 = ((($0)) + 48|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = $7 & 16384;
  $9 = ($8|0)==(0);
  if ($9) {
   _SDL_GetWindowSize($0,$3,$4);
   $10 = $2 | $1;
   $11 = ($10|0)>(-1);
   $12 = HEAP32[$3>>2]|0;
   $13 = ($12|0)>($1|0);
   $or$cond = $11 & $13;
   $14 = HEAP32[$4>>2]|0;
   $15 = ($14|0)>($2|0);
   $or$cond3 = $or$cond & $15;
   if (!($or$cond3)) {
    $16 = HEAP32[(209568)>>2]|0;
    $17 = ($16|0)==($0|0);
    if (!($17)) {
     $$023 = 0;
     STACKTOP = sp;return ($$023|0);
    }
    $18 = HEAP32[(209564)>>2]|0;
    (_SDL_PrivateSendMouseMotion($0,$18,0,$1,$2)|0);
    $19 = HEAP32[(209568)>>2]|0;
    $20 = ($19|0)==(0|0);
    if ($20) {
     $$023 = 0;
     STACKTOP = sp;return ($$023|0);
    }
    (_SDL_SendWindowEvent($19,11,0,0)|0);
    HEAP32[(209568)>>2] = 0;
    $21 = HEAP32[(209620)>>2]|0;
    $22 = HEAP32[(209628)>>2]|0;
    $notlhs$i$i5 = ($21|0)!=(0|0);
    $notrhs$i$i6 = ($22|0)!=(0);
    $or$cond27$not$i$i7 = $notlhs$i$i5 & $notrhs$i$i6;
    $23 = HEAP32[(209600)>>2]|0;
    $24 = ($23|0)==(0);
    $or$cond29$i$i8 = $or$cond27$not$i$i7 & $24;
    $25 = HEAP32[(209532)>>2]|0;
    $26 = ($25|0)==(0|0);
    if ($or$cond29$i$i8) {
     if ($26) {
      $$023 = 0;
      STACKTOP = sp;return ($$023|0);
     }
     (FUNCTION_TABLE_ii[$25 & 8191]($21)|0);
     $$023 = 0;
     STACKTOP = sp;return ($$023|0);
    } else {
     if ($26) {
      $$023 = 0;
      STACKTOP = sp;return ($$023|0);
     }
     (FUNCTION_TABLE_ii[$25 & 8191](0)|0);
     $$023 = 0;
     STACKTOP = sp;return ($$023|0);
    }
   }
  }
 }
 $27 = HEAP32[(209568)>>2]|0;
 $28 = ($27|0)==($0|0);
 if ($28) {
  $$023 = 1;
  STACKTOP = sp;return ($$023|0);
 }
 $29 = ($27|0)==(0|0);
 if (!($29)) {
  (_SDL_SendWindowEvent($27,11,0,0)|0);
 }
 HEAP32[(209568)>>2] = $0;
 if ($5) {
  $$sink$i = (209620);
 } else {
  (_SDL_SendWindowEvent($0,10,0,0)|0);
  $$pr$i = HEAP32[(209568)>>2]|0;
  $30 = ($$pr$i|0)==(0|0);
  $$$i = $30 ? (209620) : (209624);
  $$sink$i = $$$i;
 }
 $31 = HEAP32[$$sink$i>>2]|0;
 $32 = HEAP32[(209628)>>2]|0;
 $notlhs$i$i = ($31|0)!=(0|0);
 $notrhs$i$i = ($32|0)!=(0);
 $or$cond27$not$i$i = $notlhs$i$i & $notrhs$i$i;
 $33 = HEAP32[(209600)>>2]|0;
 $34 = ($33|0)==(0);
 $or$cond29$i$i = $or$cond27$not$i$i & $34;
 $35 = HEAP32[(209532)>>2]|0;
 $36 = ($35|0)==(0|0);
 if ($or$cond29$i$i) {
  if (!($36)) {
   (FUNCTION_TABLE_ii[$35 & 8191]($31)|0);
  }
 } else {
  if (!($36)) {
   (FUNCTION_TABLE_ii[$35 & 8191](0)|0);
  }
 }
 $37 = HEAP32[(209564)>>2]|0;
 (_SDL_PrivateSendMouseMotion($0,$37,0,$1,$2)|0);
 $$023 = 1;
 STACKTOP = sp;return ($$023|0);
}
function _SDL_PrivateSendMouseMotion($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$$i = 0, $$078 = 0, $$079 = 0, $$080 = 0, $$082 = 0, $$083 = 0, $$1 = 0, $$pre = 0, $$sink = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $not$ = 0, $or$cond = 0, $or$cond85 = 0, $storemerge = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(80|0);
 $5 = sp + 68|0;
 $6 = sp + 64|0;
 $7 = sp + 60|0;
 $8 = sp + 56|0;
 $9 = sp;
 $10 = HEAP32[(209604)>>2]|0;
 $11 = ($10|0)==(0);
 if (!($11)) {
  HEAP32[$5>>2] = 0;
  HEAP32[$6>>2] = 0;
  _SDL_GetWindowSize($0,$5,$6);
  $12 = HEAP32[$5>>2]|0;
  $13 = (($12|0) / 2)&-1;
  HEAP32[$5>>2] = $13;
  $14 = HEAP32[$6>>2]|0;
  $15 = (($14|0) / 2)&-1;
  HEAP32[$6>>2] = $15;
  $16 = ($13|0)==($3|0);
  $17 = ($15|0)==($4|0);
  $or$cond = $16 & $17;
  if ($or$cond) {
   HEAP32[(209588)>>2] = $3;
   HEAP32[(209592)>>2] = $4;
   $$1 = 0;
   STACKTOP = sp;return ($$1|0);
  }
  $18 = ($0|0)==(0|0);
  $19 = HEAP32[(209568)>>2]|0;
  $$$i = $18 ? $19 : $0;
  $20 = ($$$i|0)==(0|0);
  do {
   if (!($20)) {
    $21 = HEAP32[(209544)>>2]|0;
    $22 = ($21|0)==(0|0);
    if (!($22)) {
     FUNCTION_TABLE_viii[$21 & 8191]($$$i,$13,$15);
     break;
    }
    $23 = HEAP32[(209564)>>2]|0;
    $24 = (_SDL_UpdateMouseFocus($$$i,$13,$15)|0);
    $not$ = ($24|0)==(0);
    if (!($not$)) {
     (_SDL_PrivateSendMouseMotion($$$i,$23,0,$13,$15)|0);
    }
   }
  } while(0);
 }
 $25 = ($2|0)!=(0);
 $26 = HEAP32[(209592)>>2]|0;
 $27 = HEAP32[(209588)>>2]|0;
 if ($25) {
  $28 = (($27) + ($3))|0;
  $29 = (($26) + ($4))|0;
  $$078 = $4;$$079 = $3;$$082 = $29;$$083 = $28;
 } else {
  $30 = (($3) - ($27))|0;
  $31 = (($4) - ($26))|0;
  $$078 = $31;$$079 = $30;$$082 = $4;$$083 = $3;
 }
 $32 = $$078 | $$079;
 $33 = ($32|0)==(0);
 if ($33) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $34 = HEAP32[(209600)>>2]|0;
 $35 = ($34|0)==(0);
 if ($35) {
  HEAP32[(209572)>>2] = $$083;
  $storemerge = $$082;
 } else {
  $36 = HEAP32[(209572)>>2]|0;
  $37 = (($36) + ($$079))|0;
  HEAP32[(209572)>>2] = $37;
  $38 = HEAP32[(209576)>>2]|0;
  $39 = (($38) + ($$078))|0;
  $storemerge = $39;
 }
 HEAP32[(209576)>>2] = $storemerge;
 $40 = ($0|0)==(0|0);
 if ($40) {
  $64 = $34;
 } else {
  $41 = ((($0)) + 48|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = $42 & 16384;
  $44 = ($43|0)==(0);
  if ($44) {
   HEAP32[$7>>2] = 0;
   HEAP32[$8>>2] = 0;
   $45 = HEAP32[(209568)>>2]|0;
   _SDL_GetWindowSize($45,$7,$8);
   $46 = HEAP32[$7>>2]|0;
   $47 = (($46) + -1)|0;
   HEAP32[$7>>2] = $47;
   $48 = HEAP32[$8>>2]|0;
   $49 = (($48) + -1)|0;
   HEAP32[$8>>2] = $49;
   $50 = HEAP32[(209572)>>2]|0;
   $51 = ($50|0)<($46|0);
   if ($51) {
    $52 = $50;
   } else {
    HEAP32[(209572)>>2] = $47;
    $52 = $47;
   }
   $53 = ($52|0)<(0);
   if ($53) {
    HEAP32[(209572)>>2] = 0;
   }
   $54 = HEAP32[(209576)>>2]|0;
   $55 = ($54|0)<($48|0);
   if ($55) {
    $56 = $54;
   } else {
    HEAP32[(209576)>>2] = $49;
    $56 = $49;
   }
   $57 = ($56|0)<(0);
   if ($57) {
    HEAP32[(209576)>>2] = 0;
   }
   $$pre = HEAP32[(209600)>>2]|0;
   $64 = $$pre;
  } else {
   $64 = $34;
  }
 }
 $58 = HEAP32[(209580)>>2]|0;
 $59 = (($58) + ($$079))|0;
 HEAP32[(209580)>>2] = $59;
 $60 = HEAP32[(209584)>>2]|0;
 $61 = (($60) + ($$078))|0;
 HEAP32[(209584)>>2] = $61;
 $62 = HEAP32[(209628)>>2]|0;
 $63 = ($62|0)!=(0);
 $65 = ($64|0)==(0);
 $or$cond85 = $63 & $65;
 if ($or$cond85) {
  $66 = HEAP32[(209536)>>2]|0;
  $67 = ($66|0)==(0|0);
  if (!($67)) {
   $68 = HEAP32[(209624)>>2]|0;
   $69 = ($68|0)==(0|0);
   if (!($69)) {
    FUNCTION_TABLE_vi[$66 & 8191]($68);
   }
  }
 }
 $70 = (_SDL_EventState(1024,-1)|0);
 $71 = ($70<<24>>24)==(1);
 if ($71) {
  HEAP32[$9>>2] = 1024;
  $72 = HEAP32[(209568)>>2]|0;
  $73 = ($72|0)==(0|0);
  if ($73) {
   $77 = 0;
  } else {
   $74 = ((($72)) + 4|0);
   $75 = HEAP32[$74>>2]|0;
   $77 = $75;
  }
  $76 = ((($9)) + 8|0);
  HEAP32[$76>>2] = $77;
  $78 = ((($9)) + 12|0);
  HEAP32[$78>>2] = $1;
  $79 = HEAP32[(209596)>>2]|0;
  $80 = ((($9)) + 16|0);
  HEAP32[$80>>2] = $79;
  $81 = HEAP32[(209572)>>2]|0;
  $82 = ((($9)) + 20|0);
  HEAP32[$82>>2] = $81;
  $83 = HEAP32[(209576)>>2]|0;
  $84 = ((($9)) + 24|0);
  HEAP32[$84>>2] = $83;
  $85 = ((($9)) + 28|0);
  HEAP32[$85>>2] = $$079;
  $86 = ((($9)) + 32|0);
  HEAP32[$86>>2] = $$078;
  $87 = (_SDL_PushEvent($9)|0);
  $88 = ($87|0)>(0);
  $89 = $88&1;
  $$080 = $89;
 } else {
  $$080 = 0;
 }
 if ($25) {
  $90 = HEAP32[(209572)>>2]|0;
  HEAP32[(209588)>>2] = $90;
  $91 = HEAP32[(209576)>>2]|0;
  $$sink = $91;
 } else {
  HEAP32[(209588)>>2] = $$083;
  $$sink = $$082;
 }
 HEAP32[(209592)>>2] = $$sink;
 $$1 = $$080;
 STACKTOP = sp;return ($$1|0);
}
function _SDL_GetWindowDisplayIndex($0) {
 $0 = $0|0;
 var $$ = 0, $$$053 = 0, $$05169 = 0, $$05367 = 0, $$055$lcssa76 = 0, $$05566 = 0, $$1 = 0, $$152$$055 = 0, $$15268 = 0, $$2 = 0, $$neg58 = 0, $$neg59 = 0, $$neg61 = 0, $$neg62 = 0, $$phi$trans$insert = 0, $$pre = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0;
 var $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $7 = 0, $8 = 0, $9 = 0, $switch$split2D = 0, $switch$split62D = 0;
 var $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $vararg_buffer3 = sp + 16|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $1 = sp + 40|0;
 $2 = sp + 24|0;
 $3 = HEAP32[52375]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  (_SDL_SetError(175439,$vararg_buffer)|0);
  $$2 = -1;
  STACKTOP = sp;return ($$2|0);
 }
 $5 = ($0|0)==(0|0);
 if (!($5)) {
  $6 = HEAP32[$0>>2]|0;
  $7 = ((($3)) + 280|0);
  $8 = ($6|0)==($7|0);
  if ($8) {
   $9 = ((($0)) + 16|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = $10 & -65536;
   $switch$split2D = ($11|0)<(805240832);
   if ($switch$split2D) {
    switch ($11|0) {
    case 536805376:  {
     label = 7;
     break;
    }
    default: {
    }
    }
   } else {
    switch ($11|0) {
    case 805240832:  {
     label = 7;
     break;
    }
    default: {
    }
    }
   }
   if ((label|0) == 7) {
    $12 = $10 & 65535;
    $13 = ((($3)) + 264|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ($12|0)>=($14|0);
    $$ = $15 ? 0 : $12;
    $$2 = $$;
    STACKTOP = sp;return ($$2|0);
   }
   $16 = ((($0)) + 20|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = $17 & -65536;
   $switch$split62D = ($18|0)<(805240832);
   if ($switch$split62D) {
    switch ($18|0) {
    case 536805376:  {
     label = 11;
     break;
    }
    default: {
    }
    }
   } else {
    switch ($18|0) {
    case 805240832:  {
     label = 11;
     break;
    }
    default: {
    }
    }
   }
   if ((label|0) == 11) {
    $22 = $17 & 65535;
    $23 = ((($3)) + 264|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = ($22|0)>=($24|0);
    $$1 = $25 ? 0 : $22;
    $$2 = $$1;
    STACKTOP = sp;return ($$2|0);
   }
   $19 = ((($3)) + 264|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = ($20|0)>(0);
   L22: do {
    if ($21) {
     $$phi$trans$insert = ((($3)) + 268|0);
     $$pre = HEAP32[$$phi$trans$insert>>2]|0;
     $$05169 = 0;
     while(1) {
      $28 = (((($$pre) + (($$05169*68)|0)|0)) + 56|0);
      $29 = HEAP32[$28>>2]|0;
      $30 = ($29|0)==($0|0);
      $26 = (($$05169) + 1)|0;
      if ($30) {
       $$2 = $$05169;
       break;
      }
      $27 = ($26|0)<($20|0);
      if ($27) {
       $$05169 = $26;
      } else {
       break L22;
      }
     }
     STACKTOP = sp;return ($$2|0);
    }
   } while(0);
   $31 = ((($0)) + 24|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = (($32|0) / 2)&-1;
   $34 = (($33) + ($10))|0;
   HEAP32[$1>>2] = $34;
   $35 = ((($0)) + 28|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36|0) / 2)&-1;
   $38 = (($37) + ($17))|0;
   $39 = ((($1)) + 4|0);
   HEAP32[$39>>2] = $38;
   if ($21) {
    $40 = ((($2)) + 8|0);
    $41 = ((($2)) + 4|0);
    $42 = ((($2)) + 12|0);
    $$05367 = 2147483647;$$05566 = -1;$$15268 = 0;
    while(1) {
     (_SDL_GetDisplayBounds($$15268,$2)|0);
     $43 = (_SDL_EnclosePoints($1,1,$2,0)|0);
     $44 = ($43|0)==(0);
     if (!($44)) {
      $$2 = $$15268;
      label = 20;
      break;
     }
     $45 = HEAP32[$1>>2]|0;
     $46 = HEAP32[$2>>2]|0;
     $47 = HEAP32[$40>>2]|0;
     $$neg58 = (($47|0) / -2)&-1;
     $$neg59 = (($45) - ($46))|0;
     $48 = (($$neg59) + ($$neg58))|0;
     $49 = HEAP32[$39>>2]|0;
     $50 = HEAP32[$41>>2]|0;
     $51 = HEAP32[$42>>2]|0;
     $$neg61 = (($51|0) / -2)&-1;
     $$neg62 = (($49) - ($50))|0;
     $52 = (($$neg62) + ($$neg61))|0;
     $53 = Math_imul($48, $48)|0;
     $54 = Math_imul($52, $52)|0;
     $55 = (($54) + ($53))|0;
     $56 = ($55|0)<($$05367|0);
     $$152$$055 = $56 ? $$15268 : $$05566;
     $$$053 = $56 ? $55 : $$05367;
     $57 = (($$15268) + 1)|0;
     $58 = HEAP32[52375]|0;
     $59 = ((($58)) + 264|0);
     $60 = HEAP32[$59>>2]|0;
     $61 = ($57|0)<($60|0);
     if ($61) {
      $$05367 = $$$053;$$05566 = $$152$$055;$$15268 = $57;
     } else {
      break;
     }
    }
    if ((label|0) == 20) {
     STACKTOP = sp;return ($$2|0);
    }
    $62 = ($$152$$055|0)<(0);
    if ($62) {
     $$055$lcssa76 = $$152$$055;
    } else {
     $$2 = $$152$$055;
     STACKTOP = sp;return ($$2|0);
    }
   } else {
    $$055$lcssa76 = -1;
   }
   (_SDL_SetError(182313,$vararg_buffer3)|0);
   $$2 = $$055$lcssa76;
   STACKTOP = sp;return ($$2|0);
  }
 }
 (_SDL_SetError(195204,$vararg_buffer1)|0);
 $$2 = -1;
 STACKTOP = sp;return ($$2|0);
}
function _SDL_GetWindowDisplayMode($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$0$i = 0, $$0$i13 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer3 = 0, $vararg_buffer5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $vararg_buffer5 = sp + 24|0;
 $vararg_buffer3 = sp + 16|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $2 = sp + 28|0;
 $3 = HEAP32[52375]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  (_SDL_SetError(175439,$vararg_buffer)|0);
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = ($0|0)==(0|0);
 if (!($5)) {
  $6 = HEAP32[$0>>2]|0;
  $7 = ((($3)) + 280|0);
  $8 = ($6|0)==($7|0);
  if ($8) {
   $9 = ($1|0)==(0|0);
   if ($9) {
    HEAP32[$vararg_buffer3>>2] = 182275;
    $10 = (_SDL_SetError(194740,$vararg_buffer3)|0);
    $$0 = $10;
    STACKTOP = sp;return ($$0|0);
   }
   $11 = ((($0)) + 72|0);
   ;HEAP32[$2>>2]=HEAP32[$11>>2]|0;HEAP32[$2+4>>2]=HEAP32[$11+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$11+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$11+12>>2]|0;HEAP32[$2+16>>2]=HEAP32[$11+16>>2]|0;
   $12 = ((($2)) + 4|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = ($13|0)==(0);
   if ($14) {
    $15 = ((($0)) + 64|0);
    $16 = HEAP32[$15>>2]|0;
    HEAP32[$12>>2] = $16;
   }
   $17 = ((($2)) + 8|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = ($18|0)==(0);
   if ($19) {
    $20 = ((($0)) + 68|0);
    $21 = HEAP32[$20>>2]|0;
    HEAP32[$17>>2] = $21;
   }
   $22 = (_SDL_GetWindowDisplayIndex($0)|0);
   $23 = ($22|0)>(-1);
   if ($23) {
    $24 = HEAP32[52375]|0;
    $25 = ((($24)) + 268|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = (($26) + (($22*68)|0)|0);
    $$0$i = $27;
   } else {
    $$0$i = 0;
   }
   $28 = ((($0)) + 48|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = $29 & 4097;
   $31 = ($30|0)==(4097);
   if ($31) {
    $32 = ((($$0$i)) + 16|0);
    ;HEAP32[$2>>2]=HEAP32[$32>>2]|0;HEAP32[$2+4>>2]=HEAP32[$32+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$32+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$32+12>>2]|0;HEAP32[$2+16>>2]=HEAP32[$32+16>>2]|0;
   } else {
    $33 = (_SDL_GetWindowDisplayIndex($0)|0);
    $34 = ($33|0)>(-1);
    if ($34) {
     $35 = HEAP32[52375]|0;
     $36 = ((($35)) + 268|0);
     $37 = HEAP32[$36>>2]|0;
     $38 = (($37) + (($33*68)|0)|0);
     $$0$i13 = $38;
    } else {
     $$0$i13 = 0;
    }
    $39 = (_SDL_GetClosestDisplayModeForDisplay($$0$i13,$2,$2)|0);
    $40 = ($39|0)==(0|0);
    if ($40) {
     $41 = (_SDL_SetError(182280,$vararg_buffer5)|0);
     $$0 = $41;
     STACKTOP = sp;return ($$0|0);
    }
   }
   ;HEAP32[$1>>2]=HEAP32[$2>>2]|0;HEAP32[$1+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$2+12>>2]|0;HEAP32[$1+16>>2]=HEAP32[$2+16>>2]|0;
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 (_SDL_SetError(195204,$vararg_buffer1)|0);
 $$0 = -1;
 STACKTOP = sp;return ($$0|0);
}
function _SDL_SetDisplayModeForDisplay($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0;
 var $vararg_buffer2 = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(64|0);
 $vararg_buffer2 = sp + 8|0;
 $vararg_buffer = sp;
 $2 = sp + 32|0;
 $3 = sp + 12|0;
 $4 = ($1|0)==(0|0);
 if ($4) {
  $29 = ((($0)) + 16|0);
  ;HEAP32[$2>>2]=HEAP32[$29>>2]|0;HEAP32[$2+4>>2]=HEAP32[$29+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$29+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$29+12>>2]|0;HEAP32[$2+16>>2]=HEAP32[$29+16>>2]|0;
 } else {
  ;HEAP32[$2>>2]=HEAP32[$1>>2]|0;HEAP32[$2+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$1+12>>2]|0;HEAP32[$2+16>>2]=HEAP32[$1+16>>2]|0;
  $5 = HEAP32[$2>>2]|0;
  $6 = ($5|0)==(0);
  if ($6) {
   $7 = ((($0)) + 36|0);
   $8 = HEAP32[$7>>2]|0;
   HEAP32[$2>>2] = $8;
  }
  $9 = ((($2)) + 4|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10|0)==(0);
  if ($11) {
   $12 = ((($0)) + 40|0);
   $13 = HEAP32[$12>>2]|0;
   HEAP32[$9>>2] = $13;
  }
  $14 = ((($2)) + 8|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = ($15|0)==(0);
  if ($16) {
   $17 = ((($0)) + 44|0);
   $18 = HEAP32[$17>>2]|0;
   HEAP32[$14>>2] = $18;
  }
  $19 = ((($2)) + 12|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = ($20|0)==(0);
  if ($21) {
   $22 = ((($0)) + 48|0);
   $23 = HEAP32[$22>>2]|0;
   HEAP32[$19>>2] = $23;
  }
  $24 = (_SDL_GetClosestDisplayModeForDisplay($0,$2,$2)|0);
  $25 = ($24|0)==(0|0);
  if ($25) {
   $26 = HEAP32[$9>>2]|0;
   $27 = HEAP32[$14>>2]|0;
   HEAP32[$vararg_buffer>>2] = $26;
   $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
   HEAP32[$vararg_ptr1>>2] = $27;
   $28 = (_SDL_SetError(182191,$vararg_buffer)|0);
   $$0 = $28;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $30 = ((($0)) + 36|0);
 ;HEAP32[$3>>2]=HEAP32[$30>>2]|0;HEAP32[$3+4>>2]=HEAP32[$30+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$30+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$30+12>>2]|0;HEAP32[$3+16>>2]=HEAP32[$30+16>>2]|0;
 $31 = (_SDL_memcmp($2,$3,20)|0);
 $32 = ($31|0)==(0);
 if ($32) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $33 = HEAP32[52375]|0;
 $34 = ((($33)) + 28|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = ($35|0)==(0|0);
 if ($36) {
  $37 = (_SDL_SetError(182140,$vararg_buffer2)|0);
  $$0 = $37;
  STACKTOP = sp;return ($$0|0);
 }
 $38 = (FUNCTION_TABLE_iiii[$35 & 8191]($33,$0,$2)|0);
 $39 = ($38|0)<(0);
 if ($39) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 ;HEAP32[$30>>2]=HEAP32[$2>>2]|0;HEAP32[$30+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$30+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$30+12>>2]=HEAP32[$2+12>>2]|0;HEAP32[$30+16>>2]=HEAP32[$2+16>>2]|0;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _SDL_GetMouseFocus() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[(209568)>>2]|0;
 return ($0|0);
}
function _SDL_GetMouseState($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($0|0)==(0|0);
 if (!($2)) {
  $3 = HEAP32[(209572)>>2]|0;
  HEAP32[$0>>2] = $3;
 }
 $4 = ($1|0)==(0|0);
 if (!($4)) {
  $5 = HEAP32[(209576)>>2]|0;
  HEAP32[$1>>2] = $5;
 }
 $6 = HEAP32[(209596)>>2]|0;
 return ($6|0);
}
function _SDL_GetClosestDisplayModeForDisplay($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$0$ = 0, $$089 = 0, $$090 = 0, $$091 = 0, $$092 = 0, $$1 = 0, $$pre = 0, $$pre$i = 0, $$sink7 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $or$cond = 0, $or$cond93 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $3 = ($1|0)!=(0|0);
 $4 = ($2|0)!=(0|0);
 $or$cond = $3 & $4;
 if (!($or$cond)) {
  (_SDL_SetError(182228,$vararg_buffer)|0);
  $$089 = 0;
  STACKTOP = sp;return ($$089|0);
 }
 $5 = HEAP32[$1>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  $7 = ((($0)) + 16|0);
  $8 = HEAP32[$7>>2]|0;
  $$092 = $8;
 } else {
  $$092 = $5;
 }
 $9 = ((($1)) + 12|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0);
 if ($11) {
  $12 = ((($0)) + 28|0);
  $13 = HEAP32[$12>>2]|0;
  $$091 = $13;
 } else {
  $$091 = $10;
 }
 $14 = ((($1)) + 4|0);
 $15 = ((($0)) + 8|0);
 $16 = ((($0)) + 12|0);
 $17 = $$092 >>> 8;
 $18 = $17 & 255;
 $19 = ((($1)) + 8|0);
 $$pre = HEAP32[$15>>2]|0;
 $$0 = 0;$$090 = 0;$20 = $$pre;
 while(1) {
  $21 = ($20|0)==(0);
  if ($21) {
   $22 = HEAP32[52375]|0;
   $23 = ((($22)) + 24|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = ($24|0)==(0|0);
   if ($25) {
    $29 = 0;
   } else {
    FUNCTION_TABLE_vii[$24 & 8191]($22,$0);
    $26 = HEAP32[$16>>2]|0;
    $27 = HEAP32[$15>>2]|0;
    _SDL_qsort($26,$27,20,4325);
    $$pre$i = HEAP32[$15>>2]|0;
    $29 = $$pre$i;
   }
  } else {
   $29 = $20;
  }
  $28 = ($$090|0)<($29|0);
  if (!($28)) {
   break;
  }
  $30 = HEAP32[$16>>2]|0;
  $31 = (($30) + (($$090*20)|0)|0);
  $32 = (((($30) + (($$090*20)|0)|0)) + 4|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = ($33|0)!=(0);
  if ($34) {
   $35 = HEAP32[$14>>2]|0;
   $36 = ($33|0)<($35|0);
   if ($36) {
    break;
   }
  }
  $37 = (((($30) + (($$090*20)|0)|0)) + 8|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = ($38|0)==(0);
  if ($39) {
   label = 18;
  } else {
   $40 = HEAP32[$19>>2]|0;
   $41 = ($38|0)<($40|0);
   if ($41) {
    if ($34) {
     $42 = HEAP32[$14>>2]|0;
     $43 = ($33|0)==($42|0);
     if ($43) {
      break;
     } else {
      $$1 = $$0;
     }
    } else {
     $$1 = $$0;
    }
   } else {
    label = 18;
   }
  }
  do {
   if ((label|0) == 18) {
    label = 0;
    $44 = ($$0|0)==(0|0);
    if ($44) {
     $$1 = $31;
    } else {
     $45 = ((($$0)) + 4|0);
     $46 = HEAP32[$45>>2]|0;
     $47 = ($33|0)<($46|0);
     if ($47) {
      $$1 = $31;
     } else {
      $48 = ((($$0)) + 8|0);
      $49 = HEAP32[$48>>2]|0;
      $50 = ($38|0)<($49|0);
      if ($50) {
       $$1 = $31;
      } else {
       $51 = HEAP32[$31>>2]|0;
       $52 = HEAP32[$$0>>2]|0;
       $53 = ($51|0)==($52|0);
       if ($53) {
        $61 = (((($30) + (($$090*20)|0)|0)) + 12|0);
        $62 = HEAP32[$61>>2]|0;
        $63 = ((($$0)) + 12|0);
        $64 = HEAP32[$63>>2]|0;
        $65 = ($62|0)==($64|0);
        $66 = ($62|0)<($$091|0);
        $or$cond93 = $66 | $65;
        $$0$ = $or$cond93 ? $$0 : $31;
        $$1 = $$0$;
        break;
       }
       $54 = ($51|0)==($$092|0);
       if (!($54)) {
        $55 = $51 >>> 8;
        $56 = $55 & 255;
        $57 = ($56>>>0)<($18>>>0);
        if ($57) {
         $$1 = $$0;
         break;
        }
        $58 = $51 ^ $$092;
        $59 = $58 & 251658240;
        $60 = ($59|0)==(0);
        if (!($60)) {
         $$1 = $$0;
         break;
        }
       }
       $$1 = $31;
      }
     }
    }
   }
  } while(0);
  $67 = (($$090) + 1)|0;
  $$0 = $$1;$$090 = $67;$20 = $29;
 }
 $68 = ($$0|0)==(0|0);
 if ($68) {
  $$089 = 0;
  STACKTOP = sp;return ($$089|0);
 }
 $69 = HEAP32[$$0>>2]|0;
 $70 = ($69|0)==(0);
 if ($70) {
  $71 = HEAP32[$1>>2]|0;
  $72 = $71;
 } else {
  $72 = $69;
 }
 HEAP32[$2>>2] = $72;
 $73 = ((($$0)) + 4|0);
 $74 = HEAP32[$73>>2]|0;
 $75 = ($74|0)==(0);
 if ($75) {
  label = 34;
 } else {
  $76 = ((($$0)) + 8|0);
  $77 = HEAP32[$76>>2]|0;
  $78 = ($77|0)==(0);
  if ($78) {
   label = 34;
  } else {
   $79 = ((($2)) + 4|0);
   HEAP32[$79>>2] = $74;
   $84 = $77;$94 = $74;
  }
 }
 if ((label|0) == 34) {
  $80 = HEAP32[$14>>2]|0;
  $81 = ((($2)) + 4|0);
  HEAP32[$81>>2] = $80;
  $82 = HEAP32[$19>>2]|0;
  $84 = $82;$94 = $80;
 }
 $83 = ((($2)) + 8|0);
 HEAP32[$83>>2] = $84;
 $85 = ((($$0)) + 12|0);
 $86 = HEAP32[$85>>2]|0;
 $87 = ($86|0)==(0);
 if ($87) {
  $88 = HEAP32[$9>>2]|0;
  $$sink7 = $88;
 } else {
  $$sink7 = $86;
 }
 $89 = ((($2)) + 12|0);
 HEAP32[$89>>2] = $$sink7;
 $90 = ((($$0)) + 16|0);
 $91 = HEAP32[$90>>2]|0;
 $92 = ((($2)) + 16|0);
 HEAP32[$92>>2] = $91;
 $93 = ($72|0)==(0);
 if ($93) {
  HEAP32[$2>>2] = 370546692;
 }
 $95 = ($94|0)==(0);
 if ($95) {
  $96 = ((($2)) + 4|0);
  HEAP32[$96>>2] = 640;
 }
 $97 = ($84|0)==(0);
 if (!($97)) {
  $$089 = $2;
  STACKTOP = sp;return ($$089|0);
 }
 HEAP32[$83>>2] = 480;
 $$089 = $2;
 STACKTOP = sp;return ($$089|0);
}
function _cmpmodes($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$ = 0, $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($0|0)==($1|0);
 if ($2) {
  $$0 = 0;
  return ($$0|0);
 }
 $3 = ((($0)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($1)) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==($4|0);
 if (!($7)) {
  $8 = (($6) - ($4))|0;
  $$0 = $8;
  return ($$0|0);
 }
 $9 = ((($0)) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ((($1)) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==($10|0);
 if (!($13)) {
  $14 = (($12) - ($10))|0;
  $$0 = $14;
  return ($$0|0);
 }
 $15 = HEAP32[$0>>2]|0;
 $16 = $15 >>> 8;
 $17 = $16 & 255;
 $18 = HEAP32[$1>>2]|0;
 $19 = $18 >>> 8;
 $20 = $19 & 255;
 $21 = ($20|0)==($17|0);
 if (!($21)) {
  $22 = (($20) - ($17))|0;
  $$0 = $22;
  return ($$0|0);
 }
 $23 = $15 >>> 16;
 $24 = $23 & 15;
 $25 = $18 >>> 16;
 $26 = $25 & 15;
 $27 = ($26|0)==($24|0);
 if ($27) {
  $29 = ((($0)) + 12|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = ((($1)) + 12|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = ($32|0)==($30|0);
  $34 = (($32) - ($30))|0;
  $$ = $33 ? 0 : $34;
  return ($$|0);
 }
 $28 = (($26) - ($24))|0;
 $$0 = $28;
 return ($$0|0);
}
function _SDL_qsort($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 _qsort($0,$1,$2,$3);
 return;
}
function _SDL_GetDisplayBounds($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$1 = 0, $$pre = 0, $$pre$phiZ2D = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $2 = HEAP32[52375]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  (_SDL_SetError(175439,$vararg_buffer)|0);
  $$1 = -1;
  STACKTOP = sp;return ($$1|0);
 }
 $4 = ($0|0)>(-1);
 $5 = ((($2)) + 264|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)>($0|0);
 $or$cond = $4 & $7;
 if (!($or$cond)) {
  $8 = (($6) + -1)|0;
  HEAP32[$vararg_buffer1>>2] = $8;
  (_SDL_SetError(182353,$vararg_buffer1)|0);
  $$1 = -1;
  STACKTOP = sp;return ($$1|0);
 }
 $9 = ($1|0)==(0|0);
 if ($9) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $10 = ((($2)) + 268|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($2)) + 12|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0|0);
 if (!($14)) {
  $15 = (($11) + (($0*68)|0)|0);
  $16 = (FUNCTION_TABLE_iiii[$13 & 8191]($2,$15,$1)|0);
  $17 = ($16|0)==(0);
  if ($17) {
   $$1 = 0;
   STACKTOP = sp;return ($$1|0);
  }
 }
 $18 = ($0|0)==(0);
 if ($18) {
  HEAP32[$1>>2] = 0;
  $19 = ((($1)) + 4|0);
  HEAP32[$19>>2] = 0;
  $$pre = ((($1)) + 8|0);
  $$pre$phiZ2D = $$pre;
 } else {
  $20 = (($0) + -1)|0;
  (_SDL_GetDisplayBounds($20,$1)|0);
  $21 = ((($1)) + 8|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = HEAP32[$1>>2]|0;
  $24 = (($23) + ($22))|0;
  HEAP32[$1>>2] = $24;
  $$pre$phiZ2D = $21;
 }
 $25 = (((($11) + (($0*68)|0)|0)) + 40|0);
 $26 = HEAP32[$25>>2]|0;
 HEAP32[$$pre$phiZ2D>>2] = $26;
 $27 = (((($11) + (($0*68)|0)|0)) + 44|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = ((($1)) + 12|0);
 HEAP32[$29>>2] = $28;
 $$1 = 0;
 STACKTOP = sp;return ($$1|0);
}
function _SDL_EnclosePoints($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$$0103 = 0, $$$0115 = 0, $$$097 = 0, $$$3118 = 0, $$$4107 = 0, $$0103142 = 0, $$0110141 = 0, $$0113140 = 0, $$0113140$us = 0, $$0115$$$0115 = 0, $$0115139 = 0, $$095144 = 0, $$097143 = 0, $$1 = 0, $$1104 = 0, $$1111 = 0, $$1114132 = 0, $$1116 = 0, $$196 = 0, $$198 = 0;
 var $$2 = 0, $$2105 = 0, $$3100134 = 0, $$3118131 = 0, $$4101 = 0, $$4107133 = 0, $$4119 = 0, $$4135 = 0, $$5 = 0, $$5102 = 0, $$5102156 = 0, $$5108 = 0, $$5120 = 0, $$5120154 = 0, $$6 = 0, $$6109 = 0, $$6109155 = 0, $$6157 = 0, $10 = 0, $11 = 0;
 var $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $exitcond152 = 0, $not$ = 0, $notlhs = 0, $notlhs$us = 0;
 var $notrhs = 0, $notrhs$us = 0, $or$cond$not = 0, $or$cond$not$us = 0, $or$cond121 = 0, $or$cond121$not = 0, $or$cond121$not$us = 0, $or$cond121$us = 0, $or$cond122 = 0, $or$cond122$us = 0, $or$cond125 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $4 = ($0|0)==(0|0);
 if ($4) {
  HEAP32[$vararg_buffer>>2] = 182340;
  (_SDL_SetError(194740,$vararg_buffer)|0);
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $5 = ($1|0)<(1);
 if ($5) {
  HEAP32[$vararg_buffer1>>2] = 182347;
  (_SDL_SetError(194740,$vararg_buffer1)|0);
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $6 = ($2|0)==(0|0);
 if ($6) {
  $39 = ($3|0)==(0|0);
  if ($39) {
   $$1 = 1;
   STACKTOP = sp;return ($$1|0);
  }
  $40 = HEAP32[$0>>2]|0;
  $41 = ((($0)) + 4|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = ($1|0)>(1);
  if ($43) {
   $$1114132 = 1;$$3100134 = $42;$$3118131 = $42;$$4107133 = $40;$$4135 = $40;
   while(1) {
    $44 = (($0) + ($$1114132<<3)|0);
    $45 = HEAP32[$44>>2]|0;
    $46 = (((($0) + ($$1114132<<3)|0)) + 4|0);
    $47 = HEAP32[$46>>2]|0;
    $48 = ($45|0)<($$4135|0);
    $49 = ($45|0)>($$4107133|0);
    $$$4107 = $49 ? $45 : $$4107133;
    $$5108 = $48 ? $$4107133 : $$$4107;
    $$5 = $48 ? $45 : $$4135;
    $50 = ($47|0)<($$3100134|0);
    $51 = ($47|0)>($$3118131|0);
    $$$3118 = $51 ? $47 : $$3118131;
    $$4119 = $50 ? $$3118131 : $$$3118;
    $$4101 = $50 ? $47 : $$3100134;
    $52 = (($$1114132) + 1)|0;
    $exitcond = ($52|0)==($1|0);
    if ($exitcond) {
     $$5102 = $$4101;$$5120 = $$4119;$$6 = $$5;$$6109 = $$5108;
     label = 18;
     break;
    } else {
     $$1114132 = $52;$$3100134 = $$4101;$$3118131 = $$4119;$$4107133 = $$5108;$$4135 = $$5;
    }
   }
  } else {
   $$5102156 = $42;$$5120154 = $42;$$6109155 = $40;$$6157 = $40;
  }
 } else {
  $7 = HEAP32[$2>>2]|0;
  $8 = ((($2)) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ((($2)) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (($11) + ($7))|0;
  $13 = ((($2)) + 12|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($14) + ($9))|0;
  $16 = ($11|0)>(0);
  $17 = ($14|0)>(0);
  $or$cond125 = $16 & $17;
  if (!($or$cond125)) {
   $$1 = 0;
   STACKTOP = sp;return ($$1|0);
  }
  $18 = ($3|0)==(0|0);
  if ($18) {
   $$0113140$us = 0;
   while(1) {
    $19 = (($0) + ($$0113140$us<<3)|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = (((($0) + ($$0113140$us<<3)|0)) + 4|0);
    $22 = HEAP32[$21>>2]|0;
    $notlhs$us = ($20|0)<($7|0);
    $notrhs$us = ($20|0)>=($12|0);
    $or$cond$not$us = $notrhs$us | $notlhs$us;
    $23 = ($22|0)<($9|0);
    $or$cond121$us = $or$cond$not$us | $23;
    $or$cond121$not$us = $or$cond121$us ^ 1;
    $24 = ($22|0)<($15|0);
    $or$cond122$us = $24 & $or$cond121$not$us;
    if ($or$cond122$us) {
     $$1 = 1;
     label = 20;
     break;
    }
    $25 = (($$0113140$us) + 1)|0;
    $26 = ($25|0)<($1|0);
    if ($26) {
     $$0113140$us = $25;
    } else {
     $$1 = 0;
     label = 20;
     break;
    }
   }
   if ((label|0) == 20) {
    STACKTOP = sp;return ($$1|0);
   }
  } else {
   $$0103142 = 0;$$0110141 = 0;$$0113140 = 0;$$0115139 = 0;$$095144 = 0;$$097143 = 0;
  }
  while(1) {
   $27 = (($0) + ($$0113140<<3)|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = (((($0) + ($$0113140<<3)|0)) + 4|0);
   $30 = HEAP32[$29>>2]|0;
   $notlhs = ($28|0)<($7|0);
   $notrhs = ($28|0)>=($12|0);
   $or$cond$not = $notrhs | $notlhs;
   $31 = ($30|0)<($9|0);
   $or$cond121 = $or$cond$not | $31;
   $or$cond121$not = $or$cond121 ^ 1;
   $32 = ($30|0)<($15|0);
   $or$cond122 = $32 & $or$cond121$not;
   if ($or$cond122) {
    $33 = ($$0110141|0)==(0);
    if ($33) {
     $$1111 = 1;$$1116 = $30;$$198 = $30;$$2 = $28;$$2105 = $28;
    } else {
     $34 = ($28|0)<($$095144|0);
     $35 = ($28|0)>($$0103142|0);
     $$$0103 = $35 ? $28 : $$0103142;
     $$1104 = $34 ? $$0103142 : $$$0103;
     $$196 = $34 ? $28 : $$095144;
     $36 = ($30|0)<($$097143|0);
     $37 = ($30|0)>($$0115139|0);
     $$$0115 = $37 ? $30 : $$0115139;
     $$0115$$$0115 = $36 ? $$0115139 : $$$0115;
     $$$097 = $36 ? $30 : $$097143;
     $$1111 = $$0110141;$$1116 = $$0115$$$0115;$$198 = $$$097;$$2 = $$196;$$2105 = $$1104;
    }
   } else {
    $$1111 = $$0110141;$$1116 = $$0115139;$$198 = $$097143;$$2 = $$095144;$$2105 = $$0103142;
   }
   $38 = (($$0113140) + 1)|0;
   $exitcond152 = ($38|0)==($1|0);
   if ($exitcond152) {
    break;
   } else {
    $$0103142 = $$2105;$$0110141 = $$1111;$$0113140 = $38;$$0115139 = $$1116;$$095144 = $$2;$$097143 = $$198;
   }
  }
  $not$ = ($$1111|0)==(0);
  if ($not$) {
   $$1 = 0;
   STACKTOP = sp;return ($$1|0);
  } else {
   $$5102 = $$198;$$5120 = $$1116;$$6 = $$2;$$6109 = $$2105;
   label = 18;
  }
 }
 if ((label|0) == 18) {
  $53 = ($3|0)==(0|0);
  if ($53) {
   $$1 = 1;
   STACKTOP = sp;return ($$1|0);
  } else {
   $$5102156 = $$5102;$$5120154 = $$5120;$$6109155 = $$6109;$$6157 = $$6;
  }
 }
 $54 = ((($3)) + 12|0);
 $55 = (($$5120154) + 1)|0;
 $56 = (($55) - ($$5102156))|0;
 $57 = ((($3)) + 8|0);
 $58 = (($$6109155) + 1)|0;
 $59 = (($58) - ($$6157))|0;
 $60 = ((($3)) + 4|0);
 HEAP32[$3>>2] = $$6157;
 HEAP32[$60>>2] = $$5102156;
 HEAP32[$57>>2] = $59;
 HEAP32[$54>>2] = $56;
 $$1 = 1;
 STACKTOP = sp;return ($$1|0);
}
function _SW_CreateRenderer($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_SDL_GetWindowSurface($0)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  $$0 = 0;
  return ($$0|0);
 }
 $4 = (_SW_CreateRendererForSurface($2)|0);
 $$0 = $4;
 return ($$0|0);
}
function _SDL_GetWindowSurface($0) {
 $0 = $0|0;
 var $$0 = 0, $$pre = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $1 = sp + 40|0;
 $2 = sp + 36|0;
 $3 = sp + 32|0;
 $4 = sp + 28|0;
 $5 = sp + 24|0;
 $6 = sp + 20|0;
 $7 = sp + 16|0;
 $8 = sp + 12|0;
 $9 = HEAP32[52375]|0;
 $10 = ($9|0)==(0|0);
 if ($10) {
  (_SDL_SetError(175439,$vararg_buffer)|0);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $11 = ($0|0)==(0|0);
 if (!($11)) {
  $12 = HEAP32[$0>>2]|0;
  $13 = ((($9)) + 280|0);
  $14 = ($12|0)==($13|0);
  if ($14) {
   $15 = ((($0)) + 112|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ($16|0)==(0);
   $18 = ((($0)) + 108|0);
   $19 = HEAP32[$18>>2]|0;
   if (!($17)) {
    $$0 = $19;
    STACKTOP = sp;return ($$0|0);
   }
   $20 = ($19|0)==(0|0);
   if ($20) {
    $24 = $9;
   } else {
    $21 = HEAP32[$19>>2]|0;
    $22 = $21 & -5;
    HEAP32[$19>>2] = $22;
    _SDL_FreeSurface($19);
    $$pre = HEAP32[52375]|0;
    $24 = $$pre;
   }
   $23 = ((($24)) + 132|0);
   $25 = HEAP32[$23>>2]|0;
   $26 = ($25|0)==(0|0);
   if ($26) {
    $47 = 0;
   } else {
    $27 = ((($24)) + 136|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = ($28|0)==(0|0);
    if ($29) {
     $47 = 0;
    } else {
     $30 = (FUNCTION_TABLE_iiiiii[$25 & 8191]($24,$0,$1,$2,$3)|0);
     $31 = ($30|0)<(0);
     if ($31) {
      $47 = 0;
     } else {
      $32 = HEAP32[$1>>2]|0;
      $33 = (_SDL_PixelFormatEnumToMasks($32,$4,$5,$6,$7,$8)|0);
      $34 = ($33|0)==(0);
      if ($34) {
       $47 = 0;
      } else {
       $35 = HEAP32[$2>>2]|0;
       $36 = ((($0)) + 24|0);
       $37 = HEAP32[$36>>2]|0;
       $38 = ((($0)) + 28|0);
       $39 = HEAP32[$38>>2]|0;
       $40 = HEAP32[$4>>2]|0;
       $41 = HEAP32[$3>>2]|0;
       $42 = HEAP32[$5>>2]|0;
       $43 = HEAP32[$6>>2]|0;
       $44 = HEAP32[$7>>2]|0;
       $45 = HEAP32[$8>>2]|0;
       $46 = (_SDL_CreateRGBSurfaceFrom($35,$37,$39,$40,$41,$42,$43,$44,$45)|0);
       $47 = $46;
      }
     }
    }
   }
   HEAP32[$18>>2] = $47;
   $48 = ($47|0)==(0|0);
   if ($48) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$15>>2] = 1;
   $49 = HEAP32[$47>>2]|0;
   $50 = $49 | 4;
   HEAP32[$47>>2] = $50;
   $$0 = $47;
   STACKTOP = sp;return ($$0|0);
  }
 }
 (_SDL_SetError(195204,$vararg_buffer1)|0);
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _SW_CreateRendererForSurface($0) {
 $0 = $0|0;
 var $$0 = 0, $$pre$i = 0, $$pre16$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $1 = ($0|0)==(0|0);
 if ($1) {
  (_SDL_SetError(182657,$vararg_buffer)|0);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = (_SDL_calloc(1,324)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  (_SDL_Error(0)|0);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = (_SDL_calloc(1,8)|0);
 $5 = ($4|0)==(0|0);
 if ($5) {
  $6 = ((($2)) + 320|0);
  $7 = HEAP32[$6>>2]|0;
  _SDL_free($7);
  _SDL_free($2);
  (_SDL_Error(0)|0);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$4>>2] = $0;
 $8 = ((($4)) + 4|0);
 HEAP32[$8>>2] = $0;
 $9 = ((($2)) + 4|0);
 HEAP32[$9>>2] = 4326;
 $10 = ((($2)) + 8|0);
 HEAP32[$10>>2] = 4327;
 $11 = ((($2)) + 12|0);
 HEAP32[$11>>2] = 4328;
 $12 = ((($2)) + 16|0);
 HEAP32[$12>>2] = 4329;
 $13 = ((($2)) + 20|0);
 HEAP32[$13>>2] = 4330;
 $14 = ((($2)) + 24|0);
 HEAP32[$14>>2] = 4331;
 $15 = ((($2)) + 28|0);
 HEAP32[$15>>2] = 4332;
 $16 = ((($2)) + 36|0);
 HEAP32[$16>>2] = 4333;
 $17 = ((($2)) + 40|0);
 HEAP32[$17>>2] = 4334;
 $18 = ((($2)) + 44|0);
 HEAP32[$18>>2] = 4335;
 $19 = ((($2)) + 48|0);
 HEAP32[$19>>2] = 4336;
 $20 = ((($2)) + 52|0);
 HEAP32[$20>>2] = 4337;
 $21 = ((($2)) + 56|0);
 HEAP32[$21>>2] = 4338;
 $22 = ((($2)) + 60|0);
 HEAP32[$22>>2] = 4339;
 $23 = ((($2)) + 64|0);
 HEAP32[$23>>2] = 4340;
 $24 = ((($2)) + 68|0);
 HEAP32[$24>>2] = 4341;
 $25 = ((($2)) + 72|0);
 HEAP32[$25>>2] = 4342;
 $26 = ((($2)) + 76|0);
 HEAP32[$26>>2] = 4343;
 $27 = ((($2)) + 80|0);
 HEAP32[$27>>2] = 4344;
 $28 = ((($2)) + 84|0);
 HEAP32[$28>>2] = 4345;
 $29 = ((($2)) + 88|0);
 HEAP32[$29>>2] = 4346;
 $30 = ((($2)) + 92|0);
 HEAP32[$30>>2] = 4347;
 $31 = ((($2)) + 104|0);
 dest=$31; src=(88664); stop=dest+84|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $32 = ((($2)) + 320|0);
 HEAP32[$32>>2] = $4;
 $33 = HEAP32[$4>>2]|0;
 $34 = ($33|0)==(0|0);
 if (!($34)) {
  $$0 = $2;
  STACKTOP = sp;return ($$0|0);
 }
 $35 = HEAP32[$8>>2]|0;
 HEAP32[$4>>2] = $35;
 $36 = ($35|0)==(0);
 if (!($36)) {
  $$0 = $2;
  STACKTOP = sp;return ($$0|0);
 }
 $37 = ((($2)) + 188|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (_SDL_GetWindowSurface($38)|0);
 $40 = ($39|0)==(0|0);
 if ($40) {
  $$0 = $2;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$8>>2] = $39;
 HEAP32[$4>>2] = $39;
 $41 = HEAP32[$32>>2]|0;
 $42 = HEAP32[$41>>2]|0;
 $43 = ($42|0)==(0|0);
 if ($43) {
  $$0 = $2;
  STACKTOP = sp;return ($$0|0);
 }
 $44 = ((($2)) + 216|0);
 (_SDL_SetClipRect($42,$44)|0);
 $$pre$i = HEAP32[$32>>2]|0;
 $$pre16$i = HEAP32[$$pre$i>>2]|0;
 $45 = ($$pre16$i|0)==(0|0);
 if ($45) {
  $$0 = $2;
  STACKTOP = sp;return ($$0|0);
 }
 $46 = ((($2)) + 280|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = ($47|0)==(0);
 if ($48) {
  (_SDL_SetClipRect($$pre16$i,0)|0);
  $$0 = $2;
  STACKTOP = sp;return ($$0|0);
 } else {
  $49 = ((($2)) + 248|0);
  (_SDL_SetClipRect($$pre16$i,$49)|0);
  $$0 = $2;
  STACKTOP = sp;return ($$0|0);
 }
 return (0)|0;
}
function _SW_WindowEvent($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 320|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($1)) + 12|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)==(6);
 if (!($6)) {
  return;
 }
 HEAP32[$3>>2] = 0;
 $7 = ((($3)) + 4|0);
 HEAP32[$7>>2] = 0;
 return;
}
function _SW_GetOutputSize($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$pr = 0, $$pre$i = 0, $$pre16$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $3 = ((($0)) + 320|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 L1: do {
  if ($6) {
   $7 = ((($4)) + 4|0);
   $8 = HEAP32[$7>>2]|0;
   HEAP32[$4>>2] = $8;
   $9 = ($8|0)==(0);
   $10 = $8;
   if ($9) {
    $11 = ((($0)) + 188|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (_SDL_GetWindowSurface($12)|0);
    $14 = ($13|0)==(0|0);
    do {
     if (!($14)) {
      HEAP32[$7>>2] = $13;
      HEAP32[$4>>2] = $13;
      $15 = HEAP32[$3>>2]|0;
      $16 = HEAP32[$15>>2]|0;
      $17 = ($16|0)==(0|0);
      if ($17) {
       $28 = $13;
       break L1;
      }
      $18 = ((($0)) + 216|0);
      (_SDL_SetClipRect($16,$18)|0);
      $$pre$i = HEAP32[$3>>2]|0;
      $$pre16$i = HEAP32[$$pre$i>>2]|0;
      $19 = ($$pre16$i|0)==(0|0);
      if (!($19)) {
       $20 = ((($0)) + 280|0);
       $21 = HEAP32[$20>>2]|0;
       $22 = ($21|0)==(0);
       if ($22) {
        (_SDL_SetClipRect($$pre16$i,0)|0);
        break;
       } else {
        $23 = ((($0)) + 248|0);
        (_SDL_SetClipRect($$pre16$i,$23)|0);
        break;
       }
      }
     }
    } while(0);
    $$pr = HEAP32[$4>>2]|0;
    $24 = $$pr;
   } else {
    $24 = $10;
   }
   $25 = ($24|0)==(0|0);
   if ($25) {
    (_SDL_SetError(183737,$vararg_buffer)|0);
    $$0 = -1;
    STACKTOP = sp;return ($$0|0);
   } else {
    $28 = $24;
   }
  } else {
   $28 = $5;
  }
 } while(0);
 $26 = ($1|0)==(0|0);
 if (!($26)) {
  $27 = ((($28)) + 8|0);
  $29 = HEAP32[$27>>2]|0;
  HEAP32[$1>>2] = $29;
 }
 $30 = ($2|0)==(0|0);
 if ($30) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $31 = ((($28)) + 12|0);
 $32 = HEAP32[$31>>2]|0;
 HEAP32[$2>>2] = $32;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _SW_CreateTexture($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$ = 0, $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $vararg_buffer = sp;
 $2 = sp + 20|0;
 $3 = sp + 16|0;
 $4 = sp + 12|0;
 $5 = sp + 8|0;
 $6 = sp + 4|0;
 $7 = ((($1)) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (_SDL_PixelFormatEnumToMasks($8,$2,$3,$4,$5,$6)|0);
 $10 = ($9|0)==(0);
 if ($10) {
  $11 = (_SDL_SetError(183714,$vararg_buffer)|0);
  $$0 = $11;
  STACKTOP = sp;return ($$0|0);
 }
 $12 = ((($1)) + 12|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($1)) + 16|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP32[$2>>2]|0;
 $17 = HEAP32[$3>>2]|0;
 $18 = HEAP32[$4>>2]|0;
 $19 = HEAP32[$5>>2]|0;
 $20 = HEAP32[$6>>2]|0;
 $21 = (_SDL_CreateRGBSurface(0,$13,$15,$16,$17,$18,$19,$20)|0);
 $22 = ((($1)) + 68|0);
 HEAP32[$22>>2] = $21;
 $23 = ((($1)) + 28|0);
 $24 = HEAP8[$23>>0]|0;
 $25 = ((($1)) + 29|0);
 $26 = HEAP8[$25>>0]|0;
 $27 = ((($1)) + 30|0);
 $28 = HEAP8[$27>>0]|0;
 (_SDL_SetSurfaceColorMod($21,$24,$26,$28)|0);
 $29 = HEAP32[$22>>2]|0;
 $30 = ((($1)) + 31|0);
 $31 = HEAP8[$30>>0]|0;
 (_SDL_SetSurfaceAlphaMod($29,$31)|0);
 $32 = HEAP32[$22>>2]|0;
 $33 = ((($1)) + 24|0);
 $34 = HEAP32[$33>>2]|0;
 (_SDL_SetSurfaceBlendMode($32,$34)|0);
 $35 = ((($1)) + 8|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = ($36|0)==(0);
 if ($37) {
  $38 = HEAP32[$22>>2]|0;
  (_SDL_SetSurfaceRLE($38,1)|0);
 }
 $39 = HEAP32[$22>>2]|0;
 $40 = ($39|0)==(0|0);
 $$ = $40 << 31 >> 31;
 $$0 = $$;
 STACKTOP = sp;return ($$0|0);
}
function _SW_SetTextureColorMod($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$pre = 0, $$pre10 = 0, $$pre11 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 68|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($1)) + 28|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ((($1)) + 29|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7 & $5;
 $9 = ((($1)) + 30|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $8 & $10;
 $12 = ($11<<24>>24)==(-1);
 if ($12) {
  $13 = $5;$14 = $7;$15 = $10;
  $16 = (_SDL_SetSurfaceColorMod($3,$13,$14,$15)|0);
  return ($16|0);
 }
 (_SDL_SetSurfaceRLE($3,0)|0);
 $$pre = HEAP8[$4>>0]|0;
 $$pre10 = HEAP8[$6>>0]|0;
 $$pre11 = HEAP8[$9>>0]|0;
 $13 = $$pre;$14 = $$pre10;$15 = $$pre11;
 $16 = (_SDL_SetSurfaceColorMod($3,$13,$14,$15)|0);
 return ($16|0);
}
function _SW_SetTextureAlphaMod($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$pre = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 68|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($1)) + 31|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)==(-1);
 if ($6) {
  $12 = -1;
 } else {
  $7 = ((($3)) + 4|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ((($8)) + 24|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10|0)==(0);
  if ($11) {
   $12 = $5;
  } else {
   (_SDL_SetSurfaceRLE($3,0)|0);
   $$pre = HEAP8[$4>>0]|0;
   $12 = $$pre;
  }
 }
 $13 = (_SDL_SetSurfaceAlphaMod($3,$12)|0);
 return ($13|0);
}
function _SW_SetTextureBlendMode($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$pre = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 68|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($1)) + 24|0);
 $5 = HEAP32[$4>>2]|0;
 switch ($5|0) {
 case 4: case 2:  {
  (_SDL_SetSurfaceRLE($3,0)|0);
  $$pre = HEAP32[$4>>2]|0;
  $6 = $$pre;
  break;
 }
 default: {
  $6 = $5;
 }
 }
 $7 = (_SDL_SetSurfaceBlendMode($3,$6)|0);
 return ($7|0);
}
function _SW_UpdateTexture($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$03134 = 0, $$03233 = 0, $$035 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $5 = ((($1)) + 68|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 & 2;
 $9 = ($8|0)==(0);
 if (!($9)) {
  (_SDL_LockSurface($6)|0);
 }
 $10 = ((($6)) + 16|0);
 $11 = ((($6)) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ((($12)) + 9|0);
 $14 = HEAP8[$13>>0]|0;
 $15 = $14&255;
 $16 = ((($2)) + 8|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = Math_imul($17, $15)|0;
 $19 = ((($2)) + 12|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)>(0);
 if ($21) {
  $22 = ((($6)) + 20|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = HEAP32[$10>>2]|0;
  $25 = ((($2)) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = Math_imul($24, $26)|0;
  $28 = (($23) + ($27)|0);
  $29 = HEAP32[$2>>2]|0;
  $30 = Math_imul($15, $29)|0;
  $31 = (($28) + ($30)|0);
  $$03134 = 0;$$03233 = $31;$$035 = $3;
  while(1) {
   (_SDL_memcpy($$03233,$$035,$18)|0);
   $32 = (($$035) + ($4)|0);
   $33 = HEAP32[$10>>2]|0;
   $34 = (($$03233) + ($33)|0);
   $35 = (($$03134) + 1)|0;
   $36 = HEAP32[$19>>2]|0;
   $37 = ($35|0)<($36|0);
   if ($37) {
    $$03134 = $35;$$03233 = $34;$$035 = $32;
   } else {
    break;
   }
  }
 }
 $38 = HEAP32[$6>>2]|0;
 $39 = $38 & 2;
 $40 = ($39|0)==(0);
 if ($40) {
  return 0;
 }
 _SDL_UnlockSurface($6);
 return 0;
}
function _SW_LockTexture($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = ((($1)) + 68|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($6)) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($2)) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ((($6)) + 16|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = Math_imul($12, $10)|0;
 $14 = (($8) + ($13)|0);
 $15 = HEAP32[$2>>2]|0;
 $16 = ((($6)) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ((($17)) + 9|0);
 $19 = HEAP8[$18>>0]|0;
 $20 = $19&255;
 $21 = Math_imul($20, $15)|0;
 $22 = (($14) + ($21)|0);
 HEAP32[$3>>2] = $22;
 HEAP32[$4>>2] = $12;
 return 0;
}
function _SW_UnlockTexture($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function _SW_SetRenderTarget($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$sink$in = 0, $$sink9 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 320|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)==(0|0);
 $5 = ((($3)) + 4|0);
 $6 = ((($1)) + 68|0);
 $$sink$in = $4 ? $5 : $6;
 $$sink9 = HEAP32[$$sink$in>>2]|0;
 HEAP32[$3>>2] = $$sink9;
 return 0;
}
function _SW_UpdateViewport($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 320|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  return 0;
 }
 $5 = ((($0)) + 216|0);
 (_SDL_SetClipRect($3,$5)|0);
 return 0;
}
function _SW_UpdateClipRect($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 320|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  return 0;
 }
 $5 = ((($0)) + 280|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  (_SDL_SetClipRect($3,0)|0);
  return 0;
 } else {
  $8 = ((($0)) + 248|0);
  (_SDL_SetClipRect($3,$8)|0);
  return 0;
 }
 return (0)|0;
}
function _SW_RenderClear($0) {
 $0 = $0|0;
 var $$0 = 0, $$ph = 0, $$pr = 0, $$pre$i = 0, $$pre16$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $2 = ((($0)) + 320|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 L1: do {
  if ($5) {
   $6 = ((($3)) + 4|0);
   $7 = HEAP32[$6>>2]|0;
   HEAP32[$3>>2] = $7;
   $8 = ($7|0)==(0);
   $9 = $7;
   if ($8) {
    $10 = ((($0)) + 188|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = (_SDL_GetWindowSurface($11)|0);
    $13 = ($12|0)==(0|0);
    do {
     if (!($13)) {
      HEAP32[$6>>2] = $12;
      HEAP32[$3>>2] = $12;
      $14 = HEAP32[$2>>2]|0;
      $15 = HEAP32[$14>>2]|0;
      $16 = ($15|0)==(0|0);
      if ($16) {
       $$ph = $12;
       label = 10;
       break L1;
      }
      $17 = ((($0)) + 216|0);
      (_SDL_SetClipRect($15,$17)|0);
      $$pre$i = HEAP32[$2>>2]|0;
      $$pre16$i = HEAP32[$$pre$i>>2]|0;
      $18 = ($$pre16$i|0)==(0|0);
      if (!($18)) {
       $19 = ((($0)) + 280|0);
       $20 = HEAP32[$19>>2]|0;
       $21 = ($20|0)==(0);
       if ($21) {
        (_SDL_SetClipRect($$pre16$i,0)|0);
        break;
       } else {
        $22 = ((($0)) + 248|0);
        (_SDL_SetClipRect($$pre16$i,$22)|0);
        break;
       }
      }
     }
    } while(0);
    $$pr = HEAP32[$3>>2]|0;
    $23 = $$pr;
   } else {
    $23 = $9;
   }
   $24 = ($23|0)==(0|0);
   if ($24) {
    $$0 = -1;$39 = $1;
    STACKTOP = sp;return ($$0|0);
   } else {
    $26 = $23;$38 = $1;
   }
  } else {
   $$ph = $4;
   label = 10;
  }
 } while(0);
 if ((label|0) == 10) {
  $26 = $$ph;$38 = $1;
 }
 $25 = ((($26)) + 4|0);
 $27 = HEAP32[$25>>2]|0;
 $28 = ((($0)) + 312|0);
 $29 = HEAP8[$28>>0]|0;
 $30 = ((($0)) + 313|0);
 $31 = HEAP8[$30>>0]|0;
 $32 = ((($0)) + 314|0);
 $33 = HEAP8[$32>>0]|0;
 $34 = ((($0)) + 315|0);
 $35 = HEAP8[$34>>0]|0;
 $36 = (_SDL_MapRGBA($27,$29,$31,$33,$35)|0);
 $37 = ((($26)) + 36|0);
 ;HEAP32[$38>>2]=HEAP32[$37>>2]|0;HEAP32[$38+4>>2]=HEAP32[$37+4>>2]|0;HEAP32[$38+8>>2]=HEAP32[$37+8>>2]|0;HEAP32[$38+12>>2]=HEAP32[$37+12>>2]|0;
 (_SDL_SetClipRect($26,0)|0);
 (_SDL_FillRect($26,0,$36)|0);
 (_SDL_SetClipRect($26,$1)|0);
 $$0 = 0;$39 = $38;
 STACKTOP = sp;return ($$0|0);
}
function _SW_RenderDrawPoints($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$06469 = 0, $$168 = 0, $$alloca_mul = 0, $$pr = 0, $$pre$i = 0, $$pre16$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0.0, $36 = 0.0, $37 = 0, $38 = 0.0, $39 = 0.0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0.0, $44 = 0.0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0.0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0.0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0, $9 = 0, $exitcond = 0, $exitcond72 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 320|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 L1: do {
  if ($6) {
   $7 = ((($4)) + 4|0);
   $8 = HEAP32[$7>>2]|0;
   HEAP32[$4>>2] = $8;
   $9 = ($8|0)==(0);
   $10 = $8;
   if ($9) {
    $11 = ((($0)) + 188|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (_SDL_GetWindowSurface($12)|0);
    $14 = ($13|0)==(0|0);
    do {
     if (!($14)) {
      HEAP32[$7>>2] = $13;
      HEAP32[$4>>2] = $13;
      $15 = HEAP32[$3>>2]|0;
      $16 = HEAP32[$15>>2]|0;
      $17 = ($16|0)==(0|0);
      if ($17) {
       $69 = $13;
       break L1;
      }
      $18 = ((($0)) + 216|0);
      (_SDL_SetClipRect($16,$18)|0);
      $$pre$i = HEAP32[$3>>2]|0;
      $$pre16$i = HEAP32[$$pre$i>>2]|0;
      $19 = ($$pre16$i|0)==(0|0);
      if (!($19)) {
       $20 = ((($0)) + 280|0);
       $21 = HEAP32[$20>>2]|0;
       $22 = ($21|0)==(0);
       if ($22) {
        (_SDL_SetClipRect($$pre16$i,0)|0);
        break;
       } else {
        $23 = ((($0)) + 248|0);
        (_SDL_SetClipRect($$pre16$i,$23)|0);
        break;
       }
      }
     }
    } while(0);
    $$pr = HEAP32[$4>>2]|0;
    $24 = $$pr;
   } else {
    $24 = $10;
   }
   $25 = ($24|0)==(0|0);
   if ($25) {
    $$0 = -1;
    STACKTOP = sp;return ($$0|0);
   } else {
    $69 = $24;
   }
  } else {
   $69 = $5;
  }
 } while(0);
 $26 = $2 << 3;
 $$alloca_mul = $26;
 $27 = STACKTOP; STACKTOP = STACKTOP + ((((1*$$alloca_mul)|0)+15)&-16)|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(((((1*$$alloca_mul)|0)+15)&-16)|0);;
 $28 = ((($0)) + 216|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ((($0)) + 220|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = $31 | $29;
 $33 = ($32|0)==(0);
 $34 = ($2|0)>(0);
 if ($33) {
  if ($34) {
   $$168 = 0;
   while(1) {
    $48 = (($1) + ($$168<<3)|0);
    $49 = +HEAPF32[$48>>2];
    $50 = (~~(($49)));
    $51 = (($27) + ($$168<<3)|0);
    HEAP32[$51>>2] = $50;
    $52 = (((($1) + ($$168<<3)|0)) + 4|0);
    $53 = +HEAPF32[$52>>2];
    $54 = (~~(($53)));
    $55 = (((($27) + ($$168<<3)|0)) + 4|0);
    HEAP32[$55>>2] = $54;
    $56 = (($$168) + 1)|0;
    $exitcond = ($56|0)==($2|0);
    if ($exitcond) {
     break;
    } else {
     $$168 = $56;
    }
   }
  }
 } else {
  if ($34) {
   $35 = (+($29|0));
   $36 = (+($31|0));
   $$06469 = 0;
   while(1) {
    $37 = (($1) + ($$06469<<3)|0);
    $38 = +HEAPF32[$37>>2];
    $39 = $35 + $38;
    $40 = (~~(($39)));
    $41 = (($27) + ($$06469<<3)|0);
    HEAP32[$41>>2] = $40;
    $42 = (((($1) + ($$06469<<3)|0)) + 4|0);
    $43 = +HEAPF32[$42>>2];
    $44 = $36 + $43;
    $45 = (~~(($44)));
    $46 = (((($27) + ($$06469<<3)|0)) + 4|0);
    HEAP32[$46>>2] = $45;
    $47 = (($$06469) + 1)|0;
    $exitcond72 = ($47|0)==($2|0);
    if ($exitcond72) {
     break;
    } else {
     $$06469 = $47;
    }
   }
  }
 }
 $57 = ((($0)) + 316|0);
 $58 = HEAP32[$57>>2]|0;
 $59 = ($58|0)==(0);
 $60 = ((($0)) + 312|0);
 $61 = HEAP8[$60>>0]|0;
 $62 = ((($0)) + 315|0);
 $63 = HEAP8[$62>>0]|0;
 $64 = ((($0)) + 313|0);
 $65 = HEAP8[$64>>0]|0;
 $66 = ((($0)) + 314|0);
 $67 = HEAP8[$66>>0]|0;
 if ($59) {
  $68 = ((($69)) + 4|0);
  $70 = HEAP32[$68>>2]|0;
  $71 = (_SDL_MapRGBA($70,$61,$65,$67,$63)|0);
  $72 = (_SDL_DrawPoints($69,$27,$2,$71)|0);
  $$0 = $72;
  STACKTOP = sp;return ($$0|0);
 } else {
  $73 = (_SDL_BlendPoints($69,$27,$2,$58,$61,$65,$67,$63)|0);
  $$0 = $73;
  STACKTOP = sp;return ($$0|0);
 }
 return (0)|0;
}
function _SW_RenderDrawLines($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$06469 = 0, $$168 = 0, $$alloca_mul = 0, $$pr = 0, $$pre$i = 0, $$pre16$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0.0, $36 = 0.0, $37 = 0, $38 = 0.0, $39 = 0.0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0.0, $44 = 0.0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0.0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0.0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0, $9 = 0, $exitcond = 0, $exitcond72 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 320|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 L1: do {
  if ($6) {
   $7 = ((($4)) + 4|0);
   $8 = HEAP32[$7>>2]|0;
   HEAP32[$4>>2] = $8;
   $9 = ($8|0)==(0);
   $10 = $8;
   if ($9) {
    $11 = ((($0)) + 188|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (_SDL_GetWindowSurface($12)|0);
    $14 = ($13|0)==(0|0);
    do {
     if (!($14)) {
      HEAP32[$7>>2] = $13;
      HEAP32[$4>>2] = $13;
      $15 = HEAP32[$3>>2]|0;
      $16 = HEAP32[$15>>2]|0;
      $17 = ($16|0)==(0|0);
      if ($17) {
       $69 = $13;
       break L1;
      }
      $18 = ((($0)) + 216|0);
      (_SDL_SetClipRect($16,$18)|0);
      $$pre$i = HEAP32[$3>>2]|0;
      $$pre16$i = HEAP32[$$pre$i>>2]|0;
      $19 = ($$pre16$i|0)==(0|0);
      if (!($19)) {
       $20 = ((($0)) + 280|0);
       $21 = HEAP32[$20>>2]|0;
       $22 = ($21|0)==(0);
       if ($22) {
        (_SDL_SetClipRect($$pre16$i,0)|0);
        break;
       } else {
        $23 = ((($0)) + 248|0);
        (_SDL_SetClipRect($$pre16$i,$23)|0);
        break;
       }
      }
     }
    } while(0);
    $$pr = HEAP32[$4>>2]|0;
    $24 = $$pr;
   } else {
    $24 = $10;
   }
   $25 = ($24|0)==(0|0);
   if ($25) {
    $$0 = -1;
    STACKTOP = sp;return ($$0|0);
   } else {
    $69 = $24;
   }
  } else {
   $69 = $5;
  }
 } while(0);
 $26 = $2 << 3;
 $$alloca_mul = $26;
 $27 = STACKTOP; STACKTOP = STACKTOP + ((((1*$$alloca_mul)|0)+15)&-16)|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(((((1*$$alloca_mul)|0)+15)&-16)|0);;
 $28 = ((($0)) + 216|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ((($0)) + 220|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = $31 | $29;
 $33 = ($32|0)==(0);
 $34 = ($2|0)>(0);
 if ($33) {
  if ($34) {
   $$168 = 0;
   while(1) {
    $48 = (($1) + ($$168<<3)|0);
    $49 = +HEAPF32[$48>>2];
    $50 = (~~(($49)));
    $51 = (($27) + ($$168<<3)|0);
    HEAP32[$51>>2] = $50;
    $52 = (((($1) + ($$168<<3)|0)) + 4|0);
    $53 = +HEAPF32[$52>>2];
    $54 = (~~(($53)));
    $55 = (((($27) + ($$168<<3)|0)) + 4|0);
    HEAP32[$55>>2] = $54;
    $56 = (($$168) + 1)|0;
    $exitcond = ($56|0)==($2|0);
    if ($exitcond) {
     break;
    } else {
     $$168 = $56;
    }
   }
  }
 } else {
  if ($34) {
   $35 = (+($29|0));
   $36 = (+($31|0));
   $$06469 = 0;
   while(1) {
    $37 = (($1) + ($$06469<<3)|0);
    $38 = +HEAPF32[$37>>2];
    $39 = $35 + $38;
    $40 = (~~(($39)));
    $41 = (($27) + ($$06469<<3)|0);
    HEAP32[$41>>2] = $40;
    $42 = (((($1) + ($$06469<<3)|0)) + 4|0);
    $43 = +HEAPF32[$42>>2];
    $44 = $36 + $43;
    $45 = (~~(($44)));
    $46 = (((($27) + ($$06469<<3)|0)) + 4|0);
    HEAP32[$46>>2] = $45;
    $47 = (($$06469) + 1)|0;
    $exitcond72 = ($47|0)==($2|0);
    if ($exitcond72) {
     break;
    } else {
     $$06469 = $47;
    }
   }
  }
 }
 $57 = ((($0)) + 316|0);
 $58 = HEAP32[$57>>2]|0;
 $59 = ($58|0)==(0);
 $60 = ((($0)) + 312|0);
 $61 = HEAP8[$60>>0]|0;
 $62 = ((($0)) + 315|0);
 $63 = HEAP8[$62>>0]|0;
 $64 = ((($0)) + 313|0);
 $65 = HEAP8[$64>>0]|0;
 $66 = ((($0)) + 314|0);
 $67 = HEAP8[$66>>0]|0;
 if ($59) {
  $68 = ((($69)) + 4|0);
  $70 = HEAP32[$68>>2]|0;
  $71 = (_SDL_MapRGBA($70,$61,$65,$67,$63)|0);
  $72 = (_SDL_DrawLines($69,$27,$2,$71)|0);
  $$0 = $72;
  STACKTOP = sp;return ($$0|0);
 } else {
  $73 = (_SDL_BlendLines($69,$27,$2,$58,$61,$65,$67,$63)|0);
  $$0 = $73;
  STACKTOP = sp;return ($$0|0);
 }
 return (0)|0;
}
function _SW_RenderFillRects($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$ = 0, $$0 = 0, $$08894 = 0, $$193 = 0, $$90 = 0, $$alloca_mul = 0, $$pr = 0, $$pre$i = 0, $$pre16$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0.0, $36 = 0.0, $37 = 0, $38 = 0.0, $39 = 0.0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0.0, $44 = 0.0, $45 = 0, $46 = 0, $47 = 0, $48 = 0.0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0.0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0.0, $61 = 0, $62 = 0, $63 = 0, $64 = 0.0, $65 = 0, $66 = 0, $67 = 0, $68 = 0.0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0.0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $exitcond = 0, $exitcond97 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 320|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 L1: do {
  if ($6) {
   $7 = ((($4)) + 4|0);
   $8 = HEAP32[$7>>2]|0;
   HEAP32[$4>>2] = $8;
   $9 = ($8|0)==(0);
   $10 = $8;
   if ($9) {
    $11 = ((($0)) + 188|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (_SDL_GetWindowSurface($12)|0);
    $14 = ($13|0)==(0|0);
    do {
     if (!($14)) {
      HEAP32[$7>>2] = $13;
      HEAP32[$4>>2] = $13;
      $15 = HEAP32[$3>>2]|0;
      $16 = HEAP32[$15>>2]|0;
      $17 = ($16|0)==(0|0);
      if ($17) {
       $91 = $13;
       break L1;
      }
      $18 = ((($0)) + 216|0);
      (_SDL_SetClipRect($16,$18)|0);
      $$pre$i = HEAP32[$3>>2]|0;
      $$pre16$i = HEAP32[$$pre$i>>2]|0;
      $19 = ($$pre16$i|0)==(0|0);
      if (!($19)) {
       $20 = ((($0)) + 280|0);
       $21 = HEAP32[$20>>2]|0;
       $22 = ($21|0)==(0);
       if ($22) {
        (_SDL_SetClipRect($$pre16$i,0)|0);
        break;
       } else {
        $23 = ((($0)) + 248|0);
        (_SDL_SetClipRect($$pre16$i,$23)|0);
        break;
       }
      }
     }
    } while(0);
    $$pr = HEAP32[$4>>2]|0;
    $24 = $$pr;
   } else {
    $24 = $10;
   }
   $25 = ($24|0)==(0|0);
   if ($25) {
    $$0 = -1;
    STACKTOP = sp;return ($$0|0);
   } else {
    $91 = $24;
   }
  } else {
   $91 = $5;
  }
 } while(0);
 $26 = $2 << 4;
 $$alloca_mul = $26;
 $27 = STACKTOP; STACKTOP = STACKTOP + ((((1*$$alloca_mul)|0)+15)&-16)|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(((((1*$$alloca_mul)|0)+15)&-16)|0);;
 $28 = ((($0)) + 216|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ((($0)) + 220|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = $31 | $29;
 $33 = ($32|0)==(0);
 $34 = ($2|0)>(0);
 if ($33) {
  if ($34) {
   $$193 = 0;
   while(1) {
    $59 = (($1) + ($$193<<4)|0);
    $60 = +HEAPF32[$59>>2];
    $61 = (~~(($60)));
    $62 = (($27) + ($$193<<4)|0);
    HEAP32[$62>>2] = $61;
    $63 = (((($1) + ($$193<<4)|0)) + 4|0);
    $64 = +HEAPF32[$63>>2];
    $65 = (~~(($64)));
    $66 = (((($27) + ($$193<<4)|0)) + 4|0);
    HEAP32[$66>>2] = $65;
    $67 = (((($1) + ($$193<<4)|0)) + 8|0);
    $68 = +HEAPF32[$67>>2];
    $69 = (~~(($68)));
    $70 = ($69|0)>(1);
    $$90 = $70 ? $69 : 1;
    $71 = (((($27) + ($$193<<4)|0)) + 8|0);
    HEAP32[$71>>2] = $$90;
    $72 = (((($1) + ($$193<<4)|0)) + 12|0);
    $73 = +HEAPF32[$72>>2];
    $74 = (~~(($73)));
    $75 = ($74|0)>(1);
    $76 = $75 ? $74 : 1;
    $77 = (((($27) + ($$193<<4)|0)) + 12|0);
    HEAP32[$77>>2] = $76;
    $78 = (($$193) + 1)|0;
    $exitcond = ($78|0)==($2|0);
    if ($exitcond) {
     break;
    } else {
     $$193 = $78;
    }
   }
  }
 } else {
  if ($34) {
   $35 = (+($29|0));
   $36 = (+($31|0));
   $$08894 = 0;
   while(1) {
    $37 = (($1) + ($$08894<<4)|0);
    $38 = +HEAPF32[$37>>2];
    $39 = $35 + $38;
    $40 = (~~(($39)));
    $41 = (($27) + ($$08894<<4)|0);
    HEAP32[$41>>2] = $40;
    $42 = (((($1) + ($$08894<<4)|0)) + 4|0);
    $43 = +HEAPF32[$42>>2];
    $44 = $36 + $43;
    $45 = (~~(($44)));
    $46 = (((($27) + ($$08894<<4)|0)) + 4|0);
    HEAP32[$46>>2] = $45;
    $47 = (((($1) + ($$08894<<4)|0)) + 8|0);
    $48 = +HEAPF32[$47>>2];
    $49 = (~~(($48)));
    $50 = ($49|0)>(1);
    $$ = $50 ? $49 : 1;
    $51 = (((($27) + ($$08894<<4)|0)) + 8|0);
    HEAP32[$51>>2] = $$;
    $52 = (((($1) + ($$08894<<4)|0)) + 12|0);
    $53 = +HEAPF32[$52>>2];
    $54 = (~~(($53)));
    $55 = ($54|0)>(1);
    $56 = $55 ? $54 : 1;
    $57 = (((($27) + ($$08894<<4)|0)) + 12|0);
    HEAP32[$57>>2] = $56;
    $58 = (($$08894) + 1)|0;
    $exitcond97 = ($58|0)==($2|0);
    if ($exitcond97) {
     break;
    } else {
     $$08894 = $58;
    }
   }
  }
 }
 $79 = ((($0)) + 316|0);
 $80 = HEAP32[$79>>2]|0;
 $81 = ($80|0)==(0);
 $82 = ((($0)) + 314|0);
 $83 = HEAP8[$82>>0]|0;
 $84 = ((($0)) + 315|0);
 $85 = HEAP8[$84>>0]|0;
 $86 = ((($0)) + 312|0);
 $87 = HEAP8[$86>>0]|0;
 $88 = ((($0)) + 313|0);
 $89 = HEAP8[$88>>0]|0;
 if ($81) {
  $90 = ((($91)) + 4|0);
  $92 = HEAP32[$90>>2]|0;
  $93 = (_SDL_MapRGBA($92,$87,$89,$83,$85)|0);
  $94 = (_SDL_FillRects($91,$27,$2,$93)|0);
  $$0 = $94;
  STACKTOP = sp;return ($$0|0);
 } else {
  $95 = (_SDL_BlendFillRects($91,$27,$2,$80,$87,$89,$83,$85)|0);
  $$0 = $95;
  STACKTOP = sp;return ($$0|0);
 }
 return (0)|0;
}
function _SW_RenderCopy($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $$ph = 0, $$pr = 0, $$pre$i = 0, $$pre16$i = 0, $$sink = 0, $$sink$in = 0.0, $$sink2 = 0.0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0.0, $38 = 0.0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0.0, $42 = 0.0, $43 = 0.0, $44 = 0.0, $45 = 0, $46 = 0, $47 = 0, $48 = 0.0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0.0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $4 = sp;
 $5 = ((($0)) + 320|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 L1: do {
  if ($8) {
   $9 = ((($6)) + 4|0);
   $10 = HEAP32[$9>>2]|0;
   HEAP32[$6>>2] = $10;
   $11 = ($10|0)==(0);
   $12 = $10;
   if ($11) {
    $13 = ((($0)) + 188|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = (_SDL_GetWindowSurface($14)|0);
    $16 = ($15|0)==(0|0);
    do {
     if (!($16)) {
      HEAP32[$9>>2] = $15;
      HEAP32[$6>>2] = $15;
      $17 = HEAP32[$5>>2]|0;
      $18 = HEAP32[$17>>2]|0;
      $19 = ($18|0)==(0|0);
      if ($19) {
       $$ph = $15;
       label = 10;
       break L1;
      }
      $20 = ((($0)) + 216|0);
      (_SDL_SetClipRect($18,$20)|0);
      $$pre$i = HEAP32[$5>>2]|0;
      $$pre16$i = HEAP32[$$pre$i>>2]|0;
      $21 = ($$pre16$i|0)==(0|0);
      if (!($21)) {
       $22 = ((($0)) + 280|0);
       $23 = HEAP32[$22>>2]|0;
       $24 = ($23|0)==(0);
       if ($24) {
        (_SDL_SetClipRect($$pre16$i,0)|0);
        break;
       } else {
        $25 = ((($0)) + 248|0);
        (_SDL_SetClipRect($$pre16$i,$25)|0);
        break;
       }
      }
     }
    } while(0);
    $$pr = HEAP32[$6>>2]|0;
    $30 = $$pr;
   } else {
    $30 = $12;
   }
   $28 = ((($1)) + 68|0);
   $29 = HEAP32[$28>>2]|0;
   $31 = ($30|0)==(0|0);
   if ($31) {
    $$0 = -1;$66 = $4;
    STACKTOP = sp;return ($$0|0);
   } else {
    $61 = $29;$62 = $30;$65 = $4;
   }
  } else {
   $$ph = $7;
   label = 10;
  }
 } while(0);
 if ((label|0) == 10) {
  $26 = ((($1)) + 68|0);
  $27 = HEAP32[$26>>2]|0;
  $61 = $27;$62 = $$ph;$65 = $4;
 }
 $32 = ((($0)) + 216|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ((($0)) + 220|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = ((($3)) + 4|0);
 $37 = +HEAPF32[$36>>2];
 $38 = +HEAPF32[$3>>2];
 $39 = $35 | $33;
 $40 = ($39|0)==(0);
 if ($40) {
  $$sink$in = $38;$$sink2 = $37;
 } else {
  $41 = (+($33|0));
  $42 = $41 + $38;
  $43 = (+($35|0));
  $44 = $43 + $37;
  $$sink$in = $42;$$sink2 = $44;
 }
 $$sink = (~~(($$sink$in)));
 HEAP32[$4>>2] = $$sink;
 $45 = (~~(($$sink2)));
 $46 = ((($4)) + 4|0);
 HEAP32[$46>>2] = $45;
 $47 = ((($3)) + 8|0);
 $48 = +HEAPF32[$47>>2];
 $49 = (~~(($48)));
 $50 = ((($4)) + 8|0);
 HEAP32[$50>>2] = $49;
 $51 = ((($3)) + 12|0);
 $52 = +HEAPF32[$51>>2];
 $53 = (~~(($52)));
 $54 = ((($4)) + 12|0);
 HEAP32[$54>>2] = $53;
 $55 = ((($2)) + 8|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = ($56|0)==($49|0);
 if ($57) {
  $58 = ((($2)) + 12|0);
  $59 = HEAP32[$58>>2]|0;
  $60 = ($59|0)==($53|0);
  if ($60) {
   $63 = (_SDL_UpperBlit($61,$2,$62,$4)|0);
   $$0 = $63;$66 = $65;
   STACKTOP = sp;return ($$0|0);
  }
 }
 (_SDL_SetSurfaceRLE($62,0)|0);
 $64 = (_SDL_UpperBlitScaled($61,$2,$62,$4)|0);
 $$0 = $64;$66 = $65;
 STACKTOP = sp;return ($$0|0);
}
function _SW_RenderCopyEx($0,$1,$2,$3,$4,$5,$6) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = +$4;
 $5 = $5|0;
 $6 = $6|0;
 var $$ = 0.0, $$$i = 0, $$0 = 0, $$0193 = 0, $$0195200 = 0, $$0195201 = 0, $$0196 = 0, $$1 = 0, $$2 = 0, $$202 = 0.0, $$203 = 0.0, $$pr = 0, $$pre = 0, $$pre$i = 0, $$pre16$i = 0, $$pre205 = 0, $$sroa$0$0 = 0, $$sroa$10$0$$sroa_idx130 = 0, $$sroa$16$0$$sroa_idx136 = 0, $$sroa$21$0$$sroa_idx141 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0.0, $135 = 0.0;
 var $136 = 0, $137 = 0, $138 = 0, $139 = 0.0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0.0, $144 = 0, $145 = 0, $146 = 0.0, $147 = 0.0, $148 = 0, $149 = 0.0, $15 = 0, $150 = 0, $151 = 0.0, $152 = 0.0, $153 = 0.0;
 var $154 = 0.0, $155 = 0.0, $156 = 0.0, $157 = 0.0, $158 = 0.0, $159 = 0.0, $16 = 0, $160 = 0.0, $161 = 0.0, $162 = 0.0, $163 = 0, $164 = 0, $165 = 0.0, $166 = 0.0, $167 = 0.0, $168 = 0.0, $169 = 0.0, $17 = 0, $170 = 0.0, $171 = 0.0;
 var $172 = 0, $173 = 0, $174 = 0.0, $175 = 0.0, $176 = 0.0, $177 = 0.0, $178 = 0.0, $179 = 0.0, $18 = 0, $180 = 0.0, $181 = 0.0, $182 = 0.0, $183 = 0.0, $184 = 0.0, $185 = 0, $186 = 0.0, $187 = 0, $188 = 0.0, $189 = 0, $19 = 0;
 var $190 = 0, $191 = 0, $192 = 0.0, $193 = 0, $194 = 0.0, $195 = 0, $196 = 0.0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0.0, $47 = 0;
 var $48 = 0, $49 = 0.0, $50 = 0, $51 = 0, $52 = 0.0, $53 = 0.0, $54 = 0.0, $55 = 0.0, $56 = 0, $57 = 0, $58 = 0.0, $59 = 0, $60 = 0, $61 = 0.0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $not$$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(64|0);
 $7 = sp + 32|0;
 $8 = sp + 28|0;
 $9 = sp + 24|0;
 $10 = sp + 8|0;
 $11 = sp;
 $12 = sp + 20|0;
 $13 = sp + 16|0;
 $14 = sp + 51|0;
 $15 = sp + 50|0;
 $16 = sp + 49|0;
 $17 = sp + 48|0;
 $18 = ((($0)) + 320|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)==(0|0);
 L1: do {
  if ($21) {
   $22 = ((($19)) + 4|0);
   $23 = HEAP32[$22>>2]|0;
   HEAP32[$19>>2] = $23;
   $24 = ($23|0)==(0);
   $25 = $23;
   if ($24) {
    $26 = ((($0)) + 188|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = (_SDL_GetWindowSurface($27)|0);
    $29 = ($28|0)==(0|0);
    do {
     if (!($29)) {
      HEAP32[$22>>2] = $28;
      HEAP32[$19>>2] = $28;
      $30 = HEAP32[$18>>2]|0;
      $31 = HEAP32[$30>>2]|0;
      $32 = ($31|0)==(0|0);
      if ($32) {
       $41 = $28;
       break L1;
      }
      $33 = ((($0)) + 216|0);
      (_SDL_SetClipRect($31,$33)|0);
      $$pre$i = HEAP32[$18>>2]|0;
      $$pre16$i = HEAP32[$$pre$i>>2]|0;
      $34 = ($$pre16$i|0)==(0|0);
      if (!($34)) {
       $35 = ((($0)) + 280|0);
       $36 = HEAP32[$35>>2]|0;
       $37 = ($36|0)==(0);
       if ($37) {
        (_SDL_SetClipRect($$pre16$i,0)|0);
        break;
       } else {
        $38 = ((($0)) + 248|0);
        (_SDL_SetClipRect($$pre16$i,$38)|0);
        break;
       }
      }
     }
    } while(0);
    $$pr = HEAP32[$19>>2]|0;
    $41 = $$pr;
   } else {
    $41 = $25;
   }
  } else {
   $41 = $20;
  }
 } while(0);
 $39 = ((($1)) + 68|0);
 $40 = HEAP32[$39>>2]|0;
 $42 = ($41|0)==(0|0);
 if ($42) {
  $$1 = -1;
  STACKTOP = sp;return ($$1|0);
 }
 $43 = ((($0)) + 216|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = ((($3)) + 4|0);
 $46 = +HEAPF32[$45>>2];
 $47 = ((($0)) + 220|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = +HEAPF32[$3>>2];
 $50 = $48 | $44;
 $51 = ($50|0)==(0);
 $52 = (+($44|0));
 $53 = $52 + $49;
 $54 = (+($48|0));
 $55 = $46 + $54;
 $$202 = $51 ? $49 : $53;
 $$203 = $51 ? $46 : $55;
 $$sroa$0$0 = (~~(($$202)));
 $56 = (~~(($$203)));
 $57 = ((($3)) + 8|0);
 $58 = +HEAPF32[$57>>2];
 $59 = (~~(($58)));
 $60 = ((($3)) + 12|0);
 $61 = +HEAPF32[$60>>2];
 $62 = (~~(($61)));
 $$sroa$10$0$$sroa_idx130 = ((($7)) + 4|0);
 $$sroa$16$0$$sroa_idx136 = ((($7)) + 8|0);
 HEAP32[$$sroa$16$0$$sroa_idx136>>2] = $59;
 $$sroa$21$0$$sroa_idx141 = ((($7)) + 12|0);
 HEAP32[$$sroa$21$0$$sroa_idx141>>2] = $62;
 HEAP32[$7>>2] = 0;
 HEAP32[$$sroa$10$0$$sroa_idx130>>2] = 0;
 $63 = ((($2)) + 8|0);
 $64 = HEAP32[$63>>2]|0;
 $65 = ($64|0)==($59|0);
 if ($65) {
  $66 = ((($2)) + 12|0);
  $67 = HEAP32[$66>>2]|0;
  $68 = ($67|0)==($62|0);
  if ($68) {
   $69 = HEAP32[$2>>2]|0;
   $70 = ($69|0)==(0);
   if ($70) {
    $71 = ((($2)) + 4|0);
    $72 = HEAP32[$71>>2]|0;
    $73 = ($72|0)==(0);
    if ($73) {
     $$0195201 = $40;$119 = $59;$120 = $62;
     label = 29;
    } else {
     label = 15;
    }
   } else {
    label = 15;
   }
  } else {
   label = 15;
  }
 } else {
  label = 15;
 }
 if ((label|0) == 15) {
  $74 = ((($40)) + 4|0);
  $75 = HEAP32[$74>>2]|0;
  $76 = ((($75)) + 8|0);
  $77 = HEAP8[$76>>0]|0;
  $78 = $77&255;
  $79 = ((($75)) + 12|0);
  $80 = HEAP32[$79>>2]|0;
  $81 = ((($75)) + 16|0);
  $82 = HEAP32[$81>>2]|0;
  $83 = ((($75)) + 20|0);
  $84 = HEAP32[$83>>2]|0;
  $85 = ((($75)) + 24|0);
  $86 = HEAP32[$85>>2]|0;
  $87 = (_SDL_CreateRGBSurface(0,$59,$62,$78,$80,$82,$84,$86)|0);
  $88 = ($87|0)==(0|0);
  do {
   if ($88) {
    $$0193 = 0;$$0196 = 0;
   } else {
    $89 = (_SDL_GetColorKey($40,$12)|0);
    $90 = ($89|0)==(0);
    if ($90) {
     $91 = HEAP32[$12>>2]|0;
     (_SDL_SetColorKey($87,1,$91)|0);
     $$0 = 1;
    } else {
     $$0 = 0;
    }
    (_SDL_GetSurfaceAlphaMod($40,$14)|0);
    (_SDL_GetSurfaceBlendMode($40,$13)|0);
    (_SDL_GetSurfaceColorMod($40,$15,$16,$17)|0);
    $92 = HEAP32[$13>>2]|0;
    $93 = ($92|0)==(0);
    if ($93) {
     $94 = HEAP8[$14>>0]|0;
     $95 = HEAP8[$15>>0]|0;
     $96 = $95 & $94;
     $97 = HEAP8[$16>>0]|0;
     $98 = $96 & $97;
     $99 = HEAP8[$17>>0]|0;
     $100 = $98 & $99;
     $101 = ($100<<24>>24)!=(-1);
     $103 = $101;
    } else {
     $103 = 1;
    }
    $102 = $103&1;
    $104 = $102 | $$0;
    $105 = ($104|0)==(0);
    if ($105) {
     $106 = (_SDL_UpperBlitScaled($40,$2,$87,$7)|0);
     $$0193 = 1;$$0196 = $106;
     break;
    }
    $107 = HEAP32[$74>>2]|0;
    $108 = HEAP32[$40>>2]|0;
    $109 = (_SDL_ConvertSurface($40,$107,$108)|0);
    $110 = ($109|0)==(0|0);
    if ($110) {
     _SDL_FreeSurface($87);
     $$0193 = 0;$$0196 = 0;
     break;
    }
    (_SDL_SetSurfaceAlphaMod($109,-1)|0);
    (_SDL_SetSurfaceBlendMode($109,0)|0);
    (_SDL_SetColorKey($109,0,0)|0);
    (_SDL_SetSurfaceColorMod($109,-1,-1,-1)|0);
    (_SDL_SetSurfaceRLE($109,0)|0);
    $111 = HEAP8[$14>>0]|0;
    (_SDL_SetSurfaceAlphaMod($87,$111)|0);
    $112 = HEAP32[$13>>2]|0;
    (_SDL_SetSurfaceBlendMode($87,$112)|0);
    $113 = HEAP8[$15>>0]|0;
    $114 = HEAP8[$16>>0]|0;
    $115 = HEAP8[$17>>0]|0;
    (_SDL_SetSurfaceColorMod($87,$113,$114,$115)|0);
    $116 = (_SDL_UpperBlitScaled($109,$2,$87,$7)|0);
    $117 = ($109|0)==($40|0);
    if ($117) {
     $$0193 = 1;$$0196 = $116;
    } else {
     _SDL_FreeSurface($109);
     $$0193 = 1;$$0196 = $116;
    }
   }
  } while(0);
  if (!($$0193)) {
   $$1 = -1;
   STACKTOP = sp;return ($$1|0);
  }
  $118 = ($$0196|0)==(0);
  if ($118) {
   $$pre = HEAP32[$$sroa$16$0$$sroa_idx136>>2]|0;
   $$pre205 = HEAP32[$$sroa$21$0$$sroa_idx141>>2]|0;
   $$0195201 = $87;$119 = $$pre;$120 = $$pre205;
   label = 29;
  } else {
   $$0195200 = $87;$$2 = $$0196;
  }
 }
 if ((label|0) == 29) {
  _SDLgfx_rotozoomSurfaceSizeTrig($119,$120,$4,$8,$9,$10,$11);
  $121 = HEAP32[$8>>2]|0;
  $122 = (($121|0) / 2)&-1;
  $123 = HEAP32[$9>>2]|0;
  $124 = (($123|0) / 2)&-1;
  $125 = (_SDL_GetHint(182819)|0);
  $126 = ($125|0)==(0|0);
  if ($126) {
   $136 = 0;
  } else {
   $127 = HEAP8[$125>>0]|0;
   $128 = ($127<<24>>24)==(48);
   if ($128) {
    $136 = 0;
   } else {
    $129 = (_SDL_strcasecmp($125,182844)|0);
    $not$$i = ($129|0)!=(0);
    $$$i = $not$$i&1;
    $136 = $$$i;
   }
  }
  $130 = $6 & 1;
  $131 = $6 & 2;
  $132 = HEAP32[$8>>2]|0;
  $133 = HEAP32[$9>>2]|0;
  $134 = +HEAPF64[$10>>3];
  $135 = +HEAPF64[$11>>3];
  $137 = (_SDLgfx_rotateSurface($$0195201,$4,$122,$124,$136,$130,$131,$132,$133,$134,$135)|0);
  $138 = ($137|0)==(0|0);
  if ($138) {
   $$0195200 = $$0195201;$$2 = 0;
  } else {
   $139 = +HEAPF32[$5>>2];
   $140 = (~~(($139)));
   $141 = (($140) + ($$sroa$0$0))|0;
   $142 = ((($5)) + 4|0);
   $143 = +HEAPF32[$142>>2];
   $144 = (~~(($143)));
   $145 = (($144) + ($56))|0;
   $146 = +HEAPF64[$11>>3];
   $147 = -$146;
   HEAPF64[$11>>3] = $147;
   $148 = (0 - ($140))|0;
   $149 = (+($148|0));
   $150 = (0 - ($144))|0;
   $151 = (+($150|0));
   $152 = +HEAPF64[$10>>3];
   $153 = $149 * $152;
   $154 = $151 * $147;
   $155 = $153 - $154;
   $156 = (+($141|0));
   $157 = $156 + $155;
   $158 = $149 * $147;
   $159 = $151 * $152;
   $160 = $158 + $159;
   $161 = (+($145|0));
   $162 = $161 + $160;
   $163 = (($$sroa$0$0) + ($59))|0;
   $164 = (($163) - ($141))|0;
   $165 = (+($164|0));
   $166 = $165 * $152;
   $167 = $166 - $154;
   $168 = $156 + $167;
   $169 = $165 * $147;
   $170 = $169 + $159;
   $171 = $161 + $170;
   $172 = (($56) + ($62))|0;
   $173 = (($172) - ($145))|0;
   $174 = (+($173|0));
   $175 = $174 * $147;
   $176 = $153 - $175;
   $177 = $156 + $176;
   $178 = $152 * $174;
   $179 = $158 + $178;
   $180 = $161 + $179;
   $181 = $166 - $175;
   $182 = $156 + $181;
   $183 = $169 + $178;
   $184 = $161 + $183;
   $185 = $157 < $168;
   $186 = $185 ? $157 : $168;
   $187 = $177 < $182;
   $188 = $187 ? $177 : $182;
   $189 = $186 < $188;
   $$ = $189 ? $186 : $188;
   $190 = (~~(($$)));
   HEAP32[$7>>2] = $190;
   $191 = $162 < $171;
   $192 = $191 ? $162 : $171;
   $193 = $180 < $184;
   $194 = $193 ? $180 : $184;
   $195 = $192 < $194;
   $196 = $195 ? $192 : $194;
   $197 = (~~(($196)));
   HEAP32[$$sroa$10$0$$sroa_idx130>>2] = $197;
   $198 = HEAP32[$8>>2]|0;
   HEAP32[$$sroa$16$0$$sroa_idx136>>2] = $198;
   $199 = HEAP32[$9>>2]|0;
   HEAP32[$$sroa$21$0$$sroa_idx141>>2] = $199;
   $200 = (_SDL_UpperBlit($137,0,$41,$7)|0);
   _SDL_FreeSurface($137);
   $$0195200 = $$0195201;$$2 = $200;
  }
 }
 $201 = ($$0195200|0)==($40|0);
 if ($201) {
  $$1 = $$2;
  STACKTOP = sp;return ($$1|0);
 }
 _SDL_FreeSurface($$0195200);
 $$1 = $$2;
 STACKTOP = sp;return ($$1|0);
}
function _SW_RenderReadPixels($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0 = 0, $$037 = 0, $$ph = 0, $$pr = 0, $$pre = 0, $$pre$i = 0, $$pre16$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $vararg_buffer = sp;
 $5 = sp + 8|0;
 $6 = ((($0)) + 320|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 L1: do {
  if ($9) {
   $10 = ((($7)) + 4|0);
   $11 = HEAP32[$10>>2]|0;
   HEAP32[$7>>2] = $11;
   $12 = ($11|0)==(0);
   $13 = $11;
   if ($12) {
    $14 = ((($0)) + 188|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = (_SDL_GetWindowSurface($15)|0);
    $17 = ($16|0)==(0|0);
    do {
     if (!($17)) {
      HEAP32[$10>>2] = $16;
      HEAP32[$7>>2] = $16;
      $18 = HEAP32[$6>>2]|0;
      $19 = HEAP32[$18>>2]|0;
      $20 = ($19|0)==(0|0);
      if ($20) {
       $$ph = $16;
       label = 10;
       break L1;
      }
      $21 = ((($0)) + 216|0);
      (_SDL_SetClipRect($19,$21)|0);
      $$pre$i = HEAP32[$6>>2]|0;
      $$pre16$i = HEAP32[$$pre$i>>2]|0;
      $22 = ($$pre16$i|0)==(0|0);
      if (!($22)) {
       $23 = ((($0)) + 280|0);
       $24 = HEAP32[$23>>2]|0;
       $25 = ($24|0)==(0);
       if ($25) {
        (_SDL_SetClipRect($$pre16$i,0)|0);
        break;
       } else {
        $26 = ((($0)) + 248|0);
        (_SDL_SetClipRect($$pre16$i,$26)|0);
        break;
       }
      }
     }
    } while(0);
    $$pr = HEAP32[$7>>2]|0;
    $27 = $$pr;
   } else {
    $27 = $13;
   }
   $28 = ($27|0)==(0|0);
   if ($28) {
    $$0 = -1;$81 = $5;
    STACKTOP = sp;return ($$0|0);
   } else {
    $52 = $27;$80 = $5;
   }
  } else {
   $$ph = $8;
   label = 10;
  }
 } while(0);
 if ((label|0) == 10) {
  $52 = $$ph;$80 = $5;
 }
 $29 = ((($0)) + 216|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ((($0)) + 220|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = $32 | $30;
 $34 = ($33|0)==(0);
 $$pre = HEAP32[$1>>2]|0;
 if ($34) {
  $$037 = $1;$46 = $$pre;
 } else {
  $35 = (($$pre) + ($30))|0;
  HEAP32[$5>>2] = $35;
  $36 = ((($1)) + 4|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = (($37) + ($32))|0;
  $39 = ((($5)) + 4|0);
  HEAP32[$39>>2] = $38;
  $40 = ((($1)) + 8|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = ((($5)) + 8|0);
  HEAP32[$42>>2] = $41;
  $43 = ((($1)) + 12|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = ((($5)) + 12|0);
  HEAP32[$45>>2] = $44;
  $$037 = $5;$46 = $35;
 }
 $47 = ($46|0)<(0);
 if (!($47)) {
  $48 = ((($$037)) + 8|0);
  $49 = HEAP32[$48>>2]|0;
  $50 = (($49) + ($46))|0;
  $51 = ((($52)) + 8|0);
  $53 = HEAP32[$51>>2]|0;
  $54 = ($50|0)>($53|0);
  if (!($54)) {
   $55 = ((($$037)) + 4|0);
   $56 = HEAP32[$55>>2]|0;
   $57 = ($56|0)<(0);
   if (!($57)) {
    $58 = ((($$037)) + 12|0);
    $59 = HEAP32[$58>>2]|0;
    $60 = (($59) + ($56))|0;
    $61 = ((($52)) + 12|0);
    $62 = HEAP32[$61>>2]|0;
    $63 = ($60|0)>($62|0);
    if (!($63)) {
     $65 = ((($52)) + 4|0);
     $66 = HEAP32[$65>>2]|0;
     $67 = HEAP32[$66>>2]|0;
     $68 = ((($52)) + 20|0);
     $69 = HEAP32[$68>>2]|0;
     $70 = ((($52)) + 16|0);
     $71 = HEAP32[$70>>2]|0;
     $72 = Math_imul($71, $56)|0;
     $73 = (($69) + ($72)|0);
     $74 = ((($66)) + 9|0);
     $75 = HEAP8[$74>>0]|0;
     $76 = $75&255;
     $77 = Math_imul($76, $46)|0;
     $78 = (($73) + ($77)|0);
     $79 = (_SDL_ConvertPixels($49,$59,$67,$78,$71,$2,$3,$4)|0);
     $$0 = $79;$81 = $80;
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 }
 $64 = (_SDL_SetError(182779,$vararg_buffer)|0);
 $$0 = $64;$81 = $80;
 STACKTOP = sp;return ($$0|0);
}
function _SW_RenderPresent($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 188|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  return;
 }
 (_SDL_UpdateWindowSurface($2)|0);
 return;
}
function _SW_DestroyTexture($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 68|0);
 $3 = HEAP32[$2>>2]|0;
 _SDL_FreeSurface($3);
 return;
}
function _SW_DestroyRenderer($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 320|0);
 $2 = HEAP32[$1>>2]|0;
 _SDL_free($2);
 _SDL_free($0);
 return;
}
function _SDL_SetClipRect($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = ($0|0)==(0|0);
 if ($3) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$2>>2] = 0;
 $4 = ((($2)) + 4|0);
 HEAP32[$4>>2] = 0;
 $5 = ((($0)) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($2)) + 8|0);
 HEAP32[$7>>2] = $6;
 $8 = ((($0)) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($2)) + 12|0);
 HEAP32[$10>>2] = $9;
 $11 = ($1|0)==(0|0);
 $12 = ((($0)) + 36|0);
 if ($11) {
  ;HEAP32[$12>>2]=HEAP32[$2>>2]|0;HEAP32[$12+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$12+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$12+12>>2]=HEAP32[$2+12>>2]|0;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 } else {
  $13 = (_SDL_IntersectRect($1,$2,$12)|0);
  $$0 = $13;
  STACKTOP = sp;return ($$0|0);
 }
 return (0)|0;
}
function _SDL_UpdateWindowSurface($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $vararg_buffer3 = sp + 16|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $1 = sp + 24|0;
 $2 = HEAP32[52375]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  (_SDL_SetError(175439,$vararg_buffer)|0);
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = ($0|0)==(0|0);
 if (!($4)) {
  $5 = HEAP32[$0>>2]|0;
  $6 = ((($2)) + 280|0);
  $7 = ($5|0)==($6|0);
  if ($7) {
   HEAP32[$1>>2] = 0;
   $8 = ((($1)) + 4|0);
   HEAP32[$8>>2] = 0;
   $9 = ((($0)) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ((($1)) + 8|0);
   HEAP32[$11>>2] = $10;
   $12 = ((($0)) + 28|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = ((($1)) + 12|0);
   HEAP32[$14>>2] = $13;
   $15 = ((($0)) + 112|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ($16|0)==(0);
   if ($17) {
    $18 = (_SDL_SetError(182696,$vararg_buffer3)|0);
    $$0 = $18;
    STACKTOP = sp;return ($$0|0);
   } else {
    $19 = ((($2)) + 136|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = (FUNCTION_TABLE_iiiii[$20 & 8191]($2,$0,$1,1)|0);
    $$0 = $21;
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 (_SDL_SetError(195204,$vararg_buffer1)|0);
 $$0 = -1;
 STACKTOP = sp;return ($$0|0);
}
function _SDL_CreateRGBSurface($0,$1,$2,$3,$4,$5,$6,$7) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 var $$0 = 0, $10 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $8 = (_SDL_MasksToPixelFormatEnum($3,$4,$5,$6,$7)|0);
 $9 = ($8|0)==(0);
 if ($9) {
  (_SDL_SetError(182955,$vararg_buffer)|0);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  $10 = (_SDL_CreateRGBSurfaceWithFormat(0,$1,$2,0,$8)|0);
  $$0 = $10;
  STACKTOP = sp;return ($$0|0);
 }
 return (0)|0;
}
function _SDL_GetColorKey($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($0|0)==(0|0);
 if ($2) {
  $$0 = -1;
  return ($$0|0);
 }
 $3 = ((($0)) + 52|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($4)) + 68|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $6 & 256;
 $8 = ($7|0)==(0);
 if ($8) {
  $$0 = -1;
  return ($$0|0);
 }
 $9 = ($1|0)==(0|0);
 if ($9) {
  $$0 = 0;
  return ($$0|0);
 }
 $10 = ((($4)) + 72|0);
 $11 = HEAP32[$10>>2]|0;
 HEAP32[$1>>2] = $11;
 $$0 = 0;
 return ($$0|0);
}
function _SDL_SetColorKey($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$ = 0, $$0 = 0, $$27 = 0, $$phi$trans$insert = 0, $$phi$trans$insert30 = 0, $$phi$trans$insert33 = 0, $$pre = 0, $$pre28 = 0, $$pre29 = 0, $$pre31 = 0, $$pre32 = 0, $$pre34 = 0, $$pre35 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $3 = ($0|0)==(0|0);
 if ($3) {
  HEAP32[$vararg_buffer>>2] = 183206;
  $4 = (_SDL_SetError(194740,$vararg_buffer)|0);
  $$0 = $4;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = ((($0)) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($6)) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if (!($9)) {
  $10 = HEAP32[$8>>2]|0;
  $11 = ($10>>>0)>($2>>>0);
  if (!($11)) {
   HEAP32[$vararg_buffer1>>2] = 182976;
   $12 = (_SDL_SetError(194740,$vararg_buffer1)|0);
   $$0 = $12;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $13 = $1 & 2;
 $14 = ($13|0)==(0);
 $$pre35 = ((($0)) + 52|0);
 if ($14) {
  $24 = $8;
 } else {
  $15 = HEAP32[$$pre35>>2]|0;
  $16 = ((($15)) + 68|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = $17 | 4096;
  HEAP32[$16>>2] = $18;
  $19 = ($18|0)==($17|0);
  if ($19) {
   $24 = $8;
  } else {
   _SDL_InvalidateMap($15);
   $$pre = HEAP32[$5>>2]|0;
   $$phi$trans$insert = ((($$pre)) + 4|0);
   $$pre28 = HEAP32[$$phi$trans$insert>>2]|0;
   $24 = $$pre28;
  }
 }
 $20 = HEAP32[$$pre35>>2]|0;
 $21 = ((($20)) + 68|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($1|0)==(0);
 $25 = ($24|0)!=(0|0);
 if ($23) {
  if ($25) {
   $35 = ((($24)) + 4|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = ((($20)) + 72|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = (((($36) + ($38<<2)|0)) + 3|0);
   HEAP8[$39>>0] = -1;
   $40 = ((($24)) + 8|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = (($41) + 1)|0;
   $43 = ($42|0)==(0);
   $$27 = $43 ? 1 : $42;
   HEAP32[$40>>2] = $$27;
   $$pre29 = HEAP32[$$pre35>>2]|0;
   $$phi$trans$insert30 = ((($$pre29)) + 68|0);
   $$pre31 = HEAP32[$$phi$trans$insert30>>2]|0;
   $45 = $$pre29;$47 = $$pre31;
  } else {
   $45 = $20;$47 = $22;
  }
  $44 = ((($45)) + 68|0);
  $46 = $47 & -257;
  HEAP32[$44>>2] = $46;
  $48 = $46;$50 = $45;
 } else {
  $26 = $22 | 256;
  HEAP32[$21>>2] = $26;
  $27 = ((($20)) + 72|0);
  HEAP32[$27>>2] = $2;
  if ($25) {
   $28 = ((($24)) + 4|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = (((($29) + ($2<<2)|0)) + 3|0);
   HEAP8[$30>>0] = 0;
   $31 = ((($24)) + 8|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = (($32) + 1)|0;
   $34 = ($33|0)==(0);
   $$ = $34 ? 1 : $33;
   HEAP32[$31>>2] = $$;
   $$pre32 = HEAP32[$$pre35>>2]|0;
   $$phi$trans$insert33 = ((($$pre32)) + 68|0);
   $$pre34 = HEAP32[$$phi$trans$insert33>>2]|0;
   $48 = $$pre34;$50 = $$pre32;
  } else {
   $48 = $26;$50 = $20;
  }
 }
 $49 = ($48|0)==($22|0);
 if ($49) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 _SDL_InvalidateMap($50);
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _SDL_GetSurfaceAlphaMod($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($0|0)==(0|0);
 if ($2) {
  $$0 = -1;
  return ($$0|0);
 }
 $3 = ($1|0)==(0|0);
 if ($3) {
  $$0 = 0;
  return ($$0|0);
 }
 $4 = ((($0)) + 52|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($5)) + 79|0);
 $7 = HEAP8[$6>>0]|0;
 HEAP8[$1>>0] = $7;
 $$0 = 0;
 return ($$0|0);
}
function _SDL_GetSurfaceBlendMode($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$sink = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $trunc = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($0|0)==(0|0);
 if ($2) {
  $$0 = -1;
  return ($$0|0);
 }
 $3 = ($1|0)==(0|0);
 if ($3) {
  $$0 = 0;
  return ($$0|0);
 }
 $4 = ((($0)) + 52|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($5)) + 68|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 & 112;
 $trunc = $8&255;
 $trunc$clear = $trunc & 127;
 switch ($trunc$clear<<24>>24) {
 case 16:  {
  $$sink = 1;
  break;
 }
 case 32:  {
  $$sink = 2;
  break;
 }
 case 64:  {
  $$sink = 4;
  break;
 }
 default: {
  $$sink = 0;
 }
 }
 HEAP32[$1>>2] = $$sink;
 $$0 = 0;
 return ($$0|0);
}
function _SDL_GetSurfaceColorMod($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ($0|0)==(0|0);
 if ($4) {
  $$0 = -1;
  return ($$0|0);
 }
 $5 = ($1|0)==(0|0);
 if (!($5)) {
  $6 = ((($0)) + 52|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ((($7)) + 76|0);
  $9 = HEAP8[$8>>0]|0;
  HEAP8[$1>>0] = $9;
 }
 $10 = ($2|0)==(0|0);
 if (!($10)) {
  $11 = ((($0)) + 52|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ((($12)) + 77|0);
  $14 = HEAP8[$13>>0]|0;
  HEAP8[$2>>0] = $14;
 }
 $15 = ($3|0)==(0|0);
 if ($15) {
  $$0 = 0;
  return ($$0|0);
 }
 $16 = ((($0)) + 52|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ((($17)) + 78|0);
 $19 = HEAP8[$18>>0]|0;
 HEAP8[$3>>0] = $19;
 $$0 = 0;
 return ($$0|0);
}
function _SDL_UpperBlitScaled($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $$0$in = 0, $$0148 = 0, $$0148$in = 0, $$0149 = 0, $$0149$in = 0, $$0150 = 0, $$0150$in = 0, $$0151 = 0, $$0152182 = 0, $$0153 = 0.0, $$0156 = 0.0, $$0159 = 0.0, $$0163 = 0.0, $$0167 = 0.0, $$0169 = 0.0, $$0172183 = 0, $$1 = 0.0, $$1154 = 0.0, $$1157 = 0.0;
 var $$1160 = 0.0, $$1164 = 0.0, $$1168 = 0.0, $$1170 = 0.0, $$1173 = 0.0, $$2 = 0.0, $$2155 = 0.0, $$2158 = 0.0, $$2161 = 0.0, $$2165 = 0.0, $$2171 = 0.0, $$2174 = 0.0, $$3 = 0.0, $$3162 = 0.0, $$3166 = 0.0, $10 = 0, $100 = 0.0, $101 = 0.0, $102 = 0, $103 = 0;
 var $104 = 0.0, $105 = 0, $106 = 0.0, $107 = 0.0, $108 = 0.0, $109 = 0.0, $11 = 0, $110 = 0, $111 = 0.0, $112 = 0, $113 = 0.0, $114 = 0.0, $115 = 0, $116 = 0, $117 = 0.0, $118 = 0, $119 = 0.0, $12 = 0, $120 = 0.0, $121 = 0.0;
 var $122 = 0.0, $123 = 0, $124 = 0.0, $125 = 0.0, $126 = 0.0, $127 = 0.0, $128 = 0.0, $129 = 0.0, $13 = 0, $130 = 0.0, $131 = 0, $132 = 0.0, $133 = 0.0, $134 = 0, $135 = 0, $136 = 0.0, $137 = 0.0, $138 = 0.0, $139 = 0, $14 = 0;
 var $140 = 0, $141 = 0.0, $142 = 0.0, $143 = 0.0, $144 = 0, $145 = 0, $146 = 0.0, $147 = 0.0, $148 = 0, $149 = 0.0, $15 = 0, $150 = 0.0, $151 = 0, $152 = 0, $153 = 0.0, $154 = 0.0, $155 = 0.0, $156 = 0, $157 = 0, $158 = 0.0;
 var $159 = 0.0, $16 = 0, $160 = 0.0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0.0, $30 = 0.0, $31 = 0.0, $32 = 0.0, $33 = 0.0, $34 = 0.0, $35 = 0, $36 = 0.0, $37 = 0, $38 = 0.0, $39 = 0, $4 = 0, $40 = 0.0, $41 = 0;
 var $42 = 0, $43 = 0.0, $44 = 0.0, $45 = 0.0, $46 = 0.0, $47 = 0.0, $48 = 0, $49 = 0.0, $5 = 0, $50 = 0, $51 = 0.0, $52 = 0, $53 = 0.0, $54 = 0, $55 = 0, $56 = 0.0, $57 = 0.0, $58 = 0.0, $59 = 0.0, $6 = 0;
 var $60 = 0.0, $61 = 0, $62 = 0.0, $63 = 0.0, $64 = 0, $65 = 0.0, $66 = 0, $67 = 0.0, $68 = 0, $69 = 0.0, $7 = 0, $70 = 0.0, $71 = 0.0, $72 = 0.0, $73 = 0, $74 = 0.0, $75 = 0, $76 = 0.0, $77 = 0.0, $78 = 0;
 var $79 = 0.0, $8 = 0, $80 = 0, $81 = 0.0, $82 = 0, $83 = 0, $84 = 0.0, $85 = 0.0, $86 = 0.0, $87 = 0.0, $88 = 0.0, $89 = 0, $9 = 0, $90 = 0, $91 = 0.0, $92 = 0.0, $93 = 0.0, $94 = 0, $95 = 0, $96 = 0.0;
 var $97 = 0.0, $98 = 0.0, $99 = 0, $or$cond = 0, $or$cond175 = 0, $or$cond177 = 0, $or$cond179 = 0, $or$cond181 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $4 = sp + 32|0;
 $5 = sp + 16|0;
 $6 = ($0|0)!=(0|0);
 $7 = ($2|0)!=(0|0);
 $or$cond = $6 & $7;
 if (!($or$cond)) {
  $8 = (_SDL_SetError(182996,$vararg_buffer)|0);
  $$0151 = $8;
  STACKTOP = sp;return ($$0151|0);
 }
 $9 = ((($0)) + 28|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0);
 if ($11) {
  $12 = ((($2)) + 28|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($13|0)==(0);
  if ($14) {
   $16 = ($1|0)==(0|0);
   $17 = ((($0)) + 8|0);
   $18 = ((($0)) + 12|0);
   $19 = ((($1)) + 8|0);
   $20 = ((($1)) + 12|0);
   $$0150$in = $16 ? $17 : $19;
   $$0149$in = $16 ? $18 : $20;
   $$0149 = HEAP32[$$0149$in>>2]|0;
   $$0150 = HEAP32[$$0150$in>>2]|0;
   $21 = ($3|0)==(0|0);
   $22 = ((($2)) + 8|0);
   $23 = ((($2)) + 12|0);
   $24 = ((($3)) + 8|0);
   $25 = ((($3)) + 12|0);
   $$0148$in = $21 ? $22 : $24;
   $$0$in = $21 ? $23 : $25;
   $$0 = HEAP32[$$0$in>>2]|0;
   $$0148 = HEAP32[$$0148$in>>2]|0;
   $26 = ($$0148|0)==($$0150|0);
   $27 = ($$0|0)==($$0149|0);
   $or$cond175 = $27 & $26;
   if ($or$cond175) {
    $28 = (_SDL_UpperBlit($0,$1,$2,$3)|0);
    $$0151 = $28;
    STACKTOP = sp;return ($$0151|0);
   }
   $29 = (+($$0148|0));
   $30 = (+($$0150|0));
   $31 = $29 / $30;
   $32 = (+($$0|0));
   $33 = (+($$0149|0));
   $34 = $32 / $33;
   if ($21) {
    $35 = (($$0148) + -1)|0;
    $36 = (+($35|0));
    $37 = (($$0) + -1)|0;
    $38 = (+($37|0));
    $$0153 = $38;$$0156 = $36;$$0159 = 0.0;$$0163 = 0.0;
   } else {
    $39 = HEAP32[$3>>2]|0;
    $40 = (+($39|0));
    $41 = ((($3)) + 4|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = (+($42|0));
    $44 = $29 + $40;
    $45 = $44 + -1.0;
    $46 = $32 + $43;
    $47 = $46 + -1.0;
    $$0153 = $47;$$0156 = $45;$$0159 = $43;$$0163 = $40;
   }
   if ($16) {
    $48 = (($$0150) + -1)|0;
    $49 = (+($48|0));
    $50 = (($$0149) + -1)|0;
    $51 = (+($50|0));
    $$0167 = $51;$$1 = 0.0;$$1154 = $$0153;$$1170 = $49;$$1173 = 0.0;$$2158 = $$0156;$$2161 = $$0159;$$2165 = $$0163;
   } else {
    $52 = HEAP32[$1>>2]|0;
    $53 = (+($52|0));
    $54 = ((($1)) + 4|0);
    $55 = HEAP32[$54>>2]|0;
    $56 = (+($55|0));
    $57 = $30 + $53;
    $58 = $57 + -1.0;
    $59 = $33 + $56;
    $60 = $59 + -1.0;
    $61 = ($52|0)<(0);
    $62 = $31 * $53;
    $63 = $$0163 - $62;
    $$1164 = $61 ? $63 : $$0163;
    $64 = ($52|0)>(0);
    $$0152182 = $64 ? $52 : 0;
    $65 = (+($$0152182|0));
    $66 = HEAP32[$17>>2]|0;
    $67 = (+($66|0));
    $68 = !($58 >= $67);
    $69 = $58 - $67;
    $70 = $69 + 1.0;
    $71 = $31 * $70;
    $72 = $$0156 - $71;
    $73 = (($66) + -1)|0;
    $74 = (+($73|0));
    $$0169 = $68 ? $58 : $74;
    $$1157 = $68 ? $$0156 : $72;
    $75 = ($55|0)<(0);
    $76 = $34 * $56;
    $77 = $$0159 - $76;
    $78 = ($55|0)>(0);
    $$0172183 = $78 ? $55 : 0;
    $79 = (+($$0172183|0));
    $$1160 = $75 ? $77 : $$0159;
    $80 = HEAP32[$18>>2]|0;
    $81 = (+($80|0));
    $82 = !($60 >= $81);
    if ($82) {
     $$0167 = $60;$$1 = $65;$$1154 = $$0153;$$1170 = $$0169;$$1173 = $79;$$2158 = $$1157;$$2161 = $$1160;$$2165 = $$1164;
    } else {
     $83 = (($80) + -1)|0;
     $84 = (+($83|0));
     $85 = $60 - $81;
     $86 = $85 + 1.0;
     $87 = $34 * $86;
     $88 = $$0153 - $87;
     $$0167 = $84;$$1 = $65;$$1154 = $88;$$1170 = $$0169;$$1173 = $79;$$2158 = $$1157;$$2161 = $$1160;$$2165 = $$1164;
    }
   }
   $89 = ((($2)) + 36|0);
   $90 = HEAP32[$89>>2]|0;
   $91 = (+($90|0));
   $92 = $$2165 - $91;
   $93 = $$2158 - $91;
   $94 = ((($2)) + 40|0);
   $95 = HEAP32[$94>>2]|0;
   $96 = (+($95|0));
   $97 = $$2161 - $96;
   $98 = $$1154 - $96;
   $99 = $92 < 0.0;
   $100 = $92 / $31;
   $101 = $$1 - $100;
   $$3166 = $99 ? 0.0 : $92;
   $$2 = $99 ? $101 : $$1;
   $102 = ((($2)) + 44|0);
   $103 = HEAP32[$102>>2]|0;
   $104 = (+($103|0));
   $105 = !($93 >= $104);
   if ($105) {
    $$2171 = $$1170;$$3 = $93;
   } else {
    $106 = $93 - $104;
    $107 = $106 + 1.0;
    $108 = $107 / $31;
    $109 = $$1170 - $108;
    $110 = (($103) + -1)|0;
    $111 = (+($110|0));
    $$2171 = $109;$$3 = $111;
   }
   $112 = $97 < 0.0;
   $113 = $97 / $34;
   $114 = $$1173 - $113;
   $$2174 = $112 ? $114 : $$1173;
   $$3162 = $112 ? 0.0 : $97;
   $115 = ((($2)) + 48|0);
   $116 = HEAP32[$115>>2]|0;
   $117 = (+($116|0));
   $118 = !($98 >= $117);
   if ($118) {
    $$1168 = $$0167;$$2155 = $98;
   } else {
    $119 = $98 - $117;
    $120 = $119 + 1.0;
    $121 = $120 / $34;
    $122 = $$0167 - $121;
    $123 = (($116) + -1)|0;
    $124 = (+($123|0));
    $$1168 = $122;$$2155 = $124;
   }
   $125 = $$3166 + $91;
   $126 = $$3 + $91;
   $127 = $$3162 + $96;
   $128 = $$2155 + $96;
   $129 = $$2 + 0.5;
   $130 = (+_SDL_floor($129));
   $131 = (~~(($130)));
   HEAP32[$4>>2] = $131;
   $132 = $$2174 + 0.5;
   $133 = (+_SDL_floor($132));
   $134 = (~~(($133)));
   $135 = ((($4)) + 4|0);
   HEAP32[$135>>2] = $134;
   $136 = $$2171 - $$2;
   $137 = $136 + 1.5;
   $138 = (+_SDL_floor($137));
   $139 = (~~(($138)));
   $140 = ((($4)) + 8|0);
   HEAP32[$140>>2] = $139;
   $141 = $$1168 - $$2174;
   $142 = $141 + 1.5;
   $143 = (+_SDL_floor($142));
   $144 = (~~(($143)));
   $145 = ((($4)) + 12|0);
   HEAP32[$145>>2] = $144;
   $146 = $125 + 0.5;
   $147 = (+_SDL_floor($146));
   $148 = (~~(($147)));
   HEAP32[$5>>2] = $148;
   $149 = $127 + 0.5;
   $150 = (+_SDL_floor($149));
   $151 = (~~(($150)));
   $152 = ((($5)) + 4|0);
   HEAP32[$152>>2] = $151;
   $153 = $126 - $125;
   $154 = $153 + 1.5;
   $155 = (+_SDL_floor($154));
   $156 = (~~(($155)));
   $157 = ((($5)) + 8|0);
   HEAP32[$157>>2] = $156;
   $158 = $128 - $127;
   $159 = $158 + 1.5;
   $160 = (+_SDL_floor($159));
   $161 = (~~(($160)));
   $162 = ((($5)) + 12|0);
   HEAP32[$162>>2] = $161;
   $163 = ($156|0)<(0);
   if ($163) {
    HEAP32[$157>>2] = 0;
    $165 = 0;
   } else {
    $165 = $156;
   }
   $164 = ($161|0)<(0);
   if ($164) {
    HEAP32[$162>>2] = 0;
    $167 = 0;
   } else {
    $167 = $161;
   }
   if (!($21)) {
    ;HEAP32[$3>>2]=HEAP32[$5>>2]|0;HEAP32[$3+4>>2]=HEAP32[$5+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$5+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$5+12>>2]|0;
   }
   $166 = ($165|0)==(0);
   $168 = ($167|0)==(0);
   $or$cond177 = $166 | $168;
   $169 = ($139|0)<(1);
   $or$cond179 = $or$cond177 | $169;
   $170 = ($144|0)<(1);
   $or$cond181 = $or$cond179 | $170;
   if ($or$cond181) {
    $$0151 = 0;
    STACKTOP = sp;return ($$0151|0);
   }
   $171 = (_SDL_LowerBlitScaled($0,$4,$2,$5)|0);
   $$0151 = $171;
   STACKTOP = sp;return ($$0151|0);
  }
 }
 $15 = (_SDL_SetError(182889,$vararg_buffer1)|0);
 $$0151 = $15;
 STACKTOP = sp;return ($$0151|0);
}
function _SDL_ConvertSurface($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$$i = 0, $$$i107 = 0, $$06274$i = 0, $$06378$i = 0, $$06670$i = 0, $$06771$i = 0, $$096$lcssa = 0, $$096120 = 0, $$1 = 0, $$27$i$i = 0, $$in$i = 0, $$in81$i = 0, $$in82$i = 0, $$in87$i = 0, $$old = 0, $$old100 = 0, $$phi$trans$insert = 0, $$phi$trans$insert30$i$i = 0, $$phi$trans$insert33$i = 0, $$phi$trans$insert33$i109 = 0;
 var $$pr$pre$i = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i113 = 0, $$pre132 = 0, $$pre133 = 0, $$pre29$i$i = 0, $$pre31$i$i = 0, $$pre32$i = 0, $$pre32$i108 = 0, $$pre34$i = 0, $$pre34$i110 = 0, $$pre86$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0;
 var $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0;
 var $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0;
 var $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0;
 var $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0;
 var $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0;
 var $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0;
 var $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0;
 var $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0;
 var $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0;
 var $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0;
 var $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0;
 var $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer3 = 0, $vararg_buffer5 = 0, $vararg_buffer8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(80|0);
 $vararg_buffer8 = sp + 32|0;
 $vararg_buffer5 = sp + 24|0;
 $vararg_buffer3 = sp + 16|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $3 = sp + 56|0;
 $4 = sp + 40|0;
 $5 = sp + 75|0;
 $6 = sp + 74|0;
 $7 = sp + 73|0;
 $8 = sp + 72|0;
 $9 = ((($1)) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if (!($11)) {
  $12 = HEAP32[$10>>2]|0;
  $13 = ($12|0)>(0);
  L3: do {
   if ($13) {
    $$phi$trans$insert = ((($10)) + 4|0);
    $$pre132 = HEAP32[$$phi$trans$insert>>2]|0;
    $$096120 = 0;
    while(1) {
     $14 = (($$pre132) + ($$096120<<2)|0);
     $15 = HEAP8[$14>>0]|0;
     $16 = ($15<<24>>24)==(-1);
     if (!($16)) {
      $$096$lcssa = $$096120;
      break L3;
     }
     $17 = (((($$pre132) + ($$096120<<2)|0)) + 1|0);
     $18 = HEAP8[$17>>0]|0;
     $19 = ($18<<24>>24)==(-1);
     if (!($19)) {
      $$096$lcssa = $$096120;
      break L3;
     }
     $20 = (((($$pre132) + ($$096120<<2)|0)) + 2|0);
     $21 = HEAP8[$20>>0]|0;
     $22 = ($21<<24>>24)==(-1);
     if (!($22)) {
      $$096$lcssa = $$096120;
      break L3;
     }
     $23 = (($$096120) + 1)|0;
     $24 = ($23|0)<($12|0);
     if ($24) {
      $$096120 = $23;
     } else {
      $$096$lcssa = $23;
      break;
     }
    }
   } else {
    $$096$lcssa = 0;
   }
  } while(0);
  $25 = ($$096$lcssa|0)==($12|0);
  if ($25) {
   (_SDL_SetError(182929,$vararg_buffer)|0);
   $$1 = 0;
   STACKTOP = sp;return ($$1|0);
  }
 }
 $26 = ((($0)) + 8|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ((($0)) + 12|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ((($1)) + 8|0);
 $31 = HEAP8[$30>>0]|0;
 $32 = $31&255;
 $33 = ((($1)) + 12|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ((($1)) + 16|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = ((($1)) + 20|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = ((($1)) + 24|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = (_SDL_MasksToPixelFormatEnum($32,$34,$36,$38,$40)|0);
 $42 = ($41|0)==(0);
 if ($42) {
  (_SDL_SetError(182955,$vararg_buffer1)|0);
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $43 = (_SDL_CreateRGBSurfaceWithFormat(0,$27,$29,0,$41)|0);
 $44 = ($43|0)==(0|0);
 if ($44) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $45 = HEAP32[$9>>2]|0;
 $46 = ($45|0)==(0|0);
 if (!($46)) {
  $47 = ((($43)) + 4|0);
  $48 = HEAP32[$47>>2]|0;
  $49 = ((($48)) + 4|0);
  $50 = HEAP32[$49>>2]|0;
  $51 = ($50|0)==(0|0);
  if (!($51)) {
   $52 = ((($50)) + 4|0);
   $53 = HEAP32[$52>>2]|0;
   $54 = ((($45)) + 4|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = HEAP32[$45>>2]|0;
   $57 = $56 << 2;
   (_SDL_memcpy($53,$55,$57)|0);
   $58 = HEAP32[$9>>2]|0;
   $59 = HEAP32[$58>>2]|0;
   $60 = HEAP32[$47>>2]|0;
   $61 = ((($60)) + 4|0);
   $62 = HEAP32[$61>>2]|0;
   HEAP32[$62>>2] = $59;
  }
 }
 $63 = ((($0)) + 52|0);
 $64 = HEAP32[$63>>2]|0;
 $65 = ((($64)) + 68|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = ((($64)) + 76|0);
 $68 = HEAP8[$67>>0]|0;
 $69 = ((($64)) + 77|0);
 $70 = HEAP8[$69>>0]|0;
 $71 = ((($64)) + 78|0);
 $72 = HEAP8[$71>>0]|0;
 $73 = ((($64)) + 79|0);
 $74 = HEAP8[$73>>0]|0;
 HEAP32[$67>>2] = -1;
 HEAP32[$65>>2] = 0;
 _SDL_InvalidateMap($64);
 HEAP32[$4>>2] = 0;
 $75 = ((($4)) + 4|0);
 HEAP32[$75>>2] = 0;
 $76 = HEAP32[$26>>2]|0;
 $77 = ((($4)) + 8|0);
 HEAP32[$77>>2] = $76;
 $78 = HEAP32[$28>>2]|0;
 $79 = ((($4)) + 12|0);
 HEAP32[$79>>2] = $78;
 $80 = HEAP32[$63>>2]|0;
 $81 = HEAP32[$80>>2]|0;
 $82 = ($81|0)==($43|0);
 do {
  if ($82) {
   $83 = ((($43)) + 4|0);
   $84 = HEAP32[$83>>2]|0;
   $85 = ((($84)) + 4|0);
   $86 = HEAP32[$85>>2]|0;
   $87 = ($86|0)==(0|0);
   if (!($87)) {
    $88 = ((($80)) + 80|0);
    $89 = HEAP32[$88>>2]|0;
    $90 = ((($86)) + 8|0);
    $91 = HEAP32[$90>>2]|0;
    $92 = ($89|0)==($91|0);
    if (!($92)) {
     label = 21;
     break;
    }
   }
   $93 = ((($0)) + 4|0);
   $94 = HEAP32[$93>>2]|0;
   $95 = ((($94)) + 4|0);
   $96 = HEAP32[$95>>2]|0;
   $97 = ($96|0)==(0|0);
   if ($97) {
    $106 = $80;
    label = 23;
   } else {
    $98 = ((($80)) + 84|0);
    $99 = HEAP32[$98>>2]|0;
    $100 = ((($96)) + 8|0);
    $101 = HEAP32[$100>>2]|0;
    $102 = ($99|0)==($101|0);
    if ($102) {
     $106 = $80;
     label = 23;
    } else {
     label = 21;
    }
   }
  } else {
   label = 21;
  }
 } while(0);
 if ((label|0) == 21) {
  $103 = (_SDL_MapSurface($0,$43)|0);
  $104 = ($103|0)<(0);
  if (!($104)) {
   $$pre$i = HEAP32[$63>>2]|0;
   $106 = $$pre$i;
   label = 23;
  }
 }
 if ((label|0) == 23) {
  $105 = ((($106)) + 8|0);
  $107 = HEAP32[$105>>2]|0;
  (FUNCTION_TABLE_iiiii[$107 & 8191]($0,$4,$43,$4)|0);
 }
 $108 = ((($43)) + 52|0);
 $109 = HEAP32[$108>>2]|0;
 $110 = ((($109)) + 76|0);
 HEAP8[$110>>0] = $68;
 $111 = ((($109)) + 77|0);
 HEAP8[$111>>0] = $70;
 $112 = ((($109)) + 78|0);
 HEAP8[$112>>0] = $72;
 $113 = ((($109)) + 79|0);
 HEAP8[$113>>0] = $74;
 $114 = $66 & -28945;
 $115 = ((($109)) + 68|0);
 HEAP32[$115>>2] = $114;
 $116 = HEAP32[$63>>2]|0;
 $117 = ((($116)) + 76|0);
 HEAP8[$117>>0] = $68;
 $118 = ((($116)) + 77|0);
 HEAP8[$118>>0] = $70;
 $119 = ((($116)) + 78|0);
 HEAP8[$119>>0] = $72;
 $120 = ((($116)) + 79|0);
 HEAP8[$120>>0] = $74;
 $121 = ((($116)) + 68|0);
 HEAP32[$121>>2] = $66;
 _SDL_InvalidateMap($116);
 $122 = $66 & 256;
 $123 = ($122|0)==(0);
 $$pre133 = ((($0)) + 4|0);
 do {
  if (!($123)) {
   $124 = HEAP32[$$pre133>>2]|0;
   $125 = ((($124)) + 4|0);
   $126 = HEAP32[$125>>2]|0;
   $127 = ($126|0)==(0|0);
   if ($127) {
    $170 = $124;
   } else {
    $128 = HEAP32[$9>>2]|0;
    $129 = ($128|0)==(0|0);
    if (!($129)) {
     $130 = HEAP32[$126>>2]|0;
     $131 = HEAP32[$128>>2]|0;
     $132 = ($130|0)>($131|0);
     if (!($132)) {
      $133 = ((($126)) + 4|0);
      $134 = HEAP32[$133>>2]|0;
      $135 = ((($128)) + 4|0);
      $136 = HEAP32[$135>>2]|0;
      $137 = $130 << 2;
      $138 = (_SDL_memcmp($134,$136,$137)|0);
      $139 = ($138|0)==(0);
      if ($139) {
       $140 = HEAP32[$63>>2]|0;
       $141 = ((($140)) + 72|0);
       $142 = HEAP32[$141>>2]|0;
       $143 = ((($43)) + 4|0);
       $144 = HEAP32[$143>>2]|0;
       $145 = ((($144)) + 4|0);
       $146 = HEAP32[$145>>2]|0;
       $147 = ($146|0)==(0|0);
       if (!($147)) {
        $148 = HEAP32[$146>>2]|0;
        $149 = ($148>>>0)>($142>>>0);
        if (!($149)) {
         HEAP32[$vararg_buffer3>>2] = 182976;
         (_SDL_SetError(194740,$vararg_buffer3)|0);
         break;
        }
       }
       $150 = HEAP32[$108>>2]|0;
       $151 = ((($150)) + 68|0);
       $152 = HEAP32[$151>>2]|0;
       $153 = $152 | 256;
       HEAP32[$151>>2] = $153;
       $154 = ((($150)) + 72|0);
       HEAP32[$154>>2] = $142;
       if ($147) {
        $162 = $153;$164 = $150;
       } else {
        $155 = ((($146)) + 4|0);
        $156 = HEAP32[$155>>2]|0;
        $157 = (((($156) + ($142<<2)|0)) + 3|0);
        HEAP8[$157>>0] = 0;
        $158 = ((($146)) + 8|0);
        $159 = HEAP32[$158>>2]|0;
        $160 = (($159) + 1)|0;
        $161 = ($160|0)==(0);
        $$$i = $161 ? 1 : $160;
        HEAP32[$158>>2] = $$$i;
        $$pre32$i = HEAP32[$108>>2]|0;
        $$phi$trans$insert33$i = ((($$pre32$i)) + 68|0);
        $$pre34$i = HEAP32[$$phi$trans$insert33$i>>2]|0;
        $162 = $$pre34$i;$164 = $$pre32$i;
       }
       $163 = ($162|0)==($152|0);
       if ($163) {
        break;
       }
       _SDL_InvalidateMap($164);
       break;
      }
     }
    }
    $165 = HEAP32[$39>>2]|0;
    $166 = ($165|0)==(0);
    if (!($166)) {
     break;
    }
    $$pre = HEAP32[$$pre133>>2]|0;
    $170 = $$pre;
   }
   $167 = HEAP32[$63>>2]|0;
   $168 = ((($167)) + 72|0);
   $169 = HEAP32[$168>>2]|0;
   _SDL_GetRGBA($169,$170,$5,$6,$7,$8);
   $171 = ((($43)) + 4|0);
   $172 = HEAP32[$171>>2]|0;
   $173 = HEAP8[$5>>0]|0;
   $174 = HEAP8[$6>>0]|0;
   $175 = HEAP8[$7>>0]|0;
   $176 = HEAP8[$8>>0]|0;
   $177 = (_SDL_MapRGBA($172,$173,$174,$175,$176)|0);
   $178 = HEAP32[$171>>2]|0;
   $179 = ((($178)) + 4|0);
   $180 = HEAP32[$179>>2]|0;
   $181 = ($180|0)==(0|0);
   if ($181) {
    label = 41;
   } else {
    $182 = HEAP32[$180>>2]|0;
    $183 = ($182>>>0)>($177>>>0);
    if ($183) {
     label = 41;
    } else {
     HEAP32[$vararg_buffer5>>2] = 182976;
     (_SDL_SetError(194740,$vararg_buffer5)|0);
    }
   }
   if ((label|0) == 41) {
    $184 = HEAP32[$108>>2]|0;
    $185 = ((($184)) + 68|0);
    $186 = HEAP32[$185>>2]|0;
    $187 = $186 | 256;
    HEAP32[$185>>2] = $187;
    $188 = ((($184)) + 72|0);
    HEAP32[$188>>2] = $177;
    if ($181) {
     $196 = $187;$198 = $184;
    } else {
     $189 = ((($180)) + 4|0);
     $190 = HEAP32[$189>>2]|0;
     $191 = (((($190) + ($177<<2)|0)) + 3|0);
     HEAP8[$191>>0] = 0;
     $192 = ((($180)) + 8|0);
     $193 = HEAP32[$192>>2]|0;
     $194 = (($193) + 1)|0;
     $195 = ($194|0)==(0);
     $$$i107 = $195 ? 1 : $194;
     HEAP32[$192>>2] = $$$i107;
     $$pre32$i108 = HEAP32[$108>>2]|0;
     $$phi$trans$insert33$i109 = ((($$pre32$i108)) + 68|0);
     $$pre34$i110 = HEAP32[$$phi$trans$insert33$i109>>2]|0;
     $196 = $$pre34$i110;$198 = $$pre32$i108;
    }
    $197 = ($196|0)==($186|0);
    if (!($197)) {
     _SDL_InvalidateMap($198);
    }
   }
   $199 = HEAP32[$108>>2]|0;
   $200 = ((($199)) + 68|0);
   $201 = HEAP32[$200>>2]|0;
   $202 = $201 & 256;
   $203 = ($202|0)==(0);
   if (!($203)) {
    $204 = HEAP32[$171>>2]|0;
    $205 = ((($204)) + 24|0);
    $206 = HEAP32[$205>>2]|0;
    $207 = ($206|0)==(0);
    if (!($207)) {
     $208 = ((($43)) + 28|0);
     $209 = HEAP32[$208>>2]|0;
     $210 = ($209|0)==(0);
     if ($210) {
      $211 = HEAP32[$43>>2]|0;
      $212 = $211 & 2;
      $213 = ($212|0)==(0);
      if ($213) {
       $217 = 0;$219 = $204;
      } else {
       _SDL_UnRLESurface($43,1);
       $214 = HEAP32[$43>>2]|0;
       $215 = $214 | 2;
       HEAP32[$43>>2] = $215;
       $$pre$i$i = HEAP32[$208>>2]|0;
       $$pre$i113 = HEAP32[$171>>2]|0;
       $217 = $$pre$i$i;$219 = $$pre$i113;
      }
     } else {
      $217 = $209;$219 = $204;
     }
     $216 = (($217) + 1)|0;
     HEAP32[$208>>2] = $216;
     $218 = ((($219)) + 9|0);
     $220 = HEAP8[$218>>0]|0;
     switch ($220<<24>>24) {
     case 2:  {
      $221 = HEAP32[$108>>2]|0;
      $222 = ((($221)) + 72|0);
      $223 = HEAP32[$222>>2]|0;
      $224 = ((($219)) + 24|0);
      $225 = HEAP32[$224>>2]|0;
      $226 = $225 & 65535;
      $227 = $226 ^ 65535;
      $228 = $227 & $223;
      $229 = ((($43)) + 12|0);
      $230 = HEAP32[$229>>2]|0;
      $231 = ($230|0)==(0);
      if ($231) {
       $278 = $216;
      } else {
       $232 = ((($43)) + 8|0);
       $233 = HEAP32[$232>>2]|0;
       $234 = ($233|0)==(0);
       $235 = ((($43)) + 16|0);
       $236 = HEAP32[$235>>2]|0;
       $237 = (($236|0) / 2)&-1;
       if ($234) {
        $278 = $216;
       } else {
        $238 = ((($43)) + 20|0);
        $239 = HEAP32[$238>>2]|0;
        $240 = $228&65535;
        $$06771$i = $239;$$in87$i = $230;
        while(1) {
         $$06670$i = $$06771$i;$$in82$i = $233;
         while(1) {
          $241 = (($$in82$i) + -1)|0;
          $242 = HEAP16[$$06670$i>>1]|0;
          $243 = $242&65535;
          $244 = $243 & $227;
          $245 = ($244|0)==($228|0);
          if ($245) {
           HEAP16[$$06670$i>>1] = $240;
          }
          $246 = ((($$06670$i)) + 2|0);
          $247 = ($241|0)==(0);
          if ($247) {
           break;
          } else {
           $$06670$i = $246;$$in82$i = $241;
          }
         }
         $248 = (($$in87$i) + -1)|0;
         $249 = (($$06771$i) + ($237<<1)|0);
         $250 = ($248|0)==(0);
         if ($250) {
          $278 = $216;
          break;
         } else {
          $$06771$i = $249;$$in87$i = $248;
         }
        }
       }
      }
      break;
     }
     case 4:  {
      $251 = HEAP32[$108>>2]|0;
      $252 = ((($251)) + 72|0);
      $253 = HEAP32[$252>>2]|0;
      $254 = ((($219)) + 24|0);
      $255 = HEAP32[$254>>2]|0;
      $256 = $255 ^ -1;
      $257 = $253 & $256;
      $258 = ((($43)) + 12|0);
      $259 = HEAP32[$258>>2]|0;
      $260 = ($259|0)==(0);
      if ($260) {
       $278 = $216;
      } else {
       $261 = ((($43)) + 20|0);
       $262 = HEAP32[$261>>2]|0;
       $263 = ((($43)) + 8|0);
       $264 = ((($43)) + 16|0);
       $$06378$i = $262;$$in$i = $259;
       while(1) {
        $265 = (($$in$i) + -1)|0;
        $266 = HEAP32[$263>>2]|0;
        $267 = ($266|0)==(0);
        if (!($267)) {
         $$06274$i = $$06378$i;$$in81$i = $266;
         while(1) {
          $268 = (($$in81$i) + -1)|0;
          $269 = HEAP32[$$06274$i>>2]|0;
          $270 = $269 & $256;
          $271 = ($270|0)==($257|0);
          if ($271) {
           HEAP32[$$06274$i>>2] = $257;
          }
          $272 = ((($$06274$i)) + 4|0);
          $273 = ($268|0)==(0);
          if ($273) {
           break;
          } else {
           $$06274$i = $272;$$in81$i = $268;
          }
         }
        }
        $274 = HEAP32[$264>>2]|0;
        $275 = (($274|0) / 4)&-1;
        $276 = (($$06378$i) + ($275<<2)|0);
        $277 = ($265|0)==(0);
        if ($277) {
         break;
        } else {
         $$06378$i = $276;$$in$i = $265;
        }
       }
       $$pr$pre$i = HEAP32[$208>>2]|0;
       $278 = $$pr$pre$i;
      }
      break;
     }
     default: {
      $278 = $216;
     }
     }
     $279 = ($278|0)==(0);
     if ($279) {
      $287 = $219;
     } else {
      $280 = (($278) + -1)|0;
      HEAP32[$208>>2] = $280;
      $281 = ($278|0)>(1);
      if ($281) {
       $287 = $219;
      } else {
       $282 = HEAP32[$43>>2]|0;
       $283 = $282 & 2;
       $284 = ($283|0)==(0);
       if ($284) {
        $287 = $219;
       } else {
        $285 = $282 & -3;
        HEAP32[$43>>2] = $285;
        (_SDL_RLESurface($43)|0);
        $$pre86$i = HEAP32[$171>>2]|0;
        $287 = $$pre86$i;
       }
      }
     }
     $286 = ((($287)) + 4|0);
     $288 = HEAP32[$286>>2]|0;
     $289 = ($288|0)==(0|0);
     do {
      if ($289) {
       $292 = HEAP32[$108>>2]|0;
       $293 = ((($292)) + 68|0);
       $294 = HEAP32[$293>>2]|0;
       $308 = $292;$310 = $294;$312 = $294;
       label = 76;
      } else {
       $290 = HEAP32[$288>>2]|0;
       $291 = ($290|0)==(0);
       if ($291) {
        HEAP32[$vararg_buffer8>>2] = 182976;
        (_SDL_SetError(194740,$vararg_buffer8)|0);
        break;
       } else {
        $295 = HEAP32[$108>>2]|0;
        $296 = ((($295)) + 68|0);
        $297 = HEAP32[$296>>2]|0;
        $298 = ((($288)) + 4|0);
        $299 = HEAP32[$298>>2]|0;
        $300 = ((($295)) + 72|0);
        $301 = HEAP32[$300>>2]|0;
        $302 = (((($299) + ($301<<2)|0)) + 3|0);
        HEAP8[$302>>0] = -1;
        $303 = ((($288)) + 8|0);
        $304 = HEAP32[$303>>2]|0;
        $305 = (($304) + 1)|0;
        $306 = ($305|0)==(0);
        $$27$i$i = $306 ? 1 : $305;
        HEAP32[$303>>2] = $$27$i$i;
        $$pre29$i$i = HEAP32[$108>>2]|0;
        $$phi$trans$insert30$i$i = ((($$pre29$i$i)) + 68|0);
        $$pre31$i$i = HEAP32[$$phi$trans$insert30$i$i>>2]|0;
        $308 = $$pre29$i$i;$310 = $$pre31$i$i;$312 = $297;
        label = 76;
        break;
       }
      }
     } while(0);
     if ((label|0) == 76) {
      $307 = ((($308)) + 68|0);
      $309 = $310 & -257;
      HEAP32[$307>>2] = $309;
      $311 = ($309|0)==($312|0);
      if (!($311)) {
       _SDL_InvalidateMap($308);
      }
     }
     $313 = HEAP32[$108>>2]|0;
     $314 = ((($313)) + 68|0);
     $315 = HEAP32[$314>>2]|0;
     $316 = $315 & -113;
     $317 = $316 | 16;
     HEAP32[$314>>2] = $317;
     $318 = ($317|0)==($315|0);
     if (!($318)) {
      _SDL_InvalidateMap($313);
     }
    }
   }
  }
 } while(0);
 $319 = ((($0)) + 36|0);
 HEAP32[$3>>2] = 0;
 $320 = ((($3)) + 4|0);
 HEAP32[$320>>2] = 0;
 $321 = ((($43)) + 8|0);
 $322 = HEAP32[$321>>2]|0;
 $323 = ((($3)) + 8|0);
 HEAP32[$323>>2] = $322;
 $324 = ((($43)) + 12|0);
 $325 = HEAP32[$324>>2]|0;
 $326 = ((($3)) + 12|0);
 HEAP32[$326>>2] = $325;
 $327 = ((($43)) + 36|0);
 (_SDL_IntersectRect($319,$3,$327)|0);
 $328 = HEAP32[$$pre133>>2]|0;
 $329 = ((($328)) + 24|0);
 $330 = HEAP32[$329>>2]|0;
 $331 = ($330|0)==(0);
 if ($331) {
  $$old = $66 & 258;
  $$old100 = ($$old|0)==(0);
  if (!($$old100)) {
   label = 84;
  }
 } else {
  $332 = HEAP32[$39>>2]|0;
  $333 = $66 & 258;
  $334 = $332 | $333;
  $335 = ($334|0)==(0);
  if (!($335)) {
   label = 84;
  }
 }
 if ((label|0) == 84) {
  $336 = HEAP32[$108>>2]|0;
  $337 = ((($336)) + 68|0);
  $338 = HEAP32[$337>>2]|0;
  $339 = $338 & -113;
  $340 = $339 | 16;
  HEAP32[$337>>2] = $340;
  $341 = ($340|0)==($338|0);
  if (!($341)) {
   _SDL_InvalidateMap($336);
  }
 }
 $342 = $66 & 4096;
 $343 = $2 & 2;
 $344 = $342 | $343;
 $345 = ($344|0)==(0);
 if ($345) {
  $$1 = $43;
  STACKTOP = sp;return ($$1|0);
 }
 $346 = HEAP32[$108>>2]|0;
 $347 = ((($346)) + 68|0);
 $348 = HEAP32[$347>>2]|0;
 $349 = $348 | 4096;
 HEAP32[$347>>2] = $349;
 $350 = ($349|0)==($348|0);
 if ($350) {
  $$1 = $43;
  STACKTOP = sp;return ($$1|0);
 }
 _SDL_InvalidateMap($346);
 $$1 = $43;
 STACKTOP = sp;return ($$1|0);
}
function _SDL_SetSurfaceAlphaMod($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$sink = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($0|0)==(0|0);
 if ($2) {
  $$0 = -1;
  return ($$0|0);
 }
 $3 = ((($0)) + 52|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($4)) + 79|0);
 HEAP8[$5>>0] = $1;
 $6 = ((($4)) + 68|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($1<<24>>24)!=(-1);
 $9 = $7 & -3;
 $10 = $7 | 2;
 $$sink = $8 ? $10 : $9;
 HEAP32[$6>>2] = $$sink;
 $11 = ($$sink|0)==($7|0);
 if ($11) {
  $$0 = 0;
  return ($$0|0);
 }
 _SDL_InvalidateMap($4);
 $$0 = 0;
 return ($$0|0);
}
function _SDL_SetSurfaceBlendMode($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$014 = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre15 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($0|0)==(0|0);
 if ($2) {
  $$014 = -1;
  return ($$014|0);
 }
 $3 = ((($0)) + 52|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($4)) + 68|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $6 & -113;
 HEAP32[$5>>2] = $7;
 switch ($1|0) {
 case 0:  {
  $$0 = 0;$12 = $7;$14 = $4;
  break;
 }
 case 1:  {
  $8 = $7 | 16;
  HEAP32[$5>>2] = $8;
  $$0 = 0;$12 = $8;$14 = $4;
  break;
 }
 case 2:  {
  $9 = $7 | 32;
  HEAP32[$5>>2] = $9;
  $$0 = 0;$12 = $9;$14 = $4;
  break;
 }
 case 4:  {
  $10 = $7 | 64;
  HEAP32[$5>>2] = $10;
  $$0 = 0;$12 = $10;$14 = $4;
  break;
 }
 default: {
  $11 = (_SDL_Error(4)|0);
  $$pre = HEAP32[$3>>2]|0;
  $$phi$trans$insert = ((($$pre)) + 68|0);
  $$pre15 = HEAP32[$$phi$trans$insert>>2]|0;
  $$0 = $11;$12 = $$pre15;$14 = $$pre;
 }
 }
 $13 = ($12|0)==($6|0);
 if ($13) {
  $$014 = $$0;
  return ($$014|0);
 }
 _SDL_InvalidateMap($14);
 $$014 = $$0;
 return ($$014|0);
}
function _SDL_SetSurfaceColorMod($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $$sink = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond17 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ($0|0)==(0|0);
 if ($4) {
  $$0 = -1;
  return ($$0|0);
 }
 $5 = ((($0)) + 52|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($6)) + 76|0);
 HEAP8[$7>>0] = $1;
 $8 = ((($6)) + 77|0);
 HEAP8[$8>>0] = $2;
 $9 = ((($6)) + 78|0);
 HEAP8[$9>>0] = $3;
 $10 = ((($6)) + 68|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $2 & $1;
 $13 = ($12<<24>>24)==(-1);
 $14 = ($3<<24>>24)==(-1);
 $or$cond17 = $13 & $14;
 $15 = $11 & -2;
 $16 = $11 | 1;
 $$sink = $or$cond17 ? $15 : $16;
 HEAP32[$10>>2] = $$sink;
 $17 = ($$sink|0)==($11|0);
 if ($17) {
  $$0 = 0;
  return ($$0|0);
 }
 _SDL_InvalidateMap($6);
 $$0 = 0;
 return ($$0|0);
}
function _SDL_SetSurfaceRLE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$sink = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($0|0)==(0|0);
 if ($2) {
  $$0 = -1;
  return ($$0|0);
 }
 $3 = ((($0)) + 52|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($4)) + 68|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($1|0)!=(0);
 $8 = $6 & -4097;
 $9 = $6 | 4096;
 $$sink = $7 ? $9 : $8;
 HEAP32[$5>>2] = $$sink;
 $10 = ($$sink|0)==($6|0);
 if ($10) {
  $$0 = 0;
  return ($$0|0);
 }
 _SDL_InvalidateMap($4);
 $$0 = 0;
 return ($$0|0);
}
function _SDLgfx_rotozoomSurfaceSizeTrig($0,$1,$2,$3,$4,$5,$6) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = +$2;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 var $$ = 0, $$sink = 0.0, $$sink1 = 0.0, $$sink10 = 0.0, $$sink11 = 0.0, $$sink13 = 0.0, $$sink14 = 0.0, $$sink15 = 0.0, $$sink16 = 0.0, $$sink17 = 0.0, $$sink18 = 0.0, $$sink2 = 0.0, $$sink20 = 0.0, $$sink21 = 0.0, $$sink22 = 0.0, $$sink23 = 0.0, $$sink24 = 0.0, $$sink25 = 0.0, $$sink27 = 0.0, $$sink3 = 0.0;
 var $$sink4 = 0.0, $$sink6 = 0.0, $$sink7 = 0.0, $$sink8 = 0.0, $$sink9 = 0.0, $10 = 0, $100 = 0.0, $101 = 0.0, $102 = 0, $103 = 0.0, $104 = 0.0, $105 = 0, $106 = 0.0, $107 = 0.0, $108 = 0, $109 = 0.0, $11 = 0, $110 = 0.0, $111 = 0, $112 = 0.0;
 var $113 = 0.0, $114 = 0, $115 = 0, $116 = 0.0, $117 = 0.0, $118 = 0, $119 = 0.0, $12 = 0, $120 = 0.0, $121 = 0, $122 = 0.0, $123 = 0.0, $124 = 0, $125 = 0.0, $126 = 0.0, $127 = 0, $128 = 0.0, $129 = 0.0, $13 = 0, $130 = 0;
 var $131 = 0.0, $132 = 0.0, $133 = 0, $134 = 0.0, $135 = 0.0, $136 = 0, $137 = 0.0, $138 = 0.0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $15 = 0, $16 = 0, $17 = 0.0, $18 = 0, $19 = 0.0, $20 = 0.0, $21 = 0.0, $22 = 0.0;
 var $23 = 0, $24 = 0.0, $25 = 0, $26 = 0.0, $27 = 0.0, $28 = 0.0, $29 = 0.0, $30 = 0.0, $31 = 0.0, $32 = 0.0, $33 = 0.0, $34 = 0.0, $35 = 0.0, $36 = 0, $37 = 0.0, $38 = 0.0, $39 = 0.0, $40 = 0.0, $41 = 0, $42 = 0.0;
 var $43 = 0.0, $44 = 0, $45 = 0.0, $46 = 0.0, $47 = 0.0, $48 = 0, $49 = 0.0, $50 = 0.0, $51 = 0, $52 = 0.0, $53 = 0.0, $54 = 0, $55 = 0.0, $56 = 0.0, $57 = 0, $58 = 0.0, $59 = 0.0, $60 = 0, $61 = 0, $62 = 0.0;
 var $63 = 0.0, $64 = 0, $65 = 0.0, $66 = 0.0, $67 = 0, $68 = 0.0, $69 = 0.0, $7 = 0.0, $70 = 0, $71 = 0.0, $72 = 0.0, $73 = 0, $74 = 0.0, $75 = 0.0, $76 = 0, $77 = 0.0, $78 = 0.0, $79 = 0, $8 = 0, $80 = 0.0;
 var $81 = 0.0, $82 = 0, $83 = 0.0, $84 = 0.0, $85 = 0, $86 = 0.0, $87 = 0.0, $88 = 0.0, $89 = 0.0, $9 = 0.0, $90 = 0, $91 = 0.0, $92 = 0.0, $93 = 0.0, $94 = 0.0, $95 = 0, $96 = 0.0, $97 = 0.0, $98 = 0, $99 = 0.0;
 var $phitmp = 0, $phitmp217 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $7 = $2 / 90.0;
 $8 = (~~(($7)));
 $9 = (+($8|0));
 $10 = $9 == $7;
 if ($10) {
  $11 = (($8|0) % 4)&-1;
  $12 = ($11|0)<(0);
  $13 = (($11) + 4)|0;
  $$ = $12 ? $13 : $11;
  $14 = $$ & 1;
  $15 = ($14|0)==(0);
  if ($15) {
   HEAP32[$3>>2] = $0;
   HEAP32[$4>>2] = $1;
   $18 = ($$|0)==(0);
   $19 = $18 ? 1.0 : -1.0;
   HEAPF64[$5>>3] = $19;
   HEAPF64[$6>>3] = 0.0;
   return;
  } else {
   HEAP32[$3>>2] = $1;
   HEAP32[$4>>2] = $0;
   HEAPF64[$5>>3] = 0.0;
   $16 = ($$|0)==(1);
   $17 = $16 ? -1.0 : 1.0;
   HEAPF64[$6>>3] = $17;
   return;
  }
 }
 $20 = $2 * -0.017453292519943295;
 $21 = (+_SDL_sin($20));
 HEAPF64[$6>>3] = $21;
 $22 = (+_SDL_cos($20));
 HEAPF64[$5>>3] = $22;
 $23 = (($0|0) / 2)&-1;
 $24 = (+($23|0));
 $25 = (($1|0) / 2)&-1;
 $26 = (+($25|0));
 $27 = $24 * $22;
 $28 = $26 * $22;
 $29 = +HEAPF64[$6>>3];
 $30 = $24 * $29;
 $31 = $26 * $29;
 $32 = $27 + $31;
 $33 = (+_SDL_fabs($32));
 $34 = $27 - $31;
 $35 = (+_SDL_fabs($34));
 $36 = $33 > $35;
 $$sink = $36 ? $32 : $34;
 $37 = (+_SDL_fabs($$sink));
 $38 = -$27;
 $39 = $31 - $27;
 $40 = (+_SDL_fabs($39));
 $41 = $37 > $40;
 if ($41) {
  $42 = (+_SDL_fabs($32));
  $43 = (+_SDL_fabs($34));
  $44 = $42 > $43;
  $$sink1 = $44 ? $32 : $34;
  $$sink2 = $$sink1;
 } else {
  $$sink2 = $39;
 }
 $45 = (+_SDL_fabs($$sink2));
 $46 = $38 - $31;
 $47 = (+_SDL_fabs($46));
 $48 = $45 > $47;
 if ($48) {
  $49 = (+_SDL_fabs($32));
  $50 = (+_SDL_fabs($34));
  $51 = $49 > $50;
  $$sink3 = $51 ? $32 : $34;
  $52 = (+_SDL_fabs($$sink3));
  $53 = (+_SDL_fabs($39));
  $54 = $52 > $53;
  if ($54) {
   $55 = (+_SDL_fabs($32));
   $56 = (+_SDL_fabs($34));
   $57 = $55 > $56;
   $$sink4 = $57 ? $32 : $34;
   $$sink6 = $$sink4;
  } else {
   $$sink6 = $39;
  }
 } else {
  $$sink6 = $46;
 }
 $58 = (+_SDL_fabs($$sink6));
 $59 = (+_SDL_ceil($58));
 $60 = (~~(($59)));
 $61 = ($60|0)>(1);
 if ($61) {
  $62 = (+_SDL_fabs($32));
  $63 = (+_SDL_fabs($34));
  $64 = $62 > $63;
  $$sink7 = $64 ? $32 : $34;
  $65 = (+_SDL_fabs($$sink7));
  $66 = (+_SDL_fabs($39));
  $67 = $65 > $66;
  if ($67) {
   $68 = (+_SDL_fabs($32));
   $69 = (+_SDL_fabs($34));
   $70 = $68 > $69;
   $$sink8 = $70 ? $32 : $34;
   $$sink9 = $$sink8;
  } else {
   $$sink9 = $39;
  }
  $71 = (+_SDL_fabs($$sink9));
  $72 = (+_SDL_fabs($46));
  $73 = $71 > $72;
  if ($73) {
   $74 = (+_SDL_fabs($32));
   $75 = (+_SDL_fabs($34));
   $76 = $74 > $75;
   $$sink10 = $76 ? $32 : $34;
   $77 = (+_SDL_fabs($$sink10));
   $78 = (+_SDL_fabs($39));
   $79 = $77 > $78;
   if ($79) {
    $80 = (+_SDL_fabs($32));
    $81 = (+_SDL_fabs($34));
    $82 = $80 > $81;
    $$sink11 = $82 ? $32 : $34;
    $$sink13 = $$sink11;
   } else {
    $$sink13 = $39;
   }
  } else {
   $$sink13 = $46;
  }
  $83 = (+_SDL_fabs($$sink13));
  $84 = (+_SDL_ceil($83));
  $85 = (~~(($84)));
  $phitmp = $85 << 1;
  $140 = $phitmp;
 } else {
  $140 = 2;
 }
 $86 = $28 + $30;
 $87 = (+_SDL_fabs($86));
 $88 = $30 - $28;
 $89 = (+_SDL_fabs($88));
 $90 = $87 > $89;
 $$sink14 = $90 ? $86 : $88;
 $91 = (+_SDL_fabs($$sink14));
 $92 = -$30;
 $93 = $28 - $30;
 $94 = (+_SDL_fabs($93));
 $95 = $91 > $94;
 if ($95) {
  $96 = (+_SDL_fabs($86));
  $97 = (+_SDL_fabs($88));
  $98 = $96 > $97;
  $$sink15 = $98 ? $86 : $88;
  $$sink16 = $$sink15;
 } else {
  $$sink16 = $93;
 }
 $99 = (+_SDL_fabs($$sink16));
 $100 = $92 - $28;
 $101 = (+_SDL_fabs($100));
 $102 = $99 > $101;
 if ($102) {
  $103 = (+_SDL_fabs($86));
  $104 = (+_SDL_fabs($88));
  $105 = $103 > $104;
  $$sink17 = $105 ? $86 : $88;
  $106 = (+_SDL_fabs($$sink17));
  $107 = (+_SDL_fabs($93));
  $108 = $106 > $107;
  if ($108) {
   $109 = (+_SDL_fabs($86));
   $110 = (+_SDL_fabs($88));
   $111 = $109 > $110;
   $$sink18 = $111 ? $86 : $88;
   $$sink20 = $$sink18;
  } else {
   $$sink20 = $93;
  }
 } else {
  $$sink20 = $100;
 }
 $112 = (+_SDL_fabs($$sink20));
 $113 = (+_SDL_ceil($112));
 $114 = (~~(($113)));
 $115 = ($114|0)>(1);
 if ($115) {
  $116 = (+_SDL_fabs($86));
  $117 = (+_SDL_fabs($88));
  $118 = $116 > $117;
  $$sink21 = $118 ? $86 : $88;
  $119 = (+_SDL_fabs($$sink21));
  $120 = (+_SDL_fabs($93));
  $121 = $119 > $120;
  if ($121) {
   $122 = (+_SDL_fabs($86));
   $123 = (+_SDL_fabs($88));
   $124 = $122 > $123;
   $$sink22 = $124 ? $86 : $88;
   $$sink23 = $$sink22;
  } else {
   $$sink23 = $93;
  }
  $125 = (+_SDL_fabs($$sink23));
  $126 = (+_SDL_fabs($100));
  $127 = $125 > $126;
  if ($127) {
   $128 = (+_SDL_fabs($86));
   $129 = (+_SDL_fabs($88));
   $130 = $128 > $129;
   $$sink24 = $130 ? $86 : $88;
   $131 = (+_SDL_fabs($$sink24));
   $132 = (+_SDL_fabs($93));
   $133 = $131 > $132;
   if ($133) {
    $134 = (+_SDL_fabs($86));
    $135 = (+_SDL_fabs($88));
    $136 = $134 > $135;
    $$sink25 = $136 ? $86 : $88;
    $$sink27 = $$sink25;
   } else {
    $$sink27 = $93;
   }
  } else {
   $$sink27 = $100;
  }
  $137 = (+_SDL_fabs($$sink27));
  $138 = (+_SDL_ceil($137));
  $139 = (~~(($138)));
  $phitmp217 = $139 << 1;
  $141 = $phitmp217;
 } else {
  $141 = 2;
 }
 HEAP32[$3>>2] = $140;
 HEAP32[$4>>2] = $141;
 return;
}
function _SDLgfx_rotateSurface($0,$1,$2,$3,$4,$5,$6,$7,$8,$9,$10) {
 $0 = $0|0;
 $1 = +$1;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 $8 = $8|0;
 $9 = +$9;
 $10 = +$10;
 var $$ = 0, $$$060$i = 0, $$$060$i120 = 0, $$$i = 0, $$$i$i = 0, $$$i$i115 = 0, $$0 = 0, $$0104159 = 0, $$0104160 = 0, $$0105 = 0, $$0106193 = 0, $$0107 = 0, $$0108157 = 0, $$0109 = 0, $$0283320$i = 0, $$0285319$i = 0, $$0289$i = 0, $$0291312$i = 0, $$0293311$i = 0, $$0314$i = 0;
 var $$04168$i = 0, $$04168$i132 = 0, $$04168$us$i = 0, $$04168$us$i128 = 0, $$042$i = 0, $$042$i123 = 0, $$058$i = 0, $$058$i119 = 0, $$060$i = 0, $$060$i118 = 0, $$062$i = 0, $$062$i117 = 0, $$063$i = 0, $$063$i116 = 0, $$069$i = 0, $$069$i131 = 0, $$069$us$i = 0, $$069$us$i127 = 0, $$079100$i = 0, $$08099$i = 0;
 var $$08290$i = 0, $$08290$us$i = 0, $$08290$us$us$i = 0, $$08290$us95$i = 0, $$08389$i = 0, $$08389$us$i = 0, $$08389$us$us$i = 0, $$08389$us96$i = 0, $$092$i = 0, $$092$us$i = 0, $$092$us$us$i = 0, $$092$us93$i = 0, $$1$lcssa$i = 0, $$1$lcssa$i142 = 0, $$1$lcssa$i155 = 0, $$1284309$i = 0, $$1286$lcssa$i = 0, $$1286313$i = 0, $$1292300$i = 0, $$1292300$us$i = 0;
 var $$1292300$us$us$i = 0, $$1292300$us305$i = 0, $$1294299$i = 0, $$1294299$us$i = 0, $$1294299$us$us$i = 0, $$1294299$us306$i = 0, $$1302$i = 0, $$1302$us$i = 0, $$1302$us$us$i = 0, $$1302$us303$i = 0, $$159$i = 0, $$159$i121 = 0, $$165$i = 0, $$165$i136 = 0, $$191$i = 0, $$191$us$i = 0, $$191$us$us$i = 0, $$191$us94$i = 0, $$2308$i = 0, $$244$ph$i = 0;
 var $$244$ph$i124 = 0, $$24467$i = 0, $$24467$i133 = 0, $$24467$us$i = 0, $$24467$us$i129 = 0, $$3$lcssa$i = 0, $$3$lcssa$i113 = 0, $$3$lcssa$i141 = 0, $$3301$i = 0, $$3301$us$i = 0, $$3301$us$us$i = 0, $$3301$us304$i = 0, $$364$i = 0, $$364$i137 = 0, $$lcssa191 = 0, $$lcssa192 = 0, $$neg$i$neg = 0, $$neg85$i$neg = 0, $$phi$trans$insert = 0, $$pre = 0;
 var $$pre$i = 0, $$pre$i111 = 0, $$pre$i144 = 0, $$pre$i147 = 0, $$pre$phiZ2D = 0, $$pre110$i = 0, $$pre111$i = 0, $$pre112$i = 0, $$pre113$i = 0, $$pre226 = 0, $$pre330$i = 0, $$pre331$i = 0, $$pre332$i = 0, $$pre333$i = 0, $$pre334$i = 0, $$pre73$i = 0, $$pre75$i = 0, $$sroa$0$0$copyload$$sroa$098$0$copyload101$$sroa$0114$0$copyload116$$sroa$0126$0$copyload$i = 0, $$sroa$0$0$copyload$$sroa$098$0$copyload101$i = 0, $$sroa$0$0$copyload$i = 0;
 var $$sroa$0114$0$copyload116$$sroa$0126$0$copyload$$sroa$0$0$copyload$$sroa$098$0$copyload101$i = 0, $$sroa$0114$0$copyload116$$sroa$0126$0$copyload$i = 0, $$sroa$0114$0$copyload116$i = 0, $$sroa$0126$0$copyload$$sroa$0114$0$copyload116$$sroa$098$0$copyload101$$sroa$0$0$copyload$i = 0, $$sroa$0126$0$copyload$$sroa$0114$0$copyload116$i = 0, $$sroa$0126$0$copyload$i = 0, $$sroa$098$0$copyload101$$sroa$0$0$copyload$$sroa$0126$0$copyload$$sroa$0114$0$copyload116$i = 0, $$sroa$098$0$copyload101$$sroa$0$0$copyload$i = 0, $$sroa$098$0$copyload101$i = 0, $$sroa$10$0$$sroa_idx$i = 0, $$sroa$10$0$copyload$$sroa$19$0$copyload111$$sroa$16$0$copyload124$$sroa$21$0$copyload$i = 0, $$sroa$10$0$copyload$$sroa$19$0$copyload111$i = 0, $$sroa$10$0$copyload$i = 0, $$sroa$12120$0$$sroa_idx121$i = 0, $$sroa$12120$0$copyload122$$sroa$15$0$copyload$$sroa$9$0$copyload$$sroa$14106$0$copyload108$i = 0, $$sroa$12120$0$copyload122$$sroa$15$0$copyload$i = 0, $$sroa$12120$0$copyload122$i = 0, $$sroa$14106$0$$sroa_idx107$i = 0, $$sroa$14106$0$copyload108$$sroa$9$0$copyload$$sroa$15$0$copyload$$sroa$12120$0$copyload122$i = 0, $$sroa$14106$0$copyload108$$sroa$9$0$copyload$i = 0;
 var $$sroa$14106$0$copyload108$i = 0, $$sroa$15$0$$sroa_idx$i = 0, $$sroa$15$0$copyload$$sroa$12120$0$copyload122$$sroa$14106$0$copyload108$$sroa$9$0$copyload$i = 0, $$sroa$15$0$copyload$$sroa$12120$0$copyload122$i = 0, $$sroa$15$0$copyload$i = 0, $$sroa$16$0$$sroa_idx123$i = 0, $$sroa$16$0$copyload124$$sroa$21$0$copyload$$sroa$10$0$copyload$$sroa$19$0$copyload111$i = 0, $$sroa$16$0$copyload124$$sroa$21$0$copyload$i = 0, $$sroa$16$0$copyload124$i = 0, $$sroa$19$0$$sroa_idx110$i = 0, $$sroa$19$0$copyload111$$sroa$10$0$copyload$$sroa$21$0$copyload$$sroa$16$0$copyload124$i = 0, $$sroa$19$0$copyload111$$sroa$10$0$copyload$i = 0, $$sroa$19$0$copyload111$i = 0, $$sroa$21$0$$sroa_idx$i = 0, $$sroa$21$0$copyload$$sroa$16$0$copyload124$$sroa$19$0$copyload111$$sroa$10$0$copyload$i = 0, $$sroa$21$0$copyload$$sroa$16$0$copyload124$i = 0, $$sroa$21$0$copyload$i = 0, $$sroa$8$0$$sroa_idx$i = 0, $$sroa$8$0$copyload$$sroa$9102$0$copyload104$$sroa$8117$0$copyload119$$sroa$9128$0$copyload$i = 0, $$sroa$8$0$copyload$$sroa$9102$0$copyload104$i = 0;
 var $$sroa$8$0$copyload$i = 0, $$sroa$8117$0$$sroa_idx118$i = 0, $$sroa$8117$0$copyload119$$sroa$9128$0$copyload$$sroa$8$0$copyload$$sroa$9102$0$copyload104$i = 0, $$sroa$8117$0$copyload119$$sroa$9128$0$copyload$i = 0, $$sroa$8117$0$copyload119$i = 0, $$sroa$9$0$$sroa_idx$i = 0, $$sroa$9$0$copyload$$sroa$14106$0$copyload108$$sroa$12120$0$copyload122$$sroa$15$0$copyload$i = 0, $$sroa$9$0$copyload$$sroa$14106$0$copyload108$i = 0, $$sroa$9$0$copyload$i = 0, $$sroa$9102$0$$sroa_idx103$i = 0, $$sroa$9102$0$copyload104$$sroa$8$0$copyload$$sroa$9128$0$copyload$$sroa$8117$0$copyload119$i = 0, $$sroa$9102$0$copyload104$$sroa$8$0$copyload$i = 0, $$sroa$9102$0$copyload104$i = 0, $$sroa$9128$0$$sroa_idx$i = 0, $$sroa$9128$0$copyload$$sroa$8117$0$copyload119$$sroa$9102$0$copyload104$$sroa$8$0$copyload$i = 0, $$sroa$9128$0$copyload$$sroa$8117$0$copyload119$i = 0, $$sroa$9128$0$copyload$i = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0;
 var $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0;
 var $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0.0, $167 = 0, $168 = 0.0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0;
 var $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0;
 var $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0;
 var $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0;
 var $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0;
 var $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0;
 var $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0;
 var $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0;
 var $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0;
 var $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0;
 var $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0;
 var $358 = 0, $359 = 0, $36 = 0.0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0.0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0;
 var $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0;
 var $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $40 = 0.0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0.0, $410 = 0, $411 = 0;
 var $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0;
 var $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0;
 var $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0;
 var $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0;
 var $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0;
 var $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0;
 var $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0;
 var $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0;
 var $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0;
 var $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0;
 var $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0;
 var $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0;
 var $630 = 0, $631 = 0, $632 = 0, $633 = 0.0, $634 = 0.0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0;
 var $649 = 0, $65 = 0, $66 = 0, $67 = 0.0, $68 = 0, $69 = 0.0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond$i = 0, $scevgep$i = 0, $scevgep$i139 = 0, $scevgep73$i = 0;
 var $scevgep74$i = 0, $tmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $11 = sp + 16|0;
 $12 = sp + 12|0;
 $13 = sp + 8|0;
 $14 = sp + 4|0;
 $15 = sp + 26|0;
 $16 = sp + 25|0;
 $17 = sp + 24|0;
 $18 = sp;
 $19 = sp + 23|0;
 $20 = sp + 22|0;
 $21 = sp + 21|0;
 $22 = sp + 20|0;
 HEAP8[$15>>0] = 0;
 HEAP8[$16>>0] = 0;
 HEAP8[$17>>0] = 0;
 $23 = ($0|0)==(0|0);
 if ($23) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $24 = HEAP32[$0>>2]|0;
 $25 = $24 & 1;
 $26 = ($25|0)==(0);
 if ($26) {
  $$pre226 = ((($0)) + 4|0);
  $$0105 = 0;$$pre$phiZ2D = $$pre226;
 } else {
  HEAP32[$14>>2] = 0;
  (_SDL_GetColorKey($0,$14)|0);
  $27 = HEAP32[$14>>2]|0;
  $28 = ((($0)) + 4|0);
  $29 = HEAP32[$28>>2]|0;
  _SDL_GetRGB($27,$29,$15,$16,$17);
  $$0105 = 1;$$pre$phiZ2D = $28;
 }
 $30 = HEAP32[$$pre$phiZ2D>>2]|0;
 $31 = ((($30)) + 8|0);
 $32 = HEAP8[$31>>0]|0;
 L8: do {
  switch ($32<<24>>24) {
  case 8: case 32:  {
   $39 = ($32<<24>>24)==(32);
   $40 = $10 * 65536.0;
   $41 = $9 * 65536.0;
   $42 = (($8) + 2)|0;
   if ($39) {
    $$0104159 = $0;$44 = $30;$52 = $42;$633 = $41;$634 = $40;
    label = 9;
   } else {
    $54 = (_SDL_CreateRGBSurface(0,$7,$42,8,0,0,0,0)|0);
    $$0104160 = $0;$$0108157 = 0;$$0109 = $54;$166 = $40;$168 = $41;
   }
   break;
  }
  default: {
   $33 = HEAP32[$0>>2]|0;
   $34 = (_SDL_ConvertSurfaceFormat($0,377888772,$33)|0);
   $35 = ($34|0)==(0|0);
   if ($35) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   } else {
    $36 = $10 * 65536.0;
    $37 = $9 * 65536.0;
    $38 = (($8) + 2)|0;
    $$phi$trans$insert = ((($34)) + 4|0);
    $$pre = HEAP32[$$phi$trans$insert>>2]|0;
    $$0104159 = $34;$44 = $$pre;$52 = $38;$633 = $37;$634 = $36;
    label = 9;
    break L8;
   }
  }
  }
 } while(0);
 if ((label|0) == 9) {
  $43 = ((($44)) + 12|0);
  $45 = HEAP32[$43>>2]|0;
  $46 = ((($44)) + 16|0);
  $47 = HEAP32[$46>>2]|0;
  $48 = ((($44)) + 20|0);
  $49 = HEAP32[$48>>2]|0;
  $50 = ((($44)) + 24|0);
  $51 = HEAP32[$50>>2]|0;
  $53 = (_SDL_CreateRGBSurface(0,$7,$52,32,$45,$47,$49,$51)|0);
  $$0104160 = $$0104159;$$0108157 = 1;$$0109 = $53;$166 = $634;$168 = $633;
 }
 $55 = ($$0109|0)==(0|0);
 if ($55) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $56 = ((($$0109)) + 12|0);
 HEAP32[$56>>2] = $8;
 $57 = ($$0105|0)==(1);
 if ($57) {
  $58 = ((($$0109)) + 4|0);
  $59 = HEAP32[$58>>2]|0;
  $60 = HEAP8[$15>>0]|0;
  $61 = HEAP8[$16>>0]|0;
  $62 = HEAP8[$17>>0]|0;
  $63 = (_SDL_MapRGB($59,$60,$61,$62)|0);
  (_SDL_FillRect($$0109,0,$63)|0);
 }
 $64 = HEAP32[$$0104160>>2]|0;
 $65 = $64 & 2;
 $66 = ($65|0)==(0);
 if (!($66)) {
  (_SDL_LockSurface($$0104160)|0);
 }
 $67 = $1 / 90.0;
 $68 = (~~(($67)));
 $69 = (+($68|0));
 $70 = $69 == $67;
 if ($70) {
  $71 = (($68|0) % 4)&-1;
  $72 = ($71|0)<(0);
  $73 = (($71) + 4)|0;
  $$ = $72 ? $73 : $71;
  $$0107 = $$;
 } else {
  $$0107 = -1;
 }
 if ($$0108157) {
  $84 = ($$0107|0)>(-1);
  L32: do {
   if ($84) {
    $85 = ((($$0109)) + 16|0);
    $86 = HEAP32[$85>>2]|0;
    $87 = ((($$0109)) + 8|0);
    $88 = HEAP32[$87>>2]|0;
    $89 = $88 << 2;
    $90 = (($86) - ($89))|0;
    $91 = ((($$0104160)) + 20|0);
    $92 = HEAP32[$91>>2]|0;
    $93 = ((($$0109)) + 20|0);
    $94 = HEAP32[$93>>2]|0;
    $95 = ($6|0)!=(0);
    $96 = ((($$0104160)) + 16|0);
    $97 = HEAP32[$96>>2]|0;
    $98 = (0 - ($97))|0;
    $99 = $95 ? $98 : $97;
    $100 = ($5|0)!=(0);
    $$$i$i = $100 ? -4 : 4;
    switch ($$0107|0) {
    case 0:  {
     $101 = ((($$0104160)) + 8|0);
     $102 = HEAP32[$101>>2]|0;
     $103 = Math_imul($102, $$$i$i)|0;
     $104 = (($99) - ($103))|0;
     $$058$i = 1;$$060$i = 1;$$062$i = $104;$$063$i = $$$i$i;
     break;
    }
    case 1:  {
     $105 = (0 - ($99))|0;
     $106 = ((($$0104160)) + 12|0);
     $107 = HEAP32[$106>>2]|0;
     $108 = Math_imul($107, $99)|0;
     $109 = (($108) + ($$$i$i))|0;
     $$058$i = -1;$$060$i = 1;$$062$i = $109;$$063$i = $105;
     break;
    }
    case 2:  {
     $110 = (0 - ($$$i$i))|0;
     $111 = ((($$0104160)) + 8|0);
     $112 = HEAP32[$111>>2]|0;
     $113 = Math_imul($112, $$$i$i)|0;
     $114 = (($113) - ($99))|0;
     $$058$i = -1;$$060$i = -1;$$062$i = $114;$$063$i = $110;
     break;
    }
    default: {
     $115 = (0 - ($99))|0;
     $116 = ((($$0104160)) + 12|0);
     $117 = HEAP32[$116>>2]|0;
     $118 = Math_imul($117, $115)|0;
     $119 = (($118) - ($$$i$i))|0;
     $$058$i = 1;$$060$i = -1;$$062$i = $119;$$063$i = $99;
    }
    }
    $120 = (0 - ($$060$i))|0;
    $$$060$i = $100 ? $120 : $$060$i;
    $121 = (0 - ($$058$i))|0;
    $$159$i = $95 ? $121 : $$058$i;
    $122 = ($$$060$i|0)<(0);
    if ($122) {
     $123 = ((($$0104160)) + 8|0);
     $124 = HEAP32[$123>>2]|0;
     $125 = $124 << 2;
     $126 = (($125) + -4)|0;
     $127 = (($92) + ($126)|0);
     $$042$i = $127;
    } else {
     $$042$i = $92;
    }
    $128 = ($$159$i|0)<(0);
    if ($128) {
     $129 = ((($$0104160)) + 12|0);
     $130 = HEAP32[$129>>2]|0;
     $131 = (($130) + -1)|0;
     $132 = Math_imul($131, $97)|0;
     $133 = (($$042$i) + ($132)|0);
     $$244$ph$i = $133;
    } else {
     $$244$ph$i = $$042$i;
    }
    $134 = HEAP32[$56>>2]|0;
    $135 = ($134|0)>(0);
    if ($135) {
     $136 = ($$063$i|0)==(4);
     if ($136) {
      $$04168$us$i = $94;$$069$us$i = 0;$$24467$us$i = $$244$ph$i;$138 = $88;
      while(1) {
       $137 = $138 << 2;
       (_SDL_memcpy($$04168$us$i,$$24467$us$i,$137)|0);
       $139 = HEAP32[$87>>2]|0;
       $140 = $139 << 2;
       $141 = (($$24467$us$i) + ($140)|0);
       $142 = (($$04168$us$i) + ($140)|0);
       $143 = (($141) + ($$062$i)|0);
       $144 = (($142) + ($90)|0);
       $145 = (($$069$us$i) + 1)|0;
       $146 = HEAP32[$56>>2]|0;
       $147 = ($145|0)<($146|0);
       if ($147) {
        $$04168$us$i = $144;$$069$us$i = $145;$$24467$us$i = $143;$138 = $139;
       } else {
        break L32;
       }
      }
     } else {
      $$04168$i = $94;$$069$i = 0;$$24467$i = $$244$ph$i;$149 = $88;$635 = $134;
     }
     while(1) {
      $148 = $149 << 2;
      $150 = (($$04168$i) + ($148)|0);
      $151 = ($148|0)==(0);
      if ($151) {
       $$1$lcssa$i = $$04168$i;$$3$lcssa$i = $$24467$i;$162 = $635;
      } else {
       $152 = (($148) + -4)|0;
       $153 = $152 >>> 2;
       $154 = (($153) + 1)|0;
       $155 = Math_imul($154, $$063$i)|0;
       $$165$i = $$04168$i;$$364$i = $$24467$i;
       while(1) {
        $156 = HEAPU8[$$364$i>>0]|(HEAPU8[$$364$i+1>>0]<<8)|(HEAPU8[$$364$i+2>>0]<<16)|(HEAPU8[$$364$i+3>>0]<<24);
        HEAP8[$$165$i>>0]=$156&255;HEAP8[$$165$i+1>>0]=($156>>8)&255;HEAP8[$$165$i+2>>0]=($156>>16)&255;HEAP8[$$165$i+3>>0]=$156>>24;
        $157 = (($$364$i) + ($$063$i)|0);
        $158 = ((($$165$i)) + 4|0);
        $159 = ($158|0)==($150|0);
        if ($159) {
         break;
        } else {
         $$165$i = $158;$$364$i = $157;
        }
       }
       $scevgep$i = (($$24467$i) + ($155)|0);
       $scevgep73$i = ((($$04168$i)) + 4|0);
       $scevgep74$i = (($scevgep73$i) + ($152)|0);
       $$pre75$i = HEAP32[$56>>2]|0;
       $$1$lcssa$i = $scevgep74$i;$$3$lcssa$i = $scevgep$i;$162 = $$pre75$i;
      }
      $160 = (($$069$i) + 1)|0;
      $161 = ($160|0)<($162|0);
      if (!($161)) {
       break L32;
      }
      $163 = (($$1$lcssa$i) + ($90)|0);
      $164 = (($$3$lcssa$i) + ($$062$i)|0);
      $$pre$i = HEAP32[$87>>2]|0;
      $$04168$i = $163;$$069$i = $160;$$24467$i = $164;$149 = $$pre$i;$635 = $162;
     }
    }
   } else {
    $165 = (~~(($166)));
    $167 = (~~(($168)));
    $169 = ((($$0104160)) + 8|0);
    $170 = HEAP32[$169>>2]|0;
    $171 = ((($$0109)) + 8|0);
    $172 = HEAP32[$171>>2]|0;
    $173 = (($170) - ($172))|0;
    $174 = $173 << 15;
    $175 = ((($$0104160)) + 12|0);
    $176 = HEAP32[$175>>2]|0;
    $177 = HEAP32[$56>>2]|0;
    $178 = (($176) - ($177))|0;
    $179 = $178 << 15;
    $180 = (65536 - ($167))|0;
    $181 = Math_imul($180, $2)|0;
    $182 = $3 << 16;
    $183 = Math_imul($165, $2)|0;
    $184 = (($182) - ($183))|0;
    $185 = (($170) + -1)|0;
    $186 = (($176) + -1)|0;
    $187 = ((($$0109)) + 20|0);
    $188 = HEAP32[$187>>2]|0;
    $189 = ((($$0109)) + 16|0);
    $190 = HEAP32[$189>>2]|0;
    $191 = $172 << 2;
    $192 = (($190) - ($191))|0;
    $193 = ($4|0)==(0);
    $194 = ($177|0)>(0);
    if (!($193)) {
     if (!($194)) {
      break;
     }
     $195 = (($174) + ($181))|0;
     $196 = (($179) + ($184))|0;
     $197 = ($5|0)!=(0);
     $198 = ($6|0)!=(0);
     $199 = ((($$0104160)) + 20|0);
     $200 = ((($$0104160)) + 16|0);
     $$0283320$i = 0;$$0285319$i = $188;$208 = $172;$636 = $177;
     while(1) {
      $207 = (($3) - ($$0283320$i))|0;
      $209 = ($208|0)>(0);
      if ($209) {
       $210 = Math_imul($207, $167)|0;
       $211 = (($196) - ($210))|0;
       $212 = Math_imul($207, $165)|0;
       $213 = (($195) + ($212))|0;
       $$0291312$i = $213;$$0293311$i = $211;$$0314$i = 0;$$1286313$i = $$0285319$i;$638 = $208;
       while(1) {
        $214 = $$0291312$i >> 16;
        $215 = $$0293311$i >> 16;
        $216 = (($185) - ($214))|0;
        $$$i = $197 ? $216 : $214;
        $217 = (($186) - ($215))|0;
        $$0289$i = $198 ? $217 : $215;
        $218 = ($$$i>>>0)<($185>>>0);
        $219 = ($$0289$i>>>0)<($186>>>0);
        $or$cond$i = $218 & $219;
        if ($or$cond$i) {
         $220 = HEAP32[$199>>2]|0;
         $221 = HEAP32[$200>>2]|0;
         $222 = Math_imul($221, $$0289$i)|0;
         $223 = (($220) + ($222)|0);
         $224 = (($223) + ($$$i<<2)|0);
         $$sroa$0126$0$copyload$i = HEAP8[$224>>0]|0;
         $$sroa$9128$0$$sroa_idx$i = (((($223) + ($$$i<<2)|0)) + 1|0);
         $$sroa$9128$0$copyload$i = HEAP8[$$sroa$9128$0$$sroa_idx$i>>0]|0;
         $$sroa$15$0$$sroa_idx$i = (((($223) + ($$$i<<2)|0)) + 2|0);
         $$sroa$15$0$copyload$i = HEAP8[$$sroa$15$0$$sroa_idx$i>>0]|0;
         $$sroa$21$0$$sroa_idx$i = (((($223) + ($$$i<<2)|0)) + 3|0);
         $$sroa$21$0$copyload$i = HEAP8[$$sroa$21$0$$sroa_idx$i>>0]|0;
         $225 = ((($224)) + 4|0);
         $$sroa$0114$0$copyload116$i = HEAP8[$225>>0]|0;
         $$sroa$8117$0$$sroa_idx118$i = ((($225)) + 1|0);
         $$sroa$8117$0$copyload119$i = HEAP8[$$sroa$8117$0$$sroa_idx118$i>>0]|0;
         $$sroa$12120$0$$sroa_idx121$i = ((($225)) + 2|0);
         $$sroa$12120$0$copyload122$i = HEAP8[$$sroa$12120$0$$sroa_idx121$i>>0]|0;
         $$sroa$16$0$$sroa_idx123$i = ((($225)) + 3|0);
         $$sroa$16$0$copyload124$i = HEAP8[$$sroa$16$0$$sroa_idx123$i>>0]|0;
         $226 = (($221|0) / 4)&-1;
         $227 = (($225) + ($226<<2)|0);
         $$sroa$0$0$copyload$i = HEAP8[$227>>0]|0;
         $$sroa$8$0$$sroa_idx$i = ((($227)) + 1|0);
         $$sroa$8$0$copyload$i = HEAP8[$$sroa$8$0$$sroa_idx$i>>0]|0;
         $$sroa$9$0$$sroa_idx$i = ((($227)) + 2|0);
         $$sroa$9$0$copyload$i = HEAP8[$$sroa$9$0$$sroa_idx$i>>0]|0;
         $$sroa$10$0$$sroa_idx$i = ((($227)) + 3|0);
         $$sroa$10$0$copyload$i = HEAP8[$$sroa$10$0$$sroa_idx$i>>0]|0;
         $228 = ((($227)) + -4|0);
         $$sroa$098$0$copyload101$i = HEAP8[$228>>0]|0;
         $$sroa$9102$0$$sroa_idx103$i = ((($228)) + 1|0);
         $$sroa$9102$0$copyload104$i = HEAP8[$$sroa$9102$0$$sroa_idx103$i>>0]|0;
         $$sroa$14106$0$$sroa_idx107$i = ((($228)) + 2|0);
         $$sroa$14106$0$copyload108$i = HEAP8[$$sroa$14106$0$$sroa_idx107$i>>0]|0;
         $$sroa$19$0$$sroa_idx110$i = ((($228)) + 3|0);
         $$sroa$19$0$copyload111$i = HEAP8[$$sroa$19$0$$sroa_idx110$i>>0]|0;
         $$sroa$16$0$copyload124$$sroa$21$0$copyload$i = $197 ? $$sroa$16$0$copyload124$i : $$sroa$21$0$copyload$i;
         $$sroa$12120$0$copyload122$$sroa$15$0$copyload$i = $197 ? $$sroa$12120$0$copyload122$i : $$sroa$15$0$copyload$i;
         $$sroa$8117$0$copyload119$$sroa$9128$0$copyload$i = $197 ? $$sroa$8117$0$copyload119$i : $$sroa$9128$0$copyload$i;
         $$sroa$0114$0$copyload116$$sroa$0126$0$copyload$i = $197 ? $$sroa$0114$0$copyload116$i : $$sroa$0126$0$copyload$i;
         $$sroa$21$0$copyload$$sroa$16$0$copyload124$i = $197 ? $$sroa$21$0$copyload$i : $$sroa$16$0$copyload124$i;
         $$sroa$15$0$copyload$$sroa$12120$0$copyload122$i = $197 ? $$sroa$15$0$copyload$i : $$sroa$12120$0$copyload122$i;
         $$sroa$9128$0$copyload$$sroa$8117$0$copyload119$i = $197 ? $$sroa$9128$0$copyload$i : $$sroa$8117$0$copyload119$i;
         $$sroa$0126$0$copyload$$sroa$0114$0$copyload116$i = $197 ? $$sroa$0126$0$copyload$i : $$sroa$0114$0$copyload116$i;
         $$sroa$10$0$copyload$$sroa$19$0$copyload111$i = $197 ? $$sroa$10$0$copyload$i : $$sroa$19$0$copyload111$i;
         $$sroa$9$0$copyload$$sroa$14106$0$copyload108$i = $197 ? $$sroa$9$0$copyload$i : $$sroa$14106$0$copyload108$i;
         $$sroa$8$0$copyload$$sroa$9102$0$copyload104$i = $197 ? $$sroa$8$0$copyload$i : $$sroa$9102$0$copyload104$i;
         $$sroa$0$0$copyload$$sroa$098$0$copyload101$i = $197 ? $$sroa$0$0$copyload$i : $$sroa$098$0$copyload101$i;
         $$sroa$19$0$copyload111$$sroa$10$0$copyload$i = $197 ? $$sroa$19$0$copyload111$i : $$sroa$10$0$copyload$i;
         $$sroa$14106$0$copyload108$$sroa$9$0$copyload$i = $197 ? $$sroa$14106$0$copyload108$i : $$sroa$9$0$copyload$i;
         $$sroa$9102$0$copyload104$$sroa$8$0$copyload$i = $197 ? $$sroa$9102$0$copyload104$i : $$sroa$8$0$copyload$i;
         $$sroa$098$0$copyload101$$sroa$0$0$copyload$i = $197 ? $$sroa$098$0$copyload101$i : $$sroa$0$0$copyload$i;
         $$sroa$10$0$copyload$$sroa$19$0$copyload111$$sroa$16$0$copyload124$$sroa$21$0$copyload$i = $198 ? $$sroa$10$0$copyload$$sroa$19$0$copyload111$i : $$sroa$16$0$copyload124$$sroa$21$0$copyload$i;
         $$sroa$9$0$copyload$$sroa$14106$0$copyload108$$sroa$12120$0$copyload122$$sroa$15$0$copyload$i = $198 ? $$sroa$9$0$copyload$$sroa$14106$0$copyload108$i : $$sroa$12120$0$copyload122$$sroa$15$0$copyload$i;
         $$sroa$8$0$copyload$$sroa$9102$0$copyload104$$sroa$8117$0$copyload119$$sroa$9128$0$copyload$i = $198 ? $$sroa$8$0$copyload$$sroa$9102$0$copyload104$i : $$sroa$8117$0$copyload119$$sroa$9128$0$copyload$i;
         $$sroa$0$0$copyload$$sroa$098$0$copyload101$$sroa$0114$0$copyload116$$sroa$0126$0$copyload$i = $198 ? $$sroa$0$0$copyload$$sroa$098$0$copyload101$i : $$sroa$0114$0$copyload116$$sroa$0126$0$copyload$i;
         $$sroa$19$0$copyload111$$sroa$10$0$copyload$$sroa$21$0$copyload$$sroa$16$0$copyload124$i = $198 ? $$sroa$19$0$copyload111$$sroa$10$0$copyload$i : $$sroa$21$0$copyload$$sroa$16$0$copyload124$i;
         $$sroa$14106$0$copyload108$$sroa$9$0$copyload$$sroa$15$0$copyload$$sroa$12120$0$copyload122$i = $198 ? $$sroa$14106$0$copyload108$$sroa$9$0$copyload$i : $$sroa$15$0$copyload$$sroa$12120$0$copyload122$i;
         $$sroa$9102$0$copyload104$$sroa$8$0$copyload$$sroa$9128$0$copyload$$sroa$8117$0$copyload119$i = $198 ? $$sroa$9102$0$copyload104$$sroa$8$0$copyload$i : $$sroa$9128$0$copyload$$sroa$8117$0$copyload119$i;
         $$sroa$098$0$copyload101$$sroa$0$0$copyload$$sroa$0126$0$copyload$$sroa$0114$0$copyload116$i = $198 ? $$sroa$098$0$copyload101$$sroa$0$0$copyload$i : $$sroa$0126$0$copyload$$sroa$0114$0$copyload116$i;
         $$sroa$16$0$copyload124$$sroa$21$0$copyload$$sroa$10$0$copyload$$sroa$19$0$copyload111$i = $198 ? $$sroa$16$0$copyload124$$sroa$21$0$copyload$i : $$sroa$10$0$copyload$$sroa$19$0$copyload111$i;
         $$sroa$12120$0$copyload122$$sroa$15$0$copyload$$sroa$9$0$copyload$$sroa$14106$0$copyload108$i = $198 ? $$sroa$12120$0$copyload122$$sroa$15$0$copyload$i : $$sroa$9$0$copyload$$sroa$14106$0$copyload108$i;
         $$sroa$8117$0$copyload119$$sroa$9128$0$copyload$$sroa$8$0$copyload$$sroa$9102$0$copyload104$i = $198 ? $$sroa$8117$0$copyload119$$sroa$9128$0$copyload$i : $$sroa$8$0$copyload$$sroa$9102$0$copyload104$i;
         $$sroa$0114$0$copyload116$$sroa$0126$0$copyload$$sroa$0$0$copyload$$sroa$098$0$copyload101$i = $198 ? $$sroa$0114$0$copyload116$$sroa$0126$0$copyload$i : $$sroa$0$0$copyload$$sroa$098$0$copyload101$i;
         $$sroa$21$0$copyload$$sroa$16$0$copyload124$$sroa$19$0$copyload111$$sroa$10$0$copyload$i = $198 ? $$sroa$21$0$copyload$$sroa$16$0$copyload124$i : $$sroa$19$0$copyload111$$sroa$10$0$copyload$i;
         $$sroa$15$0$copyload$$sroa$12120$0$copyload122$$sroa$14106$0$copyload108$$sroa$9$0$copyload$i = $198 ? $$sroa$15$0$copyload$$sroa$12120$0$copyload122$i : $$sroa$14106$0$copyload108$$sroa$9$0$copyload$i;
         $$sroa$9128$0$copyload$$sroa$8117$0$copyload119$$sroa$9102$0$copyload104$$sroa$8$0$copyload$i = $198 ? $$sroa$9128$0$copyload$$sroa$8117$0$copyload119$i : $$sroa$9102$0$copyload104$$sroa$8$0$copyload$i;
         $$sroa$0126$0$copyload$$sroa$0114$0$copyload116$$sroa$098$0$copyload101$$sroa$0$0$copyload$i = $198 ? $$sroa$0126$0$copyload$$sroa$0114$0$copyload116$i : $$sroa$098$0$copyload101$$sroa$0$0$copyload$i;
         $229 = $$0291312$i & 65535;
         $230 = $$0293311$i & 65535;
         $231 = $$sroa$098$0$copyload101$$sroa$0$0$copyload$$sroa$0126$0$copyload$$sroa$0114$0$copyload116$i&255;
         $232 = $$sroa$0$0$copyload$$sroa$098$0$copyload101$$sroa$0114$0$copyload116$$sroa$0126$0$copyload$i&255;
         $233 = (($231) - ($232))|0;
         $234 = Math_imul($233, $229)|0;
         $235 = $234 >>> 16;
         $236 = (($235) + ($232))|0;
         $237 = $236 & 255;
         $238 = $$sroa$0126$0$copyload$$sroa$0114$0$copyload116$$sroa$098$0$copyload101$$sroa$0$0$copyload$i&255;
         $239 = $$sroa$0114$0$copyload116$$sroa$0126$0$copyload$$sroa$0$0$copyload$$sroa$098$0$copyload101$i&255;
         $240 = (($238) - ($239))|0;
         $241 = Math_imul($240, $229)|0;
         $242 = $241 >>> 16;
         $243 = (($242) + ($239))|0;
         $244 = $243 & 255;
         $245 = (($244) - ($237))|0;
         $246 = Math_imul($245, $230)|0;
         $247 = $246 >>> 16;
         $248 = (($247) + ($236))|0;
         $249 = $248&255;
         HEAP8[$$1286313$i>>0] = $249;
         $250 = $$sroa$9102$0$copyload104$$sroa$8$0$copyload$$sroa$9128$0$copyload$$sroa$8117$0$copyload119$i&255;
         $251 = $$sroa$8$0$copyload$$sroa$9102$0$copyload104$$sroa$8117$0$copyload119$$sroa$9128$0$copyload$i&255;
         $252 = (($250) - ($251))|0;
         $253 = Math_imul($252, $229)|0;
         $254 = $253 >>> 16;
         $255 = (($254) + ($251))|0;
         $256 = $255 & 255;
         $257 = $$sroa$9128$0$copyload$$sroa$8117$0$copyload119$$sroa$9102$0$copyload104$$sroa$8$0$copyload$i&255;
         $258 = $$sroa$8117$0$copyload119$$sroa$9128$0$copyload$$sroa$8$0$copyload$$sroa$9102$0$copyload104$i&255;
         $259 = (($257) - ($258))|0;
         $260 = Math_imul($259, $229)|0;
         $261 = $260 >>> 16;
         $262 = (($261) + ($258))|0;
         $263 = $262 & 255;
         $264 = (($263) - ($256))|0;
         $265 = Math_imul($264, $230)|0;
         $266 = $265 >>> 16;
         $267 = (($266) + ($255))|0;
         $268 = $267&255;
         $269 = ((($$1286313$i)) + 1|0);
         HEAP8[$269>>0] = $268;
         $270 = $$sroa$14106$0$copyload108$$sroa$9$0$copyload$$sroa$15$0$copyload$$sroa$12120$0$copyload122$i&255;
         $271 = $$sroa$9$0$copyload$$sroa$14106$0$copyload108$$sroa$12120$0$copyload122$$sroa$15$0$copyload$i&255;
         $272 = (($270) - ($271))|0;
         $273 = Math_imul($272, $229)|0;
         $274 = $273 >>> 16;
         $275 = (($274) + ($271))|0;
         $276 = $275 & 255;
         $277 = $$sroa$15$0$copyload$$sroa$12120$0$copyload122$$sroa$14106$0$copyload108$$sroa$9$0$copyload$i&255;
         $278 = $$sroa$12120$0$copyload122$$sroa$15$0$copyload$$sroa$9$0$copyload$$sroa$14106$0$copyload108$i&255;
         $279 = (($277) - ($278))|0;
         $280 = Math_imul($279, $229)|0;
         $281 = $280 >>> 16;
         $282 = (($281) + ($278))|0;
         $283 = $282 & 255;
         $284 = (($283) - ($276))|0;
         $285 = Math_imul($284, $230)|0;
         $286 = $285 >>> 16;
         $287 = (($286) + ($275))|0;
         $288 = $287&255;
         $289 = ((($$1286313$i)) + 2|0);
         HEAP8[$289>>0] = $288;
         $290 = $$sroa$19$0$copyload111$$sroa$10$0$copyload$$sroa$21$0$copyload$$sroa$16$0$copyload124$i&255;
         $291 = $$sroa$10$0$copyload$$sroa$19$0$copyload111$$sroa$16$0$copyload124$$sroa$21$0$copyload$i&255;
         $292 = (($290) - ($291))|0;
         $293 = Math_imul($292, $229)|0;
         $294 = $293 >>> 16;
         $295 = (($294) + ($291))|0;
         $296 = $295 & 255;
         $297 = $$sroa$21$0$copyload$$sroa$16$0$copyload124$$sroa$19$0$copyload111$$sroa$10$0$copyload$i&255;
         $298 = $$sroa$16$0$copyload124$$sroa$21$0$copyload$$sroa$10$0$copyload$$sroa$19$0$copyload111$i&255;
         $299 = (($297) - ($298))|0;
         $300 = Math_imul($299, $229)|0;
         $301 = $300 >>> 16;
         $302 = (($301) + ($298))|0;
         $303 = $302 & 255;
         $304 = (($303) - ($296))|0;
         $305 = Math_imul($304, $230)|0;
         $306 = $305 >>> 16;
         $307 = (($306) + ($295))|0;
         $308 = $307&255;
         $309 = ((($$1286313$i)) + 3|0);
         HEAP8[$309>>0] = $308;
         $$pre$i111 = HEAP32[$171>>2]|0;
         $315 = $$pre$i111;
        } else {
         $315 = $638;
        }
        $310 = (($$0291312$i) + ($167))|0;
        $311 = (($$0293311$i) + ($165))|0;
        $312 = ((($$1286313$i)) + 4|0);
        $313 = (($$0314$i) + 1)|0;
        $314 = ($313|0)<($315|0);
        if ($314) {
         $$0291312$i = $310;$$0293311$i = $311;$$0314$i = $313;$$1286313$i = $312;$638 = $315;
        } else {
         break;
        }
       }
       $$pre330$i = HEAP32[$56>>2]|0;
       $$1286$lcssa$i = $312;$319 = $$pre330$i;$637 = $315;
      } else {
       $$1286$lcssa$i = $$0285319$i;$319 = $636;$637 = $208;
      }
      $316 = (($$1286$lcssa$i) + ($192)|0);
      $317 = (($$0283320$i) + 1)|0;
      $318 = ($317|0)<($319|0);
      if ($318) {
       $$0283320$i = $317;$$0285319$i = $316;$208 = $637;$636 = $319;
      } else {
       break L32;
      }
     }
    }
    if ($194) {
     $201 = (($174) + ($181))|0;
     $202 = (($179) + ($184))|0;
     $203 = ($5|0)==(0);
     $204 = ($6|0)==(0);
     $205 = ((($$0104160)) + 20|0);
     $206 = ((($$0104160)) + 16|0);
     $$1284309$i = 0;$$2308$i = $188;$325 = $172;
     while(1) {
      $320 = (($3) - ($$1284309$i))|0;
      $321 = Math_imul($320, $165)|0;
      $322 = (($201) + ($321))|0;
      $323 = Math_imul($320, $167)|0;
      $324 = (($202) - ($323))|0;
      $326 = ($325|0)>(0);
      if ($326) {
       if ($203) {
        if ($204) {
         $$1292300$us$us$i = $322;$$1294299$us$us$i = $324;$$1302$us$us$i = 0;$$3301$us$us$i = $$2308$i;$640 = $325;
         while(1) {
          $327 = $$1292300$us$us$i >> 16;
          $328 = $$1294299$us$us$i >> 16;
          $329 = HEAP32[$169>>2]|0;
          $330 = ($327>>>0)<($329>>>0);
          do {
           if ($330) {
            $331 = HEAP32[$175>>2]|0;
            $332 = ($328>>>0)<($331>>>0);
            if (!($332)) {
             $344 = $640;
             break;
            }
            $333 = HEAP32[$205>>2]|0;
            $334 = HEAP32[$206>>2]|0;
            $335 = Math_imul($334, $328)|0;
            $336 = (($333) + ($335)|0);
            $337 = (($336) + ($327<<2)|0);
            $338 = HEAPU8[$337>>0]|(HEAPU8[$337+1>>0]<<8)|(HEAPU8[$337+2>>0]<<16)|(HEAPU8[$337+3>>0]<<24);
            HEAP8[$$3301$us$us$i>>0]=$338&255;HEAP8[$$3301$us$us$i+1>>0]=($338>>8)&255;HEAP8[$$3301$us$us$i+2>>0]=($338>>16)&255;HEAP8[$$3301$us$us$i+3>>0]=$338>>24;
            $$pre334$i = HEAP32[$171>>2]|0;
            $344 = $$pre334$i;
           } else {
            $344 = $640;
           }
          } while(0);
          $339 = (($$1292300$us$us$i) + ($167))|0;
          $340 = (($$1294299$us$us$i) + ($165))|0;
          $341 = ((($$3301$us$us$i)) + 4|0);
          $342 = (($$1302$us$us$i) + 1)|0;
          $343 = ($342|0)<($344|0);
          if ($343) {
           $$1292300$us$us$i = $339;$$1294299$us$us$i = $340;$$1302$us$us$i = $342;$$3301$us$us$i = $341;$640 = $344;
          } else {
           $$3$lcssa$i113 = $341;$639 = $344;
           break;
          }
         }
        } else {
         $$1292300$us$i = $322;$$1294299$us$i = $324;$$1302$us$i = 0;$$3301$us$i = $$2308$i;$641 = $325;
         while(1) {
          $345 = $$1292300$us$i >> 16;
          $346 = $$1294299$us$i >> 16;
          $347 = HEAP32[$169>>2]|0;
          $348 = ($345>>>0)<($347>>>0);
          do {
           if ($348) {
            $349 = HEAP32[$175>>2]|0;
            $350 = ($346>>>0)<($349>>>0);
            if (!($350)) {
             $363 = $641;
             break;
            }
            $351 = (($186) - ($346))|0;
            $352 = HEAP32[$205>>2]|0;
            $353 = HEAP32[$206>>2]|0;
            $354 = Math_imul($353, $351)|0;
            $355 = (($352) + ($354)|0);
            $356 = (($355) + ($345<<2)|0);
            $357 = HEAPU8[$356>>0]|(HEAPU8[$356+1>>0]<<8)|(HEAPU8[$356+2>>0]<<16)|(HEAPU8[$356+3>>0]<<24);
            HEAP8[$$3301$us$i>>0]=$357&255;HEAP8[$$3301$us$i+1>>0]=($357>>8)&255;HEAP8[$$3301$us$i+2>>0]=($357>>16)&255;HEAP8[$$3301$us$i+3>>0]=$357>>24;
            $$pre333$i = HEAP32[$171>>2]|0;
            $363 = $$pre333$i;
           } else {
            $363 = $641;
           }
          } while(0);
          $358 = (($$1292300$us$i) + ($167))|0;
          $359 = (($$1294299$us$i) + ($165))|0;
          $360 = ((($$3301$us$i)) + 4|0);
          $361 = (($$1302$us$i) + 1)|0;
          $362 = ($361|0)<($363|0);
          if ($362) {
           $$1292300$us$i = $358;$$1294299$us$i = $359;$$1302$us$i = $361;$$3301$us$i = $360;$641 = $363;
          } else {
           $$3$lcssa$i113 = $360;$639 = $363;
           break;
          }
         }
        }
       } else {
        if ($204) {
         $$1292300$us305$i = $322;$$1294299$us306$i = $324;$$1302$us303$i = 0;$$3301$us304$i = $$2308$i;$642 = $325;
         while(1) {
          $364 = $$1292300$us305$i >> 16;
          $365 = $$1294299$us306$i >> 16;
          $366 = HEAP32[$169>>2]|0;
          $367 = ($364>>>0)<($366>>>0);
          do {
           if ($367) {
            $368 = HEAP32[$175>>2]|0;
            $369 = ($365>>>0)<($368>>>0);
            if (!($369)) {
             $382 = $642;
             break;
            }
            $370 = (($185) - ($364))|0;
            $371 = HEAP32[$205>>2]|0;
            $372 = HEAP32[$206>>2]|0;
            $373 = Math_imul($372, $365)|0;
            $374 = (($371) + ($373)|0);
            $375 = (($374) + ($370<<2)|0);
            $376 = HEAPU8[$375>>0]|(HEAPU8[$375+1>>0]<<8)|(HEAPU8[$375+2>>0]<<16)|(HEAPU8[$375+3>>0]<<24);
            HEAP8[$$3301$us304$i>>0]=$376&255;HEAP8[$$3301$us304$i+1>>0]=($376>>8)&255;HEAP8[$$3301$us304$i+2>>0]=($376>>16)&255;HEAP8[$$3301$us304$i+3>>0]=$376>>24;
            $$pre332$i = HEAP32[$171>>2]|0;
            $382 = $$pre332$i;
           } else {
            $382 = $642;
           }
          } while(0);
          $377 = (($$1292300$us305$i) + ($167))|0;
          $378 = (($$1294299$us306$i) + ($165))|0;
          $379 = ((($$3301$us304$i)) + 4|0);
          $380 = (($$1302$us303$i) + 1)|0;
          $381 = ($380|0)<($382|0);
          if ($381) {
           $$1292300$us305$i = $377;$$1294299$us306$i = $378;$$1302$us303$i = $380;$$3301$us304$i = $379;$642 = $382;
          } else {
           $$3$lcssa$i113 = $379;$639 = $382;
           break;
          }
         }
        } else {
         $$1292300$i = $322;$$1294299$i = $324;$$1302$i = 0;$$3301$i = $$2308$i;$643 = $325;
         while(1) {
          $383 = $$1292300$i >> 16;
          $384 = $$1294299$i >> 16;
          $385 = HEAP32[$169>>2]|0;
          $386 = ($383>>>0)<($385>>>0);
          do {
           if ($386) {
            $387 = HEAP32[$175>>2]|0;
            $388 = ($384>>>0)<($387>>>0);
            if (!($388)) {
             $402 = $643;
             break;
            }
            $389 = (($185) - ($383))|0;
            $390 = (($186) - ($384))|0;
            $391 = HEAP32[$205>>2]|0;
            $392 = HEAP32[$206>>2]|0;
            $393 = Math_imul($392, $390)|0;
            $394 = (($391) + ($393)|0);
            $395 = (($394) + ($389<<2)|0);
            $396 = HEAPU8[$395>>0]|(HEAPU8[$395+1>>0]<<8)|(HEAPU8[$395+2>>0]<<16)|(HEAPU8[$395+3>>0]<<24);
            HEAP8[$$3301$i>>0]=$396&255;HEAP8[$$3301$i+1>>0]=($396>>8)&255;HEAP8[$$3301$i+2>>0]=($396>>16)&255;HEAP8[$$3301$i+3>>0]=$396>>24;
            $$pre331$i = HEAP32[$171>>2]|0;
            $402 = $$pre331$i;
           } else {
            $402 = $643;
           }
          } while(0);
          $397 = (($$1292300$i) + ($167))|0;
          $398 = (($$1294299$i) + ($165))|0;
          $399 = ((($$3301$i)) + 4|0);
          $400 = (($$1302$i) + 1)|0;
          $401 = ($400|0)<($402|0);
          if ($401) {
           $$1292300$i = $397;$$1294299$i = $398;$$1302$i = $400;$$3301$i = $399;$643 = $402;
          } else {
           $$3$lcssa$i113 = $399;$639 = $402;
           break;
          }
         }
        }
       }
      } else {
       $$3$lcssa$i113 = $$2308$i;$639 = $325;
      }
      $403 = (($$3$lcssa$i113) + ($192)|0);
      $404 = (($$1284309$i) + 1)|0;
      $405 = HEAP32[$56>>2]|0;
      $406 = ($404|0)<($405|0);
      if ($406) {
       $$1284309$i = $404;$$2308$i = $403;$325 = $639;
      } else {
       break;
      }
     }
    }
   }
  } while(0);
  HEAP32[$12>>2] = 0;
  (_SDL_GetColorKey($$0104160,$12)|0);
  $407 = HEAP32[$12>>2]|0;
  (_SDL_SetColorKey($$0109,3,$407)|0);
 } else {
  $74 = ((($$0104160)) + 4|0);
  $75 = HEAP32[$74>>2]|0;
  $76 = ((($75)) + 4|0);
  $77 = HEAP32[$76>>2]|0;
  $78 = HEAP32[$77>>2]|0;
  $79 = ($78|0)>(0);
  $80 = ((($$0109)) + 4|0);
  $81 = HEAP32[$80>>2]|0;
  $82 = ((($81)) + 4|0);
  $83 = HEAP32[$82>>2]|0;
  if ($79) {
   $$0106193 = 0;$409 = $83;$412 = $77;
   while(1) {
    $408 = ((($409)) + 4|0);
    $410 = HEAP32[$408>>2]|0;
    $411 = ((($412)) + 4|0);
    $413 = HEAP32[$411>>2]|0;
    $414 = (($410) + ($$0106193<<2)|0);
    $415 = (($413) + ($$0106193<<2)|0);
    $416 = HEAPU8[$415>>0]|(HEAPU8[$415+1>>0]<<8)|(HEAPU8[$415+2>>0]<<16)|(HEAPU8[$415+3>>0]<<24);
    HEAP8[$414>>0]=$416&255;HEAP8[$414+1>>0]=($416>>8)&255;HEAP8[$414+2>>0]=($416>>16)&255;HEAP8[$414+3>>0]=$416>>24;
    $417 = (($$0106193) + 1)|0;
    $418 = HEAP32[$74>>2]|0;
    $419 = ((($418)) + 4|0);
    $420 = HEAP32[$419>>2]|0;
    $421 = HEAP32[$420>>2]|0;
    $422 = ($417|0)<($421|0);
    $423 = HEAP32[$80>>2]|0;
    $424 = ((($423)) + 4|0);
    $425 = HEAP32[$424>>2]|0;
    if ($422) {
     $$0106193 = $417;$409 = $425;$412 = $420;
    } else {
     $$lcssa191 = $425;$$lcssa192 = $421;
     break;
    }
   }
  } else {
   $$lcssa191 = $83;$$lcssa192 = $78;
  }
  HEAP32[$$lcssa191>>2] = $$lcssa192;
  $426 = ($$0107|0)>(-1);
  L116: do {
   if ($426) {
    $427 = ((($$0109)) + 16|0);
    $428 = HEAP32[$427>>2]|0;
    $429 = ((($$0109)) + 8|0);
    $430 = HEAP32[$429>>2]|0;
    $431 = (($428) - ($430))|0;
    $432 = ((($$0104160)) + 20|0);
    $433 = HEAP32[$432>>2]|0;
    $434 = ((($$0109)) + 20|0);
    $435 = HEAP32[$434>>2]|0;
    $436 = ($6|0)!=(0);
    $437 = ((($$0104160)) + 16|0);
    $438 = HEAP32[$437>>2]|0;
    $439 = (0 - ($438))|0;
    $440 = $436 ? $439 : $438;
    $441 = ($5|0)!=(0);
    $$$i$i115 = $441 ? -1 : 1;
    switch ($$0107|0) {
    case 0:  {
     $442 = ((($$0104160)) + 8|0);
     $443 = HEAP32[$442>>2]|0;
     $444 = Math_imul($443, $$$i$i115)|0;
     $445 = (($440) - ($444))|0;
     $$058$i119 = 1;$$060$i118 = 1;$$062$i117 = $445;$$063$i116 = $$$i$i115;
     break;
    }
    case 1:  {
     $446 = (0 - ($440))|0;
     $447 = ((($$0104160)) + 12|0);
     $448 = HEAP32[$447>>2]|0;
     $449 = Math_imul($448, $440)|0;
     $450 = (($449) + ($$$i$i115))|0;
     $$058$i119 = -1;$$060$i118 = 1;$$062$i117 = $450;$$063$i116 = $446;
     break;
    }
    case 2:  {
     $451 = (0 - ($$$i$i115))|0;
     $452 = ((($$0104160)) + 8|0);
     $453 = HEAP32[$452>>2]|0;
     $454 = Math_imul($453, $$$i$i115)|0;
     $455 = (($454) - ($440))|0;
     $$058$i119 = -1;$$060$i118 = -1;$$062$i117 = $455;$$063$i116 = $451;
     break;
    }
    default: {
     $456 = (0 - ($440))|0;
     $457 = ((($$0104160)) + 12|0);
     $458 = HEAP32[$457>>2]|0;
     $459 = Math_imul($458, $456)|0;
     $460 = (($459) - ($$$i$i115))|0;
     $$058$i119 = 1;$$060$i118 = -1;$$062$i117 = $460;$$063$i116 = $440;
    }
    }
    $461 = (0 - ($$060$i118))|0;
    $$$060$i120 = $441 ? $461 : $$060$i118;
    $462 = (0 - ($$058$i119))|0;
    $$159$i121 = $436 ? $462 : $$058$i119;
    $463 = ($$$060$i120|0)<(0);
    if ($463) {
     $464 = ((($$0104160)) + 8|0);
     $465 = HEAP32[$464>>2]|0;
     $466 = (($465) + -1)|0;
     $467 = (($433) + ($466)|0);
     $$042$i123 = $467;
    } else {
     $$042$i123 = $433;
    }
    $468 = ($$159$i121|0)<(0);
    if ($468) {
     $469 = ((($$0104160)) + 12|0);
     $470 = HEAP32[$469>>2]|0;
     $471 = (($470) + -1)|0;
     $472 = Math_imul($471, $438)|0;
     $473 = (($$042$i123) + ($472)|0);
     $$244$ph$i124 = $473;
    } else {
     $$244$ph$i124 = $$042$i123;
    }
    $474 = HEAP32[$56>>2]|0;
    $475 = ($474|0)>(0);
    if ($475) {
     $476 = ($$063$i116|0)==(1);
     if ($476) {
      $$04168$us$i128 = $435;$$069$us$i127 = 0;$$24467$us$i129 = $$244$ph$i124;$477 = $430;
      while(1) {
       (_SDL_memcpy($$04168$us$i128,$$24467$us$i129,$477)|0);
       $478 = HEAP32[$429>>2]|0;
       $479 = (($$24467$us$i129) + ($478)|0);
       $480 = (($$04168$us$i128) + ($478)|0);
       $481 = (($479) + ($$062$i117)|0);
       $482 = (($480) + ($431)|0);
       $483 = (($$069$us$i127) + 1)|0;
       $484 = HEAP32[$56>>2]|0;
       $485 = ($483|0)<($484|0);
       if ($485) {
        $$04168$us$i128 = $482;$$069$us$i127 = $483;$$24467$us$i129 = $481;$477 = $478;
       } else {
        break L116;
       }
      }
     } else {
      $$04168$i132 = $435;$$069$i131 = 0;$$24467$i133 = $$244$ph$i124;$487 = $430;$644 = $474;
     }
     while(1) {
      $486 = (($$04168$i132) + ($487)|0);
      $488 = ($487|0)==(0);
      if ($488) {
       $$1$lcssa$i142 = $$04168$i132;$$3$lcssa$i141 = $$24467$i133;$496 = $644;
      } else {
       $$165$i136 = $$04168$i132;$$364$i137 = $$24467$i133;
       while(1) {
        $489 = HEAP8[$$364$i137>>0]|0;
        HEAP8[$$165$i136>>0] = $489;
        $490 = (($$364$i137) + ($$063$i116)|0);
        $491 = ((($$165$i136)) + 1|0);
        $492 = ($491|0)==($486|0);
        if ($492) {
         break;
        } else {
         $$165$i136 = $491;$$364$i137 = $490;
        }
       }
       $493 = Math_imul($487, $$063$i116)|0;
       $scevgep$i139 = (($$24467$i133) + ($493)|0);
       $$pre73$i = HEAP32[$56>>2]|0;
       $$1$lcssa$i142 = $486;$$3$lcssa$i141 = $scevgep$i139;$496 = $$pre73$i;
      }
      $494 = (($$069$i131) + 1)|0;
      $495 = ($494|0)<($496|0);
      if (!($495)) {
       break L116;
      }
      $497 = (($$1$lcssa$i142) + ($431)|0);
      $498 = (($$3$lcssa$i141) + ($$062$i117)|0);
      $$pre$i144 = HEAP32[$429>>2]|0;
      $$04168$i132 = $497;$$069$i131 = $494;$$24467$i133 = $498;$487 = $$pre$i144;$644 = $496;
     }
    }
   } else {
    $499 = (~~(($166)));
    $500 = (~~(($168)));
    $501 = ((($$0104160)) + 8|0);
    $502 = HEAP32[$501>>2]|0;
    $503 = ((($$0109)) + 8|0);
    $504 = HEAP32[$503>>2]|0;
    $505 = ((($$0104160)) + 12|0);
    $506 = HEAP32[$505>>2]|0;
    $507 = HEAP32[$56>>2]|0;
    $508 = ((($$0109)) + 20|0);
    $509 = HEAP32[$508>>2]|0;
    $510 = ((($$0109)) + 16|0);
    $511 = HEAP32[$510>>2]|0;
    $512 = (($511) - ($504))|0;
    HEAP32[$11>>2] = 0;
    (_SDL_GetColorKey($$0104160,$11)|0);
    $513 = HEAP32[$11>>2]|0;
    $514 = $513 & 255;
    $515 = HEAP32[$510>>2]|0;
    $516 = HEAP32[$56>>2]|0;
    $517 = Math_imul($516, $515)|0;
    (_SDL_memset($509,$514,$517)|0);
    $518 = HEAP32[$56>>2]|0;
    $519 = ($518|0)>(0);
    if ($519) {
     $520 = $3 << 16;
     $521 = (65536 - ($500))|0;
     $522 = Math_imul($521, $2)|0;
     $523 = (($506) - ($507))|0;
     $524 = $523 << 15;
     $525 = (($502) - ($504))|0;
     $526 = $525 << 15;
     $527 = (($526) + ($522))|0;
     $528 = ($5|0)==(0);
     $529 = ($6|0)==(0);
     $530 = ((($$0104160)) + 20|0);
     $531 = ((($$0104160)) + 16|0);
     $$pre$i147 = HEAP32[$503>>2]|0;
     $$neg$i$neg = Math_imul($499, $2)|0;
     $532 = (($524) + ($520))|0;
     $$079100$i = $509;$$08099$i = 0;$537 = $$pre$i147;
     while(1) {
      $533 = (($3) - ($$08099$i))|0;
      $534 = Math_imul($533, $499)|0;
      $535 = (($527) + ($534))|0;
      $$neg85$i$neg = Math_imul($533, $500)|0;
      $tmp = (($$neg85$i$neg) + ($$neg$i$neg))|0;
      $536 = (($532) - ($tmp))|0;
      $538 = ($537|0)>(0);
      if ($538) {
       if ($528) {
        if ($529) {
         $$08290$us$us$i = $536;$$08389$us$us$i = $535;$$092$us$us$i = 0;$$191$us$us$i = $$079100$i;$646 = $537;
         while(1) {
          $539 = $$08389$us$us$i >> 16;
          $540 = $$08290$us$us$i >> 16;
          $541 = HEAP32[$501>>2]|0;
          $542 = ($539>>>0)<($541>>>0);
          do {
           if ($542) {
            $543 = HEAP32[$505>>2]|0;
            $544 = ($540>>>0)<($543>>>0);
            if (!($544)) {
             $556 = $646;
             break;
            }
            $545 = HEAP32[$530>>2]|0;
            $546 = HEAP32[$531>>2]|0;
            $547 = Math_imul($546, $540)|0;
            $548 = (($545) + ($547)|0);
            $549 = (($548) + ($539)|0);
            $550 = HEAP8[$549>>0]|0;
            HEAP8[$$191$us$us$i>>0] = $550;
            $$pre113$i = HEAP32[$503>>2]|0;
            $556 = $$pre113$i;
           } else {
            $556 = $646;
           }
          } while(0);
          $551 = (($$08389$us$us$i) + ($500))|0;
          $552 = (($$08290$us$us$i) + ($499))|0;
          $553 = ((($$191$us$us$i)) + 1|0);
          $554 = (($$092$us$us$i) + 1)|0;
          $555 = ($554|0)<($556|0);
          if ($555) {
           $$08290$us$us$i = $552;$$08389$us$us$i = $551;$$092$us$us$i = $554;$$191$us$us$i = $553;$646 = $556;
          } else {
           $$1$lcssa$i155 = $553;$645 = $556;
           break;
          }
         }
        } else {
         $$08290$us$i = $536;$$08389$us$i = $535;$$092$us$i = 0;$$191$us$i = $$079100$i;$647 = $537;
         while(1) {
          $557 = $$08389$us$i >> 16;
          $558 = $$08290$us$i >> 16;
          $559 = HEAP32[$501>>2]|0;
          $560 = ($557>>>0)<($559>>>0);
          do {
           if ($560) {
            $561 = HEAP32[$505>>2]|0;
            $562 = ($558>>>0)<($561>>>0);
            if (!($562)) {
             $576 = $647;
             break;
            }
            $563 = $558 ^ -1;
            $564 = (($561) + ($563))|0;
            $565 = HEAP32[$530>>2]|0;
            $566 = HEAP32[$531>>2]|0;
            $567 = Math_imul($566, $564)|0;
            $568 = (($565) + ($567)|0);
            $569 = (($568) + ($557)|0);
            $570 = HEAP8[$569>>0]|0;
            HEAP8[$$191$us$i>>0] = $570;
            $$pre112$i = HEAP32[$503>>2]|0;
            $576 = $$pre112$i;
           } else {
            $576 = $647;
           }
          } while(0);
          $571 = (($$08389$us$i) + ($500))|0;
          $572 = (($$08290$us$i) + ($499))|0;
          $573 = ((($$191$us$i)) + 1|0);
          $574 = (($$092$us$i) + 1)|0;
          $575 = ($574|0)<($576|0);
          if ($575) {
           $$08290$us$i = $572;$$08389$us$i = $571;$$092$us$i = $574;$$191$us$i = $573;$647 = $576;
          } else {
           $$1$lcssa$i155 = $573;$645 = $576;
           break;
          }
         }
        }
       } else {
        if ($529) {
         $$08290$us95$i = $536;$$08389$us96$i = $535;$$092$us93$i = 0;$$191$us94$i = $$079100$i;$648 = $537;
         while(1) {
          $577 = $$08389$us96$i >> 16;
          $578 = $$08290$us95$i >> 16;
          $579 = HEAP32[$501>>2]|0;
          $580 = ($577>>>0)<($579>>>0);
          do {
           if ($580) {
            $581 = HEAP32[$505>>2]|0;
            $582 = ($578>>>0)<($581>>>0);
            if (!($582)) {
             $596 = $648;
             break;
            }
            $583 = $577 ^ -1;
            $584 = (($579) + ($583))|0;
            $585 = HEAP32[$530>>2]|0;
            $586 = HEAP32[$531>>2]|0;
            $587 = Math_imul($586, $578)|0;
            $588 = (($585) + ($587)|0);
            $589 = (($588) + ($584)|0);
            $590 = HEAP8[$589>>0]|0;
            HEAP8[$$191$us94$i>>0] = $590;
            $$pre111$i = HEAP32[$503>>2]|0;
            $596 = $$pre111$i;
           } else {
            $596 = $648;
           }
          } while(0);
          $591 = (($$08389$us96$i) + ($500))|0;
          $592 = (($$08290$us95$i) + ($499))|0;
          $593 = ((($$191$us94$i)) + 1|0);
          $594 = (($$092$us93$i) + 1)|0;
          $595 = ($594|0)<($596|0);
          if ($595) {
           $$08290$us95$i = $592;$$08389$us96$i = $591;$$092$us93$i = $594;$$191$us94$i = $593;$648 = $596;
          } else {
           $$1$lcssa$i155 = $593;$645 = $596;
           break;
          }
         }
        } else {
         $$08290$i = $536;$$08389$i = $535;$$092$i = 0;$$191$i = $$079100$i;$649 = $537;
         while(1) {
          $597 = $$08389$i >> 16;
          $598 = $$08290$i >> 16;
          $599 = HEAP32[$501>>2]|0;
          $600 = ($597>>>0)<($599>>>0);
          do {
           if ($600) {
            $601 = HEAP32[$505>>2]|0;
            $602 = ($598>>>0)<($601>>>0);
            if (!($602)) {
             $618 = $649;
             break;
            }
            $603 = $597 ^ -1;
            $604 = (($599) + ($603))|0;
            $605 = $598 ^ -1;
            $606 = (($601) + ($605))|0;
            $607 = HEAP32[$530>>2]|0;
            $608 = HEAP32[$531>>2]|0;
            $609 = Math_imul($608, $606)|0;
            $610 = (($607) + ($609)|0);
            $611 = (($610) + ($604)|0);
            $612 = HEAP8[$611>>0]|0;
            HEAP8[$$191$i>>0] = $612;
            $$pre110$i = HEAP32[$503>>2]|0;
            $618 = $$pre110$i;
           } else {
            $618 = $649;
           }
          } while(0);
          $613 = (($$08389$i) + ($500))|0;
          $614 = (($$08290$i) + ($499))|0;
          $615 = ((($$191$i)) + 1|0);
          $616 = (($$092$i) + 1)|0;
          $617 = ($616|0)<($618|0);
          if ($617) {
           $$08290$i = $614;$$08389$i = $613;$$092$i = $616;$$191$i = $615;$649 = $618;
          } else {
           $$1$lcssa$i155 = $615;$645 = $618;
           break;
          }
         }
        }
       }
      } else {
       $$1$lcssa$i155 = $$079100$i;$645 = $537;
      }
      $619 = (($$1$lcssa$i155) + ($512)|0);
      $620 = (($$08099$i) + 1)|0;
      $621 = HEAP32[$56>>2]|0;
      $622 = ($620|0)<($621|0);
      if ($622) {
       $$079100$i = $619;$$08099$i = $620;$537 = $645;
      } else {
       break;
      }
     }
    }
   }
  } while(0);
  HEAP32[$13>>2] = 0;
  (_SDL_GetColorKey($$0104160,$13)|0);
  $623 = HEAP32[$13>>2]|0;
  (_SDL_SetColorKey($$0109,3,$623)|0);
 }
 (_SDL_GetSurfaceAlphaMod($0,$19)|0);
 (_SDL_GetSurfaceBlendMode($0,$18)|0);
 (_SDL_GetSurfaceColorMod($0,$20,$21,$22)|0);
 $624 = HEAP8[$19>>0]|0;
 (_SDL_SetSurfaceAlphaMod($$0109,$624)|0);
 $625 = HEAP32[$18>>2]|0;
 (_SDL_SetSurfaceBlendMode($$0109,$625)|0);
 $626 = HEAP8[$20>>0]|0;
 $627 = HEAP8[$21>>0]|0;
 $628 = HEAP8[$22>>0]|0;
 (_SDL_SetSurfaceColorMod($$0109,$626,$627,$628)|0);
 $629 = HEAP32[$$0104160>>2]|0;
 $630 = $629 & 2;
 $631 = ($630|0)==(0);
 if (!($631)) {
  _SDL_UnlockSurface($$0104160);
 }
 $632 = ($$0104160|0)==($0|0);
 if ($632) {
  $$0 = $$0109;
  STACKTOP = sp;return ($$0|0);
 }
 _SDL_FreeSurface($$0104160);
 $$0 = $$0109;
 STACKTOP = sp;return ($$0|0);
}
function _SDL_UpperBlit($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$$0105 = 0, $$$0108 = 0, $$$3 = 0, $$$3111 = 0, $$0 = 0, $$0$i = 0, $$0103 = 0, $$0104 = 0, $$0105 = 0, $$0108 = 0, $$0113 = 0, $$1 = 0, $$1114 = 0, $$2 = 0, $$2107 = 0, $$2110 = 0, $$2115 = 0, $$3 = 0, $$3111 = 0, $$pre = 0;
 var $$pre$i = 0, $$pre$phiZ2D = 0, $$pre119 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $or$cond3 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $4 = sp + 32|0;
 $5 = sp + 16|0;
 $6 = ($0|0)!=(0|0);
 $7 = ($2|0)!=(0|0);
 $or$cond = $6 & $7;
 if (!($or$cond)) {
  $8 = (_SDL_SetError(182852,$vararg_buffer)|0);
  $$0 = $8;
  STACKTOP = sp;return ($$0|0);
 }
 $9 = ((($0)) + 28|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0);
 if ($11) {
  $12 = ((($2)) + 28|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($13|0)==(0);
  if ($14) {
   $16 = ($3|0)==(0|0);
   if ($16) {
    $17 = ((($4)) + 4|0);
    HEAP32[$17>>2] = 0;
    HEAP32[$4>>2] = 0;
    $18 = ((($2)) + 8|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = ((($4)) + 8|0);
    HEAP32[$20>>2] = $19;
    $21 = ((($2)) + 12|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = ((($4)) + 12|0);
    HEAP32[$23>>2] = $22;
    $$0103 = $4;
   } else {
    $$0103 = $3;
   }
   $24 = ($1|0)==(0|0);
   $25 = ((($0)) + 8|0);
   $26 = HEAP32[$25>>2]|0;
   if ($24) {
    $49 = ((($0)) + 12|0);
    $50 = HEAP32[$49>>2]|0;
    $$1 = 0;$$1114 = 0;$$2107 = $50;$$2110 = $26;$$pre$phiZ2D = $$0103;
   } else {
    $27 = HEAP32[$1>>2]|0;
    $28 = ((($1)) + 8|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = ($27|0)<(0);
    if ($30) {
     $31 = (($29) + ($27))|0;
     $32 = HEAP32[$$0103>>2]|0;
     $33 = (($32) - ($27))|0;
     HEAP32[$$0103>>2] = $33;
     $$0104 = 0;$$0108 = $31;
    } else {
     $$0104 = $27;$$0108 = $29;
    }
    $34 = (($26) - ($$0104))|0;
    $35 = ($34|0)<($$0108|0);
    $$$0108 = $35 ? $34 : $$0108;
    $36 = ((($1)) + 4|0);
    $37 = HEAP32[$36>>2]|0;
    $38 = ((($1)) + 12|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = ($37|0)<(0);
    $41 = ((($$0103)) + 4|0);
    if ($40) {
     $42 = (($39) + ($37))|0;
     $43 = HEAP32[$41>>2]|0;
     $44 = (($43) - ($37))|0;
     HEAP32[$41>>2] = $44;
     $$0105 = $42;$$0113 = 0;
    } else {
     $$0105 = $39;$$0113 = $37;
    }
    $45 = ((($0)) + 12|0);
    $46 = HEAP32[$45>>2]|0;
    $47 = (($46) - ($$0113))|0;
    $48 = ($47|0)<($$0105|0);
    $$$0105 = $48 ? $47 : $$0105;
    $$1 = $$0104;$$1114 = $$0113;$$2107 = $$$0105;$$2110 = $$$0108;$$pre$phiZ2D = $$0103;
   }
   $51 = ((($2)) + 36|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = HEAP32[$$pre$phiZ2D>>2]|0;
   $54 = (($52) - ($53))|0;
   $55 = ($54|0)>(0);
   if ($55) {
    $56 = (($54) + ($$1))|0;
    $57 = (($$2110) - ($54))|0;
    HEAP32[$$pre$phiZ2D>>2] = $52;
    $$pre = HEAP32[$51>>2]|0;
    $$2 = $56;$$3111 = $57;$59 = $52;$61 = $$pre;
   } else {
    $$2 = $$1;$$3111 = $$2110;$59 = $53;$61 = $52;
   }
   $58 = (($59) + ($$3111))|0;
   $60 = (($58) - ($61))|0;
   $62 = ((($2)) + 44|0);
   $63 = HEAP32[$62>>2]|0;
   $64 = (($60) - ($63))|0;
   $65 = ($64|0)>(0);
   $66 = $65 ? $64 : 0;
   $$$3111 = (($$3111) - ($66))|0;
   $67 = ((($2)) + 40|0);
   $68 = HEAP32[$67>>2]|0;
   $69 = ((($$0103)) + 4|0);
   $70 = HEAP32[$69>>2]|0;
   $71 = (($68) - ($70))|0;
   $72 = ($71|0)>(0);
   if ($72) {
    $73 = (($71) + ($$1114))|0;
    $74 = (($$2107) - ($71))|0;
    HEAP32[$69>>2] = $68;
    $$pre119 = HEAP32[$67>>2]|0;
    $$2115 = $73;$$3 = $74;$76 = $68;$78 = $$pre119;
   } else {
    $$2115 = $$1114;$$3 = $$2107;$76 = $70;$78 = $68;
   }
   $75 = (($76) + ($$3))|0;
   $77 = (($75) - ($78))|0;
   $79 = ((($2)) + 48|0);
   $80 = HEAP32[$79>>2]|0;
   $81 = (($77) - ($80))|0;
   $82 = ($81|0)>(0);
   $83 = $82 ? $81 : 0;
   $$$3 = (($$3) - ($83))|0;
   $84 = ((($0)) + 52|0);
   $85 = HEAP32[$84>>2]|0;
   $86 = ((($85)) + 68|0);
   $87 = HEAP32[$86>>2]|0;
   $88 = $87 & 512;
   $89 = ($88|0)==(0);
   if (!($89)) {
    $90 = $87 & -513;
    HEAP32[$86>>2] = $90;
    _SDL_InvalidateMap($85);
   }
   $91 = ($$$3111|0)>(0);
   $92 = ($$$3|0)>(0);
   $or$cond3 = $91 & $92;
   if (!($or$cond3)) {
    $127 = ((($$0103)) + 12|0);
    HEAP32[$127>>2] = 0;
    $128 = ((($$0103)) + 8|0);
    HEAP32[$128>>2] = 0;
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$5>>2] = $$2;
   $93 = ((($5)) + 4|0);
   HEAP32[$93>>2] = $$2115;
   $94 = ((($$0103)) + 8|0);
   HEAP32[$94>>2] = $$$3111;
   $95 = ((($5)) + 8|0);
   HEAP32[$95>>2] = $$$3111;
   $96 = ((($$0103)) + 12|0);
   HEAP32[$96>>2] = $$$3;
   $97 = ((($5)) + 12|0);
   HEAP32[$97>>2] = $$$3;
   $98 = HEAP32[$84>>2]|0;
   $99 = HEAP32[$98>>2]|0;
   $100 = ($99|0)==($2|0);
   do {
    if ($100) {
     $101 = ((($2)) + 4|0);
     $102 = HEAP32[$101>>2]|0;
     $103 = ((($102)) + 4|0);
     $104 = HEAP32[$103>>2]|0;
     $105 = ($104|0)==(0|0);
     if (!($105)) {
      $106 = ((($98)) + 80|0);
      $107 = HEAP32[$106>>2]|0;
      $108 = ((($104)) + 8|0);
      $109 = HEAP32[$108>>2]|0;
      $110 = ($107|0)==($109|0);
      if (!($110)) {
       label = 27;
       break;
      }
     }
     $111 = ((($0)) + 4|0);
     $112 = HEAP32[$111>>2]|0;
     $113 = ((($112)) + 4|0);
     $114 = HEAP32[$113>>2]|0;
     $115 = ($114|0)==(0|0);
     if ($115) {
      $124 = $98;
      label = 29;
     } else {
      $116 = ((($98)) + 84|0);
      $117 = HEAP32[$116>>2]|0;
      $118 = ((($114)) + 8|0);
      $119 = HEAP32[$118>>2]|0;
      $120 = ($117|0)==($119|0);
      if ($120) {
       $124 = $98;
       label = 29;
      } else {
       label = 27;
      }
     }
    } else {
     label = 27;
    }
   } while(0);
   if ((label|0) == 27) {
    $121 = (_SDL_MapSurface($0,$2)|0);
    $122 = ($121|0)<(0);
    if ($122) {
     $$0$i = -1;
    } else {
     $$pre$i = HEAP32[$84>>2]|0;
     $124 = $$pre$i;
     label = 29;
    }
   }
   if ((label|0) == 29) {
    $123 = ((($124)) + 8|0);
    $125 = HEAP32[$123>>2]|0;
    $126 = (FUNCTION_TABLE_iiiii[$125 & 8191]($0,$5,$2,$$0103)|0);
    $$0$i = $126;
   }
   $$0 = $$0$i;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $15 = (_SDL_SetError(182889,$vararg_buffer1)|0);
 $$0 = $15;
 STACKTOP = sp;return ($$0|0);
}
function _SDL_GetRGB($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = ((($1)) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $8 = ((($1)) + 12|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = $9 & $0;
  $11 = ((($1)) + 32|0);
  $12 = HEAP8[$11>>0]|0;
  $13 = $12&255;
  $14 = $10 >>> $13;
  $15 = ((($1)) + 28|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = $16&255;
  $18 = (79212 + ($17<<2)|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = (($19) + ($14)|0);
  $21 = HEAP8[$20>>0]|0;
  HEAP8[$2>>0] = $21;
  $22 = ((($1)) + 16|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = $23 & $0;
  $25 = ((($1)) + 33|0);
  $26 = HEAP8[$25>>0]|0;
  $27 = $26&255;
  $28 = $24 >>> $27;
  $29 = ((($1)) + 29|0);
  $30 = HEAP8[$29>>0]|0;
  $31 = $30&255;
  $32 = (79212 + ($31<<2)|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = (($33) + ($28)|0);
  $35 = HEAP8[$34>>0]|0;
  HEAP8[$3>>0] = $35;
  $36 = ((($1)) + 20|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = $37 & $0;
  $39 = ((($1)) + 34|0);
  $40 = HEAP8[$39>>0]|0;
  $41 = $40&255;
  $42 = $38 >>> $41;
  $43 = ((($1)) + 30|0);
  $44 = HEAP8[$43>>0]|0;
  $45 = $44&255;
  $46 = (79212 + ($45<<2)|0);
  $47 = HEAP32[$46>>2]|0;
  $48 = (($47) + ($42)|0);
  $49 = HEAP8[$48>>0]|0;
  HEAP8[$4>>0] = $49;
  return;
 }
 $50 = HEAP32[$6>>2]|0;
 $51 = ($50>>>0)>($0>>>0);
 if ($51) {
  $52 = ((($6)) + 4|0);
  $53 = HEAP32[$52>>2]|0;
  $54 = (($53) + ($0<<2)|0);
  $55 = HEAP8[$54>>0]|0;
  HEAP8[$2>>0] = $55;
  $56 = HEAP32[$5>>2]|0;
  $57 = ((($56)) + 4|0);
  $58 = HEAP32[$57>>2]|0;
  $59 = (((($58) + ($0<<2)|0)) + 1|0);
  $60 = HEAP8[$59>>0]|0;
  HEAP8[$3>>0] = $60;
  $61 = HEAP32[$5>>2]|0;
  $62 = ((($61)) + 4|0);
  $63 = HEAP32[$62>>2]|0;
  $64 = (((($63) + ($0<<2)|0)) + 2|0);
  $65 = HEAP8[$64>>0]|0;
  HEAP8[$4>>0] = $65;
  return;
 } else {
  HEAP8[$4>>0] = 0;
  HEAP8[$3>>0] = 0;
  HEAP8[$2>>0] = 0;
  return;
 }
}
function _SDL_ConvertSurfaceFormat($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (_SDL_AllocFormat($1)|0);
 $4 = ($3|0)==(0|0);
 if ($4) {
  $$0 = 0;
  return ($$0|0);
 }
 $5 = (_SDL_ConvertSurface($0,$3,$2)|0);
 _SDL_FreeFormat($3);
 $$0 = $5;
 return ($$0|0);
}
function _SDL_MapRGB($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $$04145$i = 0, $$04244$i = 0, $$046$i = 0, $$1$i = 0, $$143$i = 0, $$2$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ((($0)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $7 = $1&255;
  $8 = ((($0)) + 28|0);
  $9 = HEAP8[$8>>0]|0;
  $10 = $9&255;
  $11 = $7 >>> $10;
  $12 = ((($0)) + 32|0);
  $13 = HEAP8[$12>>0]|0;
  $14 = $13&255;
  $15 = $11 << $14;
  $16 = $2&255;
  $17 = ((($0)) + 29|0);
  $18 = HEAP8[$17>>0]|0;
  $19 = $18&255;
  $20 = $16 >>> $19;
  $21 = ((($0)) + 33|0);
  $22 = HEAP8[$21>>0]|0;
  $23 = $22&255;
  $24 = $20 << $23;
  $25 = $24 | $15;
  $26 = $3&255;
  $27 = ((($0)) + 30|0);
  $28 = HEAP8[$27>>0]|0;
  $29 = $28&255;
  $30 = $26 >>> $29;
  $31 = ((($0)) + 34|0);
  $32 = HEAP8[$31>>0]|0;
  $33 = $32&255;
  $34 = $30 << $33;
  $35 = ((($0)) + 24|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = $25 | $36;
  $38 = $37 | $34;
  $$0 = $38;
  return ($$0|0);
 }
 $39 = HEAP32[$5>>2]|0;
 $40 = ($39|0)>(0);
 L5: do {
  if ($40) {
   $41 = ((($5)) + 4|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = $1&255;
   $44 = $2&255;
   $45 = $3&255;
   $$04145$i = 0;$$04244$i = -1;$$046$i = 0;
   while(1) {
    $46 = (($42) + ($$04145$i<<2)|0);
    $47 = HEAP8[$46>>0]|0;
    $48 = $47&255;
    $49 = (($48) - ($43))|0;
    $50 = (((($42) + ($$04145$i<<2)|0)) + 1|0);
    $51 = HEAP8[$50>>0]|0;
    $52 = $51&255;
    $53 = (($52) - ($44))|0;
    $54 = (((($42) + ($$04145$i<<2)|0)) + 2|0);
    $55 = HEAP8[$54>>0]|0;
    $56 = $55&255;
    $57 = (($56) - ($45))|0;
    $58 = (((($42) + ($$04145$i<<2)|0)) + 3|0);
    $59 = HEAP8[$58>>0]|0;
    $60 = $59&255;
    $61 = (($60) + -255)|0;
    $62 = Math_imul($49, $49)|0;
    $63 = Math_imul($53, $53)|0;
    $64 = (($63) + ($62))|0;
    $65 = Math_imul($57, $57)|0;
    $66 = (($64) + ($65))|0;
    $67 = Math_imul($61, $61)|0;
    $68 = (($66) + ($67))|0;
    $69 = ($68>>>0)<($$04244$i>>>0);
    if ($69) {
     $70 = $$04145$i&255;
     $71 = ($68|0)==(0);
     if ($71) {
      $$2$i = $70;
      break L5;
     } else {
      $$1$i = $70;$$143$i = $68;
     }
    } else {
     $$1$i = $$046$i;$$143$i = $$04244$i;
    }
    $72 = (($$04145$i) + 1)|0;
    $73 = ($72|0)<($39|0);
    if ($73) {
     $$04145$i = $72;$$04244$i = $$143$i;$$046$i = $$1$i;
    } else {
     $$2$i = $$1$i;
     break;
    }
   }
  } else {
   $$2$i = 0;
  }
 } while(0);
 $74 = $$2$i&255;
 $$0 = $74;
 return ($$0|0);
}
function _SDL_AllocFormat($0) {
 $0 = $0|0;
 var $$0 = 0, $$018 = 0, $$021 = 0, $$022 = 0, $$mask = 0, $$off = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $switch = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $$021 = HEAP32[52377]|0;
 $1 = ($$021|0)==(0|0);
 L1: do {
  if (!($1)) {
   $$022 = $$021;
   while(1) {
    $2 = HEAP32[$$022>>2]|0;
    $3 = ($2|0)==($0|0);
    if ($3) {
     break;
    }
    $7 = ((($$022)) + 40|0);
    $$0 = HEAP32[$7>>2]|0;
    $8 = ($$0|0)==(0|0);
    if ($8) {
     break L1;
    } else {
     $$022 = $$0;
    }
   }
   $4 = ((($$022)) + 36|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = (($5) + 1)|0;
   HEAP32[$4>>2] = $6;
   $$018 = $$022;
   STACKTOP = sp;return ($$018|0);
  }
 } while(0);
 $9 = (_SDL_malloc(44)|0);
 $10 = ($9|0)==(0|0);
 if ($10) {
  (_SDL_Error(0)|0);
  $$018 = 0;
  STACKTOP = sp;return ($$018|0);
 }
 $11 = (_SDL_InitFormat($9,$0)|0);
 $12 = ($11|0)<(0);
 if ($12) {
  _SDL_free($9);
  HEAP32[$vararg_buffer>>2] = 176310;
  (_SDL_SetError(194740,$vararg_buffer)|0);
  $$018 = 0;
  STACKTOP = sp;return ($$018|0);
 }
 $13 = ($0|0)==(0);
 $$mask = $0 & -268435456;
 $14 = ($$mask|0)==(268435456);
 $or$cond = $13 | $14;
 if ($or$cond) {
  $15 = $0 >>> 24;
  $16 = $15 & 15;
  $$off = (($16) + -1)|0;
  $switch = ($$off>>>0)<(3);
  if ($switch) {
   $$018 = $9;
   STACKTOP = sp;return ($$018|0);
  }
 }
 $17 = HEAP32[52377]|0;
 $18 = ((($9)) + 40|0);
 HEAP32[$18>>2] = $17;
 HEAP32[52377] = $9;
 $$018 = $9;
 STACKTOP = sp;return ($$018|0);
}
function _SDL_ceil($0) {
 $0 = +$0;
 var $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (+Math_ceil((+$0)));
 return (+$1);
}
function _SDL_MasksToPixelFormatEnum($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $cond = 0, $or$cond = 0, $or$cond101 = 0, $or$cond103 = 0;
 var $or$cond105 = 0, $or$cond107 = 0, $or$cond11 = 0, $or$cond113 = 0, $or$cond119 = 0, $or$cond125 = 0, $or$cond13 = 0, $or$cond131 = 0, $or$cond133 = 0, $or$cond135 = 0, $or$cond137 = 0, $or$cond15 = 0, $or$cond17 = 0, $or$cond19 = 0, $or$cond21 = 0, $or$cond23 = 0, $or$cond25 = 0, $or$cond27 = 0, $or$cond29 = 0, $or$cond3 = 0;
 var $or$cond31 = 0, $or$cond33 = 0, $or$cond35 = 0, $or$cond37 = 0, $or$cond39 = 0, $or$cond41 = 0, $or$cond43 = 0, $or$cond45 = 0, $or$cond47 = 0, $or$cond5 = 0, $or$cond53 = 0, $or$cond55 = 0, $or$cond57 = 0, $or$cond59 = 0, $or$cond65 = 0, $or$cond67 = 0, $or$cond69 = 0, $or$cond7 = 0, $or$cond71 = 0, $or$cond73 = 0;
 var $or$cond75 = 0, $or$cond77 = 0, $or$cond79 = 0, $or$cond81 = 0, $or$cond83 = 0, $or$cond85 = 0, $or$cond87 = 0, $or$cond89 = 0, $or$cond9 = 0, $or$cond91 = 0, $or$cond93 = 0, $or$cond95 = 0, $or$cond97 = 0, $or$cond99 = 0, $switch$split12D = 0, $switch$split2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 L1: do {
  switch ($0|0) {
  case 4:  {
   $$0 = 304088064;
   return ($$0|0);
   break;
  }
  case 8:  {
   $5 = ($1|0)==(0);
   if ($5) {
    $$0 = 318769153;
    return ($$0|0);
   }
   $6 = ($1|0)==(224);
   $7 = ($2|0)==(28);
   $or$cond = $6 & $7;
   $8 = ($3|0)==(3);
   $or$cond3 = $or$cond & $8;
   $9 = ($4|0)==(0);
   $or$cond5 = $or$cond3 & $9;
   if ($or$cond5) {
    $$0 = 336660481;
    return ($$0|0);
   }
   break;
  }
  case 12:  {
   $10 = ($1|0)==(0);
   if ($10) {
    $$0 = 353504258;
    return ($$0|0);
   }
   $11 = ($1|0)==(3840);
   $12 = ($2|0)==(240);
   $or$cond7 = $11 & $12;
   $13 = ($3|0)==(15);
   $or$cond9 = $or$cond7 & $13;
   $14 = ($4|0)==(0);
   $or$cond11 = $or$cond9 & $14;
   if ($or$cond11) {
    $$0 = 353504258;
    return ($$0|0);
   }
   break;
  }
  case 15:  {
   $cond = ($1|0)==(0);
   if ($cond) {
    $$0 = 353570562;
    return ($$0|0);
   } else {
    label = 9;
   }
   break;
  }
  case 16:  {
   $15 = ($1|0)==(0);
   if ($15) {
    $$0 = 353701890;
    return ($$0|0);
   } else {
    label = 9;
   }
   break;
  }
  case 24:  {
   $switch$split2D = ($1|0)<(255);
   if ($switch$split2D) {
    switch ($1|0) {
    case 0:  {
     $$0 = 390076419;
     break;
    }
    default: {
     label = 24;
     break L1;
    }
    }
    return ($$0|0);
   }
   $switch$split12D = ($1|0)<(16711680);
   if (!($switch$split12D)) {
    switch ($1|0) {
    case 16711680:  {
     $$0 = 390076419;
     break;
    }
    default: {
     label = 24;
     break L1;
    }
    }
    return ($$0|0);
   }
   switch ($1|0) {
   case 255:  {
    break;
   }
   default: {
    label = 24;
    break L1;
   }
   }
   $$0 = 386930691;
   return ($$0|0);
   break;
  }
  case 32:  {
   $42 = ($1|0)==(0);
   if ($42) {
    $$0 = 370546692;
    return ($$0|0);
   } else {
    label = 24;
   }
   break;
  }
  case 1:  {
   $$0 = 287310080;
   return ($$0|0);
   break;
  }
  default: {
  }
  }
 } while(0);
 if ((label|0) == 9) {
  $16 = ($1|0)==(31744);
  $17 = ($2|0)==(992);
  $or$cond13 = $16 & $17;
  $18 = ($3|0)==(31);
  $or$cond15 = $or$cond13 & $18;
  $19 = ($4|0)==(0);
  $or$cond17 = $or$cond15 & $19;
  if ($or$cond17) {
   $$0 = 353570562;
   return ($$0|0);
  }
  $20 = ($1|0)==(31);
  $or$cond19 = $20 & $17;
  $21 = ($3|0)==(31744);
  $or$cond21 = $or$cond19 & $21;
  $or$cond23 = $or$cond21 & $19;
  if ($or$cond23) {
   $$0 = 357764866;
   return ($$0|0);
  }
  $22 = ($1|0)==(3840);
  $23 = ($2|0)==(240);
  $or$cond25 = $22 & $23;
  $24 = ($3|0)==(15);
  $or$cond27 = $or$cond25 & $24;
  $25 = ($4|0)==(61440);
  $or$cond29 = $or$cond27 & $25;
  if ($or$cond29) {
   $$0 = 355602434;
   return ($$0|0);
  }
  $26 = ($1|0)==(61440);
  $27 = ($2|0)==(3840);
  $or$cond31 = $26 & $27;
  $28 = ($3|0)==(240);
  $or$cond33 = $or$cond31 & $28;
  $29 = ($4|0)==(15);
  $or$cond35 = $or$cond33 & $29;
  if ($or$cond35) {
   $$0 = 356651010;
   return ($$0|0);
  }
  $30 = ($1|0)==(15);
  $or$cond37 = $30 & $23;
  $31 = ($3|0)==(3840);
  $or$cond39 = $or$cond37 & $31;
  $or$cond41 = $or$cond39 & $25;
  if ($or$cond41) {
   $$0 = 359796738;
   return ($$0|0);
  }
  $32 = ($1|0)==(240);
  $or$cond43 = $32 & $27;
  $33 = ($3|0)==(61440);
  $or$cond45 = $or$cond43 & $33;
  $or$cond47 = $or$cond45 & $29;
  if ($or$cond47) {
   $$0 = 360845314;
   return ($$0|0);
  }
  $34 = ($4|0)==(32768);
  $or$cond53 = $or$cond15 & $34;
  if ($or$cond53) {
   $$0 = 355667970;
   return ($$0|0);
  }
  $35 = ($1|0)==(63488);
  $36 = ($2|0)==(1984);
  $or$cond55 = $35 & $36;
  $37 = ($3|0)==(62);
  $or$cond57 = $or$cond55 & $37;
  $38 = ($4|0)==(1);
  $or$cond59 = $or$cond57 & $38;
  if ($or$cond59) {
   $$0 = 356782082;
   return ($$0|0);
  }
  $or$cond65 = $or$cond21 & $34;
  if ($or$cond65) {
   $$0 = 359862274;
   return ($$0|0);
  }
  $39 = ($1|0)==(62);
  $or$cond67 = $39 & $36;
  $40 = ($3|0)==(63488);
  $or$cond69 = $or$cond67 & $40;
  $or$cond71 = $or$cond69 & $38;
  if ($or$cond71) {
   $$0 = 360976386;
   return ($$0|0);
  }
  $41 = ($2|0)==(2016);
  $or$cond73 = $35 & $41;
  $or$cond75 = $or$cond73 & $18;
  $or$cond77 = $or$cond75 & $19;
  if ($or$cond77) {
   $$0 = 353701890;
   return ($$0|0);
  }
  $or$cond79 = $20 & $41;
  $or$cond81 = $or$cond79 & $40;
  $or$cond83 = $or$cond81 & $19;
  if ($or$cond83) {
   $$0 = 357896194;
   return ($$0|0);
  }
 }
 else if ((label|0) == 24) {
  $43 = ($1|0)==(16711680);
  $44 = ($2|0)==(65280);
  $or$cond85 = $43 & $44;
  $45 = ($3|0)==(255);
  $or$cond87 = $or$cond85 & $45;
  $46 = ($4|0)==(0);
  $or$cond89 = $or$cond87 & $46;
  if ($or$cond89) {
   $$0 = 370546692;
   return ($$0|0);
  }
  $47 = ($1|0)==(-16777216);
  $48 = ($2|0)==(16711680);
  $or$cond91 = $47 & $48;
  $49 = ($3|0)==(65280);
  $or$cond93 = $or$cond91 & $49;
  $or$cond95 = $or$cond93 & $46;
  if ($or$cond95) {
   $$0 = 371595268;
   return ($$0|0);
  }
  $50 = ($1|0)==(255);
  $or$cond97 = $50 & $44;
  $51 = ($3|0)==(16711680);
  $or$cond99 = $or$cond97 & $51;
  $or$cond101 = $or$cond99 & $46;
  if ($or$cond101) {
   $$0 = 374740996;
   return ($$0|0);
  }
  $52 = ($1|0)==(65280);
  $or$cond103 = $52 & $48;
  $53 = ($3|0)==(-16777216);
  $or$cond105 = $or$cond103 & $53;
  $or$cond107 = $or$cond105 & $46;
  if ($or$cond107) {
   $$0 = 375789572;
   return ($$0|0);
  }
  $54 = ($4|0)==(-16777216);
  $or$cond113 = $or$cond87 & $54;
  if ($or$cond113) {
   $$0 = 372645892;
   return ($$0|0);
  }
  $55 = ($4|0)==(255);
  $or$cond119 = $or$cond93 & $55;
  if ($or$cond119) {
   $$0 = 373694468;
   return ($$0|0);
  }
  $or$cond125 = $or$cond99 & $54;
  if ($or$cond125) {
   $$0 = 376840196;
   return ($$0|0);
  }
  $or$cond131 = $or$cond105 & $55;
  if ($or$cond131) {
   $$0 = 377888772;
   return ($$0|0);
  }
  $56 = ($1|0)==(1072693248);
  $57 = ($2|0)==(1047552);
  $or$cond133 = $56 & $57;
  $58 = ($3|0)==(1023);
  $or$cond135 = $or$cond133 & $58;
  $59 = ($4|0)==(-1073741824);
  $or$cond137 = $or$cond135 & $59;
  if ($or$cond137) {
   $$0 = 372711428;
   return ($$0|0);
  }
 }
 $$0 = 0;
 return ($$0|0);
}
function _SDL_CreateRGBSurfaceWithFormat($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$1 = 0, $$mask = 0, $$off = 0, $$pre = 0, $$sroa$0$0$$sroa_idx = 0, $$sroa$4$0$$sroa_idx55 = 0, $$sroa$5$0$$sroa_idx57 = 0, $$sroa$6$0$$sroa_idx59 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $switch = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = (_SDL_calloc(1,60)|0);
 $6 = ($5|0)==(0|0);
 if ($6) {
  (_SDL_Error(0)|0);
  $$1 = 0;
  return ($$1|0);
 }
 $7 = (_SDL_AllocFormat($4)|0);
 $8 = ((($5)) + 4|0);
 HEAP32[$8>>2] = $7;
 $9 = ($7|0)==(0|0);
 if ($9) {
  _SDL_FreeSurface($5);
  $$1 = 0;
  return ($$1|0);
 }
 $10 = ((($5)) + 8|0);
 HEAP32[$10>>2] = $1;
 $11 = ((($5)) + 12|0);
 HEAP32[$11>>2] = $2;
 $12 = (_SDL_CalculatePitch($5)|0);
 $13 = ((($5)) + 16|0);
 HEAP32[$13>>2] = $12;
 $14 = HEAP32[$10>>2]|0;
 $15 = HEAP32[$11>>2]|0;
 $$sroa$0$0$$sroa_idx = ((($5)) + 36|0);
 HEAP32[$$sroa$0$0$$sroa_idx>>2] = 0;
 $$sroa$4$0$$sroa_idx55 = ((($5)) + 40|0);
 HEAP32[$$sroa$4$0$$sroa_idx55>>2] = 0;
 $$sroa$5$0$$sroa_idx57 = ((($5)) + 44|0);
 HEAP32[$$sroa$5$0$$sroa_idx57>>2] = $14;
 $$sroa$6$0$$sroa_idx59 = ((($5)) + 48|0);
 HEAP32[$$sroa$6$0$$sroa_idx59>>2] = $15;
 $16 = HEAP32[$8>>2]|0;
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==(0);
 $$mask = $17 & -268435456;
 $19 = ($$mask|0)==(268435456);
 $or$cond = $18 | $19;
 if ($or$cond) {
  $20 = $17 >>> 24;
  $21 = $20 & 15;
  $$off = (($21) + -1)|0;
  $switch = ($$off>>>0)<(3);
  if ($switch) {
   $22 = ((($16)) + 8|0);
   $23 = HEAP8[$22>>0]|0;
   $24 = $23&255;
   $25 = 1 << $24;
   $26 = (_SDL_AllocPalette($25)|0);
   $27 = ($26|0)==(0|0);
   if ($27) {
    _SDL_FreeSurface($5);
    $$1 = 0;
    return ($$1|0);
   }
   $28 = HEAP32[$26>>2]|0;
   $29 = ($28|0)==(2);
   if ($29) {
    $30 = ((($26)) + 4|0);
    $31 = HEAP32[$30>>2]|0;
    HEAP8[$31>>0] = -1;
    $32 = ((($31)) + 1|0);
    HEAP8[$32>>0] = -1;
    $33 = ((($31)) + 2|0);
    HEAP8[$33>>0] = -1;
    $34 = ((($31)) + 4|0);
    HEAP8[$34>>0] = 0;
    $35 = ((($31)) + 5|0);
    HEAP8[$35>>0] = 0;
    $36 = ((($31)) + 6|0);
    HEAP8[$36>>0] = 0;
   }
   $37 = HEAP32[$8>>2]|0;
   $38 = (_SDL_SetPixelFormatPalette($37,$26)|0);
   $39 = ($38|0)<(0);
   if (!($39)) {
    $40 = ((($5)) + 52|0);
    $41 = HEAP32[$40>>2]|0;
    _SDL_InvalidateMap($41);
   }
   _SDL_FreePalette($26);
   $$pre = HEAP32[$10>>2]|0;
   $42 = $$pre;
  } else {
   $42 = $14;
  }
 } else {
  $42 = $14;
 }
 $43 = ($42|0)==(0);
 do {
  if (!($43)) {
   $44 = HEAP32[$11>>2]|0;
   $45 = ($44|0)==(0);
   if (!($45)) {
    $46 = HEAP32[$13>>2]|0;
    $47 = Math_imul($46, $44)|0;
    $48 = (_SDL_malloc($47)|0);
    $49 = ((($5)) + 20|0);
    HEAP32[$49>>2] = $48;
    $50 = ($48|0)==(0|0);
    if (!($50)) {
     $51 = HEAP32[$11>>2]|0;
     $52 = HEAP32[$13>>2]|0;
     $53 = Math_imul($52, $51)|0;
     (_SDL_memset($48,0,$53)|0);
     break;
    }
    _SDL_FreeSurface($5);
    (_SDL_Error(0)|0);
    $$1 = 0;
    return ($$1|0);
   }
  }
 } while(0);
 $54 = (_SDL_AllocBlitMap()|0);
 $55 = ((($5)) + 52|0);
 HEAP32[$55>>2] = $54;
 $56 = ($54|0)==(0|0);
 if ($56) {
  _SDL_FreeSurface($5);
  $$1 = 0;
  return ($$1|0);
 }
 $57 = HEAP32[$8>>2]|0;
 $58 = ((($57)) + 24|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = ($59|0)==(0);
 if (!($60)) {
  $61 = ((($54)) + 68|0);
  $62 = HEAP32[$61>>2]|0;
  $63 = $62 & -113;
  $64 = $63 | 16;
  HEAP32[$61>>2] = $64;
  $65 = ($64|0)==($62|0);
  if (!($65)) {
   _SDL_InvalidateMap($54);
  }
 }
 $66 = ((($5)) + 56|0);
 HEAP32[$66>>2] = 1;
 $$1 = $5;
 return ($$1|0);
}
function _SDL_GetRGBA($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $6 = ((($1)) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if ($8) {
  $9 = ((($1)) + 12|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = $10 & $0;
  $12 = ((($1)) + 32|0);
  $13 = HEAP8[$12>>0]|0;
  $14 = $13&255;
  $15 = $11 >>> $14;
  $16 = ((($1)) + 28|0);
  $17 = HEAP8[$16>>0]|0;
  $18 = $17&255;
  $19 = (79212 + ($18<<2)|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = (($20) + ($15)|0);
  $22 = HEAP8[$21>>0]|0;
  HEAP8[$2>>0] = $22;
  $23 = ((($1)) + 16|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = $24 & $0;
  $26 = ((($1)) + 33|0);
  $27 = HEAP8[$26>>0]|0;
  $28 = $27&255;
  $29 = $25 >>> $28;
  $30 = ((($1)) + 29|0);
  $31 = HEAP8[$30>>0]|0;
  $32 = $31&255;
  $33 = (79212 + ($32<<2)|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = (($34) + ($29)|0);
  $36 = HEAP8[$35>>0]|0;
  HEAP8[$3>>0] = $36;
  $37 = ((($1)) + 20|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = $38 & $0;
  $40 = ((($1)) + 34|0);
  $41 = HEAP8[$40>>0]|0;
  $42 = $41&255;
  $43 = $39 >>> $42;
  $44 = ((($1)) + 30|0);
  $45 = HEAP8[$44>>0]|0;
  $46 = $45&255;
  $47 = (79212 + ($46<<2)|0);
  $48 = HEAP32[$47>>2]|0;
  $49 = (($48) + ($43)|0);
  $50 = HEAP8[$49>>0]|0;
  HEAP8[$4>>0] = $50;
  $51 = ((($1)) + 24|0);
  $52 = HEAP32[$51>>2]|0;
  $53 = $52 & $0;
  $54 = ((($1)) + 35|0);
  $55 = HEAP8[$54>>0]|0;
  $56 = $55&255;
  $57 = $53 >>> $56;
  $58 = ((($1)) + 31|0);
  $59 = HEAP8[$58>>0]|0;
  $60 = $59&255;
  $61 = (79212 + ($60<<2)|0);
  $62 = HEAP32[$61>>2]|0;
  $63 = (($62) + ($57)|0);
  $64 = HEAP8[$63>>0]|0;
  HEAP8[$5>>0] = $64;
  return;
 }
 $65 = HEAP32[$7>>2]|0;
 $66 = ($65>>>0)>($0>>>0);
 if ($66) {
  $67 = ((($7)) + 4|0);
  $68 = HEAP32[$67>>2]|0;
  $69 = (($68) + ($0<<2)|0);
  $70 = HEAP8[$69>>0]|0;
  HEAP8[$2>>0] = $70;
  $71 = HEAP32[$6>>2]|0;
  $72 = ((($71)) + 4|0);
  $73 = HEAP32[$72>>2]|0;
  $74 = (((($73) + ($0<<2)|0)) + 1|0);
  $75 = HEAP8[$74>>0]|0;
  HEAP8[$3>>0] = $75;
  $76 = HEAP32[$6>>2]|0;
  $77 = ((($76)) + 4|0);
  $78 = HEAP32[$77>>2]|0;
  $79 = (((($78) + ($0<<2)|0)) + 2|0);
  $80 = HEAP8[$79>>0]|0;
  HEAP8[$4>>0] = $80;
  $81 = HEAP32[$6>>2]|0;
  $82 = ((($81)) + 4|0);
  $83 = HEAP32[$82>>2]|0;
  $84 = (((($83) + ($0<<2)|0)) + 3|0);
  $85 = HEAP8[$84>>0]|0;
  HEAP8[$5>>0] = $85;
  return;
 } else {
  HEAP8[$5>>0] = 0;
  HEAP8[$4>>0] = 0;
  HEAP8[$3>>0] = 0;
  HEAP8[$2>>0] = 0;
  return;
 }
}
function _SDL_MapRGBA($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0 = 0, $$04145$i = 0, $$04244$i = 0, $$046$i = 0, $$1$i = 0, $$143$i = 0, $$2$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = ((($0)) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $8 = $1&255;
  $9 = ((($0)) + 28|0);
  $10 = HEAP8[$9>>0]|0;
  $11 = $10&255;
  $12 = $8 >>> $11;
  $13 = ((($0)) + 32|0);
  $14 = HEAP8[$13>>0]|0;
  $15 = $14&255;
  $16 = $12 << $15;
  $17 = $2&255;
  $18 = ((($0)) + 29|0);
  $19 = HEAP8[$18>>0]|0;
  $20 = $19&255;
  $21 = $17 >>> $20;
  $22 = ((($0)) + 33|0);
  $23 = HEAP8[$22>>0]|0;
  $24 = $23&255;
  $25 = $21 << $24;
  $26 = $25 | $16;
  $27 = $3&255;
  $28 = ((($0)) + 30|0);
  $29 = HEAP8[$28>>0]|0;
  $30 = $29&255;
  $31 = $27 >>> $30;
  $32 = ((($0)) + 34|0);
  $33 = HEAP8[$32>>0]|0;
  $34 = $33&255;
  $35 = $31 << $34;
  $36 = $26 | $35;
  $37 = $4&255;
  $38 = ((($0)) + 31|0);
  $39 = HEAP8[$38>>0]|0;
  $40 = $39&255;
  $41 = $37 >>> $40;
  $42 = ((($0)) + 35|0);
  $43 = HEAP8[$42>>0]|0;
  $44 = $43&255;
  $45 = $41 << $44;
  $46 = ((($0)) + 24|0);
  $47 = HEAP32[$46>>2]|0;
  $48 = $45 & $47;
  $49 = $36 | $48;
  $$0 = $49;
  return ($$0|0);
 }
 $50 = HEAP32[$6>>2]|0;
 $51 = ($50|0)>(0);
 L5: do {
  if ($51) {
   $52 = ((($6)) + 4|0);
   $53 = HEAP32[$52>>2]|0;
   $54 = $1&255;
   $55 = $2&255;
   $56 = $3&255;
   $57 = $4&255;
   $$04145$i = 0;$$04244$i = -1;$$046$i = 0;
   while(1) {
    $58 = (($53) + ($$04145$i<<2)|0);
    $59 = HEAP8[$58>>0]|0;
    $60 = $59&255;
    $61 = (($60) - ($54))|0;
    $62 = (((($53) + ($$04145$i<<2)|0)) + 1|0);
    $63 = HEAP8[$62>>0]|0;
    $64 = $63&255;
    $65 = (($64) - ($55))|0;
    $66 = (((($53) + ($$04145$i<<2)|0)) + 2|0);
    $67 = HEAP8[$66>>0]|0;
    $68 = $67&255;
    $69 = (($68) - ($56))|0;
    $70 = (((($53) + ($$04145$i<<2)|0)) + 3|0);
    $71 = HEAP8[$70>>0]|0;
    $72 = $71&255;
    $73 = (($72) - ($57))|0;
    $74 = Math_imul($61, $61)|0;
    $75 = Math_imul($65, $65)|0;
    $76 = (($75) + ($74))|0;
    $77 = Math_imul($69, $69)|0;
    $78 = (($76) + ($77))|0;
    $79 = Math_imul($73, $73)|0;
    $80 = (($78) + ($79))|0;
    $81 = ($80>>>0)<($$04244$i>>>0);
    if ($81) {
     $82 = $$04145$i&255;
     $83 = ($80|0)==(0);
     if ($83) {
      $$2$i = $82;
      break L5;
     } else {
      $$1$i = $82;$$143$i = $80;
     }
    } else {
     $$1$i = $$046$i;$$143$i = $$04244$i;
    }
    $84 = (($$04145$i) + 1)|0;
    $85 = ($84|0)<($50|0);
    if ($85) {
     $$04145$i = $84;$$04244$i = $$143$i;$$046$i = $$1$i;
    } else {
     $$2$i = $$1$i;
     break;
    }
   }
  } else {
   $$2$i = 0;
  }
 } while(0);
 $86 = $$2$i&255;
 $$0 = $86;
 return ($$0|0);
}
function _SDL_CalculatePitch($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($4)) + 9|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = $6&255;
 $8 = Math_imul($7, $2)|0;
 $9 = ((($4)) + 8|0);
 $10 = HEAP8[$9>>0]|0;
 switch ($10<<24>>24) {
 case 1:  {
  $11 = (($8) + 7)|0;
  $12 = (($11|0) / 8)&-1;
  $$0 = $12;
  break;
 }
 case 4:  {
  $13 = (($8) + 1)|0;
  $14 = (($13|0) / 2)&-1;
  $$0 = $14;
  break;
 }
 default: {
  $$0 = $8;
 }
 }
 $15 = (($$0) + 3)|0;
 $16 = $15 & -4;
 return ($16|0);
}
function _SDL_AllocPalette($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $1 = ($0|0)<(1);
 if ($1) {
  HEAP32[$vararg_buffer>>2] = 182988;
  (_SDL_SetError(194740,$vararg_buffer)|0);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = (_SDL_malloc(16)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  (_SDL_Error(0)|0);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = $0 << 2;
 $5 = (_SDL_malloc($4)|0);
 $6 = ((($2)) + 4|0);
 HEAP32[$6>>2] = $5;
 $7 = ($5|0)==(0|0);
 if ($7) {
  _SDL_free($2);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  HEAP32[$2>>2] = $0;
  $8 = ((($2)) + 8|0);
  HEAP32[$8>>2] = 1;
  $9 = ((($2)) + 12|0);
  HEAP32[$9>>2] = 1;
  (_SDL_memset($5,255,$4)|0);
  $$0 = $2;
  STACKTOP = sp;return ($$0|0);
 }
 return (0)|0;
}
function _SDL_FreePalette($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $1 = ($0|0)==(0|0);
 if ($1) {
  HEAP32[$vararg_buffer>>2] = 182980;
  (_SDL_SetError(194740,$vararg_buffer)|0);
  STACKTOP = sp;return;
 }
 $2 = ((($0)) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + -1)|0;
 HEAP32[$2>>2] = $4;
 $5 = ($3|0)>(1);
 if ($5) {
  STACKTOP = sp;return;
 }
 $6 = ((($0)) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 _SDL_free($7);
 _SDL_free($0);
 STACKTOP = sp;return;
}
function _SDL_AllocBlitMap() {
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_SDL_calloc(1,88)|0);
 $1 = ($0|0)==(0|0);
 if ($1) {
  (_SDL_Error(0)|0);
  $$0 = 0;
  return ($$0|0);
 } else {
  $2 = ((($0)) + 76|0);
  HEAP32[$2>>2] = -1;
  $$0 = $0;
  return ($$0|0);
 }
 return (0)|0;
}
function _SDL_floor($0) {
 $0 = +$0;
 var $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (+Math_floor((+$0)));
 return (+$1);
}
function _SDL_LowerBlitScaled($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $$mask = 0, $$off = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre$i = 0, $$pre20 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $switch = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ((($0)) + 52|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($5)) + 68|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 & 512;
 $9 = ($8|0)==(0);
 if ($9) {
  $10 = $7 | 512;
  HEAP32[$6>>2] = $10;
  _SDL_InvalidateMap($5);
  $$pre = HEAP32[$4>>2]|0;
  $$phi$trans$insert = ((($$pre)) + 68|0);
  $$pre20 = HEAP32[$$phi$trans$insert>>2]|0;
  $12 = $$pre20;$27 = $$pre;
 } else {
  $12 = $7;$27 = $5;
 }
 $11 = $12 & 371;
 $13 = ($11|0)==(0);
 do {
  if ($13) {
   $14 = ((($0)) + 4|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = HEAP32[$15>>2]|0;
   $17 = ((($2)) + 4|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = HEAP32[$18>>2]|0;
   $20 = ($16|0)==($19|0);
   if ($20) {
    $21 = ($16|0)==(0);
    $$mask = $16 & -268435456;
    $22 = ($$mask|0)==(268435456);
    $or$cond = $21 | $22;
    if ($or$cond) {
     $23 = $16 >>> 24;
     $24 = $23 & 15;
     $$off = (($24) + -1)|0;
     $switch = ($$off>>>0)<(3);
     if ($switch) {
      break;
     }
    }
    $25 = (_SDL_SoftStretch($0,$1,$2,$3)|0);
    $$0 = $25;
    return ($$0|0);
   }
  }
 } while(0);
 $26 = HEAP32[$27>>2]|0;
 $28 = ($26|0)==($2|0);
 do {
  if ($28) {
   $29 = ((($2)) + 4|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = ((($30)) + 4|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ($32|0)==(0|0);
   if (!($33)) {
    $34 = ((($27)) + 80|0);
    $35 = HEAP32[$34>>2]|0;
    $36 = ((($32)) + 8|0);
    $37 = HEAP32[$36>>2]|0;
    $38 = ($35|0)==($37|0);
    if (!($38)) {
     label = 13;
     break;
    }
   }
   $39 = ((($0)) + 4|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = ((($40)) + 4|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = ($42|0)==(0|0);
   if ($43) {
    $52 = $27;
   } else {
    $44 = ((($27)) + 84|0);
    $45 = HEAP32[$44>>2]|0;
    $46 = ((($42)) + 8|0);
    $47 = HEAP32[$46>>2]|0;
    $48 = ($45|0)==($47|0);
    if ($48) {
     $52 = $27;
    } else {
     label = 13;
    }
   }
  } else {
   label = 13;
  }
 } while(0);
 do {
  if ((label|0) == 13) {
   $49 = (_SDL_MapSurface($0,$2)|0);
   $50 = ($49|0)<(0);
   if ($50) {
    $$0 = -1;
    return ($$0|0);
   } else {
    $$pre$i = HEAP32[$4>>2]|0;
    $52 = $$pre$i;
    break;
   }
  }
 } while(0);
 $51 = ((($52)) + 8|0);
 $53 = HEAP32[$51>>2]|0;
 $54 = (FUNCTION_TABLE_iiiii[$53 & 8191]($0,$1,$2,$3)|0);
 $$0 = $54;
 return ($$0|0);
}
function _SDL_SoftStretch($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $$0100 = 0, $$0101 = 0, $$0102140 = 0, $$0104 = 0, $$01629$i = 0, $$01828$i = 0, $$01831$i = 0, $$01831$i115 = 0, $$01934$i = 0, $$02027$i = 0, $$02030$i = 0, $$02030$i116 = 0, $$02126$i = 0, $$02133$i = 0, $$02229$i = 0, $$02229$i117 = 0, $$02232$i = 0, $$02328$i = 0, $$02328$i118 = 0;
 var $$030$i = 0, $$032$i = 0, $$032$i114 = 0, $$035$i = 0, $$095 = 0, $$096143 = 0, $$097142 = 0, $$098141 = 0, $$1$lcssa = 0, $$1$lcssa$i = 0, $$1$lcssa$i109 = 0, $$1$lcssa$i113 = 0, $$1$lcssa$i126 = 0, $$1103$lcssa = 0, $$117$lcssa$i = 0, $$119$lcssa$i = 0, $$119$lcssa$i108 = 0, $$119$lcssa$i125 = 0, $$120$lcssa$i = 0, $$121$lcssa$i = 0;
 var $$121$lcssa$i124 = 0, $$199$lcssa = 0, $$sroa$0$036$i = 0, $$sroa$0$1$lcssa$i = 0, $$sroa$5$037$i = 0, $$sroa$5$1$lcssa$i = 0, $$sroa$7$038$i = 0, $$sroa$7$1$lcssa$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0;
 var $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0;
 var $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $scevgep$i = 0, $scevgep$i106 = 0;
 var $scevgep$i111 = 0, $scevgep$i121 = 0, $scevgep33$i = 0, $scevgep34$i = 0, $scevgep35$i = 0, $scevgep35$i120 = 0, $scevgep36$i = 0, $scevgep36$i122 = 0, $scevgep41$i = 0, $scevgep42$i = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer3 = 0, $vararg_buffer5 = 0, $vararg_buffer7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(80|0);
 $vararg_buffer7 = sp + 32|0;
 $vararg_buffer5 = sp + 24|0;
 $vararg_buffer3 = sp + 16|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $4 = sp + 56|0;
 $5 = sp + 40|0;
 $6 = ((($2)) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($7)) + 9|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = $9&255;
 $11 = ((($0)) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = HEAP32[$12>>2]|0;
 $14 = HEAP32[$7>>2]|0;
 $15 = ($13|0)==($14|0);
 if (!($15)) {
  $16 = (_SDL_SetError(183039,$vararg_buffer)|0);
  $$0 = $16;
  STACKTOP = sp;return ($$0|0);
 }
 $17 = ($1|0)==(0|0);
 do {
  if ($17) {
   HEAP32[$4>>2] = 0;
   $36 = ((($4)) + 4|0);
   HEAP32[$36>>2] = 0;
   $37 = ((($0)) + 8|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = ((($4)) + 8|0);
   HEAP32[$39>>2] = $38;
   $40 = ((($0)) + 12|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = ((($4)) + 12|0);
   HEAP32[$42>>2] = $41;
   $$095 = $4;
  } else {
   $18 = HEAP32[$1>>2]|0;
   $19 = ($18|0)<(0);
   if (!($19)) {
    $20 = ((($1)) + 4|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = ($21|0)<(0);
    if (!($22)) {
     $23 = ((($1)) + 8|0);
     $24 = HEAP32[$23>>2]|0;
     $25 = (($24) + ($18))|0;
     $26 = ((($0)) + 8|0);
     $27 = HEAP32[$26>>2]|0;
     $28 = ($25|0)>($27|0);
     if (!($28)) {
      $29 = ((($1)) + 12|0);
      $30 = HEAP32[$29>>2]|0;
      $31 = (($30) + ($21))|0;
      $32 = ((($0)) + 12|0);
      $33 = HEAP32[$32>>2]|0;
      $34 = ($31|0)>($33|0);
      if (!($34)) {
       $$095 = $1;
       break;
      }
     }
    }
   }
   $35 = (_SDL_SetError(183076,$vararg_buffer1)|0);
   $$0 = $35;
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 $43 = ($3|0)==(0|0);
 do {
  if ($43) {
   HEAP32[$5>>2] = 0;
   $62 = ((($5)) + 4|0);
   HEAP32[$62>>2] = 0;
   $63 = ((($2)) + 8|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = ((($5)) + 8|0);
   HEAP32[$65>>2] = $64;
   $66 = ((($2)) + 12|0);
   $67 = HEAP32[$66>>2]|0;
   $68 = ((($5)) + 12|0);
   HEAP32[$68>>2] = $67;
   $$0100 = $5;
  } else {
   $44 = HEAP32[$3>>2]|0;
   $45 = ($44|0)<(0);
   if (!($45)) {
    $46 = ((($3)) + 4|0);
    $47 = HEAP32[$46>>2]|0;
    $48 = ($47|0)<(0);
    if (!($48)) {
     $49 = ((($3)) + 8|0);
     $50 = HEAP32[$49>>2]|0;
     $51 = (($50) + ($44))|0;
     $52 = ((($2)) + 8|0);
     $53 = HEAP32[$52>>2]|0;
     $54 = ($51|0)>($53|0);
     if (!($54)) {
      $55 = ((($3)) + 12|0);
      $56 = HEAP32[$55>>2]|0;
      $57 = (($56) + ($47))|0;
      $58 = ((($2)) + 12|0);
      $59 = HEAP32[$58>>2]|0;
      $60 = ($57|0)>($59|0);
      if (!($60)) {
       $$0100 = $3;
       break;
      }
     }
    }
   }
   $61 = (_SDL_SetError(183106,$vararg_buffer3)|0);
   $$0 = $61;
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 $69 = HEAP32[$2>>2]|0;
 $70 = $69 & 2;
 $71 = ($70|0)==(0);
 if ($71) {
  $$0104 = 0;
 } else {
  $72 = (_SDL_LockSurface($2)|0);
  $73 = ($72|0)<(0);
  if ($73) {
   $74 = (_SDL_SetError(183141,$vararg_buffer5)|0);
   $$0 = $74;
   STACKTOP = sp;return ($$0|0);
  } else {
   $$0104 = 1;
  }
 }
 $75 = HEAP32[$0>>2]|0;
 $76 = $75 & 2;
 $77 = ($76|0)==(0);
 if ($77) {
  $$0101 = 0;
 } else {
  $78 = (_SDL_LockSurface($0)|0);
  $79 = ($78|0)<(0);
  if ($79) {
   $80 = ($$0104|0)==(0);
   if (!($80)) {
    _SDL_UnlockSurface($2);
   }
   $81 = (_SDL_SetError(183176,$vararg_buffer7)|0);
   $$0 = $81;
   STACKTOP = sp;return ($$0|0);
  } else {
   $$0101 = 1;
  }
 }
 $82 = ((($$095)) + 12|0);
 $83 = HEAP32[$82>>2]|0;
 $84 = $83 << 16;
 $85 = ((($$0100)) + 12|0);
 $86 = HEAP32[$85>>2]|0;
 $87 = (($84|0) / ($86|0))&-1;
 $88 = ((($$0100)) + 4|0);
 $89 = HEAP32[$88>>2]|0;
 $90 = (($89) + ($86))|0;
 $91 = ($86|0)>(0);
 L38: do {
  if ($91) {
   $92 = ((($$095)) + 4|0);
   $93 = HEAP32[$92>>2]|0;
   $94 = ((($2)) + 20|0);
   $95 = ((($2)) + 16|0);
   $96 = ((($$095)) + 8|0);
   $97 = ((($$0100)) + 8|0);
   $98 = ((($0)) + 20|0);
   $99 = ((($0)) + 16|0);
   $$0102140 = 65536;$$096143 = 0;$$097142 = $89;$$098141 = $93;
   while(1) {
    $100 = HEAP32[$94>>2]|0;
    $101 = HEAP32[$95>>2]|0;
    $102 = Math_imul($101, $$097142)|0;
    $103 = (($100) + ($102)|0);
    $104 = HEAP32[$$0100>>2]|0;
    $105 = Math_imul($104, $10)|0;
    $106 = (($103) + ($105)|0);
    $107 = ($$0102140|0)>(65535);
    if ($107) {
     $108 = (($$0102140) + -65536)|0;
     $109 = $108 >>> 16;
     $110 = (($$098141) + 1)|0;
     $111 = $109 << 16;
     $112 = (($$098141) + ($109))|0;
     $113 = (($110) + ($109))|0;
     $114 = (($108) - ($111))|0;
     $115 = HEAP32[$98>>2]|0;
     $116 = HEAP32[$99>>2]|0;
     $117 = Math_imul($116, $112)|0;
     $118 = (($115) + ($117)|0);
     $119 = HEAP32[$$095>>2]|0;
     $120 = Math_imul($119, $10)|0;
     $121 = (($118) + ($120)|0);
     $$1$lcssa = $121;$$1103$lcssa = $114;$$199$lcssa = $113;
    } else {
     $$1$lcssa = $$096143;$$1103$lcssa = $$0102140;$$199$lcssa = $$098141;
    }
    switch ($9<<24>>24) {
    case 1:  {
     $122 = HEAP32[$96>>2]|0;
     $123 = HEAP32[$97>>2]|0;
     $124 = $122 << 16;
     $125 = (($124|0) / ($123|0))&-1;
     $126 = ($123|0)>(0);
     if ($126) {
      $$01629$i = $$1$lcssa;$$01828$i = 65536;$$02027$i = $123;$$02126$i = $106;$$030$i = 0;
      while(1) {
       $127 = ($$01828$i|0)>(65535);
       $128 = (($$01828$i) + -65536)|0;
       $129 = $128 >>> 16;
       if ($127) {
        $130 = $129 << 16;
        $131 = (($128) - ($130))|0;
        $scevgep33$i = ((($$01629$i)) + 1|0);
        $scevgep34$i = (($scevgep33$i) + ($129)|0);
        $scevgep$i = (($$01629$i) + ($129)|0);
        $132 = HEAP8[$scevgep$i>>0]|0;
        $$1$lcssa$i = $132;$$117$lcssa$i = $scevgep34$i;$$119$lcssa$i = $131;
       } else {
        $$1$lcssa$i = $$030$i;$$117$lcssa$i = $$01629$i;$$119$lcssa$i = $$01828$i;
       }
       $133 = ((($$02126$i)) + 1|0);
       HEAP8[$$02126$i>>0] = $$1$lcssa$i;
       $134 = (($$119$lcssa$i) + ($125))|0;
       $135 = (($$02027$i) + -1)|0;
       $136 = ($$02027$i|0)>(1);
       if ($136) {
        $$01629$i = $$117$lcssa$i;$$01828$i = $134;$$02027$i = $135;$$02126$i = $133;$$030$i = $$1$lcssa$i;
       } else {
        break;
       }
      }
     }
     break;
    }
    case 2:  {
     $137 = HEAP32[$96>>2]|0;
     $138 = HEAP32[$97>>2]|0;
     $139 = $137 << 16;
     $140 = (($139|0) / ($138|0))&-1;
     $141 = ($138|0)>(0);
     if ($141) {
      $$01831$i115 = $$1$lcssa;$$02030$i116 = 65536;$$02229$i117 = $138;$$02328$i118 = $106;$$032$i114 = 0;
      while(1) {
       $142 = ($$02030$i116|0)>(65535);
       $143 = (($$02030$i116) + -65536)|0;
       $144 = $143 >>> 16;
       if ($142) {
        $145 = $144 << 16;
        $146 = (($143) - ($145))|0;
        $scevgep35$i120 = ((($$01831$i115)) + 2|0);
        $scevgep36$i122 = (($scevgep35$i120) + ($144<<1)|0);
        $scevgep$i121 = (($$01831$i115) + ($144<<1)|0);
        $147 = HEAP16[$scevgep$i121>>1]|0;
        $$1$lcssa$i126 = $147;$$119$lcssa$i125 = $scevgep36$i122;$$121$lcssa$i124 = $146;
       } else {
        $$1$lcssa$i126 = $$032$i114;$$119$lcssa$i125 = $$01831$i115;$$121$lcssa$i124 = $$02030$i116;
       }
       $148 = ((($$02328$i118)) + 2|0);
       HEAP16[$$02328$i118>>1] = $$1$lcssa$i126;
       $149 = (($$121$lcssa$i124) + ($140))|0;
       $150 = (($$02229$i117) + -1)|0;
       $151 = ($$02229$i117|0)>(1);
       if ($151) {
        $$01831$i115 = $$119$lcssa$i125;$$02030$i116 = $149;$$02229$i117 = $150;$$02328$i118 = $148;$$032$i114 = $$1$lcssa$i126;
       } else {
        break;
       }
      }
     }
     break;
    }
    case 3:  {
     $152 = HEAP32[$96>>2]|0;
     $153 = HEAP32[$97>>2]|0;
     $154 = $152 << 16;
     $155 = (($154|0) / ($153|0))&-1;
     $156 = ($153|0)>(0);
     if ($156) {
      $$01934$i = 65536;$$02133$i = $153;$$02232$i = $106;$$035$i = $$1$lcssa;$$sroa$0$036$i = 0;$$sroa$5$037$i = 0;$$sroa$7$038$i = 0;
      while(1) {
       $157 = ($$01934$i|0)>(65535);
       $158 = (($$01934$i) + -65536)|0;
       $159 = $158 >>> 16;
       $160 = ($159*3)|0;
       $scevgep$i111 = (($$035$i) + ($160)|0);
       if ($157) {
        $161 = ((($scevgep$i111)) + 2|0);
        $162 = ((($scevgep$i111)) + 1|0);
        $163 = $159 << 16;
        $164 = (($158) - ($163))|0;
        $scevgep41$i = ((($$035$i)) + 3|0);
        $scevgep42$i = (($scevgep41$i) + ($160)|0);
        $165 = HEAP8[$scevgep$i111>>0]|0;
        $166 = HEAP8[$162>>0]|0;
        $167 = HEAP8[$161>>0]|0;
        $$1$lcssa$i113 = $scevgep42$i;$$120$lcssa$i = $164;$$sroa$0$1$lcssa$i = $165;$$sroa$5$1$lcssa$i = $166;$$sroa$7$1$lcssa$i = $167;
       } else {
        $$1$lcssa$i113 = $$035$i;$$120$lcssa$i = $$01934$i;$$sroa$0$1$lcssa$i = $$sroa$0$036$i;$$sroa$5$1$lcssa$i = $$sroa$5$037$i;$$sroa$7$1$lcssa$i = $$sroa$7$038$i;
       }
       $168 = ((($$02232$i)) + 1|0);
       HEAP8[$$02232$i>>0] = $$sroa$0$1$lcssa$i;
       $169 = ((($$02232$i)) + 2|0);
       HEAP8[$168>>0] = $$sroa$5$1$lcssa$i;
       $170 = ((($$02232$i)) + 3|0);
       HEAP8[$169>>0] = $$sroa$7$1$lcssa$i;
       $171 = (($$120$lcssa$i) + ($155))|0;
       $172 = (($$02133$i) + -1)|0;
       $173 = ($$02133$i|0)>(1);
       if ($173) {
        $$01934$i = $171;$$02133$i = $172;$$02232$i = $170;$$035$i = $$1$lcssa$i113;$$sroa$0$036$i = $$sroa$0$1$lcssa$i;$$sroa$5$037$i = $$sroa$5$1$lcssa$i;$$sroa$7$038$i = $$sroa$7$1$lcssa$i;
       } else {
        break;
       }
      }
     }
     break;
    }
    case 4:  {
     $174 = HEAP32[$96>>2]|0;
     $175 = HEAP32[$97>>2]|0;
     $176 = $174 << 16;
     $177 = (($176|0) / ($175|0))&-1;
     $178 = ($175|0)>(0);
     if ($178) {
      $$01831$i = $$1$lcssa;$$02030$i = 65536;$$02229$i = $175;$$02328$i = $106;$$032$i = 0;
      while(1) {
       $179 = ($$02030$i|0)>(65535);
       $180 = (($$02030$i) + -65536)|0;
       $181 = $180 >>> 16;
       if ($179) {
        $182 = $181 << 16;
        $183 = (($180) - ($182))|0;
        $scevgep35$i = ((($$01831$i)) + 4|0);
        $scevgep36$i = (($scevgep35$i) + ($181<<2)|0);
        $scevgep$i106 = (($$01831$i) + ($181<<2)|0);
        $184 = HEAP32[$scevgep$i106>>2]|0;
        $$1$lcssa$i109 = $184;$$119$lcssa$i108 = $scevgep36$i;$$121$lcssa$i = $183;
       } else {
        $$1$lcssa$i109 = $$032$i;$$119$lcssa$i108 = $$01831$i;$$121$lcssa$i = $$02030$i;
       }
       $185 = ((($$02328$i)) + 4|0);
       HEAP32[$$02328$i>>2] = $$1$lcssa$i109;
       $186 = (($$121$lcssa$i) + ($177))|0;
       $187 = (($$02229$i) + -1)|0;
       $188 = ($$02229$i|0)>(1);
       if ($188) {
        $$01831$i = $$119$lcssa$i108;$$02030$i = $186;$$02229$i = $187;$$02328$i = $185;$$032$i = $$1$lcssa$i109;
       } else {
        break;
       }
      }
     }
     break;
    }
    default: {
    }
    }
    $189 = (($$1103$lcssa) + ($87))|0;
    $190 = (($$097142) + 1)|0;
    $191 = ($190|0)<($90|0);
    if ($191) {
     $$0102140 = $189;$$096143 = $$1$lcssa;$$097142 = $190;$$098141 = $$199$lcssa;
    } else {
     break L38;
    }
   }
  }
 } while(0);
 $192 = ($$0104|0)==(0);
 if (!($192)) {
  _SDL_UnlockSurface($2);
 }
 $193 = ($$0101|0)==(0);
 if ($193) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 _SDL_UnlockSurface($0);
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _SDL_FillRects($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$01315 = 0, $$014 = 0, $$016 = 0, $10 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $4 = ($1|0)==(0|0);
 if ($4) {
  $6 = (_SDL_SetError(183263,$vararg_buffer)|0);
  $$014 = $6;
 } else {
  $5 = ($2|0)>(0);
  if ($5) {
   $$01315 = 0;$$016 = 0;
   while(1) {
    $7 = (($1) + ($$01315<<4)|0);
    $8 = (_SDL_FillRect($0,$7,$3)|0);
    $9 = (($8) + ($$016))|0;
    $10 = (($$01315) + 1)|0;
    $exitcond = ($10|0)==($2|0);
    if ($exitcond) {
     $$014 = $9;
     break;
    } else {
     $$01315 = $10;$$016 = $9;
    }
   }
  } else {
   $$014 = 0;
  }
 }
 STACKTOP = sp;return ($$014|0);
}
function _SDL_BlendFillRects($0,$1,$2,$3,$4,$5,$6,$7) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 var $$04149 = 0, $$042 = 0, $$043 = 0, $$044 = 0, $$045 = 0, $$050 = 0, $$1 = 0, $$140 = 0, $$off = 0, $$sink = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $8 = 0, $9 = 0, $SDL_BlendFillRect_RGB$SDL_BlendFillRect_RGBA = 0, $SDL_BlendFillRect_RGB888$SDL_BlendFillRect_ARGB8888 = 0, $cond = 0, $cond1 = 0, $cond2 = 0, $exitcond = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $vararg_buffer = sp;
 $8 = sp + 8|0;
 $9 = ($0|0)==(0|0);
 if ($9) {
  $$sink = 183547;
 } else {
  $10 = ((($0)) + 4|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ((($11)) + 8|0);
  $13 = HEAP8[$12>>0]|0;
  $14 = ($13&255)<(8);
  if ($14) {
   $$sink = 183214;
  } else {
   $$off = (($3) + -1)|0;
   $15 = ($$off>>>0)<(2);
   if ($15) {
    $16 = $4&255;
    $17 = $7&255;
    $18 = Math_imul($17, $16)|0;
    $19 = (($18>>>0) / 255)&-1;
    $20 = $19&255;
    $21 = $5&255;
    $22 = Math_imul($17, $21)|0;
    $23 = (($22>>>0) / 255)&-1;
    $24 = $23&255;
    $25 = $6&255;
    $26 = Math_imul($17, $25)|0;
    $27 = (($26>>>0) / 255)&-1;
    $28 = $27&255;
    $$043 = $28;$$044 = $24;$$045 = $20;
   } else {
    $$043 = $6;$$044 = $5;$$045 = $4;
   }
   switch ($13<<24>>24) {
   case 15:  {
    $29 = ((($11)) + 12|0);
    $30 = HEAP32[$29>>2]|0;
    $cond2 = ($30|0)==(31744);
    if ($cond2) {
     $$140 = 4352;
    } else {
     label = 10;
    }
    break;
   }
   case 16:  {
    $31 = ((($11)) + 12|0);
    $32 = HEAP32[$31>>2]|0;
    $cond1 = ($32|0)==(63488);
    if ($cond1) {
     $$140 = 4353;
    } else {
     label = 10;
    }
    break;
   }
   case 32:  {
    $33 = ((($11)) + 12|0);
    $34 = HEAP32[$33>>2]|0;
    $cond = ($34|0)==(16711680);
    if ($cond) {
     $35 = ((($11)) + 24|0);
     $36 = HEAP32[$35>>2]|0;
     $37 = ($36|0)==(0);
     $SDL_BlendFillRect_RGB888$SDL_BlendFillRect_ARGB8888 = $37 ? 4349 : 4348;
     $$140 = $SDL_BlendFillRect_RGB888$SDL_BlendFillRect_ARGB8888;
    } else {
     label = 10;
    }
    break;
   }
   default: {
    label = 10;
   }
   }
   if ((label|0) == 10) {
    $38 = ((($11)) + 24|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = ($39|0)==(0);
    $SDL_BlendFillRect_RGB$SDL_BlendFillRect_RGBA = $40 ? 4351 : 4350;
    $$140 = $SDL_BlendFillRect_RGB$SDL_BlendFillRect_RGBA;
   }
   $41 = ($2|0)>(0);
   if (!($41)) {
    $$042 = 0;
    STACKTOP = sp;return ($$042|0);
   }
   $42 = ((($0)) + 36|0);
   $$04149 = 0;$$050 = 0;
   while(1) {
    $43 = (($1) + ($$04149<<4)|0);
    $44 = (_SDL_IntersectRect($43,$42,$8)|0);
    $45 = ($44|0)==(0);
    if ($45) {
     $$1 = $$050;
    } else {
     $46 = (FUNCTION_TABLE_iiiiiiii[$$140 & 8191]($0,$8,$3,$$045,$$044,$$043,$7)|0);
     $$1 = $46;
    }
    $47 = (($$04149) + 1)|0;
    $exitcond = ($47|0)==($2|0);
    if ($exitcond) {
     $$042 = $$1;
     break;
    } else {
     $$04149 = $47;$$050 = $$1;
    }
   }
   STACKTOP = sp;return ($$042|0);
  }
 }
 $48 = (_SDL_SetError($$sink,$vararg_buffer)|0);
 $$042 = $48;
 STACKTOP = sp;return ($$042|0);
}
function _SDL_BlendFillRect_RGB888($0,$1,$2,$3,$4,$5,$6) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 var $$ = 0, $$0505574 = 0, $$0510 = 0, $$0515577 = 0, $$0520 = 0, $$0525580 = 0, $$0530 = 0, $$0535550 = 0, $$0535550$us = 0, $$0535550$us551 = 0, $$0535550$us562 = 0, $$0540$us = 0, $$1 = 0, $$10 = 0, $$11 = 0, $$1506 = 0, $$1511 = 0, $$1516 = 0, $$1521 = 0, $$1526 = 0;
 var $$1531 = 0, $$1536$us = 0, $$1541$us554616 = 0, $$2 = 0, $$2507 = 0, $$2512 = 0, $$2517 = 0, $$2522 = 0, $$2527 = 0, $$2532 = 0, $$2537$us555617 = 0, $$2542$us567621 = 0, $$3 = 0, $$3508 = 0, $$3513 = 0, $$3518 = 0, $$3523 = 0, $$3528 = 0, $$3533 = 0, $$3538$us568622 = 0;
 var $$3543613 = 0, $$4 = 0, $$4509 = 0, $$4519 = 0, $$4529 = 0, $$4539614 = 0, $$5 = 0, $$6 = 0, $$7 = 0, $$8 = 0, $$9 = 0, $$in = 0, $$in584 = 0, $$in585 = 0, $$lcssa = 0, $$lcssa611 = 0, $$lcssa612 = 0, $10 = 0, $100 = 0, $101 = 0;
 var $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0;
 var $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0;
 var $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0;
 var $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0;
 var $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0;
 var $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0;
 var $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0;
 var $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0;
 var $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0;
 var $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0;
 var $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $30 = 0, $300 = 0, $301 = 0;
 var $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0;
 var $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0;
 var $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0;
 var $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0;
 var $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0;
 var $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $trunc = 0, $trunc$clear = 0, $trunc544 = 0, $trunc544$clear = 0, $trunc545 = 0;
 var $trunc545$clear = 0, $trunc546 = 0, $trunc546$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $7 = $6 ^ -1;
 $8 = $7&255;
 switch ($2|0) {
 case 1:  {
  $9 = ((($1)) + 8|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ((($1)) + 12|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ((($0)) + 16|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = ((($0)) + 4|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ((($16)) + 9|0);
  $18 = HEAP8[$17>>0]|0;
  $19 = $18&255;
  $20 = (($14|0) / ($19|0))&-1;
  $21 = (($20) - ($10))|0;
  $22 = ($12|0)==(0);
  if ($22) {
   return 0;
  }
  $23 = ((($0)) + 20|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = ((($1)) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = Math_imul($26, $20)|0;
  $28 = (($24) + ($27<<2)|0);
  $29 = HEAP32[$1>>2]|0;
  $30 = (($28) + ($29<<2)|0);
  $31 = (($10) + 3)|0;
  $32 = (($31|0) / 4)&-1;
  $trunc545 = $10&255;
  $33 = $3&255;
  $34 = $4&255;
  $35 = $5&255;
  $$0505574 = $30;$$in585 = $12;
  L41: while(1) {
   $36 = (($$in585) + -1)|0;
   $trunc545$clear = $trunc545 & 3;
   switch ($trunc545$clear<<24>>24) {
   case 0:  {
    $$0510 = $32;$$1506 = $$0505574;
    label = 5;
    break;
   }
   case 3:  {
    $$1511 = $32;$$2507 = $$0505574;
    label = 6;
    break;
   }
   case 2:  {
    $$2512 = $32;$$3508 = $$0505574;
    label = 7;
    break;
   }
   case 1:  {
    $$3513 = $32;$$4509 = $$0505574;
    label = 8;
    break;
   }
   default: {
    label = 9;
    break L41;
   }
   }
   while(1) {
    if ((label|0) == 5) {
     label = 0;
     $37 = HEAP32[$$1506>>2]|0;
     $38 = $37 >>> 16;
     $39 = $38 & 255;
     $40 = $37 >>> 8;
     $41 = $40 & 255;
     $42 = $37 & 255;
     $43 = Math_imul($39, $8)|0;
     $44 = (($43>>>0) / 255)&-1;
     $45 = (($44) + ($33))|0;
     $46 = Math_imul($41, $8)|0;
     $47 = (($46>>>0) / 255)&-1;
     $48 = (($47) + ($34))|0;
     $49 = Math_imul($42, $8)|0;
     $50 = (($49>>>0) / 255)&-1;
     $51 = (($50) + ($35))|0;
     $52 = $45 << 16;
     $53 = $48 << 8;
     $54 = $53 | $51;
     $55 = $54 | $52;
     HEAP32[$$1506>>2] = $55;
     $56 = ((($$1506)) + 4|0);
     $$1511 = $$0510;$$2507 = $56;
     label = 6;
     continue;
    }
    else if ((label|0) == 6) {
     label = 0;
     $57 = HEAP32[$$2507>>2]|0;
     $58 = $57 >>> 16;
     $59 = $58 & 255;
     $60 = $57 >>> 8;
     $61 = $60 & 255;
     $62 = $57 & 255;
     $63 = Math_imul($59, $8)|0;
     $64 = (($63>>>0) / 255)&-1;
     $65 = (($64) + ($33))|0;
     $66 = Math_imul($61, $8)|0;
     $67 = (($66>>>0) / 255)&-1;
     $68 = (($67) + ($34))|0;
     $69 = Math_imul($62, $8)|0;
     $70 = (($69>>>0) / 255)&-1;
     $71 = (($70) + ($35))|0;
     $72 = $65 << 16;
     $73 = $68 << 8;
     $74 = $73 | $71;
     $75 = $74 | $72;
     HEAP32[$$2507>>2] = $75;
     $76 = ((($$2507)) + 4|0);
     $$2512 = $$1511;$$3508 = $76;
     label = 7;
     continue;
    }
    else if ((label|0) == 7) {
     label = 0;
     $77 = HEAP32[$$3508>>2]|0;
     $78 = $77 >>> 16;
     $79 = $78 & 255;
     $80 = $77 >>> 8;
     $81 = $80 & 255;
     $82 = $77 & 255;
     $83 = Math_imul($79, $8)|0;
     $84 = (($83>>>0) / 255)&-1;
     $85 = (($84) + ($33))|0;
     $86 = Math_imul($81, $8)|0;
     $87 = (($86>>>0) / 255)&-1;
     $88 = (($87) + ($34))|0;
     $89 = Math_imul($82, $8)|0;
     $90 = (($89>>>0) / 255)&-1;
     $91 = (($90) + ($35))|0;
     $92 = $85 << 16;
     $93 = $88 << 8;
     $94 = $93 | $91;
     $95 = $94 | $92;
     HEAP32[$$3508>>2] = $95;
     $96 = ((($$3508)) + 4|0);
     $$3513 = $$2512;$$4509 = $96;
     label = 8;
     continue;
    }
    else if ((label|0) == 8) {
     label = 0;
     $97 = HEAP32[$$4509>>2]|0;
     $98 = $97 >>> 16;
     $99 = $98 & 255;
     $100 = $97 >>> 8;
     $101 = $100 & 255;
     $102 = $97 & 255;
     $103 = Math_imul($99, $8)|0;
     $104 = (($103>>>0) / 255)&-1;
     $105 = (($104) + ($33))|0;
     $106 = Math_imul($101, $8)|0;
     $107 = (($106>>>0) / 255)&-1;
     $108 = (($107) + ($34))|0;
     $109 = Math_imul($102, $8)|0;
     $110 = (($109>>>0) / 255)&-1;
     $111 = (($110) + ($35))|0;
     $112 = $105 << 16;
     $113 = $108 << 8;
     $114 = $113 | $111;
     $115 = $114 | $112;
     HEAP32[$$4509>>2] = $115;
     $116 = ((($$4509)) + 4|0);
     $117 = (($$3513) + -1)|0;
     $118 = ($$3513|0)>(1);
     if ($118) {
      $$0510 = $117;$$1506 = $116;
      label = 5;
      continue;
     } else {
      break;
     }
    }
   }
   $119 = (($116) + ($21<<2)|0);
   $120 = ($36|0)==(0);
   if ($120) {
    label = 46;
    break;
   } else {
    $$0505574 = $119;$$in585 = $36;
   }
  }
  if ((label|0) == 9) {
   // unreachable;
  }
  else if ((label|0) == 46) {
   return 0;
  }
  break;
 }
 case 2:  {
  $121 = ((($1)) + 8|0);
  $122 = HEAP32[$121>>2]|0;
  $123 = ((($1)) + 12|0);
  $124 = HEAP32[$123>>2]|0;
  $125 = ((($0)) + 16|0);
  $126 = HEAP32[$125>>2]|0;
  $127 = ((($0)) + 4|0);
  $128 = HEAP32[$127>>2]|0;
  $129 = ((($128)) + 9|0);
  $130 = HEAP8[$129>>0]|0;
  $131 = $130&255;
  $132 = (($126|0) / ($131|0))&-1;
  $133 = (($132) - ($122))|0;
  $134 = ($124|0)==(0);
  if ($134) {
   return 0;
  }
  $135 = ((($0)) + 20|0);
  $136 = HEAP32[$135>>2]|0;
  $137 = ((($1)) + 4|0);
  $138 = HEAP32[$137>>2]|0;
  $139 = Math_imul($138, $132)|0;
  $140 = (($136) + ($139<<2)|0);
  $141 = HEAP32[$1>>2]|0;
  $142 = (($140) + ($141<<2)|0);
  $143 = (($122) + 3)|0;
  $144 = (($143|0) / 4)&-1;
  $trunc544 = $122&255;
  $145 = $3&255;
  $146 = $4&255;
  $147 = $5&255;
  $$0515577 = $142;$$in584 = $124;
  L57: while(1) {
   $148 = (($$in584) + -1)|0;
   $trunc544$clear = $trunc544 & 3;
   switch ($trunc544$clear<<24>>24) {
   case 0:  {
    $$0520 = $144;$$1516 = $$0515577;
    label = 14;
    break;
   }
   case 3:  {
    $$1521 = $144;$$2517 = $$0515577;
    label = 15;
    break;
   }
   case 2:  {
    $$2522 = $144;$$3518 = $$0515577;
    label = 16;
    break;
   }
   case 1:  {
    $$3523 = $144;$$4519 = $$0515577;
    label = 17;
    break;
   }
   default: {
    label = 18;
    break L57;
   }
   }
   while(1) {
    if ((label|0) == 14) {
     label = 0;
     $149 = HEAP32[$$1516>>2]|0;
     $150 = $149 >>> 16;
     $151 = $150 & 255;
     $152 = $149 >>> 8;
     $153 = $152 & 255;
     $154 = $149 & 255;
     $155 = (($151) + ($145))|0;
     $156 = ($155>>>0)<(255);
     $$7 = $156 ? $155 : 255;
     $157 = (($153) + ($146))|0;
     $158 = ($157>>>0)<(255);
     $$ = $158 ? $157 : 255;
     $159 = (($154) + ($147))|0;
     $160 = ($159>>>0)<(255);
     $$11 = $160 ? $159 : 255;
     $161 = $$7 << 16;
     $162 = $$ << 8;
     $163 = $162 | $$11;
     $164 = $163 | $161;
     HEAP32[$$1516>>2] = $164;
     $165 = ((($$1516)) + 4|0);
     $$1521 = $$0520;$$2517 = $165;
     label = 15;
     continue;
    }
    else if ((label|0) == 15) {
     label = 0;
     $166 = HEAP32[$$2517>>2]|0;
     $167 = $166 >>> 16;
     $168 = $167 & 255;
     $169 = $166 >>> 8;
     $170 = $169 & 255;
     $171 = $166 & 255;
     $172 = (($168) + ($145))|0;
     $173 = ($172>>>0)<(255);
     $$1 = $173 ? $172 : 255;
     $174 = (($170) + ($146))|0;
     $175 = ($174>>>0)<(255);
     $$8 = $175 ? $174 : 255;
     $176 = (($171) + ($147))|0;
     $177 = ($176>>>0)<(255);
     $$2 = $177 ? $176 : 255;
     $178 = $$1 << 16;
     $179 = $$8 << 8;
     $180 = $179 | $$2;
     $181 = $180 | $178;
     HEAP32[$$2517>>2] = $181;
     $182 = ((($$2517)) + 4|0);
     $$2522 = $$1521;$$3518 = $182;
     label = 16;
     continue;
    }
    else if ((label|0) == 16) {
     label = 0;
     $183 = HEAP32[$$3518>>2]|0;
     $184 = $183 >>> 16;
     $185 = $184 & 255;
     $186 = $183 >>> 8;
     $187 = $186 & 255;
     $188 = $183 & 255;
     $189 = (($185) + ($145))|0;
     $190 = ($189>>>0)<(255);
     $$3 = $190 ? $189 : 255;
     $191 = (($187) + ($146))|0;
     $192 = ($191>>>0)<(255);
     $$9 = $192 ? $191 : 255;
     $193 = (($188) + ($147))|0;
     $194 = ($193>>>0)<(255);
     $$4 = $194 ? $193 : 255;
     $195 = $$3 << 16;
     $196 = $$9 << 8;
     $197 = $196 | $$4;
     $198 = $197 | $195;
     HEAP32[$$3518>>2] = $198;
     $199 = ((($$3518)) + 4|0);
     $$3523 = $$2522;$$4519 = $199;
     label = 17;
     continue;
    }
    else if ((label|0) == 17) {
     label = 0;
     $200 = HEAP32[$$4519>>2]|0;
     $201 = $200 >>> 16;
     $202 = $201 & 255;
     $203 = $200 >>> 8;
     $204 = $203 & 255;
     $205 = $200 & 255;
     $206 = (($202) + ($145))|0;
     $207 = ($206>>>0)<(255);
     $$5 = $207 ? $206 : 255;
     $208 = (($204) + ($146))|0;
     $209 = ($208>>>0)<(255);
     $$10 = $209 ? $208 : 255;
     $210 = (($205) + ($147))|0;
     $211 = ($210>>>0)<(255);
     $$6 = $211 ? $210 : 255;
     $212 = $$5 << 16;
     $213 = $$10 << 8;
     $214 = $213 | $$6;
     $215 = $214 | $212;
     HEAP32[$$4519>>2] = $215;
     $216 = ((($$4519)) + 4|0);
     $217 = (($$3523) + -1)|0;
     $218 = ($$3523|0)>(1);
     if ($218) {
      $$0520 = $217;$$1516 = $216;
      label = 14;
      continue;
     } else {
      break;
     }
    }
   }
   $219 = (($216) + ($133<<2)|0);
   $220 = ($148|0)==(0);
   if ($220) {
    label = 46;
    break;
   } else {
    $$0515577 = $219;$$in584 = $148;
   }
  }
  if ((label|0) == 18) {
   // unreachable;
  }
  else if ((label|0) == 46) {
   return 0;
  }
  break;
 }
 case 4:  {
  $221 = ((($1)) + 8|0);
  $222 = HEAP32[$221>>2]|0;
  $223 = ((($1)) + 12|0);
  $224 = HEAP32[$223>>2]|0;
  $225 = ((($0)) + 16|0);
  $226 = HEAP32[$225>>2]|0;
  $227 = ((($0)) + 4|0);
  $228 = HEAP32[$227>>2]|0;
  $229 = ((($228)) + 9|0);
  $230 = HEAP8[$229>>0]|0;
  $231 = $230&255;
  $232 = (($226|0) / ($231|0))&-1;
  $233 = (($232) - ($222))|0;
  $234 = ($224|0)==(0);
  if ($234) {
   return 0;
  }
  $235 = ((($0)) + 20|0);
  $236 = HEAP32[$235>>2]|0;
  $237 = ((($1)) + 4|0);
  $238 = HEAP32[$237>>2]|0;
  $239 = Math_imul($238, $232)|0;
  $240 = (($236) + ($239<<2)|0);
  $241 = HEAP32[$1>>2]|0;
  $242 = (($240) + ($241<<2)|0);
  $243 = (($222) + 3)|0;
  $244 = (($243|0) / 4)&-1;
  $trunc = $222&255;
  $245 = $3&255;
  $246 = $4&255;
  $247 = $5&255;
  $$0525580 = $242;$$in = $224;
  L73: while(1) {
   $248 = (($$in) + -1)|0;
   $trunc$clear = $trunc & 3;
   switch ($trunc$clear<<24>>24) {
   case 0:  {
    $$0530 = $244;$$1526 = $$0525580;
    label = 23;
    break;
   }
   case 3:  {
    $$1531 = $244;$$2527 = $$0525580;
    label = 24;
    break;
   }
   case 2:  {
    $$2532 = $244;$$3528 = $$0525580;
    label = 25;
    break;
   }
   case 1:  {
    $$3533 = $244;$$4529 = $$0525580;
    label = 26;
    break;
   }
   default: {
    label = 27;
    break L73;
   }
   }
   while(1) {
    if ((label|0) == 23) {
     label = 0;
     $249 = HEAP32[$$1526>>2]|0;
     $250 = $249 >>> 16;
     $251 = $250 & 255;
     $252 = $249 >>> 8;
     $253 = $252 & 255;
     $254 = $249 & 255;
     $255 = Math_imul($251, $245)|0;
     $256 = (($255>>>0) / 255)&-1;
     $257 = Math_imul($253, $246)|0;
     $258 = (($257>>>0) / 255)&-1;
     $259 = Math_imul($254, $247)|0;
     $260 = (($259>>>0) / 255)&-1;
     $261 = $256 << 16;
     $262 = $258 << 8;
     $263 = $262 | $260;
     $264 = $263 | $261;
     HEAP32[$$1526>>2] = $264;
     $265 = ((($$1526)) + 4|0);
     $$1531 = $$0530;$$2527 = $265;
     label = 24;
     continue;
    }
    else if ((label|0) == 24) {
     label = 0;
     $266 = HEAP32[$$2527>>2]|0;
     $267 = $266 >>> 16;
     $268 = $267 & 255;
     $269 = $266 >>> 8;
     $270 = $269 & 255;
     $271 = $266 & 255;
     $272 = Math_imul($268, $245)|0;
     $273 = (($272>>>0) / 255)&-1;
     $274 = Math_imul($270, $246)|0;
     $275 = (($274>>>0) / 255)&-1;
     $276 = Math_imul($271, $247)|0;
     $277 = (($276>>>0) / 255)&-1;
     $278 = $273 << 16;
     $279 = $275 << 8;
     $280 = $279 | $277;
     $281 = $280 | $278;
     HEAP32[$$2527>>2] = $281;
     $282 = ((($$2527)) + 4|0);
     $$2532 = $$1531;$$3528 = $282;
     label = 25;
     continue;
    }
    else if ((label|0) == 25) {
     label = 0;
     $283 = HEAP32[$$3528>>2]|0;
     $284 = $283 >>> 16;
     $285 = $284 & 255;
     $286 = $283 >>> 8;
     $287 = $286 & 255;
     $288 = $283 & 255;
     $289 = Math_imul($285, $245)|0;
     $290 = (($289>>>0) / 255)&-1;
     $291 = Math_imul($287, $246)|0;
     $292 = (($291>>>0) / 255)&-1;
     $293 = Math_imul($288, $247)|0;
     $294 = (($293>>>0) / 255)&-1;
     $295 = $290 << 16;
     $296 = $292 << 8;
     $297 = $296 | $294;
     $298 = $297 | $295;
     HEAP32[$$3528>>2] = $298;
     $299 = ((($$3528)) + 4|0);
     $$3533 = $$2532;$$4529 = $299;
     label = 26;
     continue;
    }
    else if ((label|0) == 26) {
     label = 0;
     $300 = HEAP32[$$4529>>2]|0;
     $301 = $300 >>> 16;
     $302 = $301 & 255;
     $303 = $300 >>> 8;
     $304 = $303 & 255;
     $305 = $300 & 255;
     $306 = Math_imul($302, $245)|0;
     $307 = (($306>>>0) / 255)&-1;
     $308 = Math_imul($304, $246)|0;
     $309 = (($308>>>0) / 255)&-1;
     $310 = Math_imul($305, $247)|0;
     $311 = (($310>>>0) / 255)&-1;
     $312 = $307 << 16;
     $313 = $309 << 8;
     $314 = $313 | $311;
     $315 = $314 | $312;
     HEAP32[$$4529>>2] = $315;
     $316 = ((($$4529)) + 4|0);
     $317 = (($$3533) + -1)|0;
     $318 = ($$3533|0)>(1);
     if ($318) {
      $$0530 = $317;$$1526 = $316;
      label = 23;
      continue;
     } else {
      break;
     }
    }
   }
   $319 = (($316) + ($233<<2)|0);
   $320 = ($248|0)==(0);
   if ($320) {
    label = 46;
    break;
   } else {
    $$0525580 = $319;$$in = $248;
   }
  }
  if ((label|0) == 27) {
   // unreachable;
  }
  else if ((label|0) == 46) {
   return 0;
  }
  break;
 }
 default: {
  $321 = ((($1)) + 8|0);
  $322 = HEAP32[$321>>2]|0;
  $323 = ((($1)) + 12|0);
  $324 = HEAP32[$323>>2]|0;
  $325 = ((($0)) + 16|0);
  $326 = HEAP32[$325>>2]|0;
  $327 = ((($0)) + 4|0);
  $328 = HEAP32[$327>>2]|0;
  $329 = ((($328)) + 9|0);
  $330 = HEAP8[$329>>0]|0;
  $331 = $330&255;
  $332 = (($326|0) / ($331|0))&-1;
  $333 = (($332) - ($322))|0;
  $334 = ((($0)) + 20|0);
  $335 = HEAP32[$334>>2]|0;
  $336 = ((($1)) + 4|0);
  $337 = HEAP32[$336>>2]|0;
  $338 = Math_imul($337, $332)|0;
  $339 = (($335) + ($338<<2)|0);
  $340 = HEAP32[$1>>2]|0;
  $341 = (($339) + ($340<<2)|0);
  $342 = (($324) + -1)|0;
  $343 = ($324|0)==(0);
  if ($343) {
   return 0;
  }
  $344 = (($322) + 3)|0;
  $345 = (($344|0) / 4)&-1;
  $trunc546 = $322&255;
  $346 = $3&255;
  $347 = $4&255;
  $348 = $5&255;
  $349 = $346 << 16;
  $350 = $347 << 8;
  $351 = $350 | $349;
  $352 = $351 | $348;
  $trunc546$clear = $trunc546 & 3;
  switch ($trunc546$clear<<24>>24) {
  case 0:  {
   $$0535550$us = $341;$364 = $342;
   while(1) {
    $$0540$us = $345;$$1536$us = $$0535550$us;
    while(1) {
     HEAP32[$$1536$us>>2] = $352;
     $356 = ((($$1536$us)) + 4|0);
     HEAP32[$356>>2] = $352;
     $357 = ((($$1536$us)) + 8|0);
     HEAP32[$357>>2] = $352;
     $358 = ((($$1536$us)) + 12|0);
     HEAP32[$358>>2] = $352;
     $359 = ((($$1536$us)) + 16|0);
     $360 = (($$0540$us) + -1)|0;
     $361 = ($$0540$us|0)>(1);
     if ($361) {
      $$0540$us = $360;$$1536$us = $359;
     } else {
      break;
     }
    }
    $362 = (($359) + ($333<<2)|0);
    $363 = (($364) + -1)|0;
    $365 = ($364|0)==(0);
    if ($365) {
     break;
    } else {
     $$0535550$us = $362;$364 = $363;
    }
   }
   return 0;
   break;
  }
  case 3:  {
   $354 = ($344|0)>(7);
   $$0535550$us551 = $341;$378 = $342;
   while(1) {
    HEAP32[$$0535550$us551>>2] = $352;
    $366 = ((($$0535550$us551)) + 4|0);
    HEAP32[$366>>2] = $352;
    $367 = ((($$0535550$us551)) + 8|0);
    HEAP32[$367>>2] = $352;
    $368 = ((($$0535550$us551)) + 12|0);
    if ($354) {
     $$1541$us554616 = $345;$$2537$us555617 = $$0535550$us551;$370 = $368;
     while(1) {
      $369 = (($$1541$us554616) + -1)|0;
      HEAP32[$370>>2] = $352;
      $371 = ((($$2537$us555617)) + 16|0);
      HEAP32[$371>>2] = $352;
      $372 = ((($$2537$us555617)) + 20|0);
      HEAP32[$372>>2] = $352;
      $373 = ((($$2537$us555617)) + 24|0);
      HEAP32[$373>>2] = $352;
      $374 = ((($$2537$us555617)) + 28|0);
      $375 = ($369|0)>(1);
      if ($375) {
       $$1541$us554616 = $369;$$2537$us555617 = $371;$370 = $374;
      } else {
       $$lcssa611 = $374;
       break;
      }
     }
    } else {
     $$lcssa611 = $368;
    }
    $376 = (($$lcssa611) + ($333<<2)|0);
    $377 = (($378) + -1)|0;
    $379 = ($378|0)==(0);
    if ($379) {
     break;
    } else {
     $$0535550$us551 = $376;$378 = $377;
    }
   }
   return 0;
   break;
  }
  case 2:  {
   $353 = ($344|0)>(7);
   $$0535550$us562 = $341;$391 = $342;
   while(1) {
    HEAP32[$$0535550$us562>>2] = $352;
    $380 = ((($$0535550$us562)) + 4|0);
    HEAP32[$380>>2] = $352;
    $381 = ((($$0535550$us562)) + 8|0);
    if ($353) {
     $$2542$us567621 = $345;$$3538$us568622 = $$0535550$us562;$383 = $381;
     while(1) {
      $382 = (($$2542$us567621) + -1)|0;
      HEAP32[$383>>2] = $352;
      $384 = ((($$3538$us568622)) + 12|0);
      HEAP32[$384>>2] = $352;
      $385 = ((($$3538$us568622)) + 16|0);
      HEAP32[$385>>2] = $352;
      $386 = ((($$3538$us568622)) + 20|0);
      HEAP32[$386>>2] = $352;
      $387 = ((($$3538$us568622)) + 24|0);
      $388 = ($382|0)>(1);
      if ($388) {
       $$2542$us567621 = $382;$$3538$us568622 = $385;$383 = $387;
      } else {
       $$lcssa612 = $387;
       break;
      }
     }
    } else {
     $$lcssa612 = $381;
    }
    $389 = (($$lcssa612) + ($333<<2)|0);
    $390 = (($391) + -1)|0;
    $392 = ($391|0)==(0);
    if ($392) {
     break;
    } else {
     $$0535550$us562 = $389;$391 = $390;
    }
   }
   return 0;
   break;
  }
  default: {
   $355 = ($344|0)>(7);
   $$0535550 = $341;$403 = $342;
   while(1) {
    HEAP32[$$0535550>>2] = $352;
    $393 = ((($$0535550)) + 4|0);
    if ($355) {
     $$3543613 = $345;$$4539614 = $$0535550;$395 = $393;
     while(1) {
      $394 = (($$3543613) + -1)|0;
      HEAP32[$395>>2] = $352;
      $396 = ((($$4539614)) + 8|0);
      HEAP32[$396>>2] = $352;
      $397 = ((($$4539614)) + 12|0);
      HEAP32[$397>>2] = $352;
      $398 = ((($$4539614)) + 16|0);
      HEAP32[$398>>2] = $352;
      $399 = ((($$4539614)) + 20|0);
      $400 = ($394|0)>(1);
      if ($400) {
       $$3543613 = $394;$$4539614 = $398;$395 = $399;
      } else {
       $$lcssa = $399;
       break;
      }
     }
    } else {
     $$lcssa = $393;
    }
    $401 = (($$lcssa) + ($333<<2)|0);
    $402 = (($403) + -1)|0;
    $404 = ($403|0)==(0);
    if ($404) {
     break;
    } else {
     $$0535550 = $401;$403 = $402;
    }
   }
   return 0;
  }
  }
 }
 }
 return (0)|0;
}
function _SDL_BlendFillRect_ARGB8888($0,$1,$2,$3,$4,$5,$6) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 var $$ = 0, $$0533642 = 0, $$0538 = 0, $$0543647 = 0, $$0548 = 0, $$0573652 = 0, $$0578 = 0, $$0597$us = 0, $$0601618 = 0, $$0601618$us = 0, $$0601618$us619 = 0, $$0601618$us630 = 0, $$1 = 0, $$10 = 0, $$11 = 0, $$1534 = 0, $$1539 = 0, $$1544 = 0, $$1549 = 0, $$1574 = 0;
 var $$1579 = 0, $$1598$us623689 = 0, $$1602$us = 0, $$2 = 0, $$2535 = 0, $$2540 = 0, $$2545 = 0, $$2550 = 0, $$2575 = 0, $$2580 = 0, $$2599$us636694 = 0, $$2603$us622688 = 0, $$3 = 0, $$3536 = 0, $$3541 = 0, $$3546 = 0, $$3551 = 0, $$3576 = 0, $$3581 = 0, $$3600686 = 0;
 var $$3604$us635693 = 0, $$4 = 0, $$4537 = 0, $$4547 = 0, $$4577 = 0, $$4605685 = 0, $$5 = 0, $$6 = 0, $$7 = 0, $$8 = 0, $$9 = 0, $$in = 0, $$in656 = 0, $$in657 = 0, $$lcssa = 0, $$lcssa683 = 0, $$lcssa684 = 0, $10 = 0, $100 = 0, $101 = 0;
 var $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0;
 var $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0;
 var $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0;
 var $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0;
 var $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0;
 var $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0;
 var $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0;
 var $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0;
 var $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0;
 var $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0;
 var $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $30 = 0, $300 = 0, $301 = 0;
 var $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0;
 var $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0;
 var $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0;
 var $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0;
 var $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0;
 var $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0;
 var $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0;
 var $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $trunc = 0, $trunc$clear = 0, $trunc612 = 0;
 var $trunc612$clear = 0, $trunc613 = 0, $trunc613$clear = 0, $trunc614 = 0, $trunc614$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $7 = $6&255;
 $8 = $7 ^ 255;
 switch ($2|0) {
 case 1:  {
  $9 = ((($1)) + 8|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ((($1)) + 12|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ((($0)) + 16|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = ((($0)) + 4|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ((($16)) + 9|0);
  $18 = HEAP8[$17>>0]|0;
  $19 = $18&255;
  $20 = (($14|0) / ($19|0))&-1;
  $21 = (($20) - ($10))|0;
  $22 = ($12|0)==(0);
  if ($22) {
   return 0;
  }
  $23 = ((($0)) + 20|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = ((($1)) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = Math_imul($26, $20)|0;
  $28 = (($24) + ($27<<2)|0);
  $29 = HEAP32[$1>>2]|0;
  $30 = (($28) + ($29<<2)|0);
  $31 = (($10) + 3)|0;
  $32 = (($31|0) / 4)&-1;
  $trunc613 = $10&255;
  $33 = $3&255;
  $34 = $4&255;
  $35 = $5&255;
  $$0533642 = $30;$$in657 = $12;
  L41: while(1) {
   $36 = (($$in657) + -1)|0;
   $trunc613$clear = $trunc613 & 3;
   switch ($trunc613$clear<<24>>24) {
   case 0:  {
    $$0538 = $32;$$1534 = $$0533642;
    label = 5;
    break;
   }
   case 3:  {
    $$1539 = $32;$$2535 = $$0533642;
    label = 6;
    break;
   }
   case 2:  {
    $$2540 = $32;$$3536 = $$0533642;
    label = 7;
    break;
   }
   case 1:  {
    $$3541 = $32;$$4537 = $$0533642;
    label = 8;
    break;
   }
   default: {
    label = 9;
    break L41;
   }
   }
   while(1) {
    if ((label|0) == 5) {
     label = 0;
     $37 = HEAP32[$$1534>>2]|0;
     $38 = $37 >>> 16;
     $39 = $38 & 255;
     $40 = $37 >>> 8;
     $41 = $40 & 255;
     $42 = $37 & 255;
     $43 = $37 >>> 24;
     $44 = Math_imul($39, $8)|0;
     $45 = (($44>>>0) / 255)&-1;
     $46 = (($45) + ($33))|0;
     $47 = Math_imul($41, $8)|0;
     $48 = (($47>>>0) / 255)&-1;
     $49 = (($48) + ($34))|0;
     $50 = Math_imul($42, $8)|0;
     $51 = (($50>>>0) / 255)&-1;
     $52 = (($51) + ($35))|0;
     $53 = Math_imul($43, $8)|0;
     $54 = (($53>>>0) / 255)&-1;
     $55 = (($54) + ($7))|0;
     $56 = $55 << 24;
     $57 = $46 << 16;
     $58 = $49 << 8;
     $59 = $56 | $52;
     $60 = $59 | $57;
     $61 = $60 | $58;
     HEAP32[$$1534>>2] = $61;
     $62 = ((($$1534)) + 4|0);
     $$1539 = $$0538;$$2535 = $62;
     label = 6;
     continue;
    }
    else if ((label|0) == 6) {
     label = 0;
     $63 = HEAP32[$$2535>>2]|0;
     $64 = $63 >>> 16;
     $65 = $64 & 255;
     $66 = $63 >>> 8;
     $67 = $66 & 255;
     $68 = $63 & 255;
     $69 = $63 >>> 24;
     $70 = Math_imul($65, $8)|0;
     $71 = (($70>>>0) / 255)&-1;
     $72 = (($71) + ($33))|0;
     $73 = Math_imul($67, $8)|0;
     $74 = (($73>>>0) / 255)&-1;
     $75 = (($74) + ($34))|0;
     $76 = Math_imul($68, $8)|0;
     $77 = (($76>>>0) / 255)&-1;
     $78 = (($77) + ($35))|0;
     $79 = Math_imul($69, $8)|0;
     $80 = (($79>>>0) / 255)&-1;
     $81 = (($80) + ($7))|0;
     $82 = $81 << 24;
     $83 = $72 << 16;
     $84 = $75 << 8;
     $85 = $82 | $78;
     $86 = $85 | $83;
     $87 = $86 | $84;
     HEAP32[$$2535>>2] = $87;
     $88 = ((($$2535)) + 4|0);
     $$2540 = $$1539;$$3536 = $88;
     label = 7;
     continue;
    }
    else if ((label|0) == 7) {
     label = 0;
     $89 = HEAP32[$$3536>>2]|0;
     $90 = $89 >>> 16;
     $91 = $90 & 255;
     $92 = $89 >>> 8;
     $93 = $92 & 255;
     $94 = $89 & 255;
     $95 = $89 >>> 24;
     $96 = Math_imul($91, $8)|0;
     $97 = (($96>>>0) / 255)&-1;
     $98 = (($97) + ($33))|0;
     $99 = Math_imul($93, $8)|0;
     $100 = (($99>>>0) / 255)&-1;
     $101 = (($100) + ($34))|0;
     $102 = Math_imul($94, $8)|0;
     $103 = (($102>>>0) / 255)&-1;
     $104 = (($103) + ($35))|0;
     $105 = Math_imul($95, $8)|0;
     $106 = (($105>>>0) / 255)&-1;
     $107 = (($106) + ($7))|0;
     $108 = $107 << 24;
     $109 = $98 << 16;
     $110 = $101 << 8;
     $111 = $108 | $104;
     $112 = $111 | $109;
     $113 = $112 | $110;
     HEAP32[$$3536>>2] = $113;
     $114 = ((($$3536)) + 4|0);
     $$3541 = $$2540;$$4537 = $114;
     label = 8;
     continue;
    }
    else if ((label|0) == 8) {
     label = 0;
     $115 = HEAP32[$$4537>>2]|0;
     $116 = $115 >>> 16;
     $117 = $116 & 255;
     $118 = $115 >>> 8;
     $119 = $118 & 255;
     $120 = $115 & 255;
     $121 = $115 >>> 24;
     $122 = Math_imul($117, $8)|0;
     $123 = (($122>>>0) / 255)&-1;
     $124 = (($123) + ($33))|0;
     $125 = Math_imul($119, $8)|0;
     $126 = (($125>>>0) / 255)&-1;
     $127 = (($126) + ($34))|0;
     $128 = Math_imul($120, $8)|0;
     $129 = (($128>>>0) / 255)&-1;
     $130 = (($129) + ($35))|0;
     $131 = Math_imul($121, $8)|0;
     $132 = (($131>>>0) / 255)&-1;
     $133 = (($132) + ($7))|0;
     $134 = $133 << 24;
     $135 = $124 << 16;
     $136 = $127 << 8;
     $137 = $134 | $130;
     $138 = $137 | $135;
     $139 = $138 | $136;
     HEAP32[$$4537>>2] = $139;
     $140 = ((($$4537)) + 4|0);
     $141 = (($$3541) + -1)|0;
     $142 = ($$3541|0)>(1);
     if ($142) {
      $$0538 = $141;$$1534 = $140;
      label = 5;
      continue;
     } else {
      break;
     }
    }
   }
   $143 = (($140) + ($21<<2)|0);
   $144 = ($36|0)==(0);
   if ($144) {
    label = 46;
    break;
   } else {
    $$0533642 = $143;$$in657 = $36;
   }
  }
  if ((label|0) == 9) {
   // unreachable;
  }
  else if ((label|0) == 46) {
   return 0;
  }
  break;
 }
 case 2:  {
  $145 = ((($1)) + 8|0);
  $146 = HEAP32[$145>>2]|0;
  $147 = ((($1)) + 12|0);
  $148 = HEAP32[$147>>2]|0;
  $149 = ((($0)) + 16|0);
  $150 = HEAP32[$149>>2]|0;
  $151 = ((($0)) + 4|0);
  $152 = HEAP32[$151>>2]|0;
  $153 = ((($152)) + 9|0);
  $154 = HEAP8[$153>>0]|0;
  $155 = $154&255;
  $156 = (($150|0) / ($155|0))&-1;
  $157 = (($156) - ($146))|0;
  $158 = ($148|0)==(0);
  if ($158) {
   return 0;
  }
  $159 = ((($0)) + 20|0);
  $160 = HEAP32[$159>>2]|0;
  $161 = ((($1)) + 4|0);
  $162 = HEAP32[$161>>2]|0;
  $163 = Math_imul($162, $156)|0;
  $164 = (($160) + ($163<<2)|0);
  $165 = HEAP32[$1>>2]|0;
  $166 = (($164) + ($165<<2)|0);
  $167 = (($146) + 3)|0;
  $168 = (($167|0) / 4)&-1;
  $trunc612 = $146&255;
  $169 = $3&255;
  $170 = $4&255;
  $171 = $5&255;
  $$0543647 = $166;$$in656 = $148;
  L57: while(1) {
   $172 = (($$in656) + -1)|0;
   $trunc612$clear = $trunc612 & 3;
   switch ($trunc612$clear<<24>>24) {
   case 0:  {
    $$0548 = $168;$$1544 = $$0543647;
    label = 14;
    break;
   }
   case 3:  {
    $$1549 = $168;$$2545 = $$0543647;
    label = 15;
    break;
   }
   case 2:  {
    $$2550 = $168;$$3546 = $$0543647;
    label = 16;
    break;
   }
   case 1:  {
    $$3551 = $168;$$4547 = $$0543647;
    label = 17;
    break;
   }
   default: {
    label = 18;
    break L57;
   }
   }
   while(1) {
    if ((label|0) == 14) {
     label = 0;
     $173 = HEAP32[$$1544>>2]|0;
     $174 = $173 >>> 16;
     $175 = $174 & 255;
     $176 = $173 >>> 8;
     $177 = $176 & 255;
     $178 = $173 & 255;
     $179 = $173 & -16777216;
     $180 = (($175) + ($169))|0;
     $181 = ($180>>>0)<(255);
     $$7 = $181 ? $180 : 255;
     $182 = (($177) + ($170))|0;
     $183 = ($182>>>0)<(255);
     $$ = $183 ? $182 : 255;
     $184 = (($178) + ($171))|0;
     $185 = ($184>>>0)<(255);
     $$11 = $185 ? $184 : 255;
     $186 = $$7 << 16;
     $187 = $$ << 8;
     $188 = $$11 | $179;
     $189 = $188 | $186;
     $190 = $189 | $187;
     HEAP32[$$1544>>2] = $190;
     $191 = ((($$1544)) + 4|0);
     $$1549 = $$0548;$$2545 = $191;
     label = 15;
     continue;
    }
    else if ((label|0) == 15) {
     label = 0;
     $192 = HEAP32[$$2545>>2]|0;
     $193 = $192 >>> 16;
     $194 = $193 & 255;
     $195 = $192 >>> 8;
     $196 = $195 & 255;
     $197 = $192 & 255;
     $198 = $192 & -16777216;
     $199 = (($194) + ($169))|0;
     $200 = ($199>>>0)<(255);
     $$1 = $200 ? $199 : 255;
     $201 = (($196) + ($170))|0;
     $202 = ($201>>>0)<(255);
     $$8 = $202 ? $201 : 255;
     $203 = (($197) + ($171))|0;
     $204 = ($203>>>0)<(255);
     $$2 = $204 ? $203 : 255;
     $205 = $$1 << 16;
     $206 = $$8 << 8;
     $207 = $$2 | $198;
     $208 = $207 | $205;
     $209 = $208 | $206;
     HEAP32[$$2545>>2] = $209;
     $210 = ((($$2545)) + 4|0);
     $$2550 = $$1549;$$3546 = $210;
     label = 16;
     continue;
    }
    else if ((label|0) == 16) {
     label = 0;
     $211 = HEAP32[$$3546>>2]|0;
     $212 = $211 >>> 16;
     $213 = $212 & 255;
     $214 = $211 >>> 8;
     $215 = $214 & 255;
     $216 = $211 & 255;
     $217 = $211 & -16777216;
     $218 = (($213) + ($169))|0;
     $219 = ($218>>>0)<(255);
     $$3 = $219 ? $218 : 255;
     $220 = (($215) + ($170))|0;
     $221 = ($220>>>0)<(255);
     $$9 = $221 ? $220 : 255;
     $222 = (($216) + ($171))|0;
     $223 = ($222>>>0)<(255);
     $$4 = $223 ? $222 : 255;
     $224 = $$3 << 16;
     $225 = $$9 << 8;
     $226 = $$4 | $217;
     $227 = $226 | $224;
     $228 = $227 | $225;
     HEAP32[$$3546>>2] = $228;
     $229 = ((($$3546)) + 4|0);
     $$3551 = $$2550;$$4547 = $229;
     label = 17;
     continue;
    }
    else if ((label|0) == 17) {
     label = 0;
     $230 = HEAP32[$$4547>>2]|0;
     $231 = $230 >>> 16;
     $232 = $231 & 255;
     $233 = $230 >>> 8;
     $234 = $233 & 255;
     $235 = $230 & 255;
     $236 = $230 & -16777216;
     $237 = (($232) + ($169))|0;
     $238 = ($237>>>0)<(255);
     $$5 = $238 ? $237 : 255;
     $239 = (($234) + ($170))|0;
     $240 = ($239>>>0)<(255);
     $$10 = $240 ? $239 : 255;
     $241 = (($235) + ($171))|0;
     $242 = ($241>>>0)<(255);
     $$6 = $242 ? $241 : 255;
     $243 = $$5 << 16;
     $244 = $$10 << 8;
     $245 = $$6 | $236;
     $246 = $245 | $243;
     $247 = $246 | $244;
     HEAP32[$$4547>>2] = $247;
     $248 = ((($$4547)) + 4|0);
     $249 = (($$3551) + -1)|0;
     $250 = ($$3551|0)>(1);
     if ($250) {
      $$0548 = $249;$$1544 = $248;
      label = 14;
      continue;
     } else {
      break;
     }
    }
   }
   $251 = (($248) + ($157<<2)|0);
   $252 = ($172|0)==(0);
   if ($252) {
    label = 46;
    break;
   } else {
    $$0543647 = $251;$$in656 = $172;
   }
  }
  if ((label|0) == 18) {
   // unreachable;
  }
  else if ((label|0) == 46) {
   return 0;
  }
  break;
 }
 case 4:  {
  $253 = ((($1)) + 8|0);
  $254 = HEAP32[$253>>2]|0;
  $255 = ((($1)) + 12|0);
  $256 = HEAP32[$255>>2]|0;
  $257 = ((($0)) + 16|0);
  $258 = HEAP32[$257>>2]|0;
  $259 = ((($0)) + 4|0);
  $260 = HEAP32[$259>>2]|0;
  $261 = ((($260)) + 9|0);
  $262 = HEAP8[$261>>0]|0;
  $263 = $262&255;
  $264 = (($258|0) / ($263|0))&-1;
  $265 = (($264) - ($254))|0;
  $266 = ($256|0)==(0);
  if ($266) {
   return 0;
  }
  $267 = ((($0)) + 20|0);
  $268 = HEAP32[$267>>2]|0;
  $269 = ((($1)) + 4|0);
  $270 = HEAP32[$269>>2]|0;
  $271 = Math_imul($270, $264)|0;
  $272 = (($268) + ($271<<2)|0);
  $273 = HEAP32[$1>>2]|0;
  $274 = (($272) + ($273<<2)|0);
  $275 = (($254) + 3)|0;
  $276 = (($275|0) / 4)&-1;
  $trunc = $254&255;
  $277 = $3&255;
  $278 = $4&255;
  $279 = $5&255;
  $$0573652 = $274;$$in = $256;
  L73: while(1) {
   $280 = (($$in) + -1)|0;
   $trunc$clear = $trunc & 3;
   switch ($trunc$clear<<24>>24) {
   case 0:  {
    $$0578 = $276;$$1574 = $$0573652;
    label = 23;
    break;
   }
   case 3:  {
    $$1579 = $276;$$2575 = $$0573652;
    label = 24;
    break;
   }
   case 2:  {
    $$2580 = $276;$$3576 = $$0573652;
    label = 25;
    break;
   }
   case 1:  {
    $$3581 = $276;$$4577 = $$0573652;
    label = 26;
    break;
   }
   default: {
    label = 27;
    break L73;
   }
   }
   while(1) {
    if ((label|0) == 23) {
     label = 0;
     $281 = HEAP32[$$1574>>2]|0;
     $282 = $281 >>> 16;
     $283 = $282 & 255;
     $284 = $281 >>> 8;
     $285 = $284 & 255;
     $286 = $281 & 255;
     $287 = $281 & -16777216;
     $288 = Math_imul($283, $277)|0;
     $289 = (($288>>>0) / 255)&-1;
     $290 = Math_imul($285, $278)|0;
     $291 = (($290>>>0) / 255)&-1;
     $292 = Math_imul($286, $279)|0;
     $293 = (($292>>>0) / 255)&-1;
     $294 = $289 << 16;
     $295 = $291 << 8;
     $296 = $293 | $287;
     $297 = $296 | $294;
     $298 = $297 | $295;
     HEAP32[$$1574>>2] = $298;
     $299 = ((($$1574)) + 4|0);
     $$1579 = $$0578;$$2575 = $299;
     label = 24;
     continue;
    }
    else if ((label|0) == 24) {
     label = 0;
     $300 = HEAP32[$$2575>>2]|0;
     $301 = $300 >>> 16;
     $302 = $301 & 255;
     $303 = $300 >>> 8;
     $304 = $303 & 255;
     $305 = $300 & 255;
     $306 = $300 & -16777216;
     $307 = Math_imul($302, $277)|0;
     $308 = (($307>>>0) / 255)&-1;
     $309 = Math_imul($304, $278)|0;
     $310 = (($309>>>0) / 255)&-1;
     $311 = Math_imul($305, $279)|0;
     $312 = (($311>>>0) / 255)&-1;
     $313 = $308 << 16;
     $314 = $310 << 8;
     $315 = $312 | $306;
     $316 = $315 | $313;
     $317 = $316 | $314;
     HEAP32[$$2575>>2] = $317;
     $318 = ((($$2575)) + 4|0);
     $$2580 = $$1579;$$3576 = $318;
     label = 25;
     continue;
    }
    else if ((label|0) == 25) {
     label = 0;
     $319 = HEAP32[$$3576>>2]|0;
     $320 = $319 >>> 16;
     $321 = $320 & 255;
     $322 = $319 >>> 8;
     $323 = $322 & 255;
     $324 = $319 & 255;
     $325 = $319 & -16777216;
     $326 = Math_imul($321, $277)|0;
     $327 = (($326>>>0) / 255)&-1;
     $328 = Math_imul($323, $278)|0;
     $329 = (($328>>>0) / 255)&-1;
     $330 = Math_imul($324, $279)|0;
     $331 = (($330>>>0) / 255)&-1;
     $332 = $327 << 16;
     $333 = $329 << 8;
     $334 = $331 | $325;
     $335 = $334 | $332;
     $336 = $335 | $333;
     HEAP32[$$3576>>2] = $336;
     $337 = ((($$3576)) + 4|0);
     $$3581 = $$2580;$$4577 = $337;
     label = 26;
     continue;
    }
    else if ((label|0) == 26) {
     label = 0;
     $338 = HEAP32[$$4577>>2]|0;
     $339 = $338 >>> 16;
     $340 = $339 & 255;
     $341 = $338 >>> 8;
     $342 = $341 & 255;
     $343 = $338 & 255;
     $344 = $338 & -16777216;
     $345 = Math_imul($340, $277)|0;
     $346 = (($345>>>0) / 255)&-1;
     $347 = Math_imul($342, $278)|0;
     $348 = (($347>>>0) / 255)&-1;
     $349 = Math_imul($343, $279)|0;
     $350 = (($349>>>0) / 255)&-1;
     $351 = $346 << 16;
     $352 = $348 << 8;
     $353 = $350 | $344;
     $354 = $353 | $351;
     $355 = $354 | $352;
     HEAP32[$$4577>>2] = $355;
     $356 = ((($$4577)) + 4|0);
     $357 = (($$3581) + -1)|0;
     $358 = ($$3581|0)>(1);
     if ($358) {
      $$0578 = $357;$$1574 = $356;
      label = 23;
      continue;
     } else {
      break;
     }
    }
   }
   $359 = (($356) + ($265<<2)|0);
   $360 = ($280|0)==(0);
   if ($360) {
    label = 46;
    break;
   } else {
    $$0573652 = $359;$$in = $280;
   }
  }
  if ((label|0) == 27) {
   // unreachable;
  }
  else if ((label|0) == 46) {
   return 0;
  }
  break;
 }
 default: {
  $361 = ((($1)) + 8|0);
  $362 = HEAP32[$361>>2]|0;
  $363 = ((($1)) + 12|0);
  $364 = HEAP32[$363>>2]|0;
  $365 = ((($0)) + 16|0);
  $366 = HEAP32[$365>>2]|0;
  $367 = ((($0)) + 4|0);
  $368 = HEAP32[$367>>2]|0;
  $369 = ((($368)) + 9|0);
  $370 = HEAP8[$369>>0]|0;
  $371 = $370&255;
  $372 = (($366|0) / ($371|0))&-1;
  $373 = (($372) - ($362))|0;
  $374 = ((($0)) + 20|0);
  $375 = HEAP32[$374>>2]|0;
  $376 = ((($1)) + 4|0);
  $377 = HEAP32[$376>>2]|0;
  $378 = Math_imul($377, $372)|0;
  $379 = (($375) + ($378<<2)|0);
  $380 = HEAP32[$1>>2]|0;
  $381 = (($379) + ($380<<2)|0);
  $382 = (($364) + -1)|0;
  $383 = ($364|0)==(0);
  if ($383) {
   return 0;
  }
  $384 = (($362) + 3)|0;
  $385 = (($384|0) / 4)&-1;
  $trunc614 = $362&255;
  $386 = $3&255;
  $387 = $4&255;
  $388 = $5&255;
  $389 = $7 << 24;
  $390 = $386 << 16;
  $391 = $387 << 8;
  $392 = $391 | $390;
  $393 = $392 | $388;
  $394 = $393 | $389;
  $trunc614$clear = $trunc614 & 3;
  switch ($trunc614$clear<<24>>24) {
  case 0:  {
   $$0601618$us = $381;$406 = $382;
   while(1) {
    $$0597$us = $385;$$1602$us = $$0601618$us;
    while(1) {
     HEAP32[$$1602$us>>2] = $394;
     $398 = ((($$1602$us)) + 4|0);
     HEAP32[$398>>2] = $394;
     $399 = ((($$1602$us)) + 8|0);
     HEAP32[$399>>2] = $394;
     $400 = ((($$1602$us)) + 12|0);
     HEAP32[$400>>2] = $394;
     $401 = ((($$1602$us)) + 16|0);
     $402 = (($$0597$us) + -1)|0;
     $403 = ($$0597$us|0)>(1);
     if ($403) {
      $$0597$us = $402;$$1602$us = $401;
     } else {
      break;
     }
    }
    $404 = (($401) + ($373<<2)|0);
    $405 = (($406) + -1)|0;
    $407 = ($406|0)==(0);
    if ($407) {
     break;
    } else {
     $$0601618$us = $404;$406 = $405;
    }
   }
   return 0;
   break;
  }
  case 3:  {
   $396 = ($384|0)>(7);
   $$0601618$us619 = $381;$420 = $382;
   while(1) {
    HEAP32[$$0601618$us619>>2] = $394;
    $408 = ((($$0601618$us619)) + 4|0);
    HEAP32[$408>>2] = $394;
    $409 = ((($$0601618$us619)) + 8|0);
    HEAP32[$409>>2] = $394;
    $410 = ((($$0601618$us619)) + 12|0);
    if ($396) {
     $$1598$us623689 = $385;$$2603$us622688 = $$0601618$us619;$412 = $410;
     while(1) {
      $411 = (($$1598$us623689) + -1)|0;
      HEAP32[$412>>2] = $394;
      $413 = ((($$2603$us622688)) + 16|0);
      HEAP32[$413>>2] = $394;
      $414 = ((($$2603$us622688)) + 20|0);
      HEAP32[$414>>2] = $394;
      $415 = ((($$2603$us622688)) + 24|0);
      HEAP32[$415>>2] = $394;
      $416 = ((($$2603$us622688)) + 28|0);
      $417 = ($411|0)>(1);
      if ($417) {
       $$1598$us623689 = $411;$$2603$us622688 = $413;$412 = $416;
      } else {
       $$lcssa683 = $416;
       break;
      }
     }
    } else {
     $$lcssa683 = $410;
    }
    $418 = (($$lcssa683) + ($373<<2)|0);
    $419 = (($420) + -1)|0;
    $421 = ($420|0)==(0);
    if ($421) {
     break;
    } else {
     $$0601618$us619 = $418;$420 = $419;
    }
   }
   return 0;
   break;
  }
  case 2:  {
   $395 = ($384|0)>(7);
   $$0601618$us630 = $381;$433 = $382;
   while(1) {
    HEAP32[$$0601618$us630>>2] = $394;
    $422 = ((($$0601618$us630)) + 4|0);
    HEAP32[$422>>2] = $394;
    $423 = ((($$0601618$us630)) + 8|0);
    if ($395) {
     $$2599$us636694 = $385;$$3604$us635693 = $$0601618$us630;$425 = $423;
     while(1) {
      $424 = (($$2599$us636694) + -1)|0;
      HEAP32[$425>>2] = $394;
      $426 = ((($$3604$us635693)) + 12|0);
      HEAP32[$426>>2] = $394;
      $427 = ((($$3604$us635693)) + 16|0);
      HEAP32[$427>>2] = $394;
      $428 = ((($$3604$us635693)) + 20|0);
      HEAP32[$428>>2] = $394;
      $429 = ((($$3604$us635693)) + 24|0);
      $430 = ($424|0)>(1);
      if ($430) {
       $$2599$us636694 = $424;$$3604$us635693 = $427;$425 = $429;
      } else {
       $$lcssa684 = $429;
       break;
      }
     }
    } else {
     $$lcssa684 = $423;
    }
    $431 = (($$lcssa684) + ($373<<2)|0);
    $432 = (($433) + -1)|0;
    $434 = ($433|0)==(0);
    if ($434) {
     break;
    } else {
     $$0601618$us630 = $431;$433 = $432;
    }
   }
   return 0;
   break;
  }
  default: {
   $397 = ($384|0)>(7);
   $$0601618 = $381;$445 = $382;
   while(1) {
    HEAP32[$$0601618>>2] = $394;
    $435 = ((($$0601618)) + 4|0);
    if ($397) {
     $$3600686 = $385;$$4605685 = $$0601618;$437 = $435;
     while(1) {
      $436 = (($$3600686) + -1)|0;
      HEAP32[$437>>2] = $394;
      $438 = ((($$4605685)) + 8|0);
      HEAP32[$438>>2] = $394;
      $439 = ((($$4605685)) + 12|0);
      HEAP32[$439>>2] = $394;
      $440 = ((($$4605685)) + 16|0);
      HEAP32[$440>>2] = $394;
      $441 = ((($$4605685)) + 20|0);
      $442 = ($436|0)>(1);
      if ($442) {
       $$3600686 = $436;$$4605685 = $440;$437 = $441;
      } else {
       $$lcssa = $441;
       break;
      }
     }
    } else {
     $$lcssa = $435;
    }
    $443 = (($$lcssa) + ($373<<2)|0);
    $444 = (($445) + -1)|0;
    $446 = ($445|0)==(0);
    if ($446) {
     break;
    } else {
     $$0601618 = $443;$445 = $444;
    }
   }
   return 0;
  }
  }
 }
 }
 return (0)|0;
}
function _SDL_BlendFillRect_RGB($0,$1,$2,$3,$4,$5,$6) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 var $$ = 0, $$0 = 0, $$014561550 = 0, $$01461 = 0, $$014661552 = 0, $$01471 = 0, $$014761554 = 0, $$01481 = 0, $$014861549 = 0, $$01491 = 0, $$014961558 = 0, $$01501 = 0, $$015051556 = 0, $$01510 = 0, $$015161560 = 0, $$01521 = 0, $$015261562 = 0, $$01531 = 0, $$1 = 0, $$10 = 0;
 var $$11 = 0, $$11457 = 0, $$11462 = 0, $$11467 = 0, $$11472 = 0, $$11477 = 0, $$11482 = 0, $$11487 = 0, $$11492 = 0, $$11497 = 0, $$11502 = 0, $$11506 = 0, $$11511 = 0, $$11517 = 0, $$11522 = 0, $$11527 = 0, $$11532 = 0, $$12 = 0, $$13 = 0, $$14 = 0;
 var $$15 = 0, $$16 = 0, $$17 = 0, $$18 = 0, $$19 = 0, $$2 = 0, $$20 = 0, $$21 = 0, $$21458 = 0, $$21463 = 0, $$21468 = 0, $$21473 = 0, $$21478 = 0, $$21483 = 0, $$21488 = 0, $$21493 = 0, $$21498 = 0, $$21503 = 0, $$21507 = 0, $$21512 = 0;
 var $$21518 = 0, $$21523 = 0, $$21528 = 0, $$21533 = 0, $$22 = 0, $$23 = 0, $$3 = 0, $$31459 = 0, $$31464 = 0, $$31469 = 0, $$31474 = 0, $$31479 = 0, $$31484 = 0, $$31489 = 0, $$31494 = 0, $$31499 = 0, $$31504 = 0, $$31508 = 0, $$31513 = 0, $$31519 = 0;
 var $$31524 = 0, $$31529 = 0, $$31534 = 0, $$4 = 0, $$41460 = 0, $$41470 = 0, $$41480 = 0, $$41490 = 0, $$41500 = 0, $$41509 = 0, $$41520 = 0, $$41530 = 0, $$5 = 0, $$6 = 0, $$7 = 0, $$8 = 0, $$9 = 0, $$in = 0, $$in1564 = 0, $$in1565 = 0;
 var $$in1566 = 0, $$in1567 = 0, $$in1568 = 0, $$in1569 = 0, $$in1570 = 0, $$phi$trans$insert = 0, $$phi$trans$insert1578 = 0, $$phi$trans$insert1582 = 0, $$phi$trans$insert1583 = 0, $$phi$trans$insert1587 = 0, $$phi$trans$insert1588 = 0, $$phi$trans$insert1593 = 0, $$phi$trans$insert1594 = 0, $$phi$trans$insert1598 = 0, $$phi$trans$insert1599 = 0, $$phi$trans$insert1603 = 0, $$phi$trans$insert1604 = 0, $$phi$trans$insert1609 = 0, $$phi$trans$insert1610 = 0, $$phi$trans$insert1614 = 0;
 var $$phi$trans$insert1615 = 0, $$phi$trans$insert1619 = 0, $$phi$trans$insert1620 = 0, $$phi$trans$insert1625 = 0, $$phi$trans$insert1626 = 0, $$phi$trans$insert1630 = 0, $$phi$trans$insert1631 = 0, $$phi$trans$insert1635 = 0, $$phi$trans$insert1636 = 0, $$phi$trans$insert1641 = 0, $$phi$trans$insert1642 = 0, $$phi$trans$insert1646 = 0, $$phi$trans$insert1647 = 0, $$phi$trans$insert1651 = 0, $$phi$trans$insert1652 = 0, $$phi$trans$insert1657 = 0, $$phi$trans$insert1658 = 0, $$phi$trans$insert1662 = 0, $$phi$trans$insert1663 = 0, $$phi$trans$insert1667 = 0;
 var $$phi$trans$insert1668 = 0, $$phi$trans$insert1673 = 0, $$phi$trans$insert1674 = 0, $$phi$trans$insert1678 = 0, $$phi$trans$insert1679 = 0, $$phi$trans$insert1683 = 0, $$phi$trans$insert1684 = 0, $$phi$trans$insert1689 = 0, $$phi$trans$insert1690 = 0, $$phi$trans$insert1694 = 0, $$phi$trans$insert1695 = 0, $$phi$trans$insert1699 = 0, $$phi$trans$insert1700 = 0, $$phi$trans$insert1705 = 0, $$phi$trans$insert1706 = 0, $$phi$trans$insert1710 = 0, $$phi$trans$insert1711 = 0, $$phi$trans$insert1715 = 0, $$phi$trans$insert1716 = 0, $$phi$trans$insert1721 = 0;
 var $$phi$trans$insert1722 = 0, $$phi$trans$insert1726 = 0, $$phi$trans$insert1727 = 0, $$phi$trans$insert1731 = 0, $$phi$trans$insert1732 = 0, $$phi$trans$insert1737 = 0, $$phi$trans$insert1738 = 0, $$phi$trans$insert1742 = 0, $$phi$trans$insert1743 = 0, $$phi$trans$insert1747 = 0, $$phi$trans$insert1748 = 0, $$phi$trans$insert1753 = 0, $$phi$trans$insert1754 = 0, $$phi$trans$insert1758 = 0, $$phi$trans$insert1759 = 0, $$phi$trans$insert1763 = 0, $$phi$trans$insert1764 = 0, $$phi$trans$insert1797 = 0, $$phi$trans$insert1798 = 0, $$phi$trans$insert1803 = 0;
 var $$phi$trans$insert1804 = 0, $$phi$trans$insert1809 = 0, $$phi$trans$insert1810 = 0, $$phi$trans$insert1817 = 0, $$phi$trans$insert1818 = 0, $$phi$trans$insert1823 = 0, $$phi$trans$insert1824 = 0, $$phi$trans$insert1829 = 0, $$phi$trans$insert1830 = 0, $$phi$trans$insert1837 = 0, $$phi$trans$insert1838 = 0, $$phi$trans$insert1843 = 0, $$phi$trans$insert1844 = 0, $$phi$trans$insert1849 = 0, $$phi$trans$insert1850 = 0, $$phi$trans$insert1857 = 0, $$phi$trans$insert1858 = 0, $$phi$trans$insert1863 = 0, $$phi$trans$insert1864 = 0, $$phi$trans$insert1869 = 0;
 var $$phi$trans$insert1870 = 0, $$phi$trans$insert1877 = 0, $$phi$trans$insert1878 = 0, $$phi$trans$insert1883 = 0, $$phi$trans$insert1884 = 0, $$phi$trans$insert1889 = 0, $$phi$trans$insert1890 = 0, $$phi$trans$insert1897 = 0, $$phi$trans$insert1898 = 0, $$phi$trans$insert1903 = 0, $$phi$trans$insert1904 = 0, $$phi$trans$insert1909 = 0, $$phi$trans$insert1910 = 0, $$phi$trans$insert1917 = 0, $$phi$trans$insert1918 = 0, $$phi$trans$insert1923 = 0, $$phi$trans$insert1924 = 0, $$phi$trans$insert1929 = 0, $$phi$trans$insert1930 = 0, $$phi$trans$insert1937 = 0;
 var $$phi$trans$insert1938 = 0, $$phi$trans$insert1943 = 0, $$phi$trans$insert1944 = 0, $$phi$trans$insert1949 = 0, $$phi$trans$insert1950 = 0, $$phi$trans$insert1957 = 0, $$phi$trans$insert1958 = 0, $$phi$trans$insert1963 = 0, $$phi$trans$insert1964 = 0, $$phi$trans$insert1969 = 0, $$phi$trans$insert1970 = 0, $$phi$trans$insert1977 = 0, $$phi$trans$insert1978 = 0, $$phi$trans$insert1983 = 0, $$phi$trans$insert1984 = 0, $$phi$trans$insert1989 = 0, $$phi$trans$insert1990 = 0, $$phi$trans$insert1997 = 0, $$phi$trans$insert1998 = 0, $$phi$trans$insert2003 = 0;
 var $$phi$trans$insert2004 = 0, $$phi$trans$insert2009 = 0, $$phi$trans$insert2010 = 0, $$phi$trans$insert2017 = 0, $$phi$trans$insert2018 = 0, $$phi$trans$insert2023 = 0, $$phi$trans$insert2024 = 0, $$phi$trans$insert2029 = 0, $$phi$trans$insert2030 = 0, $$pre = 0, $$pre1579 = 0, $$pre1580 = 0, $$pre1581 = 0, $$pre1584 = 0, $$pre1585 = 0, $$pre1586 = 0, $$pre1589 = 0, $$pre1590 = 0, $$pre1592 = 0, $$pre1595 = 0;
 var $$pre1596 = 0, $$pre1597 = 0, $$pre1600 = 0, $$pre1601 = 0, $$pre1602 = 0, $$pre1605 = 0, $$pre1606 = 0, $$pre1608 = 0, $$pre1611 = 0, $$pre1612 = 0, $$pre1613 = 0, $$pre1616 = 0, $$pre1617 = 0, $$pre1618 = 0, $$pre1621 = 0, $$pre1622 = 0, $$pre1624 = 0, $$pre1627 = 0, $$pre1628 = 0, $$pre1629 = 0;
 var $$pre1632 = 0, $$pre1633 = 0, $$pre1634 = 0, $$pre1637 = 0, $$pre1638 = 0, $$pre1640 = 0, $$pre1643 = 0, $$pre1644 = 0, $$pre1645 = 0, $$pre1648 = 0, $$pre1649 = 0, $$pre1650 = 0, $$pre1653 = 0, $$pre1654 = 0, $$pre1656 = 0, $$pre1659 = 0, $$pre1660 = 0, $$pre1661 = 0, $$pre1664 = 0, $$pre1665 = 0;
 var $$pre1666 = 0, $$pre1669 = 0, $$pre1670 = 0, $$pre1672 = 0, $$pre1675 = 0, $$pre1676 = 0, $$pre1677 = 0, $$pre1680 = 0, $$pre1681 = 0, $$pre1682 = 0, $$pre1685 = 0, $$pre1686 = 0, $$pre1688 = 0, $$pre1691 = 0, $$pre1692 = 0, $$pre1693 = 0, $$pre1696 = 0, $$pre1697 = 0, $$pre1698 = 0, $$pre1701 = 0;
 var $$pre1702 = 0, $$pre1704 = 0, $$pre1707 = 0, $$pre1708 = 0, $$pre1709 = 0, $$pre1712 = 0, $$pre1713 = 0, $$pre1714 = 0, $$pre1717 = 0, $$pre1718 = 0, $$pre1720 = 0, $$pre1723 = 0, $$pre1724 = 0, $$pre1725 = 0, $$pre1728 = 0, $$pre1729 = 0, $$pre1730 = 0, $$pre1733 = 0, $$pre1734 = 0, $$pre1736 = 0;
 var $$pre1739 = 0, $$pre1740 = 0, $$pre1741 = 0, $$pre1744 = 0, $$pre1745 = 0, $$pre1746 = 0, $$pre1749 = 0, $$pre1750 = 0, $$pre1752 = 0, $$pre1755 = 0, $$pre1756 = 0, $$pre1757 = 0, $$pre1760 = 0, $$pre1761 = 0, $$pre1762 = 0, $$pre1765 = 0, $$pre1766 = 0, $$pre1768 = 0, $$pre1769 = 0, $$pre1770 = 0;
 var $$pre1771 = 0, $$pre1772 = 0, $$pre1773 = 0, $$pre1775 = 0, $$pre1776 = 0, $$pre1777 = 0, $$pre1778 = 0, $$pre1779 = 0, $$pre1780 = 0, $$pre1782 = 0, $$pre1783 = 0, $$pre1784 = 0, $$pre1785 = 0, $$pre1786 = 0, $$pre1787 = 0, $$pre1789 = 0, $$pre1790 = 0, $$pre1791 = 0, $$pre1792 = 0, $$pre1793 = 0;
 var $$pre1794 = 0, $$pre1796 = 0, $$pre1799 = 0, $$pre1800 = 0, $$pre1801 = 0, $$pre1802 = 0, $$pre1805 = 0, $$pre1806 = 0, $$pre1807 = 0, $$pre1808 = 0, $$pre1811 = 0, $$pre1812 = 0, $$pre1813 = 0, $$pre1814 = 0, $$pre1816 = 0, $$pre1819 = 0, $$pre1820 = 0, $$pre1821 = 0, $$pre1822 = 0, $$pre1825 = 0;
 var $$pre1826 = 0, $$pre1827 = 0, $$pre1828 = 0, $$pre1831 = 0, $$pre1832 = 0, $$pre1833 = 0, $$pre1834 = 0, $$pre1836 = 0, $$pre1839 = 0, $$pre1840 = 0, $$pre1841 = 0, $$pre1842 = 0, $$pre1845 = 0, $$pre1846 = 0, $$pre1847 = 0, $$pre1848 = 0, $$pre1851 = 0, $$pre1852 = 0, $$pre1853 = 0, $$pre1854 = 0;
 var $$pre1856 = 0, $$pre1859 = 0, $$pre1860 = 0, $$pre1861 = 0, $$pre1862 = 0, $$pre1865 = 0, $$pre1866 = 0, $$pre1867 = 0, $$pre1868 = 0, $$pre1871 = 0, $$pre1872 = 0, $$pre1873 = 0, $$pre1874 = 0, $$pre1876 = 0, $$pre1879 = 0, $$pre1880 = 0, $$pre1881 = 0, $$pre1882 = 0, $$pre1885 = 0, $$pre1886 = 0;
 var $$pre1887 = 0, $$pre1888 = 0, $$pre1891 = 0, $$pre1892 = 0, $$pre1893 = 0, $$pre1894 = 0, $$pre1896 = 0, $$pre1899 = 0, $$pre1900 = 0, $$pre1901 = 0, $$pre1902 = 0, $$pre1905 = 0, $$pre1906 = 0, $$pre1907 = 0, $$pre1908 = 0, $$pre1911 = 0, $$pre1912 = 0, $$pre1913 = 0, $$pre1914 = 0, $$pre1916 = 0;
 var $$pre1919 = 0, $$pre1920 = 0, $$pre1921 = 0, $$pre1922 = 0, $$pre1925 = 0, $$pre1926 = 0, $$pre1927 = 0, $$pre1928 = 0, $$pre1931 = 0, $$pre1932 = 0, $$pre1933 = 0, $$pre1934 = 0, $$pre1936 = 0, $$pre1939 = 0, $$pre1940 = 0, $$pre1941 = 0, $$pre1942 = 0, $$pre1945 = 0, $$pre1946 = 0, $$pre1947 = 0;
 var $$pre1948 = 0, $$pre1951 = 0, $$pre1952 = 0, $$pre1953 = 0, $$pre1954 = 0, $$pre1956 = 0, $$pre1959 = 0, $$pre1960 = 0, $$pre1961 = 0, $$pre1962 = 0, $$pre1965 = 0, $$pre1966 = 0, $$pre1967 = 0, $$pre1968 = 0, $$pre1971 = 0, $$pre1972 = 0, $$pre1973 = 0, $$pre1974 = 0, $$pre1976 = 0, $$pre1979 = 0;
 var $$pre1980 = 0, $$pre1981 = 0, $$pre1982 = 0, $$pre1985 = 0, $$pre1986 = 0, $$pre1987 = 0, $$pre1988 = 0, $$pre1991 = 0, $$pre1992 = 0, $$pre1993 = 0, $$pre1994 = 0, $$pre1996 = 0, $$pre1999 = 0, $$pre2000 = 0, $$pre2001 = 0, $$pre2002 = 0, $$pre2005 = 0, $$pre2006 = 0, $$pre2007 = 0, $$pre2008 = 0;
 var $$pre2011 = 0, $$pre2012 = 0, $$pre2013 = 0, $$pre2014 = 0, $$pre2016 = 0, $$pre2019 = 0, $$pre2020 = 0, $$pre2021 = 0, $$pre2022 = 0, $$pre2025 = 0, $$pre2026 = 0, $$pre2027 = 0, $$pre2028 = 0, $$pre2031 = 0, $$pre2032 = 0, $$pre2033 = 0, $$pre2034 = 0, $$pre2036 = 0, $$pre2037 = 0, $$pre2038 = 0;
 var $$pre2039 = 0, $$pre2040 = 0, $$pre2041 = 0, $$pre2042 = 0, $$pre2044 = 0, $$pre2045 = 0, $$pre2046 = 0, $$pre2047 = 0, $$pre2048 = 0, $$pre2049 = 0, $$pre2050 = 0, $$pre2052 = 0, $$pre2053 = 0, $$pre2054 = 0, $$pre2055 = 0, $$pre2056 = 0, $$pre2057 = 0, $$pre2058 = 0, $$pre2060 = 0, $$pre2061 = 0;
 var $$pre2062 = 0, $$pre2063 = 0, $$pre2064 = 0, $$pre2065 = 0, $$pre2066 = 0, $10 = 0, $100 = 0, $1000 = 0, $1001 = 0, $1002 = 0, $1003 = 0, $1004 = 0, $1005 = 0, $1006 = 0, $1007 = 0, $1008 = 0, $1009 = 0, $101 = 0, $1010 = 0, $1011 = 0;
 var $1012 = 0, $1013 = 0, $1014 = 0, $1015 = 0, $1016 = 0, $1017 = 0, $1018 = 0, $1019 = 0, $102 = 0, $1020 = 0, $1021 = 0, $1022 = 0, $1023 = 0, $1024 = 0, $1025 = 0, $1026 = 0, $1027 = 0, $1028 = 0, $1029 = 0, $103 = 0;
 var $1030 = 0, $1031 = 0, $1032 = 0, $1033 = 0, $1034 = 0, $1035 = 0, $1036 = 0, $1037 = 0, $1038 = 0, $1039 = 0, $104 = 0, $1040 = 0, $1041 = 0, $1042 = 0, $1043 = 0, $1044 = 0, $1045 = 0, $1046 = 0, $1047 = 0, $1048 = 0;
 var $1049 = 0, $105 = 0, $1050 = 0, $1051 = 0, $1052 = 0, $1053 = 0, $1054 = 0, $1055 = 0, $1056 = 0, $1057 = 0, $1058 = 0, $1059 = 0, $106 = 0, $1060 = 0, $1061 = 0, $1062 = 0, $1063 = 0, $1064 = 0, $1065 = 0, $1066 = 0;
 var $1067 = 0, $1068 = 0, $1069 = 0, $107 = 0, $1070 = 0, $1071 = 0, $1072 = 0, $1073 = 0, $1074 = 0, $1075 = 0, $1076 = 0, $1077 = 0, $1078 = 0, $1079 = 0, $108 = 0, $1080 = 0, $1081 = 0, $1082 = 0, $1083 = 0, $1084 = 0;
 var $1085 = 0, $1086 = 0, $1087 = 0, $1088 = 0, $1089 = 0, $109 = 0, $1090 = 0, $1091 = 0, $1092 = 0, $1093 = 0, $1094 = 0, $1095 = 0, $1096 = 0, $1097 = 0, $1098 = 0, $1099 = 0, $11 = 0, $110 = 0, $1100 = 0, $1101 = 0;
 var $1102 = 0, $1103 = 0, $1104 = 0, $1105 = 0, $1106 = 0, $1107 = 0, $1108 = 0, $1109 = 0, $111 = 0, $1110 = 0, $1111 = 0, $1112 = 0, $1113 = 0, $1114 = 0, $1115 = 0, $1116 = 0, $1117 = 0, $1118 = 0, $1119 = 0, $112 = 0;
 var $1120 = 0, $1121 = 0, $1122 = 0, $1123 = 0, $1124 = 0, $1125 = 0, $1126 = 0, $1127 = 0, $1128 = 0, $1129 = 0, $113 = 0, $1130 = 0, $1131 = 0, $1132 = 0, $1133 = 0, $1134 = 0, $1135 = 0, $1136 = 0, $1137 = 0, $1138 = 0;
 var $1139 = 0, $114 = 0, $1140 = 0, $1141 = 0, $1142 = 0, $1143 = 0, $1144 = 0, $1145 = 0, $1146 = 0, $1147 = 0, $1148 = 0, $1149 = 0, $115 = 0, $1150 = 0, $1151 = 0, $1152 = 0, $1153 = 0, $1154 = 0, $1155 = 0, $1156 = 0;
 var $1157 = 0, $1158 = 0, $1159 = 0, $116 = 0, $1160 = 0, $1161 = 0, $1162 = 0, $1163 = 0, $1164 = 0, $1165 = 0, $1166 = 0, $1167 = 0, $1168 = 0, $1169 = 0, $117 = 0, $1170 = 0, $1171 = 0, $1172 = 0, $1173 = 0, $1174 = 0;
 var $1175 = 0, $1176 = 0, $1177 = 0, $1178 = 0, $1179 = 0, $118 = 0, $1180 = 0, $1181 = 0, $1182 = 0, $1183 = 0, $1184 = 0, $1185 = 0, $1186 = 0, $1187 = 0, $1188 = 0, $1189 = 0, $119 = 0, $1190 = 0, $1191 = 0, $1192 = 0;
 var $1193 = 0, $1194 = 0, $1195 = 0, $1196 = 0, $1197 = 0, $1198 = 0, $1199 = 0, $12 = 0, $120 = 0, $1200 = 0, $1201 = 0, $1202 = 0, $1203 = 0, $1204 = 0, $1205 = 0, $1206 = 0, $1207 = 0, $1208 = 0, $1209 = 0, $121 = 0;
 var $1210 = 0, $1211 = 0, $1212 = 0, $1213 = 0, $1214 = 0, $1215 = 0, $1216 = 0, $1217 = 0, $1218 = 0, $1219 = 0, $122 = 0, $1220 = 0, $1221 = 0, $1222 = 0, $1223 = 0, $1224 = 0, $1225 = 0, $1226 = 0, $1227 = 0, $1228 = 0;
 var $1229 = 0, $123 = 0, $1230 = 0, $1231 = 0, $1232 = 0, $1233 = 0, $1234 = 0, $1235 = 0, $1236 = 0, $1237 = 0, $1238 = 0, $1239 = 0, $124 = 0, $1240 = 0, $1241 = 0, $1242 = 0, $1243 = 0, $1244 = 0, $1245 = 0, $1246 = 0;
 var $1247 = 0, $1248 = 0, $1249 = 0, $125 = 0, $1250 = 0, $1251 = 0, $1252 = 0, $1253 = 0, $1254 = 0, $1255 = 0, $1256 = 0, $1257 = 0, $1258 = 0, $1259 = 0, $126 = 0, $1260 = 0, $1261 = 0, $1262 = 0, $1263 = 0, $1264 = 0;
 var $1265 = 0, $1266 = 0, $1267 = 0, $1268 = 0, $1269 = 0, $127 = 0, $1270 = 0, $1271 = 0, $1272 = 0, $1273 = 0, $1274 = 0, $1275 = 0, $1276 = 0, $1277 = 0, $1278 = 0, $1279 = 0, $128 = 0, $1280 = 0, $1281 = 0, $1282 = 0;
 var $1283 = 0, $1284 = 0, $1285 = 0, $1286 = 0, $1287 = 0, $1288 = 0, $1289 = 0, $129 = 0, $1290 = 0, $1291 = 0, $1292 = 0, $1293 = 0, $1294 = 0, $1295 = 0, $1296 = 0, $1297 = 0, $1298 = 0, $1299 = 0, $13 = 0, $130 = 0;
 var $1300 = 0, $1301 = 0, $1302 = 0, $1303 = 0, $1304 = 0, $1305 = 0, $1306 = 0, $1307 = 0, $1308 = 0, $1309 = 0, $131 = 0, $1310 = 0, $1311 = 0, $1312 = 0, $1313 = 0, $1314 = 0, $1315 = 0, $1316 = 0, $1317 = 0, $1318 = 0;
 var $1319 = 0, $132 = 0, $1320 = 0, $1321 = 0, $1322 = 0, $1323 = 0, $1324 = 0, $1325 = 0, $1326 = 0, $1327 = 0, $1328 = 0, $1329 = 0, $133 = 0, $1330 = 0, $1331 = 0, $1332 = 0, $1333 = 0, $1334 = 0, $1335 = 0, $1336 = 0;
 var $1337 = 0, $1338 = 0, $1339 = 0, $134 = 0, $1340 = 0, $1341 = 0, $1342 = 0, $1343 = 0, $1344 = 0, $1345 = 0, $1346 = 0, $1347 = 0, $1348 = 0, $1349 = 0, $135 = 0, $1350 = 0, $1351 = 0, $1352 = 0, $1353 = 0, $1354 = 0;
 var $1355 = 0, $1356 = 0, $1357 = 0, $1358 = 0, $1359 = 0, $136 = 0, $1360 = 0, $1361 = 0, $1362 = 0, $1363 = 0, $1364 = 0, $1365 = 0, $1366 = 0, $1367 = 0, $1368 = 0, $1369 = 0, $137 = 0, $1370 = 0, $1371 = 0, $1372 = 0;
 var $1373 = 0, $1374 = 0, $1375 = 0, $1376 = 0, $1377 = 0, $1378 = 0, $1379 = 0, $138 = 0, $1380 = 0, $1381 = 0, $1382 = 0, $1383 = 0, $1384 = 0, $1385 = 0, $1386 = 0, $1387 = 0, $1388 = 0, $1389 = 0, $139 = 0, $1390 = 0;
 var $1391 = 0, $1392 = 0, $1393 = 0, $1394 = 0, $1395 = 0, $1396 = 0, $1397 = 0, $1398 = 0, $1399 = 0, $14 = 0, $140 = 0, $1400 = 0, $1401 = 0, $1402 = 0, $1403 = 0, $1404 = 0, $1405 = 0, $1406 = 0, $1407 = 0, $1408 = 0;
 var $1409 = 0, $141 = 0, $1410 = 0, $1411 = 0, $1412 = 0, $1413 = 0, $1414 = 0, $1415 = 0, $1416 = 0, $1417 = 0, $1418 = 0, $1419 = 0, $142 = 0, $1420 = 0, $1421 = 0, $1422 = 0, $1423 = 0, $1424 = 0, $1425 = 0, $1426 = 0;
 var $1427 = 0, $1428 = 0, $1429 = 0, $143 = 0, $1430 = 0, $1431 = 0, $1432 = 0, $1433 = 0, $1434 = 0, $1435 = 0, $1436 = 0, $1437 = 0, $1438 = 0, $1439 = 0, $144 = 0, $1440 = 0, $1441 = 0, $1442 = 0, $1443 = 0, $1444 = 0;
 var $1445 = 0, $1446 = 0, $1447 = 0, $1448 = 0, $1449 = 0, $145 = 0, $1450 = 0, $1451 = 0, $1452 = 0, $1453 = 0, $1454 = 0, $1455 = 0, $1456 = 0, $1457 = 0, $1458 = 0, $1459 = 0, $146 = 0, $1460 = 0, $1461 = 0, $1462 = 0;
 var $1463 = 0, $1464 = 0, $1465 = 0, $1466 = 0, $1467 = 0, $1468 = 0, $1469 = 0, $147 = 0, $1470 = 0, $1471 = 0, $1472 = 0, $1473 = 0, $1474 = 0, $1475 = 0, $1476 = 0, $1477 = 0, $1478 = 0, $1479 = 0, $148 = 0, $1480 = 0;
 var $1481 = 0, $1482 = 0, $1483 = 0, $1484 = 0, $1485 = 0, $1486 = 0, $1487 = 0, $1488 = 0, $1489 = 0, $149 = 0, $1490 = 0, $1491 = 0, $1492 = 0, $1493 = 0, $1494 = 0, $1495 = 0, $1496 = 0, $1497 = 0, $1498 = 0, $1499 = 0;
 var $15 = 0, $150 = 0, $1500 = 0, $1501 = 0, $1502 = 0, $1503 = 0, $1504 = 0, $1505 = 0, $1506 = 0, $1507 = 0, $1508 = 0, $1509 = 0, $151 = 0, $1510 = 0, $1511 = 0, $1512 = 0, $1513 = 0, $1514 = 0, $1515 = 0, $1516 = 0;
 var $1517 = 0, $1518 = 0, $1519 = 0, $152 = 0, $1520 = 0, $1521 = 0, $1522 = 0, $1523 = 0, $1524 = 0, $1525 = 0, $1526 = 0, $1527 = 0, $1528 = 0, $1529 = 0, $153 = 0, $1530 = 0, $1531 = 0, $1532 = 0, $1533 = 0, $1534 = 0;
 var $1535 = 0, $1536 = 0, $1537 = 0, $1538 = 0, $1539 = 0, $154 = 0, $1540 = 0, $1541 = 0, $1542 = 0, $1543 = 0, $1544 = 0, $1545 = 0, $1546 = 0, $1547 = 0, $1548 = 0, $1549 = 0, $155 = 0, $1550 = 0, $1551 = 0, $1552 = 0;
 var $1553 = 0, $1554 = 0, $1555 = 0, $1556 = 0, $1557 = 0, $1558 = 0, $1559 = 0, $156 = 0, $1560 = 0, $1561 = 0, $1562 = 0, $1563 = 0, $1564 = 0, $1565 = 0, $1566 = 0, $1567 = 0, $1568 = 0, $1569 = 0, $157 = 0, $1570 = 0;
 var $1571 = 0, $1572 = 0, $1573 = 0, $1574 = 0, $1575 = 0, $1576 = 0, $1577 = 0, $1578 = 0, $1579 = 0, $158 = 0, $1580 = 0, $1581 = 0, $1582 = 0, $1583 = 0, $1584 = 0, $1585 = 0, $1586 = 0, $1587 = 0, $1588 = 0, $1589 = 0;
 var $159 = 0, $1590 = 0, $1591 = 0, $1592 = 0, $1593 = 0, $1594 = 0, $1595 = 0, $1596 = 0, $1597 = 0, $1598 = 0, $1599 = 0, $16 = 0, $160 = 0, $1600 = 0, $1601 = 0, $1602 = 0, $1603 = 0, $1604 = 0, $1605 = 0, $1606 = 0;
 var $1607 = 0, $1608 = 0, $1609 = 0, $161 = 0, $1610 = 0, $1611 = 0, $1612 = 0, $1613 = 0, $1614 = 0, $1615 = 0, $1616 = 0, $1617 = 0, $1618 = 0, $1619 = 0, $162 = 0, $1620 = 0, $1621 = 0, $1622 = 0, $1623 = 0, $1624 = 0;
 var $1625 = 0, $1626 = 0, $1627 = 0, $1628 = 0, $1629 = 0, $163 = 0, $1630 = 0, $1631 = 0, $1632 = 0, $1633 = 0, $1634 = 0, $1635 = 0, $1636 = 0, $1637 = 0, $1638 = 0, $1639 = 0, $164 = 0, $1640 = 0, $1641 = 0, $1642 = 0;
 var $1643 = 0, $1644 = 0, $1645 = 0, $1646 = 0, $1647 = 0, $1648 = 0, $1649 = 0, $165 = 0, $1650 = 0, $1651 = 0, $1652 = 0, $1653 = 0, $1654 = 0, $1655 = 0, $1656 = 0, $1657 = 0, $1658 = 0, $1659 = 0, $166 = 0, $1660 = 0;
 var $1661 = 0, $1662 = 0, $1663 = 0, $1664 = 0, $1665 = 0, $1666 = 0, $1667 = 0, $1668 = 0, $1669 = 0, $167 = 0, $1670 = 0, $1671 = 0, $1672 = 0, $1673 = 0, $1674 = 0, $1675 = 0, $1676 = 0, $1677 = 0, $1678 = 0, $1679 = 0;
 var $168 = 0, $1680 = 0, $1681 = 0, $1682 = 0, $1683 = 0, $1684 = 0, $1685 = 0, $1686 = 0, $1687 = 0, $1688 = 0, $1689 = 0, $169 = 0, $1690 = 0, $1691 = 0, $1692 = 0, $1693 = 0, $1694 = 0, $1695 = 0, $1696 = 0, $1697 = 0;
 var $1698 = 0, $1699 = 0, $17 = 0, $170 = 0, $1700 = 0, $1701 = 0, $1702 = 0, $1703 = 0, $1704 = 0, $1705 = 0, $1706 = 0, $1707 = 0, $1708 = 0, $1709 = 0, $171 = 0, $1710 = 0, $1711 = 0, $1712 = 0, $1713 = 0, $1714 = 0;
 var $1715 = 0, $1716 = 0, $1717 = 0, $1718 = 0, $1719 = 0, $172 = 0, $1720 = 0, $1721 = 0, $1722 = 0, $1723 = 0, $1724 = 0, $1725 = 0, $1726 = 0, $1727 = 0, $1728 = 0, $1729 = 0, $173 = 0, $1730 = 0, $1731 = 0, $1732 = 0;
 var $1733 = 0, $1734 = 0, $1735 = 0, $1736 = 0, $1737 = 0, $1738 = 0, $1739 = 0, $174 = 0, $1740 = 0, $1741 = 0, $1742 = 0, $1743 = 0, $1744 = 0, $1745 = 0, $1746 = 0, $1747 = 0, $1748 = 0, $1749 = 0, $175 = 0, $1750 = 0;
 var $1751 = 0, $1752 = 0, $1753 = 0, $1754 = 0, $1755 = 0, $1756 = 0, $1757 = 0, $1758 = 0, $1759 = 0, $176 = 0, $1760 = 0, $1761 = 0, $1762 = 0, $1763 = 0, $1764 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0;
 var $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0;
 var $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0;
 var $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0;
 var $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0;
 var $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0;
 var $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0;
 var $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0;
 var $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0;
 var $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0;
 var $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0;
 var $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0;
 var $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0;
 var $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0;
 var $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0;
 var $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0;
 var $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0;
 var $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0;
 var $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0;
 var $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0;
 var $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0;
 var $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0;
 var $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0;
 var $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0;
 var $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0;
 var $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0;
 var $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0;
 var $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0;
 var $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0;
 var $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0;
 var $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0;
 var $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0;
 var $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0;
 var $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0;
 var $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0;
 var $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0;
 var $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = 0;
 var $834 = 0, $835 = 0, $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0, $850 = 0, $851 = 0;
 var $852 = 0, $853 = 0, $854 = 0, $855 = 0, $856 = 0, $857 = 0, $858 = 0, $859 = 0, $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0, $869 = 0, $87 = 0;
 var $870 = 0, $871 = 0, $872 = 0, $873 = 0, $874 = 0, $875 = 0, $876 = 0, $877 = 0, $878 = 0, $879 = 0, $88 = 0, $880 = 0, $881 = 0, $882 = 0, $883 = 0, $884 = 0, $885 = 0, $886 = 0, $887 = 0, $888 = 0;
 var $889 = 0, $89 = 0, $890 = 0, $891 = 0, $892 = 0, $893 = 0, $894 = 0, $895 = 0, $896 = 0, $897 = 0, $898 = 0, $899 = 0, $9 = 0, $90 = 0, $900 = 0, $901 = 0, $902 = 0, $903 = 0, $904 = 0, $905 = 0;
 var $906 = 0, $907 = 0, $908 = 0, $909 = 0, $91 = 0, $910 = 0, $911 = 0, $912 = 0, $913 = 0, $914 = 0, $915 = 0, $916 = 0, $917 = 0, $918 = 0, $919 = 0, $92 = 0, $920 = 0, $921 = 0, $922 = 0, $923 = 0;
 var $924 = 0, $925 = 0, $926 = 0, $927 = 0, $928 = 0, $929 = 0, $93 = 0, $930 = 0, $931 = 0, $932 = 0, $933 = 0, $934 = 0, $935 = 0, $936 = 0, $937 = 0, $938 = 0, $939 = 0, $94 = 0, $940 = 0, $941 = 0;
 var $942 = 0, $943 = 0, $944 = 0, $945 = 0, $946 = 0, $947 = 0, $948 = 0, $949 = 0, $95 = 0, $950 = 0, $951 = 0, $952 = 0, $953 = 0, $954 = 0, $955 = 0, $956 = 0, $957 = 0, $958 = 0, $959 = 0, $96 = 0;
 var $960 = 0, $961 = 0, $962 = 0, $963 = 0, $964 = 0, $965 = 0, $966 = 0, $967 = 0, $968 = 0, $969 = 0, $97 = 0, $970 = 0, $971 = 0, $972 = 0, $973 = 0, $974 = 0, $975 = 0, $976 = 0, $977 = 0, $978 = 0;
 var $979 = 0, $98 = 0, $980 = 0, $981 = 0, $982 = 0, $983 = 0, $984 = 0, $985 = 0, $986 = 0, $987 = 0, $988 = 0, $989 = 0, $99 = 0, $990 = 0, $991 = 0, $992 = 0, $993 = 0, $994 = 0, $995 = 0, $996 = 0;
 var $997 = 0, $998 = 0, $999 = 0, $trunc = 0, $trunc$clear = 0, $trunc1535 = 0, $trunc1535$clear = 0, $trunc1536 = 0, $trunc1536$clear = 0, $trunc1537 = 0, $trunc1537$clear = 0, $trunc1538 = 0, $trunc1538$clear = 0, $trunc1539 = 0, $trunc1539$clear = 0, $trunc1540 = 0, $trunc1540$clear = 0, $trunc1541 = 0, $trunc1541$clear = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $7 = ((($0)) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $6 ^ -1;
 $10 = $9&255;
 $11 = ((($8)) + 9|0);
 $12 = HEAP8[$11>>0]|0;
 $13 = $12&255;
 switch ($12<<24>>24) {
 case 2:  {
  switch ($2|0) {
  case 1:  {
   $14 = ((($1)) + 8|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = ((($1)) + 12|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = ((($0)) + 16|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($19|0) / ($13|0))&-1;
   $21 = (($20) - ($15))|0;
   $22 = ($17|0)==(0);
   if ($22) {
    $$0 = 0;
    return ($$0|0);
   }
   $23 = ((($0)) + 20|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = ((($1)) + 4|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = Math_imul($26, $20)|0;
   $28 = (($24) + ($27<<1)|0);
   $29 = HEAP32[$1>>2]|0;
   $30 = (($28) + ($29<<1)|0);
   $31 = (($15) + 3)|0;
   $32 = (($31|0) / 4)&-1;
   $trunc1540 = $15&255;
   $33 = ((($8)) + 28|0);
   $34 = ((($8)) + 12|0);
   $35 = ((($8)) + 32|0);
   $36 = ((($8)) + 29|0);
   $37 = ((($8)) + 16|0);
   $38 = ((($8)) + 33|0);
   $39 = ((($8)) + 30|0);
   $40 = ((($8)) + 20|0);
   $41 = ((($8)) + 34|0);
   $42 = $3&255;
   $43 = $4&255;
   $44 = $5&255;
   $45 = ((($8)) + 24|0);
   $$014561550 = $30;$$in1569 = $17;
   L31: while(1) {
    $46 = (($$in1569) + -1)|0;
    $trunc1540$clear = $trunc1540 & 3;
    switch ($trunc1540$clear<<24>>24) {
    case 0:  {
     $$pre1956 = HEAP8[$33>>0]|0;
     $$phi$trans$insert1957 = $$pre1956&255;
     $$phi$trans$insert1958 = (79212 + ($$phi$trans$insert1957<<2)|0);
     $$pre1959 = HEAP32[$$phi$trans$insert1958>>2]|0;
     $$pre1960 = HEAP32[$34>>2]|0;
     $$pre1961 = HEAP8[$35>>0]|0;
     $$pre1962 = HEAP8[$36>>0]|0;
     $$phi$trans$insert1963 = $$pre1962&255;
     $$phi$trans$insert1964 = (79212 + ($$phi$trans$insert1963<<2)|0);
     $$pre1965 = HEAP32[$$phi$trans$insert1964>>2]|0;
     $$pre1966 = HEAP32[$37>>2]|0;
     $$pre1967 = HEAP8[$38>>0]|0;
     $$pre1968 = HEAP8[$39>>0]|0;
     $$phi$trans$insert1969 = $$pre1968&255;
     $$phi$trans$insert1970 = (79212 + ($$phi$trans$insert1969<<2)|0);
     $$pre1971 = HEAP32[$$phi$trans$insert1970>>2]|0;
     $$pre1972 = HEAP32[$40>>2]|0;
     $$pre1973 = HEAP8[$41>>0]|0;
     $$pre1974 = HEAP32[$45>>2]|0;
     $$01461 = $32;$$11457 = $$014561550;$48 = $$pre1956;$52 = $$pre1960;$54 = $$pre1961;$57 = $$pre1959;$61 = $$pre1962;$63 = $$pre1966;$65 = $$pre1967;$68 = $$pre1965;$72 = $$pre1968;$74 = $$pre1972;$76 = $$pre1973;$79 = $$pre1971;$99 = $$pre1974;
     label = 10;
     break;
    }
    case 3:  {
     $$pre1976 = HEAP8[$33>>0]|0;
     $$phi$trans$insert1977 = $$pre1976&255;
     $$phi$trans$insert1978 = (79212 + ($$phi$trans$insert1977<<2)|0);
     $$pre1979 = HEAP32[$$phi$trans$insert1978>>2]|0;
     $$pre1980 = HEAP32[$34>>2]|0;
     $$pre1981 = HEAP8[$35>>0]|0;
     $$pre1982 = HEAP8[$36>>0]|0;
     $$phi$trans$insert1983 = $$pre1982&255;
     $$phi$trans$insert1984 = (79212 + ($$phi$trans$insert1983<<2)|0);
     $$pre1985 = HEAP32[$$phi$trans$insert1984>>2]|0;
     $$pre1986 = HEAP32[$37>>2]|0;
     $$pre1987 = HEAP8[$38>>0]|0;
     $$pre1988 = HEAP8[$39>>0]|0;
     $$phi$trans$insert1989 = $$pre1988&255;
     $$phi$trans$insert1990 = (79212 + ($$phi$trans$insert1989<<2)|0);
     $$pre1991 = HEAP32[$$phi$trans$insert1990>>2]|0;
     $$pre1992 = HEAP32[$40>>2]|0;
     $$pre1993 = HEAP8[$41>>0]|0;
     $$pre1994 = HEAP32[$45>>2]|0;
     $$11462 = $32;$$21458 = $$014561550;$104 = $$pre1976;$108 = $$pre1980;$110 = $$pre1981;$113 = $$pre1979;$117 = $$pre1982;$119 = $$pre1986;$121 = $$pre1987;$124 = $$pre1985;$128 = $$pre1988;$130 = $$pre1992;$132 = $$pre1993;$135 = $$pre1991;$155 = $$pre1994;
     label = 11;
     break;
    }
    case 2:  {
     $$pre1996 = HEAP8[$33>>0]|0;
     $$phi$trans$insert1997 = $$pre1996&255;
     $$phi$trans$insert1998 = (79212 + ($$phi$trans$insert1997<<2)|0);
     $$pre1999 = HEAP32[$$phi$trans$insert1998>>2]|0;
     $$pre2000 = HEAP32[$34>>2]|0;
     $$pre2001 = HEAP8[$35>>0]|0;
     $$pre2002 = HEAP8[$36>>0]|0;
     $$phi$trans$insert2003 = $$pre2002&255;
     $$phi$trans$insert2004 = (79212 + ($$phi$trans$insert2003<<2)|0);
     $$pre2005 = HEAP32[$$phi$trans$insert2004>>2]|0;
     $$pre2006 = HEAP32[$37>>2]|0;
     $$pre2007 = HEAP8[$38>>0]|0;
     $$pre2008 = HEAP8[$39>>0]|0;
     $$phi$trans$insert2009 = $$pre2008&255;
     $$phi$trans$insert2010 = (79212 + ($$phi$trans$insert2009<<2)|0);
     $$pre2011 = HEAP32[$$phi$trans$insert2010>>2]|0;
     $$pre2012 = HEAP32[$40>>2]|0;
     $$pre2013 = HEAP8[$41>>0]|0;
     $$pre2014 = HEAP32[$45>>2]|0;
     $$21463 = $32;$$31459 = $$014561550;$160 = $$pre1996;$164 = $$pre2000;$166 = $$pre2001;$169 = $$pre1999;$173 = $$pre2002;$175 = $$pre2006;$177 = $$pre2007;$180 = $$pre2005;$184 = $$pre2008;$186 = $$pre2012;$188 = $$pre2013;$191 = $$pre2011;$211 = $$pre2014;
     label = 12;
     break;
    }
    case 1:  {
     $$pre2016 = HEAP8[$33>>0]|0;
     $$phi$trans$insert2017 = $$pre2016&255;
     $$phi$trans$insert2018 = (79212 + ($$phi$trans$insert2017<<2)|0);
     $$pre2019 = HEAP32[$$phi$trans$insert2018>>2]|0;
     $$pre2020 = HEAP32[$34>>2]|0;
     $$pre2021 = HEAP8[$35>>0]|0;
     $$pre2022 = HEAP8[$36>>0]|0;
     $$phi$trans$insert2023 = $$pre2022&255;
     $$phi$trans$insert2024 = (79212 + ($$phi$trans$insert2023<<2)|0);
     $$pre2025 = HEAP32[$$phi$trans$insert2024>>2]|0;
     $$pre2026 = HEAP32[$37>>2]|0;
     $$pre2027 = HEAP8[$38>>0]|0;
     $$pre2028 = HEAP8[$39>>0]|0;
     $$phi$trans$insert2029 = $$pre2028&255;
     $$phi$trans$insert2030 = (79212 + ($$phi$trans$insert2029<<2)|0);
     $$pre2031 = HEAP32[$$phi$trans$insert2030>>2]|0;
     $$pre2032 = HEAP32[$40>>2]|0;
     $$pre2033 = HEAP8[$41>>0]|0;
     $$pre2034 = HEAP32[$45>>2]|0;
     $$31464 = $32;$$41460 = $$014561550;$216 = $$pre2016;$220 = $$pre2020;$222 = $$pre2021;$225 = $$pre2019;$229 = $$pre2022;$231 = $$pre2026;$233 = $$pre2027;$236 = $$pre2025;$240 = $$pre2028;$242 = $$pre2032;$244 = $$pre2033;$247 = $$pre2031;$267 = $$pre2034;
     label = 13;
     break;
    }
    default: {
     label = 14;
     break L31;
    }
    }
    while(1) {
     if ((label|0) == 10) {
      label = 0;
      $47 = $48&255;
      $49 = HEAP16[$$11457>>1]|0;
      $50 = $49&65535;
      $51 = $50 & $52;
      $53 = $54&255;
      $55 = $51 >>> $53;
      $56 = (($57) + ($55)|0);
      $58 = HEAP8[$56>>0]|0;
      $59 = $58&255;
      $60 = $61&255;
      $62 = $63 & $50;
      $64 = $65&255;
      $66 = $62 >>> $64;
      $67 = (($68) + ($66)|0);
      $69 = HEAP8[$67>>0]|0;
      $70 = $69&255;
      $71 = $72&255;
      $73 = $74 & $50;
      $75 = $76&255;
      $77 = $73 >>> $75;
      $78 = (($79) + ($77)|0);
      $80 = HEAP8[$78>>0]|0;
      $81 = $80&255;
      $82 = Math_imul($59, $10)|0;
      $83 = (($82>>>0) / 255)&-1;
      $84 = (($83) + ($42))|0;
      $85 = Math_imul($70, $10)|0;
      $86 = (($85>>>0) / 255)&-1;
      $87 = (($86) + ($43))|0;
      $88 = Math_imul($81, $10)|0;
      $89 = (($88>>>0) / 255)&-1;
      $90 = (($89) + ($44))|0;
      $91 = $84 >>> $47;
      $92 = $91 << $53;
      $93 = $87 >>> $60;
      $94 = $93 << $64;
      $95 = $94 | $92;
      $96 = $90 >>> $71;
      $97 = $96 << $75;
      $98 = $95 | $99;
      $100 = $98 | $97;
      $101 = $100&65535;
      HEAP16[$$11457>>1] = $101;
      $102 = ((($$11457)) + 2|0);
      $$11462 = $$01461;$$21458 = $102;$104 = $48;$108 = $52;$110 = $54;$113 = $57;$117 = $61;$119 = $63;$121 = $65;$124 = $68;$128 = $72;$130 = $74;$132 = $76;$135 = $79;$155 = $99;
      label = 11;
      continue;
     }
     else if ((label|0) == 11) {
      label = 0;
      $103 = $104&255;
      $105 = HEAP16[$$21458>>1]|0;
      $106 = $105&65535;
      $107 = $106 & $108;
      $109 = $110&255;
      $111 = $107 >>> $109;
      $112 = (($113) + ($111)|0);
      $114 = HEAP8[$112>>0]|0;
      $115 = $114&255;
      $116 = $117&255;
      $118 = $119 & $106;
      $120 = $121&255;
      $122 = $118 >>> $120;
      $123 = (($124) + ($122)|0);
      $125 = HEAP8[$123>>0]|0;
      $126 = $125&255;
      $127 = $128&255;
      $129 = $130 & $106;
      $131 = $132&255;
      $133 = $129 >>> $131;
      $134 = (($135) + ($133)|0);
      $136 = HEAP8[$134>>0]|0;
      $137 = $136&255;
      $138 = Math_imul($115, $10)|0;
      $139 = (($138>>>0) / 255)&-1;
      $140 = (($139) + ($42))|0;
      $141 = Math_imul($126, $10)|0;
      $142 = (($141>>>0) / 255)&-1;
      $143 = (($142) + ($43))|0;
      $144 = Math_imul($137, $10)|0;
      $145 = (($144>>>0) / 255)&-1;
      $146 = (($145) + ($44))|0;
      $147 = $140 >>> $103;
      $148 = $147 << $109;
      $149 = $143 >>> $116;
      $150 = $149 << $120;
      $151 = $150 | $148;
      $152 = $146 >>> $127;
      $153 = $152 << $131;
      $154 = $151 | $155;
      $156 = $154 | $153;
      $157 = $156&65535;
      HEAP16[$$21458>>1] = $157;
      $158 = ((($$21458)) + 2|0);
      $$21463 = $$11462;$$31459 = $158;$160 = $104;$164 = $108;$166 = $110;$169 = $113;$173 = $117;$175 = $119;$177 = $121;$180 = $124;$184 = $128;$186 = $130;$188 = $132;$191 = $135;$211 = $155;
      label = 12;
      continue;
     }
     else if ((label|0) == 12) {
      label = 0;
      $159 = $160&255;
      $161 = HEAP16[$$31459>>1]|0;
      $162 = $161&65535;
      $163 = $162 & $164;
      $165 = $166&255;
      $167 = $163 >>> $165;
      $168 = (($169) + ($167)|0);
      $170 = HEAP8[$168>>0]|0;
      $171 = $170&255;
      $172 = $173&255;
      $174 = $175 & $162;
      $176 = $177&255;
      $178 = $174 >>> $176;
      $179 = (($180) + ($178)|0);
      $181 = HEAP8[$179>>0]|0;
      $182 = $181&255;
      $183 = $184&255;
      $185 = $186 & $162;
      $187 = $188&255;
      $189 = $185 >>> $187;
      $190 = (($191) + ($189)|0);
      $192 = HEAP8[$190>>0]|0;
      $193 = $192&255;
      $194 = Math_imul($171, $10)|0;
      $195 = (($194>>>0) / 255)&-1;
      $196 = (($195) + ($42))|0;
      $197 = Math_imul($182, $10)|0;
      $198 = (($197>>>0) / 255)&-1;
      $199 = (($198) + ($43))|0;
      $200 = Math_imul($193, $10)|0;
      $201 = (($200>>>0) / 255)&-1;
      $202 = (($201) + ($44))|0;
      $203 = $196 >>> $159;
      $204 = $203 << $165;
      $205 = $199 >>> $172;
      $206 = $205 << $176;
      $207 = $206 | $204;
      $208 = $202 >>> $183;
      $209 = $208 << $187;
      $210 = $207 | $211;
      $212 = $210 | $209;
      $213 = $212&65535;
      HEAP16[$$31459>>1] = $213;
      $214 = ((($$31459)) + 2|0);
      $$31464 = $$21463;$$41460 = $214;$216 = $160;$220 = $164;$222 = $166;$225 = $169;$229 = $173;$231 = $175;$233 = $177;$236 = $180;$240 = $184;$242 = $186;$244 = $188;$247 = $191;$267 = $211;
      label = 13;
      continue;
     }
     else if ((label|0) == 13) {
      label = 0;
      $215 = $216&255;
      $217 = HEAP16[$$41460>>1]|0;
      $218 = $217&65535;
      $219 = $218 & $220;
      $221 = $222&255;
      $223 = $219 >>> $221;
      $224 = (($225) + ($223)|0);
      $226 = HEAP8[$224>>0]|0;
      $227 = $226&255;
      $228 = $229&255;
      $230 = $231 & $218;
      $232 = $233&255;
      $234 = $230 >>> $232;
      $235 = (($236) + ($234)|0);
      $237 = HEAP8[$235>>0]|0;
      $238 = $237&255;
      $239 = $240&255;
      $241 = $242 & $218;
      $243 = $244&255;
      $245 = $241 >>> $243;
      $246 = (($247) + ($245)|0);
      $248 = HEAP8[$246>>0]|0;
      $249 = $248&255;
      $250 = Math_imul($227, $10)|0;
      $251 = (($250>>>0) / 255)&-1;
      $252 = (($251) + ($42))|0;
      $253 = Math_imul($238, $10)|0;
      $254 = (($253>>>0) / 255)&-1;
      $255 = (($254) + ($43))|0;
      $256 = Math_imul($249, $10)|0;
      $257 = (($256>>>0) / 255)&-1;
      $258 = (($257) + ($44))|0;
      $259 = $252 >>> $215;
      $260 = $259 << $221;
      $261 = $255 >>> $228;
      $262 = $261 << $232;
      $263 = $262 | $260;
      $264 = $258 >>> $239;
      $265 = $264 << $243;
      $266 = $263 | $267;
      $268 = $266 | $265;
      $269 = $268&65535;
      HEAP16[$$41460>>1] = $269;
      $270 = ((($$41460)) + 2|0);
      $271 = (($$31464) + -1)|0;
      $272 = ($$31464|0)>(1);
      if ($272) {
       $$01461 = $271;$$11457 = $270;$48 = $216;$52 = $220;$54 = $222;$57 = $225;$61 = $229;$63 = $231;$65 = $233;$68 = $236;$72 = $240;$74 = $242;$76 = $244;$79 = $247;$99 = $267;
       label = 10;
       continue;
      } else {
       break;
      }
     }
    }
    $273 = (($270) + ($21<<1)|0);
    $274 = ($46|0)==(0);
    if ($274) {
     $$0 = 0;
     label = 109;
     break;
    } else {
     $$014561550 = $273;$$in1569 = $46;
    }
   }
   if ((label|0) == 14) {
    // unreachable;
   }
   else if ((label|0) == 109) {
    return ($$0|0);
   }
   break;
  }
  case 2:  {
   $275 = ((($1)) + 8|0);
   $276 = HEAP32[$275>>2]|0;
   $277 = ((($1)) + 12|0);
   $278 = HEAP32[$277>>2]|0;
   $279 = ((($0)) + 16|0);
   $280 = HEAP32[$279>>2]|0;
   $281 = (($280|0) / ($13|0))&-1;
   $282 = (($281) - ($276))|0;
   $283 = ($278|0)==(0);
   if ($283) {
    $$0 = 0;
    return ($$0|0);
   }
   $284 = ((($0)) + 20|0);
   $285 = HEAP32[$284>>2]|0;
   $286 = ((($1)) + 4|0);
   $287 = HEAP32[$286>>2]|0;
   $288 = Math_imul($287, $281)|0;
   $289 = (($285) + ($288<<1)|0);
   $290 = HEAP32[$1>>2]|0;
   $291 = (($289) + ($290<<1)|0);
   $292 = (($276) + 3)|0;
   $293 = (($292|0) / 4)&-1;
   $trunc1539 = $276&255;
   $294 = ((($8)) + 28|0);
   $295 = ((($8)) + 12|0);
   $296 = ((($8)) + 32|0);
   $297 = ((($8)) + 29|0);
   $298 = ((($8)) + 16|0);
   $299 = ((($8)) + 33|0);
   $300 = ((($8)) + 30|0);
   $301 = ((($8)) + 20|0);
   $302 = ((($8)) + 34|0);
   $303 = $3&255;
   $304 = $4&255;
   $305 = $5&255;
   $306 = ((($8)) + 24|0);
   $$014661552 = $291;$$in1568 = $278;
   L52: while(1) {
    $307 = (($$in1568) + -1)|0;
    $trunc1539$clear = $trunc1539 & 3;
    switch ($trunc1539$clear<<24>>24) {
    case 0:  {
     $$pre1876 = HEAP8[$294>>0]|0;
     $$phi$trans$insert1877 = $$pre1876&255;
     $$phi$trans$insert1878 = (79212 + ($$phi$trans$insert1877<<2)|0);
     $$pre1879 = HEAP32[$$phi$trans$insert1878>>2]|0;
     $$pre1880 = HEAP32[$295>>2]|0;
     $$pre1881 = HEAP8[$296>>0]|0;
     $$pre1882 = HEAP8[$297>>0]|0;
     $$phi$trans$insert1883 = $$pre1882&255;
     $$phi$trans$insert1884 = (79212 + ($$phi$trans$insert1883<<2)|0);
     $$pre1885 = HEAP32[$$phi$trans$insert1884>>2]|0;
     $$pre1886 = HEAP32[$298>>2]|0;
     $$pre1887 = HEAP8[$299>>0]|0;
     $$pre1888 = HEAP8[$300>>0]|0;
     $$phi$trans$insert1889 = $$pre1888&255;
     $$phi$trans$insert1890 = (79212 + ($$phi$trans$insert1889<<2)|0);
     $$pre1891 = HEAP32[$$phi$trans$insert1890>>2]|0;
     $$pre1892 = HEAP32[$301>>2]|0;
     $$pre1893 = HEAP8[$302>>0]|0;
     $$pre1894 = HEAP32[$306>>2]|0;
     $$01471 = $293;$$11467 = $$014661552;$309 = $$pre1876;$313 = $$pre1880;$315 = $$pre1881;$318 = $$pre1879;$322 = $$pre1882;$324 = $$pre1886;$326 = $$pre1887;$329 = $$pre1885;$333 = $$pre1888;$335 = $$pre1892;$337 = $$pre1893;$340 = $$pre1891;$357 = $$pre1894;
     label = 23;
     break;
    }
    case 3:  {
     $$pre1896 = HEAP8[$294>>0]|0;
     $$phi$trans$insert1897 = $$pre1896&255;
     $$phi$trans$insert1898 = (79212 + ($$phi$trans$insert1897<<2)|0);
     $$pre1899 = HEAP32[$$phi$trans$insert1898>>2]|0;
     $$pre1900 = HEAP32[$295>>2]|0;
     $$pre1901 = HEAP8[$296>>0]|0;
     $$pre1902 = HEAP8[$297>>0]|0;
     $$phi$trans$insert1903 = $$pre1902&255;
     $$phi$trans$insert1904 = (79212 + ($$phi$trans$insert1903<<2)|0);
     $$pre1905 = HEAP32[$$phi$trans$insert1904>>2]|0;
     $$pre1906 = HEAP32[$298>>2]|0;
     $$pre1907 = HEAP8[$299>>0]|0;
     $$pre1908 = HEAP8[$300>>0]|0;
     $$phi$trans$insert1909 = $$pre1908&255;
     $$phi$trans$insert1910 = (79212 + ($$phi$trans$insert1909<<2)|0);
     $$pre1911 = HEAP32[$$phi$trans$insert1910>>2]|0;
     $$pre1912 = HEAP32[$301>>2]|0;
     $$pre1913 = HEAP8[$302>>0]|0;
     $$pre1914 = HEAP32[$306>>2]|0;
     $$11472 = $293;$$21468 = $$014661552;$362 = $$pre1896;$366 = $$pre1900;$368 = $$pre1901;$371 = $$pre1899;$375 = $$pre1902;$377 = $$pre1906;$379 = $$pre1907;$382 = $$pre1905;$386 = $$pre1908;$388 = $$pre1912;$390 = $$pre1913;$393 = $$pre1911;$410 = $$pre1914;
     label = 24;
     break;
    }
    case 2:  {
     $$pre1916 = HEAP8[$294>>0]|0;
     $$phi$trans$insert1917 = $$pre1916&255;
     $$phi$trans$insert1918 = (79212 + ($$phi$trans$insert1917<<2)|0);
     $$pre1919 = HEAP32[$$phi$trans$insert1918>>2]|0;
     $$pre1920 = HEAP32[$295>>2]|0;
     $$pre1921 = HEAP8[$296>>0]|0;
     $$pre1922 = HEAP8[$297>>0]|0;
     $$phi$trans$insert1923 = $$pre1922&255;
     $$phi$trans$insert1924 = (79212 + ($$phi$trans$insert1923<<2)|0);
     $$pre1925 = HEAP32[$$phi$trans$insert1924>>2]|0;
     $$pre1926 = HEAP32[$298>>2]|0;
     $$pre1927 = HEAP8[$299>>0]|0;
     $$pre1928 = HEAP8[$300>>0]|0;
     $$phi$trans$insert1929 = $$pre1928&255;
     $$phi$trans$insert1930 = (79212 + ($$phi$trans$insert1929<<2)|0);
     $$pre1931 = HEAP32[$$phi$trans$insert1930>>2]|0;
     $$pre1932 = HEAP32[$301>>2]|0;
     $$pre1933 = HEAP8[$302>>0]|0;
     $$pre1934 = HEAP32[$306>>2]|0;
     $$21473 = $293;$$31469 = $$014661552;$415 = $$pre1916;$419 = $$pre1920;$421 = $$pre1921;$424 = $$pre1919;$428 = $$pre1922;$430 = $$pre1926;$432 = $$pre1927;$435 = $$pre1925;$439 = $$pre1928;$441 = $$pre1932;$443 = $$pre1933;$446 = $$pre1931;$463 = $$pre1934;
     label = 25;
     break;
    }
    case 1:  {
     $$pre1936 = HEAP8[$294>>0]|0;
     $$phi$trans$insert1937 = $$pre1936&255;
     $$phi$trans$insert1938 = (79212 + ($$phi$trans$insert1937<<2)|0);
     $$pre1939 = HEAP32[$$phi$trans$insert1938>>2]|0;
     $$pre1940 = HEAP32[$295>>2]|0;
     $$pre1941 = HEAP8[$296>>0]|0;
     $$pre1942 = HEAP8[$297>>0]|0;
     $$phi$trans$insert1943 = $$pre1942&255;
     $$phi$trans$insert1944 = (79212 + ($$phi$trans$insert1943<<2)|0);
     $$pre1945 = HEAP32[$$phi$trans$insert1944>>2]|0;
     $$pre1946 = HEAP32[$298>>2]|0;
     $$pre1947 = HEAP8[$299>>0]|0;
     $$pre1948 = HEAP8[$300>>0]|0;
     $$phi$trans$insert1949 = $$pre1948&255;
     $$phi$trans$insert1950 = (79212 + ($$phi$trans$insert1949<<2)|0);
     $$pre1951 = HEAP32[$$phi$trans$insert1950>>2]|0;
     $$pre1952 = HEAP32[$301>>2]|0;
     $$pre1953 = HEAP8[$302>>0]|0;
     $$pre1954 = HEAP32[$306>>2]|0;
     $$31474 = $293;$$41470 = $$014661552;$468 = $$pre1936;$472 = $$pre1940;$474 = $$pre1941;$477 = $$pre1939;$481 = $$pre1942;$483 = $$pre1946;$485 = $$pre1947;$488 = $$pre1945;$492 = $$pre1948;$494 = $$pre1952;$496 = $$pre1953;$499 = $$pre1951;$516 = $$pre1954;
     label = 26;
     break;
    }
    default: {
     label = 27;
     break L52;
    }
    }
    while(1) {
     if ((label|0) == 23) {
      label = 0;
      $308 = $309&255;
      $310 = HEAP16[$$11467>>1]|0;
      $311 = $310&65535;
      $312 = $311 & $313;
      $314 = $315&255;
      $316 = $312 >>> $314;
      $317 = (($318) + ($316)|0);
      $319 = HEAP8[$317>>0]|0;
      $320 = $319&255;
      $321 = $322&255;
      $323 = $324 & $311;
      $325 = $326&255;
      $327 = $323 >>> $325;
      $328 = (($329) + ($327)|0);
      $330 = HEAP8[$328>>0]|0;
      $331 = $330&255;
      $332 = $333&255;
      $334 = $335 & $311;
      $336 = $337&255;
      $338 = $334 >>> $336;
      $339 = (($340) + ($338)|0);
      $341 = HEAP8[$339>>0]|0;
      $342 = $341&255;
      $343 = (($320) + ($303))|0;
      $344 = ($343>>>0)<(255);
      $$14 = $344 ? $343 : 255;
      $345 = (($331) + ($304))|0;
      $346 = ($345>>>0)<(255);
      $$ = $346 ? $345 : 255;
      $347 = (($342) + ($305))|0;
      $348 = ($347>>>0)<(255);
      $$22 = $348 ? $347 : 255;
      $349 = $$14 >>> $308;
      $350 = $349 << $314;
      $351 = $$ >>> $321;
      $352 = $351 << $325;
      $353 = $352 | $350;
      $354 = $$22 >>> $332;
      $355 = $354 << $336;
      $356 = $353 | $357;
      $358 = $356 | $355;
      $359 = $358&65535;
      HEAP16[$$11467>>1] = $359;
      $360 = ((($$11467)) + 2|0);
      $$11472 = $$01471;$$21468 = $360;$362 = $309;$366 = $313;$368 = $315;$371 = $318;$375 = $322;$377 = $324;$379 = $326;$382 = $329;$386 = $333;$388 = $335;$390 = $337;$393 = $340;$410 = $357;
      label = 24;
      continue;
     }
     else if ((label|0) == 24) {
      label = 0;
      $361 = $362&255;
      $363 = HEAP16[$$21468>>1]|0;
      $364 = $363&65535;
      $365 = $364 & $366;
      $367 = $368&255;
      $369 = $365 >>> $367;
      $370 = (($371) + ($369)|0);
      $372 = HEAP8[$370>>0]|0;
      $373 = $372&255;
      $374 = $375&255;
      $376 = $377 & $364;
      $378 = $379&255;
      $380 = $376 >>> $378;
      $381 = (($382) + ($380)|0);
      $383 = HEAP8[$381>>0]|0;
      $384 = $383&255;
      $385 = $386&255;
      $387 = $388 & $364;
      $389 = $390&255;
      $391 = $387 >>> $389;
      $392 = (($393) + ($391)|0);
      $394 = HEAP8[$392>>0]|0;
      $395 = $394&255;
      $396 = (($373) + ($303))|0;
      $397 = ($396>>>0)<(255);
      $$1 = $397 ? $396 : 255;
      $398 = (($384) + ($304))|0;
      $399 = ($398>>>0)<(255);
      $$15 = $399 ? $398 : 255;
      $400 = (($395) + ($305))|0;
      $401 = ($400>>>0)<(255);
      $$2 = $401 ? $400 : 255;
      $402 = $$1 >>> $361;
      $403 = $402 << $367;
      $404 = $$15 >>> $374;
      $405 = $404 << $378;
      $406 = $405 | $403;
      $407 = $$2 >>> $385;
      $408 = $407 << $389;
      $409 = $406 | $410;
      $411 = $409 | $408;
      $412 = $411&65535;
      HEAP16[$$21468>>1] = $412;
      $413 = ((($$21468)) + 2|0);
      $$21473 = $$11472;$$31469 = $413;$415 = $362;$419 = $366;$421 = $368;$424 = $371;$428 = $375;$430 = $377;$432 = $379;$435 = $382;$439 = $386;$441 = $388;$443 = $390;$446 = $393;$463 = $410;
      label = 25;
      continue;
     }
     else if ((label|0) == 25) {
      label = 0;
      $414 = $415&255;
      $416 = HEAP16[$$31469>>1]|0;
      $417 = $416&65535;
      $418 = $417 & $419;
      $420 = $421&255;
      $422 = $418 >>> $420;
      $423 = (($424) + ($422)|0);
      $425 = HEAP8[$423>>0]|0;
      $426 = $425&255;
      $427 = $428&255;
      $429 = $430 & $417;
      $431 = $432&255;
      $433 = $429 >>> $431;
      $434 = (($435) + ($433)|0);
      $436 = HEAP8[$434>>0]|0;
      $437 = $436&255;
      $438 = $439&255;
      $440 = $441 & $417;
      $442 = $443&255;
      $444 = $440 >>> $442;
      $445 = (($446) + ($444)|0);
      $447 = HEAP8[$445>>0]|0;
      $448 = $447&255;
      $449 = (($426) + ($303))|0;
      $450 = ($449>>>0)<(255);
      $$3 = $450 ? $449 : 255;
      $451 = (($437) + ($304))|0;
      $452 = ($451>>>0)<(255);
      $$16 = $452 ? $451 : 255;
      $453 = (($448) + ($305))|0;
      $454 = ($453>>>0)<(255);
      $$4 = $454 ? $453 : 255;
      $455 = $$3 >>> $414;
      $456 = $455 << $420;
      $457 = $$16 >>> $427;
      $458 = $457 << $431;
      $459 = $458 | $456;
      $460 = $$4 >>> $438;
      $461 = $460 << $442;
      $462 = $459 | $463;
      $464 = $462 | $461;
      $465 = $464&65535;
      HEAP16[$$31469>>1] = $465;
      $466 = ((($$31469)) + 2|0);
      $$31474 = $$21473;$$41470 = $466;$468 = $415;$472 = $419;$474 = $421;$477 = $424;$481 = $428;$483 = $430;$485 = $432;$488 = $435;$492 = $439;$494 = $441;$496 = $443;$499 = $446;$516 = $463;
      label = 26;
      continue;
     }
     else if ((label|0) == 26) {
      label = 0;
      $467 = $468&255;
      $469 = HEAP16[$$41470>>1]|0;
      $470 = $469&65535;
      $471 = $470 & $472;
      $473 = $474&255;
      $475 = $471 >>> $473;
      $476 = (($477) + ($475)|0);
      $478 = HEAP8[$476>>0]|0;
      $479 = $478&255;
      $480 = $481&255;
      $482 = $483 & $470;
      $484 = $485&255;
      $486 = $482 >>> $484;
      $487 = (($488) + ($486)|0);
      $489 = HEAP8[$487>>0]|0;
      $490 = $489&255;
      $491 = $492&255;
      $493 = $494 & $470;
      $495 = $496&255;
      $497 = $493 >>> $495;
      $498 = (($499) + ($497)|0);
      $500 = HEAP8[$498>>0]|0;
      $501 = $500&255;
      $502 = (($479) + ($303))|0;
      $503 = ($502>>>0)<(255);
      $$5 = $503 ? $502 : 255;
      $504 = (($490) + ($304))|0;
      $505 = ($504>>>0)<(255);
      $$17 = $505 ? $504 : 255;
      $506 = (($501) + ($305))|0;
      $507 = ($506>>>0)<(255);
      $$6 = $507 ? $506 : 255;
      $508 = $$5 >>> $467;
      $509 = $508 << $473;
      $510 = $$17 >>> $480;
      $511 = $510 << $484;
      $512 = $511 | $509;
      $513 = $$6 >>> $491;
      $514 = $513 << $495;
      $515 = $512 | $516;
      $517 = $515 | $514;
      $518 = $517&65535;
      HEAP16[$$41470>>1] = $518;
      $519 = ((($$41470)) + 2|0);
      $520 = (($$31474) + -1)|0;
      $521 = ($$31474|0)>(1);
      if ($521) {
       $$01471 = $520;$$11467 = $519;$309 = $468;$313 = $472;$315 = $474;$318 = $477;$322 = $481;$324 = $483;$326 = $485;$329 = $488;$333 = $492;$335 = $494;$337 = $496;$340 = $499;$357 = $516;
       label = 23;
       continue;
      } else {
       break;
      }
     }
    }
    $522 = (($519) + ($282<<1)|0);
    $523 = ($307|0)==(0);
    if ($523) {
     $$0 = 0;
     label = 109;
     break;
    } else {
     $$014661552 = $522;$$in1568 = $307;
    }
   }
   if ((label|0) == 27) {
    // unreachable;
   }
   else if ((label|0) == 109) {
    return ($$0|0);
   }
   break;
  }
  case 4:  {
   $524 = ((($1)) + 8|0);
   $525 = HEAP32[$524>>2]|0;
   $526 = ((($1)) + 12|0);
   $527 = HEAP32[$526>>2]|0;
   $528 = ((($0)) + 16|0);
   $529 = HEAP32[$528>>2]|0;
   $530 = (($529|0) / ($13|0))&-1;
   $531 = (($530) - ($525))|0;
   $532 = ($527|0)==(0);
   if ($532) {
    $$0 = 0;
    return ($$0|0);
   }
   $533 = ((($0)) + 20|0);
   $534 = HEAP32[$533>>2]|0;
   $535 = ((($1)) + 4|0);
   $536 = HEAP32[$535>>2]|0;
   $537 = Math_imul($536, $530)|0;
   $538 = (($534) + ($537<<1)|0);
   $539 = HEAP32[$1>>2]|0;
   $540 = (($538) + ($539<<1)|0);
   $541 = (($525) + 3)|0;
   $542 = (($541|0) / 4)&-1;
   $trunc1538 = $525&255;
   $543 = ((($8)) + 28|0);
   $544 = ((($8)) + 12|0);
   $545 = ((($8)) + 32|0);
   $546 = ((($8)) + 29|0);
   $547 = ((($8)) + 16|0);
   $548 = ((($8)) + 33|0);
   $549 = ((($8)) + 30|0);
   $550 = ((($8)) + 20|0);
   $551 = ((($8)) + 34|0);
   $552 = $3&255;
   $553 = $4&255;
   $554 = $5&255;
   $555 = ((($8)) + 24|0);
   $$014761554 = $540;$$in1567 = $527;
   L73: while(1) {
    $556 = (($$in1567) + -1)|0;
    $trunc1538$clear = $trunc1538 & 3;
    switch ($trunc1538$clear<<24>>24) {
    case 0:  {
     $$pre1796 = HEAP8[$543>>0]|0;
     $$phi$trans$insert1797 = $$pre1796&255;
     $$phi$trans$insert1798 = (79212 + ($$phi$trans$insert1797<<2)|0);
     $$pre1799 = HEAP32[$$phi$trans$insert1798>>2]|0;
     $$pre1800 = HEAP32[$544>>2]|0;
     $$pre1801 = HEAP8[$545>>0]|0;
     $$pre1802 = HEAP8[$546>>0]|0;
     $$phi$trans$insert1803 = $$pre1802&255;
     $$phi$trans$insert1804 = (79212 + ($$phi$trans$insert1803<<2)|0);
     $$pre1805 = HEAP32[$$phi$trans$insert1804>>2]|0;
     $$pre1806 = HEAP32[$547>>2]|0;
     $$pre1807 = HEAP8[$548>>0]|0;
     $$pre1808 = HEAP8[$549>>0]|0;
     $$phi$trans$insert1809 = $$pre1808&255;
     $$phi$trans$insert1810 = (79212 + ($$phi$trans$insert1809<<2)|0);
     $$pre1811 = HEAP32[$$phi$trans$insert1810>>2]|0;
     $$pre1812 = HEAP32[$550>>2]|0;
     $$pre1813 = HEAP8[$551>>0]|0;
     $$pre1814 = HEAP32[$555>>2]|0;
     $$01481 = $542;$$11477 = $$014761554;$558 = $$pre1796;$562 = $$pre1800;$564 = $$pre1801;$567 = $$pre1799;$571 = $$pre1802;$573 = $$pre1806;$575 = $$pre1807;$578 = $$pre1805;$582 = $$pre1808;$584 = $$pre1812;$586 = $$pre1813;$589 = $$pre1811;$606 = $$pre1814;
     label = 36;
     break;
    }
    case 3:  {
     $$pre1816 = HEAP8[$543>>0]|0;
     $$phi$trans$insert1817 = $$pre1816&255;
     $$phi$trans$insert1818 = (79212 + ($$phi$trans$insert1817<<2)|0);
     $$pre1819 = HEAP32[$$phi$trans$insert1818>>2]|0;
     $$pre1820 = HEAP32[$544>>2]|0;
     $$pre1821 = HEAP8[$545>>0]|0;
     $$pre1822 = HEAP8[$546>>0]|0;
     $$phi$trans$insert1823 = $$pre1822&255;
     $$phi$trans$insert1824 = (79212 + ($$phi$trans$insert1823<<2)|0);
     $$pre1825 = HEAP32[$$phi$trans$insert1824>>2]|0;
     $$pre1826 = HEAP32[$547>>2]|0;
     $$pre1827 = HEAP8[$548>>0]|0;
     $$pre1828 = HEAP8[$549>>0]|0;
     $$phi$trans$insert1829 = $$pre1828&255;
     $$phi$trans$insert1830 = (79212 + ($$phi$trans$insert1829<<2)|0);
     $$pre1831 = HEAP32[$$phi$trans$insert1830>>2]|0;
     $$pre1832 = HEAP32[$550>>2]|0;
     $$pre1833 = HEAP8[$551>>0]|0;
     $$pre1834 = HEAP32[$555>>2]|0;
     $$11482 = $542;$$21478 = $$014761554;$611 = $$pre1816;$615 = $$pre1820;$617 = $$pre1821;$620 = $$pre1819;$624 = $$pre1822;$626 = $$pre1826;$628 = $$pre1827;$631 = $$pre1825;$635 = $$pre1828;$637 = $$pre1832;$639 = $$pre1833;$642 = $$pre1831;$659 = $$pre1834;
     label = 37;
     break;
    }
    case 2:  {
     $$pre1836 = HEAP8[$543>>0]|0;
     $$phi$trans$insert1837 = $$pre1836&255;
     $$phi$trans$insert1838 = (79212 + ($$phi$trans$insert1837<<2)|0);
     $$pre1839 = HEAP32[$$phi$trans$insert1838>>2]|0;
     $$pre1840 = HEAP32[$544>>2]|0;
     $$pre1841 = HEAP8[$545>>0]|0;
     $$pre1842 = HEAP8[$546>>0]|0;
     $$phi$trans$insert1843 = $$pre1842&255;
     $$phi$trans$insert1844 = (79212 + ($$phi$trans$insert1843<<2)|0);
     $$pre1845 = HEAP32[$$phi$trans$insert1844>>2]|0;
     $$pre1846 = HEAP32[$547>>2]|0;
     $$pre1847 = HEAP8[$548>>0]|0;
     $$pre1848 = HEAP8[$549>>0]|0;
     $$phi$trans$insert1849 = $$pre1848&255;
     $$phi$trans$insert1850 = (79212 + ($$phi$trans$insert1849<<2)|0);
     $$pre1851 = HEAP32[$$phi$trans$insert1850>>2]|0;
     $$pre1852 = HEAP32[$550>>2]|0;
     $$pre1853 = HEAP8[$551>>0]|0;
     $$pre1854 = HEAP32[$555>>2]|0;
     $$21483 = $542;$$31479 = $$014761554;$664 = $$pre1836;$668 = $$pre1840;$670 = $$pre1841;$673 = $$pre1839;$677 = $$pre1842;$679 = $$pre1846;$681 = $$pre1847;$684 = $$pre1845;$688 = $$pre1848;$690 = $$pre1852;$692 = $$pre1853;$695 = $$pre1851;$712 = $$pre1854;
     label = 38;
     break;
    }
    case 1:  {
     $$pre1856 = HEAP8[$543>>0]|0;
     $$phi$trans$insert1857 = $$pre1856&255;
     $$phi$trans$insert1858 = (79212 + ($$phi$trans$insert1857<<2)|0);
     $$pre1859 = HEAP32[$$phi$trans$insert1858>>2]|0;
     $$pre1860 = HEAP32[$544>>2]|0;
     $$pre1861 = HEAP8[$545>>0]|0;
     $$pre1862 = HEAP8[$546>>0]|0;
     $$phi$trans$insert1863 = $$pre1862&255;
     $$phi$trans$insert1864 = (79212 + ($$phi$trans$insert1863<<2)|0);
     $$pre1865 = HEAP32[$$phi$trans$insert1864>>2]|0;
     $$pre1866 = HEAP32[$547>>2]|0;
     $$pre1867 = HEAP8[$548>>0]|0;
     $$pre1868 = HEAP8[$549>>0]|0;
     $$phi$trans$insert1869 = $$pre1868&255;
     $$phi$trans$insert1870 = (79212 + ($$phi$trans$insert1869<<2)|0);
     $$pre1871 = HEAP32[$$phi$trans$insert1870>>2]|0;
     $$pre1872 = HEAP32[$550>>2]|0;
     $$pre1873 = HEAP8[$551>>0]|0;
     $$pre1874 = HEAP32[$555>>2]|0;
     $$31484 = $542;$$41480 = $$014761554;$717 = $$pre1856;$721 = $$pre1860;$723 = $$pre1861;$726 = $$pre1859;$730 = $$pre1862;$732 = $$pre1866;$734 = $$pre1867;$737 = $$pre1865;$741 = $$pre1868;$743 = $$pre1872;$745 = $$pre1873;$748 = $$pre1871;$765 = $$pre1874;
     label = 39;
     break;
    }
    default: {
     label = 40;
     break L73;
    }
    }
    while(1) {
     if ((label|0) == 36) {
      label = 0;
      $557 = $558&255;
      $559 = HEAP16[$$11477>>1]|0;
      $560 = $559&65535;
      $561 = $560 & $562;
      $563 = $564&255;
      $565 = $561 >>> $563;
      $566 = (($567) + ($565)|0);
      $568 = HEAP8[$566>>0]|0;
      $569 = $568&255;
      $570 = $571&255;
      $572 = $573 & $560;
      $574 = $575&255;
      $576 = $572 >>> $574;
      $577 = (($578) + ($576)|0);
      $579 = HEAP8[$577>>0]|0;
      $580 = $579&255;
      $581 = $582&255;
      $583 = $584 & $560;
      $585 = $586&255;
      $587 = $583 >>> $585;
      $588 = (($589) + ($587)|0);
      $590 = HEAP8[$588>>0]|0;
      $591 = $590&255;
      $592 = Math_imul($569, $552)|0;
      $593 = (($592>>>0) / 255)&-1;
      $594 = Math_imul($580, $553)|0;
      $595 = (($594>>>0) / 255)&-1;
      $596 = Math_imul($591, $554)|0;
      $597 = (($596>>>0) / 255)&-1;
      $598 = $593 >>> $557;
      $599 = $598 << $563;
      $600 = $595 >>> $570;
      $601 = $600 << $574;
      $602 = $601 | $599;
      $603 = $597 >>> $581;
      $604 = $603 << $585;
      $605 = $602 | $606;
      $607 = $605 | $604;
      $608 = $607&65535;
      HEAP16[$$11477>>1] = $608;
      $609 = ((($$11477)) + 2|0);
      $$11482 = $$01481;$$21478 = $609;$611 = $558;$615 = $562;$617 = $564;$620 = $567;$624 = $571;$626 = $573;$628 = $575;$631 = $578;$635 = $582;$637 = $584;$639 = $586;$642 = $589;$659 = $606;
      label = 37;
      continue;
     }
     else if ((label|0) == 37) {
      label = 0;
      $610 = $611&255;
      $612 = HEAP16[$$21478>>1]|0;
      $613 = $612&65535;
      $614 = $613 & $615;
      $616 = $617&255;
      $618 = $614 >>> $616;
      $619 = (($620) + ($618)|0);
      $621 = HEAP8[$619>>0]|0;
      $622 = $621&255;
      $623 = $624&255;
      $625 = $626 & $613;
      $627 = $628&255;
      $629 = $625 >>> $627;
      $630 = (($631) + ($629)|0);
      $632 = HEAP8[$630>>0]|0;
      $633 = $632&255;
      $634 = $635&255;
      $636 = $637 & $613;
      $638 = $639&255;
      $640 = $636 >>> $638;
      $641 = (($642) + ($640)|0);
      $643 = HEAP8[$641>>0]|0;
      $644 = $643&255;
      $645 = Math_imul($622, $552)|0;
      $646 = (($645>>>0) / 255)&-1;
      $647 = Math_imul($633, $553)|0;
      $648 = (($647>>>0) / 255)&-1;
      $649 = Math_imul($644, $554)|0;
      $650 = (($649>>>0) / 255)&-1;
      $651 = $646 >>> $610;
      $652 = $651 << $616;
      $653 = $648 >>> $623;
      $654 = $653 << $627;
      $655 = $654 | $652;
      $656 = $650 >>> $634;
      $657 = $656 << $638;
      $658 = $655 | $659;
      $660 = $658 | $657;
      $661 = $660&65535;
      HEAP16[$$21478>>1] = $661;
      $662 = ((($$21478)) + 2|0);
      $$21483 = $$11482;$$31479 = $662;$664 = $611;$668 = $615;$670 = $617;$673 = $620;$677 = $624;$679 = $626;$681 = $628;$684 = $631;$688 = $635;$690 = $637;$692 = $639;$695 = $642;$712 = $659;
      label = 38;
      continue;
     }
     else if ((label|0) == 38) {
      label = 0;
      $663 = $664&255;
      $665 = HEAP16[$$31479>>1]|0;
      $666 = $665&65535;
      $667 = $666 & $668;
      $669 = $670&255;
      $671 = $667 >>> $669;
      $672 = (($673) + ($671)|0);
      $674 = HEAP8[$672>>0]|0;
      $675 = $674&255;
      $676 = $677&255;
      $678 = $679 & $666;
      $680 = $681&255;
      $682 = $678 >>> $680;
      $683 = (($684) + ($682)|0);
      $685 = HEAP8[$683>>0]|0;
      $686 = $685&255;
      $687 = $688&255;
      $689 = $690 & $666;
      $691 = $692&255;
      $693 = $689 >>> $691;
      $694 = (($695) + ($693)|0);
      $696 = HEAP8[$694>>0]|0;
      $697 = $696&255;
      $698 = Math_imul($675, $552)|0;
      $699 = (($698>>>0) / 255)&-1;
      $700 = Math_imul($686, $553)|0;
      $701 = (($700>>>0) / 255)&-1;
      $702 = Math_imul($697, $554)|0;
      $703 = (($702>>>0) / 255)&-1;
      $704 = $699 >>> $663;
      $705 = $704 << $669;
      $706 = $701 >>> $676;
      $707 = $706 << $680;
      $708 = $707 | $705;
      $709 = $703 >>> $687;
      $710 = $709 << $691;
      $711 = $708 | $712;
      $713 = $711 | $710;
      $714 = $713&65535;
      HEAP16[$$31479>>1] = $714;
      $715 = ((($$31479)) + 2|0);
      $$31484 = $$21483;$$41480 = $715;$717 = $664;$721 = $668;$723 = $670;$726 = $673;$730 = $677;$732 = $679;$734 = $681;$737 = $684;$741 = $688;$743 = $690;$745 = $692;$748 = $695;$765 = $712;
      label = 39;
      continue;
     }
     else if ((label|0) == 39) {
      label = 0;
      $716 = $717&255;
      $718 = HEAP16[$$41480>>1]|0;
      $719 = $718&65535;
      $720 = $719 & $721;
      $722 = $723&255;
      $724 = $720 >>> $722;
      $725 = (($726) + ($724)|0);
      $727 = HEAP8[$725>>0]|0;
      $728 = $727&255;
      $729 = $730&255;
      $731 = $732 & $719;
      $733 = $734&255;
      $735 = $731 >>> $733;
      $736 = (($737) + ($735)|0);
      $738 = HEAP8[$736>>0]|0;
      $739 = $738&255;
      $740 = $741&255;
      $742 = $743 & $719;
      $744 = $745&255;
      $746 = $742 >>> $744;
      $747 = (($748) + ($746)|0);
      $749 = HEAP8[$747>>0]|0;
      $750 = $749&255;
      $751 = Math_imul($728, $552)|0;
      $752 = (($751>>>0) / 255)&-1;
      $753 = Math_imul($739, $553)|0;
      $754 = (($753>>>0) / 255)&-1;
      $755 = Math_imul($750, $554)|0;
      $756 = (($755>>>0) / 255)&-1;
      $757 = $752 >>> $716;
      $758 = $757 << $722;
      $759 = $754 >>> $729;
      $760 = $759 << $733;
      $761 = $760 | $758;
      $762 = $756 >>> $740;
      $763 = $762 << $744;
      $764 = $761 | $765;
      $766 = $764 | $763;
      $767 = $766&65535;
      HEAP16[$$41480>>1] = $767;
      $768 = ((($$41480)) + 2|0);
      $769 = (($$31484) + -1)|0;
      $770 = ($$31484|0)>(1);
      if ($770) {
       $$01481 = $769;$$11477 = $768;$558 = $717;$562 = $721;$564 = $723;$567 = $726;$571 = $730;$573 = $732;$575 = $734;$578 = $737;$582 = $741;$584 = $743;$586 = $745;$589 = $748;$606 = $765;
       label = 36;
       continue;
      } else {
       break;
      }
     }
    }
    $771 = (($768) + ($531<<1)|0);
    $772 = ($556|0)==(0);
    if ($772) {
     $$0 = 0;
     label = 109;
     break;
    } else {
     $$014761554 = $771;$$in1567 = $556;
    }
   }
   if ((label|0) == 40) {
    // unreachable;
   }
   else if ((label|0) == 109) {
    return ($$0|0);
   }
   break;
  }
  default: {
   $773 = ((($1)) + 8|0);
   $774 = HEAP32[$773>>2]|0;
   $775 = ((($1)) + 12|0);
   $776 = HEAP32[$775>>2]|0;
   $777 = ((($0)) + 16|0);
   $778 = HEAP32[$777>>2]|0;
   $779 = (($778|0) / ($13|0))&-1;
   $780 = (($779) - ($774))|0;
   $781 = ($776|0)==(0);
   if ($781) {
    $$0 = 0;
    return ($$0|0);
   }
   $782 = ((($0)) + 20|0);
   $783 = HEAP32[$782>>2]|0;
   $784 = ((($1)) + 4|0);
   $785 = HEAP32[$784>>2]|0;
   $786 = Math_imul($785, $779)|0;
   $787 = (($783) + ($786<<1)|0);
   $788 = HEAP32[$1>>2]|0;
   $789 = (($787) + ($788<<1)|0);
   $790 = (($774) + 3)|0;
   $791 = (($790|0) / 4)&-1;
   $trunc1541 = $774&255;
   $792 = $3&255;
   $793 = $4&255;
   $794 = $5&255;
   $795 = ((($8)) + 28|0);
   $796 = ((($8)) + 32|0);
   $797 = ((($8)) + 29|0);
   $798 = ((($8)) + 33|0);
   $799 = ((($8)) + 30|0);
   $800 = ((($8)) + 34|0);
   $801 = ((($8)) + 24|0);
   $$014861549 = $789;$$in1570 = $776;
   L10: while(1) {
    $802 = (($$in1570) + -1)|0;
    $trunc1541$clear = $trunc1541 & 3;
    switch ($trunc1541$clear<<24>>24) {
    case 0:  {
     $$pre2036 = HEAP8[$795>>0]|0;
     $$pre2037 = HEAP8[$796>>0]|0;
     $$pre2038 = HEAP8[$797>>0]|0;
     $$pre2039 = HEAP8[$798>>0]|0;
     $$pre2040 = HEAP8[$799>>0]|0;
     $$pre2041 = HEAP8[$800>>0]|0;
     $$pre2042 = HEAP32[$801>>2]|0;
     $$01491 = $791;$$11487 = $$014861549;$804 = $$pre2036;$807 = $$pre2037;$810 = $$pre2038;$813 = $$pre2039;$817 = $$pre2040;$820 = $$pre2041;$823 = $$pre2042;
     label = 49;
     break;
    }
    case 3:  {
     $$pre2044 = HEAP8[$795>>0]|0;
     $$pre2045 = HEAP8[$796>>0]|0;
     $$pre2046 = HEAP8[$797>>0]|0;
     $$pre2047 = HEAP8[$798>>0]|0;
     $$pre2048 = HEAP8[$799>>0]|0;
     $$pre2049 = HEAP8[$800>>0]|0;
     $$pre2050 = HEAP32[$801>>2]|0;
     $$11492 = $791;$$21488 = $$014861549;$828 = $$pre2044;$831 = $$pre2045;$834 = $$pre2046;$837 = $$pre2047;$841 = $$pre2048;$844 = $$pre2049;$847 = $$pre2050;
     label = 50;
     break;
    }
    case 2:  {
     $$pre2052 = HEAP8[$795>>0]|0;
     $$pre2053 = HEAP8[$796>>0]|0;
     $$pre2054 = HEAP8[$797>>0]|0;
     $$pre2055 = HEAP8[$798>>0]|0;
     $$pre2056 = HEAP8[$799>>0]|0;
     $$pre2057 = HEAP8[$800>>0]|0;
     $$pre2058 = HEAP32[$801>>2]|0;
     $$21493 = $791;$$31489 = $$014861549;$852 = $$pre2052;$855 = $$pre2053;$858 = $$pre2054;$861 = $$pre2055;$865 = $$pre2056;$868 = $$pre2057;$871 = $$pre2058;
     label = 51;
     break;
    }
    case 1:  {
     $$pre2060 = HEAP8[$795>>0]|0;
     $$pre2061 = HEAP8[$796>>0]|0;
     $$pre2062 = HEAP8[$797>>0]|0;
     $$pre2063 = HEAP8[$798>>0]|0;
     $$pre2064 = HEAP8[$799>>0]|0;
     $$pre2065 = HEAP8[$800>>0]|0;
     $$pre2066 = HEAP32[$801>>2]|0;
     $$31494 = $791;$$41490 = $$014861549;$876 = $$pre2060;$879 = $$pre2061;$882 = $$pre2062;$885 = $$pre2063;$889 = $$pre2064;$892 = $$pre2065;$895 = $$pre2066;
     label = 52;
     break;
    }
    default: {
     label = 53;
     break L10;
    }
    }
    while(1) {
     if ((label|0) == 49) {
      label = 0;
      $803 = $804&255;
      $805 = $792 >>> $803;
      $806 = $807&255;
      $808 = $805 << $806;
      $809 = $810&255;
      $811 = $793 >>> $809;
      $812 = $813&255;
      $814 = $811 << $812;
      $815 = $814 | $808;
      $816 = $817&255;
      $818 = $794 >>> $816;
      $819 = $820&255;
      $821 = $818 << $819;
      $822 = $815 | $823;
      $824 = $822 | $821;
      $825 = $824&65535;
      HEAP16[$$11487>>1] = $825;
      $826 = ((($$11487)) + 2|0);
      $$11492 = $$01491;$$21488 = $826;$828 = $804;$831 = $807;$834 = $810;$837 = $813;$841 = $817;$844 = $820;$847 = $823;
      label = 50;
      continue;
     }
     else if ((label|0) == 50) {
      label = 0;
      $827 = $828&255;
      $829 = $792 >>> $827;
      $830 = $831&255;
      $832 = $829 << $830;
      $833 = $834&255;
      $835 = $793 >>> $833;
      $836 = $837&255;
      $838 = $835 << $836;
      $839 = $838 | $832;
      $840 = $841&255;
      $842 = $794 >>> $840;
      $843 = $844&255;
      $845 = $842 << $843;
      $846 = $839 | $847;
      $848 = $846 | $845;
      $849 = $848&65535;
      HEAP16[$$21488>>1] = $849;
      $850 = ((($$21488)) + 2|0);
      $$21493 = $$11492;$$31489 = $850;$852 = $828;$855 = $831;$858 = $834;$861 = $837;$865 = $841;$868 = $844;$871 = $847;
      label = 51;
      continue;
     }
     else if ((label|0) == 51) {
      label = 0;
      $851 = $852&255;
      $853 = $792 >>> $851;
      $854 = $855&255;
      $856 = $853 << $854;
      $857 = $858&255;
      $859 = $793 >>> $857;
      $860 = $861&255;
      $862 = $859 << $860;
      $863 = $862 | $856;
      $864 = $865&255;
      $866 = $794 >>> $864;
      $867 = $868&255;
      $869 = $866 << $867;
      $870 = $863 | $871;
      $872 = $870 | $869;
      $873 = $872&65535;
      HEAP16[$$31489>>1] = $873;
      $874 = ((($$31489)) + 2|0);
      $$31494 = $$21493;$$41490 = $874;$876 = $852;$879 = $855;$882 = $858;$885 = $861;$889 = $865;$892 = $868;$895 = $871;
      label = 52;
      continue;
     }
     else if ((label|0) == 52) {
      label = 0;
      $875 = $876&255;
      $877 = $792 >>> $875;
      $878 = $879&255;
      $880 = $877 << $878;
      $881 = $882&255;
      $883 = $793 >>> $881;
      $884 = $885&255;
      $886 = $883 << $884;
      $887 = $886 | $880;
      $888 = $889&255;
      $890 = $794 >>> $888;
      $891 = $892&255;
      $893 = $890 << $891;
      $894 = $887 | $895;
      $896 = $894 | $893;
      $897 = $896&65535;
      HEAP16[$$41490>>1] = $897;
      $898 = ((($$41490)) + 2|0);
      $899 = (($$31494) + -1)|0;
      $900 = ($$31494|0)>(1);
      if ($900) {
       $$01491 = $899;$$11487 = $898;$804 = $876;$807 = $879;$810 = $882;$813 = $885;$817 = $889;$820 = $892;$823 = $895;
       label = 49;
       continue;
      } else {
       break;
      }
     }
    }
    $901 = (($898) + ($780<<1)|0);
    $902 = ($802|0)==(0);
    if ($902) {
     $$0 = 0;
     label = 109;
     break;
    } else {
     $$014861549 = $901;$$in1570 = $802;
    }
   }
   if ((label|0) == 53) {
    // unreachable;
   }
   else if ((label|0) == 109) {
    return ($$0|0);
   }
  }
  }
  break;
 }
 case 4:  {
  switch ($2|0) {
  case 1:  {
   $903 = ((($1)) + 8|0);
   $904 = HEAP32[$903>>2]|0;
   $905 = ((($1)) + 12|0);
   $906 = HEAP32[$905>>2]|0;
   $907 = ((($0)) + 16|0);
   $908 = HEAP32[$907>>2]|0;
   $909 = (($908|0) / ($13|0))&-1;
   $910 = (($909) - ($904))|0;
   $911 = ($906|0)==(0);
   if ($911) {
    $$0 = 0;
    return ($$0|0);
   }
   $912 = ((($0)) + 20|0);
   $913 = HEAP32[$912>>2]|0;
   $914 = ((($1)) + 4|0);
   $915 = HEAP32[$914>>2]|0;
   $916 = Math_imul($915, $909)|0;
   $917 = (($913) + ($916<<2)|0);
   $918 = HEAP32[$1>>2]|0;
   $919 = (($917) + ($918<<2)|0);
   $920 = (($904) + 3)|0;
   $921 = (($920|0) / 4)&-1;
   $trunc1536 = $904&255;
   $922 = ((($8)) + 28|0);
   $923 = ((($8)) + 12|0);
   $924 = ((($8)) + 32|0);
   $925 = ((($8)) + 29|0);
   $926 = ((($8)) + 16|0);
   $927 = ((($8)) + 33|0);
   $928 = ((($8)) + 30|0);
   $929 = ((($8)) + 20|0);
   $930 = ((($8)) + 34|0);
   $931 = $3&255;
   $932 = $4&255;
   $933 = $5&255;
   $934 = ((($8)) + 24|0);
   $$014961558 = $919;$$in1565 = $906;
   L117: while(1) {
    $935 = (($$in1565) + -1)|0;
    $trunc1536$clear = $trunc1536 & 3;
    switch ($trunc1536$clear<<24>>24) {
    case 0:  {
     $$pre1704 = HEAP8[$922>>0]|0;
     $$phi$trans$insert1705 = $$pre1704&255;
     $$phi$trans$insert1706 = (79212 + ($$phi$trans$insert1705<<2)|0);
     $$pre1707 = HEAP32[$$phi$trans$insert1706>>2]|0;
     $$pre1708 = HEAP8[$924>>0]|0;
     $$pre1709 = HEAP8[$925>>0]|0;
     $$phi$trans$insert1710 = $$pre1709&255;
     $$phi$trans$insert1711 = (79212 + ($$phi$trans$insert1710<<2)|0);
     $$pre1712 = HEAP32[$$phi$trans$insert1711>>2]|0;
     $$pre1713 = HEAP8[$927>>0]|0;
     $$pre1714 = HEAP8[$928>>0]|0;
     $$phi$trans$insert1715 = $$pre1714&255;
     $$phi$trans$insert1716 = (79212 + ($$phi$trans$insert1715<<2)|0);
     $$pre1717 = HEAP32[$$phi$trans$insert1716>>2]|0;
     $$pre1718 = HEAP8[$930>>0]|0;
     $$01510 = $921;$$11497 = $$014961558;$937 = $$pre1704;$942 = $$pre1708;$945 = $$pre1707;$949 = $$pre1709;$953 = $$pre1713;$956 = $$pre1712;$960 = $$pre1714;$964 = $$pre1718;$967 = $$pre1717;
     label = 63;
     break;
    }
    case 3:  {
     $$pre1720 = HEAP8[$922>>0]|0;
     $$phi$trans$insert1721 = $$pre1720&255;
     $$phi$trans$insert1722 = (79212 + ($$phi$trans$insert1721<<2)|0);
     $$pre1723 = HEAP32[$$phi$trans$insert1722>>2]|0;
     $$pre1724 = HEAP8[$924>>0]|0;
     $$pre1725 = HEAP8[$925>>0]|0;
     $$phi$trans$insert1726 = $$pre1725&255;
     $$phi$trans$insert1727 = (79212 + ($$phi$trans$insert1726<<2)|0);
     $$pre1728 = HEAP32[$$phi$trans$insert1727>>2]|0;
     $$pre1729 = HEAP8[$927>>0]|0;
     $$pre1730 = HEAP8[$928>>0]|0;
     $$phi$trans$insert1731 = $$pre1730&255;
     $$phi$trans$insert1732 = (79212 + ($$phi$trans$insert1731<<2)|0);
     $$pre1733 = HEAP32[$$phi$trans$insert1732>>2]|0;
     $$pre1734 = HEAP8[$930>>0]|0;
     $$11511 = $921;$$21498 = $$014961558;$1003 = $$pre1725;$1007 = $$pre1729;$1010 = $$pre1728;$1014 = $$pre1730;$1018 = $$pre1734;$1021 = $$pre1733;$991 = $$pre1720;$996 = $$pre1724;$999 = $$pre1723;
     label = 64;
     break;
    }
    case 2:  {
     $$pre1736 = HEAP8[$922>>0]|0;
     $$phi$trans$insert1737 = $$pre1736&255;
     $$phi$trans$insert1738 = (79212 + ($$phi$trans$insert1737<<2)|0);
     $$pre1739 = HEAP32[$$phi$trans$insert1738>>2]|0;
     $$pre1740 = HEAP8[$924>>0]|0;
     $$pre1741 = HEAP8[$925>>0]|0;
     $$phi$trans$insert1742 = $$pre1741&255;
     $$phi$trans$insert1743 = (79212 + ($$phi$trans$insert1742<<2)|0);
     $$pre1744 = HEAP32[$$phi$trans$insert1743>>2]|0;
     $$pre1745 = HEAP8[$927>>0]|0;
     $$pre1746 = HEAP8[$928>>0]|0;
     $$phi$trans$insert1747 = $$pre1746&255;
     $$phi$trans$insert1748 = (79212 + ($$phi$trans$insert1747<<2)|0);
     $$pre1749 = HEAP32[$$phi$trans$insert1748>>2]|0;
     $$pre1750 = HEAP8[$930>>0]|0;
     $$21512 = $921;$$31499 = $$014961558;$1045 = $$pre1736;$1050 = $$pre1740;$1053 = $$pre1739;$1057 = $$pre1741;$1061 = $$pre1745;$1064 = $$pre1744;$1068 = $$pre1746;$1072 = $$pre1750;$1075 = $$pre1749;
     label = 65;
     break;
    }
    case 1:  {
     $$pre1752 = HEAP8[$922>>0]|0;
     $$phi$trans$insert1753 = $$pre1752&255;
     $$phi$trans$insert1754 = (79212 + ($$phi$trans$insert1753<<2)|0);
     $$pre1755 = HEAP32[$$phi$trans$insert1754>>2]|0;
     $$pre1756 = HEAP8[$924>>0]|0;
     $$pre1757 = HEAP8[$925>>0]|0;
     $$phi$trans$insert1758 = $$pre1757&255;
     $$phi$trans$insert1759 = (79212 + ($$phi$trans$insert1758<<2)|0);
     $$pre1760 = HEAP32[$$phi$trans$insert1759>>2]|0;
     $$pre1761 = HEAP8[$927>>0]|0;
     $$pre1762 = HEAP8[$928>>0]|0;
     $$phi$trans$insert1763 = $$pre1762&255;
     $$phi$trans$insert1764 = (79212 + ($$phi$trans$insert1763<<2)|0);
     $$pre1765 = HEAP32[$$phi$trans$insert1764>>2]|0;
     $$pre1766 = HEAP8[$930>>0]|0;
     $$31513 = $921;$$41500 = $$014961558;$1099 = $$pre1752;$1104 = $$pre1756;$1107 = $$pre1755;$1111 = $$pre1757;$1115 = $$pre1761;$1118 = $$pre1760;$1122 = $$pre1762;$1126 = $$pre1766;$1129 = $$pre1765;
     label = 66;
     break;
    }
    default: {
     label = 67;
     break L117;
    }
    }
    while(1) {
     if ((label|0) == 63) {
      label = 0;
      $936 = $937&255;
      $938 = HEAP32[$$11497>>2]|0;
      $939 = HEAP32[$923>>2]|0;
      $940 = $939 & $938;
      $941 = $942&255;
      $943 = $940 >>> $941;
      $944 = (($945) + ($943)|0);
      $946 = HEAP8[$944>>0]|0;
      $947 = $946&255;
      $948 = $949&255;
      $950 = HEAP32[$926>>2]|0;
      $951 = $950 & $938;
      $952 = $953&255;
      $954 = $951 >>> $952;
      $955 = (($956) + ($954)|0);
      $957 = HEAP8[$955>>0]|0;
      $958 = $957&255;
      $959 = $960&255;
      $961 = HEAP32[$929>>2]|0;
      $962 = $961 & $938;
      $963 = $964&255;
      $965 = $962 >>> $963;
      $966 = (($967) + ($965)|0);
      $968 = HEAP8[$966>>0]|0;
      $969 = $968&255;
      $970 = Math_imul($947, $10)|0;
      $971 = (($970>>>0) / 255)&-1;
      $972 = (($971) + ($931))|0;
      $973 = Math_imul($958, $10)|0;
      $974 = (($973>>>0) / 255)&-1;
      $975 = (($974) + ($932))|0;
      $976 = Math_imul($969, $10)|0;
      $977 = (($976>>>0) / 255)&-1;
      $978 = (($977) + ($933))|0;
      $979 = $972 >>> $936;
      $980 = $979 << $941;
      $981 = $975 >>> $948;
      $982 = $981 << $952;
      $983 = $982 | $980;
      $984 = $978 >>> $959;
      $985 = $984 << $963;
      $986 = HEAP32[$934>>2]|0;
      $987 = $983 | $986;
      $988 = $987 | $985;
      HEAP32[$$11497>>2] = $988;
      $989 = ((($$11497)) + 4|0);
      $$11511 = $$01510;$$21498 = $989;$1003 = $949;$1007 = $953;$1010 = $956;$1014 = $960;$1018 = $964;$1021 = $967;$991 = $937;$996 = $942;$999 = $945;
      label = 64;
      continue;
     }
     else if ((label|0) == 64) {
      label = 0;
      $990 = $991&255;
      $992 = HEAP32[$$21498>>2]|0;
      $993 = HEAP32[$923>>2]|0;
      $994 = $993 & $992;
      $995 = $996&255;
      $997 = $994 >>> $995;
      $998 = (($999) + ($997)|0);
      $1000 = HEAP8[$998>>0]|0;
      $1001 = $1000&255;
      $1002 = $1003&255;
      $1004 = HEAP32[$926>>2]|0;
      $1005 = $1004 & $992;
      $1006 = $1007&255;
      $1008 = $1005 >>> $1006;
      $1009 = (($1010) + ($1008)|0);
      $1011 = HEAP8[$1009>>0]|0;
      $1012 = $1011&255;
      $1013 = $1014&255;
      $1015 = HEAP32[$929>>2]|0;
      $1016 = $1015 & $992;
      $1017 = $1018&255;
      $1019 = $1016 >>> $1017;
      $1020 = (($1021) + ($1019)|0);
      $1022 = HEAP8[$1020>>0]|0;
      $1023 = $1022&255;
      $1024 = Math_imul($1001, $10)|0;
      $1025 = (($1024>>>0) / 255)&-1;
      $1026 = (($1025) + ($931))|0;
      $1027 = Math_imul($1012, $10)|0;
      $1028 = (($1027>>>0) / 255)&-1;
      $1029 = (($1028) + ($932))|0;
      $1030 = Math_imul($1023, $10)|0;
      $1031 = (($1030>>>0) / 255)&-1;
      $1032 = (($1031) + ($933))|0;
      $1033 = $1026 >>> $990;
      $1034 = $1033 << $995;
      $1035 = $1029 >>> $1002;
      $1036 = $1035 << $1006;
      $1037 = $1036 | $1034;
      $1038 = $1032 >>> $1013;
      $1039 = $1038 << $1017;
      $1040 = HEAP32[$934>>2]|0;
      $1041 = $1037 | $1040;
      $1042 = $1041 | $1039;
      HEAP32[$$21498>>2] = $1042;
      $1043 = ((($$21498)) + 4|0);
      $$21512 = $$11511;$$31499 = $1043;$1045 = $991;$1050 = $996;$1053 = $999;$1057 = $1003;$1061 = $1007;$1064 = $1010;$1068 = $1014;$1072 = $1018;$1075 = $1021;
      label = 65;
      continue;
     }
     else if ((label|0) == 65) {
      label = 0;
      $1044 = $1045&255;
      $1046 = HEAP32[$$31499>>2]|0;
      $1047 = HEAP32[$923>>2]|0;
      $1048 = $1047 & $1046;
      $1049 = $1050&255;
      $1051 = $1048 >>> $1049;
      $1052 = (($1053) + ($1051)|0);
      $1054 = HEAP8[$1052>>0]|0;
      $1055 = $1054&255;
      $1056 = $1057&255;
      $1058 = HEAP32[$926>>2]|0;
      $1059 = $1058 & $1046;
      $1060 = $1061&255;
      $1062 = $1059 >>> $1060;
      $1063 = (($1064) + ($1062)|0);
      $1065 = HEAP8[$1063>>0]|0;
      $1066 = $1065&255;
      $1067 = $1068&255;
      $1069 = HEAP32[$929>>2]|0;
      $1070 = $1069 & $1046;
      $1071 = $1072&255;
      $1073 = $1070 >>> $1071;
      $1074 = (($1075) + ($1073)|0);
      $1076 = HEAP8[$1074>>0]|0;
      $1077 = $1076&255;
      $1078 = Math_imul($1055, $10)|0;
      $1079 = (($1078>>>0) / 255)&-1;
      $1080 = (($1079) + ($931))|0;
      $1081 = Math_imul($1066, $10)|0;
      $1082 = (($1081>>>0) / 255)&-1;
      $1083 = (($1082) + ($932))|0;
      $1084 = Math_imul($1077, $10)|0;
      $1085 = (($1084>>>0) / 255)&-1;
      $1086 = (($1085) + ($933))|0;
      $1087 = $1080 >>> $1044;
      $1088 = $1087 << $1049;
      $1089 = $1083 >>> $1056;
      $1090 = $1089 << $1060;
      $1091 = $1090 | $1088;
      $1092 = $1086 >>> $1067;
      $1093 = $1092 << $1071;
      $1094 = HEAP32[$934>>2]|0;
      $1095 = $1091 | $1094;
      $1096 = $1095 | $1093;
      HEAP32[$$31499>>2] = $1096;
      $1097 = ((($$31499)) + 4|0);
      $$31513 = $$21512;$$41500 = $1097;$1099 = $1045;$1104 = $1050;$1107 = $1053;$1111 = $1057;$1115 = $1061;$1118 = $1064;$1122 = $1068;$1126 = $1072;$1129 = $1075;
      label = 66;
      continue;
     }
     else if ((label|0) == 66) {
      label = 0;
      $1098 = $1099&255;
      $1100 = HEAP32[$$41500>>2]|0;
      $1101 = HEAP32[$923>>2]|0;
      $1102 = $1101 & $1100;
      $1103 = $1104&255;
      $1105 = $1102 >>> $1103;
      $1106 = (($1107) + ($1105)|0);
      $1108 = HEAP8[$1106>>0]|0;
      $1109 = $1108&255;
      $1110 = $1111&255;
      $1112 = HEAP32[$926>>2]|0;
      $1113 = $1112 & $1100;
      $1114 = $1115&255;
      $1116 = $1113 >>> $1114;
      $1117 = (($1118) + ($1116)|0);
      $1119 = HEAP8[$1117>>0]|0;
      $1120 = $1119&255;
      $1121 = $1122&255;
      $1123 = HEAP32[$929>>2]|0;
      $1124 = $1123 & $1100;
      $1125 = $1126&255;
      $1127 = $1124 >>> $1125;
      $1128 = (($1129) + ($1127)|0);
      $1130 = HEAP8[$1128>>0]|0;
      $1131 = $1130&255;
      $1132 = Math_imul($1109, $10)|0;
      $1133 = (($1132>>>0) / 255)&-1;
      $1134 = (($1133) + ($931))|0;
      $1135 = Math_imul($1120, $10)|0;
      $1136 = (($1135>>>0) / 255)&-1;
      $1137 = (($1136) + ($932))|0;
      $1138 = Math_imul($1131, $10)|0;
      $1139 = (($1138>>>0) / 255)&-1;
      $1140 = (($1139) + ($933))|0;
      $1141 = $1134 >>> $1098;
      $1142 = $1141 << $1103;
      $1143 = $1137 >>> $1110;
      $1144 = $1143 << $1114;
      $1145 = $1144 | $1142;
      $1146 = $1140 >>> $1121;
      $1147 = $1146 << $1125;
      $1148 = HEAP32[$934>>2]|0;
      $1149 = $1145 | $1148;
      $1150 = $1149 | $1147;
      HEAP32[$$41500>>2] = $1150;
      $1151 = ((($$41500)) + 4|0);
      $1152 = (($$31513) + -1)|0;
      $1153 = ($$31513|0)>(1);
      if ($1153) {
       $$01510 = $1152;$$11497 = $1151;$937 = $1099;$942 = $1104;$945 = $1107;$949 = $1111;$953 = $1115;$956 = $1118;$960 = $1122;$964 = $1126;$967 = $1129;
       label = 63;
       continue;
      } else {
       break;
      }
     }
    }
    $1154 = (($1151) + ($910<<2)|0);
    $1155 = ($935|0)==(0);
    if ($1155) {
     $$0 = 0;
     label = 109;
     break;
    } else {
     $$014961558 = $1154;$$in1565 = $935;
    }
   }
   if ((label|0) == 67) {
    // unreachable;
   }
   else if ((label|0) == 109) {
    return ($$0|0);
   }
   break;
  }
  case 2:  {
   $1156 = ((($1)) + 8|0);
   $1157 = HEAP32[$1156>>2]|0;
   $1158 = ((($1)) + 12|0);
   $1159 = HEAP32[$1158>>2]|0;
   $1160 = ((($0)) + 16|0);
   $1161 = HEAP32[$1160>>2]|0;
   $1162 = (($1161|0) / ($13|0))&-1;
   $1163 = (($1162) - ($1157))|0;
   $1164 = ($1159|0)==(0);
   if ($1164) {
    $$0 = 0;
    return ($$0|0);
   }
   $1165 = ((($0)) + 20|0);
   $1166 = HEAP32[$1165>>2]|0;
   $1167 = ((($1)) + 4|0);
   $1168 = HEAP32[$1167>>2]|0;
   $1169 = Math_imul($1168, $1162)|0;
   $1170 = (($1166) + ($1169<<2)|0);
   $1171 = HEAP32[$1>>2]|0;
   $1172 = (($1170) + ($1171<<2)|0);
   $1173 = (($1157) + 3)|0;
   $1174 = (($1173|0) / 4)&-1;
   $trunc1535 = $1157&255;
   $1175 = ((($8)) + 28|0);
   $1176 = ((($8)) + 12|0);
   $1177 = ((($8)) + 32|0);
   $1178 = ((($8)) + 29|0);
   $1179 = ((($8)) + 16|0);
   $1180 = ((($8)) + 33|0);
   $1181 = ((($8)) + 30|0);
   $1182 = ((($8)) + 20|0);
   $1183 = ((($8)) + 34|0);
   $1184 = $3&255;
   $1185 = $4&255;
   $1186 = $5&255;
   $1187 = ((($8)) + 24|0);
   $$015161560 = $1172;$$in1564 = $1159;
   L138: while(1) {
    $1188 = (($$in1564) + -1)|0;
    $trunc1535$clear = $trunc1535 & 3;
    switch ($trunc1535$clear<<24>>24) {
    case 0:  {
     $$pre1640 = HEAP8[$1175>>0]|0;
     $$phi$trans$insert1641 = $$pre1640&255;
     $$phi$trans$insert1642 = (79212 + ($$phi$trans$insert1641<<2)|0);
     $$pre1643 = HEAP32[$$phi$trans$insert1642>>2]|0;
     $$pre1644 = HEAP8[$1177>>0]|0;
     $$pre1645 = HEAP8[$1178>>0]|0;
     $$phi$trans$insert1646 = $$pre1645&255;
     $$phi$trans$insert1647 = (79212 + ($$phi$trans$insert1646<<2)|0);
     $$pre1648 = HEAP32[$$phi$trans$insert1647>>2]|0;
     $$pre1649 = HEAP8[$1180>>0]|0;
     $$pre1650 = HEAP8[$1181>>0]|0;
     $$phi$trans$insert1651 = $$pre1650&255;
     $$phi$trans$insert1652 = (79212 + ($$phi$trans$insert1651<<2)|0);
     $$pre1653 = HEAP32[$$phi$trans$insert1652>>2]|0;
     $$pre1654 = HEAP8[$1183>>0]|0;
     $$01521 = $1174;$$11517 = $$015161560;$1190 = $$pre1640;$1195 = $$pre1644;$1198 = $$pre1643;$1202 = $$pre1645;$1206 = $$pre1649;$1209 = $$pre1648;$1213 = $$pre1650;$1217 = $$pre1654;$1220 = $$pre1653;
     label = 76;
     break;
    }
    case 3:  {
     $$pre1656 = HEAP8[$1175>>0]|0;
     $$phi$trans$insert1657 = $$pre1656&255;
     $$phi$trans$insert1658 = (79212 + ($$phi$trans$insert1657<<2)|0);
     $$pre1659 = HEAP32[$$phi$trans$insert1658>>2]|0;
     $$pre1660 = HEAP8[$1177>>0]|0;
     $$pre1661 = HEAP8[$1178>>0]|0;
     $$phi$trans$insert1662 = $$pre1661&255;
     $$phi$trans$insert1663 = (79212 + ($$phi$trans$insert1662<<2)|0);
     $$pre1664 = HEAP32[$$phi$trans$insert1663>>2]|0;
     $$pre1665 = HEAP8[$1180>>0]|0;
     $$pre1666 = HEAP8[$1181>>0]|0;
     $$phi$trans$insert1667 = $$pre1666&255;
     $$phi$trans$insert1668 = (79212 + ($$phi$trans$insert1667<<2)|0);
     $$pre1669 = HEAP32[$$phi$trans$insert1668>>2]|0;
     $$pre1670 = HEAP8[$1183>>0]|0;
     $$11522 = $1174;$$21518 = $$015161560;$1241 = $$pre1656;$1246 = $$pre1660;$1249 = $$pre1659;$1253 = $$pre1661;$1257 = $$pre1665;$1260 = $$pre1664;$1264 = $$pre1666;$1268 = $$pre1670;$1271 = $$pre1669;
     label = 77;
     break;
    }
    case 2:  {
     $$pre1672 = HEAP8[$1175>>0]|0;
     $$phi$trans$insert1673 = $$pre1672&255;
     $$phi$trans$insert1674 = (79212 + ($$phi$trans$insert1673<<2)|0);
     $$pre1675 = HEAP32[$$phi$trans$insert1674>>2]|0;
     $$pre1676 = HEAP8[$1177>>0]|0;
     $$pre1677 = HEAP8[$1178>>0]|0;
     $$phi$trans$insert1678 = $$pre1677&255;
     $$phi$trans$insert1679 = (79212 + ($$phi$trans$insert1678<<2)|0);
     $$pre1680 = HEAP32[$$phi$trans$insert1679>>2]|0;
     $$pre1681 = HEAP8[$1180>>0]|0;
     $$pre1682 = HEAP8[$1181>>0]|0;
     $$phi$trans$insert1683 = $$pre1682&255;
     $$phi$trans$insert1684 = (79212 + ($$phi$trans$insert1683<<2)|0);
     $$pre1685 = HEAP32[$$phi$trans$insert1684>>2]|0;
     $$pre1686 = HEAP8[$1183>>0]|0;
     $$21523 = $1174;$$31519 = $$015161560;$1292 = $$pre1672;$1297 = $$pre1676;$1300 = $$pre1675;$1304 = $$pre1677;$1308 = $$pre1681;$1311 = $$pre1680;$1315 = $$pre1682;$1319 = $$pre1686;$1322 = $$pre1685;
     label = 78;
     break;
    }
    case 1:  {
     $$pre1688 = HEAP8[$1175>>0]|0;
     $$phi$trans$insert1689 = $$pre1688&255;
     $$phi$trans$insert1690 = (79212 + ($$phi$trans$insert1689<<2)|0);
     $$pre1691 = HEAP32[$$phi$trans$insert1690>>2]|0;
     $$pre1692 = HEAP8[$1177>>0]|0;
     $$pre1693 = HEAP8[$1178>>0]|0;
     $$phi$trans$insert1694 = $$pre1693&255;
     $$phi$trans$insert1695 = (79212 + ($$phi$trans$insert1694<<2)|0);
     $$pre1696 = HEAP32[$$phi$trans$insert1695>>2]|0;
     $$pre1697 = HEAP8[$1180>>0]|0;
     $$pre1698 = HEAP8[$1181>>0]|0;
     $$phi$trans$insert1699 = $$pre1698&255;
     $$phi$trans$insert1700 = (79212 + ($$phi$trans$insert1699<<2)|0);
     $$pre1701 = HEAP32[$$phi$trans$insert1700>>2]|0;
     $$pre1702 = HEAP8[$1183>>0]|0;
     $$31524 = $1174;$$41520 = $$015161560;$1343 = $$pre1688;$1348 = $$pre1692;$1351 = $$pre1691;$1355 = $$pre1693;$1359 = $$pre1697;$1362 = $$pre1696;$1366 = $$pre1698;$1370 = $$pre1702;$1373 = $$pre1701;
     label = 79;
     break;
    }
    default: {
     label = 80;
     break L138;
    }
    }
    while(1) {
     if ((label|0) == 76) {
      label = 0;
      $1189 = $1190&255;
      $1191 = HEAP32[$$11517>>2]|0;
      $1192 = HEAP32[$1176>>2]|0;
      $1193 = $1192 & $1191;
      $1194 = $1195&255;
      $1196 = $1193 >>> $1194;
      $1197 = (($1198) + ($1196)|0);
      $1199 = HEAP8[$1197>>0]|0;
      $1200 = $1199&255;
      $1201 = $1202&255;
      $1203 = HEAP32[$1179>>2]|0;
      $1204 = $1203 & $1191;
      $1205 = $1206&255;
      $1207 = $1204 >>> $1205;
      $1208 = (($1209) + ($1207)|0);
      $1210 = HEAP8[$1208>>0]|0;
      $1211 = $1210&255;
      $1212 = $1213&255;
      $1214 = HEAP32[$1182>>2]|0;
      $1215 = $1214 & $1191;
      $1216 = $1217&255;
      $1218 = $1215 >>> $1216;
      $1219 = (($1220) + ($1218)|0);
      $1221 = HEAP8[$1219>>0]|0;
      $1222 = $1221&255;
      $1223 = (($1200) + ($1184))|0;
      $1224 = ($1223>>>0)<(255);
      $$18 = $1224 ? $1223 : 255;
      $1225 = (($1211) + ($1185))|0;
      $1226 = ($1225>>>0)<(255);
      $$7 = $1226 ? $1225 : 255;
      $1227 = (($1222) + ($1186))|0;
      $1228 = ($1227>>>0)<(255);
      $$23 = $1228 ? $1227 : 255;
      $1229 = $$18 >>> $1189;
      $1230 = $1229 << $1194;
      $1231 = $$7 >>> $1201;
      $1232 = $1231 << $1205;
      $1233 = $1232 | $1230;
      $1234 = $$23 >>> $1212;
      $1235 = $1234 << $1216;
      $1236 = HEAP32[$1187>>2]|0;
      $1237 = $1233 | $1236;
      $1238 = $1237 | $1235;
      HEAP32[$$11517>>2] = $1238;
      $1239 = ((($$11517)) + 4|0);
      $$11522 = $$01521;$$21518 = $1239;$1241 = $1190;$1246 = $1195;$1249 = $1198;$1253 = $1202;$1257 = $1206;$1260 = $1209;$1264 = $1213;$1268 = $1217;$1271 = $1220;
      label = 77;
      continue;
     }
     else if ((label|0) == 77) {
      label = 0;
      $1240 = $1241&255;
      $1242 = HEAP32[$$21518>>2]|0;
      $1243 = HEAP32[$1176>>2]|0;
      $1244 = $1243 & $1242;
      $1245 = $1246&255;
      $1247 = $1244 >>> $1245;
      $1248 = (($1249) + ($1247)|0);
      $1250 = HEAP8[$1248>>0]|0;
      $1251 = $1250&255;
      $1252 = $1253&255;
      $1254 = HEAP32[$1179>>2]|0;
      $1255 = $1254 & $1242;
      $1256 = $1257&255;
      $1258 = $1255 >>> $1256;
      $1259 = (($1260) + ($1258)|0);
      $1261 = HEAP8[$1259>>0]|0;
      $1262 = $1261&255;
      $1263 = $1264&255;
      $1265 = HEAP32[$1182>>2]|0;
      $1266 = $1265 & $1242;
      $1267 = $1268&255;
      $1269 = $1266 >>> $1267;
      $1270 = (($1271) + ($1269)|0);
      $1272 = HEAP8[$1270>>0]|0;
      $1273 = $1272&255;
      $1274 = (($1251) + ($1184))|0;
      $1275 = ($1274>>>0)<(255);
      $$8 = $1275 ? $1274 : 255;
      $1276 = (($1262) + ($1185))|0;
      $1277 = ($1276>>>0)<(255);
      $$19 = $1277 ? $1276 : 255;
      $1278 = (($1273) + ($1186))|0;
      $1279 = ($1278>>>0)<(255);
      $$9 = $1279 ? $1278 : 255;
      $1280 = $$8 >>> $1240;
      $1281 = $1280 << $1245;
      $1282 = $$19 >>> $1252;
      $1283 = $1282 << $1256;
      $1284 = $1283 | $1281;
      $1285 = $$9 >>> $1263;
      $1286 = $1285 << $1267;
      $1287 = HEAP32[$1187>>2]|0;
      $1288 = $1284 | $1287;
      $1289 = $1288 | $1286;
      HEAP32[$$21518>>2] = $1289;
      $1290 = ((($$21518)) + 4|0);
      $$21523 = $$11522;$$31519 = $1290;$1292 = $1241;$1297 = $1246;$1300 = $1249;$1304 = $1253;$1308 = $1257;$1311 = $1260;$1315 = $1264;$1319 = $1268;$1322 = $1271;
      label = 78;
      continue;
     }
     else if ((label|0) == 78) {
      label = 0;
      $1291 = $1292&255;
      $1293 = HEAP32[$$31519>>2]|0;
      $1294 = HEAP32[$1176>>2]|0;
      $1295 = $1294 & $1293;
      $1296 = $1297&255;
      $1298 = $1295 >>> $1296;
      $1299 = (($1300) + ($1298)|0);
      $1301 = HEAP8[$1299>>0]|0;
      $1302 = $1301&255;
      $1303 = $1304&255;
      $1305 = HEAP32[$1179>>2]|0;
      $1306 = $1305 & $1293;
      $1307 = $1308&255;
      $1309 = $1306 >>> $1307;
      $1310 = (($1311) + ($1309)|0);
      $1312 = HEAP8[$1310>>0]|0;
      $1313 = $1312&255;
      $1314 = $1315&255;
      $1316 = HEAP32[$1182>>2]|0;
      $1317 = $1316 & $1293;
      $1318 = $1319&255;
      $1320 = $1317 >>> $1318;
      $1321 = (($1322) + ($1320)|0);
      $1323 = HEAP8[$1321>>0]|0;
      $1324 = $1323&255;
      $1325 = (($1302) + ($1184))|0;
      $1326 = ($1325>>>0)<(255);
      $$10 = $1326 ? $1325 : 255;
      $1327 = (($1313) + ($1185))|0;
      $1328 = ($1327>>>0)<(255);
      $$20 = $1328 ? $1327 : 255;
      $1329 = (($1324) + ($1186))|0;
      $1330 = ($1329>>>0)<(255);
      $$11 = $1330 ? $1329 : 255;
      $1331 = $$10 >>> $1291;
      $1332 = $1331 << $1296;
      $1333 = $$20 >>> $1303;
      $1334 = $1333 << $1307;
      $1335 = $1334 | $1332;
      $1336 = $$11 >>> $1314;
      $1337 = $1336 << $1318;
      $1338 = HEAP32[$1187>>2]|0;
      $1339 = $1335 | $1338;
      $1340 = $1339 | $1337;
      HEAP32[$$31519>>2] = $1340;
      $1341 = ((($$31519)) + 4|0);
      $$31524 = $$21523;$$41520 = $1341;$1343 = $1292;$1348 = $1297;$1351 = $1300;$1355 = $1304;$1359 = $1308;$1362 = $1311;$1366 = $1315;$1370 = $1319;$1373 = $1322;
      label = 79;
      continue;
     }
     else if ((label|0) == 79) {
      label = 0;
      $1342 = $1343&255;
      $1344 = HEAP32[$$41520>>2]|0;
      $1345 = HEAP32[$1176>>2]|0;
      $1346 = $1345 & $1344;
      $1347 = $1348&255;
      $1349 = $1346 >>> $1347;
      $1350 = (($1351) + ($1349)|0);
      $1352 = HEAP8[$1350>>0]|0;
      $1353 = $1352&255;
      $1354 = $1355&255;
      $1356 = HEAP32[$1179>>2]|0;
      $1357 = $1356 & $1344;
      $1358 = $1359&255;
      $1360 = $1357 >>> $1358;
      $1361 = (($1362) + ($1360)|0);
      $1363 = HEAP8[$1361>>0]|0;
      $1364 = $1363&255;
      $1365 = $1366&255;
      $1367 = HEAP32[$1182>>2]|0;
      $1368 = $1367 & $1344;
      $1369 = $1370&255;
      $1371 = $1368 >>> $1369;
      $1372 = (($1373) + ($1371)|0);
      $1374 = HEAP8[$1372>>0]|0;
      $1375 = $1374&255;
      $1376 = (($1353) + ($1184))|0;
      $1377 = ($1376>>>0)<(255);
      $$12 = $1377 ? $1376 : 255;
      $1378 = (($1364) + ($1185))|0;
      $1379 = ($1378>>>0)<(255);
      $$21 = $1379 ? $1378 : 255;
      $1380 = (($1375) + ($1186))|0;
      $1381 = ($1380>>>0)<(255);
      $$13 = $1381 ? $1380 : 255;
      $1382 = $$12 >>> $1342;
      $1383 = $1382 << $1347;
      $1384 = $$21 >>> $1354;
      $1385 = $1384 << $1358;
      $1386 = $1385 | $1383;
      $1387 = $$13 >>> $1365;
      $1388 = $1387 << $1369;
      $1389 = HEAP32[$1187>>2]|0;
      $1390 = $1386 | $1389;
      $1391 = $1390 | $1388;
      HEAP32[$$41520>>2] = $1391;
      $1392 = ((($$41520)) + 4|0);
      $1393 = (($$31524) + -1)|0;
      $1394 = ($$31524|0)>(1);
      if ($1394) {
       $$01521 = $1393;$$11517 = $1392;$1190 = $1343;$1195 = $1348;$1198 = $1351;$1202 = $1355;$1206 = $1359;$1209 = $1362;$1213 = $1366;$1217 = $1370;$1220 = $1373;
       label = 76;
       continue;
      } else {
       break;
      }
     }
    }
    $1395 = (($1392) + ($1163<<2)|0);
    $1396 = ($1188|0)==(0);
    if ($1396) {
     $$0 = 0;
     label = 109;
     break;
    } else {
     $$015161560 = $1395;$$in1564 = $1188;
    }
   }
   if ((label|0) == 80) {
    // unreachable;
   }
   else if ((label|0) == 109) {
    return ($$0|0);
   }
   break;
  }
  case 4:  {
   $1397 = ((($1)) + 8|0);
   $1398 = HEAP32[$1397>>2]|0;
   $1399 = ((($1)) + 12|0);
   $1400 = HEAP32[$1399>>2]|0;
   $1401 = ((($0)) + 16|0);
   $1402 = HEAP32[$1401>>2]|0;
   $1403 = (($1402|0) / ($13|0))&-1;
   $1404 = (($1403) - ($1398))|0;
   $1405 = ($1400|0)==(0);
   if ($1405) {
    $$0 = 0;
    return ($$0|0);
   }
   $1406 = ((($0)) + 20|0);
   $1407 = HEAP32[$1406>>2]|0;
   $1408 = ((($1)) + 4|0);
   $1409 = HEAP32[$1408>>2]|0;
   $1410 = Math_imul($1409, $1403)|0;
   $1411 = (($1407) + ($1410<<2)|0);
   $1412 = HEAP32[$1>>2]|0;
   $1413 = (($1411) + ($1412<<2)|0);
   $1414 = (($1398) + 3)|0;
   $1415 = (($1414|0) / 4)&-1;
   $trunc = $1398&255;
   $1416 = ((($8)) + 28|0);
   $1417 = ((($8)) + 12|0);
   $1418 = ((($8)) + 32|0);
   $1419 = ((($8)) + 29|0);
   $1420 = ((($8)) + 16|0);
   $1421 = ((($8)) + 33|0);
   $1422 = ((($8)) + 30|0);
   $1423 = ((($8)) + 20|0);
   $1424 = ((($8)) + 34|0);
   $1425 = $3&255;
   $1426 = $4&255;
   $1427 = $5&255;
   $1428 = ((($8)) + 24|0);
   $$015261562 = $1413;$$in = $1400;
   L159: while(1) {
    $1429 = (($$in) + -1)|0;
    $trunc$clear = $trunc & 3;
    switch ($trunc$clear<<24>>24) {
    case 0:  {
     $$pre = HEAP8[$1416>>0]|0;
     $$phi$trans$insert = $$pre&255;
     $$phi$trans$insert1578 = (79212 + ($$phi$trans$insert<<2)|0);
     $$pre1579 = HEAP32[$$phi$trans$insert1578>>2]|0;
     $$pre1580 = HEAP8[$1418>>0]|0;
     $$pre1581 = HEAP8[$1419>>0]|0;
     $$phi$trans$insert1582 = $$pre1581&255;
     $$phi$trans$insert1583 = (79212 + ($$phi$trans$insert1582<<2)|0);
     $$pre1584 = HEAP32[$$phi$trans$insert1583>>2]|0;
     $$pre1585 = HEAP8[$1421>>0]|0;
     $$pre1586 = HEAP8[$1422>>0]|0;
     $$phi$trans$insert1587 = $$pre1586&255;
     $$phi$trans$insert1588 = (79212 + ($$phi$trans$insert1587<<2)|0);
     $$pre1589 = HEAP32[$$phi$trans$insert1588>>2]|0;
     $$pre1590 = HEAP8[$1424>>0]|0;
     $$01531 = $1415;$$11527 = $$015261562;$1431 = $$pre;$1436 = $$pre1580;$1439 = $$pre1579;$1443 = $$pre1581;$1447 = $$pre1585;$1450 = $$pre1584;$1454 = $$pre1586;$1458 = $$pre1590;$1461 = $$pre1589;
     label = 89;
     break;
    }
    case 3:  {
     $$pre1592 = HEAP8[$1416>>0]|0;
     $$phi$trans$insert1593 = $$pre1592&255;
     $$phi$trans$insert1594 = (79212 + ($$phi$trans$insert1593<<2)|0);
     $$pre1595 = HEAP32[$$phi$trans$insert1594>>2]|0;
     $$pre1596 = HEAP8[$1418>>0]|0;
     $$pre1597 = HEAP8[$1419>>0]|0;
     $$phi$trans$insert1598 = $$pre1597&255;
     $$phi$trans$insert1599 = (79212 + ($$phi$trans$insert1598<<2)|0);
     $$pre1600 = HEAP32[$$phi$trans$insert1599>>2]|0;
     $$pre1601 = HEAP8[$1421>>0]|0;
     $$pre1602 = HEAP8[$1422>>0]|0;
     $$phi$trans$insert1603 = $$pre1602&255;
     $$phi$trans$insert1604 = (79212 + ($$phi$trans$insert1603<<2)|0);
     $$pre1605 = HEAP32[$$phi$trans$insert1604>>2]|0;
     $$pre1606 = HEAP8[$1424>>0]|0;
     $$11532 = $1415;$$21528 = $$015261562;$1482 = $$pre1592;$1487 = $$pre1596;$1490 = $$pre1595;$1494 = $$pre1597;$1498 = $$pre1601;$1501 = $$pre1600;$1505 = $$pre1602;$1509 = $$pre1606;$1512 = $$pre1605;
     label = 90;
     break;
    }
    case 2:  {
     $$pre1608 = HEAP8[$1416>>0]|0;
     $$phi$trans$insert1609 = $$pre1608&255;
     $$phi$trans$insert1610 = (79212 + ($$phi$trans$insert1609<<2)|0);
     $$pre1611 = HEAP32[$$phi$trans$insert1610>>2]|0;
     $$pre1612 = HEAP8[$1418>>0]|0;
     $$pre1613 = HEAP8[$1419>>0]|0;
     $$phi$trans$insert1614 = $$pre1613&255;
     $$phi$trans$insert1615 = (79212 + ($$phi$trans$insert1614<<2)|0);
     $$pre1616 = HEAP32[$$phi$trans$insert1615>>2]|0;
     $$pre1617 = HEAP8[$1421>>0]|0;
     $$pre1618 = HEAP8[$1422>>0]|0;
     $$phi$trans$insert1619 = $$pre1618&255;
     $$phi$trans$insert1620 = (79212 + ($$phi$trans$insert1619<<2)|0);
     $$pre1621 = HEAP32[$$phi$trans$insert1620>>2]|0;
     $$pre1622 = HEAP8[$1424>>0]|0;
     $$21533 = $1415;$$31529 = $$015261562;$1533 = $$pre1608;$1538 = $$pre1612;$1541 = $$pre1611;$1545 = $$pre1613;$1549 = $$pre1617;$1552 = $$pre1616;$1556 = $$pre1618;$1560 = $$pre1622;$1563 = $$pre1621;
     label = 91;
     break;
    }
    case 1:  {
     $$pre1624 = HEAP8[$1416>>0]|0;
     $$phi$trans$insert1625 = $$pre1624&255;
     $$phi$trans$insert1626 = (79212 + ($$phi$trans$insert1625<<2)|0);
     $$pre1627 = HEAP32[$$phi$trans$insert1626>>2]|0;
     $$pre1628 = HEAP8[$1418>>0]|0;
     $$pre1629 = HEAP8[$1419>>0]|0;
     $$phi$trans$insert1630 = $$pre1629&255;
     $$phi$trans$insert1631 = (79212 + ($$phi$trans$insert1630<<2)|0);
     $$pre1632 = HEAP32[$$phi$trans$insert1631>>2]|0;
     $$pre1633 = HEAP8[$1421>>0]|0;
     $$pre1634 = HEAP8[$1422>>0]|0;
     $$phi$trans$insert1635 = $$pre1634&255;
     $$phi$trans$insert1636 = (79212 + ($$phi$trans$insert1635<<2)|0);
     $$pre1637 = HEAP32[$$phi$trans$insert1636>>2]|0;
     $$pre1638 = HEAP8[$1424>>0]|0;
     $$31534 = $1415;$$41530 = $$015261562;$1584 = $$pre1624;$1589 = $$pre1628;$1592 = $$pre1627;$1596 = $$pre1629;$1600 = $$pre1633;$1603 = $$pre1632;$1607 = $$pre1634;$1611 = $$pre1638;$1614 = $$pre1637;
     label = 92;
     break;
    }
    default: {
     label = 93;
     break L159;
    }
    }
    while(1) {
     if ((label|0) == 89) {
      label = 0;
      $1430 = $1431&255;
      $1432 = HEAP32[$$11527>>2]|0;
      $1433 = HEAP32[$1417>>2]|0;
      $1434 = $1433 & $1432;
      $1435 = $1436&255;
      $1437 = $1434 >>> $1435;
      $1438 = (($1439) + ($1437)|0);
      $1440 = HEAP8[$1438>>0]|0;
      $1441 = $1440&255;
      $1442 = $1443&255;
      $1444 = HEAP32[$1420>>2]|0;
      $1445 = $1444 & $1432;
      $1446 = $1447&255;
      $1448 = $1445 >>> $1446;
      $1449 = (($1450) + ($1448)|0);
      $1451 = HEAP8[$1449>>0]|0;
      $1452 = $1451&255;
      $1453 = $1454&255;
      $1455 = HEAP32[$1423>>2]|0;
      $1456 = $1455 & $1432;
      $1457 = $1458&255;
      $1459 = $1456 >>> $1457;
      $1460 = (($1461) + ($1459)|0);
      $1462 = HEAP8[$1460>>0]|0;
      $1463 = $1462&255;
      $1464 = Math_imul($1441, $1425)|0;
      $1465 = (($1464>>>0) / 255)&-1;
      $1466 = Math_imul($1452, $1426)|0;
      $1467 = (($1466>>>0) / 255)&-1;
      $1468 = Math_imul($1463, $1427)|0;
      $1469 = (($1468>>>0) / 255)&-1;
      $1470 = $1465 >>> $1430;
      $1471 = $1470 << $1435;
      $1472 = $1467 >>> $1442;
      $1473 = $1472 << $1446;
      $1474 = $1473 | $1471;
      $1475 = $1469 >>> $1453;
      $1476 = $1475 << $1457;
      $1477 = HEAP32[$1428>>2]|0;
      $1478 = $1474 | $1477;
      $1479 = $1478 | $1476;
      HEAP32[$$11527>>2] = $1479;
      $1480 = ((($$11527)) + 4|0);
      $$11532 = $$01531;$$21528 = $1480;$1482 = $1431;$1487 = $1436;$1490 = $1439;$1494 = $1443;$1498 = $1447;$1501 = $1450;$1505 = $1454;$1509 = $1458;$1512 = $1461;
      label = 90;
      continue;
     }
     else if ((label|0) == 90) {
      label = 0;
      $1481 = $1482&255;
      $1483 = HEAP32[$$21528>>2]|0;
      $1484 = HEAP32[$1417>>2]|0;
      $1485 = $1484 & $1483;
      $1486 = $1487&255;
      $1488 = $1485 >>> $1486;
      $1489 = (($1490) + ($1488)|0);
      $1491 = HEAP8[$1489>>0]|0;
      $1492 = $1491&255;
      $1493 = $1494&255;
      $1495 = HEAP32[$1420>>2]|0;
      $1496 = $1495 & $1483;
      $1497 = $1498&255;
      $1499 = $1496 >>> $1497;
      $1500 = (($1501) + ($1499)|0);
      $1502 = HEAP8[$1500>>0]|0;
      $1503 = $1502&255;
      $1504 = $1505&255;
      $1506 = HEAP32[$1423>>2]|0;
      $1507 = $1506 & $1483;
      $1508 = $1509&255;
      $1510 = $1507 >>> $1508;
      $1511 = (($1512) + ($1510)|0);
      $1513 = HEAP8[$1511>>0]|0;
      $1514 = $1513&255;
      $1515 = Math_imul($1492, $1425)|0;
      $1516 = (($1515>>>0) / 255)&-1;
      $1517 = Math_imul($1503, $1426)|0;
      $1518 = (($1517>>>0) / 255)&-1;
      $1519 = Math_imul($1514, $1427)|0;
      $1520 = (($1519>>>0) / 255)&-1;
      $1521 = $1516 >>> $1481;
      $1522 = $1521 << $1486;
      $1523 = $1518 >>> $1493;
      $1524 = $1523 << $1497;
      $1525 = $1524 | $1522;
      $1526 = $1520 >>> $1504;
      $1527 = $1526 << $1508;
      $1528 = HEAP32[$1428>>2]|0;
      $1529 = $1525 | $1528;
      $1530 = $1529 | $1527;
      HEAP32[$$21528>>2] = $1530;
      $1531 = ((($$21528)) + 4|0);
      $$21533 = $$11532;$$31529 = $1531;$1533 = $1482;$1538 = $1487;$1541 = $1490;$1545 = $1494;$1549 = $1498;$1552 = $1501;$1556 = $1505;$1560 = $1509;$1563 = $1512;
      label = 91;
      continue;
     }
     else if ((label|0) == 91) {
      label = 0;
      $1532 = $1533&255;
      $1534 = HEAP32[$$31529>>2]|0;
      $1535 = HEAP32[$1417>>2]|0;
      $1536 = $1535 & $1534;
      $1537 = $1538&255;
      $1539 = $1536 >>> $1537;
      $1540 = (($1541) + ($1539)|0);
      $1542 = HEAP8[$1540>>0]|0;
      $1543 = $1542&255;
      $1544 = $1545&255;
      $1546 = HEAP32[$1420>>2]|0;
      $1547 = $1546 & $1534;
      $1548 = $1549&255;
      $1550 = $1547 >>> $1548;
      $1551 = (($1552) + ($1550)|0);
      $1553 = HEAP8[$1551>>0]|0;
      $1554 = $1553&255;
      $1555 = $1556&255;
      $1557 = HEAP32[$1423>>2]|0;
      $1558 = $1557 & $1534;
      $1559 = $1560&255;
      $1561 = $1558 >>> $1559;
      $1562 = (($1563) + ($1561)|0);
      $1564 = HEAP8[$1562>>0]|0;
      $1565 = $1564&255;
      $1566 = Math_imul($1543, $1425)|0;
      $1567 = (($1566>>>0) / 255)&-1;
      $1568 = Math_imul($1554, $1426)|0;
      $1569 = (($1568>>>0) / 255)&-1;
      $1570 = Math_imul($1565, $1427)|0;
      $1571 = (($1570>>>0) / 255)&-1;
      $1572 = $1567 >>> $1532;
      $1573 = $1572 << $1537;
      $1574 = $1569 >>> $1544;
      $1575 = $1574 << $1548;
      $1576 = $1575 | $1573;
      $1577 = $1571 >>> $1555;
      $1578 = $1577 << $1559;
      $1579 = HEAP32[$1428>>2]|0;
      $1580 = $1576 | $1579;
      $1581 = $1580 | $1578;
      HEAP32[$$31529>>2] = $1581;
      $1582 = ((($$31529)) + 4|0);
      $$31534 = $$21533;$$41530 = $1582;$1584 = $1533;$1589 = $1538;$1592 = $1541;$1596 = $1545;$1600 = $1549;$1603 = $1552;$1607 = $1556;$1611 = $1560;$1614 = $1563;
      label = 92;
      continue;
     }
     else if ((label|0) == 92) {
      label = 0;
      $1583 = $1584&255;
      $1585 = HEAP32[$$41530>>2]|0;
      $1586 = HEAP32[$1417>>2]|0;
      $1587 = $1586 & $1585;
      $1588 = $1589&255;
      $1590 = $1587 >>> $1588;
      $1591 = (($1592) + ($1590)|0);
      $1593 = HEAP8[$1591>>0]|0;
      $1594 = $1593&255;
      $1595 = $1596&255;
      $1597 = HEAP32[$1420>>2]|0;
      $1598 = $1597 & $1585;
      $1599 = $1600&255;
      $1601 = $1598 >>> $1599;
      $1602 = (($1603) + ($1601)|0);
      $1604 = HEAP8[$1602>>0]|0;
      $1605 = $1604&255;
      $1606 = $1607&255;
      $1608 = HEAP32[$1423>>2]|0;
      $1609 = $1608 & $1585;
      $1610 = $1611&255;
      $1612 = $1609 >>> $1610;
      $1613 = (($1614) + ($1612)|0);
      $1615 = HEAP8[$1613>>0]|0;
      $1616 = $1615&255;
      $1617 = Math_imul($1594, $1425)|0;
      $1618 = (($1617>>>0) / 255)&-1;
      $1619 = Math_imul($1605, $1426)|0;
      $1620 = (($1619>>>0) / 255)&-1;
      $1621 = Math_imul($1616, $1427)|0;
      $1622 = (($1621>>>0) / 255)&-1;
      $1623 = $1618 >>> $1583;
      $1624 = $1623 << $1588;
      $1625 = $1620 >>> $1595;
      $1626 = $1625 << $1599;
      $1627 = $1626 | $1624;
      $1628 = $1622 >>> $1606;
      $1629 = $1628 << $1610;
      $1630 = HEAP32[$1428>>2]|0;
      $1631 = $1627 | $1630;
      $1632 = $1631 | $1629;
      HEAP32[$$41530>>2] = $1632;
      $1633 = ((($$41530)) + 4|0);
      $1634 = (($$31534) + -1)|0;
      $1635 = ($$31534|0)>(1);
      if ($1635) {
       $$01531 = $1634;$$11527 = $1633;$1431 = $1584;$1436 = $1589;$1439 = $1592;$1443 = $1596;$1447 = $1600;$1450 = $1603;$1454 = $1607;$1458 = $1611;$1461 = $1614;
       label = 89;
       continue;
      } else {
       break;
      }
     }
    }
    $1636 = (($1633) + ($1404<<2)|0);
    $1637 = ($1429|0)==(0);
    if ($1637) {
     $$0 = 0;
     label = 109;
     break;
    } else {
     $$015261562 = $1636;$$in = $1429;
    }
   }
   if ((label|0) == 93) {
    // unreachable;
   }
   else if ((label|0) == 109) {
    return ($$0|0);
   }
   break;
  }
  default: {
   $1638 = ((($1)) + 8|0);
   $1639 = HEAP32[$1638>>2]|0;
   $1640 = ((($1)) + 12|0);
   $1641 = HEAP32[$1640>>2]|0;
   $1642 = ((($0)) + 16|0);
   $1643 = HEAP32[$1642>>2]|0;
   $1644 = (($1643|0) / ($13|0))&-1;
   $1645 = (($1644) - ($1639))|0;
   $1646 = ($1641|0)==(0);
   if ($1646) {
    $$0 = 0;
    return ($$0|0);
   }
   $1647 = ((($0)) + 20|0);
   $1648 = HEAP32[$1647>>2]|0;
   $1649 = ((($1)) + 4|0);
   $1650 = HEAP32[$1649>>2]|0;
   $1651 = Math_imul($1650, $1644)|0;
   $1652 = (($1648) + ($1651<<2)|0);
   $1653 = HEAP32[$1>>2]|0;
   $1654 = (($1652) + ($1653<<2)|0);
   $1655 = (($1639) + 3)|0;
   $1656 = (($1655|0) / 4)&-1;
   $trunc1537 = $1639&255;
   $1657 = $3&255;
   $1658 = $4&255;
   $1659 = $5&255;
   $1660 = ((($8)) + 28|0);
   $1661 = ((($8)) + 32|0);
   $1662 = ((($8)) + 29|0);
   $1663 = ((($8)) + 33|0);
   $1664 = ((($8)) + 30|0);
   $1665 = ((($8)) + 34|0);
   $1666 = ((($8)) + 24|0);
   $$015051556 = $1654;$$in1566 = $1641;
   L96: while(1) {
    $1667 = (($$in1566) + -1)|0;
    $trunc1537$clear = $trunc1537 & 3;
    switch ($trunc1537$clear<<24>>24) {
    case 0:  {
     $$pre1768 = HEAP8[$1660>>0]|0;
     $$pre1769 = HEAP8[$1661>>0]|0;
     $$pre1770 = HEAP8[$1662>>0]|0;
     $$pre1771 = HEAP8[$1663>>0]|0;
     $$pre1772 = HEAP8[$1664>>0]|0;
     $$pre1773 = HEAP8[$1665>>0]|0;
     $$01501 = $1656;$$11506 = $$015051556;$1669 = $$pre1768;$1672 = $$pre1769;$1675 = $$pre1770;$1678 = $$pre1771;$1682 = $$pre1772;$1685 = $$pre1773;
     label = 102;
     break;
    }
    case 3:  {
     $$pre1775 = HEAP8[$1660>>0]|0;
     $$pre1776 = HEAP8[$1661>>0]|0;
     $$pre1777 = HEAP8[$1662>>0]|0;
     $$pre1778 = HEAP8[$1663>>0]|0;
     $$pre1779 = HEAP8[$1664>>0]|0;
     $$pre1780 = HEAP8[$1665>>0]|0;
     $$11502 = $1656;$$21507 = $$015051556;$1692 = $$pre1775;$1695 = $$pre1776;$1698 = $$pre1777;$1701 = $$pre1778;$1705 = $$pre1779;$1708 = $$pre1780;
     label = 103;
     break;
    }
    case 2:  {
     $$pre1782 = HEAP8[$1660>>0]|0;
     $$pre1783 = HEAP8[$1661>>0]|0;
     $$pre1784 = HEAP8[$1662>>0]|0;
     $$pre1785 = HEAP8[$1663>>0]|0;
     $$pre1786 = HEAP8[$1664>>0]|0;
     $$pre1787 = HEAP8[$1665>>0]|0;
     $$21503 = $1656;$$31508 = $$015051556;$1715 = $$pre1782;$1718 = $$pre1783;$1721 = $$pre1784;$1724 = $$pre1785;$1728 = $$pre1786;$1731 = $$pre1787;
     label = 104;
     break;
    }
    case 1:  {
     $$pre1789 = HEAP8[$1660>>0]|0;
     $$pre1790 = HEAP8[$1661>>0]|0;
     $$pre1791 = HEAP8[$1662>>0]|0;
     $$pre1792 = HEAP8[$1663>>0]|0;
     $$pre1793 = HEAP8[$1664>>0]|0;
     $$pre1794 = HEAP8[$1665>>0]|0;
     $$31504 = $1656;$$41509 = $$015051556;$1738 = $$pre1789;$1741 = $$pre1790;$1744 = $$pre1791;$1747 = $$pre1792;$1751 = $$pre1793;$1754 = $$pre1794;
     label = 105;
     break;
    }
    default: {
     label = 106;
     break L96;
    }
    }
    while(1) {
     if ((label|0) == 102) {
      label = 0;
      $1668 = $1669&255;
      $1670 = $1657 >>> $1668;
      $1671 = $1672&255;
      $1673 = $1670 << $1671;
      $1674 = $1675&255;
      $1676 = $1658 >>> $1674;
      $1677 = $1678&255;
      $1679 = $1676 << $1677;
      $1680 = $1679 | $1673;
      $1681 = $1682&255;
      $1683 = $1659 >>> $1681;
      $1684 = $1685&255;
      $1686 = $1683 << $1684;
      $1687 = HEAP32[$1666>>2]|0;
      $1688 = $1680 | $1687;
      $1689 = $1688 | $1686;
      HEAP32[$$11506>>2] = $1689;
      $1690 = ((($$11506)) + 4|0);
      $$11502 = $$01501;$$21507 = $1690;$1692 = $1669;$1695 = $1672;$1698 = $1675;$1701 = $1678;$1705 = $1682;$1708 = $1685;
      label = 103;
      continue;
     }
     else if ((label|0) == 103) {
      label = 0;
      $1691 = $1692&255;
      $1693 = $1657 >>> $1691;
      $1694 = $1695&255;
      $1696 = $1693 << $1694;
      $1697 = $1698&255;
      $1699 = $1658 >>> $1697;
      $1700 = $1701&255;
      $1702 = $1699 << $1700;
      $1703 = $1702 | $1696;
      $1704 = $1705&255;
      $1706 = $1659 >>> $1704;
      $1707 = $1708&255;
      $1709 = $1706 << $1707;
      $1710 = HEAP32[$1666>>2]|0;
      $1711 = $1703 | $1710;
      $1712 = $1711 | $1709;
      HEAP32[$$21507>>2] = $1712;
      $1713 = ((($$21507)) + 4|0);
      $$21503 = $$11502;$$31508 = $1713;$1715 = $1692;$1718 = $1695;$1721 = $1698;$1724 = $1701;$1728 = $1705;$1731 = $1708;
      label = 104;
      continue;
     }
     else if ((label|0) == 104) {
      label = 0;
      $1714 = $1715&255;
      $1716 = $1657 >>> $1714;
      $1717 = $1718&255;
      $1719 = $1716 << $1717;
      $1720 = $1721&255;
      $1722 = $1658 >>> $1720;
      $1723 = $1724&255;
      $1725 = $1722 << $1723;
      $1726 = $1725 | $1719;
      $1727 = $1728&255;
      $1729 = $1659 >>> $1727;
      $1730 = $1731&255;
      $1732 = $1729 << $1730;
      $1733 = HEAP32[$1666>>2]|0;
      $1734 = $1726 | $1733;
      $1735 = $1734 | $1732;
      HEAP32[$$31508>>2] = $1735;
      $1736 = ((($$31508)) + 4|0);
      $$31504 = $$21503;$$41509 = $1736;$1738 = $1715;$1741 = $1718;$1744 = $1721;$1747 = $1724;$1751 = $1728;$1754 = $1731;
      label = 105;
      continue;
     }
     else if ((label|0) == 105) {
      label = 0;
      $1737 = $1738&255;
      $1739 = $1657 >>> $1737;
      $1740 = $1741&255;
      $1742 = $1739 << $1740;
      $1743 = $1744&255;
      $1745 = $1658 >>> $1743;
      $1746 = $1747&255;
      $1748 = $1745 << $1746;
      $1749 = $1748 | $1742;
      $1750 = $1751&255;
      $1752 = $1659 >>> $1750;
      $1753 = $1754&255;
      $1755 = $1752 << $1753;
      $1756 = HEAP32[$1666>>2]|0;
      $1757 = $1749 | $1756;
      $1758 = $1757 | $1755;
      HEAP32[$$41509>>2] = $1758;
      $1759 = ((($$41509)) + 4|0);
      $1760 = (($$31504) + -1)|0;
      $1761 = ($$31504|0)>(1);
      if ($1761) {
       $$01501 = $1760;$$11506 = $1759;$1669 = $1738;$1672 = $1741;$1675 = $1744;$1678 = $1747;$1682 = $1751;$1685 = $1754;
       label = 102;
       continue;
      } else {
       break;
      }
     }
    }
    $1762 = (($1759) + ($1645<<2)|0);
    $1763 = ($1667|0)==(0);
    if ($1763) {
     $$0 = 0;
     label = 109;
     break;
    } else {
     $$015051556 = $1762;$$in1566 = $1667;
    }
   }
   if ((label|0) == 106) {
    // unreachable;
   }
   else if ((label|0) == 109) {
    return ($$0|0);
   }
  }
  }
  break;
 }
 default: {
  $1764 = (_SDL_Error(4)|0);
  $$0 = $1764;
  return ($$0|0);
 }
 }
 return (0)|0;
}
function _SDL_BlendFillRect_RGBA($0,$1,$2,$3,$4,$5,$6) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 var $$ = 0, $$0 = 0, $$0811897 = 0, $$0816 = 0, $$0821901 = 0, $$0826 = 0, $$0851905 = 0, $$0856 = 0, $$0870 = 0, $$0874896 = 0, $$1 = 0, $$10 = 0, $$11 = 0, $$1812 = 0, $$1817 = 0, $$1822 = 0, $$1827 = 0, $$1852 = 0, $$1857 = 0, $$1871 = 0;
 var $$1875 = 0, $$2 = 0, $$2813 = 0, $$2818 = 0, $$2823 = 0, $$2828 = 0, $$2853 = 0, $$2858 = 0, $$2872 = 0, $$2876 = 0, $$3 = 0, $$3814 = 0, $$3819 = 0, $$3824 = 0, $$3829 = 0, $$3854 = 0, $$3859 = 0, $$3873 = 0, $$3877 = 0, $$4 = 0;
 var $$4815 = 0, $$4825 = 0, $$4855 = 0, $$4878 = 0, $$5 = 0, $$6 = 0, $$7 = 0, $$8 = 0, $$9 = 0, $$in = 0, $$in907 = 0, $$in908 = 0, $$in909 = 0, $$phi$trans$insert = 0, $$phi$trans$insert1001 = 0, $$phi$trans$insert1002 = 0, $$phi$trans$insert1006 = 0, $$phi$trans$insert1007 = 0, $$phi$trans$insert1011 = 0, $$phi$trans$insert1012 = 0;
 var $$phi$trans$insert1017 = 0, $$phi$trans$insert1018 = 0, $$phi$trans$insert1022 = 0, $$phi$trans$insert1023 = 0, $$phi$trans$insert1027 = 0, $$phi$trans$insert1028 = 0, $$phi$trans$insert1032 = 0, $$phi$trans$insert1033 = 0, $$phi$trans$insert1038 = 0, $$phi$trans$insert1039 = 0, $$phi$trans$insert1043 = 0, $$phi$trans$insert1044 = 0, $$phi$trans$insert1048 = 0, $$phi$trans$insert1049 = 0, $$phi$trans$insert1053 = 0, $$phi$trans$insert1054 = 0, $$phi$trans$insert1059 = 0, $$phi$trans$insert1060 = 0, $$phi$trans$insert1064 = 0, $$phi$trans$insert1065 = 0;
 var $$phi$trans$insert1069 = 0, $$phi$trans$insert1070 = 0, $$phi$trans$insert1074 = 0, $$phi$trans$insert1075 = 0, $$phi$trans$insert1080 = 0, $$phi$trans$insert1081 = 0, $$phi$trans$insert1085 = 0, $$phi$trans$insert1086 = 0, $$phi$trans$insert1090 = 0, $$phi$trans$insert1091 = 0, $$phi$trans$insert1095 = 0, $$phi$trans$insert1096 = 0, $$phi$trans$insert1101 = 0, $$phi$trans$insert1102 = 0, $$phi$trans$insert1106 = 0, $$phi$trans$insert1107 = 0, $$phi$trans$insert1111 = 0, $$phi$trans$insert1112 = 0, $$phi$trans$insert1116 = 0, $$phi$trans$insert1117 = 0;
 var $$phi$trans$insert1122 = 0, $$phi$trans$insert1123 = 0, $$phi$trans$insert1127 = 0, $$phi$trans$insert1128 = 0, $$phi$trans$insert1132 = 0, $$phi$trans$insert1133 = 0, $$phi$trans$insert1137 = 0, $$phi$trans$insert1138 = 0, $$phi$trans$insert1143 = 0, $$phi$trans$insert1144 = 0, $$phi$trans$insert1148 = 0, $$phi$trans$insert1149 = 0, $$phi$trans$insert1153 = 0, $$phi$trans$insert1154 = 0, $$phi$trans$insert1158 = 0, $$phi$trans$insert1159 = 0, $$phi$trans$insert913 = 0, $$phi$trans$insert917 = 0, $$phi$trans$insert918 = 0, $$phi$trans$insert922 = 0;
 var $$phi$trans$insert923 = 0, $$phi$trans$insert927 = 0, $$phi$trans$insert928 = 0, $$phi$trans$insert933 = 0, $$phi$trans$insert934 = 0, $$phi$trans$insert938 = 0, $$phi$trans$insert939 = 0, $$phi$trans$insert943 = 0, $$phi$trans$insert944 = 0, $$phi$trans$insert948 = 0, $$phi$trans$insert949 = 0, $$phi$trans$insert954 = 0, $$phi$trans$insert955 = 0, $$phi$trans$insert959 = 0, $$phi$trans$insert960 = 0, $$phi$trans$insert964 = 0, $$phi$trans$insert965 = 0, $$phi$trans$insert969 = 0, $$phi$trans$insert970 = 0, $$phi$trans$insert975 = 0;
 var $$phi$trans$insert976 = 0, $$phi$trans$insert980 = 0, $$phi$trans$insert981 = 0, $$phi$trans$insert985 = 0, $$phi$trans$insert986 = 0, $$phi$trans$insert990 = 0, $$phi$trans$insert991 = 0, $$phi$trans$insert996 = 0, $$phi$trans$insert997 = 0, $$pre = 0, $$pre1000 = 0, $$pre1003 = 0, $$pre1004 = 0, $$pre1005 = 0, $$pre1008 = 0, $$pre1009 = 0, $$pre1010 = 0, $$pre1013 = 0, $$pre1014 = 0, $$pre1016 = 0;
 var $$pre1019 = 0, $$pre1020 = 0, $$pre1021 = 0, $$pre1024 = 0, $$pre1025 = 0, $$pre1026 = 0, $$pre1029 = 0, $$pre1030 = 0, $$pre1031 = 0, $$pre1034 = 0, $$pre1035 = 0, $$pre1037 = 0, $$pre1040 = 0, $$pre1041 = 0, $$pre1042 = 0, $$pre1045 = 0, $$pre1046 = 0, $$pre1047 = 0, $$pre1050 = 0, $$pre1051 = 0;
 var $$pre1052 = 0, $$pre1055 = 0, $$pre1056 = 0, $$pre1058 = 0, $$pre1061 = 0, $$pre1062 = 0, $$pre1063 = 0, $$pre1066 = 0, $$pre1067 = 0, $$pre1068 = 0, $$pre1071 = 0, $$pre1072 = 0, $$pre1073 = 0, $$pre1076 = 0, $$pre1077 = 0, $$pre1079 = 0, $$pre1082 = 0, $$pre1083 = 0, $$pre1084 = 0, $$pre1087 = 0;
 var $$pre1088 = 0, $$pre1089 = 0, $$pre1092 = 0, $$pre1093 = 0, $$pre1094 = 0, $$pre1097 = 0, $$pre1098 = 0, $$pre1100 = 0, $$pre1103 = 0, $$pre1104 = 0, $$pre1105 = 0, $$pre1108 = 0, $$pre1109 = 0, $$pre1110 = 0, $$pre1113 = 0, $$pre1114 = 0, $$pre1115 = 0, $$pre1118 = 0, $$pre1119 = 0, $$pre1121 = 0;
 var $$pre1124 = 0, $$pre1125 = 0, $$pre1126 = 0, $$pre1129 = 0, $$pre1130 = 0, $$pre1131 = 0, $$pre1134 = 0, $$pre1135 = 0, $$pre1136 = 0, $$pre1139 = 0, $$pre1140 = 0, $$pre1142 = 0, $$pre1145 = 0, $$pre1146 = 0, $$pre1147 = 0, $$pre1150 = 0, $$pre1151 = 0, $$pre1152 = 0, $$pre1155 = 0, $$pre1156 = 0;
 var $$pre1157 = 0, $$pre1160 = 0, $$pre1161 = 0, $$pre1163 = 0, $$pre1164 = 0, $$pre1165 = 0, $$pre1166 = 0, $$pre1167 = 0, $$pre1168 = 0, $$pre1169 = 0, $$pre1170 = 0, $$pre1172 = 0, $$pre1173 = 0, $$pre1174 = 0, $$pre1175 = 0, $$pre1176 = 0, $$pre1177 = 0, $$pre1178 = 0, $$pre1179 = 0, $$pre1181 = 0;
 var $$pre1182 = 0, $$pre1183 = 0, $$pre1184 = 0, $$pre1185 = 0, $$pre1186 = 0, $$pre1187 = 0, $$pre1188 = 0, $$pre1190 = 0, $$pre1191 = 0, $$pre1192 = 0, $$pre1193 = 0, $$pre1194 = 0, $$pre1195 = 0, $$pre1196 = 0, $$pre1197 = 0, $$pre914 = 0, $$pre915 = 0, $$pre916 = 0, $$pre919 = 0, $$pre920 = 0;
 var $$pre921 = 0, $$pre924 = 0, $$pre925 = 0, $$pre926 = 0, $$pre929 = 0, $$pre930 = 0, $$pre932 = 0, $$pre935 = 0, $$pre936 = 0, $$pre937 = 0, $$pre940 = 0, $$pre941 = 0, $$pre942 = 0, $$pre945 = 0, $$pre946 = 0, $$pre947 = 0, $$pre950 = 0, $$pre951 = 0, $$pre953 = 0, $$pre956 = 0;
 var $$pre957 = 0, $$pre958 = 0, $$pre961 = 0, $$pre962 = 0, $$pre963 = 0, $$pre966 = 0, $$pre967 = 0, $$pre968 = 0, $$pre971 = 0, $$pre972 = 0, $$pre974 = 0, $$pre977 = 0, $$pre978 = 0, $$pre979 = 0, $$pre982 = 0, $$pre983 = 0, $$pre984 = 0, $$pre987 = 0, $$pre988 = 0, $$pre989 = 0;
 var $$pre992 = 0, $$pre993 = 0, $$pre995 = 0, $$pre998 = 0, $$pre999 = 0, $10 = 0, $100 = 0, $1000 = 0, $1001 = 0, $1002 = 0, $1003 = 0, $1004 = 0, $1005 = 0, $1006 = 0, $1007 = 0, $1008 = 0, $1009 = 0, $101 = 0, $1010 = 0, $1011 = 0;
 var $1012 = 0, $1013 = 0, $1014 = 0, $1015 = 0, $1016 = 0, $1017 = 0, $1018 = 0, $1019 = 0, $102 = 0, $1020 = 0, $1021 = 0, $1022 = 0, $1023 = 0, $1024 = 0, $1025 = 0, $1026 = 0, $1027 = 0, $1028 = 0, $1029 = 0, $103 = 0;
 var $1030 = 0, $1031 = 0, $1032 = 0, $1033 = 0, $1034 = 0, $1035 = 0, $1036 = 0, $1037 = 0, $1038 = 0, $1039 = 0, $104 = 0, $1040 = 0, $1041 = 0, $1042 = 0, $1043 = 0, $1044 = 0, $1045 = 0, $1046 = 0, $1047 = 0, $1048 = 0;
 var $1049 = 0, $105 = 0, $1050 = 0, $1051 = 0, $1052 = 0, $1053 = 0, $1054 = 0, $1055 = 0, $1056 = 0, $1057 = 0, $1058 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0;
 var $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0;
 var $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0;
 var $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0;
 var $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0;
 var $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0;
 var $296 = 0, $297 = 0, $298 = 0, $299 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0;
 var $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0;
 var $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0;
 var $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0;
 var $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0;
 var $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0;
 var $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0;
 var $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0;
 var $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0;
 var $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0;
 var $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0;
 var $496 = 0, $497 = 0, $498 = 0, $499 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0;
 var $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0;
 var $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0;
 var $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0;
 var $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0;
 var $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0;
 var $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0;
 var $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0;
 var $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0;
 var $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0;
 var $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0;
 var $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0;
 var $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0;
 var $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0;
 var $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0;
 var $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0;
 var $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0;
 var $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0;
 var $821 = 0, $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = 0, $834 = 0, $835 = 0, $836 = 0, $837 = 0, $838 = 0, $839 = 0;
 var $84 = 0, $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0, $850 = 0, $851 = 0, $852 = 0, $853 = 0, $854 = 0, $855 = 0, $856 = 0, $857 = 0;
 var $858 = 0, $859 = 0, $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0, $869 = 0, $87 = 0, $870 = 0, $871 = 0, $872 = 0, $873 = 0, $874 = 0, $875 = 0;
 var $876 = 0, $877 = 0, $878 = 0, $879 = 0, $88 = 0, $880 = 0, $881 = 0, $882 = 0, $883 = 0, $884 = 0, $885 = 0, $886 = 0, $887 = 0, $888 = 0, $889 = 0, $89 = 0, $890 = 0, $891 = 0, $892 = 0, $893 = 0;
 var $894 = 0, $895 = 0, $896 = 0, $897 = 0, $898 = 0, $899 = 0, $9 = 0, $90 = 0, $900 = 0, $901 = 0, $902 = 0, $903 = 0, $904 = 0, $905 = 0, $906 = 0, $907 = 0, $908 = 0, $909 = 0, $91 = 0, $910 = 0;
 var $911 = 0, $912 = 0, $913 = 0, $914 = 0, $915 = 0, $916 = 0, $917 = 0, $918 = 0, $919 = 0, $92 = 0, $920 = 0, $921 = 0, $922 = 0, $923 = 0, $924 = 0, $925 = 0, $926 = 0, $927 = 0, $928 = 0, $929 = 0;
 var $93 = 0, $930 = 0, $931 = 0, $932 = 0, $933 = 0, $934 = 0, $935 = 0, $936 = 0, $937 = 0, $938 = 0, $939 = 0, $94 = 0, $940 = 0, $941 = 0, $942 = 0, $943 = 0, $944 = 0, $945 = 0, $946 = 0, $947 = 0;
 var $948 = 0, $949 = 0, $95 = 0, $950 = 0, $951 = 0, $952 = 0, $953 = 0, $954 = 0, $955 = 0, $956 = 0, $957 = 0, $958 = 0, $959 = 0, $96 = 0, $960 = 0, $961 = 0, $962 = 0, $963 = 0, $964 = 0, $965 = 0;
 var $966 = 0, $967 = 0, $968 = 0, $969 = 0, $97 = 0, $970 = 0, $971 = 0, $972 = 0, $973 = 0, $974 = 0, $975 = 0, $976 = 0, $977 = 0, $978 = 0, $979 = 0, $98 = 0, $980 = 0, $981 = 0, $982 = 0, $983 = 0;
 var $984 = 0, $985 = 0, $986 = 0, $987 = 0, $988 = 0, $989 = 0, $99 = 0, $990 = 0, $991 = 0, $992 = 0, $993 = 0, $994 = 0, $995 = 0, $996 = 0, $997 = 0, $998 = 0, $999 = 0, $cond = 0, $trunc = 0, $trunc$clear = 0;
 var $trunc890 = 0, $trunc890$clear = 0, $trunc891 = 0, $trunc891$clear = 0, $trunc892 = 0, $trunc892$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $7 = ((($0)) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $6&255;
 $10 = $9 ^ 255;
 $11 = ((($8)) + 9|0);
 $12 = HEAP8[$11>>0]|0;
 $13 = $12&255;
 $cond = ($12<<24>>24)==(4);
 if (!($cond)) {
  $1058 = (_SDL_Error(4)|0);
  $$0 = $1058;
  return ($$0|0);
 }
 switch ($2|0) {
 case 1:  {
  $14 = ((($1)) + 8|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = ((($1)) + 12|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = ((($0)) + 16|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = (($19|0) / ($13|0))&-1;
  $21 = (($20) - ($15))|0;
  $22 = ($17|0)==(0);
  if ($22) {
   $$0 = 0;
   return ($$0|0);
  }
  $23 = ((($0)) + 20|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = ((($1)) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = Math_imul($26, $20)|0;
  $28 = (($24) + ($27<<2)|0);
  $29 = HEAP32[$1>>2]|0;
  $30 = (($28) + ($29<<2)|0);
  $31 = (($15) + 3)|0;
  $32 = (($31|0) / 4)&-1;
  $trunc891 = $15&255;
  $33 = ((($8)) + 28|0);
  $34 = ((($8)) + 12|0);
  $35 = ((($8)) + 32|0);
  $36 = ((($8)) + 29|0);
  $37 = ((($8)) + 16|0);
  $38 = ((($8)) + 33|0);
  $39 = ((($8)) + 30|0);
  $40 = ((($8)) + 20|0);
  $41 = ((($8)) + 34|0);
  $42 = ((($8)) + 31|0);
  $43 = ((($8)) + 24|0);
  $44 = ((($8)) + 35|0);
  $45 = $3&255;
  $46 = $4&255;
  $47 = $5&255;
  $$0811897 = $30;$$in908 = $17;
  L31: while(1) {
   $48 = (($$in908) + -1)|0;
   $trunc891$clear = $trunc891 & 3;
   switch ($trunc891$clear<<24>>24) {
   case 0:  {
    $$pre1079 = HEAP8[$33>>0]|0;
    $$phi$trans$insert1080 = $$pre1079&255;
    $$phi$trans$insert1081 = (79212 + ($$phi$trans$insert1080<<2)|0);
    $$pre1082 = HEAP32[$$phi$trans$insert1081>>2]|0;
    $$pre1083 = HEAP8[$35>>0]|0;
    $$pre1084 = HEAP8[$36>>0]|0;
    $$phi$trans$insert1085 = $$pre1084&255;
    $$phi$trans$insert1086 = (79212 + ($$phi$trans$insert1085<<2)|0);
    $$pre1087 = HEAP32[$$phi$trans$insert1086>>2]|0;
    $$pre1088 = HEAP8[$38>>0]|0;
    $$pre1089 = HEAP8[$39>>0]|0;
    $$phi$trans$insert1090 = $$pre1089&255;
    $$phi$trans$insert1091 = (79212 + ($$phi$trans$insert1090<<2)|0);
    $$pre1092 = HEAP32[$$phi$trans$insert1091>>2]|0;
    $$pre1093 = HEAP8[$41>>0]|0;
    $$pre1094 = HEAP8[$42>>0]|0;
    $$phi$trans$insert1095 = $$pre1094&255;
    $$phi$trans$insert1096 = (79212 + ($$phi$trans$insert1095<<2)|0);
    $$pre1097 = HEAP32[$$phi$trans$insert1096>>2]|0;
    $$pre1098 = HEAP8[$44>>0]|0;
    $$0816 = $32;$$1812 = $$0811897;$50 = $$pre1079;$55 = $$pre1083;$58 = $$pre1082;$62 = $$pre1084;$66 = $$pre1088;$69 = $$pre1087;$73 = $$pre1089;$77 = $$pre1093;$80 = $$pre1092;$84 = $$pre1094;$88 = $$pre1098;$91 = $$pre1097;
    label = 10;
    break;
   }
   case 3:  {
    $$pre1100 = HEAP8[$33>>0]|0;
    $$phi$trans$insert1101 = $$pre1100&255;
    $$phi$trans$insert1102 = (79212 + ($$phi$trans$insert1101<<2)|0);
    $$pre1103 = HEAP32[$$phi$trans$insert1102>>2]|0;
    $$pre1104 = HEAP8[$35>>0]|0;
    $$pre1105 = HEAP8[$36>>0]|0;
    $$phi$trans$insert1106 = $$pre1105&255;
    $$phi$trans$insert1107 = (79212 + ($$phi$trans$insert1106<<2)|0);
    $$pre1108 = HEAP32[$$phi$trans$insert1107>>2]|0;
    $$pre1109 = HEAP8[$38>>0]|0;
    $$pre1110 = HEAP8[$39>>0]|0;
    $$phi$trans$insert1111 = $$pre1110&255;
    $$phi$trans$insert1112 = (79212 + ($$phi$trans$insert1111<<2)|0);
    $$pre1113 = HEAP32[$$phi$trans$insert1112>>2]|0;
    $$pre1114 = HEAP8[$41>>0]|0;
    $$pre1115 = HEAP8[$42>>0]|0;
    $$phi$trans$insert1116 = $$pre1115&255;
    $$phi$trans$insert1117 = (79212 + ($$phi$trans$insert1116<<2)|0);
    $$pre1118 = HEAP32[$$phi$trans$insert1117>>2]|0;
    $$pre1119 = HEAP8[$44>>0]|0;
    $$1817 = $32;$$2813 = $$0811897;$119 = $$pre1100;$124 = $$pre1104;$127 = $$pre1103;$131 = $$pre1105;$135 = $$pre1109;$138 = $$pre1108;$142 = $$pre1110;$146 = $$pre1114;$149 = $$pre1113;$153 = $$pre1115;$157 = $$pre1119;$160 = $$pre1118;
    label = 11;
    break;
   }
   case 2:  {
    $$pre1121 = HEAP8[$33>>0]|0;
    $$phi$trans$insert1122 = $$pre1121&255;
    $$phi$trans$insert1123 = (79212 + ($$phi$trans$insert1122<<2)|0);
    $$pre1124 = HEAP32[$$phi$trans$insert1123>>2]|0;
    $$pre1125 = HEAP8[$35>>0]|0;
    $$pre1126 = HEAP8[$36>>0]|0;
    $$phi$trans$insert1127 = $$pre1126&255;
    $$phi$trans$insert1128 = (79212 + ($$phi$trans$insert1127<<2)|0);
    $$pre1129 = HEAP32[$$phi$trans$insert1128>>2]|0;
    $$pre1130 = HEAP8[$38>>0]|0;
    $$pre1131 = HEAP8[$39>>0]|0;
    $$phi$trans$insert1132 = $$pre1131&255;
    $$phi$trans$insert1133 = (79212 + ($$phi$trans$insert1132<<2)|0);
    $$pre1134 = HEAP32[$$phi$trans$insert1133>>2]|0;
    $$pre1135 = HEAP8[$41>>0]|0;
    $$pre1136 = HEAP8[$42>>0]|0;
    $$phi$trans$insert1137 = $$pre1136&255;
    $$phi$trans$insert1138 = (79212 + ($$phi$trans$insert1137<<2)|0);
    $$pre1139 = HEAP32[$$phi$trans$insert1138>>2]|0;
    $$pre1140 = HEAP8[$44>>0]|0;
    $$2818 = $32;$$3814 = $$0811897;$188 = $$pre1121;$193 = $$pre1125;$196 = $$pre1124;$200 = $$pre1126;$204 = $$pre1130;$207 = $$pre1129;$211 = $$pre1131;$215 = $$pre1135;$218 = $$pre1134;$222 = $$pre1136;$226 = $$pre1140;$229 = $$pre1139;
    label = 12;
    break;
   }
   case 1:  {
    $$pre1142 = HEAP8[$33>>0]|0;
    $$phi$trans$insert1143 = $$pre1142&255;
    $$phi$trans$insert1144 = (79212 + ($$phi$trans$insert1143<<2)|0);
    $$pre1145 = HEAP32[$$phi$trans$insert1144>>2]|0;
    $$pre1146 = HEAP8[$35>>0]|0;
    $$pre1147 = HEAP8[$36>>0]|0;
    $$phi$trans$insert1148 = $$pre1147&255;
    $$phi$trans$insert1149 = (79212 + ($$phi$trans$insert1148<<2)|0);
    $$pre1150 = HEAP32[$$phi$trans$insert1149>>2]|0;
    $$pre1151 = HEAP8[$38>>0]|0;
    $$pre1152 = HEAP8[$39>>0]|0;
    $$phi$trans$insert1153 = $$pre1152&255;
    $$phi$trans$insert1154 = (79212 + ($$phi$trans$insert1153<<2)|0);
    $$pre1155 = HEAP32[$$phi$trans$insert1154>>2]|0;
    $$pre1156 = HEAP8[$41>>0]|0;
    $$pre1157 = HEAP8[$42>>0]|0;
    $$phi$trans$insert1158 = $$pre1157&255;
    $$phi$trans$insert1159 = (79212 + ($$phi$trans$insert1158<<2)|0);
    $$pre1160 = HEAP32[$$phi$trans$insert1159>>2]|0;
    $$pre1161 = HEAP8[$44>>0]|0;
    $$3819 = $32;$$4815 = $$0811897;$257 = $$pre1142;$262 = $$pre1146;$265 = $$pre1145;$269 = $$pre1147;$273 = $$pre1151;$276 = $$pre1150;$280 = $$pre1152;$284 = $$pre1156;$287 = $$pre1155;$291 = $$pre1157;$295 = $$pre1161;$298 = $$pre1160;
    label = 13;
    break;
   }
   default: {
    label = 14;
    break L31;
   }
   }
   while(1) {
    if ((label|0) == 10) {
     label = 0;
     $49 = $50&255;
     $51 = HEAP32[$$1812>>2]|0;
     $52 = HEAP32[$34>>2]|0;
     $53 = $52 & $51;
     $54 = $55&255;
     $56 = $53 >>> $54;
     $57 = (($58) + ($56)|0);
     $59 = HEAP8[$57>>0]|0;
     $60 = $59&255;
     $61 = $62&255;
     $63 = HEAP32[$37>>2]|0;
     $64 = $63 & $51;
     $65 = $66&255;
     $67 = $64 >>> $65;
     $68 = (($69) + ($67)|0);
     $70 = HEAP8[$68>>0]|0;
     $71 = $70&255;
     $72 = $73&255;
     $74 = HEAP32[$40>>2]|0;
     $75 = $74 & $51;
     $76 = $77&255;
     $78 = $75 >>> $76;
     $79 = (($80) + ($78)|0);
     $81 = HEAP8[$79>>0]|0;
     $82 = $81&255;
     $83 = $84&255;
     $85 = HEAP32[$43>>2]|0;
     $86 = $85 & $51;
     $87 = $88&255;
     $89 = $86 >>> $87;
     $90 = (($91) + ($89)|0);
     $92 = HEAP8[$90>>0]|0;
     $93 = $92&255;
     $94 = Math_imul($60, $10)|0;
     $95 = (($94>>>0) / 255)&-1;
     $96 = (($95) + ($45))|0;
     $97 = Math_imul($71, $10)|0;
     $98 = (($97>>>0) / 255)&-1;
     $99 = (($98) + ($46))|0;
     $100 = Math_imul($82, $10)|0;
     $101 = (($100>>>0) / 255)&-1;
     $102 = (($101) + ($47))|0;
     $103 = Math_imul($93, $10)|0;
     $104 = (($103>>>0) / 255)&-1;
     $105 = (($104) + ($9))|0;
     $106 = $96 >>> $49;
     $107 = $106 << $54;
     $108 = $99 >>> $61;
     $109 = $108 << $65;
     $110 = $109 | $107;
     $111 = $102 >>> $72;
     $112 = $111 << $76;
     $113 = $110 | $112;
     $114 = $105 >>> $83;
     $115 = $114 << $87;
     $116 = $113 | $115;
     HEAP32[$$1812>>2] = $116;
     $117 = ((($$1812)) + 4|0);
     $$1817 = $$0816;$$2813 = $117;$119 = $50;$124 = $55;$127 = $58;$131 = $62;$135 = $66;$138 = $69;$142 = $73;$146 = $77;$149 = $80;$153 = $84;$157 = $88;$160 = $91;
     label = 11;
     continue;
    }
    else if ((label|0) == 11) {
     label = 0;
     $118 = $119&255;
     $120 = HEAP32[$$2813>>2]|0;
     $121 = HEAP32[$34>>2]|0;
     $122 = $121 & $120;
     $123 = $124&255;
     $125 = $122 >>> $123;
     $126 = (($127) + ($125)|0);
     $128 = HEAP8[$126>>0]|0;
     $129 = $128&255;
     $130 = $131&255;
     $132 = HEAP32[$37>>2]|0;
     $133 = $132 & $120;
     $134 = $135&255;
     $136 = $133 >>> $134;
     $137 = (($138) + ($136)|0);
     $139 = HEAP8[$137>>0]|0;
     $140 = $139&255;
     $141 = $142&255;
     $143 = HEAP32[$40>>2]|0;
     $144 = $143 & $120;
     $145 = $146&255;
     $147 = $144 >>> $145;
     $148 = (($149) + ($147)|0);
     $150 = HEAP8[$148>>0]|0;
     $151 = $150&255;
     $152 = $153&255;
     $154 = HEAP32[$43>>2]|0;
     $155 = $154 & $120;
     $156 = $157&255;
     $158 = $155 >>> $156;
     $159 = (($160) + ($158)|0);
     $161 = HEAP8[$159>>0]|0;
     $162 = $161&255;
     $163 = Math_imul($129, $10)|0;
     $164 = (($163>>>0) / 255)&-1;
     $165 = (($164) + ($45))|0;
     $166 = Math_imul($140, $10)|0;
     $167 = (($166>>>0) / 255)&-1;
     $168 = (($167) + ($46))|0;
     $169 = Math_imul($151, $10)|0;
     $170 = (($169>>>0) / 255)&-1;
     $171 = (($170) + ($47))|0;
     $172 = Math_imul($162, $10)|0;
     $173 = (($172>>>0) / 255)&-1;
     $174 = (($173) + ($9))|0;
     $175 = $165 >>> $118;
     $176 = $175 << $123;
     $177 = $168 >>> $130;
     $178 = $177 << $134;
     $179 = $178 | $176;
     $180 = $171 >>> $141;
     $181 = $180 << $145;
     $182 = $179 | $181;
     $183 = $174 >>> $152;
     $184 = $183 << $156;
     $185 = $182 | $184;
     HEAP32[$$2813>>2] = $185;
     $186 = ((($$2813)) + 4|0);
     $$2818 = $$1817;$$3814 = $186;$188 = $119;$193 = $124;$196 = $127;$200 = $131;$204 = $135;$207 = $138;$211 = $142;$215 = $146;$218 = $149;$222 = $153;$226 = $157;$229 = $160;
     label = 12;
     continue;
    }
    else if ((label|0) == 12) {
     label = 0;
     $187 = $188&255;
     $189 = HEAP32[$$3814>>2]|0;
     $190 = HEAP32[$34>>2]|0;
     $191 = $190 & $189;
     $192 = $193&255;
     $194 = $191 >>> $192;
     $195 = (($196) + ($194)|0);
     $197 = HEAP8[$195>>0]|0;
     $198 = $197&255;
     $199 = $200&255;
     $201 = HEAP32[$37>>2]|0;
     $202 = $201 & $189;
     $203 = $204&255;
     $205 = $202 >>> $203;
     $206 = (($207) + ($205)|0);
     $208 = HEAP8[$206>>0]|0;
     $209 = $208&255;
     $210 = $211&255;
     $212 = HEAP32[$40>>2]|0;
     $213 = $212 & $189;
     $214 = $215&255;
     $216 = $213 >>> $214;
     $217 = (($218) + ($216)|0);
     $219 = HEAP8[$217>>0]|0;
     $220 = $219&255;
     $221 = $222&255;
     $223 = HEAP32[$43>>2]|0;
     $224 = $223 & $189;
     $225 = $226&255;
     $227 = $224 >>> $225;
     $228 = (($229) + ($227)|0);
     $230 = HEAP8[$228>>0]|0;
     $231 = $230&255;
     $232 = Math_imul($198, $10)|0;
     $233 = (($232>>>0) / 255)&-1;
     $234 = (($233) + ($45))|0;
     $235 = Math_imul($209, $10)|0;
     $236 = (($235>>>0) / 255)&-1;
     $237 = (($236) + ($46))|0;
     $238 = Math_imul($220, $10)|0;
     $239 = (($238>>>0) / 255)&-1;
     $240 = (($239) + ($47))|0;
     $241 = Math_imul($231, $10)|0;
     $242 = (($241>>>0) / 255)&-1;
     $243 = (($242) + ($9))|0;
     $244 = $234 >>> $187;
     $245 = $244 << $192;
     $246 = $237 >>> $199;
     $247 = $246 << $203;
     $248 = $247 | $245;
     $249 = $240 >>> $210;
     $250 = $249 << $214;
     $251 = $248 | $250;
     $252 = $243 >>> $221;
     $253 = $252 << $225;
     $254 = $251 | $253;
     HEAP32[$$3814>>2] = $254;
     $255 = ((($$3814)) + 4|0);
     $$3819 = $$2818;$$4815 = $255;$257 = $188;$262 = $193;$265 = $196;$269 = $200;$273 = $204;$276 = $207;$280 = $211;$284 = $215;$287 = $218;$291 = $222;$295 = $226;$298 = $229;
     label = 13;
     continue;
    }
    else if ((label|0) == 13) {
     label = 0;
     $256 = $257&255;
     $258 = HEAP32[$$4815>>2]|0;
     $259 = HEAP32[$34>>2]|0;
     $260 = $259 & $258;
     $261 = $262&255;
     $263 = $260 >>> $261;
     $264 = (($265) + ($263)|0);
     $266 = HEAP8[$264>>0]|0;
     $267 = $266&255;
     $268 = $269&255;
     $270 = HEAP32[$37>>2]|0;
     $271 = $270 & $258;
     $272 = $273&255;
     $274 = $271 >>> $272;
     $275 = (($276) + ($274)|0);
     $277 = HEAP8[$275>>0]|0;
     $278 = $277&255;
     $279 = $280&255;
     $281 = HEAP32[$40>>2]|0;
     $282 = $281 & $258;
     $283 = $284&255;
     $285 = $282 >>> $283;
     $286 = (($287) + ($285)|0);
     $288 = HEAP8[$286>>0]|0;
     $289 = $288&255;
     $290 = $291&255;
     $292 = HEAP32[$43>>2]|0;
     $293 = $292 & $258;
     $294 = $295&255;
     $296 = $293 >>> $294;
     $297 = (($298) + ($296)|0);
     $299 = HEAP8[$297>>0]|0;
     $300 = $299&255;
     $301 = Math_imul($267, $10)|0;
     $302 = (($301>>>0) / 255)&-1;
     $303 = (($302) + ($45))|0;
     $304 = Math_imul($278, $10)|0;
     $305 = (($304>>>0) / 255)&-1;
     $306 = (($305) + ($46))|0;
     $307 = Math_imul($289, $10)|0;
     $308 = (($307>>>0) / 255)&-1;
     $309 = (($308) + ($47))|0;
     $310 = Math_imul($300, $10)|0;
     $311 = (($310>>>0) / 255)&-1;
     $312 = (($311) + ($9))|0;
     $313 = $303 >>> $256;
     $314 = $313 << $261;
     $315 = $306 >>> $268;
     $316 = $315 << $272;
     $317 = $316 | $314;
     $318 = $309 >>> $279;
     $319 = $318 << $283;
     $320 = $317 | $319;
     $321 = $312 >>> $290;
     $322 = $321 << $294;
     $323 = $320 | $322;
     HEAP32[$$4815>>2] = $323;
     $324 = ((($$4815)) + 4|0);
     $325 = (($$3819) + -1)|0;
     $326 = ($$3819|0)>(1);
     if ($326) {
      $$0816 = $325;$$1812 = $324;$50 = $257;$55 = $262;$58 = $265;$62 = $269;$66 = $273;$69 = $276;$73 = $280;$77 = $284;$80 = $287;$84 = $291;$88 = $295;$91 = $298;
      label = 10;
      continue;
     } else {
      break;
     }
    }
   }
   $327 = (($324) + ($21<<2)|0);
   $328 = ($48|0)==(0);
   if ($328) {
    $$0 = 0;
    label = 56;
    break;
   } else {
    $$0811897 = $327;$$in908 = $48;
   }
  }
  if ((label|0) == 14) {
   // unreachable;
  }
  else if ((label|0) == 56) {
   return ($$0|0);
  }
  break;
 }
 case 2:  {
  $329 = ((($1)) + 8|0);
  $330 = HEAP32[$329>>2]|0;
  $331 = ((($1)) + 12|0);
  $332 = HEAP32[$331>>2]|0;
  $333 = ((($0)) + 16|0);
  $334 = HEAP32[$333>>2]|0;
  $335 = (($334|0) / ($13|0))&-1;
  $336 = (($335) - ($330))|0;
  $337 = ($332|0)==(0);
  if ($337) {
   $$0 = 0;
   return ($$0|0);
  }
  $338 = ((($0)) + 20|0);
  $339 = HEAP32[$338>>2]|0;
  $340 = ((($1)) + 4|0);
  $341 = HEAP32[$340>>2]|0;
  $342 = Math_imul($341, $335)|0;
  $343 = (($339) + ($342<<2)|0);
  $344 = HEAP32[$1>>2]|0;
  $345 = (($343) + ($344<<2)|0);
  $346 = (($330) + 3)|0;
  $347 = (($346|0) / 4)&-1;
  $trunc890 = $330&255;
  $348 = ((($8)) + 28|0);
  $349 = ((($8)) + 12|0);
  $350 = ((($8)) + 32|0);
  $351 = ((($8)) + 29|0);
  $352 = ((($8)) + 16|0);
  $353 = ((($8)) + 33|0);
  $354 = ((($8)) + 30|0);
  $355 = ((($8)) + 20|0);
  $356 = ((($8)) + 34|0);
  $357 = ((($8)) + 31|0);
  $358 = ((($8)) + 24|0);
  $359 = ((($8)) + 35|0);
  $360 = $3&255;
  $361 = $4&255;
  $362 = $5&255;
  $$0821901 = $345;$$in907 = $332;
  L52: while(1) {
   $363 = (($$in907) + -1)|0;
   $trunc890$clear = $trunc890 & 3;
   switch ($trunc890$clear<<24>>24) {
   case 0:  {
    $$pre995 = HEAP8[$348>>0]|0;
    $$phi$trans$insert996 = $$pre995&255;
    $$phi$trans$insert997 = (79212 + ($$phi$trans$insert996<<2)|0);
    $$pre998 = HEAP32[$$phi$trans$insert997>>2]|0;
    $$pre999 = HEAP8[$350>>0]|0;
    $$pre1000 = HEAP8[$351>>0]|0;
    $$phi$trans$insert1001 = $$pre1000&255;
    $$phi$trans$insert1002 = (79212 + ($$phi$trans$insert1001<<2)|0);
    $$pre1003 = HEAP32[$$phi$trans$insert1002>>2]|0;
    $$pre1004 = HEAP8[$353>>0]|0;
    $$pre1005 = HEAP8[$354>>0]|0;
    $$phi$trans$insert1006 = $$pre1005&255;
    $$phi$trans$insert1007 = (79212 + ($$phi$trans$insert1006<<2)|0);
    $$pre1008 = HEAP32[$$phi$trans$insert1007>>2]|0;
    $$pre1009 = HEAP8[$356>>0]|0;
    $$pre1010 = HEAP8[$357>>0]|0;
    $$phi$trans$insert1011 = $$pre1010&255;
    $$phi$trans$insert1012 = (79212 + ($$phi$trans$insert1011<<2)|0);
    $$pre1013 = HEAP32[$$phi$trans$insert1012>>2]|0;
    $$pre1014 = HEAP8[$359>>0]|0;
    $$0826 = $347;$$1822 = $$0821901;$365 = $$pre995;$370 = $$pre999;$373 = $$pre998;$377 = $$pre1000;$381 = $$pre1004;$384 = $$pre1003;$388 = $$pre1005;$392 = $$pre1009;$395 = $$pre1008;$399 = $$pre1010;$403 = $$pre1014;$406 = $$pre1013;
    label = 23;
    break;
   }
   case 3:  {
    $$pre1016 = HEAP8[$348>>0]|0;
    $$phi$trans$insert1017 = $$pre1016&255;
    $$phi$trans$insert1018 = (79212 + ($$phi$trans$insert1017<<2)|0);
    $$pre1019 = HEAP32[$$phi$trans$insert1018>>2]|0;
    $$pre1020 = HEAP8[$350>>0]|0;
    $$pre1021 = HEAP8[$351>>0]|0;
    $$phi$trans$insert1022 = $$pre1021&255;
    $$phi$trans$insert1023 = (79212 + ($$phi$trans$insert1022<<2)|0);
    $$pre1024 = HEAP32[$$phi$trans$insert1023>>2]|0;
    $$pre1025 = HEAP8[$353>>0]|0;
    $$pre1026 = HEAP8[$354>>0]|0;
    $$phi$trans$insert1027 = $$pre1026&255;
    $$phi$trans$insert1028 = (79212 + ($$phi$trans$insert1027<<2)|0);
    $$pre1029 = HEAP32[$$phi$trans$insert1028>>2]|0;
    $$pre1030 = HEAP8[$356>>0]|0;
    $$pre1031 = HEAP8[$357>>0]|0;
    $$phi$trans$insert1032 = $$pre1031&255;
    $$phi$trans$insert1033 = (79212 + ($$phi$trans$insert1032<<2)|0);
    $$pre1034 = HEAP32[$$phi$trans$insert1033>>2]|0;
    $$pre1035 = HEAP8[$359>>0]|0;
    $$1827 = $347;$$2823 = $$0821901;$428 = $$pre1016;$433 = $$pre1020;$436 = $$pre1019;$440 = $$pre1021;$444 = $$pre1025;$447 = $$pre1024;$451 = $$pre1026;$455 = $$pre1030;$458 = $$pre1029;$462 = $$pre1031;$466 = $$pre1035;$469 = $$pre1034;
    label = 24;
    break;
   }
   case 2:  {
    $$pre1037 = HEAP8[$348>>0]|0;
    $$phi$trans$insert1038 = $$pre1037&255;
    $$phi$trans$insert1039 = (79212 + ($$phi$trans$insert1038<<2)|0);
    $$pre1040 = HEAP32[$$phi$trans$insert1039>>2]|0;
    $$pre1041 = HEAP8[$350>>0]|0;
    $$pre1042 = HEAP8[$351>>0]|0;
    $$phi$trans$insert1043 = $$pre1042&255;
    $$phi$trans$insert1044 = (79212 + ($$phi$trans$insert1043<<2)|0);
    $$pre1045 = HEAP32[$$phi$trans$insert1044>>2]|0;
    $$pre1046 = HEAP8[$353>>0]|0;
    $$pre1047 = HEAP8[$354>>0]|0;
    $$phi$trans$insert1048 = $$pre1047&255;
    $$phi$trans$insert1049 = (79212 + ($$phi$trans$insert1048<<2)|0);
    $$pre1050 = HEAP32[$$phi$trans$insert1049>>2]|0;
    $$pre1051 = HEAP8[$356>>0]|0;
    $$pre1052 = HEAP8[$357>>0]|0;
    $$phi$trans$insert1053 = $$pre1052&255;
    $$phi$trans$insert1054 = (79212 + ($$phi$trans$insert1053<<2)|0);
    $$pre1055 = HEAP32[$$phi$trans$insert1054>>2]|0;
    $$pre1056 = HEAP8[$359>>0]|0;
    $$2828 = $347;$$3824 = $$0821901;$491 = $$pre1037;$496 = $$pre1041;$499 = $$pre1040;$503 = $$pre1042;$507 = $$pre1046;$510 = $$pre1045;$514 = $$pre1047;$518 = $$pre1051;$521 = $$pre1050;$525 = $$pre1052;$529 = $$pre1056;$532 = $$pre1055;
    label = 25;
    break;
   }
   case 1:  {
    $$pre1058 = HEAP8[$348>>0]|0;
    $$phi$trans$insert1059 = $$pre1058&255;
    $$phi$trans$insert1060 = (79212 + ($$phi$trans$insert1059<<2)|0);
    $$pre1061 = HEAP32[$$phi$trans$insert1060>>2]|0;
    $$pre1062 = HEAP8[$350>>0]|0;
    $$pre1063 = HEAP8[$351>>0]|0;
    $$phi$trans$insert1064 = $$pre1063&255;
    $$phi$trans$insert1065 = (79212 + ($$phi$trans$insert1064<<2)|0);
    $$pre1066 = HEAP32[$$phi$trans$insert1065>>2]|0;
    $$pre1067 = HEAP8[$353>>0]|0;
    $$pre1068 = HEAP8[$354>>0]|0;
    $$phi$trans$insert1069 = $$pre1068&255;
    $$phi$trans$insert1070 = (79212 + ($$phi$trans$insert1069<<2)|0);
    $$pre1071 = HEAP32[$$phi$trans$insert1070>>2]|0;
    $$pre1072 = HEAP8[$356>>0]|0;
    $$pre1073 = HEAP8[$357>>0]|0;
    $$phi$trans$insert1074 = $$pre1073&255;
    $$phi$trans$insert1075 = (79212 + ($$phi$trans$insert1074<<2)|0);
    $$pre1076 = HEAP32[$$phi$trans$insert1075>>2]|0;
    $$pre1077 = HEAP8[$359>>0]|0;
    $$3829 = $347;$$4825 = $$0821901;$554 = $$pre1058;$559 = $$pre1062;$562 = $$pre1061;$566 = $$pre1063;$570 = $$pre1067;$573 = $$pre1066;$577 = $$pre1068;$581 = $$pre1072;$584 = $$pre1071;$588 = $$pre1073;$592 = $$pre1077;$595 = $$pre1076;
    label = 26;
    break;
   }
   default: {
    label = 27;
    break L52;
   }
   }
   while(1) {
    if ((label|0) == 23) {
     label = 0;
     $364 = $365&255;
     $366 = HEAP32[$$1822>>2]|0;
     $367 = HEAP32[$349>>2]|0;
     $368 = $367 & $366;
     $369 = $370&255;
     $371 = $368 >>> $369;
     $372 = (($373) + ($371)|0);
     $374 = HEAP8[$372>>0]|0;
     $375 = $374&255;
     $376 = $377&255;
     $378 = HEAP32[$352>>2]|0;
     $379 = $378 & $366;
     $380 = $381&255;
     $382 = $379 >>> $380;
     $383 = (($384) + ($382)|0);
     $385 = HEAP8[$383>>0]|0;
     $386 = $385&255;
     $387 = $388&255;
     $389 = HEAP32[$355>>2]|0;
     $390 = $389 & $366;
     $391 = $392&255;
     $393 = $390 >>> $391;
     $394 = (($395) + ($393)|0);
     $396 = HEAP8[$394>>0]|0;
     $397 = $396&255;
     $398 = $399&255;
     $400 = HEAP32[$358>>2]|0;
     $401 = $400 & $366;
     $402 = $403&255;
     $404 = $401 >>> $402;
     $405 = (($406) + ($404)|0);
     $407 = HEAP8[$405>>0]|0;
     $408 = $407&255;
     $409 = (($375) + ($360))|0;
     $410 = ($409>>>0)<(255);
     $$7 = $410 ? $409 : 255;
     $411 = (($386) + ($361))|0;
     $412 = ($411>>>0)<(255);
     $$ = $412 ? $411 : 255;
     $413 = (($397) + ($362))|0;
     $414 = ($413>>>0)<(255);
     $$11 = $414 ? $413 : 255;
     $415 = $$7 >>> $364;
     $416 = $415 << $369;
     $417 = $$ >>> $376;
     $418 = $417 << $380;
     $419 = $418 | $416;
     $420 = $$11 >>> $387;
     $421 = $420 << $391;
     $422 = $419 | $421;
     $423 = $408 >>> $398;
     $424 = $423 << $402;
     $425 = $422 | $424;
     HEAP32[$$1822>>2] = $425;
     $426 = ((($$1822)) + 4|0);
     $$1827 = $$0826;$$2823 = $426;$428 = $365;$433 = $370;$436 = $373;$440 = $377;$444 = $381;$447 = $384;$451 = $388;$455 = $392;$458 = $395;$462 = $399;$466 = $403;$469 = $406;
     label = 24;
     continue;
    }
    else if ((label|0) == 24) {
     label = 0;
     $427 = $428&255;
     $429 = HEAP32[$$2823>>2]|0;
     $430 = HEAP32[$349>>2]|0;
     $431 = $430 & $429;
     $432 = $433&255;
     $434 = $431 >>> $432;
     $435 = (($436) + ($434)|0);
     $437 = HEAP8[$435>>0]|0;
     $438 = $437&255;
     $439 = $440&255;
     $441 = HEAP32[$352>>2]|0;
     $442 = $441 & $429;
     $443 = $444&255;
     $445 = $442 >>> $443;
     $446 = (($447) + ($445)|0);
     $448 = HEAP8[$446>>0]|0;
     $449 = $448&255;
     $450 = $451&255;
     $452 = HEAP32[$355>>2]|0;
     $453 = $452 & $429;
     $454 = $455&255;
     $456 = $453 >>> $454;
     $457 = (($458) + ($456)|0);
     $459 = HEAP8[$457>>0]|0;
     $460 = $459&255;
     $461 = $462&255;
     $463 = HEAP32[$358>>2]|0;
     $464 = $463 & $429;
     $465 = $466&255;
     $467 = $464 >>> $465;
     $468 = (($469) + ($467)|0);
     $470 = HEAP8[$468>>0]|0;
     $471 = $470&255;
     $472 = (($438) + ($360))|0;
     $473 = ($472>>>0)<(255);
     $$1 = $473 ? $472 : 255;
     $474 = (($449) + ($361))|0;
     $475 = ($474>>>0)<(255);
     $$8 = $475 ? $474 : 255;
     $476 = (($460) + ($362))|0;
     $477 = ($476>>>0)<(255);
     $$2 = $477 ? $476 : 255;
     $478 = $$1 >>> $427;
     $479 = $478 << $432;
     $480 = $$8 >>> $439;
     $481 = $480 << $443;
     $482 = $481 | $479;
     $483 = $$2 >>> $450;
     $484 = $483 << $454;
     $485 = $482 | $484;
     $486 = $471 >>> $461;
     $487 = $486 << $465;
     $488 = $485 | $487;
     HEAP32[$$2823>>2] = $488;
     $489 = ((($$2823)) + 4|0);
     $$2828 = $$1827;$$3824 = $489;$491 = $428;$496 = $433;$499 = $436;$503 = $440;$507 = $444;$510 = $447;$514 = $451;$518 = $455;$521 = $458;$525 = $462;$529 = $466;$532 = $469;
     label = 25;
     continue;
    }
    else if ((label|0) == 25) {
     label = 0;
     $490 = $491&255;
     $492 = HEAP32[$$3824>>2]|0;
     $493 = HEAP32[$349>>2]|0;
     $494 = $493 & $492;
     $495 = $496&255;
     $497 = $494 >>> $495;
     $498 = (($499) + ($497)|0);
     $500 = HEAP8[$498>>0]|0;
     $501 = $500&255;
     $502 = $503&255;
     $504 = HEAP32[$352>>2]|0;
     $505 = $504 & $492;
     $506 = $507&255;
     $508 = $505 >>> $506;
     $509 = (($510) + ($508)|0);
     $511 = HEAP8[$509>>0]|0;
     $512 = $511&255;
     $513 = $514&255;
     $515 = HEAP32[$355>>2]|0;
     $516 = $515 & $492;
     $517 = $518&255;
     $519 = $516 >>> $517;
     $520 = (($521) + ($519)|0);
     $522 = HEAP8[$520>>0]|0;
     $523 = $522&255;
     $524 = $525&255;
     $526 = HEAP32[$358>>2]|0;
     $527 = $526 & $492;
     $528 = $529&255;
     $530 = $527 >>> $528;
     $531 = (($532) + ($530)|0);
     $533 = HEAP8[$531>>0]|0;
     $534 = $533&255;
     $535 = (($501) + ($360))|0;
     $536 = ($535>>>0)<(255);
     $$3 = $536 ? $535 : 255;
     $537 = (($512) + ($361))|0;
     $538 = ($537>>>0)<(255);
     $$9 = $538 ? $537 : 255;
     $539 = (($523) + ($362))|0;
     $540 = ($539>>>0)<(255);
     $$4 = $540 ? $539 : 255;
     $541 = $$3 >>> $490;
     $542 = $541 << $495;
     $543 = $$9 >>> $502;
     $544 = $543 << $506;
     $545 = $544 | $542;
     $546 = $$4 >>> $513;
     $547 = $546 << $517;
     $548 = $545 | $547;
     $549 = $534 >>> $524;
     $550 = $549 << $528;
     $551 = $548 | $550;
     HEAP32[$$3824>>2] = $551;
     $552 = ((($$3824)) + 4|0);
     $$3829 = $$2828;$$4825 = $552;$554 = $491;$559 = $496;$562 = $499;$566 = $503;$570 = $507;$573 = $510;$577 = $514;$581 = $518;$584 = $521;$588 = $525;$592 = $529;$595 = $532;
     label = 26;
     continue;
    }
    else if ((label|0) == 26) {
     label = 0;
     $553 = $554&255;
     $555 = HEAP32[$$4825>>2]|0;
     $556 = HEAP32[$349>>2]|0;
     $557 = $556 & $555;
     $558 = $559&255;
     $560 = $557 >>> $558;
     $561 = (($562) + ($560)|0);
     $563 = HEAP8[$561>>0]|0;
     $564 = $563&255;
     $565 = $566&255;
     $567 = HEAP32[$352>>2]|0;
     $568 = $567 & $555;
     $569 = $570&255;
     $571 = $568 >>> $569;
     $572 = (($573) + ($571)|0);
     $574 = HEAP8[$572>>0]|0;
     $575 = $574&255;
     $576 = $577&255;
     $578 = HEAP32[$355>>2]|0;
     $579 = $578 & $555;
     $580 = $581&255;
     $582 = $579 >>> $580;
     $583 = (($584) + ($582)|0);
     $585 = HEAP8[$583>>0]|0;
     $586 = $585&255;
     $587 = $588&255;
     $589 = HEAP32[$358>>2]|0;
     $590 = $589 & $555;
     $591 = $592&255;
     $593 = $590 >>> $591;
     $594 = (($595) + ($593)|0);
     $596 = HEAP8[$594>>0]|0;
     $597 = $596&255;
     $598 = (($564) + ($360))|0;
     $599 = ($598>>>0)<(255);
     $$5 = $599 ? $598 : 255;
     $600 = (($575) + ($361))|0;
     $601 = ($600>>>0)<(255);
     $$10 = $601 ? $600 : 255;
     $602 = (($586) + ($362))|0;
     $603 = ($602>>>0)<(255);
     $$6 = $603 ? $602 : 255;
     $604 = $$5 >>> $553;
     $605 = $604 << $558;
     $606 = $$10 >>> $565;
     $607 = $606 << $569;
     $608 = $607 | $605;
     $609 = $$6 >>> $576;
     $610 = $609 << $580;
     $611 = $608 | $610;
     $612 = $597 >>> $587;
     $613 = $612 << $591;
     $614 = $611 | $613;
     HEAP32[$$4825>>2] = $614;
     $615 = ((($$4825)) + 4|0);
     $616 = (($$3829) + -1)|0;
     $617 = ($$3829|0)>(1);
     if ($617) {
      $$0826 = $616;$$1822 = $615;$365 = $554;$370 = $559;$373 = $562;$377 = $566;$381 = $570;$384 = $573;$388 = $577;$392 = $581;$395 = $584;$399 = $588;$403 = $592;$406 = $595;
      label = 23;
      continue;
     } else {
      break;
     }
    }
   }
   $618 = (($615) + ($336<<2)|0);
   $619 = ($363|0)==(0);
   if ($619) {
    $$0 = 0;
    label = 56;
    break;
   } else {
    $$0821901 = $618;$$in907 = $363;
   }
  }
  if ((label|0) == 27) {
   // unreachable;
  }
  else if ((label|0) == 56) {
   return ($$0|0);
  }
  break;
 }
 case 4:  {
  $620 = ((($1)) + 8|0);
  $621 = HEAP32[$620>>2]|0;
  $622 = ((($1)) + 12|0);
  $623 = HEAP32[$622>>2]|0;
  $624 = ((($0)) + 16|0);
  $625 = HEAP32[$624>>2]|0;
  $626 = (($625|0) / ($13|0))&-1;
  $627 = (($626) - ($621))|0;
  $628 = ($623|0)==(0);
  if ($628) {
   $$0 = 0;
   return ($$0|0);
  }
  $629 = ((($0)) + 20|0);
  $630 = HEAP32[$629>>2]|0;
  $631 = ((($1)) + 4|0);
  $632 = HEAP32[$631>>2]|0;
  $633 = Math_imul($632, $626)|0;
  $634 = (($630) + ($633<<2)|0);
  $635 = HEAP32[$1>>2]|0;
  $636 = (($634) + ($635<<2)|0);
  $637 = (($621) + 3)|0;
  $638 = (($637|0) / 4)&-1;
  $trunc = $621&255;
  $639 = ((($8)) + 28|0);
  $640 = ((($8)) + 12|0);
  $641 = ((($8)) + 32|0);
  $642 = ((($8)) + 29|0);
  $643 = ((($8)) + 16|0);
  $644 = ((($8)) + 33|0);
  $645 = ((($8)) + 30|0);
  $646 = ((($8)) + 20|0);
  $647 = ((($8)) + 34|0);
  $648 = ((($8)) + 31|0);
  $649 = ((($8)) + 24|0);
  $650 = ((($8)) + 35|0);
  $651 = $3&255;
  $652 = $4&255;
  $653 = $5&255;
  $$0851905 = $636;$$in = $623;
  L73: while(1) {
   $654 = (($$in) + -1)|0;
   $trunc$clear = $trunc & 3;
   switch ($trunc$clear<<24>>24) {
   case 0:  {
    $$pre = HEAP8[$639>>0]|0;
    $$phi$trans$insert = $$pre&255;
    $$phi$trans$insert913 = (79212 + ($$phi$trans$insert<<2)|0);
    $$pre914 = HEAP32[$$phi$trans$insert913>>2]|0;
    $$pre915 = HEAP8[$641>>0]|0;
    $$pre916 = HEAP8[$642>>0]|0;
    $$phi$trans$insert917 = $$pre916&255;
    $$phi$trans$insert918 = (79212 + ($$phi$trans$insert917<<2)|0);
    $$pre919 = HEAP32[$$phi$trans$insert918>>2]|0;
    $$pre920 = HEAP8[$644>>0]|0;
    $$pre921 = HEAP8[$645>>0]|0;
    $$phi$trans$insert922 = $$pre921&255;
    $$phi$trans$insert923 = (79212 + ($$phi$trans$insert922<<2)|0);
    $$pre924 = HEAP32[$$phi$trans$insert923>>2]|0;
    $$pre925 = HEAP8[$647>>0]|0;
    $$pre926 = HEAP8[$648>>0]|0;
    $$phi$trans$insert927 = $$pre926&255;
    $$phi$trans$insert928 = (79212 + ($$phi$trans$insert927<<2)|0);
    $$pre929 = HEAP32[$$phi$trans$insert928>>2]|0;
    $$pre930 = HEAP8[$650>>0]|0;
    $$0856 = $638;$$1852 = $$0851905;$656 = $$pre;$661 = $$pre915;$664 = $$pre914;$668 = $$pre916;$672 = $$pre920;$675 = $$pre919;$679 = $$pre921;$683 = $$pre925;$686 = $$pre924;$690 = $$pre926;$694 = $$pre930;$697 = $$pre929;
    label = 36;
    break;
   }
   case 3:  {
    $$pre932 = HEAP8[$639>>0]|0;
    $$phi$trans$insert933 = $$pre932&255;
    $$phi$trans$insert934 = (79212 + ($$phi$trans$insert933<<2)|0);
    $$pre935 = HEAP32[$$phi$trans$insert934>>2]|0;
    $$pre936 = HEAP8[$641>>0]|0;
    $$pre937 = HEAP8[$642>>0]|0;
    $$phi$trans$insert938 = $$pre937&255;
    $$phi$trans$insert939 = (79212 + ($$phi$trans$insert938<<2)|0);
    $$pre940 = HEAP32[$$phi$trans$insert939>>2]|0;
    $$pre941 = HEAP8[$644>>0]|0;
    $$pre942 = HEAP8[$645>>0]|0;
    $$phi$trans$insert943 = $$pre942&255;
    $$phi$trans$insert944 = (79212 + ($$phi$trans$insert943<<2)|0);
    $$pre945 = HEAP32[$$phi$trans$insert944>>2]|0;
    $$pre946 = HEAP8[$647>>0]|0;
    $$pre947 = HEAP8[$648>>0]|0;
    $$phi$trans$insert948 = $$pre947&255;
    $$phi$trans$insert949 = (79212 + ($$phi$trans$insert948<<2)|0);
    $$pre950 = HEAP32[$$phi$trans$insert949>>2]|0;
    $$pre951 = HEAP8[$650>>0]|0;
    $$1857 = $638;$$2853 = $$0851905;$719 = $$pre932;$724 = $$pre936;$727 = $$pre935;$731 = $$pre937;$735 = $$pre941;$738 = $$pre940;$742 = $$pre942;$746 = $$pre946;$749 = $$pre945;$753 = $$pre947;$757 = $$pre951;$760 = $$pre950;
    label = 37;
    break;
   }
   case 2:  {
    $$pre953 = HEAP8[$639>>0]|0;
    $$phi$trans$insert954 = $$pre953&255;
    $$phi$trans$insert955 = (79212 + ($$phi$trans$insert954<<2)|0);
    $$pre956 = HEAP32[$$phi$trans$insert955>>2]|0;
    $$pre957 = HEAP8[$641>>0]|0;
    $$pre958 = HEAP8[$642>>0]|0;
    $$phi$trans$insert959 = $$pre958&255;
    $$phi$trans$insert960 = (79212 + ($$phi$trans$insert959<<2)|0);
    $$pre961 = HEAP32[$$phi$trans$insert960>>2]|0;
    $$pre962 = HEAP8[$644>>0]|0;
    $$pre963 = HEAP8[$645>>0]|0;
    $$phi$trans$insert964 = $$pre963&255;
    $$phi$trans$insert965 = (79212 + ($$phi$trans$insert964<<2)|0);
    $$pre966 = HEAP32[$$phi$trans$insert965>>2]|0;
    $$pre967 = HEAP8[$647>>0]|0;
    $$pre968 = HEAP8[$648>>0]|0;
    $$phi$trans$insert969 = $$pre968&255;
    $$phi$trans$insert970 = (79212 + ($$phi$trans$insert969<<2)|0);
    $$pre971 = HEAP32[$$phi$trans$insert970>>2]|0;
    $$pre972 = HEAP8[$650>>0]|0;
    $$2858 = $638;$$3854 = $$0851905;$782 = $$pre953;$787 = $$pre957;$790 = $$pre956;$794 = $$pre958;$798 = $$pre962;$801 = $$pre961;$805 = $$pre963;$809 = $$pre967;$812 = $$pre966;$816 = $$pre968;$820 = $$pre972;$823 = $$pre971;
    label = 38;
    break;
   }
   case 1:  {
    $$pre974 = HEAP8[$639>>0]|0;
    $$phi$trans$insert975 = $$pre974&255;
    $$phi$trans$insert976 = (79212 + ($$phi$trans$insert975<<2)|0);
    $$pre977 = HEAP32[$$phi$trans$insert976>>2]|0;
    $$pre978 = HEAP8[$641>>0]|0;
    $$pre979 = HEAP8[$642>>0]|0;
    $$phi$trans$insert980 = $$pre979&255;
    $$phi$trans$insert981 = (79212 + ($$phi$trans$insert980<<2)|0);
    $$pre982 = HEAP32[$$phi$trans$insert981>>2]|0;
    $$pre983 = HEAP8[$644>>0]|0;
    $$pre984 = HEAP8[$645>>0]|0;
    $$phi$trans$insert985 = $$pre984&255;
    $$phi$trans$insert986 = (79212 + ($$phi$trans$insert985<<2)|0);
    $$pre987 = HEAP32[$$phi$trans$insert986>>2]|0;
    $$pre988 = HEAP8[$647>>0]|0;
    $$pre989 = HEAP8[$648>>0]|0;
    $$phi$trans$insert990 = $$pre989&255;
    $$phi$trans$insert991 = (79212 + ($$phi$trans$insert990<<2)|0);
    $$pre992 = HEAP32[$$phi$trans$insert991>>2]|0;
    $$pre993 = HEAP8[$650>>0]|0;
    $$3859 = $638;$$4855 = $$0851905;$845 = $$pre974;$850 = $$pre978;$853 = $$pre977;$857 = $$pre979;$861 = $$pre983;$864 = $$pre982;$868 = $$pre984;$872 = $$pre988;$875 = $$pre987;$879 = $$pre989;$883 = $$pre993;$886 = $$pre992;
    label = 39;
    break;
   }
   default: {
    label = 40;
    break L73;
   }
   }
   while(1) {
    if ((label|0) == 36) {
     label = 0;
     $655 = $656&255;
     $657 = HEAP32[$$1852>>2]|0;
     $658 = HEAP32[$640>>2]|0;
     $659 = $658 & $657;
     $660 = $661&255;
     $662 = $659 >>> $660;
     $663 = (($664) + ($662)|0);
     $665 = HEAP8[$663>>0]|0;
     $666 = $665&255;
     $667 = $668&255;
     $669 = HEAP32[$643>>2]|0;
     $670 = $669 & $657;
     $671 = $672&255;
     $673 = $670 >>> $671;
     $674 = (($675) + ($673)|0);
     $676 = HEAP8[$674>>0]|0;
     $677 = $676&255;
     $678 = $679&255;
     $680 = HEAP32[$646>>2]|0;
     $681 = $680 & $657;
     $682 = $683&255;
     $684 = $681 >>> $682;
     $685 = (($686) + ($684)|0);
     $687 = HEAP8[$685>>0]|0;
     $688 = $687&255;
     $689 = $690&255;
     $691 = HEAP32[$649>>2]|0;
     $692 = $691 & $657;
     $693 = $694&255;
     $695 = $692 >>> $693;
     $696 = (($697) + ($695)|0);
     $698 = HEAP8[$696>>0]|0;
     $699 = $698&255;
     $700 = Math_imul($666, $651)|0;
     $701 = (($700>>>0) / 255)&-1;
     $702 = Math_imul($677, $652)|0;
     $703 = (($702>>>0) / 255)&-1;
     $704 = Math_imul($688, $653)|0;
     $705 = (($704>>>0) / 255)&-1;
     $706 = $701 >>> $655;
     $707 = $706 << $660;
     $708 = $703 >>> $667;
     $709 = $708 << $671;
     $710 = $709 | $707;
     $711 = $705 >>> $678;
     $712 = $711 << $682;
     $713 = $710 | $712;
     $714 = $699 >>> $689;
     $715 = $714 << $693;
     $716 = $713 | $715;
     HEAP32[$$1852>>2] = $716;
     $717 = ((($$1852)) + 4|0);
     $$1857 = $$0856;$$2853 = $717;$719 = $656;$724 = $661;$727 = $664;$731 = $668;$735 = $672;$738 = $675;$742 = $679;$746 = $683;$749 = $686;$753 = $690;$757 = $694;$760 = $697;
     label = 37;
     continue;
    }
    else if ((label|0) == 37) {
     label = 0;
     $718 = $719&255;
     $720 = HEAP32[$$2853>>2]|0;
     $721 = HEAP32[$640>>2]|0;
     $722 = $721 & $720;
     $723 = $724&255;
     $725 = $722 >>> $723;
     $726 = (($727) + ($725)|0);
     $728 = HEAP8[$726>>0]|0;
     $729 = $728&255;
     $730 = $731&255;
     $732 = HEAP32[$643>>2]|0;
     $733 = $732 & $720;
     $734 = $735&255;
     $736 = $733 >>> $734;
     $737 = (($738) + ($736)|0);
     $739 = HEAP8[$737>>0]|0;
     $740 = $739&255;
     $741 = $742&255;
     $743 = HEAP32[$646>>2]|0;
     $744 = $743 & $720;
     $745 = $746&255;
     $747 = $744 >>> $745;
     $748 = (($749) + ($747)|0);
     $750 = HEAP8[$748>>0]|0;
     $751 = $750&255;
     $752 = $753&255;
     $754 = HEAP32[$649>>2]|0;
     $755 = $754 & $720;
     $756 = $757&255;
     $758 = $755 >>> $756;
     $759 = (($760) + ($758)|0);
     $761 = HEAP8[$759>>0]|0;
     $762 = $761&255;
     $763 = Math_imul($729, $651)|0;
     $764 = (($763>>>0) / 255)&-1;
     $765 = Math_imul($740, $652)|0;
     $766 = (($765>>>0) / 255)&-1;
     $767 = Math_imul($751, $653)|0;
     $768 = (($767>>>0) / 255)&-1;
     $769 = $764 >>> $718;
     $770 = $769 << $723;
     $771 = $766 >>> $730;
     $772 = $771 << $734;
     $773 = $772 | $770;
     $774 = $768 >>> $741;
     $775 = $774 << $745;
     $776 = $773 | $775;
     $777 = $762 >>> $752;
     $778 = $777 << $756;
     $779 = $776 | $778;
     HEAP32[$$2853>>2] = $779;
     $780 = ((($$2853)) + 4|0);
     $$2858 = $$1857;$$3854 = $780;$782 = $719;$787 = $724;$790 = $727;$794 = $731;$798 = $735;$801 = $738;$805 = $742;$809 = $746;$812 = $749;$816 = $753;$820 = $757;$823 = $760;
     label = 38;
     continue;
    }
    else if ((label|0) == 38) {
     label = 0;
     $781 = $782&255;
     $783 = HEAP32[$$3854>>2]|0;
     $784 = HEAP32[$640>>2]|0;
     $785 = $784 & $783;
     $786 = $787&255;
     $788 = $785 >>> $786;
     $789 = (($790) + ($788)|0);
     $791 = HEAP8[$789>>0]|0;
     $792 = $791&255;
     $793 = $794&255;
     $795 = HEAP32[$643>>2]|0;
     $796 = $795 & $783;
     $797 = $798&255;
     $799 = $796 >>> $797;
     $800 = (($801) + ($799)|0);
     $802 = HEAP8[$800>>0]|0;
     $803 = $802&255;
     $804 = $805&255;
     $806 = HEAP32[$646>>2]|0;
     $807 = $806 & $783;
     $808 = $809&255;
     $810 = $807 >>> $808;
     $811 = (($812) + ($810)|0);
     $813 = HEAP8[$811>>0]|0;
     $814 = $813&255;
     $815 = $816&255;
     $817 = HEAP32[$649>>2]|0;
     $818 = $817 & $783;
     $819 = $820&255;
     $821 = $818 >>> $819;
     $822 = (($823) + ($821)|0);
     $824 = HEAP8[$822>>0]|0;
     $825 = $824&255;
     $826 = Math_imul($792, $651)|0;
     $827 = (($826>>>0) / 255)&-1;
     $828 = Math_imul($803, $652)|0;
     $829 = (($828>>>0) / 255)&-1;
     $830 = Math_imul($814, $653)|0;
     $831 = (($830>>>0) / 255)&-1;
     $832 = $827 >>> $781;
     $833 = $832 << $786;
     $834 = $829 >>> $793;
     $835 = $834 << $797;
     $836 = $835 | $833;
     $837 = $831 >>> $804;
     $838 = $837 << $808;
     $839 = $836 | $838;
     $840 = $825 >>> $815;
     $841 = $840 << $819;
     $842 = $839 | $841;
     HEAP32[$$3854>>2] = $842;
     $843 = ((($$3854)) + 4|0);
     $$3859 = $$2858;$$4855 = $843;$845 = $782;$850 = $787;$853 = $790;$857 = $794;$861 = $798;$864 = $801;$868 = $805;$872 = $809;$875 = $812;$879 = $816;$883 = $820;$886 = $823;
     label = 39;
     continue;
    }
    else if ((label|0) == 39) {
     label = 0;
     $844 = $845&255;
     $846 = HEAP32[$$4855>>2]|0;
     $847 = HEAP32[$640>>2]|0;
     $848 = $847 & $846;
     $849 = $850&255;
     $851 = $848 >>> $849;
     $852 = (($853) + ($851)|0);
     $854 = HEAP8[$852>>0]|0;
     $855 = $854&255;
     $856 = $857&255;
     $858 = HEAP32[$643>>2]|0;
     $859 = $858 & $846;
     $860 = $861&255;
     $862 = $859 >>> $860;
     $863 = (($864) + ($862)|0);
     $865 = HEAP8[$863>>0]|0;
     $866 = $865&255;
     $867 = $868&255;
     $869 = HEAP32[$646>>2]|0;
     $870 = $869 & $846;
     $871 = $872&255;
     $873 = $870 >>> $871;
     $874 = (($875) + ($873)|0);
     $876 = HEAP8[$874>>0]|0;
     $877 = $876&255;
     $878 = $879&255;
     $880 = HEAP32[$649>>2]|0;
     $881 = $880 & $846;
     $882 = $883&255;
     $884 = $881 >>> $882;
     $885 = (($886) + ($884)|0);
     $887 = HEAP8[$885>>0]|0;
     $888 = $887&255;
     $889 = Math_imul($855, $651)|0;
     $890 = (($889>>>0) / 255)&-1;
     $891 = Math_imul($866, $652)|0;
     $892 = (($891>>>0) / 255)&-1;
     $893 = Math_imul($877, $653)|0;
     $894 = (($893>>>0) / 255)&-1;
     $895 = $890 >>> $844;
     $896 = $895 << $849;
     $897 = $892 >>> $856;
     $898 = $897 << $860;
     $899 = $898 | $896;
     $900 = $894 >>> $867;
     $901 = $900 << $871;
     $902 = $899 | $901;
     $903 = $888 >>> $878;
     $904 = $903 << $882;
     $905 = $902 | $904;
     HEAP32[$$4855>>2] = $905;
     $906 = ((($$4855)) + 4|0);
     $907 = (($$3859) + -1)|0;
     $908 = ($$3859|0)>(1);
     if ($908) {
      $$0856 = $907;$$1852 = $906;$656 = $845;$661 = $850;$664 = $853;$668 = $857;$672 = $861;$675 = $864;$679 = $868;$683 = $872;$686 = $875;$690 = $879;$694 = $883;$697 = $886;
      label = 36;
      continue;
     } else {
      break;
     }
    }
   }
   $909 = (($906) + ($627<<2)|0);
   $910 = ($654|0)==(0);
   if ($910) {
    $$0 = 0;
    label = 56;
    break;
   } else {
    $$0851905 = $909;$$in = $654;
   }
  }
  if ((label|0) == 40) {
   // unreachable;
  }
  else if ((label|0) == 56) {
   return ($$0|0);
  }
  break;
 }
 default: {
  $911 = ((($1)) + 8|0);
  $912 = HEAP32[$911>>2]|0;
  $913 = ((($1)) + 12|0);
  $914 = HEAP32[$913>>2]|0;
  $915 = ((($0)) + 16|0);
  $916 = HEAP32[$915>>2]|0;
  $917 = (($916|0) / ($13|0))&-1;
  $918 = (($917) - ($912))|0;
  $919 = ($914|0)==(0);
  if ($919) {
   $$0 = 0;
   return ($$0|0);
  }
  $920 = ((($0)) + 20|0);
  $921 = HEAP32[$920>>2]|0;
  $922 = ((($1)) + 4|0);
  $923 = HEAP32[$922>>2]|0;
  $924 = Math_imul($923, $917)|0;
  $925 = (($921) + ($924<<2)|0);
  $926 = HEAP32[$1>>2]|0;
  $927 = (($925) + ($926<<2)|0);
  $928 = (($912) + 3)|0;
  $929 = (($928|0) / 4)&-1;
  $trunc892 = $912&255;
  $930 = $3&255;
  $931 = $4&255;
  $932 = $5&255;
  $933 = ((($8)) + 28|0);
  $934 = ((($8)) + 32|0);
  $935 = ((($8)) + 29|0);
  $936 = ((($8)) + 33|0);
  $937 = ((($8)) + 30|0);
  $938 = ((($8)) + 34|0);
  $939 = ((($8)) + 31|0);
  $940 = ((($8)) + 35|0);
  $$0874896 = $927;$$in909 = $914;
  L10: while(1) {
   $941 = (($$in909) + -1)|0;
   $trunc892$clear = $trunc892 & 3;
   switch ($trunc892$clear<<24>>24) {
   case 0:  {
    $$pre1163 = HEAP8[$933>>0]|0;
    $$pre1164 = HEAP8[$934>>0]|0;
    $$pre1165 = HEAP8[$935>>0]|0;
    $$pre1166 = HEAP8[$936>>0]|0;
    $$pre1167 = HEAP8[$937>>0]|0;
    $$pre1168 = HEAP8[$938>>0]|0;
    $$pre1169 = HEAP8[$939>>0]|0;
    $$pre1170 = HEAP8[$940>>0]|0;
    $$0870 = $929;$$1875 = $$0874896;$943 = $$pre1163;$946 = $$pre1164;$949 = $$pre1165;$952 = $$pre1166;$956 = $$pre1167;$959 = $$pre1168;$963 = $$pre1169;$966 = $$pre1170;
    label = 49;
    break;
   }
   case 3:  {
    $$pre1172 = HEAP8[$933>>0]|0;
    $$pre1173 = HEAP8[$934>>0]|0;
    $$pre1174 = HEAP8[$935>>0]|0;
    $$pre1175 = HEAP8[$936>>0]|0;
    $$pre1176 = HEAP8[$937>>0]|0;
    $$pre1177 = HEAP8[$938>>0]|0;
    $$pre1178 = HEAP8[$939>>0]|0;
    $$pre1179 = HEAP8[$940>>0]|0;
    $$1871 = $929;$$2876 = $$0874896;$971 = $$pre1172;$974 = $$pre1173;$977 = $$pre1174;$980 = $$pre1175;$984 = $$pre1176;$987 = $$pre1177;$991 = $$pre1178;$994 = $$pre1179;
    label = 50;
    break;
   }
   case 2:  {
    $$pre1181 = HEAP8[$933>>0]|0;
    $$pre1182 = HEAP8[$934>>0]|0;
    $$pre1183 = HEAP8[$935>>0]|0;
    $$pre1184 = HEAP8[$936>>0]|0;
    $$pre1185 = HEAP8[$937>>0]|0;
    $$pre1186 = HEAP8[$938>>0]|0;
    $$pre1187 = HEAP8[$939>>0]|0;
    $$pre1188 = HEAP8[$940>>0]|0;
    $$2872 = $929;$$3877 = $$0874896;$1002 = $$pre1182;$1005 = $$pre1183;$1008 = $$pre1184;$1012 = $$pre1185;$1015 = $$pre1186;$1019 = $$pre1187;$1022 = $$pre1188;$999 = $$pre1181;
    label = 51;
    break;
   }
   case 1:  {
    $$pre1190 = HEAP8[$933>>0]|0;
    $$pre1191 = HEAP8[$934>>0]|0;
    $$pre1192 = HEAP8[$935>>0]|0;
    $$pre1193 = HEAP8[$936>>0]|0;
    $$pre1194 = HEAP8[$937>>0]|0;
    $$pre1195 = HEAP8[$938>>0]|0;
    $$pre1196 = HEAP8[$939>>0]|0;
    $$pre1197 = HEAP8[$940>>0]|0;
    $$3873 = $929;$$4878 = $$0874896;$1027 = $$pre1190;$1030 = $$pre1191;$1033 = $$pre1192;$1036 = $$pre1193;$1040 = $$pre1194;$1043 = $$pre1195;$1047 = $$pre1196;$1050 = $$pre1197;
    label = 52;
    break;
   }
   default: {
    label = 53;
    break L10;
   }
   }
   while(1) {
    if ((label|0) == 49) {
     label = 0;
     $942 = $943&255;
     $944 = $930 >>> $942;
     $945 = $946&255;
     $947 = $944 << $945;
     $948 = $949&255;
     $950 = $931 >>> $948;
     $951 = $952&255;
     $953 = $950 << $951;
     $954 = $953 | $947;
     $955 = $956&255;
     $957 = $932 >>> $955;
     $958 = $959&255;
     $960 = $957 << $958;
     $961 = $954 | $960;
     $962 = $963&255;
     $964 = $9 >>> $962;
     $965 = $966&255;
     $967 = $964 << $965;
     $968 = $961 | $967;
     HEAP32[$$1875>>2] = $968;
     $969 = ((($$1875)) + 4|0);
     $$1871 = $$0870;$$2876 = $969;$971 = $943;$974 = $946;$977 = $949;$980 = $952;$984 = $956;$987 = $959;$991 = $963;$994 = $966;
     label = 50;
     continue;
    }
    else if ((label|0) == 50) {
     label = 0;
     $970 = $971&255;
     $972 = $930 >>> $970;
     $973 = $974&255;
     $975 = $972 << $973;
     $976 = $977&255;
     $978 = $931 >>> $976;
     $979 = $980&255;
     $981 = $978 << $979;
     $982 = $981 | $975;
     $983 = $984&255;
     $985 = $932 >>> $983;
     $986 = $987&255;
     $988 = $985 << $986;
     $989 = $982 | $988;
     $990 = $991&255;
     $992 = $9 >>> $990;
     $993 = $994&255;
     $995 = $992 << $993;
     $996 = $989 | $995;
     HEAP32[$$2876>>2] = $996;
     $997 = ((($$2876)) + 4|0);
     $$2872 = $$1871;$$3877 = $997;$1002 = $974;$1005 = $977;$1008 = $980;$1012 = $984;$1015 = $987;$1019 = $991;$1022 = $994;$999 = $971;
     label = 51;
     continue;
    }
    else if ((label|0) == 51) {
     label = 0;
     $998 = $999&255;
     $1000 = $930 >>> $998;
     $1001 = $1002&255;
     $1003 = $1000 << $1001;
     $1004 = $1005&255;
     $1006 = $931 >>> $1004;
     $1007 = $1008&255;
     $1009 = $1006 << $1007;
     $1010 = $1009 | $1003;
     $1011 = $1012&255;
     $1013 = $932 >>> $1011;
     $1014 = $1015&255;
     $1016 = $1013 << $1014;
     $1017 = $1010 | $1016;
     $1018 = $1019&255;
     $1020 = $9 >>> $1018;
     $1021 = $1022&255;
     $1023 = $1020 << $1021;
     $1024 = $1017 | $1023;
     HEAP32[$$3877>>2] = $1024;
     $1025 = ((($$3877)) + 4|0);
     $$3873 = $$2872;$$4878 = $1025;$1027 = $999;$1030 = $1002;$1033 = $1005;$1036 = $1008;$1040 = $1012;$1043 = $1015;$1047 = $1019;$1050 = $1022;
     label = 52;
     continue;
    }
    else if ((label|0) == 52) {
     label = 0;
     $1026 = $1027&255;
     $1028 = $930 >>> $1026;
     $1029 = $1030&255;
     $1031 = $1028 << $1029;
     $1032 = $1033&255;
     $1034 = $931 >>> $1032;
     $1035 = $1036&255;
     $1037 = $1034 << $1035;
     $1038 = $1037 | $1031;
     $1039 = $1040&255;
     $1041 = $932 >>> $1039;
     $1042 = $1043&255;
     $1044 = $1041 << $1042;
     $1045 = $1038 | $1044;
     $1046 = $1047&255;
     $1048 = $9 >>> $1046;
     $1049 = $1050&255;
     $1051 = $1048 << $1049;
     $1052 = $1045 | $1051;
     HEAP32[$$4878>>2] = $1052;
     $1053 = ((($$4878)) + 4|0);
     $1054 = (($$3873) + -1)|0;
     $1055 = ($$3873|0)>(1);
     if ($1055) {
      $$0870 = $1054;$$1875 = $1053;$943 = $1027;$946 = $1030;$949 = $1033;$952 = $1036;$956 = $1040;$959 = $1043;$963 = $1047;$966 = $1050;
      label = 49;
      continue;
     } else {
      break;
     }
    }
   }
   $1056 = (($1053) + ($918<<2)|0);
   $1057 = ($941|0)==(0);
   if ($1057) {
    $$0 = 0;
    label = 56;
    break;
   } else {
    $$0874896 = $1056;$$in909 = $941;
   }
  }
  if ((label|0) == 53) {
   // unreachable;
  }
  else if ((label|0) == 56) {
   return ($$0|0);
  }
 }
 }
 return (0)|0;
}
function _SDL_BlendFillRect_RGB555($0,$1,$2,$3,$4,$5,$6) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 var $$ = 0, $$0505574 = 0, $$0510 = 0, $$0515577 = 0, $$0520 = 0, $$0525580 = 0, $$0530 = 0, $$0535550 = 0, $$0535550$us = 0, $$0535550$us551 = 0, $$0535550$us562 = 0, $$0540$us = 0, $$1 = 0, $$10 = 0, $$11 = 0, $$1506 = 0, $$1511 = 0, $$1516 = 0, $$1521 = 0, $$1526 = 0;
 var $$1531 = 0, $$1536$us = 0, $$1541$us554639 = 0, $$2 = 0, $$2507 = 0, $$2512 = 0, $$2517 = 0, $$2522 = 0, $$2527 = 0, $$2532 = 0, $$2537$us555640 = 0, $$2542$us567644 = 0, $$3 = 0, $$3508 = 0, $$3513 = 0, $$3518 = 0, $$3523 = 0, $$3528 = 0, $$3533 = 0, $$3538$us568645 = 0;
 var $$3543635 = 0, $$4 = 0, $$4509 = 0, $$4519 = 0, $$4529 = 0, $$4539636 = 0, $$5 = 0, $$6 = 0, $$7 = 0, $$8 = 0, $$9 = 0, $$in = 0, $$in584 = 0, $$in585 = 0, $$lcssa = 0, $$lcssa633 = 0, $$lcssa634 = 0, $$pre = 0, $$pre596 = 0, $$pre598 = 0;
 var $$pre600 = 0, $$pre602 = 0, $$pre604 = 0, $$pre606 = 0, $$pre608 = 0, $$pre610 = 0, $$pre612 = 0, $$pre614 = 0, $$pre616 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0;
 var $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0;
 var $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0;
 var $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0;
 var $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0;
 var $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0;
 var $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0;
 var $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0;
 var $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0;
 var $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0;
 var $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0;
 var $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0;
 var $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0;
 var $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $40 = 0;
 var $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0;
 var $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0;
 var $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0;
 var $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0;
 var $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0;
 var $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0;
 var $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0;
 var $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0;
 var $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0;
 var $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0;
 var $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $trunc = 0, $trunc$clear = 0, $trunc544 = 0, $trunc544$clear = 0, $trunc545 = 0, $trunc545$clear = 0, $trunc546 = 0, $trunc546$clear = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $7 = $6 ^ -1;
 $8 = $7&255;
 switch ($2|0) {
 case 1:  {
  $9 = ((($1)) + 8|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ((($1)) + 12|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ((($0)) + 16|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = ((($0)) + 4|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ((($16)) + 9|0);
  $18 = HEAP8[$17>>0]|0;
  $19 = $18&255;
  $20 = (($14|0) / ($19|0))&-1;
  $21 = (($20) - ($10))|0;
  $22 = ($12|0)==(0);
  if ($22) {
   return 0;
  }
  $23 = ((($0)) + 20|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = ((($1)) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = Math_imul($26, $20)|0;
  $28 = (($24) + ($27<<1)|0);
  $29 = HEAP32[$1>>2]|0;
  $30 = (($28) + ($29<<1)|0);
  $31 = (($10) + 3)|0;
  $32 = (($31|0) / 4)&-1;
  $trunc545 = $10&255;
  $33 = $3&255;
  $34 = $4&255;
  $35 = $5&255;
  $$0505574 = $30;$$in585 = $12;
  L41: while(1) {
   $36 = (($$in585) + -1)|0;
   $trunc545$clear = $trunc545 & 3;
   switch ($trunc545$clear<<24>>24) {
   case 0:  {
    $$pre610 = HEAP32[(79224)>>2]|0;
    $$0510 = $32;$$1506 = $$0505574;$42 = $$pre610;
    label = 9;
    break;
   }
   case 3:  {
    $$pre612 = HEAP32[(79224)>>2]|0;
    $$1511 = $32;$$2507 = $$0505574;$77 = $$pre612;
    label = 10;
    break;
   }
   case 2:  {
    $$pre614 = HEAP32[(79224)>>2]|0;
    $$2512 = $32;$$3508 = $$0505574;$112 = $$pre614;
    label = 11;
    break;
   }
   case 1:  {
    $$pre616 = HEAP32[(79224)>>2]|0;
    $$3513 = $32;$$4509 = $$0505574;$147 = $$pre616;
    label = 12;
    break;
   }
   default: {
    label = 13;
    break L41;
   }
   }
   while(1) {
    if ((label|0) == 9) {
     label = 0;
     $37 = HEAP16[$$1506>>1]|0;
     $38 = $37&65535;
     $39 = $38 >>> 10;
     $40 = $39 & 31;
     $41 = (($42) + ($40)|0);
     $43 = HEAP8[$41>>0]|0;
     $44 = $43&255;
     $45 = $38 >>> 5;
     $46 = $45 & 31;
     $47 = (($42) + ($46)|0);
     $48 = HEAP8[$47>>0]|0;
     $49 = $48&255;
     $50 = $38 & 31;
     $51 = (($42) + ($50)|0);
     $52 = HEAP8[$51>>0]|0;
     $53 = $52&255;
     $54 = Math_imul($44, $8)|0;
     $55 = (($54>>>0) / 255)&-1;
     $56 = (($55) + ($33))|0;
     $57 = Math_imul($49, $8)|0;
     $58 = (($57>>>0) / 255)&-1;
     $59 = (($58) + ($34))|0;
     $60 = Math_imul($53, $8)|0;
     $61 = (($60>>>0) / 255)&-1;
     $62 = (($61) + ($35))|0;
     $63 = $56 >>> 3;
     $64 = $63 << 10;
     $65 = $59 >>> 3;
     $66 = $65 << 5;
     $67 = $66 | $64;
     $68 = $62 >>> 3;
     $69 = $67 | $68;
     $70 = $69&65535;
     HEAP16[$$1506>>1] = $70;
     $71 = ((($$1506)) + 2|0);
     $$1511 = $$0510;$$2507 = $71;$77 = $42;
     label = 10;
     continue;
    }
    else if ((label|0) == 10) {
     label = 0;
     $72 = HEAP16[$$2507>>1]|0;
     $73 = $72&65535;
     $74 = $73 >>> 10;
     $75 = $74 & 31;
     $76 = (($77) + ($75)|0);
     $78 = HEAP8[$76>>0]|0;
     $79 = $78&255;
     $80 = $73 >>> 5;
     $81 = $80 & 31;
     $82 = (($77) + ($81)|0);
     $83 = HEAP8[$82>>0]|0;
     $84 = $83&255;
     $85 = $73 & 31;
     $86 = (($77) + ($85)|0);
     $87 = HEAP8[$86>>0]|0;
     $88 = $87&255;
     $89 = Math_imul($79, $8)|0;
     $90 = (($89>>>0) / 255)&-1;
     $91 = (($90) + ($33))|0;
     $92 = Math_imul($84, $8)|0;
     $93 = (($92>>>0) / 255)&-1;
     $94 = (($93) + ($34))|0;
     $95 = Math_imul($88, $8)|0;
     $96 = (($95>>>0) / 255)&-1;
     $97 = (($96) + ($35))|0;
     $98 = $91 >>> 3;
     $99 = $98 << 10;
     $100 = $94 >>> 3;
     $101 = $100 << 5;
     $102 = $101 | $99;
     $103 = $97 >>> 3;
     $104 = $102 | $103;
     $105 = $104&65535;
     HEAP16[$$2507>>1] = $105;
     $106 = ((($$2507)) + 2|0);
     $$2512 = $$1511;$$3508 = $106;$112 = $77;
     label = 11;
     continue;
    }
    else if ((label|0) == 11) {
     label = 0;
     $107 = HEAP16[$$3508>>1]|0;
     $108 = $107&65535;
     $109 = $108 >>> 10;
     $110 = $109 & 31;
     $111 = (($112) + ($110)|0);
     $113 = HEAP8[$111>>0]|0;
     $114 = $113&255;
     $115 = $108 >>> 5;
     $116 = $115 & 31;
     $117 = (($112) + ($116)|0);
     $118 = HEAP8[$117>>0]|0;
     $119 = $118&255;
     $120 = $108 & 31;
     $121 = (($112) + ($120)|0);
     $122 = HEAP8[$121>>0]|0;
     $123 = $122&255;
     $124 = Math_imul($114, $8)|0;
     $125 = (($124>>>0) / 255)&-1;
     $126 = (($125) + ($33))|0;
     $127 = Math_imul($119, $8)|0;
     $128 = (($127>>>0) / 255)&-1;
     $129 = (($128) + ($34))|0;
     $130 = Math_imul($123, $8)|0;
     $131 = (($130>>>0) / 255)&-1;
     $132 = (($131) + ($35))|0;
     $133 = $126 >>> 3;
     $134 = $133 << 10;
     $135 = $129 >>> 3;
     $136 = $135 << 5;
     $137 = $136 | $134;
     $138 = $132 >>> 3;
     $139 = $137 | $138;
     $140 = $139&65535;
     HEAP16[$$3508>>1] = $140;
     $141 = ((($$3508)) + 2|0);
     $$3513 = $$2512;$$4509 = $141;$147 = $112;
     label = 12;
     continue;
    }
    else if ((label|0) == 12) {
     label = 0;
     $142 = HEAP16[$$4509>>1]|0;
     $143 = $142&65535;
     $144 = $143 >>> 10;
     $145 = $144 & 31;
     $146 = (($147) + ($145)|0);
     $148 = HEAP8[$146>>0]|0;
     $149 = $148&255;
     $150 = $143 >>> 5;
     $151 = $150 & 31;
     $152 = (($147) + ($151)|0);
     $153 = HEAP8[$152>>0]|0;
     $154 = $153&255;
     $155 = $143 & 31;
     $156 = (($147) + ($155)|0);
     $157 = HEAP8[$156>>0]|0;
     $158 = $157&255;
     $159 = Math_imul($149, $8)|0;
     $160 = (($159>>>0) / 255)&-1;
     $161 = (($160) + ($33))|0;
     $162 = Math_imul($154, $8)|0;
     $163 = (($162>>>0) / 255)&-1;
     $164 = (($163) + ($34))|0;
     $165 = Math_imul($158, $8)|0;
     $166 = (($165>>>0) / 255)&-1;
     $167 = (($166) + ($35))|0;
     $168 = $161 >>> 3;
     $169 = $168 << 10;
     $170 = $164 >>> 3;
     $171 = $170 << 5;
     $172 = $171 | $169;
     $173 = $167 >>> 3;
     $174 = $172 | $173;
     $175 = $174&65535;
     HEAP16[$$4509>>1] = $175;
     $176 = ((($$4509)) + 2|0);
     $177 = (($$3513) + -1)|0;
     $178 = ($$3513|0)>(1);
     if ($178) {
      $$0510 = $177;$$1506 = $176;$42 = $147;
      label = 9;
      continue;
     } else {
      break;
     }
    }
   }
   $179 = (($176) + ($21<<1)|0);
   $180 = ($36|0)==(0);
   if ($180) {
    label = 58;
    break;
   } else {
    $$0505574 = $179;$$in585 = $36;
   }
  }
  if ((label|0) == 13) {
   // unreachable;
  }
  else if ((label|0) == 58) {
   return 0;
  }
  break;
 }
 case 2:  {
  $181 = ((($1)) + 8|0);
  $182 = HEAP32[$181>>2]|0;
  $183 = ((($1)) + 12|0);
  $184 = HEAP32[$183>>2]|0;
  $185 = ((($0)) + 16|0);
  $186 = HEAP32[$185>>2]|0;
  $187 = ((($0)) + 4|0);
  $188 = HEAP32[$187>>2]|0;
  $189 = ((($188)) + 9|0);
  $190 = HEAP8[$189>>0]|0;
  $191 = $190&255;
  $192 = (($186|0) / ($191|0))&-1;
  $193 = (($192) - ($182))|0;
  $194 = ($184|0)==(0);
  if ($194) {
   return 0;
  }
  $195 = ((($0)) + 20|0);
  $196 = HEAP32[$195>>2]|0;
  $197 = ((($1)) + 4|0);
  $198 = HEAP32[$197>>2]|0;
  $199 = Math_imul($198, $192)|0;
  $200 = (($196) + ($199<<1)|0);
  $201 = HEAP32[$1>>2]|0;
  $202 = (($200) + ($201<<1)|0);
  $203 = (($182) + 3)|0;
  $204 = (($203|0) / 4)&-1;
  $trunc544 = $182&255;
  $205 = $3&255;
  $206 = $4&255;
  $207 = $5&255;
  $$0515577 = $202;$$in584 = $184;
  L62: while(1) {
   $208 = (($$in584) + -1)|0;
   $trunc544$clear = $trunc544 & 3;
   switch ($trunc544$clear<<24>>24) {
   case 0:  {
    $$pre602 = HEAP32[(79224)>>2]|0;
    $$0520 = $204;$$1516 = $$0515577;$214 = $$pre602;
    label = 22;
    break;
   }
   case 3:  {
    $$pre604 = HEAP32[(79224)>>2]|0;
    $$1521 = $204;$$2517 = $$0515577;$246 = $$pre604;
    label = 23;
    break;
   }
   case 2:  {
    $$pre606 = HEAP32[(79224)>>2]|0;
    $$2522 = $204;$$3518 = $$0515577;$278 = $$pre606;
    label = 24;
    break;
   }
   case 1:  {
    $$pre608 = HEAP32[(79224)>>2]|0;
    $$3523 = $204;$$4519 = $$0515577;$310 = $$pre608;
    label = 25;
    break;
   }
   default: {
    label = 26;
    break L62;
   }
   }
   while(1) {
    if ((label|0) == 22) {
     label = 0;
     $209 = HEAP16[$$1516>>1]|0;
     $210 = $209&65535;
     $211 = $210 >>> 10;
     $212 = $211 & 31;
     $213 = (($214) + ($212)|0);
     $215 = HEAP8[$213>>0]|0;
     $216 = $215&255;
     $217 = $210 >>> 5;
     $218 = $217 & 31;
     $219 = (($214) + ($218)|0);
     $220 = HEAP8[$219>>0]|0;
     $221 = $220&255;
     $222 = $210 & 31;
     $223 = (($214) + ($222)|0);
     $224 = HEAP8[$223>>0]|0;
     $225 = $224&255;
     $226 = (($216) + ($205))|0;
     $227 = ($226>>>0)<(255);
     $$7 = $227 ? $226 : 255;
     $228 = (($221) + ($206))|0;
     $229 = ($228>>>0)<(255);
     $$ = $229 ? $228 : 255;
     $230 = (($225) + ($207))|0;
     $231 = ($230>>>0)<(255);
     $$11 = $231 ? $230 : 255;
     $232 = $$7 >>> 3;
     $233 = $232 << 10;
     $234 = $$ >>> 3;
     $235 = $234 << 5;
     $236 = $235 | $233;
     $237 = $$11 >>> 3;
     $238 = $236 | $237;
     $239 = $238&65535;
     HEAP16[$$1516>>1] = $239;
     $240 = ((($$1516)) + 2|0);
     $$1521 = $$0520;$$2517 = $240;$246 = $214;
     label = 23;
     continue;
    }
    else if ((label|0) == 23) {
     label = 0;
     $241 = HEAP16[$$2517>>1]|0;
     $242 = $241&65535;
     $243 = $242 >>> 10;
     $244 = $243 & 31;
     $245 = (($246) + ($244)|0);
     $247 = HEAP8[$245>>0]|0;
     $248 = $247&255;
     $249 = $242 >>> 5;
     $250 = $249 & 31;
     $251 = (($246) + ($250)|0);
     $252 = HEAP8[$251>>0]|0;
     $253 = $252&255;
     $254 = $242 & 31;
     $255 = (($246) + ($254)|0);
     $256 = HEAP8[$255>>0]|0;
     $257 = $256&255;
     $258 = (($248) + ($205))|0;
     $259 = ($258>>>0)<(255);
     $$1 = $259 ? $258 : 255;
     $260 = (($253) + ($206))|0;
     $261 = ($260>>>0)<(255);
     $$8 = $261 ? $260 : 255;
     $262 = (($257) + ($207))|0;
     $263 = ($262>>>0)<(255);
     $$2 = $263 ? $262 : 255;
     $264 = $$1 >>> 3;
     $265 = $264 << 10;
     $266 = $$8 >>> 3;
     $267 = $266 << 5;
     $268 = $267 | $265;
     $269 = $$2 >>> 3;
     $270 = $268 | $269;
     $271 = $270&65535;
     HEAP16[$$2517>>1] = $271;
     $272 = ((($$2517)) + 2|0);
     $$2522 = $$1521;$$3518 = $272;$278 = $246;
     label = 24;
     continue;
    }
    else if ((label|0) == 24) {
     label = 0;
     $273 = HEAP16[$$3518>>1]|0;
     $274 = $273&65535;
     $275 = $274 >>> 10;
     $276 = $275 & 31;
     $277 = (($278) + ($276)|0);
     $279 = HEAP8[$277>>0]|0;
     $280 = $279&255;
     $281 = $274 >>> 5;
     $282 = $281 & 31;
     $283 = (($278) + ($282)|0);
     $284 = HEAP8[$283>>0]|0;
     $285 = $284&255;
     $286 = $274 & 31;
     $287 = (($278) + ($286)|0);
     $288 = HEAP8[$287>>0]|0;
     $289 = $288&255;
     $290 = (($280) + ($205))|0;
     $291 = ($290>>>0)<(255);
     $$3 = $291 ? $290 : 255;
     $292 = (($285) + ($206))|0;
     $293 = ($292>>>0)<(255);
     $$9 = $293 ? $292 : 255;
     $294 = (($289) + ($207))|0;
     $295 = ($294>>>0)<(255);
     $$4 = $295 ? $294 : 255;
     $296 = $$3 >>> 3;
     $297 = $296 << 10;
     $298 = $$9 >>> 3;
     $299 = $298 << 5;
     $300 = $299 | $297;
     $301 = $$4 >>> 3;
     $302 = $300 | $301;
     $303 = $302&65535;
     HEAP16[$$3518>>1] = $303;
     $304 = ((($$3518)) + 2|0);
     $$3523 = $$2522;$$4519 = $304;$310 = $278;
     label = 25;
     continue;
    }
    else if ((label|0) == 25) {
     label = 0;
     $305 = HEAP16[$$4519>>1]|0;
     $306 = $305&65535;
     $307 = $306 >>> 10;
     $308 = $307 & 31;
     $309 = (($310) + ($308)|0);
     $311 = HEAP8[$309>>0]|0;
     $312 = $311&255;
     $313 = $306 >>> 5;
     $314 = $313 & 31;
     $315 = (($310) + ($314)|0);
     $316 = HEAP8[$315>>0]|0;
     $317 = $316&255;
     $318 = $306 & 31;
     $319 = (($310) + ($318)|0);
     $320 = HEAP8[$319>>0]|0;
     $321 = $320&255;
     $322 = (($312) + ($205))|0;
     $323 = ($322>>>0)<(255);
     $$5 = $323 ? $322 : 255;
     $324 = (($317) + ($206))|0;
     $325 = ($324>>>0)<(255);
     $$10 = $325 ? $324 : 255;
     $326 = (($321) + ($207))|0;
     $327 = ($326>>>0)<(255);
     $$6 = $327 ? $326 : 255;
     $328 = $$5 >>> 3;
     $329 = $328 << 10;
     $330 = $$10 >>> 3;
     $331 = $330 << 5;
     $332 = $331 | $329;
     $333 = $$6 >>> 3;
     $334 = $332 | $333;
     $335 = $334&65535;
     HEAP16[$$4519>>1] = $335;
     $336 = ((($$4519)) + 2|0);
     $337 = (($$3523) + -1)|0;
     $338 = ($$3523|0)>(1);
     if ($338) {
      $$0520 = $337;$$1516 = $336;$214 = $310;
      label = 22;
      continue;
     } else {
      break;
     }
    }
   }
   $339 = (($336) + ($193<<1)|0);
   $340 = ($208|0)==(0);
   if ($340) {
    label = 58;
    break;
   } else {
    $$0515577 = $339;$$in584 = $208;
   }
  }
  if ((label|0) == 26) {
   // unreachable;
  }
  else if ((label|0) == 58) {
   return 0;
  }
  break;
 }
 case 4:  {
  $341 = ((($1)) + 8|0);
  $342 = HEAP32[$341>>2]|0;
  $343 = ((($1)) + 12|0);
  $344 = HEAP32[$343>>2]|0;
  $345 = ((($0)) + 16|0);
  $346 = HEAP32[$345>>2]|0;
  $347 = ((($0)) + 4|0);
  $348 = HEAP32[$347>>2]|0;
  $349 = ((($348)) + 9|0);
  $350 = HEAP8[$349>>0]|0;
  $351 = $350&255;
  $352 = (($346|0) / ($351|0))&-1;
  $353 = (($352) - ($342))|0;
  $354 = ($344|0)==(0);
  if ($354) {
   return 0;
  }
  $355 = ((($0)) + 20|0);
  $356 = HEAP32[$355>>2]|0;
  $357 = ((($1)) + 4|0);
  $358 = HEAP32[$357>>2]|0;
  $359 = Math_imul($358, $352)|0;
  $360 = (($356) + ($359<<1)|0);
  $361 = HEAP32[$1>>2]|0;
  $362 = (($360) + ($361<<1)|0);
  $363 = (($342) + 3)|0;
  $364 = (($363|0) / 4)&-1;
  $trunc = $342&255;
  $365 = $3&255;
  $366 = $4&255;
  $367 = $5&255;
  $$0525580 = $362;$$in = $344;
  L83: while(1) {
   $368 = (($$in) + -1)|0;
   $trunc$clear = $trunc & 3;
   switch ($trunc$clear<<24>>24) {
   case 0:  {
    $$pre = HEAP32[(79224)>>2]|0;
    $$0530 = $364;$$1526 = $$0525580;$374 = $$pre;
    label = 35;
    break;
   }
   case 3:  {
    $$pre596 = HEAP32[(79224)>>2]|0;
    $$1531 = $364;$$2527 = $$0525580;$406 = $$pre596;
    label = 36;
    break;
   }
   case 2:  {
    $$pre598 = HEAP32[(79224)>>2]|0;
    $$2532 = $364;$$3528 = $$0525580;$438 = $$pre598;
    label = 37;
    break;
   }
   case 1:  {
    $$pre600 = HEAP32[(79224)>>2]|0;
    $$3533 = $364;$$4529 = $$0525580;$470 = $$pre600;
    label = 38;
    break;
   }
   default: {
    label = 39;
    break L83;
   }
   }
   while(1) {
    if ((label|0) == 35) {
     label = 0;
     $369 = HEAP16[$$1526>>1]|0;
     $370 = $369&65535;
     $371 = $370 >>> 10;
     $372 = $371 & 31;
     $373 = (($374) + ($372)|0);
     $375 = HEAP8[$373>>0]|0;
     $376 = $375&255;
     $377 = $370 >>> 5;
     $378 = $377 & 31;
     $379 = (($374) + ($378)|0);
     $380 = HEAP8[$379>>0]|0;
     $381 = $380&255;
     $382 = $370 & 31;
     $383 = (($374) + ($382)|0);
     $384 = HEAP8[$383>>0]|0;
     $385 = $384&255;
     $386 = Math_imul($376, $365)|0;
     $387 = (($386>>>0) / 255)&-1;
     $388 = Math_imul($381, $366)|0;
     $389 = (($388>>>0) / 255)&-1;
     $390 = Math_imul($385, $367)|0;
     $391 = (($390>>>0) / 255)&-1;
     $392 = $387 >>> 3;
     $393 = $392 << 10;
     $394 = $389 >>> 3;
     $395 = $394 << 5;
     $396 = $395 | $393;
     $397 = $391 >>> 3;
     $398 = $396 | $397;
     $399 = $398&65535;
     HEAP16[$$1526>>1] = $399;
     $400 = ((($$1526)) + 2|0);
     $$1531 = $$0530;$$2527 = $400;$406 = $374;
     label = 36;
     continue;
    }
    else if ((label|0) == 36) {
     label = 0;
     $401 = HEAP16[$$2527>>1]|0;
     $402 = $401&65535;
     $403 = $402 >>> 10;
     $404 = $403 & 31;
     $405 = (($406) + ($404)|0);
     $407 = HEAP8[$405>>0]|0;
     $408 = $407&255;
     $409 = $402 >>> 5;
     $410 = $409 & 31;
     $411 = (($406) + ($410)|0);
     $412 = HEAP8[$411>>0]|0;
     $413 = $412&255;
     $414 = $402 & 31;
     $415 = (($406) + ($414)|0);
     $416 = HEAP8[$415>>0]|0;
     $417 = $416&255;
     $418 = Math_imul($408, $365)|0;
     $419 = (($418>>>0) / 255)&-1;
     $420 = Math_imul($413, $366)|0;
     $421 = (($420>>>0) / 255)&-1;
     $422 = Math_imul($417, $367)|0;
     $423 = (($422>>>0) / 255)&-1;
     $424 = $419 >>> 3;
     $425 = $424 << 10;
     $426 = $421 >>> 3;
     $427 = $426 << 5;
     $428 = $427 | $425;
     $429 = $423 >>> 3;
     $430 = $428 | $429;
     $431 = $430&65535;
     HEAP16[$$2527>>1] = $431;
     $432 = ((($$2527)) + 2|0);
     $$2532 = $$1531;$$3528 = $432;$438 = $406;
     label = 37;
     continue;
    }
    else if ((label|0) == 37) {
     label = 0;
     $433 = HEAP16[$$3528>>1]|0;
     $434 = $433&65535;
     $435 = $434 >>> 10;
     $436 = $435 & 31;
     $437 = (($438) + ($436)|0);
     $439 = HEAP8[$437>>0]|0;
     $440 = $439&255;
     $441 = $434 >>> 5;
     $442 = $441 & 31;
     $443 = (($438) + ($442)|0);
     $444 = HEAP8[$443>>0]|0;
     $445 = $444&255;
     $446 = $434 & 31;
     $447 = (($438) + ($446)|0);
     $448 = HEAP8[$447>>0]|0;
     $449 = $448&255;
     $450 = Math_imul($440, $365)|0;
     $451 = (($450>>>0) / 255)&-1;
     $452 = Math_imul($445, $366)|0;
     $453 = (($452>>>0) / 255)&-1;
     $454 = Math_imul($449, $367)|0;
     $455 = (($454>>>0) / 255)&-1;
     $456 = $451 >>> 3;
     $457 = $456 << 10;
     $458 = $453 >>> 3;
     $459 = $458 << 5;
     $460 = $459 | $457;
     $461 = $455 >>> 3;
     $462 = $460 | $461;
     $463 = $462&65535;
     HEAP16[$$3528>>1] = $463;
     $464 = ((($$3528)) + 2|0);
     $$3533 = $$2532;$$4529 = $464;$470 = $438;
     label = 38;
     continue;
    }
    else if ((label|0) == 38) {
     label = 0;
     $465 = HEAP16[$$4529>>1]|0;
     $466 = $465&65535;
     $467 = $466 >>> 10;
     $468 = $467 & 31;
     $469 = (($470) + ($468)|0);
     $471 = HEAP8[$469>>0]|0;
     $472 = $471&255;
     $473 = $466 >>> 5;
     $474 = $473 & 31;
     $475 = (($470) + ($474)|0);
     $476 = HEAP8[$475>>0]|0;
     $477 = $476&255;
     $478 = $466 & 31;
     $479 = (($470) + ($478)|0);
     $480 = HEAP8[$479>>0]|0;
     $481 = $480&255;
     $482 = Math_imul($472, $365)|0;
     $483 = (($482>>>0) / 255)&-1;
     $484 = Math_imul($477, $366)|0;
     $485 = (($484>>>0) / 255)&-1;
     $486 = Math_imul($481, $367)|0;
     $487 = (($486>>>0) / 255)&-1;
     $488 = $483 >>> 3;
     $489 = $488 << 10;
     $490 = $485 >>> 3;
     $491 = $490 << 5;
     $492 = $491 | $489;
     $493 = $487 >>> 3;
     $494 = $492 | $493;
     $495 = $494&65535;
     HEAP16[$$4529>>1] = $495;
     $496 = ((($$4529)) + 2|0);
     $497 = (($$3533) + -1)|0;
     $498 = ($$3533|0)>(1);
     if ($498) {
      $$0530 = $497;$$1526 = $496;$374 = $470;
      label = 35;
      continue;
     } else {
      break;
     }
    }
   }
   $499 = (($496) + ($353<<1)|0);
   $500 = ($368|0)==(0);
   if ($500) {
    label = 58;
    break;
   } else {
    $$0525580 = $499;$$in = $368;
   }
  }
  if ((label|0) == 39) {
   // unreachable;
  }
  else if ((label|0) == 58) {
   return 0;
  }
  break;
 }
 default: {
  $501 = ((($1)) + 8|0);
  $502 = HEAP32[$501>>2]|0;
  $503 = ((($1)) + 12|0);
  $504 = HEAP32[$503>>2]|0;
  $505 = ((($0)) + 16|0);
  $506 = HEAP32[$505>>2]|0;
  $507 = ((($0)) + 4|0);
  $508 = HEAP32[$507>>2]|0;
  $509 = ((($508)) + 9|0);
  $510 = HEAP8[$509>>0]|0;
  $511 = $510&255;
  $512 = (($506|0) / ($511|0))&-1;
  $513 = (($512) - ($502))|0;
  $514 = ((($0)) + 20|0);
  $515 = HEAP32[$514>>2]|0;
  $516 = ((($1)) + 4|0);
  $517 = HEAP32[$516>>2]|0;
  $518 = Math_imul($517, $512)|0;
  $519 = (($515) + ($518<<1)|0);
  $520 = HEAP32[$1>>2]|0;
  $521 = (($519) + ($520<<1)|0);
  $522 = (($504) + -1)|0;
  $523 = ($504|0)==(0);
  if ($523) {
   return 0;
  }
  $524 = (($502) + 3)|0;
  $525 = (($524|0) / 4)&-1;
  $trunc546 = $502&255;
  $526 = $3&255;
  $527 = $4&255;
  $528 = $5&255;
  $529 = $526 >>> 3;
  $530 = $529 << 10;
  $531 = $527 >>> 3;
  $532 = $531 << 5;
  $533 = $532 | $530;
  $534 = $528 >>> 3;
  $535 = $533 | $534;
  $536 = $535&65535;
  $trunc546$clear = $trunc546 & 3;
  switch ($trunc546$clear<<24>>24) {
  case 0:  {
   $$0535550$us = $521;$548 = $522;
   while(1) {
    $$0540$us = $525;$$1536$us = $$0535550$us;
    while(1) {
     HEAP16[$$1536$us>>1] = $536;
     $540 = ((($$1536$us)) + 2|0);
     HEAP16[$540>>1] = $536;
     $541 = ((($$1536$us)) + 4|0);
     HEAP16[$541>>1] = $536;
     $542 = ((($$1536$us)) + 6|0);
     HEAP16[$542>>1] = $536;
     $543 = ((($$1536$us)) + 8|0);
     $544 = (($$0540$us) + -1)|0;
     $545 = ($$0540$us|0)>(1);
     if ($545) {
      $$0540$us = $544;$$1536$us = $543;
     } else {
      break;
     }
    }
    $546 = (($543) + ($513<<1)|0);
    $547 = (($548) + -1)|0;
    $549 = ($548|0)==(0);
    if ($549) {
     break;
    } else {
     $$0535550$us = $546;$548 = $547;
    }
   }
   return 0;
   break;
  }
  case 3:  {
   $538 = ($524|0)>(7);
   $$0535550$us551 = $521;$562 = $522;
   while(1) {
    HEAP16[$$0535550$us551>>1] = $536;
    $550 = ((($$0535550$us551)) + 2|0);
    HEAP16[$550>>1] = $536;
    $551 = ((($$0535550$us551)) + 4|0);
    HEAP16[$551>>1] = $536;
    $552 = ((($$0535550$us551)) + 6|0);
    if ($538) {
     $$1541$us554639 = $525;$$2537$us555640 = $$0535550$us551;$554 = $552;
     while(1) {
      $553 = (($$1541$us554639) + -1)|0;
      HEAP16[$554>>1] = $536;
      $555 = ((($$2537$us555640)) + 8|0);
      HEAP16[$555>>1] = $536;
      $556 = ((($$2537$us555640)) + 10|0);
      HEAP16[$556>>1] = $536;
      $557 = ((($$2537$us555640)) + 12|0);
      HEAP16[$557>>1] = $536;
      $558 = ((($$2537$us555640)) + 14|0);
      $559 = ($553|0)>(1);
      if ($559) {
       $$1541$us554639 = $553;$$2537$us555640 = $555;$554 = $558;
      } else {
       $$lcssa633 = $558;
       break;
      }
     }
    } else {
     $$lcssa633 = $552;
    }
    $560 = (($$lcssa633) + ($513<<1)|0);
    $561 = (($562) + -1)|0;
    $563 = ($562|0)==(0);
    if ($563) {
     break;
    } else {
     $$0535550$us551 = $560;$562 = $561;
    }
   }
   return 0;
   break;
  }
  case 2:  {
   $537 = ($524|0)>(7);
   $$0535550$us562 = $521;$575 = $522;
   while(1) {
    HEAP16[$$0535550$us562>>1] = $536;
    $564 = ((($$0535550$us562)) + 2|0);
    HEAP16[$564>>1] = $536;
    $565 = ((($$0535550$us562)) + 4|0);
    if ($537) {
     $$2542$us567644 = $525;$$3538$us568645 = $$0535550$us562;$567 = $565;
     while(1) {
      $566 = (($$2542$us567644) + -1)|0;
      HEAP16[$567>>1] = $536;
      $568 = ((($$3538$us568645)) + 6|0);
      HEAP16[$568>>1] = $536;
      $569 = ((($$3538$us568645)) + 8|0);
      HEAP16[$569>>1] = $536;
      $570 = ((($$3538$us568645)) + 10|0);
      HEAP16[$570>>1] = $536;
      $571 = ((($$3538$us568645)) + 12|0);
      $572 = ($566|0)>(1);
      if ($572) {
       $$2542$us567644 = $566;$$3538$us568645 = $569;$567 = $571;
      } else {
       $$lcssa634 = $571;
       break;
      }
     }
    } else {
     $$lcssa634 = $565;
    }
    $573 = (($$lcssa634) + ($513<<1)|0);
    $574 = (($575) + -1)|0;
    $576 = ($575|0)==(0);
    if ($576) {
     break;
    } else {
     $$0535550$us562 = $573;$575 = $574;
    }
   }
   return 0;
   break;
  }
  default: {
   $539 = ($524|0)>(7);
   $$0535550 = $521;$587 = $522;
   while(1) {
    HEAP16[$$0535550>>1] = $536;
    $577 = ((($$0535550)) + 2|0);
    if ($539) {
     $$3543635 = $525;$$4539636 = $$0535550;$579 = $577;
     while(1) {
      $578 = (($$3543635) + -1)|0;
      HEAP16[$579>>1] = $536;
      $580 = ((($$4539636)) + 4|0);
      HEAP16[$580>>1] = $536;
      $581 = ((($$4539636)) + 6|0);
      HEAP16[$581>>1] = $536;
      $582 = ((($$4539636)) + 8|0);
      HEAP16[$582>>1] = $536;
      $583 = ((($$4539636)) + 10|0);
      $584 = ($578|0)>(1);
      if ($584) {
       $$3543635 = $578;$$4539636 = $582;$579 = $583;
      } else {
       $$lcssa = $583;
       break;
      }
     }
    } else {
     $$lcssa = $577;
    }
    $585 = (($$lcssa) + ($513<<1)|0);
    $586 = (($587) + -1)|0;
    $588 = ($587|0)==(0);
    if ($588) {
     break;
    } else {
     $$0535550 = $585;$587 = $586;
    }
   }
   return 0;
  }
  }
 }
 }
 return (0)|0;
}
function _SDL_BlendFillRect_RGB565($0,$1,$2,$3,$4,$5,$6) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 var $$ = 0, $$0505574 = 0, $$0510 = 0, $$0515577 = 0, $$0520 = 0, $$0525580 = 0, $$0530 = 0, $$0535550 = 0, $$0535550$us = 0, $$0535550$us551 = 0, $$0535550$us562 = 0, $$0540$us = 0, $$1 = 0, $$10 = 0, $$11 = 0, $$1506 = 0, $$1511 = 0, $$1516 = 0, $$1521 = 0, $$1526 = 0;
 var $$1531 = 0, $$1536$us = 0, $$1541$us554651 = 0, $$2 = 0, $$2507 = 0, $$2512 = 0, $$2517 = 0, $$2522 = 0, $$2527 = 0, $$2532 = 0, $$2537$us555652 = 0, $$2542$us567656 = 0, $$3 = 0, $$3508 = 0, $$3513 = 0, $$3518 = 0, $$3523 = 0, $$3528 = 0, $$3533 = 0, $$3538$us568657 = 0;
 var $$3543647 = 0, $$4 = 0, $$4509 = 0, $$4519 = 0, $$4529 = 0, $$4539648 = 0, $$5 = 0, $$6 = 0, $$7 = 0, $$8 = 0, $$9 = 0, $$in = 0, $$in584 = 0, $$in585 = 0, $$lcssa = 0, $$lcssa645 = 0, $$lcssa646 = 0, $$pre = 0, $$pre595 = 0, $$pre597 = 0;
 var $$pre598 = 0, $$pre600 = 0, $$pre601 = 0, $$pre603 = 0, $$pre604 = 0, $$pre606 = 0, $$pre607 = 0, $$pre609 = 0, $$pre610 = 0, $$pre612 = 0, $$pre613 = 0, $$pre615 = 0, $$pre616 = 0, $$pre618 = 0, $$pre619 = 0, $$pre621 = 0, $$pre622 = 0, $$pre624 = 0, $$pre625 = 0, $$pre627 = 0;
 var $$pre628 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0;
 var $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0;
 var $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0;
 var $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0;
 var $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0;
 var $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0;
 var $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0;
 var $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0;
 var $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0;
 var $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0;
 var $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0;
 var $299 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0;
 var $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0;
 var $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0;
 var $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0;
 var $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0;
 var $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0;
 var $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0;
 var $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0;
 var $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0;
 var $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0;
 var $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0;
 var $499 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0;
 var $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0;
 var $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0;
 var $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0;
 var $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $59 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $trunc = 0, $trunc$clear = 0, $trunc544 = 0, $trunc544$clear = 0, $trunc545 = 0, $trunc545$clear = 0, $trunc546 = 0, $trunc546$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $7 = $6 ^ -1;
 $8 = $7&255;
 switch ($2|0) {
 case 1:  {
  $9 = ((($1)) + 8|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ((($1)) + 12|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ((($0)) + 16|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = ((($0)) + 4|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ((($16)) + 9|0);
  $18 = HEAP8[$17>>0]|0;
  $19 = $18&255;
  $20 = (($14|0) / ($19|0))&-1;
  $21 = (($20) - ($10))|0;
  $22 = ($12|0)==(0);
  if ($22) {
   return 0;
  }
  $23 = ((($0)) + 20|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = ((($1)) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = Math_imul($26, $20)|0;
  $28 = (($24) + ($27<<1)|0);
  $29 = HEAP32[$1>>2]|0;
  $30 = (($28) + ($29<<1)|0);
  $31 = (($10) + 3)|0;
  $32 = (($31|0) / 4)&-1;
  $trunc545 = $10&255;
  $33 = $3&255;
  $34 = $4&255;
  $35 = $5&255;
  $$0505574 = $30;$$in585 = $12;
  L41: while(1) {
   $36 = (($$in585) + -1)|0;
   $trunc545$clear = $trunc545 & 3;
   switch ($trunc545$clear<<24>>24) {
   case 0:  {
    $$pre618 = HEAP32[(79224)>>2]|0;
    $$pre619 = HEAP32[(79220)>>2]|0;
    $$0510 = $32;$$1506 = $$0505574;$41 = $$pre618;$47 = $$pre619;
    label = 9;
    break;
   }
   case 3:  {
    $$pre621 = HEAP32[(79224)>>2]|0;
    $$pre622 = HEAP32[(79220)>>2]|0;
    $$1511 = $32;$$2507 = $$0505574;$76 = $$pre621;$82 = $$pre622;
    label = 10;
    break;
   }
   case 2:  {
    $$pre624 = HEAP32[(79224)>>2]|0;
    $$pre625 = HEAP32[(79220)>>2]|0;
    $$2512 = $32;$$3508 = $$0505574;$111 = $$pre624;$117 = $$pre625;
    label = 11;
    break;
   }
   case 1:  {
    $$pre627 = HEAP32[(79224)>>2]|0;
    $$pre628 = HEAP32[(79220)>>2]|0;
    $$3513 = $32;$$4509 = $$0505574;$146 = $$pre627;$152 = $$pre628;
    label = 12;
    break;
   }
   default: {
    label = 13;
    break L41;
   }
   }
   while(1) {
    if ((label|0) == 9) {
     label = 0;
     $37 = HEAP16[$$1506>>1]|0;
     $38 = $37&65535;
     $39 = $38 >>> 11;
     $40 = (($41) + ($39)|0);
     $42 = HEAP8[$40>>0]|0;
     $43 = $42&255;
     $44 = $38 >>> 5;
     $45 = $44 & 63;
     $46 = (($47) + ($45)|0);
     $48 = HEAP8[$46>>0]|0;
     $49 = $48&255;
     $50 = $38 & 31;
     $51 = (($41) + ($50)|0);
     $52 = HEAP8[$51>>0]|0;
     $53 = $52&255;
     $54 = Math_imul($43, $8)|0;
     $55 = (($54>>>0) / 255)&-1;
     $56 = (($55) + ($33))|0;
     $57 = Math_imul($49, $8)|0;
     $58 = (($57>>>0) / 255)&-1;
     $59 = (($58) + ($34))|0;
     $60 = Math_imul($53, $8)|0;
     $61 = (($60>>>0) / 255)&-1;
     $62 = (($61) + ($35))|0;
     $63 = $56 >>> 3;
     $64 = $63 << 11;
     $65 = $59 >>> 2;
     $66 = $65 << 5;
     $67 = $66 | $64;
     $68 = $62 >>> 3;
     $69 = $67 | $68;
     $70 = $69&65535;
     HEAP16[$$1506>>1] = $70;
     $71 = ((($$1506)) + 2|0);
     $$1511 = $$0510;$$2507 = $71;$76 = $41;$82 = $47;
     label = 10;
     continue;
    }
    else if ((label|0) == 10) {
     label = 0;
     $72 = HEAP16[$$2507>>1]|0;
     $73 = $72&65535;
     $74 = $73 >>> 11;
     $75 = (($76) + ($74)|0);
     $77 = HEAP8[$75>>0]|0;
     $78 = $77&255;
     $79 = $73 >>> 5;
     $80 = $79 & 63;
     $81 = (($82) + ($80)|0);
     $83 = HEAP8[$81>>0]|0;
     $84 = $83&255;
     $85 = $73 & 31;
     $86 = (($76) + ($85)|0);
     $87 = HEAP8[$86>>0]|0;
     $88 = $87&255;
     $89 = Math_imul($78, $8)|0;
     $90 = (($89>>>0) / 255)&-1;
     $91 = (($90) + ($33))|0;
     $92 = Math_imul($84, $8)|0;
     $93 = (($92>>>0) / 255)&-1;
     $94 = (($93) + ($34))|0;
     $95 = Math_imul($88, $8)|0;
     $96 = (($95>>>0) / 255)&-1;
     $97 = (($96) + ($35))|0;
     $98 = $91 >>> 3;
     $99 = $98 << 11;
     $100 = $94 >>> 2;
     $101 = $100 << 5;
     $102 = $101 | $99;
     $103 = $97 >>> 3;
     $104 = $102 | $103;
     $105 = $104&65535;
     HEAP16[$$2507>>1] = $105;
     $106 = ((($$2507)) + 2|0);
     $$2512 = $$1511;$$3508 = $106;$111 = $76;$117 = $82;
     label = 11;
     continue;
    }
    else if ((label|0) == 11) {
     label = 0;
     $107 = HEAP16[$$3508>>1]|0;
     $108 = $107&65535;
     $109 = $108 >>> 11;
     $110 = (($111) + ($109)|0);
     $112 = HEAP8[$110>>0]|0;
     $113 = $112&255;
     $114 = $108 >>> 5;
     $115 = $114 & 63;
     $116 = (($117) + ($115)|0);
     $118 = HEAP8[$116>>0]|0;
     $119 = $118&255;
     $120 = $108 & 31;
     $121 = (($111) + ($120)|0);
     $122 = HEAP8[$121>>0]|0;
     $123 = $122&255;
     $124 = Math_imul($113, $8)|0;
     $125 = (($124>>>0) / 255)&-1;
     $126 = (($125) + ($33))|0;
     $127 = Math_imul($119, $8)|0;
     $128 = (($127>>>0) / 255)&-1;
     $129 = (($128) + ($34))|0;
     $130 = Math_imul($123, $8)|0;
     $131 = (($130>>>0) / 255)&-1;
     $132 = (($131) + ($35))|0;
     $133 = $126 >>> 3;
     $134 = $133 << 11;
     $135 = $129 >>> 2;
     $136 = $135 << 5;
     $137 = $136 | $134;
     $138 = $132 >>> 3;
     $139 = $137 | $138;
     $140 = $139&65535;
     HEAP16[$$3508>>1] = $140;
     $141 = ((($$3508)) + 2|0);
     $$3513 = $$2512;$$4509 = $141;$146 = $111;$152 = $117;
     label = 12;
     continue;
    }
    else if ((label|0) == 12) {
     label = 0;
     $142 = HEAP16[$$4509>>1]|0;
     $143 = $142&65535;
     $144 = $143 >>> 11;
     $145 = (($146) + ($144)|0);
     $147 = HEAP8[$145>>0]|0;
     $148 = $147&255;
     $149 = $143 >>> 5;
     $150 = $149 & 63;
     $151 = (($152) + ($150)|0);
     $153 = HEAP8[$151>>0]|0;
     $154 = $153&255;
     $155 = $143 & 31;
     $156 = (($146) + ($155)|0);
     $157 = HEAP8[$156>>0]|0;
     $158 = $157&255;
     $159 = Math_imul($148, $8)|0;
     $160 = (($159>>>0) / 255)&-1;
     $161 = (($160) + ($33))|0;
     $162 = Math_imul($154, $8)|0;
     $163 = (($162>>>0) / 255)&-1;
     $164 = (($163) + ($34))|0;
     $165 = Math_imul($158, $8)|0;
     $166 = (($165>>>0) / 255)&-1;
     $167 = (($166) + ($35))|0;
     $168 = $161 >>> 3;
     $169 = $168 << 11;
     $170 = $164 >>> 2;
     $171 = $170 << 5;
     $172 = $171 | $169;
     $173 = $167 >>> 3;
     $174 = $172 | $173;
     $175 = $174&65535;
     HEAP16[$$4509>>1] = $175;
     $176 = ((($$4509)) + 2|0);
     $177 = (($$3513) + -1)|0;
     $178 = ($$3513|0)>(1);
     if ($178) {
      $$0510 = $177;$$1506 = $176;$41 = $146;$47 = $152;
      label = 9;
      continue;
     } else {
      break;
     }
    }
   }
   $179 = (($176) + ($21<<1)|0);
   $180 = ($36|0)==(0);
   if ($180) {
    label = 58;
    break;
   } else {
    $$0505574 = $179;$$in585 = $36;
   }
  }
  if ((label|0) == 13) {
   // unreachable;
  }
  else if ((label|0) == 58) {
   return 0;
  }
  break;
 }
 case 2:  {
  $181 = ((($1)) + 8|0);
  $182 = HEAP32[$181>>2]|0;
  $183 = ((($1)) + 12|0);
  $184 = HEAP32[$183>>2]|0;
  $185 = ((($0)) + 16|0);
  $186 = HEAP32[$185>>2]|0;
  $187 = ((($0)) + 4|0);
  $188 = HEAP32[$187>>2]|0;
  $189 = ((($188)) + 9|0);
  $190 = HEAP8[$189>>0]|0;
  $191 = $190&255;
  $192 = (($186|0) / ($191|0))&-1;
  $193 = (($192) - ($182))|0;
  $194 = ($184|0)==(0);
  if ($194) {
   return 0;
  }
  $195 = ((($0)) + 20|0);
  $196 = HEAP32[$195>>2]|0;
  $197 = ((($1)) + 4|0);
  $198 = HEAP32[$197>>2]|0;
  $199 = Math_imul($198, $192)|0;
  $200 = (($196) + ($199<<1)|0);
  $201 = HEAP32[$1>>2]|0;
  $202 = (($200) + ($201<<1)|0);
  $203 = (($182) + 3)|0;
  $204 = (($203|0) / 4)&-1;
  $trunc544 = $182&255;
  $205 = $3&255;
  $206 = $4&255;
  $207 = $5&255;
  $$0515577 = $202;$$in584 = $184;
  L62: while(1) {
   $208 = (($$in584) + -1)|0;
   $trunc544$clear = $trunc544 & 3;
   switch ($trunc544$clear<<24>>24) {
   case 0:  {
    $$pre606 = HEAP32[(79224)>>2]|0;
    $$pre607 = HEAP32[(79220)>>2]|0;
    $$0520 = $204;$$1516 = $$0515577;$213 = $$pre606;$219 = $$pre607;
    label = 22;
    break;
   }
   case 3:  {
    $$pre609 = HEAP32[(79224)>>2]|0;
    $$pre610 = HEAP32[(79220)>>2]|0;
    $$1521 = $204;$$2517 = $$0515577;$245 = $$pre609;$251 = $$pre610;
    label = 23;
    break;
   }
   case 2:  {
    $$pre612 = HEAP32[(79224)>>2]|0;
    $$pre613 = HEAP32[(79220)>>2]|0;
    $$2522 = $204;$$3518 = $$0515577;$277 = $$pre612;$283 = $$pre613;
    label = 24;
    break;
   }
   case 1:  {
    $$pre615 = HEAP32[(79224)>>2]|0;
    $$pre616 = HEAP32[(79220)>>2]|0;
    $$3523 = $204;$$4519 = $$0515577;$309 = $$pre615;$315 = $$pre616;
    label = 25;
    break;
   }
   default: {
    label = 26;
    break L62;
   }
   }
   while(1) {
    if ((label|0) == 22) {
     label = 0;
     $209 = HEAP16[$$1516>>1]|0;
     $210 = $209&65535;
     $211 = $210 >>> 11;
     $212 = (($213) + ($211)|0);
     $214 = HEAP8[$212>>0]|0;
     $215 = $214&255;
     $216 = $210 >>> 5;
     $217 = $216 & 63;
     $218 = (($219) + ($217)|0);
     $220 = HEAP8[$218>>0]|0;
     $221 = $220&255;
     $222 = $210 & 31;
     $223 = (($213) + ($222)|0);
     $224 = HEAP8[$223>>0]|0;
     $225 = $224&255;
     $226 = (($215) + ($205))|0;
     $227 = ($226>>>0)<(255);
     $$7 = $227 ? $226 : 255;
     $228 = (($221) + ($206))|0;
     $229 = ($228>>>0)<(255);
     $$ = $229 ? $228 : 255;
     $230 = (($225) + ($207))|0;
     $231 = ($230>>>0)<(255);
     $$11 = $231 ? $230 : 255;
     $232 = $$7 >>> 3;
     $233 = $232 << 11;
     $234 = $$ >>> 2;
     $235 = $234 << 5;
     $236 = $235 | $233;
     $237 = $$11 >>> 3;
     $238 = $236 | $237;
     $239 = $238&65535;
     HEAP16[$$1516>>1] = $239;
     $240 = ((($$1516)) + 2|0);
     $$1521 = $$0520;$$2517 = $240;$245 = $213;$251 = $219;
     label = 23;
     continue;
    }
    else if ((label|0) == 23) {
     label = 0;
     $241 = HEAP16[$$2517>>1]|0;
     $242 = $241&65535;
     $243 = $242 >>> 11;
     $244 = (($245) + ($243)|0);
     $246 = HEAP8[$244>>0]|0;
     $247 = $246&255;
     $248 = $242 >>> 5;
     $249 = $248 & 63;
     $250 = (($251) + ($249)|0);
     $252 = HEAP8[$250>>0]|0;
     $253 = $252&255;
     $254 = $242 & 31;
     $255 = (($245) + ($254)|0);
     $256 = HEAP8[$255>>0]|0;
     $257 = $256&255;
     $258 = (($247) + ($205))|0;
     $259 = ($258>>>0)<(255);
     $$1 = $259 ? $258 : 255;
     $260 = (($253) + ($206))|0;
     $261 = ($260>>>0)<(255);
     $$8 = $261 ? $260 : 255;
     $262 = (($257) + ($207))|0;
     $263 = ($262>>>0)<(255);
     $$2 = $263 ? $262 : 255;
     $264 = $$1 >>> 3;
     $265 = $264 << 11;
     $266 = $$8 >>> 2;
     $267 = $266 << 5;
     $268 = $267 | $265;
     $269 = $$2 >>> 3;
     $270 = $268 | $269;
     $271 = $270&65535;
     HEAP16[$$2517>>1] = $271;
     $272 = ((($$2517)) + 2|0);
     $$2522 = $$1521;$$3518 = $272;$277 = $245;$283 = $251;
     label = 24;
     continue;
    }
    else if ((label|0) == 24) {
     label = 0;
     $273 = HEAP16[$$3518>>1]|0;
     $274 = $273&65535;
     $275 = $274 >>> 11;
     $276 = (($277) + ($275)|0);
     $278 = HEAP8[$276>>0]|0;
     $279 = $278&255;
     $280 = $274 >>> 5;
     $281 = $280 & 63;
     $282 = (($283) + ($281)|0);
     $284 = HEAP8[$282>>0]|0;
     $285 = $284&255;
     $286 = $274 & 31;
     $287 = (($277) + ($286)|0);
     $288 = HEAP8[$287>>0]|0;
     $289 = $288&255;
     $290 = (($279) + ($205))|0;
     $291 = ($290>>>0)<(255);
     $$3 = $291 ? $290 : 255;
     $292 = (($285) + ($206))|0;
     $293 = ($292>>>0)<(255);
     $$9 = $293 ? $292 : 255;
     $294 = (($289) + ($207))|0;
     $295 = ($294>>>0)<(255);
     $$4 = $295 ? $294 : 255;
     $296 = $$3 >>> 3;
     $297 = $296 << 11;
     $298 = $$9 >>> 2;
     $299 = $298 << 5;
     $300 = $299 | $297;
     $301 = $$4 >>> 3;
     $302 = $300 | $301;
     $303 = $302&65535;
     HEAP16[$$3518>>1] = $303;
     $304 = ((($$3518)) + 2|0);
     $$3523 = $$2522;$$4519 = $304;$309 = $277;$315 = $283;
     label = 25;
     continue;
    }
    else if ((label|0) == 25) {
     label = 0;
     $305 = HEAP16[$$4519>>1]|0;
     $306 = $305&65535;
     $307 = $306 >>> 11;
     $308 = (($309) + ($307)|0);
     $310 = HEAP8[$308>>0]|0;
     $311 = $310&255;
     $312 = $306 >>> 5;
     $313 = $312 & 63;
     $314 = (($315) + ($313)|0);
     $316 = HEAP8[$314>>0]|0;
     $317 = $316&255;
     $318 = $306 & 31;
     $319 = (($309) + ($318)|0);
     $320 = HEAP8[$319>>0]|0;
     $321 = $320&255;
     $322 = (($311) + ($205))|0;
     $323 = ($322>>>0)<(255);
     $$5 = $323 ? $322 : 255;
     $324 = (($317) + ($206))|0;
     $325 = ($324>>>0)<(255);
     $$10 = $325 ? $324 : 255;
     $326 = (($321) + ($207))|0;
     $327 = ($326>>>0)<(255);
     $$6 = $327 ? $326 : 255;
     $328 = $$5 >>> 3;
     $329 = $328 << 11;
     $330 = $$10 >>> 2;
     $331 = $330 << 5;
     $332 = $331 | $329;
     $333 = $$6 >>> 3;
     $334 = $332 | $333;
     $335 = $334&65535;
     HEAP16[$$4519>>1] = $335;
     $336 = ((($$4519)) + 2|0);
     $337 = (($$3523) + -1)|0;
     $338 = ($$3523|0)>(1);
     if ($338) {
      $$0520 = $337;$$1516 = $336;$213 = $309;$219 = $315;
      label = 22;
      continue;
     } else {
      break;
     }
    }
   }
   $339 = (($336) + ($193<<1)|0);
   $340 = ($208|0)==(0);
   if ($340) {
    label = 58;
    break;
   } else {
    $$0515577 = $339;$$in584 = $208;
   }
  }
  if ((label|0) == 26) {
   // unreachable;
  }
  else if ((label|0) == 58) {
   return 0;
  }
  break;
 }
 case 4:  {
  $341 = ((($1)) + 8|0);
  $342 = HEAP32[$341>>2]|0;
  $343 = ((($1)) + 12|0);
  $344 = HEAP32[$343>>2]|0;
  $345 = ((($0)) + 16|0);
  $346 = HEAP32[$345>>2]|0;
  $347 = ((($0)) + 4|0);
  $348 = HEAP32[$347>>2]|0;
  $349 = ((($348)) + 9|0);
  $350 = HEAP8[$349>>0]|0;
  $351 = $350&255;
  $352 = (($346|0) / ($351|0))&-1;
  $353 = (($352) - ($342))|0;
  $354 = ($344|0)==(0);
  if ($354) {
   return 0;
  }
  $355 = ((($0)) + 20|0);
  $356 = HEAP32[$355>>2]|0;
  $357 = ((($1)) + 4|0);
  $358 = HEAP32[$357>>2]|0;
  $359 = Math_imul($358, $352)|0;
  $360 = (($356) + ($359<<1)|0);
  $361 = HEAP32[$1>>2]|0;
  $362 = (($360) + ($361<<1)|0);
  $363 = (($342) + 3)|0;
  $364 = (($363|0) / 4)&-1;
  $trunc = $342&255;
  $365 = $3&255;
  $366 = $4&255;
  $367 = $5&255;
  $$0525580 = $362;$$in = $344;
  L83: while(1) {
   $368 = (($$in) + -1)|0;
   $trunc$clear = $trunc & 3;
   switch ($trunc$clear<<24>>24) {
   case 0:  {
    $$pre = HEAP32[(79224)>>2]|0;
    $$pre595 = HEAP32[(79220)>>2]|0;
    $$0530 = $364;$$1526 = $$0525580;$373 = $$pre;$379 = $$pre595;
    label = 35;
    break;
   }
   case 3:  {
    $$pre597 = HEAP32[(79224)>>2]|0;
    $$pre598 = HEAP32[(79220)>>2]|0;
    $$1531 = $364;$$2527 = $$0525580;$405 = $$pre597;$411 = $$pre598;
    label = 36;
    break;
   }
   case 2:  {
    $$pre600 = HEAP32[(79224)>>2]|0;
    $$pre601 = HEAP32[(79220)>>2]|0;
    $$2532 = $364;$$3528 = $$0525580;$437 = $$pre600;$443 = $$pre601;
    label = 37;
    break;
   }
   case 1:  {
    $$pre603 = HEAP32[(79224)>>2]|0;
    $$pre604 = HEAP32[(79220)>>2]|0;
    $$3533 = $364;$$4529 = $$0525580;$469 = $$pre603;$475 = $$pre604;
    label = 38;
    break;
   }
   default: {
    label = 39;
    break L83;
   }
   }
   while(1) {
    if ((label|0) == 35) {
     label = 0;
     $369 = HEAP16[$$1526>>1]|0;
     $370 = $369&65535;
     $371 = $370 >>> 11;
     $372 = (($373) + ($371)|0);
     $374 = HEAP8[$372>>0]|0;
     $375 = $374&255;
     $376 = $370 >>> 5;
     $377 = $376 & 63;
     $378 = (($379) + ($377)|0);
     $380 = HEAP8[$378>>0]|0;
     $381 = $380&255;
     $382 = $370 & 31;
     $383 = (($373) + ($382)|0);
     $384 = HEAP8[$383>>0]|0;
     $385 = $384&255;
     $386 = Math_imul($375, $365)|0;
     $387 = (($386>>>0) / 255)&-1;
     $388 = Math_imul($381, $366)|0;
     $389 = (($388>>>0) / 255)&-1;
     $390 = Math_imul($385, $367)|0;
     $391 = (($390>>>0) / 255)&-1;
     $392 = $387 >>> 3;
     $393 = $392 << 11;
     $394 = $389 >>> 2;
     $395 = $394 << 5;
     $396 = $395 | $393;
     $397 = $391 >>> 3;
     $398 = $396 | $397;
     $399 = $398&65535;
     HEAP16[$$1526>>1] = $399;
     $400 = ((($$1526)) + 2|0);
     $$1531 = $$0530;$$2527 = $400;$405 = $373;$411 = $379;
     label = 36;
     continue;
    }
    else if ((label|0) == 36) {
     label = 0;
     $401 = HEAP16[$$2527>>1]|0;
     $402 = $401&65535;
     $403 = $402 >>> 11;
     $404 = (($405) + ($403)|0);
     $406 = HEAP8[$404>>0]|0;
     $407 = $406&255;
     $408 = $402 >>> 5;
     $409 = $408 & 63;
     $410 = (($411) + ($409)|0);
     $412 = HEAP8[$410>>0]|0;
     $413 = $412&255;
     $414 = $402 & 31;
     $415 = (($405) + ($414)|0);
     $416 = HEAP8[$415>>0]|0;
     $417 = $416&255;
     $418 = Math_imul($407, $365)|0;
     $419 = (($418>>>0) / 255)&-1;
     $420 = Math_imul($413, $366)|0;
     $421 = (($420>>>0) / 255)&-1;
     $422 = Math_imul($417, $367)|0;
     $423 = (($422>>>0) / 255)&-1;
     $424 = $419 >>> 3;
     $425 = $424 << 11;
     $426 = $421 >>> 2;
     $427 = $426 << 5;
     $428 = $427 | $425;
     $429 = $423 >>> 3;
     $430 = $428 | $429;
     $431 = $430&65535;
     HEAP16[$$2527>>1] = $431;
     $432 = ((($$2527)) + 2|0);
     $$2532 = $$1531;$$3528 = $432;$437 = $405;$443 = $411;
     label = 37;
     continue;
    }
    else if ((label|0) == 37) {
     label = 0;
     $433 = HEAP16[$$3528>>1]|0;
     $434 = $433&65535;
     $435 = $434 >>> 11;
     $436 = (($437) + ($435)|0);
     $438 = HEAP8[$436>>0]|0;
     $439 = $438&255;
     $440 = $434 >>> 5;
     $441 = $440 & 63;
     $442 = (($443) + ($441)|0);
     $444 = HEAP8[$442>>0]|0;
     $445 = $444&255;
     $446 = $434 & 31;
     $447 = (($437) + ($446)|0);
     $448 = HEAP8[$447>>0]|0;
     $449 = $448&255;
     $450 = Math_imul($439, $365)|0;
     $451 = (($450>>>0) / 255)&-1;
     $452 = Math_imul($445, $366)|0;
     $453 = (($452>>>0) / 255)&-1;
     $454 = Math_imul($449, $367)|0;
     $455 = (($454>>>0) / 255)&-1;
     $456 = $451 >>> 3;
     $457 = $456 << 11;
     $458 = $453 >>> 2;
     $459 = $458 << 5;
     $460 = $459 | $457;
     $461 = $455 >>> 3;
     $462 = $460 | $461;
     $463 = $462&65535;
     HEAP16[$$3528>>1] = $463;
     $464 = ((($$3528)) + 2|0);
     $$3533 = $$2532;$$4529 = $464;$469 = $437;$475 = $443;
     label = 38;
     continue;
    }
    else if ((label|0) == 38) {
     label = 0;
     $465 = HEAP16[$$4529>>1]|0;
     $466 = $465&65535;
     $467 = $466 >>> 11;
     $468 = (($469) + ($467)|0);
     $470 = HEAP8[$468>>0]|0;
     $471 = $470&255;
     $472 = $466 >>> 5;
     $473 = $472 & 63;
     $474 = (($475) + ($473)|0);
     $476 = HEAP8[$474>>0]|0;
     $477 = $476&255;
     $478 = $466 & 31;
     $479 = (($469) + ($478)|0);
     $480 = HEAP8[$479>>0]|0;
     $481 = $480&255;
     $482 = Math_imul($471, $365)|0;
     $483 = (($482>>>0) / 255)&-1;
     $484 = Math_imul($477, $366)|0;
     $485 = (($484>>>0) / 255)&-1;
     $486 = Math_imul($481, $367)|0;
     $487 = (($486>>>0) / 255)&-1;
     $488 = $483 >>> 3;
     $489 = $488 << 11;
     $490 = $485 >>> 2;
     $491 = $490 << 5;
     $492 = $491 | $489;
     $493 = $487 >>> 3;
     $494 = $492 | $493;
     $495 = $494&65535;
     HEAP16[$$4529>>1] = $495;
     $496 = ((($$4529)) + 2|0);
     $497 = (($$3533) + -1)|0;
     $498 = ($$3533|0)>(1);
     if ($498) {
      $$0530 = $497;$$1526 = $496;$373 = $469;$379 = $475;
      label = 35;
      continue;
     } else {
      break;
     }
    }
   }
   $499 = (($496) + ($353<<1)|0);
   $500 = ($368|0)==(0);
   if ($500) {
    label = 58;
    break;
   } else {
    $$0525580 = $499;$$in = $368;
   }
  }
  if ((label|0) == 39) {
   // unreachable;
  }
  else if ((label|0) == 58) {
   return 0;
  }
  break;
 }
 default: {
  $501 = ((($1)) + 8|0);
  $502 = HEAP32[$501>>2]|0;
  $503 = ((($1)) + 12|0);
  $504 = HEAP32[$503>>2]|0;
  $505 = ((($0)) + 16|0);
  $506 = HEAP32[$505>>2]|0;
  $507 = ((($0)) + 4|0);
  $508 = HEAP32[$507>>2]|0;
  $509 = ((($508)) + 9|0);
  $510 = HEAP8[$509>>0]|0;
  $511 = $510&255;
  $512 = (($506|0) / ($511|0))&-1;
  $513 = (($512) - ($502))|0;
  $514 = ((($0)) + 20|0);
  $515 = HEAP32[$514>>2]|0;
  $516 = ((($1)) + 4|0);
  $517 = HEAP32[$516>>2]|0;
  $518 = Math_imul($517, $512)|0;
  $519 = (($515) + ($518<<1)|0);
  $520 = HEAP32[$1>>2]|0;
  $521 = (($519) + ($520<<1)|0);
  $522 = (($504) + -1)|0;
  $523 = ($504|0)==(0);
  if ($523) {
   return 0;
  }
  $524 = (($502) + 3)|0;
  $525 = (($524|0) / 4)&-1;
  $trunc546 = $502&255;
  $526 = $3&255;
  $527 = $4&255;
  $528 = $5&255;
  $529 = $526 >>> 3;
  $530 = $529 << 11;
  $531 = $527 >>> 2;
  $532 = $531 << 5;
  $533 = $532 | $530;
  $534 = $528 >>> 3;
  $535 = $533 | $534;
  $536 = $535&65535;
  $trunc546$clear = $trunc546 & 3;
  switch ($trunc546$clear<<24>>24) {
  case 0:  {
   $$0535550$us = $521;$548 = $522;
   while(1) {
    $$0540$us = $525;$$1536$us = $$0535550$us;
    while(1) {
     HEAP16[$$1536$us>>1] = $536;
     $540 = ((($$1536$us)) + 2|0);
     HEAP16[$540>>1] = $536;
     $541 = ((($$1536$us)) + 4|0);
     HEAP16[$541>>1] = $536;
     $542 = ((($$1536$us)) + 6|0);
     HEAP16[$542>>1] = $536;
     $543 = ((($$1536$us)) + 8|0);
     $544 = (($$0540$us) + -1)|0;
     $545 = ($$0540$us|0)>(1);
     if ($545) {
      $$0540$us = $544;$$1536$us = $543;
     } else {
      break;
     }
    }
    $546 = (($543) + ($513<<1)|0);
    $547 = (($548) + -1)|0;
    $549 = ($548|0)==(0);
    if ($549) {
     break;
    } else {
     $$0535550$us = $546;$548 = $547;
    }
   }
   return 0;
   break;
  }
  case 3:  {
   $538 = ($524|0)>(7);
   $$0535550$us551 = $521;$562 = $522;
   while(1) {
    HEAP16[$$0535550$us551>>1] = $536;
    $550 = ((($$0535550$us551)) + 2|0);
    HEAP16[$550>>1] = $536;
    $551 = ((($$0535550$us551)) + 4|0);
    HEAP16[$551>>1] = $536;
    $552 = ((($$0535550$us551)) + 6|0);
    if ($538) {
     $$1541$us554651 = $525;$$2537$us555652 = $$0535550$us551;$554 = $552;
     while(1) {
      $553 = (($$1541$us554651) + -1)|0;
      HEAP16[$554>>1] = $536;
      $555 = ((($$2537$us555652)) + 8|0);
      HEAP16[$555>>1] = $536;
      $556 = ((($$2537$us555652)) + 10|0);
      HEAP16[$556>>1] = $536;
      $557 = ((($$2537$us555652)) + 12|0);
      HEAP16[$557>>1] = $536;
      $558 = ((($$2537$us555652)) + 14|0);
      $559 = ($553|0)>(1);
      if ($559) {
       $$1541$us554651 = $553;$$2537$us555652 = $555;$554 = $558;
      } else {
       $$lcssa645 = $558;
       break;
      }
     }
    } else {
     $$lcssa645 = $552;
    }
    $560 = (($$lcssa645) + ($513<<1)|0);
    $561 = (($562) + -1)|0;
    $563 = ($562|0)==(0);
    if ($563) {
     break;
    } else {
     $$0535550$us551 = $560;$562 = $561;
    }
   }
   return 0;
   break;
  }
  case 2:  {
   $537 = ($524|0)>(7);
   $$0535550$us562 = $521;$575 = $522;
   while(1) {
    HEAP16[$$0535550$us562>>1] = $536;
    $564 = ((($$0535550$us562)) + 2|0);
    HEAP16[$564>>1] = $536;
    $565 = ((($$0535550$us562)) + 4|0);
    if ($537) {
     $$2542$us567656 = $525;$$3538$us568657 = $$0535550$us562;$567 = $565;
     while(1) {
      $566 = (($$2542$us567656) + -1)|0;
      HEAP16[$567>>1] = $536;
      $568 = ((($$3538$us568657)) + 6|0);
      HEAP16[$568>>1] = $536;
      $569 = ((($$3538$us568657)) + 8|0);
      HEAP16[$569>>1] = $536;
      $570 = ((($$3538$us568657)) + 10|0);
      HEAP16[$570>>1] = $536;
      $571 = ((($$3538$us568657)) + 12|0);
      $572 = ($566|0)>(1);
      if ($572) {
       $$2542$us567656 = $566;$$3538$us568657 = $569;$567 = $571;
      } else {
       $$lcssa646 = $571;
       break;
      }
     }
    } else {
     $$lcssa646 = $565;
    }
    $573 = (($$lcssa646) + ($513<<1)|0);
    $574 = (($575) + -1)|0;
    $576 = ($575|0)==(0);
    if ($576) {
     break;
    } else {
     $$0535550$us562 = $573;$575 = $574;
    }
   }
   return 0;
   break;
  }
  default: {
   $539 = ($524|0)>(7);
   $$0535550 = $521;$587 = $522;
   while(1) {
    HEAP16[$$0535550>>1] = $536;
    $577 = ((($$0535550)) + 2|0);
    if ($539) {
     $$3543647 = $525;$$4539648 = $$0535550;$579 = $577;
     while(1) {
      $578 = (($$3543647) + -1)|0;
      HEAP16[$579>>1] = $536;
      $580 = ((($$4539648)) + 4|0);
      HEAP16[$580>>1] = $536;
      $581 = ((($$4539648)) + 6|0);
      HEAP16[$581>>1] = $536;
      $582 = ((($$4539648)) + 8|0);
      HEAP16[$582>>1] = $536;
      $583 = ((($$4539648)) + 10|0);
      $584 = ($578|0)>(1);
      if ($584) {
       $$3543647 = $578;$$4539648 = $582;$579 = $583;
      } else {
       $$lcssa = $583;
       break;
      }
     }
    } else {
     $$lcssa = $577;
    }
    $585 = (($$lcssa) + ($513<<1)|0);
    $586 = (($587) + -1)|0;
    $588 = ($587|0)==(0);
    if ($588) {
     break;
    } else {
     $$0535550 = $585;$587 = $586;
    }
   }
   return 0;
  }
  }
 }
 }
 return (0)|0;
}
function _SDL_DrawLines($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $$0$i$ph = 0, $$03941 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $4 = sp + 24|0;
 $5 = sp + 20|0;
 $6 = sp + 16|0;
 $7 = sp + 12|0;
 $8 = ($0|0)==(0|0);
 if ($8) {
  $9 = (_SDL_SetError(183454,$vararg_buffer)|0);
  $$0 = $9;
  STACKTOP = sp;return ($$0|0);
 }
 $10 = ((($0)) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11)) + 9|0);
 $13 = HEAP8[$12>>0]|0;
 switch ($13<<24>>24) {
 case 1:  {
  $14 = ((($11)) + 8|0);
  $15 = HEAP8[$14>>0]|0;
  $16 = ($15&255)<(8);
  if ($16) {
   label = 8;
  } else {
   $$0$i$ph = 4355;
  }
  break;
 }
 case 2:  {
  $$0$i$ph = 4354;
  break;
 }
 case 4:  {
  $$0$i$ph = 4356;
  break;
 }
 default: {
  label = 8;
 }
 }
 if ((label|0) == 8) {
  $19 = (_SDL_SetError(183503,$vararg_buffer1)|0);
  $$0 = $19;
  STACKTOP = sp;return ($$0|0);
 }
 $17 = ($2|0)>(1);
 if ($17) {
  $18 = ((($0)) + 36|0);
  $$03941 = 1;
  while(1) {
   $20 = (($$03941) + -1)|0;
   $21 = (($1) + ($20<<3)|0);
   $22 = HEAP32[$21>>2]|0;
   HEAP32[$4>>2] = $22;
   $23 = (((($1) + ($20<<3)|0)) + 4|0);
   $24 = HEAP32[$23>>2]|0;
   HEAP32[$5>>2] = $24;
   $25 = (($1) + ($$03941<<3)|0);
   $26 = HEAP32[$25>>2]|0;
   HEAP32[$6>>2] = $26;
   $27 = (((($1) + ($$03941<<3)|0)) + 4|0);
   $28 = HEAP32[$27>>2]|0;
   HEAP32[$7>>2] = $28;
   $29 = (_SDL_IntersectRectAndLine($18,$4,$5,$6,$7)|0);
   $30 = ($29|0)==(0);
   if (!($30)) {
    $31 = HEAP32[$6>>2]|0;
    $32 = HEAP32[$25>>2]|0;
    $33 = ($31|0)==($32|0);
    $34 = HEAP32[$7>>2]|0;
    if ($33) {
     $35 = HEAP32[$27>>2]|0;
     $36 = ($34|0)!=($35|0);
     $38 = $36;
    } else {
     $38 = 1;
    }
    $37 = $38&1;
    $39 = HEAP32[$4>>2]|0;
    $40 = HEAP32[$5>>2]|0;
    FUNCTION_TABLE_viiiiiii[$$0$i$ph & 8191]($0,$39,$40,$31,$34,$3,$37);
   }
   $41 = (($$03941) + 1)|0;
   $exitcond = ($41|0)==($2|0);
   if ($exitcond) {
    break;
   } else {
    $$03941 = $41;
   }
  }
 }
 $42 = HEAP32[$1>>2]|0;
 $43 = (($2) + -1)|0;
 $44 = (($1) + ($43<<3)|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = ($42|0)==($45|0);
 $47 = (((($1) + ($43<<3)|0)) + 4|0);
 $48 = HEAP32[$47>>2]|0;
 if ($46) {
  $49 = ((($1)) + 4|0);
  $50 = HEAP32[$49>>2]|0;
  $51 = ($50|0)==($48|0);
  if ($51) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 (_SDL_DrawPoint($0,$45,$48,$3)|0);
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _SDL_BlendLines($0,$1,$2,$3,$4,$5,$6,$7) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 var $$0 = 0, $$0$i48$ph = 0, $$04749 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $8 = 0, $9 = 0, $SDL_BlendLine_ARGB8888$SDL_BlendLine_RGB888$i = 0, $SDL_BlendLine_RGB555$switch$select$i = 0, $SDL_BlendLine_RGBA4$SDL_BlendLine_RGB4$i = 0, $exitcond = 0;
 var $switch$select$i = 0, $switch$selectcmp$i = 0, $switch$selectcmp6$i = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $8 = sp + 24|0;
 $9 = sp + 20|0;
 $10 = sp + 16|0;
 $11 = sp + 12|0;
 $12 = ($0|0)==(0|0);
 if ($12) {
  $13 = (_SDL_SetError(183297,$vararg_buffer)|0);
  $$0 = $13;
  STACKTOP = sp;return ($$0|0);
 }
 $14 = ((($0)) + 4|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ((($15)) + 9|0);
 $17 = HEAP8[$16>>0]|0;
 L5: do {
  switch ($17<<24>>24) {
  case 2:  {
   $18 = ((($15)) + 12|0);
   $19 = HEAP32[$18>>2]|0;
   $switch$selectcmp$i = ($19|0)==(63488);
   $switch$select$i = $switch$selectcmp$i ? 4358 : 4357;
   $switch$selectcmp6$i = ($19|0)==(31744);
   $SDL_BlendLine_RGB555$switch$select$i = $switch$selectcmp6$i ? 4359 : $switch$select$i;
   $$0$i48$ph = $SDL_BlendLine_RGB555$switch$select$i;
   break;
  }
  case 4:  {
   $22 = ((($15)) + 12|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = ($23|0)==(16711680);
   $25 = ((($15)) + 24|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = ($26|0)!=(0);
   if ($24) {
    $SDL_BlendLine_ARGB8888$SDL_BlendLine_RGB888$i = $27 ? 4361 : 4360;
    $$0$i48$ph = $SDL_BlendLine_ARGB8888$SDL_BlendLine_RGB888$i;
    break L5;
   } else {
    $SDL_BlendLine_RGBA4$SDL_BlendLine_RGB4$i = $27 ? 4363 : 4362;
    $$0$i48$ph = $SDL_BlendLine_RGBA4$SDL_BlendLine_RGB4$i;
    break L5;
   }
   break;
  }
  default: {
   $28 = (_SDL_SetError(183347,$vararg_buffer1)|0);
   $$0 = $28;
   STACKTOP = sp;return ($$0|0);
  }
  }
 } while(0);
 $20 = ($2|0)>(1);
 if ($20) {
  $21 = ((($0)) + 36|0);
  $$04749 = 1;
  while(1) {
   $29 = (($$04749) + -1)|0;
   $30 = (($1) + ($29<<3)|0);
   $31 = HEAP32[$30>>2]|0;
   HEAP32[$8>>2] = $31;
   $32 = (((($1) + ($29<<3)|0)) + 4|0);
   $33 = HEAP32[$32>>2]|0;
   HEAP32[$9>>2] = $33;
   $34 = (($1) + ($$04749<<3)|0);
   $35 = HEAP32[$34>>2]|0;
   HEAP32[$10>>2] = $35;
   $36 = (((($1) + ($$04749<<3)|0)) + 4|0);
   $37 = HEAP32[$36>>2]|0;
   HEAP32[$11>>2] = $37;
   $38 = (_SDL_IntersectRectAndLine($21,$8,$9,$10,$11)|0);
   $39 = ($38|0)==(0);
   if (!($39)) {
    $40 = HEAP32[$10>>2]|0;
    $41 = HEAP32[$34>>2]|0;
    $42 = ($40|0)==($41|0);
    $43 = HEAP32[$11>>2]|0;
    if ($42) {
     $44 = HEAP32[$36>>2]|0;
     $45 = ($43|0)!=($44|0);
     $47 = $45;
    } else {
     $47 = 1;
    }
    $46 = $47&1;
    $48 = HEAP32[$8>>2]|0;
    $49 = HEAP32[$9>>2]|0;
    FUNCTION_TABLE_viiiiiiiiiii[$$0$i48$ph & 8191]($0,$48,$49,$40,$43,$3,$4,$5,$6,$7,$46);
   }
   $50 = (($$04749) + 1)|0;
   $exitcond = ($50|0)==($2|0);
   if ($exitcond) {
    break;
   } else {
    $$04749 = $50;
   }
  }
 }
 $51 = HEAP32[$1>>2]|0;
 $52 = (($2) + -1)|0;
 $53 = (($1) + ($52<<3)|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = ($51|0)==($54|0);
 $56 = (((($1) + ($52<<3)|0)) + 4|0);
 $57 = HEAP32[$56>>2]|0;
 if ($55) {
  $58 = ((($1)) + 4|0);
  $59 = HEAP32[$58>>2]|0;
  $60 = ($59|0)==($57|0);
  if ($60) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 (_SDL_BlendPoint($0,$54,$57,$3,$4,$5,$6,$7)|0);
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _SDL_BlendLine_RGB565($0,$1,$2,$3,$4,$5,$6,$7,$8,$9,$10) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 $8 = $8|0;
 $9 = $9|0;
 $10 = $10|0;
 var $$ = 0, $$$01107 = 0, $$$01107$$1256 = 0, $$$01138 = 0, $$$01138$$1255 = 0, $$$01168 = 0, $$$01168$$1254 = 0, $$$01206 = 0, $$$01206$$1253 = 0, $$0 = 0, $$01096 = 0, $$01097 = 0, $$010991292 = 0, $$01101 = 0, $$011031327 = 0, $$01107 = 0, $$011091326 = 0, $$01111 = 0, $$01111$in = 0, $$01112 = 0;
 var $$01112$$01111 = 0, $$01113 = 0, $$01116 = 0, $$01116$in = 0, $$01116$in$$01116 = 0, $$011201295 = 0, $$011211324 = 0, $$011241298 = 0, $$011271290 = 0, $$01132 = 0, $$011341342 = 0, $$01138 = 0, $$011401341 = 0, $$01142 = 0, $$01142$in = 0, $$01143 = 0, $$01143$$01142 = 0, $$01144 = 0, $$01147 = 0, $$01147$in = 0;
 var $$01147$in$$01147 = 0, $$011491304 = 0, $$011521339 = 0, $$011531307 = 0, $$011561310 = 0, $$011591301 = 0, $$01162 = 0, $$011641337 = 0, $$01168 = 0, $$011701336 = 0, $$01172 = 0, $$01172$in = 0, $$01173 = 0, $$01173$$01172 = 0, $$01174 = 0, $$01177 = 0, $$01177$in = 0, $$01177$in$$01177 = 0, $$01181 = 0, $$01181$ = 0;
 var $$011831334 = 0, $$01190 = 0, $$01190$ = 0, $$01200 = 0, $$012021332 = 0, $$01206 = 0, $$012081331 = 0, $$01210 = 0, $$01210$in = 0, $$01211 = 0, $$01211$$01210 = 0, $$01212 = 0, $$01215 = 0, $$01215$in = 0, $$01215$in$$01215 = 0, $$01217 = 0, $$01217$ = 0, $$012221329 = 0, $$01226 = 0, $$01226$ = 0;
 var $$1 = 0, $$10 = 0, $$11 = 0, $$11102 = 0, $$11102$$1 = 0, $$11104 = 0, $$11110 = 0, $$111141325 = 0, $$11119$ph = 0, $$111191291 = 0, $$11123$ph = 0, $$111231294 = 0, $$11126$ph = 0, $$111261297 = 0, $$11129$ph = 0, $$111291289 = 0, $$11131 = 0, $$11133 = 0, $$11133$$11131 = 0, $$11135 = 0;
 var $$11141 = 0, $$111451340 = 0, $$11151$ph = 0, $$111511303 = 0, $$11155$ph = 0, $$111551306 = 0, $$11158$ph = 0, $$111581309 = 0, $$11161 = 0, $$11163 = 0, $$11163$$11161 = 0, $$11165 = 0, $$11171 = 0, $$111751335 = 0, $$11180$ph = 0, $$111801300 = 0, $$111821316 = 0, $$11188 = 0, $$111911319 = 0, $$11196 = 0;
 var $$11199 = 0, $$11201 = 0, $$11201$$11199 = 0, $$11203 = 0, $$11209 = 0, $$112131330 = 0, $$112181322 = 0, $$11224 = 0, $$112271313 = 0, $$11232 = 0, $$12 = 0, $$1234 = 0, $$1235 = 0, $$1236 = 0, $$1237 = 0, $$1238 = 0, $$1239 = 0, $$1240 = 0, $$1241 = 0, $$1243 = 0;
 var $$1246 = 0, $$1249 = 0, $$1252 = 0, $$1253 = 0, $$1254 = 0, $$1255 = 0, $$1256 = 0, $$2 = 0, $$21115 = 0, $$21146 = 0, $$21176 = 0, $$21186 = 0, $$211891315 = 0, $$21194 = 0, $$211971318 = 0, $$21214 = 0, $$21221 = 0, $$212251321 = 0, $$21230 = 0, $$212331312 = 0;
 var $$3 = 0, $$4 = 0, $$5 = 0, $$6 = 0, $$7 = 0, $$8 = 0, $$9 = 0, $$off = 0, $$pre = 0, $$pre1375 = 0, $$pre1376 = 0, $$pre1377 = 0, $$pre1378 = 0, $$pre1379 = 0, $$pre1380 = 0, $$pre1381 = 0, $$pre1382 = 0, $$pre1383 = 0, $$pre1384 = 0, $$pre1385 = 0;
 var $$pre1386 = 0, $$pre1387 = 0, $$pre1388 = 0, $$pre1389 = 0, $$pre1390 = 0, $$pre1391 = 0, $$pre1392 = 0, $$pre1393 = 0, $$pre1394 = 0, $$pre1395 = 0, $$pre1396 = 0, $$pre1397 = 0, $$pre1398 = 0, $$pre1399 = 0, $$pre1400 = 0, $$pre1401 = 0, $$pre1402 = 0, $$pre1403 = 0, $$sink = 0, $$sink1242 = 0;
 var $$sink1244 = 0, $$sink1245 = 0, $$sink1247 = 0, $$sink1248 = 0, $$sink1250 = 0, $$sink1251 = 0, $$sink1344 = 0, $$sink1346 = 0, $$sink1348 = 0, $$sink1350 = 0, $$sink1352 = 0, $$sink1354 = 0, $$sink1356 = 0, $$sink1358 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0;
 var $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0;
 var $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0;
 var $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0;
 var $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0;
 var $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0;
 var $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0;
 var $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0;
 var $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0;
 var $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0;
 var $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0;
 var $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0;
 var $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0;
 var $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0;
 var $397 = 0, $398 = 0, $399 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0;
 var $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0;
 var $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0;
 var $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0;
 var $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0;
 var $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0;
 var $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0;
 var $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0;
 var $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0;
 var $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0;
 var $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0;
 var $597 = 0, $598 = 0, $599 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0;
 var $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0;
 var $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0;
 var $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0;
 var $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0;
 var $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0;
 var $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0;
 var $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0;
 var $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0;
 var $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0;
 var $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0;
 var $797 = 0, $798 = 0, $799 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0;
 var $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0;
 var $833 = 0, $834 = 0, $835 = 0, $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0, $850 = 0;
 var $851 = 0, $852 = 0, $853 = 0, $854 = 0, $855 = 0, $856 = 0, $857 = 0, $858 = 0, $859 = 0, $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $not$ = 0, $not$1257 = 0, $not$1258 = 0, $not$1259 = 0, $not$1260 = 0, $not$1261 = 0, $not$1262 = 0, $not$1263 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $$off = (($5) + -1)|0;
 $11 = ($$off>>>0)<(2);
 $12 = $6&255;
 $13 = $7&255;
 $14 = $9&255;
 $15 = $8&255;
 if ($11) {
  $16 = Math_imul($14, $15)|0;
  $17 = Math_imul($14, $13)|0;
  $18 = Math_imul($14, $12)|0;
  $19 = (($18>>>0) / 255)&-1;
  $20 = (($17>>>0) / 255)&-1;
  $21 = (($16>>>0) / 255)&-1;
  $$0 = $19;$$01096 = $20;$$01097 = $21;
 } else {
  $$0 = $12;$$01096 = $13;$$01097 = $15;
 }
 $22 = $14 ^ 255;
 $23 = ($4|0)==($2|0);
 if ($23) {
  switch ($5|0) {
  case 1:  {
   $24 = ((($0)) + 16|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = ((($0)) + 4|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = ((($27)) + 9|0);
   $29 = HEAP8[$28>>0]|0;
   $30 = $29&255;
   $31 = (($25|0) / ($30|0))&-1;
   $32 = ($3|0)<($1|0);
   $33 = ((($0)) + 20|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = Math_imul($31, $4)|0;
   $36 = (($34) + ($35<<1)|0);
   $37 = ($10|0)!=(0);
   if ($32) {
    $40 = (($36) + ($3<<1)|0);
    $41 = ((($40)) + 2|0);
    $$1234 = $37 ? $40 : $41;
    $42 = (($1) - ($3))|0;
    $$11119$ph = $$1234;$$sink1344 = $42;
   } else {
    $38 = (($36) + ($1<<1)|0);
    $39 = (($3) - ($1))|0;
    $$11119$ph = $38;$$sink1344 = $39;
   }
   $43 = $37&1;
   $44 = (($$sink1344) + ($43))|0;
   $45 = ($44|0)==(0);
   if ($45) {
    return;
   }
   $$pre1402 = HEAP32[(79224)>>2]|0;
   $$pre1403 = HEAP32[(79220)>>2]|0;
   $$010991292 = $44;$$111191291 = $$11119$ph;
   while(1) {
    $46 = (($$010991292) + -1)|0;
    $47 = HEAP16[$$111191291>>1]|0;
    $48 = $47&65535;
    $49 = $48 >>> 11;
    $50 = (($$pre1402) + ($49)|0);
    $51 = HEAP8[$50>>0]|0;
    $52 = $51&255;
    $53 = $48 >>> 5;
    $54 = $53 & 63;
    $55 = (($$pre1403) + ($54)|0);
    $56 = HEAP8[$55>>0]|0;
    $57 = $56&255;
    $58 = $48 & 31;
    $59 = (($$pre1402) + ($58)|0);
    $60 = HEAP8[$59>>0]|0;
    $61 = $60&255;
    $62 = Math_imul($52, $22)|0;
    $63 = (($62>>>0) / 255)&-1;
    $64 = (($63) + ($$0))|0;
    $65 = Math_imul($57, $22)|0;
    $66 = (($65>>>0) / 255)&-1;
    $67 = (($66) + ($$01096))|0;
    $68 = Math_imul($61, $22)|0;
    $69 = (($68>>>0) / 255)&-1;
    $70 = (($69) + ($$01097))|0;
    $71 = $64 >>> 3;
    $72 = $71 << 11;
    $73 = $67 >>> 2;
    $74 = $73 << 5;
    $75 = $74 | $72;
    $76 = $70 >>> 3;
    $77 = $75 | $76;
    $78 = $77&65535;
    HEAP16[$$111191291>>1] = $78;
    $79 = ((($$111191291)) + 2|0);
    $80 = ($46|0)==(0);
    if ($80) {
     break;
    } else {
     $$010991292 = $46;$$111191291 = $79;
    }
   }
   return;
   break;
  }
  case 2:  {
   $81 = ((($0)) + 16|0);
   $82 = HEAP32[$81>>2]|0;
   $83 = ((($0)) + 4|0);
   $84 = HEAP32[$83>>2]|0;
   $85 = ((($84)) + 9|0);
   $86 = HEAP8[$85>>0]|0;
   $87 = $86&255;
   $88 = (($82|0) / ($87|0))&-1;
   $89 = ($3|0)<($1|0);
   $90 = ((($0)) + 20|0);
   $91 = HEAP32[$90>>2]|0;
   $92 = Math_imul($88, $4)|0;
   $93 = (($91) + ($92<<1)|0);
   $94 = ($10|0)!=(0);
   if ($89) {
    $97 = (($93) + ($3<<1)|0);
    $98 = ((($97)) + 2|0);
    $$1235 = $94 ? $97 : $98;
    $99 = (($1) - ($3))|0;
    $$11123$ph = $$1235;$$sink1346 = $99;
   } else {
    $95 = (($93) + ($1<<1)|0);
    $96 = (($3) - ($1))|0;
    $$11123$ph = $95;$$sink1346 = $96;
   }
   $100 = $94&1;
   $101 = (($$sink1346) + ($100))|0;
   $102 = ($101|0)==(0);
   if ($102) {
    return;
   }
   $$pre1400 = HEAP32[(79224)>>2]|0;
   $$pre1401 = HEAP32[(79220)>>2]|0;
   $$011201295 = $101;$$111231294 = $$11123$ph;
   while(1) {
    $103 = (($$011201295) + -1)|0;
    $104 = HEAP16[$$111231294>>1]|0;
    $105 = $104&65535;
    $106 = $105 >>> 11;
    $107 = (($$pre1400) + ($106)|0);
    $108 = HEAP8[$107>>0]|0;
    $109 = $108&255;
    $110 = $105 >>> 5;
    $111 = $110 & 63;
    $112 = (($$pre1401) + ($111)|0);
    $113 = HEAP8[$112>>0]|0;
    $114 = $113&255;
    $115 = $105 & 31;
    $116 = (($$pre1400) + ($115)|0);
    $117 = HEAP8[$116>>0]|0;
    $118 = $117&255;
    $119 = (($109) + ($$0))|0;
    $120 = ($119>>>0)<(255);
    $$ = $120 ? $119 : 255;
    $121 = (($114) + ($$01096))|0;
    $122 = ($121>>>0)<(255);
    $$8 = $122 ? $121 : 255;
    $123 = (($118) + ($$01097))|0;
    $124 = ($123>>>0)<(255);
    $$2 = $124 ? $123 : 255;
    $125 = $$ >>> 3;
    $126 = $125 << 11;
    $127 = $$8 >>> 2;
    $128 = $127 << 5;
    $129 = $128 | $126;
    $130 = $$2 >>> 3;
    $131 = $129 | $130;
    $132 = $131&65535;
    HEAP16[$$111231294>>1] = $132;
    $133 = ((($$111231294)) + 2|0);
    $134 = ($103|0)==(0);
    if ($134) {
     break;
    } else {
     $$011201295 = $103;$$111231294 = $133;
    }
   }
   return;
   break;
  }
  case 4:  {
   $135 = ((($0)) + 16|0);
   $136 = HEAP32[$135>>2]|0;
   $137 = ((($0)) + 4|0);
   $138 = HEAP32[$137>>2]|0;
   $139 = ((($138)) + 9|0);
   $140 = HEAP8[$139>>0]|0;
   $141 = $140&255;
   $142 = (($136|0) / ($141|0))&-1;
   $143 = ($3|0)<($1|0);
   $144 = ((($0)) + 20|0);
   $145 = HEAP32[$144>>2]|0;
   $146 = Math_imul($142, $4)|0;
   $147 = (($145) + ($146<<1)|0);
   $148 = ($10|0)!=(0);
   if ($143) {
    $151 = (($147) + ($3<<1)|0);
    $152 = ((($151)) + 2|0);
    $$1236 = $148 ? $151 : $152;
    $153 = (($1) - ($3))|0;
    $$11126$ph = $$1236;$$sink1348 = $153;
   } else {
    $149 = (($147) + ($1<<1)|0);
    $150 = (($3) - ($1))|0;
    $$11126$ph = $149;$$sink1348 = $150;
   }
   $154 = $148&1;
   $155 = (($$sink1348) + ($154))|0;
   $156 = ($155|0)==(0);
   if ($156) {
    return;
   }
   $$pre1398 = HEAP32[(79224)>>2]|0;
   $$pre1399 = HEAP32[(79220)>>2]|0;
   $$011241298 = $155;$$111261297 = $$11126$ph;
   while(1) {
    $157 = (($$011241298) + -1)|0;
    $158 = HEAP16[$$111261297>>1]|0;
    $159 = $158&65535;
    $160 = $159 >>> 11;
    $161 = (($$pre1398) + ($160)|0);
    $162 = HEAP8[$161>>0]|0;
    $163 = $162&255;
    $164 = $159 >>> 5;
    $165 = $164 & 63;
    $166 = (($$pre1399) + ($165)|0);
    $167 = HEAP8[$166>>0]|0;
    $168 = $167&255;
    $169 = $159 & 31;
    $170 = (($$pre1398) + ($169)|0);
    $171 = HEAP8[$170>>0]|0;
    $172 = $171&255;
    $173 = Math_imul($163, $$0)|0;
    $174 = (($173>>>0) / 255)&-1;
    $175 = Math_imul($168, $$01096)|0;
    $176 = (($175>>>0) / 255)&-1;
    $177 = Math_imul($172, $$01097)|0;
    $178 = (($177>>>0) / 255)&-1;
    $179 = $174 >>> 3;
    $180 = $179 << 11;
    $181 = $176 >>> 2;
    $182 = $181 << 5;
    $183 = $182 | $180;
    $184 = $178 >>> 3;
    $185 = $183 | $184;
    $186 = $185&65535;
    HEAP16[$$111261297>>1] = $186;
    $187 = ((($$111261297)) + 2|0);
    $188 = ($157|0)==(0);
    if ($188) {
     break;
    } else {
     $$011241298 = $157;$$111261297 = $187;
    }
   }
   return;
   break;
  }
  default: {
   $189 = ((($0)) + 16|0);
   $190 = HEAP32[$189>>2]|0;
   $191 = ((($0)) + 4|0);
   $192 = HEAP32[$191>>2]|0;
   $193 = ((($192)) + 9|0);
   $194 = HEAP8[$193>>0]|0;
   $195 = $194&255;
   $196 = (($190|0) / ($195|0))&-1;
   $197 = ($3|0)<($1|0);
   $198 = ((($0)) + 20|0);
   $199 = HEAP32[$198>>2]|0;
   $200 = Math_imul($196, $4)|0;
   $201 = (($199) + ($200<<1)|0);
   $202 = ($10|0)!=(0);
   if ($197) {
    $205 = (($201) + ($3<<1)|0);
    $206 = ((($205)) + 2|0);
    $$1237 = $202 ? $205 : $206;
    $207 = (($1) - ($3))|0;
    $$11129$ph = $$1237;$$sink1350 = $207;
   } else {
    $203 = (($201) + ($1<<1)|0);
    $204 = (($3) - ($1))|0;
    $$11129$ph = $203;$$sink1350 = $204;
   }
   $208 = $202&1;
   $209 = (($$sink1350) + ($208))|0;
   $210 = ($209|0)==(0);
   if ($210) {
    return;
   }
   $211 = $$0 >>> 3;
   $212 = $211 << 11;
   $213 = $$01096 >>> 2;
   $214 = $213 << 5;
   $215 = $$01097 >>> 3;
   $216 = $214 | $215;
   $217 = $216 | $212;
   $218 = $217&65535;
   $$011271290 = $209;$$111291289 = $$11129$ph;
   while(1) {
    $219 = (($$011271290) + -1)|0;
    HEAP16[$$111291289>>1] = $218;
    $220 = ((($$111291289)) + 2|0);
    $221 = ($219|0)==(0);
    if ($221) {
     break;
    } else {
     $$011271290 = $219;$$111291289 = $220;
    }
   }
   return;
  }
  }
 }
 $222 = ($3|0)==($1|0);
 if ($222) {
  switch ($5|0) {
  case 1:  {
   $223 = ((($0)) + 16|0);
   $224 = HEAP32[$223>>2]|0;
   $225 = ((($0)) + 4|0);
   $226 = HEAP32[$225>>2]|0;
   $227 = ((($226)) + 9|0);
   $228 = HEAP8[$227>>0]|0;
   $229 = $228&255;
   $230 = (($224|0) / ($229|0))&-1;
   $231 = ($4|0)<($2|0);
   $232 = ((($0)) + 20|0);
   $233 = HEAP32[$232>>2]|0;
   $234 = ($10|0)!=(0);
   if ($231) {
    $239 = Math_imul($230, $4)|0;
    $240 = (($233) + ($239<<1)|0);
    $241 = (($240) + ($3<<1)|0);
    $242 = (($241) + ($230<<1)|0);
    $$1238 = $234 ? $241 : $242;
    $243 = (($2) - ($4))|0;
    $$11151$ph = $$1238;$$sink1352 = $243;
   } else {
    $235 = Math_imul($230, $2)|0;
    $236 = (($233) + ($235<<1)|0);
    $237 = (($236) + ($3<<1)|0);
    $238 = (($4) - ($2))|0;
    $$11151$ph = $237;$$sink1352 = $238;
   }
   $244 = $234&1;
   $245 = (($$sink1352) + ($244))|0;
   $246 = ($245|0)==(0);
   if ($246) {
    return;
   }
   $$pre1396 = HEAP32[(79224)>>2]|0;
   $$pre1397 = HEAP32[(79220)>>2]|0;
   $$011491304 = $245;$$111511303 = $$11151$ph;
   while(1) {
    $247 = (($$011491304) + -1)|0;
    $248 = HEAP16[$$111511303>>1]|0;
    $249 = $248&65535;
    $250 = $249 >>> 11;
    $251 = (($$pre1396) + ($250)|0);
    $252 = HEAP8[$251>>0]|0;
    $253 = $252&255;
    $254 = $249 >>> 5;
    $255 = $254 & 63;
    $256 = (($$pre1397) + ($255)|0);
    $257 = HEAP8[$256>>0]|0;
    $258 = $257&255;
    $259 = $249 & 31;
    $260 = (($$pre1396) + ($259)|0);
    $261 = HEAP8[$260>>0]|0;
    $262 = $261&255;
    $263 = Math_imul($253, $22)|0;
    $264 = (($263>>>0) / 255)&-1;
    $265 = (($264) + ($$0))|0;
    $266 = Math_imul($258, $22)|0;
    $267 = (($266>>>0) / 255)&-1;
    $268 = (($267) + ($$01096))|0;
    $269 = Math_imul($262, $22)|0;
    $270 = (($269>>>0) / 255)&-1;
    $271 = (($270) + ($$01097))|0;
    $272 = $265 >>> 3;
    $273 = $272 << 11;
    $274 = $268 >>> 2;
    $275 = $274 << 5;
    $276 = $275 | $273;
    $277 = $271 >>> 3;
    $278 = $276 | $277;
    $279 = $278&65535;
    HEAP16[$$111511303>>1] = $279;
    $280 = (($$111511303) + ($230<<1)|0);
    $281 = ($247|0)==(0);
    if ($281) {
     break;
    } else {
     $$011491304 = $247;$$111511303 = $280;
    }
   }
   return;
   break;
  }
  case 2:  {
   $282 = ((($0)) + 16|0);
   $283 = HEAP32[$282>>2]|0;
   $284 = ((($0)) + 4|0);
   $285 = HEAP32[$284>>2]|0;
   $286 = ((($285)) + 9|0);
   $287 = HEAP8[$286>>0]|0;
   $288 = $287&255;
   $289 = (($283|0) / ($288|0))&-1;
   $290 = ($4|0)<($2|0);
   $291 = ((($0)) + 20|0);
   $292 = HEAP32[$291>>2]|0;
   $293 = ($10|0)!=(0);
   if ($290) {
    $298 = Math_imul($289, $4)|0;
    $299 = (($292) + ($298<<1)|0);
    $300 = (($299) + ($3<<1)|0);
    $301 = (($300) + ($289<<1)|0);
    $$1239 = $293 ? $300 : $301;
    $302 = (($2) - ($4))|0;
    $$11155$ph = $$1239;$$sink1354 = $302;
   } else {
    $294 = Math_imul($289, $2)|0;
    $295 = (($292) + ($294<<1)|0);
    $296 = (($295) + ($3<<1)|0);
    $297 = (($4) - ($2))|0;
    $$11155$ph = $296;$$sink1354 = $297;
   }
   $303 = $293&1;
   $304 = (($$sink1354) + ($303))|0;
   $305 = ($304|0)==(0);
   if ($305) {
    return;
   }
   $$pre1394 = HEAP32[(79224)>>2]|0;
   $$pre1395 = HEAP32[(79220)>>2]|0;
   $$011531307 = $304;$$111551306 = $$11155$ph;
   while(1) {
    $306 = (($$011531307) + -1)|0;
    $307 = HEAP16[$$111551306>>1]|0;
    $308 = $307&65535;
    $309 = $308 >>> 11;
    $310 = (($$pre1394) + ($309)|0);
    $311 = HEAP8[$310>>0]|0;
    $312 = $311&255;
    $313 = $308 >>> 5;
    $314 = $313 & 63;
    $315 = (($$pre1395) + ($314)|0);
    $316 = HEAP8[$315>>0]|0;
    $317 = $316&255;
    $318 = $308 & 31;
    $319 = (($$pre1394) + ($318)|0);
    $320 = HEAP8[$319>>0]|0;
    $321 = $320&255;
    $322 = (($312) + ($$0))|0;
    $323 = ($322>>>0)<(255);
    $$3 = $323 ? $322 : 255;
    $324 = (($317) + ($$01096))|0;
    $325 = ($324>>>0)<(255);
    $$9 = $325 ? $324 : 255;
    $326 = (($321) + ($$01097))|0;
    $327 = ($326>>>0)<(255);
    $$4 = $327 ? $326 : 255;
    $328 = $$3 >>> 3;
    $329 = $328 << 11;
    $330 = $$9 >>> 2;
    $331 = $330 << 5;
    $332 = $331 | $329;
    $333 = $$4 >>> 3;
    $334 = $332 | $333;
    $335 = $334&65535;
    HEAP16[$$111551306>>1] = $335;
    $336 = (($$111551306) + ($289<<1)|0);
    $337 = ($306|0)==(0);
    if ($337) {
     break;
    } else {
     $$011531307 = $306;$$111551306 = $336;
    }
   }
   return;
   break;
  }
  case 4:  {
   $338 = ((($0)) + 16|0);
   $339 = HEAP32[$338>>2]|0;
   $340 = ((($0)) + 4|0);
   $341 = HEAP32[$340>>2]|0;
   $342 = ((($341)) + 9|0);
   $343 = HEAP8[$342>>0]|0;
   $344 = $343&255;
   $345 = (($339|0) / ($344|0))&-1;
   $346 = ($4|0)<($2|0);
   $347 = ((($0)) + 20|0);
   $348 = HEAP32[$347>>2]|0;
   $349 = ($10|0)!=(0);
   if ($346) {
    $354 = Math_imul($345, $4)|0;
    $355 = (($348) + ($354<<1)|0);
    $356 = (($355) + ($3<<1)|0);
    $357 = (($356) + ($345<<1)|0);
    $$1240 = $349 ? $356 : $357;
    $358 = (($2) - ($4))|0;
    $$11158$ph = $$1240;$$sink1356 = $358;
   } else {
    $350 = Math_imul($345, $2)|0;
    $351 = (($348) + ($350<<1)|0);
    $352 = (($351) + ($3<<1)|0);
    $353 = (($4) - ($2))|0;
    $$11158$ph = $352;$$sink1356 = $353;
   }
   $359 = $349&1;
   $360 = (($$sink1356) + ($359))|0;
   $361 = ($360|0)==(0);
   if ($361) {
    return;
   }
   $$pre1392 = HEAP32[(79224)>>2]|0;
   $$pre1393 = HEAP32[(79220)>>2]|0;
   $$011561310 = $360;$$111581309 = $$11158$ph;
   while(1) {
    $362 = (($$011561310) + -1)|0;
    $363 = HEAP16[$$111581309>>1]|0;
    $364 = $363&65535;
    $365 = $364 >>> 11;
    $366 = (($$pre1392) + ($365)|0);
    $367 = HEAP8[$366>>0]|0;
    $368 = $367&255;
    $369 = $364 >>> 5;
    $370 = $369 & 63;
    $371 = (($$pre1393) + ($370)|0);
    $372 = HEAP8[$371>>0]|0;
    $373 = $372&255;
    $374 = $364 & 31;
    $375 = (($$pre1392) + ($374)|0);
    $376 = HEAP8[$375>>0]|0;
    $377 = $376&255;
    $378 = Math_imul($368, $$0)|0;
    $379 = (($378>>>0) / 255)&-1;
    $380 = Math_imul($373, $$01096)|0;
    $381 = (($380>>>0) / 255)&-1;
    $382 = Math_imul($377, $$01097)|0;
    $383 = (($382>>>0) / 255)&-1;
    $384 = $379 >>> 3;
    $385 = $384 << 11;
    $386 = $381 >>> 2;
    $387 = $386 << 5;
    $388 = $387 | $385;
    $389 = $383 >>> 3;
    $390 = $388 | $389;
    $391 = $390&65535;
    HEAP16[$$111581309>>1] = $391;
    $392 = (($$111581309) + ($345<<1)|0);
    $393 = ($362|0)==(0);
    if ($393) {
     break;
    } else {
     $$011561310 = $362;$$111581309 = $392;
    }
   }
   return;
   break;
  }
  default: {
   $394 = ((($0)) + 16|0);
   $395 = HEAP32[$394>>2]|0;
   $396 = ((($0)) + 4|0);
   $397 = HEAP32[$396>>2]|0;
   $398 = ((($397)) + 9|0);
   $399 = HEAP8[$398>>0]|0;
   $400 = $399&255;
   $401 = (($395|0) / ($400|0))&-1;
   $402 = ($4|0)<($2|0);
   $403 = ((($0)) + 20|0);
   $404 = HEAP32[$403>>2]|0;
   $405 = ($10|0)!=(0);
   if ($402) {
    $410 = Math_imul($401, $4)|0;
    $411 = (($404) + ($410<<1)|0);
    $412 = (($411) + ($3<<1)|0);
    $413 = (($412) + ($401<<1)|0);
    $$1241 = $405 ? $412 : $413;
    $414 = (($2) - ($4))|0;
    $$11180$ph = $$1241;$$sink1358 = $414;
   } else {
    $406 = Math_imul($401, $2)|0;
    $407 = (($404) + ($406<<1)|0);
    $408 = (($407) + ($3<<1)|0);
    $409 = (($4) - ($2))|0;
    $$11180$ph = $408;$$sink1358 = $409;
   }
   $415 = $405&1;
   $416 = (($$sink1358) + ($415))|0;
   $417 = ($416|0)==(0);
   if ($417) {
    return;
   }
   $418 = $$0 >>> 3;
   $419 = $418 << 11;
   $420 = $$01096 >>> 2;
   $421 = $420 << 5;
   $422 = $$01097 >>> 3;
   $423 = $421 | $422;
   $424 = $423 | $419;
   $425 = $424&65535;
   $$011591301 = $416;$$111801300 = $$11180$ph;
   while(1) {
    $426 = (($$011591301) + -1)|0;
    HEAP16[$$111801300>>1] = $425;
    $427 = (($$111801300) + ($401<<1)|0);
    $428 = ($426|0)==(0);
    if ($428) {
     break;
    } else {
     $$011591301 = $426;$$111801300 = $427;
    }
   }
   return;
  }
  }
 }
 $429 = (($1) - ($3))|0;
 $430 = ($429|0)<(0);
 $431 = (0 - ($429))|0;
 $432 = $430 ? $431 : $429;
 $433 = (($2) - ($4))|0;
 $434 = ($433|0)<(0);
 $435 = (0 - ($433))|0;
 $436 = $434 ? $435 : $433;
 $437 = ($432|0)==($436|0);
 if ($437) {
  switch ($5|0) {
  case 1:  {
   $438 = ((($0)) + 16|0);
   $439 = HEAP32[$438>>2]|0;
   $440 = ((($0)) + 4|0);
   $441 = HEAP32[$440>>2]|0;
   $442 = ((($441)) + 9|0);
   $443 = HEAP8[$442>>0]|0;
   $444 = $443&255;
   $445 = (($439|0) / ($444|0))&-1;
   $446 = ($4|0)<($2|0);
   $447 = ((($0)) + 20|0);
   $448 = HEAP32[$447>>2]|0;
   if ($446) {
    $455 = Math_imul($445, $4)|0;
    $456 = (($448) + ($455<<1)|0);
    $457 = (($456) + ($3<<1)|0);
    $458 = ($3|0)>($1|0);
    $$sink1242 = $458 ? -1 : 1;
    $459 = (($445) + ($$sink1242))|0;
    $460 = ($10|0)==(0);
    $461 = (($457) + ($459<<1)|0);
    $$1243 = $460 ? $461 : $457;
    $$01181 = $433;$$11188 = $$1243;$$21186 = $459;
   } else {
    $449 = Math_imul($445, $2)|0;
    $450 = (($448) + ($449<<1)|0);
    $451 = (($450) + ($1<<1)|0);
    $452 = ($3|0)<($1|0);
    $$sink = $452 ? -1 : 1;
    $453 = (($445) + ($$sink))|0;
    $454 = (($4) - ($2))|0;
    $$01181 = $454;$$11188 = $451;$$21186 = $453;
   }
   $not$1262 = ($10|0)!=(0);
   $462 = $not$1262&1;
   $$01181$ = (($$01181) + ($462))|0;
   $463 = ($$01181$|0)==(0);
   if ($463) {
    return;
   }
   $$pre1390 = HEAP32[(79224)>>2]|0;
   $$pre1391 = HEAP32[(79220)>>2]|0;
   $$111821316 = $$01181$;$$211891315 = $$11188;
   while(1) {
    $464 = (($$111821316) + -1)|0;
    $465 = HEAP16[$$211891315>>1]|0;
    $466 = $465&65535;
    $467 = $466 >>> 11;
    $468 = (($$pre1390) + ($467)|0);
    $469 = HEAP8[$468>>0]|0;
    $470 = $469&255;
    $471 = $466 >>> 5;
    $472 = $471 & 63;
    $473 = (($$pre1391) + ($472)|0);
    $474 = HEAP8[$473>>0]|0;
    $475 = $474&255;
    $476 = $466 & 31;
    $477 = (($$pre1390) + ($476)|0);
    $478 = HEAP8[$477>>0]|0;
    $479 = $478&255;
    $480 = Math_imul($470, $22)|0;
    $481 = (($480>>>0) / 255)&-1;
    $482 = (($481) + ($$0))|0;
    $483 = Math_imul($475, $22)|0;
    $484 = (($483>>>0) / 255)&-1;
    $485 = (($484) + ($$01096))|0;
    $486 = Math_imul($479, $22)|0;
    $487 = (($486>>>0) / 255)&-1;
    $488 = (($487) + ($$01097))|0;
    $489 = $482 >>> 3;
    $490 = $489 << 11;
    $491 = $485 >>> 2;
    $492 = $491 << 5;
    $493 = $492 | $490;
    $494 = $488 >>> 3;
    $495 = $493 | $494;
    $496 = $495&65535;
    HEAP16[$$211891315>>1] = $496;
    $497 = (($$211891315) + ($$21186<<1)|0);
    $498 = ($464|0)==(0);
    if ($498) {
     break;
    } else {
     $$111821316 = $464;$$211891315 = $497;
    }
   }
   return;
   break;
  }
  case 2:  {
   $499 = ((($0)) + 16|0);
   $500 = HEAP32[$499>>2]|0;
   $501 = ((($0)) + 4|0);
   $502 = HEAP32[$501>>2]|0;
   $503 = ((($502)) + 9|0);
   $504 = HEAP8[$503>>0]|0;
   $505 = $504&255;
   $506 = (($500|0) / ($505|0))&-1;
   $507 = ($4|0)<($2|0);
   $508 = ((($0)) + 20|0);
   $509 = HEAP32[$508>>2]|0;
   if ($507) {
    $516 = Math_imul($506, $4)|0;
    $517 = (($509) + ($516<<1)|0);
    $518 = (($517) + ($3<<1)|0);
    $519 = ($3|0)>($1|0);
    $$sink1245 = $519 ? -1 : 1;
    $520 = (($506) + ($$sink1245))|0;
    $521 = ($10|0)==(0);
    $522 = (($518) + ($520<<1)|0);
    $$1246 = $521 ? $522 : $518;
    $$01190 = $433;$$11196 = $$1246;$$21194 = $520;
   } else {
    $510 = Math_imul($506, $2)|0;
    $511 = (($509) + ($510<<1)|0);
    $512 = (($511) + ($1<<1)|0);
    $513 = ($3|0)<($1|0);
    $$sink1244 = $513 ? -1 : 1;
    $514 = (($506) + ($$sink1244))|0;
    $515 = (($4) - ($2))|0;
    $$01190 = $515;$$11196 = $512;$$21194 = $514;
   }
   $not$1261 = ($10|0)!=(0);
   $523 = $not$1261&1;
   $$01190$ = (($$01190) + ($523))|0;
   $524 = ($$01190$|0)==(0);
   if ($524) {
    return;
   }
   $$pre1388 = HEAP32[(79224)>>2]|0;
   $$pre1389 = HEAP32[(79220)>>2]|0;
   $$111911319 = $$01190$;$$211971318 = $$11196;
   while(1) {
    $525 = (($$111911319) + -1)|0;
    $526 = HEAP16[$$211971318>>1]|0;
    $527 = $526&65535;
    $528 = $527 >>> 11;
    $529 = (($$pre1388) + ($528)|0);
    $530 = HEAP8[$529>>0]|0;
    $531 = $530&255;
    $532 = $527 >>> 5;
    $533 = $532 & 63;
    $534 = (($$pre1389) + ($533)|0);
    $535 = HEAP8[$534>>0]|0;
    $536 = $535&255;
    $537 = $527 & 31;
    $538 = (($$pre1388) + ($537)|0);
    $539 = HEAP8[$538>>0]|0;
    $540 = $539&255;
    $541 = (($531) + ($$0))|0;
    $542 = ($541>>>0)<(255);
    $$5 = $542 ? $541 : 255;
    $543 = (($536) + ($$01096))|0;
    $544 = ($543>>>0)<(255);
    $$10 = $544 ? $543 : 255;
    $545 = (($540) + ($$01097))|0;
    $546 = ($545>>>0)<(255);
    $$6 = $546 ? $545 : 255;
    $547 = $$5 >>> 3;
    $548 = $547 << 11;
    $549 = $$10 >>> 2;
    $550 = $549 << 5;
    $551 = $550 | $548;
    $552 = $$6 >>> 3;
    $553 = $551 | $552;
    $554 = $553&65535;
    HEAP16[$$211971318>>1] = $554;
    $555 = (($$211971318) + ($$21194<<1)|0);
    $556 = ($525|0)==(0);
    if ($556) {
     break;
    } else {
     $$111911319 = $525;$$211971318 = $555;
    }
   }
   return;
   break;
  }
  case 4:  {
   $557 = ((($0)) + 16|0);
   $558 = HEAP32[$557>>2]|0;
   $559 = ((($0)) + 4|0);
   $560 = HEAP32[$559>>2]|0;
   $561 = ((($560)) + 9|0);
   $562 = HEAP8[$561>>0]|0;
   $563 = $562&255;
   $564 = (($558|0) / ($563|0))&-1;
   $565 = ($4|0)<($2|0);
   $566 = ((($0)) + 20|0);
   $567 = HEAP32[$566>>2]|0;
   if ($565) {
    $574 = Math_imul($564, $4)|0;
    $575 = (($567) + ($574<<1)|0);
    $576 = (($575) + ($3<<1)|0);
    $577 = ($3|0)>($1|0);
    $$sink1248 = $577 ? -1 : 1;
    $578 = (($564) + ($$sink1248))|0;
    $579 = ($10|0)==(0);
    $580 = (($576) + ($578<<1)|0);
    $$1249 = $579 ? $580 : $576;
    $$01217 = $433;$$11224 = $$1249;$$21221 = $578;
   } else {
    $568 = Math_imul($564, $2)|0;
    $569 = (($567) + ($568<<1)|0);
    $570 = (($569) + ($1<<1)|0);
    $571 = ($3|0)<($1|0);
    $$sink1247 = $571 ? -1 : 1;
    $572 = (($564) + ($$sink1247))|0;
    $573 = (($4) - ($2))|0;
    $$01217 = $573;$$11224 = $570;$$21221 = $572;
   }
   $not$1260 = ($10|0)!=(0);
   $581 = $not$1260&1;
   $$01217$ = (($$01217) + ($581))|0;
   $582 = ($$01217$|0)==(0);
   if ($582) {
    return;
   }
   $$pre1386 = HEAP32[(79224)>>2]|0;
   $$pre1387 = HEAP32[(79220)>>2]|0;
   $$112181322 = $$01217$;$$212251321 = $$11224;
   while(1) {
    $583 = (($$112181322) + -1)|0;
    $584 = HEAP16[$$212251321>>1]|0;
    $585 = $584&65535;
    $586 = $585 >>> 11;
    $587 = (($$pre1386) + ($586)|0);
    $588 = HEAP8[$587>>0]|0;
    $589 = $588&255;
    $590 = $585 >>> 5;
    $591 = $590 & 63;
    $592 = (($$pre1387) + ($591)|0);
    $593 = HEAP8[$592>>0]|0;
    $594 = $593&255;
    $595 = $585 & 31;
    $596 = (($$pre1386) + ($595)|0);
    $597 = HEAP8[$596>>0]|0;
    $598 = $597&255;
    $599 = Math_imul($589, $$0)|0;
    $600 = (($599>>>0) / 255)&-1;
    $601 = Math_imul($594, $$01096)|0;
    $602 = (($601>>>0) / 255)&-1;
    $603 = Math_imul($598, $$01097)|0;
    $604 = (($603>>>0) / 255)&-1;
    $605 = $600 >>> 3;
    $606 = $605 << 11;
    $607 = $602 >>> 2;
    $608 = $607 << 5;
    $609 = $608 | $606;
    $610 = $604 >>> 3;
    $611 = $609 | $610;
    $612 = $611&65535;
    HEAP16[$$212251321>>1] = $612;
    $613 = (($$212251321) + ($$21221<<1)|0);
    $614 = ($583|0)==(0);
    if ($614) {
     break;
    } else {
     $$112181322 = $583;$$212251321 = $613;
    }
   }
   return;
   break;
  }
  default: {
   $615 = ((($0)) + 16|0);
   $616 = HEAP32[$615>>2]|0;
   $617 = ((($0)) + 4|0);
   $618 = HEAP32[$617>>2]|0;
   $619 = ((($618)) + 9|0);
   $620 = HEAP8[$619>>0]|0;
   $621 = $620&255;
   $622 = (($616|0) / ($621|0))&-1;
   $623 = ($4|0)<($2|0);
   $624 = ((($0)) + 20|0);
   $625 = HEAP32[$624>>2]|0;
   if ($623) {
    $632 = Math_imul($622, $4)|0;
    $633 = (($625) + ($632<<1)|0);
    $634 = (($633) + ($3<<1)|0);
    $635 = ($3|0)>($1|0);
    $$sink1251 = $635 ? -1 : 1;
    $636 = (($622) + ($$sink1251))|0;
    $637 = ($10|0)==(0);
    $638 = (($634) + ($636<<1)|0);
    $$1252 = $637 ? $638 : $634;
    $$01226 = $433;$$11232 = $$1252;$$21230 = $636;
   } else {
    $626 = Math_imul($622, $2)|0;
    $627 = (($625) + ($626<<1)|0);
    $628 = (($627) + ($1<<1)|0);
    $629 = ($3|0)<($1|0);
    $$sink1250 = $629 ? -1 : 1;
    $630 = (($622) + ($$sink1250))|0;
    $631 = (($4) - ($2))|0;
    $$01226 = $631;$$11232 = $628;$$21230 = $630;
   }
   $not$1263 = ($10|0)!=(0);
   $639 = $not$1263&1;
   $$01226$ = (($$01226) + ($639))|0;
   $640 = ($$01226$|0)==(0);
   if ($640) {
    return;
   }
   $641 = $$0 >>> 3;
   $642 = $641 << 11;
   $643 = $$01096 >>> 2;
   $644 = $643 << 5;
   $645 = $$01097 >>> 3;
   $646 = $644 | $645;
   $647 = $646 | $642;
   $648 = $647&65535;
   $$112271313 = $$01226$;$$212331312 = $$11232;
   while(1) {
    $649 = (($$112271313) + -1)|0;
    HEAP16[$$212331312>>1] = $648;
    $650 = (($$212331312) + ($$21230<<1)|0);
    $651 = ($649|0)==(0);
    if ($651) {
     break;
    } else {
     $$112271313 = $649;$$212331312 = $650;
    }
   }
   return;
  }
  }
 } else {
  switch ($5|0) {
  case 1:  {
   $652 = (($3) - ($1))|0;
   $653 = ($652|0)<(0);
   $654 = (0 - ($652))|0;
   $655 = $653 ? $654 : $652;
   $656 = (($4) - ($2))|0;
   $657 = ($656|0)<(0);
   $658 = (0 - ($656))|0;
   $659 = $657 ? $658 : $656;
   $660 = ($655|0)<($659|0);
   if ($660) {
    $664 = $655 << 1;
    $665 = (($664) - ($659))|0;
    $666 = (($655) - ($659))|0;
    $$01200 = 1;$$01206 = 0;$$01210$in = $666;$$01211 = $664;$$01212 = $665;$$01215$in = $659;
   } else {
    $661 = $659 << 1;
    $662 = (($661) - ($655))|0;
    $663 = (($659) - ($655))|0;
    $$01200 = 0;$$01206 = 1;$$01210$in = $663;$$01211 = $661;$$01212 = $662;$$01215$in = $655;
   }
   $$01210 = $$01210$in << 1;
   $667 = ($3|0)<($1|0);
   $668 = (0 - ($$01206))|0;
   $$$01206 = $667 ? $668 : $$01206;
   $$1253 = $667 ? -1 : 1;
   $669 = ($4|0)<($2|0);
   $670 = (0 - ($$01200))|0;
   $$11201 = $669 ? $670 : $$01200;
   $$11199 = $669 ? -1 : 1;
   $not$1258 = ($10|0)!=(0);
   $$01215 = $not$1258&1;
   $$01215$in$$01215 = (($$01215$in) + ($$01215))|0;
   $671 = ($$01215$in$$01215|0)>(0);
   if (!($671)) {
    return;
   }
   $672 = ((($0)) + 20|0);
   $673 = ((($0)) + 16|0);
   $$pre1382 = HEAP32[$672>>2]|0;
   $$pre1383 = HEAP32[$673>>2]|0;
   $$pre1384 = HEAP32[(79224)>>2]|0;
   $$pre1385 = HEAP32[(79220)>>2]|0;
   $$012021332 = $2;$$012081331 = $1;$$012221329 = 0;$$112131330 = $$01212;
   while(1) {
    $674 = Math_imul($$pre1383, $$012021332)|0;
    $675 = (($$pre1382) + ($674)|0);
    $676 = $$012081331 << 1;
    $677 = (($675) + ($676)|0);
    $678 = HEAP16[$677>>1]|0;
    $679 = $678&65535;
    $680 = $679 >>> 11;
    $681 = (($$pre1384) + ($680)|0);
    $682 = HEAP8[$681>>0]|0;
    $683 = $682&255;
    $684 = $679 >>> 5;
    $685 = $684 & 63;
    $686 = (($$pre1385) + ($685)|0);
    $687 = HEAP8[$686>>0]|0;
    $688 = $687&255;
    $689 = $679 & 31;
    $690 = (($$pre1384) + ($689)|0);
    $691 = HEAP8[$690>>0]|0;
    $692 = $691&255;
    $693 = Math_imul($683, $22)|0;
    $694 = (($693>>>0) / 255)&-1;
    $695 = (($694) + ($$0))|0;
    $696 = Math_imul($688, $22)|0;
    $697 = (($696>>>0) / 255)&-1;
    $698 = (($697) + ($$01096))|0;
    $699 = Math_imul($692, $22)|0;
    $700 = (($699>>>0) / 255)&-1;
    $701 = (($700) + ($$01097))|0;
    $702 = $695 >>> 3;
    $703 = $702 << 11;
    $704 = $698 >>> 2;
    $705 = $704 << 5;
    $706 = $705 | $703;
    $707 = $701 >>> 3;
    $708 = $706 | $707;
    $709 = $708&65535;
    HEAP16[$677>>1] = $709;
    $710 = ($$112131330|0)<(0);
    $$01211$$01210 = $710 ? $$01211 : $$01210;
    $$$01206$$1253 = $710 ? $$$01206 : $$1253;
    $$11201$$11199 = $710 ? $$11201 : $$11199;
    $$11203 = (($$012021332) + ($$11201$$11199))|0;
    $$11209 = (($$$01206$$1253) + ($$012081331))|0;
    $$21214 = (($$01211$$01210) + ($$112131330))|0;
    $711 = (($$012221329) + 1)|0;
    $712 = ($711|0)<($$01215$in$$01215|0);
    if ($712) {
     $$012021332 = $$11203;$$012081331 = $$11209;$$012221329 = $711;$$112131330 = $$21214;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 2:  {
   $713 = (($3) - ($1))|0;
   $714 = ($713|0)<(0);
   $715 = (0 - ($713))|0;
   $716 = $714 ? $715 : $713;
   $717 = (($4) - ($2))|0;
   $718 = ($717|0)<(0);
   $719 = (0 - ($717))|0;
   $720 = $718 ? $719 : $717;
   $721 = ($716|0)<($720|0);
   if ($721) {
    $725 = $716 << 1;
    $726 = (($725) - ($720))|0;
    $727 = (($716) - ($720))|0;
    $$01162 = 1;$$01168 = 0;$$01172$in = $727;$$01173 = $725;$$01174 = $726;$$01177$in = $720;
   } else {
    $722 = $720 << 1;
    $723 = (($722) - ($716))|0;
    $724 = (($720) - ($716))|0;
    $$01162 = 0;$$01168 = 1;$$01172$in = $724;$$01173 = $722;$$01174 = $723;$$01177$in = $716;
   }
   $$01172 = $$01172$in << 1;
   $728 = ($3|0)<($1|0);
   $729 = (0 - ($$01168))|0;
   $$$01168 = $728 ? $729 : $$01168;
   $$1254 = $728 ? -1 : 1;
   $730 = ($4|0)<($2|0);
   $731 = (0 - ($$01162))|0;
   $$11163 = $730 ? $731 : $$01162;
   $$11161 = $730 ? -1 : 1;
   $not$1257 = ($10|0)!=(0);
   $$01177 = $not$1257&1;
   $$01177$in$$01177 = (($$01177$in) + ($$01177))|0;
   $732 = ($$01177$in$$01177|0)>(0);
   if (!($732)) {
    return;
   }
   $733 = ((($0)) + 20|0);
   $734 = ((($0)) + 16|0);
   $$pre1378 = HEAP32[$733>>2]|0;
   $$pre1379 = HEAP32[$734>>2]|0;
   $$pre1380 = HEAP32[(79224)>>2]|0;
   $$pre1381 = HEAP32[(79220)>>2]|0;
   $$011641337 = $2;$$011701336 = $1;$$011831334 = 0;$$111751335 = $$01174;
   while(1) {
    $735 = Math_imul($$pre1379, $$011641337)|0;
    $736 = (($$pre1378) + ($735)|0);
    $737 = $$011701336 << 1;
    $738 = (($736) + ($737)|0);
    $739 = HEAP16[$738>>1]|0;
    $740 = $739&65535;
    $741 = $740 >>> 11;
    $742 = (($$pre1380) + ($741)|0);
    $743 = HEAP8[$742>>0]|0;
    $744 = $743&255;
    $745 = $740 >>> 5;
    $746 = $745 & 63;
    $747 = (($$pre1381) + ($746)|0);
    $748 = HEAP8[$747>>0]|0;
    $749 = $748&255;
    $750 = $740 & 31;
    $751 = (($$pre1380) + ($750)|0);
    $752 = HEAP8[$751>>0]|0;
    $753 = $752&255;
    $754 = (($744) + ($$0))|0;
    $755 = ($754>>>0)<(255);
    $$11 = $755 ? $754 : 255;
    $756 = (($749) + ($$01096))|0;
    $757 = ($756>>>0)<(255);
    $$7 = $757 ? $756 : 255;
    $758 = (($753) + ($$01097))|0;
    $759 = ($758>>>0)<(255);
    $$12 = $759 ? $758 : 255;
    $760 = $$11 >>> 3;
    $761 = $760 << 11;
    $762 = $$7 >>> 2;
    $763 = $762 << 5;
    $764 = $763 | $761;
    $765 = $$12 >>> 3;
    $766 = $764 | $765;
    $767 = $766&65535;
    HEAP16[$738>>1] = $767;
    $768 = ($$111751335|0)<(0);
    $$01173$$01172 = $768 ? $$01173 : $$01172;
    $$$01168$$1254 = $768 ? $$$01168 : $$1254;
    $$11163$$11161 = $768 ? $$11163 : $$11161;
    $$11165 = (($$011641337) + ($$11163$$11161))|0;
    $$11171 = (($$$01168$$1254) + ($$011701336))|0;
    $$21176 = (($$01173$$01172) + ($$111751335))|0;
    $769 = (($$011831334) + 1)|0;
    $770 = ($769|0)<($$01177$in$$01177|0);
    if ($770) {
     $$011641337 = $$11165;$$011701336 = $$11171;$$011831334 = $769;$$111751335 = $$21176;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 4:  {
   $771 = (($3) - ($1))|0;
   $772 = ($771|0)<(0);
   $773 = (0 - ($771))|0;
   $774 = $772 ? $773 : $771;
   $775 = (($4) - ($2))|0;
   $776 = ($775|0)<(0);
   $777 = (0 - ($775))|0;
   $778 = $776 ? $777 : $775;
   $779 = ($774|0)<($778|0);
   if ($779) {
    $783 = $774 << 1;
    $784 = (($783) - ($778))|0;
    $785 = (($774) - ($778))|0;
    $$01132 = 1;$$01138 = 0;$$01142$in = $785;$$01143 = $783;$$01144 = $784;$$01147$in = $778;
   } else {
    $780 = $778 << 1;
    $781 = (($780) - ($774))|0;
    $782 = (($778) - ($774))|0;
    $$01132 = 0;$$01138 = 1;$$01142$in = $782;$$01143 = $780;$$01144 = $781;$$01147$in = $774;
   }
   $$01142 = $$01142$in << 1;
   $786 = ($3|0)<($1|0);
   $787 = (0 - ($$01138))|0;
   $$$01138 = $786 ? $787 : $$01138;
   $$1255 = $786 ? -1 : 1;
   $788 = ($4|0)<($2|0);
   $789 = (0 - ($$01132))|0;
   $$11133 = $788 ? $789 : $$01132;
   $$11131 = $788 ? -1 : 1;
   $not$ = ($10|0)!=(0);
   $$01147 = $not$&1;
   $$01147$in$$01147 = (($$01147$in) + ($$01147))|0;
   $790 = ($$01147$in$$01147|0)>(0);
   if (!($790)) {
    return;
   }
   $791 = ((($0)) + 20|0);
   $792 = ((($0)) + 16|0);
   $$pre = HEAP32[$791>>2]|0;
   $$pre1375 = HEAP32[$792>>2]|0;
   $$pre1376 = HEAP32[(79224)>>2]|0;
   $$pre1377 = HEAP32[(79220)>>2]|0;
   $$011341342 = $2;$$011401341 = $1;$$011521339 = 0;$$111451340 = $$01144;
   while(1) {
    $793 = Math_imul($$pre1375, $$011341342)|0;
    $794 = (($$pre) + ($793)|0);
    $795 = $$011401341 << 1;
    $796 = (($794) + ($795)|0);
    $797 = HEAP16[$796>>1]|0;
    $798 = $797&65535;
    $799 = $798 >>> 11;
    $800 = (($$pre1376) + ($799)|0);
    $801 = HEAP8[$800>>0]|0;
    $802 = $801&255;
    $803 = $798 >>> 5;
    $804 = $803 & 63;
    $805 = (($$pre1377) + ($804)|0);
    $806 = HEAP8[$805>>0]|0;
    $807 = $806&255;
    $808 = $798 & 31;
    $809 = (($$pre1376) + ($808)|0);
    $810 = HEAP8[$809>>0]|0;
    $811 = $810&255;
    $812 = Math_imul($802, $$0)|0;
    $813 = (($812>>>0) / 255)&-1;
    $814 = Math_imul($807, $$01096)|0;
    $815 = (($814>>>0) / 255)&-1;
    $816 = Math_imul($811, $$01097)|0;
    $817 = (($816>>>0) / 255)&-1;
    $818 = $813 >>> 3;
    $819 = $818 << 11;
    $820 = $815 >>> 2;
    $821 = $820 << 5;
    $822 = $821 | $819;
    $823 = $817 >>> 3;
    $824 = $822 | $823;
    $825 = $824&65535;
    HEAP16[$796>>1] = $825;
    $826 = ($$111451340|0)<(0);
    $$01143$$01142 = $826 ? $$01143 : $$01142;
    $$$01138$$1255 = $826 ? $$$01138 : $$1255;
    $$11133$$11131 = $826 ? $$11133 : $$11131;
    $$11135 = (($$011341342) + ($$11133$$11131))|0;
    $$11141 = (($$$01138$$1255) + ($$011401341))|0;
    $$21146 = (($$01143$$01142) + ($$111451340))|0;
    $827 = (($$011521339) + 1)|0;
    $828 = ($827|0)<($$01147$in$$01147|0);
    if ($828) {
     $$011341342 = $$11135;$$011401341 = $$11141;$$011521339 = $827;$$111451340 = $$21146;
    } else {
     break;
    }
   }
   return;
   break;
  }
  default: {
   $829 = (($3) - ($1))|0;
   $830 = ($829|0)<(0);
   $831 = (0 - ($829))|0;
   $832 = $830 ? $831 : $829;
   $833 = (($4) - ($2))|0;
   $834 = ($833|0)<(0);
   $835 = (0 - ($833))|0;
   $836 = $834 ? $835 : $833;
   $837 = ($832|0)<($836|0);
   if ($837) {
    $841 = $832 << 1;
    $842 = (($841) - ($836))|0;
    $843 = (($832) - ($836))|0;
    $$01101 = 1;$$01107 = 0;$$01111$in = $843;$$01112 = $841;$$01113 = $842;$$01116$in = $836;
   } else {
    $838 = $836 << 1;
    $839 = (($838) - ($832))|0;
    $840 = (($836) - ($832))|0;
    $$01101 = 0;$$01107 = 1;$$01111$in = $840;$$01112 = $838;$$01113 = $839;$$01116$in = $832;
   }
   $$01111 = $$01111$in << 1;
   $844 = ($3|0)<($1|0);
   $845 = (0 - ($$01107))|0;
   $$$01107 = $844 ? $845 : $$01107;
   $$1256 = $844 ? -1 : 1;
   $846 = ($4|0)<($2|0);
   $847 = (0 - ($$01101))|0;
   $$11102 = $846 ? $847 : $$01101;
   $$1 = $846 ? -1 : 1;
   $not$1259 = ($10|0)!=(0);
   $$01116 = $not$1259&1;
   $$01116$in$$01116 = (($$01116$in) + ($$01116))|0;
   $848 = ($$01116$in$$01116|0)>(0);
   if (!($848)) {
    return;
   }
   $849 = ((($0)) + 20|0);
   $850 = HEAP32[$849>>2]|0;
   $851 = ((($0)) + 16|0);
   $852 = HEAP32[$851>>2]|0;
   $853 = $$0 >>> 3;
   $854 = $853 << 11;
   $855 = $$01096 >>> 2;
   $856 = $855 << 5;
   $857 = $$01097 >>> 3;
   $858 = $856 | $857;
   $859 = $858 | $854;
   $860 = $859&65535;
   $$011031327 = $2;$$011091326 = $1;$$011211324 = 0;$$111141325 = $$01113;
   while(1) {
    $861 = Math_imul($852, $$011031327)|0;
    $862 = (($850) + ($861)|0);
    $863 = $$011091326 << 1;
    $864 = (($862) + ($863)|0);
    HEAP16[$864>>1] = $860;
    $865 = ($$111141325|0)<(0);
    $$01112$$01111 = $865 ? $$01112 : $$01111;
    $$$01107$$1256 = $865 ? $$$01107 : $$1256;
    $$11102$$1 = $865 ? $$11102 : $$1;
    $$11104 = (($$011031327) + ($$11102$$1))|0;
    $$11110 = (($$$01107$$1256) + ($$011091326))|0;
    $$21115 = (($$01112$$01111) + ($$111141325))|0;
    $866 = (($$011211324) + 1)|0;
    $867 = ($866|0)<($$01116$in$$01116|0);
    if ($867) {
     $$011031327 = $$11104;$$011091326 = $$11110;$$011211324 = $866;$$111141325 = $$21115;
    } else {
     break;
    }
   }
   return;
  }
  }
 }
}
function _SDL_BlendLine_RGB2($0,$1,$2,$3,$4,$5,$6,$7,$8,$9,$10) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 $8 = $8|0;
 $9 = $9|0;
 $10 = $10|0;
 var $$ = 0, $$$01330 = 0, $$$01330$$1479 = 0, $$$01361 = 0, $$$01361$$1478 = 0, $$$01391 = 0, $$$01391$$1477 = 0, $$$01429 = 0, $$$01429$$1476 = 0, $$0 = 0, $$01319 = 0, $$01320 = 0, $$013221515 = 0, $$01324 = 0, $$013261550 = 0, $$01330 = 0, $$013321549 = 0, $$01334 = 0, $$01334$in = 0, $$01335 = 0;
 var $$01335$$01334 = 0, $$01336 = 0, $$01339 = 0, $$01339$in = 0, $$01339$in$$01339 = 0, $$013431518 = 0, $$013441547 = 0, $$013471521 = 0, $$013501513 = 0, $$01355 = 0, $$013571565 = 0, $$01361 = 0, $$013631564 = 0, $$01365 = 0, $$01365$in = 0, $$01366 = 0, $$01366$$01365 = 0, $$01367 = 0, $$01370 = 0, $$01370$in = 0;
 var $$01370$in$$01370 = 0, $$013721527 = 0, $$013751562 = 0, $$013761530 = 0, $$013791533 = 0, $$013821524 = 0, $$01385 = 0, $$013871560 = 0, $$01391 = 0, $$013931559 = 0, $$01395 = 0, $$01395$in = 0, $$01396 = 0, $$01396$$01395 = 0, $$01397 = 0, $$01400 = 0, $$01400$in = 0, $$01400$in$$01400 = 0, $$01404 = 0, $$01404$ = 0;
 var $$014061557 = 0, $$01413 = 0, $$01413$ = 0, $$01423 = 0, $$014251555 = 0, $$01429 = 0, $$014311554 = 0, $$01433 = 0, $$01433$in = 0, $$01434 = 0, $$01434$$01433 = 0, $$01435 = 0, $$01438 = 0, $$01438$in = 0, $$01438$in$$01438 = 0, $$01440 = 0, $$01440$ = 0, $$014451552 = 0, $$01449 = 0, $$01449$ = 0;
 var $$1 = 0, $$10 = 0, $$11 = 0, $$11325 = 0, $$11325$$1 = 0, $$11327 = 0, $$11333 = 0, $$113371548 = 0, $$11342$ph = 0, $$113421514 = 0, $$11346$ph = 0, $$113461517 = 0, $$11349$ph = 0, $$113491520 = 0, $$11352$ph = 0, $$113521512 = 0, $$11354 = 0, $$11356 = 0, $$11356$$11354 = 0, $$11358 = 0;
 var $$11364 = 0, $$113681563 = 0, $$11374$ph = 0, $$113741526 = 0, $$11378$ph = 0, $$113781529 = 0, $$11381$ph = 0, $$113811532 = 0, $$11384 = 0, $$11386 = 0, $$11386$$11384 = 0, $$11388 = 0, $$11394 = 0, $$113981558 = 0, $$11403$ph = 0, $$114031523 = 0, $$114051539 = 0, $$11411 = 0, $$114141542 = 0, $$11419 = 0;
 var $$11422 = 0, $$11424 = 0, $$11424$$11422 = 0, $$11426 = 0, $$11432 = 0, $$114361553 = 0, $$114411545 = 0, $$11447 = 0, $$114501536 = 0, $$11455 = 0, $$12 = 0, $$1457 = 0, $$1458 = 0, $$1459 = 0, $$1460 = 0, $$1461 = 0, $$1462 = 0, $$1463 = 0, $$1464 = 0, $$1466 = 0;
 var $$1469 = 0, $$1472 = 0, $$1475 = 0, $$1476 = 0, $$1477 = 0, $$1478 = 0, $$1479 = 0, $$2 = 0, $$21338 = 0, $$21369 = 0, $$21399 = 0, $$21409 = 0, $$214121538 = 0, $$21417 = 0, $$214201541 = 0, $$21437 = 0, $$21444 = 0, $$214481544 = 0, $$21453 = 0, $$214561535 = 0;
 var $$3 = 0, $$4 = 0, $$5 = 0, $$6 = 0, $$7 = 0, $$8 = 0, $$9 = 0, $$off = 0, $$phi$trans$insert = 0, $$phi$trans$insert1600 = 0, $$phi$trans$insert1605 = 0, $$phi$trans$insert1606 = 0, $$phi$trans$insert1611 = 0, $$phi$trans$insert1612 = 0, $$phi$trans$insert1620 = 0, $$phi$trans$insert1621 = 0, $$phi$trans$insert1626 = 0, $$phi$trans$insert1627 = 0, $$phi$trans$insert1632 = 0, $$phi$trans$insert1633 = 0;
 var $$phi$trans$insert1641 = 0, $$phi$trans$insert1642 = 0, $$phi$trans$insert1647 = 0, $$phi$trans$insert1648 = 0, $$phi$trans$insert1653 = 0, $$phi$trans$insert1654 = 0, $$phi$trans$insert1660 = 0, $$phi$trans$insert1661 = 0, $$phi$trans$insert1666 = 0, $$phi$trans$insert1667 = 0, $$phi$trans$insert1672 = 0, $$phi$trans$insert1673 = 0, $$phi$trans$insert1679 = 0, $$phi$trans$insert1680 = 0, $$phi$trans$insert1685 = 0, $$phi$trans$insert1686 = 0, $$phi$trans$insert1691 = 0, $$phi$trans$insert1692 = 0, $$phi$trans$insert1698 = 0, $$phi$trans$insert1699 = 0;
 var $$phi$trans$insert1704 = 0, $$phi$trans$insert1705 = 0, $$phi$trans$insert1710 = 0, $$phi$trans$insert1711 = 0, $$phi$trans$insert1717 = 0, $$phi$trans$insert1718 = 0, $$phi$trans$insert1723 = 0, $$phi$trans$insert1724 = 0, $$phi$trans$insert1729 = 0, $$phi$trans$insert1730 = 0, $$phi$trans$insert1736 = 0, $$phi$trans$insert1737 = 0, $$phi$trans$insert1742 = 0, $$phi$trans$insert1743 = 0, $$phi$trans$insert1748 = 0, $$phi$trans$insert1749 = 0, $$phi$trans$insert1755 = 0, $$phi$trans$insert1756 = 0, $$phi$trans$insert1761 = 0, $$phi$trans$insert1762 = 0;
 var $$phi$trans$insert1767 = 0, $$phi$trans$insert1768 = 0, $$phi$trans$insert1774 = 0, $$phi$trans$insert1775 = 0, $$phi$trans$insert1780 = 0, $$phi$trans$insert1781 = 0, $$phi$trans$insert1786 = 0, $$phi$trans$insert1787 = 0, $$phi$trans$insert1793 = 0, $$phi$trans$insert1794 = 0, $$phi$trans$insert1799 = 0, $$phi$trans$insert1800 = 0, $$phi$trans$insert1805 = 0, $$phi$trans$insert1806 = 0, $$phi$trans$insert1812 = 0, $$phi$trans$insert1813 = 0, $$phi$trans$insert1818 = 0, $$phi$trans$insert1819 = 0, $$phi$trans$insert1824 = 0, $$phi$trans$insert1825 = 0;
 var $$pre = 0, $$pre1598 = 0, $$pre1599 = 0, $$pre1601 = 0, $$pre1602 = 0, $$pre1603 = 0, $$pre1604 = 0, $$pre1607 = 0, $$pre1608 = 0, $$pre1609 = 0, $$pre1610 = 0, $$pre1613 = 0, $$pre1614 = 0, $$pre1615 = 0, $$pre1616 = 0, $$pre1617 = 0, $$pre1618 = 0, $$pre1619 = 0, $$pre1622 = 0, $$pre1623 = 0;
 var $$pre1624 = 0, $$pre1625 = 0, $$pre1628 = 0, $$pre1629 = 0, $$pre1630 = 0, $$pre1631 = 0, $$pre1634 = 0, $$pre1635 = 0, $$pre1636 = 0, $$pre1637 = 0, $$pre1638 = 0, $$pre1639 = 0, $$pre1640 = 0, $$pre1643 = 0, $$pre1644 = 0, $$pre1645 = 0, $$pre1646 = 0, $$pre1649 = 0, $$pre1650 = 0, $$pre1651 = 0;
 var $$pre1652 = 0, $$pre1655 = 0, $$pre1656 = 0, $$pre1657 = 0, $$pre1658 = 0, $$pre1659 = 0, $$pre1662 = 0, $$pre1663 = 0, $$pre1664 = 0, $$pre1665 = 0, $$pre1668 = 0, $$pre1669 = 0, $$pre1670 = 0, $$pre1671 = 0, $$pre1674 = 0, $$pre1675 = 0, $$pre1676 = 0, $$pre1677 = 0, $$pre1678 = 0, $$pre1681 = 0;
 var $$pre1682 = 0, $$pre1683 = 0, $$pre1684 = 0, $$pre1687 = 0, $$pre1688 = 0, $$pre1689 = 0, $$pre1690 = 0, $$pre1693 = 0, $$pre1694 = 0, $$pre1695 = 0, $$pre1696 = 0, $$pre1697 = 0, $$pre1700 = 0, $$pre1701 = 0, $$pre1702 = 0, $$pre1703 = 0, $$pre1706 = 0, $$pre1707 = 0, $$pre1708 = 0, $$pre1709 = 0;
 var $$pre1712 = 0, $$pre1713 = 0, $$pre1714 = 0, $$pre1715 = 0, $$pre1716 = 0, $$pre1719 = 0, $$pre1720 = 0, $$pre1721 = 0, $$pre1722 = 0, $$pre1725 = 0, $$pre1726 = 0, $$pre1727 = 0, $$pre1728 = 0, $$pre1731 = 0, $$pre1732 = 0, $$pre1733 = 0, $$pre1734 = 0, $$pre1735 = 0, $$pre1738 = 0, $$pre1739 = 0;
 var $$pre1740 = 0, $$pre1741 = 0, $$pre1744 = 0, $$pre1745 = 0, $$pre1746 = 0, $$pre1747 = 0, $$pre1750 = 0, $$pre1751 = 0, $$pre1752 = 0, $$pre1753 = 0, $$pre1754 = 0, $$pre1757 = 0, $$pre1758 = 0, $$pre1759 = 0, $$pre1760 = 0, $$pre1763 = 0, $$pre1764 = 0, $$pre1765 = 0, $$pre1766 = 0, $$pre1769 = 0;
 var $$pre1770 = 0, $$pre1771 = 0, $$pre1772 = 0, $$pre1773 = 0, $$pre1776 = 0, $$pre1777 = 0, $$pre1778 = 0, $$pre1779 = 0, $$pre1782 = 0, $$pre1783 = 0, $$pre1784 = 0, $$pre1785 = 0, $$pre1788 = 0, $$pre1789 = 0, $$pre1790 = 0, $$pre1791 = 0, $$pre1792 = 0, $$pre1795 = 0, $$pre1796 = 0, $$pre1797 = 0;
 var $$pre1798 = 0, $$pre1801 = 0, $$pre1802 = 0, $$pre1803 = 0, $$pre1804 = 0, $$pre1807 = 0, $$pre1808 = 0, $$pre1809 = 0, $$pre1810 = 0, $$pre1811 = 0, $$pre1814 = 0, $$pre1815 = 0, $$pre1816 = 0, $$pre1817 = 0, $$pre1820 = 0, $$pre1821 = 0, $$pre1822 = 0, $$pre1823 = 0, $$pre1826 = 0, $$pre1827 = 0;
 var $$pre1828 = 0, $$pre1829 = 0, $$sink = 0, $$sink1465 = 0, $$sink1467 = 0, $$sink1468 = 0, $$sink1470 = 0, $$sink1471 = 0, $$sink1473 = 0, $$sink1474 = 0, $$sink1567 = 0, $$sink1569 = 0, $$sink1571 = 0, $$sink1573 = 0, $$sink1575 = 0, $$sink1577 = 0, $$sink1579 = 0, $$sink1581 = 0, $100 = 0, $1000 = 0;
 var $1001 = 0, $1002 = 0, $1003 = 0, $1004 = 0, $1005 = 0, $1006 = 0, $1007 = 0, $1008 = 0, $1009 = 0, $101 = 0, $1010 = 0, $1011 = 0, $1012 = 0, $1013 = 0, $1014 = 0, $1015 = 0, $1016 = 0, $1017 = 0, $1018 = 0, $1019 = 0;
 var $102 = 0, $1020 = 0, $1021 = 0, $1022 = 0, $1023 = 0, $1024 = 0, $1025 = 0, $1026 = 0, $1027 = 0, $1028 = 0, $1029 = 0, $103 = 0, $1030 = 0, $1031 = 0, $1032 = 0, $1033 = 0, $1034 = 0, $1035 = 0, $1036 = 0, $1037 = 0;
 var $1038 = 0, $1039 = 0, $104 = 0, $1040 = 0, $1041 = 0, $1042 = 0, $1043 = 0, $1044 = 0, $1045 = 0, $1046 = 0, $1047 = 0, $1048 = 0, $1049 = 0, $105 = 0, $1050 = 0, $1051 = 0, $1052 = 0, $1053 = 0, $1054 = 0, $1055 = 0;
 var $1056 = 0, $1057 = 0, $1058 = 0, $1059 = 0, $106 = 0, $1060 = 0, $1061 = 0, $1062 = 0, $1063 = 0, $1064 = 0, $1065 = 0, $1066 = 0, $1067 = 0, $1068 = 0, $1069 = 0, $107 = 0, $1070 = 0, $1071 = 0, $1072 = 0, $1073 = 0;
 var $1074 = 0, $1075 = 0, $1076 = 0, $1077 = 0, $1078 = 0, $1079 = 0, $108 = 0, $1080 = 0, $1081 = 0, $1082 = 0, $1083 = 0, $1084 = 0, $1085 = 0, $1086 = 0, $1087 = 0, $1088 = 0, $1089 = 0, $109 = 0, $1090 = 0, $1091 = 0;
 var $1092 = 0, $1093 = 0, $1094 = 0, $1095 = 0, $1096 = 0, $1097 = 0, $1098 = 0, $1099 = 0, $11 = 0, $110 = 0, $1100 = 0, $1101 = 0, $1102 = 0, $1103 = 0, $1104 = 0, $1105 = 0, $1106 = 0, $1107 = 0, $1108 = 0, $1109 = 0;
 var $111 = 0, $1110 = 0, $1111 = 0, $1112 = 0, $1113 = 0, $1114 = 0, $1115 = 0, $1116 = 0, $1117 = 0, $1118 = 0, $1119 = 0, $112 = 0, $1120 = 0, $1121 = 0, $1122 = 0, $1123 = 0, $1124 = 0, $1125 = 0, $1126 = 0, $1127 = 0;
 var $1128 = 0, $1129 = 0, $113 = 0, $1130 = 0, $1131 = 0, $1132 = 0, $1133 = 0, $1134 = 0, $1135 = 0, $1136 = 0, $1137 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0;
 var $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0;
 var $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0;
 var $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0;
 var $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0;
 var $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0;
 var $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0;
 var $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0;
 var $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0;
 var $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0;
 var $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0;
 var $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0;
 var $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0;
 var $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0;
 var $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0;
 var $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0;
 var $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0;
 var $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0;
 var $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0;
 var $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0;
 var $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0;
 var $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0;
 var $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0;
 var $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0;
 var $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0;
 var $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0;
 var $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0;
 var $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0;
 var $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0;
 var $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0;
 var $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0;
 var $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0;
 var $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0;
 var $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0;
 var $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0;
 var $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0;
 var $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0;
 var $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0;
 var $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0;
 var $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0;
 var $831 = 0, $832 = 0, $833 = 0, $834 = 0, $835 = 0, $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0;
 var $85 = 0, $850 = 0, $851 = 0, $852 = 0, $853 = 0, $854 = 0, $855 = 0, $856 = 0, $857 = 0, $858 = 0, $859 = 0, $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0;
 var $868 = 0, $869 = 0, $87 = 0, $870 = 0, $871 = 0, $872 = 0, $873 = 0, $874 = 0, $875 = 0, $876 = 0, $877 = 0, $878 = 0, $879 = 0, $88 = 0, $880 = 0, $881 = 0, $882 = 0, $883 = 0, $884 = 0, $885 = 0;
 var $886 = 0, $887 = 0, $888 = 0, $889 = 0, $89 = 0, $890 = 0, $891 = 0, $892 = 0, $893 = 0, $894 = 0, $895 = 0, $896 = 0, $897 = 0, $898 = 0, $899 = 0, $90 = 0, $900 = 0, $901 = 0, $902 = 0, $903 = 0;
 var $904 = 0, $905 = 0, $906 = 0, $907 = 0, $908 = 0, $909 = 0, $91 = 0, $910 = 0, $911 = 0, $912 = 0, $913 = 0, $914 = 0, $915 = 0, $916 = 0, $917 = 0, $918 = 0, $919 = 0, $92 = 0, $920 = 0, $921 = 0;
 var $922 = 0, $923 = 0, $924 = 0, $925 = 0, $926 = 0, $927 = 0, $928 = 0, $929 = 0, $93 = 0, $930 = 0, $931 = 0, $932 = 0, $933 = 0, $934 = 0, $935 = 0, $936 = 0, $937 = 0, $938 = 0, $939 = 0, $94 = 0;
 var $940 = 0, $941 = 0, $942 = 0, $943 = 0, $944 = 0, $945 = 0, $946 = 0, $947 = 0, $948 = 0, $949 = 0, $95 = 0, $950 = 0, $951 = 0, $952 = 0, $953 = 0, $954 = 0, $955 = 0, $956 = 0, $957 = 0, $958 = 0;
 var $959 = 0, $96 = 0, $960 = 0, $961 = 0, $962 = 0, $963 = 0, $964 = 0, $965 = 0, $966 = 0, $967 = 0, $968 = 0, $969 = 0, $97 = 0, $970 = 0, $971 = 0, $972 = 0, $973 = 0, $974 = 0, $975 = 0, $976 = 0;
 var $977 = 0, $978 = 0, $979 = 0, $98 = 0, $980 = 0, $981 = 0, $982 = 0, $983 = 0, $984 = 0, $985 = 0, $986 = 0, $987 = 0, $988 = 0, $989 = 0, $99 = 0, $990 = 0, $991 = 0, $992 = 0, $993 = 0, $994 = 0;
 var $995 = 0, $996 = 0, $997 = 0, $998 = 0, $999 = 0, $not$ = 0, $not$1480 = 0, $not$1481 = 0, $not$1482 = 0, $not$1483 = 0, $not$1484 = 0, $not$1485 = 0, $not$1486 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $11 = ((($0)) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $$off = (($5) + -1)|0;
 $13 = ($$off>>>0)<(2);
 $14 = $6&255;
 $15 = $7&255;
 $16 = $8&255;
 $17 = $9&255;
 if ($13) {
  $18 = Math_imul($17, $16)|0;
  $19 = Math_imul($17, $15)|0;
  $20 = Math_imul($17, $14)|0;
  $21 = (($20>>>0) / 255)&-1;
  $22 = (($19>>>0) / 255)&-1;
  $23 = (($18>>>0) / 255)&-1;
  $$0 = $21;$$01319 = $22;$$01320 = $23;
 } else {
  $$0 = $14;$$01319 = $15;$$01320 = $16;
 }
 $24 = $17 ^ 255;
 $25 = ($4|0)==($2|0);
 if ($25) {
  switch ($5|0) {
  case 1:  {
   $26 = ((($0)) + 16|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = ((($12)) + 9|0);
   $29 = HEAP8[$28>>0]|0;
   $30 = $29&255;
   $31 = (($27|0) / ($30|0))&-1;
   $32 = ($3|0)<($1|0);
   $33 = ((($0)) + 20|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = Math_imul($31, $4)|0;
   $36 = (($34) + ($35<<1)|0);
   $37 = ($10|0)!=(0);
   if ($32) {
    $40 = (($36) + ($3<<1)|0);
    $41 = ((($40)) + 2|0);
    $$1457 = $37 ? $40 : $41;
    $42 = (($1) - ($3))|0;
    $$11342$ph = $$1457;$$sink1567 = $42;
   } else {
    $38 = (($36) + ($1<<1)|0);
    $39 = (($3) - ($1))|0;
    $$11342$ph = $38;$$sink1567 = $39;
   }
   $43 = $37&1;
   $44 = (($$sink1567) + ($43))|0;
   $45 = ($44|0)==(0);
   if ($45) {
    return;
   }
   $46 = ((($12)) + 28|0);
   $47 = ((($12)) + 12|0);
   $48 = ((($12)) + 32|0);
   $49 = ((($12)) + 29|0);
   $50 = ((($12)) + 16|0);
   $51 = ((($12)) + 33|0);
   $52 = ((($12)) + 30|0);
   $53 = ((($12)) + 20|0);
   $54 = ((($12)) + 34|0);
   $55 = ((($12)) + 24|0);
   $$pre1811 = HEAP8[$46>>0]|0;
   $$phi$trans$insert1812 = $$pre1811&255;
   $$phi$trans$insert1813 = (79212 + ($$phi$trans$insert1812<<2)|0);
   $$pre1814 = HEAP32[$$phi$trans$insert1813>>2]|0;
   $$pre1815 = HEAP32[$47>>2]|0;
   $$pre1816 = HEAP8[$48>>0]|0;
   $$pre1817 = HEAP8[$49>>0]|0;
   $$phi$trans$insert1818 = $$pre1817&255;
   $$phi$trans$insert1819 = (79212 + ($$phi$trans$insert1818<<2)|0);
   $$pre1820 = HEAP32[$$phi$trans$insert1819>>2]|0;
   $$pre1821 = HEAP32[$50>>2]|0;
   $$pre1822 = HEAP8[$51>>0]|0;
   $$pre1823 = HEAP8[$52>>0]|0;
   $$phi$trans$insert1824 = $$pre1823&255;
   $$phi$trans$insert1825 = (79212 + ($$phi$trans$insert1824<<2)|0);
   $$pre1826 = HEAP32[$$phi$trans$insert1825>>2]|0;
   $$pre1827 = HEAP32[$53>>2]|0;
   $$pre1828 = HEAP8[$54>>0]|0;
   $$pre1829 = HEAP32[$55>>2]|0;
   $56 = $$pre1816&255;
   $57 = $$pre1822&255;
   $58 = $$pre1828&255;
   $$013221515 = $44;$$113421514 = $$11342$ph;
   while(1) {
    $59 = (($$013221515) + -1)|0;
    $60 = HEAP16[$$113421514>>1]|0;
    $61 = $60&65535;
    $62 = $61 & $$pre1815;
    $63 = $62 >>> $56;
    $64 = (($$pre1814) + ($63)|0);
    $65 = HEAP8[$64>>0]|0;
    $66 = $65&255;
    $67 = $$pre1821 & $61;
    $68 = $67 >>> $57;
    $69 = (($$pre1820) + ($68)|0);
    $70 = HEAP8[$69>>0]|0;
    $71 = $70&255;
    $72 = $$pre1827 & $61;
    $73 = $72 >>> $58;
    $74 = (($$pre1826) + ($73)|0);
    $75 = HEAP8[$74>>0]|0;
    $76 = $75&255;
    $77 = Math_imul($66, $24)|0;
    $78 = (($77>>>0) / 255)&-1;
    $79 = (($78) + ($$0))|0;
    $80 = Math_imul($71, $24)|0;
    $81 = (($80>>>0) / 255)&-1;
    $82 = (($81) + ($$01319))|0;
    $83 = Math_imul($76, $24)|0;
    $84 = (($83>>>0) / 255)&-1;
    $85 = (($84) + ($$01320))|0;
    $86 = $79 >>> $$phi$trans$insert1812;
    $87 = $86 << $56;
    $88 = $82 >>> $$phi$trans$insert1818;
    $89 = $88 << $57;
    $90 = $89 | $87;
    $91 = $85 >>> $$phi$trans$insert1824;
    $92 = $91 << $58;
    $93 = $90 | $$pre1829;
    $94 = $93 | $92;
    $95 = $94&65535;
    HEAP16[$$113421514>>1] = $95;
    $96 = ((($$113421514)) + 2|0);
    $97 = ($59|0)==(0);
    if ($97) {
     break;
    } else {
     $$013221515 = $59;$$113421514 = $96;
    }
   }
   return;
   break;
  }
  case 2:  {
   $98 = ((($0)) + 16|0);
   $99 = HEAP32[$98>>2]|0;
   $100 = ((($12)) + 9|0);
   $101 = HEAP8[$100>>0]|0;
   $102 = $101&255;
   $103 = (($99|0) / ($102|0))&-1;
   $104 = ($3|0)<($1|0);
   $105 = ((($0)) + 20|0);
   $106 = HEAP32[$105>>2]|0;
   $107 = Math_imul($103, $4)|0;
   $108 = (($106) + ($107<<1)|0);
   $109 = ($10|0)!=(0);
   if ($104) {
    $112 = (($108) + ($3<<1)|0);
    $113 = ((($112)) + 2|0);
    $$1458 = $109 ? $112 : $113;
    $114 = (($1) - ($3))|0;
    $$11346$ph = $$1458;$$sink1569 = $114;
   } else {
    $110 = (($108) + ($1<<1)|0);
    $111 = (($3) - ($1))|0;
    $$11346$ph = $110;$$sink1569 = $111;
   }
   $115 = $109&1;
   $116 = (($$sink1569) + ($115))|0;
   $117 = ($116|0)==(0);
   if ($117) {
    return;
   }
   $118 = ((($12)) + 28|0);
   $119 = ((($12)) + 12|0);
   $120 = ((($12)) + 32|0);
   $121 = ((($12)) + 29|0);
   $122 = ((($12)) + 16|0);
   $123 = ((($12)) + 33|0);
   $124 = ((($12)) + 30|0);
   $125 = ((($12)) + 20|0);
   $126 = ((($12)) + 34|0);
   $127 = ((($12)) + 24|0);
   $$pre1792 = HEAP8[$118>>0]|0;
   $$phi$trans$insert1793 = $$pre1792&255;
   $$phi$trans$insert1794 = (79212 + ($$phi$trans$insert1793<<2)|0);
   $$pre1795 = HEAP32[$$phi$trans$insert1794>>2]|0;
   $$pre1796 = HEAP32[$119>>2]|0;
   $$pre1797 = HEAP8[$120>>0]|0;
   $$pre1798 = HEAP8[$121>>0]|0;
   $$phi$trans$insert1799 = $$pre1798&255;
   $$phi$trans$insert1800 = (79212 + ($$phi$trans$insert1799<<2)|0);
   $$pre1801 = HEAP32[$$phi$trans$insert1800>>2]|0;
   $$pre1802 = HEAP32[$122>>2]|0;
   $$pre1803 = HEAP8[$123>>0]|0;
   $$pre1804 = HEAP8[$124>>0]|0;
   $$phi$trans$insert1805 = $$pre1804&255;
   $$phi$trans$insert1806 = (79212 + ($$phi$trans$insert1805<<2)|0);
   $$pre1807 = HEAP32[$$phi$trans$insert1806>>2]|0;
   $$pre1808 = HEAP32[$125>>2]|0;
   $$pre1809 = HEAP8[$126>>0]|0;
   $$pre1810 = HEAP32[$127>>2]|0;
   $128 = $$pre1797&255;
   $129 = $$pre1803&255;
   $130 = $$pre1809&255;
   $$013431518 = $116;$$113461517 = $$11346$ph;
   while(1) {
    $131 = (($$013431518) + -1)|0;
    $132 = HEAP16[$$113461517>>1]|0;
    $133 = $132&65535;
    $134 = $133 & $$pre1796;
    $135 = $134 >>> $128;
    $136 = (($$pre1795) + ($135)|0);
    $137 = HEAP8[$136>>0]|0;
    $138 = $137&255;
    $139 = $$pre1802 & $133;
    $140 = $139 >>> $129;
    $141 = (($$pre1801) + ($140)|0);
    $142 = HEAP8[$141>>0]|0;
    $143 = $142&255;
    $144 = $$pre1808 & $133;
    $145 = $144 >>> $130;
    $146 = (($$pre1807) + ($145)|0);
    $147 = HEAP8[$146>>0]|0;
    $148 = $147&255;
    $149 = (($138) + ($$0))|0;
    $150 = ($149>>>0)<(255);
    $$ = $150 ? $149 : 255;
    $151 = (($143) + ($$01319))|0;
    $152 = ($151>>>0)<(255);
    $$8 = $152 ? $151 : 255;
    $153 = (($148) + ($$01320))|0;
    $154 = ($153>>>0)<(255);
    $$2 = $154 ? $153 : 255;
    $155 = $$ >>> $$phi$trans$insert1793;
    $156 = $155 << $128;
    $157 = $$8 >>> $$phi$trans$insert1799;
    $158 = $157 << $129;
    $159 = $158 | $156;
    $160 = $$2 >>> $$phi$trans$insert1805;
    $161 = $160 << $130;
    $162 = $159 | $$pre1810;
    $163 = $162 | $161;
    $164 = $163&65535;
    HEAP16[$$113461517>>1] = $164;
    $165 = ((($$113461517)) + 2|0);
    $166 = ($131|0)==(0);
    if ($166) {
     break;
    } else {
     $$013431518 = $131;$$113461517 = $165;
    }
   }
   return;
   break;
  }
  case 4:  {
   $167 = ((($0)) + 16|0);
   $168 = HEAP32[$167>>2]|0;
   $169 = ((($12)) + 9|0);
   $170 = HEAP8[$169>>0]|0;
   $171 = $170&255;
   $172 = (($168|0) / ($171|0))&-1;
   $173 = ($3|0)<($1|0);
   $174 = ((($0)) + 20|0);
   $175 = HEAP32[$174>>2]|0;
   $176 = Math_imul($172, $4)|0;
   $177 = (($175) + ($176<<1)|0);
   $178 = ($10|0)!=(0);
   if ($173) {
    $181 = (($177) + ($3<<1)|0);
    $182 = ((($181)) + 2|0);
    $$1459 = $178 ? $181 : $182;
    $183 = (($1) - ($3))|0;
    $$11349$ph = $$1459;$$sink1571 = $183;
   } else {
    $179 = (($177) + ($1<<1)|0);
    $180 = (($3) - ($1))|0;
    $$11349$ph = $179;$$sink1571 = $180;
   }
   $184 = $178&1;
   $185 = (($$sink1571) + ($184))|0;
   $186 = ($185|0)==(0);
   if ($186) {
    return;
   }
   $187 = ((($12)) + 28|0);
   $188 = ((($12)) + 12|0);
   $189 = ((($12)) + 32|0);
   $190 = ((($12)) + 29|0);
   $191 = ((($12)) + 16|0);
   $192 = ((($12)) + 33|0);
   $193 = ((($12)) + 30|0);
   $194 = ((($12)) + 20|0);
   $195 = ((($12)) + 34|0);
   $196 = ((($12)) + 24|0);
   $$pre1773 = HEAP8[$187>>0]|0;
   $$phi$trans$insert1774 = $$pre1773&255;
   $$phi$trans$insert1775 = (79212 + ($$phi$trans$insert1774<<2)|0);
   $$pre1776 = HEAP32[$$phi$trans$insert1775>>2]|0;
   $$pre1777 = HEAP32[$188>>2]|0;
   $$pre1778 = HEAP8[$189>>0]|0;
   $$pre1779 = HEAP8[$190>>0]|0;
   $$phi$trans$insert1780 = $$pre1779&255;
   $$phi$trans$insert1781 = (79212 + ($$phi$trans$insert1780<<2)|0);
   $$pre1782 = HEAP32[$$phi$trans$insert1781>>2]|0;
   $$pre1783 = HEAP32[$191>>2]|0;
   $$pre1784 = HEAP8[$192>>0]|0;
   $$pre1785 = HEAP8[$193>>0]|0;
   $$phi$trans$insert1786 = $$pre1785&255;
   $$phi$trans$insert1787 = (79212 + ($$phi$trans$insert1786<<2)|0);
   $$pre1788 = HEAP32[$$phi$trans$insert1787>>2]|0;
   $$pre1789 = HEAP32[$194>>2]|0;
   $$pre1790 = HEAP8[$195>>0]|0;
   $$pre1791 = HEAP32[$196>>2]|0;
   $197 = $$pre1778&255;
   $198 = $$pre1784&255;
   $199 = $$pre1790&255;
   $$013471521 = $185;$$113491520 = $$11349$ph;
   while(1) {
    $200 = (($$013471521) + -1)|0;
    $201 = HEAP16[$$113491520>>1]|0;
    $202 = $201&65535;
    $203 = $202 & $$pre1777;
    $204 = $203 >>> $197;
    $205 = (($$pre1776) + ($204)|0);
    $206 = HEAP8[$205>>0]|0;
    $207 = $206&255;
    $208 = $$pre1783 & $202;
    $209 = $208 >>> $198;
    $210 = (($$pre1782) + ($209)|0);
    $211 = HEAP8[$210>>0]|0;
    $212 = $211&255;
    $213 = $$pre1789 & $202;
    $214 = $213 >>> $199;
    $215 = (($$pre1788) + ($214)|0);
    $216 = HEAP8[$215>>0]|0;
    $217 = $216&255;
    $218 = Math_imul($207, $$0)|0;
    $219 = (($218>>>0) / 255)&-1;
    $220 = Math_imul($212, $$01319)|0;
    $221 = (($220>>>0) / 255)&-1;
    $222 = Math_imul($217, $$01320)|0;
    $223 = (($222>>>0) / 255)&-1;
    $224 = $219 >>> $$phi$trans$insert1774;
    $225 = $224 << $197;
    $226 = $221 >>> $$phi$trans$insert1780;
    $227 = $226 << $198;
    $228 = $227 | $225;
    $229 = $223 >>> $$phi$trans$insert1786;
    $230 = $229 << $199;
    $231 = $228 | $$pre1791;
    $232 = $231 | $230;
    $233 = $232&65535;
    HEAP16[$$113491520>>1] = $233;
    $234 = ((($$113491520)) + 2|0);
    $235 = ($200|0)==(0);
    if ($235) {
     break;
    } else {
     $$013471521 = $200;$$113491520 = $234;
    }
   }
   return;
   break;
  }
  default: {
   $236 = ((($0)) + 16|0);
   $237 = HEAP32[$236>>2]|0;
   $238 = ((($12)) + 9|0);
   $239 = HEAP8[$238>>0]|0;
   $240 = $239&255;
   $241 = (($237|0) / ($240|0))&-1;
   $242 = ($3|0)<($1|0);
   $243 = ((($0)) + 20|0);
   $244 = HEAP32[$243>>2]|0;
   $245 = Math_imul($241, $4)|0;
   $246 = (($244) + ($245<<1)|0);
   $247 = ($10|0)!=(0);
   if ($242) {
    $250 = (($246) + ($3<<1)|0);
    $251 = ((($250)) + 2|0);
    $$1460 = $247 ? $250 : $251;
    $252 = (($1) - ($3))|0;
    $$11352$ph = $$1460;$$sink1573 = $252;
   } else {
    $248 = (($246) + ($1<<1)|0);
    $249 = (($3) - ($1))|0;
    $$11352$ph = $248;$$sink1573 = $249;
   }
   $253 = $247&1;
   $254 = (($$sink1573) + ($253))|0;
   $255 = ($254|0)==(0);
   if ($255) {
    return;
   }
   $256 = ((($12)) + 28|0);
   $257 = HEAP8[$256>>0]|0;
   $258 = $257&255;
   $259 = $$0 >>> $258;
   $260 = ((($12)) + 32|0);
   $261 = HEAP8[$260>>0]|0;
   $262 = $261&255;
   $263 = $259 << $262;
   $264 = ((($12)) + 29|0);
   $265 = HEAP8[$264>>0]|0;
   $266 = $265&255;
   $267 = $$01319 >>> $266;
   $268 = ((($12)) + 33|0);
   $269 = HEAP8[$268>>0]|0;
   $270 = $269&255;
   $271 = $267 << $270;
   $272 = $271 | $263;
   $273 = ((($12)) + 30|0);
   $274 = HEAP8[$273>>0]|0;
   $275 = $274&255;
   $276 = $$01320 >>> $275;
   $277 = ((($12)) + 34|0);
   $278 = HEAP8[$277>>0]|0;
   $279 = $278&255;
   $280 = $276 << $279;
   $281 = ((($12)) + 24|0);
   $282 = HEAP32[$281>>2]|0;
   $283 = $272 | $282;
   $284 = $283 | $280;
   $285 = $284&65535;
   $$013501513 = $254;$$113521512 = $$11352$ph;
   while(1) {
    $286 = (($$013501513) + -1)|0;
    HEAP16[$$113521512>>1] = $285;
    $287 = ((($$113521512)) + 2|0);
    $288 = ($286|0)==(0);
    if ($288) {
     break;
    } else {
     $$013501513 = $286;$$113521512 = $287;
    }
   }
   return;
  }
  }
 }
 $289 = ($3|0)==($1|0);
 if ($289) {
  switch ($5|0) {
  case 1:  {
   $290 = ((($0)) + 16|0);
   $291 = HEAP32[$290>>2]|0;
   $292 = ((($12)) + 9|0);
   $293 = HEAP8[$292>>0]|0;
   $294 = $293&255;
   $295 = (($291|0) / ($294|0))&-1;
   $296 = ($4|0)<($2|0);
   $297 = ((($0)) + 20|0);
   $298 = HEAP32[$297>>2]|0;
   $299 = ($10|0)!=(0);
   if ($296) {
    $304 = Math_imul($295, $4)|0;
    $305 = (($298) + ($304<<1)|0);
    $306 = (($305) + ($3<<1)|0);
    $307 = (($306) + ($295<<1)|0);
    $$1461 = $299 ? $306 : $307;
    $308 = (($2) - ($4))|0;
    $$11374$ph = $$1461;$$sink1575 = $308;
   } else {
    $300 = Math_imul($295, $2)|0;
    $301 = (($298) + ($300<<1)|0);
    $302 = (($301) + ($3<<1)|0);
    $303 = (($4) - ($2))|0;
    $$11374$ph = $302;$$sink1575 = $303;
   }
   $309 = $299&1;
   $310 = (($$sink1575) + ($309))|0;
   $311 = ($310|0)==(0);
   if ($311) {
    return;
   }
   $312 = ((($12)) + 28|0);
   $313 = ((($12)) + 12|0);
   $314 = ((($12)) + 32|0);
   $315 = ((($12)) + 29|0);
   $316 = ((($12)) + 16|0);
   $317 = ((($12)) + 33|0);
   $318 = ((($12)) + 30|0);
   $319 = ((($12)) + 20|0);
   $320 = ((($12)) + 34|0);
   $321 = ((($12)) + 24|0);
   $$pre1754 = HEAP8[$312>>0]|0;
   $$phi$trans$insert1755 = $$pre1754&255;
   $$phi$trans$insert1756 = (79212 + ($$phi$trans$insert1755<<2)|0);
   $$pre1757 = HEAP32[$$phi$trans$insert1756>>2]|0;
   $$pre1758 = HEAP32[$313>>2]|0;
   $$pre1759 = HEAP8[$314>>0]|0;
   $$pre1760 = HEAP8[$315>>0]|0;
   $$phi$trans$insert1761 = $$pre1760&255;
   $$phi$trans$insert1762 = (79212 + ($$phi$trans$insert1761<<2)|0);
   $$pre1763 = HEAP32[$$phi$trans$insert1762>>2]|0;
   $$pre1764 = HEAP32[$316>>2]|0;
   $$pre1765 = HEAP8[$317>>0]|0;
   $$pre1766 = HEAP8[$318>>0]|0;
   $$phi$trans$insert1767 = $$pre1766&255;
   $$phi$trans$insert1768 = (79212 + ($$phi$trans$insert1767<<2)|0);
   $$pre1769 = HEAP32[$$phi$trans$insert1768>>2]|0;
   $$pre1770 = HEAP32[$319>>2]|0;
   $$pre1771 = HEAP8[$320>>0]|0;
   $$pre1772 = HEAP32[$321>>2]|0;
   $322 = $$pre1759&255;
   $323 = $$pre1765&255;
   $324 = $$pre1771&255;
   $$013721527 = $310;$$113741526 = $$11374$ph;
   while(1) {
    $325 = (($$013721527) + -1)|0;
    $326 = HEAP16[$$113741526>>1]|0;
    $327 = $326&65535;
    $328 = $327 & $$pre1758;
    $329 = $328 >>> $322;
    $330 = (($$pre1757) + ($329)|0);
    $331 = HEAP8[$330>>0]|0;
    $332 = $331&255;
    $333 = $$pre1764 & $327;
    $334 = $333 >>> $323;
    $335 = (($$pre1763) + ($334)|0);
    $336 = HEAP8[$335>>0]|0;
    $337 = $336&255;
    $338 = $$pre1770 & $327;
    $339 = $338 >>> $324;
    $340 = (($$pre1769) + ($339)|0);
    $341 = HEAP8[$340>>0]|0;
    $342 = $341&255;
    $343 = Math_imul($332, $24)|0;
    $344 = (($343>>>0) / 255)&-1;
    $345 = (($344) + ($$0))|0;
    $346 = Math_imul($337, $24)|0;
    $347 = (($346>>>0) / 255)&-1;
    $348 = (($347) + ($$01319))|0;
    $349 = Math_imul($342, $24)|0;
    $350 = (($349>>>0) / 255)&-1;
    $351 = (($350) + ($$01320))|0;
    $352 = $345 >>> $$phi$trans$insert1755;
    $353 = $352 << $322;
    $354 = $348 >>> $$phi$trans$insert1761;
    $355 = $354 << $323;
    $356 = $355 | $353;
    $357 = $351 >>> $$phi$trans$insert1767;
    $358 = $357 << $324;
    $359 = $356 | $$pre1772;
    $360 = $359 | $358;
    $361 = $360&65535;
    HEAP16[$$113741526>>1] = $361;
    $362 = (($$113741526) + ($295<<1)|0);
    $363 = ($325|0)==(0);
    if ($363) {
     break;
    } else {
     $$013721527 = $325;$$113741526 = $362;
    }
   }
   return;
   break;
  }
  case 2:  {
   $364 = ((($0)) + 16|0);
   $365 = HEAP32[$364>>2]|0;
   $366 = ((($12)) + 9|0);
   $367 = HEAP8[$366>>0]|0;
   $368 = $367&255;
   $369 = (($365|0) / ($368|0))&-1;
   $370 = ($4|0)<($2|0);
   $371 = ((($0)) + 20|0);
   $372 = HEAP32[$371>>2]|0;
   $373 = ($10|0)!=(0);
   if ($370) {
    $378 = Math_imul($369, $4)|0;
    $379 = (($372) + ($378<<1)|0);
    $380 = (($379) + ($3<<1)|0);
    $381 = (($380) + ($369<<1)|0);
    $$1462 = $373 ? $380 : $381;
    $382 = (($2) - ($4))|0;
    $$11378$ph = $$1462;$$sink1577 = $382;
   } else {
    $374 = Math_imul($369, $2)|0;
    $375 = (($372) + ($374<<1)|0);
    $376 = (($375) + ($3<<1)|0);
    $377 = (($4) - ($2))|0;
    $$11378$ph = $376;$$sink1577 = $377;
   }
   $383 = $373&1;
   $384 = (($$sink1577) + ($383))|0;
   $385 = ($384|0)==(0);
   if ($385) {
    return;
   }
   $386 = ((($12)) + 28|0);
   $387 = ((($12)) + 12|0);
   $388 = ((($12)) + 32|0);
   $389 = ((($12)) + 29|0);
   $390 = ((($12)) + 16|0);
   $391 = ((($12)) + 33|0);
   $392 = ((($12)) + 30|0);
   $393 = ((($12)) + 20|0);
   $394 = ((($12)) + 34|0);
   $395 = ((($12)) + 24|0);
   $$pre1735 = HEAP8[$386>>0]|0;
   $$phi$trans$insert1736 = $$pre1735&255;
   $$phi$trans$insert1737 = (79212 + ($$phi$trans$insert1736<<2)|0);
   $$pre1738 = HEAP32[$$phi$trans$insert1737>>2]|0;
   $$pre1739 = HEAP32[$387>>2]|0;
   $$pre1740 = HEAP8[$388>>0]|0;
   $$pre1741 = HEAP8[$389>>0]|0;
   $$phi$trans$insert1742 = $$pre1741&255;
   $$phi$trans$insert1743 = (79212 + ($$phi$trans$insert1742<<2)|0);
   $$pre1744 = HEAP32[$$phi$trans$insert1743>>2]|0;
   $$pre1745 = HEAP32[$390>>2]|0;
   $$pre1746 = HEAP8[$391>>0]|0;
   $$pre1747 = HEAP8[$392>>0]|0;
   $$phi$trans$insert1748 = $$pre1747&255;
   $$phi$trans$insert1749 = (79212 + ($$phi$trans$insert1748<<2)|0);
   $$pre1750 = HEAP32[$$phi$trans$insert1749>>2]|0;
   $$pre1751 = HEAP32[$393>>2]|0;
   $$pre1752 = HEAP8[$394>>0]|0;
   $$pre1753 = HEAP32[$395>>2]|0;
   $396 = $$pre1740&255;
   $397 = $$pre1746&255;
   $398 = $$pre1752&255;
   $$013761530 = $384;$$113781529 = $$11378$ph;
   while(1) {
    $399 = (($$013761530) + -1)|0;
    $400 = HEAP16[$$113781529>>1]|0;
    $401 = $400&65535;
    $402 = $401 & $$pre1739;
    $403 = $402 >>> $396;
    $404 = (($$pre1738) + ($403)|0);
    $405 = HEAP8[$404>>0]|0;
    $406 = $405&255;
    $407 = $$pre1745 & $401;
    $408 = $407 >>> $397;
    $409 = (($$pre1744) + ($408)|0);
    $410 = HEAP8[$409>>0]|0;
    $411 = $410&255;
    $412 = $$pre1751 & $401;
    $413 = $412 >>> $398;
    $414 = (($$pre1750) + ($413)|0);
    $415 = HEAP8[$414>>0]|0;
    $416 = $415&255;
    $417 = (($406) + ($$0))|0;
    $418 = ($417>>>0)<(255);
    $$3 = $418 ? $417 : 255;
    $419 = (($411) + ($$01319))|0;
    $420 = ($419>>>0)<(255);
    $$9 = $420 ? $419 : 255;
    $421 = (($416) + ($$01320))|0;
    $422 = ($421>>>0)<(255);
    $$4 = $422 ? $421 : 255;
    $423 = $$3 >>> $$phi$trans$insert1736;
    $424 = $423 << $396;
    $425 = $$9 >>> $$phi$trans$insert1742;
    $426 = $425 << $397;
    $427 = $426 | $424;
    $428 = $$4 >>> $$phi$trans$insert1748;
    $429 = $428 << $398;
    $430 = $427 | $$pre1753;
    $431 = $430 | $429;
    $432 = $431&65535;
    HEAP16[$$113781529>>1] = $432;
    $433 = (($$113781529) + ($369<<1)|0);
    $434 = ($399|0)==(0);
    if ($434) {
     break;
    } else {
     $$013761530 = $399;$$113781529 = $433;
    }
   }
   return;
   break;
  }
  case 4:  {
   $435 = ((($0)) + 16|0);
   $436 = HEAP32[$435>>2]|0;
   $437 = ((($12)) + 9|0);
   $438 = HEAP8[$437>>0]|0;
   $439 = $438&255;
   $440 = (($436|0) / ($439|0))&-1;
   $441 = ($4|0)<($2|0);
   $442 = ((($0)) + 20|0);
   $443 = HEAP32[$442>>2]|0;
   $444 = ($10|0)!=(0);
   if ($441) {
    $449 = Math_imul($440, $4)|0;
    $450 = (($443) + ($449<<1)|0);
    $451 = (($450) + ($3<<1)|0);
    $452 = (($451) + ($440<<1)|0);
    $$1463 = $444 ? $451 : $452;
    $453 = (($2) - ($4))|0;
    $$11381$ph = $$1463;$$sink1579 = $453;
   } else {
    $445 = Math_imul($440, $2)|0;
    $446 = (($443) + ($445<<1)|0);
    $447 = (($446) + ($3<<1)|0);
    $448 = (($4) - ($2))|0;
    $$11381$ph = $447;$$sink1579 = $448;
   }
   $454 = $444&1;
   $455 = (($$sink1579) + ($454))|0;
   $456 = ($455|0)==(0);
   if ($456) {
    return;
   }
   $457 = ((($12)) + 28|0);
   $458 = ((($12)) + 12|0);
   $459 = ((($12)) + 32|0);
   $460 = ((($12)) + 29|0);
   $461 = ((($12)) + 16|0);
   $462 = ((($12)) + 33|0);
   $463 = ((($12)) + 30|0);
   $464 = ((($12)) + 20|0);
   $465 = ((($12)) + 34|0);
   $466 = ((($12)) + 24|0);
   $$pre1716 = HEAP8[$457>>0]|0;
   $$phi$trans$insert1717 = $$pre1716&255;
   $$phi$trans$insert1718 = (79212 + ($$phi$trans$insert1717<<2)|0);
   $$pre1719 = HEAP32[$$phi$trans$insert1718>>2]|0;
   $$pre1720 = HEAP32[$458>>2]|0;
   $$pre1721 = HEAP8[$459>>0]|0;
   $$pre1722 = HEAP8[$460>>0]|0;
   $$phi$trans$insert1723 = $$pre1722&255;
   $$phi$trans$insert1724 = (79212 + ($$phi$trans$insert1723<<2)|0);
   $$pre1725 = HEAP32[$$phi$trans$insert1724>>2]|0;
   $$pre1726 = HEAP32[$461>>2]|0;
   $$pre1727 = HEAP8[$462>>0]|0;
   $$pre1728 = HEAP8[$463>>0]|0;
   $$phi$trans$insert1729 = $$pre1728&255;
   $$phi$trans$insert1730 = (79212 + ($$phi$trans$insert1729<<2)|0);
   $$pre1731 = HEAP32[$$phi$trans$insert1730>>2]|0;
   $$pre1732 = HEAP32[$464>>2]|0;
   $$pre1733 = HEAP8[$465>>0]|0;
   $$pre1734 = HEAP32[$466>>2]|0;
   $467 = $$pre1721&255;
   $468 = $$pre1727&255;
   $469 = $$pre1733&255;
   $$013791533 = $455;$$113811532 = $$11381$ph;
   while(1) {
    $470 = (($$013791533) + -1)|0;
    $471 = HEAP16[$$113811532>>1]|0;
    $472 = $471&65535;
    $473 = $472 & $$pre1720;
    $474 = $473 >>> $467;
    $475 = (($$pre1719) + ($474)|0);
    $476 = HEAP8[$475>>0]|0;
    $477 = $476&255;
    $478 = $$pre1726 & $472;
    $479 = $478 >>> $468;
    $480 = (($$pre1725) + ($479)|0);
    $481 = HEAP8[$480>>0]|0;
    $482 = $481&255;
    $483 = $$pre1732 & $472;
    $484 = $483 >>> $469;
    $485 = (($$pre1731) + ($484)|0);
    $486 = HEAP8[$485>>0]|0;
    $487 = $486&255;
    $488 = Math_imul($477, $$0)|0;
    $489 = (($488>>>0) / 255)&-1;
    $490 = Math_imul($482, $$01319)|0;
    $491 = (($490>>>0) / 255)&-1;
    $492 = Math_imul($487, $$01320)|0;
    $493 = (($492>>>0) / 255)&-1;
    $494 = $489 >>> $$phi$trans$insert1717;
    $495 = $494 << $467;
    $496 = $491 >>> $$phi$trans$insert1723;
    $497 = $496 << $468;
    $498 = $497 | $495;
    $499 = $493 >>> $$phi$trans$insert1729;
    $500 = $499 << $469;
    $501 = $498 | $$pre1734;
    $502 = $501 | $500;
    $503 = $502&65535;
    HEAP16[$$113811532>>1] = $503;
    $504 = (($$113811532) + ($440<<1)|0);
    $505 = ($470|0)==(0);
    if ($505) {
     break;
    } else {
     $$013791533 = $470;$$113811532 = $504;
    }
   }
   return;
   break;
  }
  default: {
   $506 = ((($0)) + 16|0);
   $507 = HEAP32[$506>>2]|0;
   $508 = ((($12)) + 9|0);
   $509 = HEAP8[$508>>0]|0;
   $510 = $509&255;
   $511 = (($507|0) / ($510|0))&-1;
   $512 = ($4|0)<($2|0);
   $513 = ((($0)) + 20|0);
   $514 = HEAP32[$513>>2]|0;
   $515 = ($10|0)!=(0);
   if ($512) {
    $520 = Math_imul($511, $4)|0;
    $521 = (($514) + ($520<<1)|0);
    $522 = (($521) + ($3<<1)|0);
    $523 = (($522) + ($511<<1)|0);
    $$1464 = $515 ? $522 : $523;
    $524 = (($2) - ($4))|0;
    $$11403$ph = $$1464;$$sink1581 = $524;
   } else {
    $516 = Math_imul($511, $2)|0;
    $517 = (($514) + ($516<<1)|0);
    $518 = (($517) + ($3<<1)|0);
    $519 = (($4) - ($2))|0;
    $$11403$ph = $518;$$sink1581 = $519;
   }
   $525 = $515&1;
   $526 = (($$sink1581) + ($525))|0;
   $527 = ($526|0)==(0);
   if ($527) {
    return;
   }
   $528 = ((($12)) + 28|0);
   $529 = HEAP8[$528>>0]|0;
   $530 = $529&255;
   $531 = $$0 >>> $530;
   $532 = ((($12)) + 32|0);
   $533 = HEAP8[$532>>0]|0;
   $534 = $533&255;
   $535 = $531 << $534;
   $536 = ((($12)) + 29|0);
   $537 = HEAP8[$536>>0]|0;
   $538 = $537&255;
   $539 = $$01319 >>> $538;
   $540 = ((($12)) + 33|0);
   $541 = HEAP8[$540>>0]|0;
   $542 = $541&255;
   $543 = $539 << $542;
   $544 = $543 | $535;
   $545 = ((($12)) + 30|0);
   $546 = HEAP8[$545>>0]|0;
   $547 = $546&255;
   $548 = $$01320 >>> $547;
   $549 = ((($12)) + 34|0);
   $550 = HEAP8[$549>>0]|0;
   $551 = $550&255;
   $552 = $548 << $551;
   $553 = ((($12)) + 24|0);
   $554 = HEAP32[$553>>2]|0;
   $555 = $544 | $554;
   $556 = $555 | $552;
   $557 = $556&65535;
   $$013821524 = $526;$$114031523 = $$11403$ph;
   while(1) {
    $558 = (($$013821524) + -1)|0;
    HEAP16[$$114031523>>1] = $557;
    $559 = (($$114031523) + ($511<<1)|0);
    $560 = ($558|0)==(0);
    if ($560) {
     break;
    } else {
     $$013821524 = $558;$$114031523 = $559;
    }
   }
   return;
  }
  }
 }
 $561 = (($1) - ($3))|0;
 $562 = ($561|0)<(0);
 $563 = (0 - ($561))|0;
 $564 = $562 ? $563 : $561;
 $565 = (($2) - ($4))|0;
 $566 = ($565|0)<(0);
 $567 = (0 - ($565))|0;
 $568 = $566 ? $567 : $565;
 $569 = ($564|0)==($568|0);
 if ($569) {
  switch ($5|0) {
  case 1:  {
   $570 = ((($0)) + 16|0);
   $571 = HEAP32[$570>>2]|0;
   $572 = ((($12)) + 9|0);
   $573 = HEAP8[$572>>0]|0;
   $574 = $573&255;
   $575 = (($571|0) / ($574|0))&-1;
   $576 = ($4|0)<($2|0);
   $577 = ((($0)) + 20|0);
   $578 = HEAP32[$577>>2]|0;
   if ($576) {
    $585 = Math_imul($575, $4)|0;
    $586 = (($578) + ($585<<1)|0);
    $587 = (($586) + ($3<<1)|0);
    $588 = ($3|0)>($1|0);
    $$sink1465 = $588 ? -1 : 1;
    $589 = (($575) + ($$sink1465))|0;
    $590 = ($10|0)==(0);
    $591 = (($587) + ($589<<1)|0);
    $$1466 = $590 ? $591 : $587;
    $$01404 = $565;$$11411 = $$1466;$$21409 = $589;
   } else {
    $579 = Math_imul($575, $2)|0;
    $580 = (($578) + ($579<<1)|0);
    $581 = (($580) + ($1<<1)|0);
    $582 = ($3|0)<($1|0);
    $$sink = $582 ? -1 : 1;
    $583 = (($575) + ($$sink))|0;
    $584 = (($4) - ($2))|0;
    $$01404 = $584;$$11411 = $581;$$21409 = $583;
   }
   $not$1485 = ($10|0)!=(0);
   $592 = $not$1485&1;
   $$01404$ = (($$01404) + ($592))|0;
   $593 = ($$01404$|0)==(0);
   if ($593) {
    return;
   }
   $594 = ((($12)) + 28|0);
   $595 = ((($12)) + 12|0);
   $596 = ((($12)) + 32|0);
   $597 = ((($12)) + 29|0);
   $598 = ((($12)) + 16|0);
   $599 = ((($12)) + 33|0);
   $600 = ((($12)) + 30|0);
   $601 = ((($12)) + 20|0);
   $602 = ((($12)) + 34|0);
   $603 = ((($12)) + 24|0);
   $$pre1697 = HEAP8[$594>>0]|0;
   $$phi$trans$insert1698 = $$pre1697&255;
   $$phi$trans$insert1699 = (79212 + ($$phi$trans$insert1698<<2)|0);
   $$pre1700 = HEAP32[$$phi$trans$insert1699>>2]|0;
   $$pre1701 = HEAP32[$595>>2]|0;
   $$pre1702 = HEAP8[$596>>0]|0;
   $$pre1703 = HEAP8[$597>>0]|0;
   $$phi$trans$insert1704 = $$pre1703&255;
   $$phi$trans$insert1705 = (79212 + ($$phi$trans$insert1704<<2)|0);
   $$pre1706 = HEAP32[$$phi$trans$insert1705>>2]|0;
   $$pre1707 = HEAP32[$598>>2]|0;
   $$pre1708 = HEAP8[$599>>0]|0;
   $$pre1709 = HEAP8[$600>>0]|0;
   $$phi$trans$insert1710 = $$pre1709&255;
   $$phi$trans$insert1711 = (79212 + ($$phi$trans$insert1710<<2)|0);
   $$pre1712 = HEAP32[$$phi$trans$insert1711>>2]|0;
   $$pre1713 = HEAP32[$601>>2]|0;
   $$pre1714 = HEAP8[$602>>0]|0;
   $$pre1715 = HEAP32[$603>>2]|0;
   $604 = $$pre1702&255;
   $605 = $$pre1708&255;
   $606 = $$pre1714&255;
   $$114051539 = $$01404$;$$214121538 = $$11411;
   while(1) {
    $607 = (($$114051539) + -1)|0;
    $608 = HEAP16[$$214121538>>1]|0;
    $609 = $608&65535;
    $610 = $609 & $$pre1701;
    $611 = $610 >>> $604;
    $612 = (($$pre1700) + ($611)|0);
    $613 = HEAP8[$612>>0]|0;
    $614 = $613&255;
    $615 = $$pre1707 & $609;
    $616 = $615 >>> $605;
    $617 = (($$pre1706) + ($616)|0);
    $618 = HEAP8[$617>>0]|0;
    $619 = $618&255;
    $620 = $$pre1713 & $609;
    $621 = $620 >>> $606;
    $622 = (($$pre1712) + ($621)|0);
    $623 = HEAP8[$622>>0]|0;
    $624 = $623&255;
    $625 = Math_imul($614, $24)|0;
    $626 = (($625>>>0) / 255)&-1;
    $627 = (($626) + ($$0))|0;
    $628 = Math_imul($619, $24)|0;
    $629 = (($628>>>0) / 255)&-1;
    $630 = (($629) + ($$01319))|0;
    $631 = Math_imul($624, $24)|0;
    $632 = (($631>>>0) / 255)&-1;
    $633 = (($632) + ($$01320))|0;
    $634 = $627 >>> $$phi$trans$insert1698;
    $635 = $634 << $604;
    $636 = $630 >>> $$phi$trans$insert1704;
    $637 = $636 << $605;
    $638 = $637 | $635;
    $639 = $633 >>> $$phi$trans$insert1710;
    $640 = $639 << $606;
    $641 = $638 | $$pre1715;
    $642 = $641 | $640;
    $643 = $642&65535;
    HEAP16[$$214121538>>1] = $643;
    $644 = (($$214121538) + ($$21409<<1)|0);
    $645 = ($607|0)==(0);
    if ($645) {
     break;
    } else {
     $$114051539 = $607;$$214121538 = $644;
    }
   }
   return;
   break;
  }
  case 2:  {
   $646 = ((($0)) + 16|0);
   $647 = HEAP32[$646>>2]|0;
   $648 = ((($12)) + 9|0);
   $649 = HEAP8[$648>>0]|0;
   $650 = $649&255;
   $651 = (($647|0) / ($650|0))&-1;
   $652 = ($4|0)<($2|0);
   $653 = ((($0)) + 20|0);
   $654 = HEAP32[$653>>2]|0;
   if ($652) {
    $661 = Math_imul($651, $4)|0;
    $662 = (($654) + ($661<<1)|0);
    $663 = (($662) + ($3<<1)|0);
    $664 = ($3|0)>($1|0);
    $$sink1468 = $664 ? -1 : 1;
    $665 = (($651) + ($$sink1468))|0;
    $666 = ($10|0)==(0);
    $667 = (($663) + ($665<<1)|0);
    $$1469 = $666 ? $667 : $663;
    $$01413 = $565;$$11419 = $$1469;$$21417 = $665;
   } else {
    $655 = Math_imul($651, $2)|0;
    $656 = (($654) + ($655<<1)|0);
    $657 = (($656) + ($1<<1)|0);
    $658 = ($3|0)<($1|0);
    $$sink1467 = $658 ? -1 : 1;
    $659 = (($651) + ($$sink1467))|0;
    $660 = (($4) - ($2))|0;
    $$01413 = $660;$$11419 = $657;$$21417 = $659;
   }
   $not$1484 = ($10|0)!=(0);
   $668 = $not$1484&1;
   $$01413$ = (($$01413) + ($668))|0;
   $669 = ($$01413$|0)==(0);
   if ($669) {
    return;
   }
   $670 = ((($12)) + 28|0);
   $671 = ((($12)) + 12|0);
   $672 = ((($12)) + 32|0);
   $673 = ((($12)) + 29|0);
   $674 = ((($12)) + 16|0);
   $675 = ((($12)) + 33|0);
   $676 = ((($12)) + 30|0);
   $677 = ((($12)) + 20|0);
   $678 = ((($12)) + 34|0);
   $679 = ((($12)) + 24|0);
   $$pre1678 = HEAP8[$670>>0]|0;
   $$phi$trans$insert1679 = $$pre1678&255;
   $$phi$trans$insert1680 = (79212 + ($$phi$trans$insert1679<<2)|0);
   $$pre1681 = HEAP32[$$phi$trans$insert1680>>2]|0;
   $$pre1682 = HEAP32[$671>>2]|0;
   $$pre1683 = HEAP8[$672>>0]|0;
   $$pre1684 = HEAP8[$673>>0]|0;
   $$phi$trans$insert1685 = $$pre1684&255;
   $$phi$trans$insert1686 = (79212 + ($$phi$trans$insert1685<<2)|0);
   $$pre1687 = HEAP32[$$phi$trans$insert1686>>2]|0;
   $$pre1688 = HEAP32[$674>>2]|0;
   $$pre1689 = HEAP8[$675>>0]|0;
   $$pre1690 = HEAP8[$676>>0]|0;
   $$phi$trans$insert1691 = $$pre1690&255;
   $$phi$trans$insert1692 = (79212 + ($$phi$trans$insert1691<<2)|0);
   $$pre1693 = HEAP32[$$phi$trans$insert1692>>2]|0;
   $$pre1694 = HEAP32[$677>>2]|0;
   $$pre1695 = HEAP8[$678>>0]|0;
   $$pre1696 = HEAP32[$679>>2]|0;
   $680 = $$pre1683&255;
   $681 = $$pre1689&255;
   $682 = $$pre1695&255;
   $$114141542 = $$01413$;$$214201541 = $$11419;
   while(1) {
    $683 = (($$114141542) + -1)|0;
    $684 = HEAP16[$$214201541>>1]|0;
    $685 = $684&65535;
    $686 = $685 & $$pre1682;
    $687 = $686 >>> $680;
    $688 = (($$pre1681) + ($687)|0);
    $689 = HEAP8[$688>>0]|0;
    $690 = $689&255;
    $691 = $$pre1688 & $685;
    $692 = $691 >>> $681;
    $693 = (($$pre1687) + ($692)|0);
    $694 = HEAP8[$693>>0]|0;
    $695 = $694&255;
    $696 = $$pre1694 & $685;
    $697 = $696 >>> $682;
    $698 = (($$pre1693) + ($697)|0);
    $699 = HEAP8[$698>>0]|0;
    $700 = $699&255;
    $701 = (($690) + ($$0))|0;
    $702 = ($701>>>0)<(255);
    $$5 = $702 ? $701 : 255;
    $703 = (($695) + ($$01319))|0;
    $704 = ($703>>>0)<(255);
    $$10 = $704 ? $703 : 255;
    $705 = (($700) + ($$01320))|0;
    $706 = ($705>>>0)<(255);
    $$6 = $706 ? $705 : 255;
    $707 = $$5 >>> $$phi$trans$insert1679;
    $708 = $707 << $680;
    $709 = $$10 >>> $$phi$trans$insert1685;
    $710 = $709 << $681;
    $711 = $710 | $708;
    $712 = $$6 >>> $$phi$trans$insert1691;
    $713 = $712 << $682;
    $714 = $711 | $$pre1696;
    $715 = $714 | $713;
    $716 = $715&65535;
    HEAP16[$$214201541>>1] = $716;
    $717 = (($$214201541) + ($$21417<<1)|0);
    $718 = ($683|0)==(0);
    if ($718) {
     break;
    } else {
     $$114141542 = $683;$$214201541 = $717;
    }
   }
   return;
   break;
  }
  case 4:  {
   $719 = ((($0)) + 16|0);
   $720 = HEAP32[$719>>2]|0;
   $721 = ((($12)) + 9|0);
   $722 = HEAP8[$721>>0]|0;
   $723 = $722&255;
   $724 = (($720|0) / ($723|0))&-1;
   $725 = ($4|0)<($2|0);
   $726 = ((($0)) + 20|0);
   $727 = HEAP32[$726>>2]|0;
   if ($725) {
    $734 = Math_imul($724, $4)|0;
    $735 = (($727) + ($734<<1)|0);
    $736 = (($735) + ($3<<1)|0);
    $737 = ($3|0)>($1|0);
    $$sink1471 = $737 ? -1 : 1;
    $738 = (($724) + ($$sink1471))|0;
    $739 = ($10|0)==(0);
    $740 = (($736) + ($738<<1)|0);
    $$1472 = $739 ? $740 : $736;
    $$01440 = $565;$$11447 = $$1472;$$21444 = $738;
   } else {
    $728 = Math_imul($724, $2)|0;
    $729 = (($727) + ($728<<1)|0);
    $730 = (($729) + ($1<<1)|0);
    $731 = ($3|0)<($1|0);
    $$sink1470 = $731 ? -1 : 1;
    $732 = (($724) + ($$sink1470))|0;
    $733 = (($4) - ($2))|0;
    $$01440 = $733;$$11447 = $730;$$21444 = $732;
   }
   $not$1483 = ($10|0)!=(0);
   $741 = $not$1483&1;
   $$01440$ = (($$01440) + ($741))|0;
   $742 = ($$01440$|0)==(0);
   if ($742) {
    return;
   }
   $743 = ((($12)) + 28|0);
   $744 = ((($12)) + 12|0);
   $745 = ((($12)) + 32|0);
   $746 = ((($12)) + 29|0);
   $747 = ((($12)) + 16|0);
   $748 = ((($12)) + 33|0);
   $749 = ((($12)) + 30|0);
   $750 = ((($12)) + 20|0);
   $751 = ((($12)) + 34|0);
   $752 = ((($12)) + 24|0);
   $$pre1659 = HEAP8[$743>>0]|0;
   $$phi$trans$insert1660 = $$pre1659&255;
   $$phi$trans$insert1661 = (79212 + ($$phi$trans$insert1660<<2)|0);
   $$pre1662 = HEAP32[$$phi$trans$insert1661>>2]|0;
   $$pre1663 = HEAP32[$744>>2]|0;
   $$pre1664 = HEAP8[$745>>0]|0;
   $$pre1665 = HEAP8[$746>>0]|0;
   $$phi$trans$insert1666 = $$pre1665&255;
   $$phi$trans$insert1667 = (79212 + ($$phi$trans$insert1666<<2)|0);
   $$pre1668 = HEAP32[$$phi$trans$insert1667>>2]|0;
   $$pre1669 = HEAP32[$747>>2]|0;
   $$pre1670 = HEAP8[$748>>0]|0;
   $$pre1671 = HEAP8[$749>>0]|0;
   $$phi$trans$insert1672 = $$pre1671&255;
   $$phi$trans$insert1673 = (79212 + ($$phi$trans$insert1672<<2)|0);
   $$pre1674 = HEAP32[$$phi$trans$insert1673>>2]|0;
   $$pre1675 = HEAP32[$750>>2]|0;
   $$pre1676 = HEAP8[$751>>0]|0;
   $$pre1677 = HEAP32[$752>>2]|0;
   $753 = $$pre1664&255;
   $754 = $$pre1670&255;
   $755 = $$pre1676&255;
   $$114411545 = $$01440$;$$214481544 = $$11447;
   while(1) {
    $756 = (($$114411545) + -1)|0;
    $757 = HEAP16[$$214481544>>1]|0;
    $758 = $757&65535;
    $759 = $758 & $$pre1663;
    $760 = $759 >>> $753;
    $761 = (($$pre1662) + ($760)|0);
    $762 = HEAP8[$761>>0]|0;
    $763 = $762&255;
    $764 = $$pre1669 & $758;
    $765 = $764 >>> $754;
    $766 = (($$pre1668) + ($765)|0);
    $767 = HEAP8[$766>>0]|0;
    $768 = $767&255;
    $769 = $$pre1675 & $758;
    $770 = $769 >>> $755;
    $771 = (($$pre1674) + ($770)|0);
    $772 = HEAP8[$771>>0]|0;
    $773 = $772&255;
    $774 = Math_imul($763, $$0)|0;
    $775 = (($774>>>0) / 255)&-1;
    $776 = Math_imul($768, $$01319)|0;
    $777 = (($776>>>0) / 255)&-1;
    $778 = Math_imul($773, $$01320)|0;
    $779 = (($778>>>0) / 255)&-1;
    $780 = $775 >>> $$phi$trans$insert1660;
    $781 = $780 << $753;
    $782 = $777 >>> $$phi$trans$insert1666;
    $783 = $782 << $754;
    $784 = $783 | $781;
    $785 = $779 >>> $$phi$trans$insert1672;
    $786 = $785 << $755;
    $787 = $784 | $$pre1677;
    $788 = $787 | $786;
    $789 = $788&65535;
    HEAP16[$$214481544>>1] = $789;
    $790 = (($$214481544) + ($$21444<<1)|0);
    $791 = ($756|0)==(0);
    if ($791) {
     break;
    } else {
     $$114411545 = $756;$$214481544 = $790;
    }
   }
   return;
   break;
  }
  default: {
   $792 = ((($0)) + 16|0);
   $793 = HEAP32[$792>>2]|0;
   $794 = ((($12)) + 9|0);
   $795 = HEAP8[$794>>0]|0;
   $796 = $795&255;
   $797 = (($793|0) / ($796|0))&-1;
   $798 = ($4|0)<($2|0);
   $799 = ((($0)) + 20|0);
   $800 = HEAP32[$799>>2]|0;
   if ($798) {
    $807 = Math_imul($797, $4)|0;
    $808 = (($800) + ($807<<1)|0);
    $809 = (($808) + ($3<<1)|0);
    $810 = ($3|0)>($1|0);
    $$sink1474 = $810 ? -1 : 1;
    $811 = (($797) + ($$sink1474))|0;
    $812 = ($10|0)==(0);
    $813 = (($809) + ($811<<1)|0);
    $$1475 = $812 ? $813 : $809;
    $$01449 = $565;$$11455 = $$1475;$$21453 = $811;
   } else {
    $801 = Math_imul($797, $2)|0;
    $802 = (($800) + ($801<<1)|0);
    $803 = (($802) + ($1<<1)|0);
    $804 = ($3|0)<($1|0);
    $$sink1473 = $804 ? -1 : 1;
    $805 = (($797) + ($$sink1473))|0;
    $806 = (($4) - ($2))|0;
    $$01449 = $806;$$11455 = $803;$$21453 = $805;
   }
   $not$1486 = ($10|0)!=(0);
   $814 = $not$1486&1;
   $$01449$ = (($$01449) + ($814))|0;
   $815 = ($$01449$|0)==(0);
   if ($815) {
    return;
   }
   $816 = ((($12)) + 28|0);
   $817 = HEAP8[$816>>0]|0;
   $818 = $817&255;
   $819 = $$0 >>> $818;
   $820 = ((($12)) + 32|0);
   $821 = HEAP8[$820>>0]|0;
   $822 = $821&255;
   $823 = $819 << $822;
   $824 = ((($12)) + 29|0);
   $825 = HEAP8[$824>>0]|0;
   $826 = $825&255;
   $827 = $$01319 >>> $826;
   $828 = ((($12)) + 33|0);
   $829 = HEAP8[$828>>0]|0;
   $830 = $829&255;
   $831 = $827 << $830;
   $832 = $831 | $823;
   $833 = ((($12)) + 30|0);
   $834 = HEAP8[$833>>0]|0;
   $835 = $834&255;
   $836 = $$01320 >>> $835;
   $837 = ((($12)) + 34|0);
   $838 = HEAP8[$837>>0]|0;
   $839 = $838&255;
   $840 = $836 << $839;
   $841 = ((($12)) + 24|0);
   $842 = HEAP32[$841>>2]|0;
   $843 = $832 | $842;
   $844 = $843 | $840;
   $845 = $844&65535;
   $$114501536 = $$01449$;$$214561535 = $$11455;
   while(1) {
    $846 = (($$114501536) + -1)|0;
    HEAP16[$$214561535>>1] = $845;
    $847 = (($$214561535) + ($$21453<<1)|0);
    $848 = ($846|0)==(0);
    if ($848) {
     break;
    } else {
     $$114501536 = $846;$$214561535 = $847;
    }
   }
   return;
  }
  }
 } else {
  switch ($5|0) {
  case 1:  {
   $849 = (($3) - ($1))|0;
   $850 = ($849|0)<(0);
   $851 = (0 - ($849))|0;
   $852 = $850 ? $851 : $849;
   $853 = (($4) - ($2))|0;
   $854 = ($853|0)<(0);
   $855 = (0 - ($853))|0;
   $856 = $854 ? $855 : $853;
   $857 = ($852|0)<($856|0);
   if ($857) {
    $861 = $852 << 1;
    $862 = (($861) - ($856))|0;
    $863 = (($852) - ($856))|0;
    $$01423 = 1;$$01429 = 0;$$01433$in = $863;$$01434 = $861;$$01435 = $862;$$01438$in = $856;
   } else {
    $858 = $856 << 1;
    $859 = (($858) - ($852))|0;
    $860 = (($856) - ($852))|0;
    $$01423 = 0;$$01429 = 1;$$01433$in = $860;$$01434 = $858;$$01435 = $859;$$01438$in = $852;
   }
   $$01433 = $$01433$in << 1;
   $864 = ($3|0)<($1|0);
   $865 = (0 - ($$01429))|0;
   $$$01429 = $864 ? $865 : $$01429;
   $$1476 = $864 ? -1 : 1;
   $866 = ($4|0)<($2|0);
   $867 = (0 - ($$01423))|0;
   $$11424 = $866 ? $867 : $$01423;
   $$11422 = $866 ? -1 : 1;
   $not$1481 = ($10|0)!=(0);
   $$01438 = $not$1481&1;
   $$01438$in$$01438 = (($$01438$in) + ($$01438))|0;
   $868 = ($$01438$in$$01438|0)>(0);
   if (!($868)) {
    return;
   }
   $869 = ((($0)) + 20|0);
   $870 = ((($0)) + 16|0);
   $871 = ((($12)) + 28|0);
   $872 = ((($12)) + 12|0);
   $873 = ((($12)) + 32|0);
   $874 = ((($12)) + 29|0);
   $875 = ((($12)) + 16|0);
   $876 = ((($12)) + 33|0);
   $877 = ((($12)) + 30|0);
   $878 = ((($12)) + 20|0);
   $879 = ((($12)) + 34|0);
   $880 = ((($12)) + 24|0);
   $$pre1638 = HEAP32[$869>>2]|0;
   $$pre1639 = HEAP32[$870>>2]|0;
   $$pre1640 = HEAP8[$871>>0]|0;
   $$phi$trans$insert1641 = $$pre1640&255;
   $$phi$trans$insert1642 = (79212 + ($$phi$trans$insert1641<<2)|0);
   $$pre1643 = HEAP32[$$phi$trans$insert1642>>2]|0;
   $$pre1644 = HEAP32[$872>>2]|0;
   $$pre1645 = HEAP8[$873>>0]|0;
   $$pre1646 = HEAP8[$874>>0]|0;
   $$phi$trans$insert1647 = $$pre1646&255;
   $$phi$trans$insert1648 = (79212 + ($$phi$trans$insert1647<<2)|0);
   $$pre1649 = HEAP32[$$phi$trans$insert1648>>2]|0;
   $$pre1650 = HEAP32[$875>>2]|0;
   $$pre1651 = HEAP8[$876>>0]|0;
   $$pre1652 = HEAP8[$877>>0]|0;
   $$phi$trans$insert1653 = $$pre1652&255;
   $$phi$trans$insert1654 = (79212 + ($$phi$trans$insert1653<<2)|0);
   $$pre1655 = HEAP32[$$phi$trans$insert1654>>2]|0;
   $$pre1656 = HEAP32[$878>>2]|0;
   $$pre1657 = HEAP8[$879>>0]|0;
   $$pre1658 = HEAP32[$880>>2]|0;
   $881 = $$pre1645&255;
   $882 = $$pre1651&255;
   $883 = $$pre1657&255;
   $$014251555 = $2;$$014311554 = $1;$$014451552 = 0;$$114361553 = $$01435;
   while(1) {
    $884 = Math_imul($$pre1639, $$014251555)|0;
    $885 = (($$pre1638) + ($884)|0);
    $886 = $$014311554 << 1;
    $887 = (($885) + ($886)|0);
    $888 = HEAP16[$887>>1]|0;
    $889 = $888&65535;
    $890 = $889 & $$pre1644;
    $891 = $890 >>> $881;
    $892 = (($$pre1643) + ($891)|0);
    $893 = HEAP8[$892>>0]|0;
    $894 = $893&255;
    $895 = $$pre1650 & $889;
    $896 = $895 >>> $882;
    $897 = (($$pre1649) + ($896)|0);
    $898 = HEAP8[$897>>0]|0;
    $899 = $898&255;
    $900 = $$pre1656 & $889;
    $901 = $900 >>> $883;
    $902 = (($$pre1655) + ($901)|0);
    $903 = HEAP8[$902>>0]|0;
    $904 = $903&255;
    $905 = Math_imul($894, $24)|0;
    $906 = (($905>>>0) / 255)&-1;
    $907 = (($906) + ($$0))|0;
    $908 = Math_imul($899, $24)|0;
    $909 = (($908>>>0) / 255)&-1;
    $910 = (($909) + ($$01319))|0;
    $911 = Math_imul($904, $24)|0;
    $912 = (($911>>>0) / 255)&-1;
    $913 = (($912) + ($$01320))|0;
    $914 = $907 >>> $$phi$trans$insert1641;
    $915 = $914 << $881;
    $916 = $910 >>> $$phi$trans$insert1647;
    $917 = $916 << $882;
    $918 = $917 | $915;
    $919 = $913 >>> $$phi$trans$insert1653;
    $920 = $919 << $883;
    $921 = $918 | $$pre1658;
    $922 = $921 | $920;
    $923 = $922&65535;
    HEAP16[$887>>1] = $923;
    $924 = ($$114361553|0)<(0);
    $$01434$$01433 = $924 ? $$01434 : $$01433;
    $$$01429$$1476 = $924 ? $$$01429 : $$1476;
    $$11424$$11422 = $924 ? $$11424 : $$11422;
    $$11426 = (($$014251555) + ($$11424$$11422))|0;
    $$11432 = (($$$01429$$1476) + ($$014311554))|0;
    $$21437 = (($$01434$$01433) + ($$114361553))|0;
    $925 = (($$014451552) + 1)|0;
    $926 = ($925|0)<($$01438$in$$01438|0);
    if ($926) {
     $$014251555 = $$11426;$$014311554 = $$11432;$$014451552 = $925;$$114361553 = $$21437;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 2:  {
   $927 = (($3) - ($1))|0;
   $928 = ($927|0)<(0);
   $929 = (0 - ($927))|0;
   $930 = $928 ? $929 : $927;
   $931 = (($4) - ($2))|0;
   $932 = ($931|0)<(0);
   $933 = (0 - ($931))|0;
   $934 = $932 ? $933 : $931;
   $935 = ($930|0)<($934|0);
   if ($935) {
    $939 = $930 << 1;
    $940 = (($939) - ($934))|0;
    $941 = (($930) - ($934))|0;
    $$01385 = 1;$$01391 = 0;$$01395$in = $941;$$01396 = $939;$$01397 = $940;$$01400$in = $934;
   } else {
    $936 = $934 << 1;
    $937 = (($936) - ($930))|0;
    $938 = (($934) - ($930))|0;
    $$01385 = 0;$$01391 = 1;$$01395$in = $938;$$01396 = $936;$$01397 = $937;$$01400$in = $930;
   }
   $$01395 = $$01395$in << 1;
   $942 = ($3|0)<($1|0);
   $943 = (0 - ($$01391))|0;
   $$$01391 = $942 ? $943 : $$01391;
   $$1477 = $942 ? -1 : 1;
   $944 = ($4|0)<($2|0);
   $945 = (0 - ($$01385))|0;
   $$11386 = $944 ? $945 : $$01385;
   $$11384 = $944 ? -1 : 1;
   $not$1480 = ($10|0)!=(0);
   $$01400 = $not$1480&1;
   $$01400$in$$01400 = (($$01400$in) + ($$01400))|0;
   $946 = ($$01400$in$$01400|0)>(0);
   if (!($946)) {
    return;
   }
   $947 = ((($0)) + 20|0);
   $948 = ((($0)) + 16|0);
   $949 = ((($12)) + 28|0);
   $950 = ((($12)) + 12|0);
   $951 = ((($12)) + 32|0);
   $952 = ((($12)) + 29|0);
   $953 = ((($12)) + 16|0);
   $954 = ((($12)) + 33|0);
   $955 = ((($12)) + 30|0);
   $956 = ((($12)) + 20|0);
   $957 = ((($12)) + 34|0);
   $958 = ((($12)) + 24|0);
   $$pre1617 = HEAP32[$947>>2]|0;
   $$pre1618 = HEAP32[$948>>2]|0;
   $$pre1619 = HEAP8[$949>>0]|0;
   $$phi$trans$insert1620 = $$pre1619&255;
   $$phi$trans$insert1621 = (79212 + ($$phi$trans$insert1620<<2)|0);
   $$pre1622 = HEAP32[$$phi$trans$insert1621>>2]|0;
   $$pre1623 = HEAP32[$950>>2]|0;
   $$pre1624 = HEAP8[$951>>0]|0;
   $$pre1625 = HEAP8[$952>>0]|0;
   $$phi$trans$insert1626 = $$pre1625&255;
   $$phi$trans$insert1627 = (79212 + ($$phi$trans$insert1626<<2)|0);
   $$pre1628 = HEAP32[$$phi$trans$insert1627>>2]|0;
   $$pre1629 = HEAP32[$953>>2]|0;
   $$pre1630 = HEAP8[$954>>0]|0;
   $$pre1631 = HEAP8[$955>>0]|0;
   $$phi$trans$insert1632 = $$pre1631&255;
   $$phi$trans$insert1633 = (79212 + ($$phi$trans$insert1632<<2)|0);
   $$pre1634 = HEAP32[$$phi$trans$insert1633>>2]|0;
   $$pre1635 = HEAP32[$956>>2]|0;
   $$pre1636 = HEAP8[$957>>0]|0;
   $$pre1637 = HEAP32[$958>>2]|0;
   $959 = $$pre1624&255;
   $960 = $$pre1630&255;
   $961 = $$pre1636&255;
   $$013871560 = $2;$$013931559 = $1;$$014061557 = 0;$$113981558 = $$01397;
   while(1) {
    $962 = Math_imul($$pre1618, $$013871560)|0;
    $963 = (($$pre1617) + ($962)|0);
    $964 = $$013931559 << 1;
    $965 = (($963) + ($964)|0);
    $966 = HEAP16[$965>>1]|0;
    $967 = $966&65535;
    $968 = $967 & $$pre1623;
    $969 = $968 >>> $959;
    $970 = (($$pre1622) + ($969)|0);
    $971 = HEAP8[$970>>0]|0;
    $972 = $971&255;
    $973 = $$pre1629 & $967;
    $974 = $973 >>> $960;
    $975 = (($$pre1628) + ($974)|0);
    $976 = HEAP8[$975>>0]|0;
    $977 = $976&255;
    $978 = $$pre1635 & $967;
    $979 = $978 >>> $961;
    $980 = (($$pre1634) + ($979)|0);
    $981 = HEAP8[$980>>0]|0;
    $982 = $981&255;
    $983 = (($972) + ($$0))|0;
    $984 = ($983>>>0)<(255);
    $$11 = $984 ? $983 : 255;
    $985 = (($977) + ($$01319))|0;
    $986 = ($985>>>0)<(255);
    $$7 = $986 ? $985 : 255;
    $987 = (($982) + ($$01320))|0;
    $988 = ($987>>>0)<(255);
    $$12 = $988 ? $987 : 255;
    $989 = $$11 >>> $$phi$trans$insert1620;
    $990 = $989 << $959;
    $991 = $$7 >>> $$phi$trans$insert1626;
    $992 = $991 << $960;
    $993 = $992 | $990;
    $994 = $$12 >>> $$phi$trans$insert1632;
    $995 = $994 << $961;
    $996 = $993 | $$pre1637;
    $997 = $996 | $995;
    $998 = $997&65535;
    HEAP16[$965>>1] = $998;
    $999 = ($$113981558|0)<(0);
    $$01396$$01395 = $999 ? $$01396 : $$01395;
    $$$01391$$1477 = $999 ? $$$01391 : $$1477;
    $$11386$$11384 = $999 ? $$11386 : $$11384;
    $$11388 = (($$013871560) + ($$11386$$11384))|0;
    $$11394 = (($$$01391$$1477) + ($$013931559))|0;
    $$21399 = (($$01396$$01395) + ($$113981558))|0;
    $1000 = (($$014061557) + 1)|0;
    $1001 = ($1000|0)<($$01400$in$$01400|0);
    if ($1001) {
     $$013871560 = $$11388;$$013931559 = $$11394;$$014061557 = $1000;$$113981558 = $$21399;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 4:  {
   $1002 = (($3) - ($1))|0;
   $1003 = ($1002|0)<(0);
   $1004 = (0 - ($1002))|0;
   $1005 = $1003 ? $1004 : $1002;
   $1006 = (($4) - ($2))|0;
   $1007 = ($1006|0)<(0);
   $1008 = (0 - ($1006))|0;
   $1009 = $1007 ? $1008 : $1006;
   $1010 = ($1005|0)<($1009|0);
   if ($1010) {
    $1014 = $1005 << 1;
    $1015 = (($1014) - ($1009))|0;
    $1016 = (($1005) - ($1009))|0;
    $$01355 = 1;$$01361 = 0;$$01365$in = $1016;$$01366 = $1014;$$01367 = $1015;$$01370$in = $1009;
   } else {
    $1011 = $1009 << 1;
    $1012 = (($1011) - ($1005))|0;
    $1013 = (($1009) - ($1005))|0;
    $$01355 = 0;$$01361 = 1;$$01365$in = $1013;$$01366 = $1011;$$01367 = $1012;$$01370$in = $1005;
   }
   $$01365 = $$01365$in << 1;
   $1017 = ($3|0)<($1|0);
   $1018 = (0 - ($$01361))|0;
   $$$01361 = $1017 ? $1018 : $$01361;
   $$1478 = $1017 ? -1 : 1;
   $1019 = ($4|0)<($2|0);
   $1020 = (0 - ($$01355))|0;
   $$11356 = $1019 ? $1020 : $$01355;
   $$11354 = $1019 ? -1 : 1;
   $not$ = ($10|0)!=(0);
   $$01370 = $not$&1;
   $$01370$in$$01370 = (($$01370$in) + ($$01370))|0;
   $1021 = ($$01370$in$$01370|0)>(0);
   if (!($1021)) {
    return;
   }
   $1022 = ((($0)) + 20|0);
   $1023 = ((($0)) + 16|0);
   $1024 = ((($12)) + 28|0);
   $1025 = ((($12)) + 12|0);
   $1026 = ((($12)) + 32|0);
   $1027 = ((($12)) + 29|0);
   $1028 = ((($12)) + 16|0);
   $1029 = ((($12)) + 33|0);
   $1030 = ((($12)) + 30|0);
   $1031 = ((($12)) + 20|0);
   $1032 = ((($12)) + 34|0);
   $1033 = ((($12)) + 24|0);
   $$pre = HEAP32[$1022>>2]|0;
   $$pre1598 = HEAP32[$1023>>2]|0;
   $$pre1599 = HEAP8[$1024>>0]|0;
   $$phi$trans$insert = $$pre1599&255;
   $$phi$trans$insert1600 = (79212 + ($$phi$trans$insert<<2)|0);
   $$pre1601 = HEAP32[$$phi$trans$insert1600>>2]|0;
   $$pre1602 = HEAP32[$1025>>2]|0;
   $$pre1603 = HEAP8[$1026>>0]|0;
   $$pre1604 = HEAP8[$1027>>0]|0;
   $$phi$trans$insert1605 = $$pre1604&255;
   $$phi$trans$insert1606 = (79212 + ($$phi$trans$insert1605<<2)|0);
   $$pre1607 = HEAP32[$$phi$trans$insert1606>>2]|0;
   $$pre1608 = HEAP32[$1028>>2]|0;
   $$pre1609 = HEAP8[$1029>>0]|0;
   $$pre1610 = HEAP8[$1030>>0]|0;
   $$phi$trans$insert1611 = $$pre1610&255;
   $$phi$trans$insert1612 = (79212 + ($$phi$trans$insert1611<<2)|0);
   $$pre1613 = HEAP32[$$phi$trans$insert1612>>2]|0;
   $$pre1614 = HEAP32[$1031>>2]|0;
   $$pre1615 = HEAP8[$1032>>0]|0;
   $$pre1616 = HEAP32[$1033>>2]|0;
   $1034 = $$pre1603&255;
   $1035 = $$pre1609&255;
   $1036 = $$pre1615&255;
   $$013571565 = $2;$$013631564 = $1;$$013751562 = 0;$$113681563 = $$01367;
   while(1) {
    $1037 = Math_imul($$pre1598, $$013571565)|0;
    $1038 = (($$pre) + ($1037)|0);
    $1039 = $$013631564 << 1;
    $1040 = (($1038) + ($1039)|0);
    $1041 = HEAP16[$1040>>1]|0;
    $1042 = $1041&65535;
    $1043 = $1042 & $$pre1602;
    $1044 = $1043 >>> $1034;
    $1045 = (($$pre1601) + ($1044)|0);
    $1046 = HEAP8[$1045>>0]|0;
    $1047 = $1046&255;
    $1048 = $$pre1608 & $1042;
    $1049 = $1048 >>> $1035;
    $1050 = (($$pre1607) + ($1049)|0);
    $1051 = HEAP8[$1050>>0]|0;
    $1052 = $1051&255;
    $1053 = $$pre1614 & $1042;
    $1054 = $1053 >>> $1036;
    $1055 = (($$pre1613) + ($1054)|0);
    $1056 = HEAP8[$1055>>0]|0;
    $1057 = $1056&255;
    $1058 = Math_imul($1047, $$0)|0;
    $1059 = (($1058>>>0) / 255)&-1;
    $1060 = Math_imul($1052, $$01319)|0;
    $1061 = (($1060>>>0) / 255)&-1;
    $1062 = Math_imul($1057, $$01320)|0;
    $1063 = (($1062>>>0) / 255)&-1;
    $1064 = $1059 >>> $$phi$trans$insert;
    $1065 = $1064 << $1034;
    $1066 = $1061 >>> $$phi$trans$insert1605;
    $1067 = $1066 << $1035;
    $1068 = $1067 | $1065;
    $1069 = $1063 >>> $$phi$trans$insert1611;
    $1070 = $1069 << $1036;
    $1071 = $1068 | $$pre1616;
    $1072 = $1071 | $1070;
    $1073 = $1072&65535;
    HEAP16[$1040>>1] = $1073;
    $1074 = ($$113681563|0)<(0);
    $$01366$$01365 = $1074 ? $$01366 : $$01365;
    $$$01361$$1478 = $1074 ? $$$01361 : $$1478;
    $$11356$$11354 = $1074 ? $$11356 : $$11354;
    $$11358 = (($$013571565) + ($$11356$$11354))|0;
    $$11364 = (($$$01361$$1478) + ($$013631564))|0;
    $$21369 = (($$01366$$01365) + ($$113681563))|0;
    $1075 = (($$013751562) + 1)|0;
    $1076 = ($1075|0)<($$01370$in$$01370|0);
    if ($1076) {
     $$013571565 = $$11358;$$013631564 = $$11364;$$013751562 = $1075;$$113681563 = $$21369;
    } else {
     break;
    }
   }
   return;
   break;
  }
  default: {
   $1077 = (($3) - ($1))|0;
   $1078 = ($1077|0)<(0);
   $1079 = (0 - ($1077))|0;
   $1080 = $1078 ? $1079 : $1077;
   $1081 = (($4) - ($2))|0;
   $1082 = ($1081|0)<(0);
   $1083 = (0 - ($1081))|0;
   $1084 = $1082 ? $1083 : $1081;
   $1085 = ($1080|0)<($1084|0);
   if ($1085) {
    $1089 = $1080 << 1;
    $1090 = (($1089) - ($1084))|0;
    $1091 = (($1080) - ($1084))|0;
    $$01324 = 1;$$01330 = 0;$$01334$in = $1091;$$01335 = $1089;$$01336 = $1090;$$01339$in = $1084;
   } else {
    $1086 = $1084 << 1;
    $1087 = (($1086) - ($1080))|0;
    $1088 = (($1084) - ($1080))|0;
    $$01324 = 0;$$01330 = 1;$$01334$in = $1088;$$01335 = $1086;$$01336 = $1087;$$01339$in = $1080;
   }
   $$01334 = $$01334$in << 1;
   $1092 = ($3|0)<($1|0);
   $1093 = (0 - ($$01330))|0;
   $$$01330 = $1092 ? $1093 : $$01330;
   $$1479 = $1092 ? -1 : 1;
   $1094 = ($4|0)<($2|0);
   $1095 = (0 - ($$01324))|0;
   $$11325 = $1094 ? $1095 : $$01324;
   $$1 = $1094 ? -1 : 1;
   $not$1482 = ($10|0)!=(0);
   $$01339 = $not$1482&1;
   $$01339$in$$01339 = (($$01339$in) + ($$01339))|0;
   $1096 = ($$01339$in$$01339|0)>(0);
   if (!($1096)) {
    return;
   }
   $1097 = ((($0)) + 20|0);
   $1098 = HEAP32[$1097>>2]|0;
   $1099 = ((($0)) + 16|0);
   $1100 = HEAP32[$1099>>2]|0;
   $1101 = ((($12)) + 28|0);
   $1102 = HEAP8[$1101>>0]|0;
   $1103 = $1102&255;
   $1104 = $$0 >>> $1103;
   $1105 = ((($12)) + 32|0);
   $1106 = HEAP8[$1105>>0]|0;
   $1107 = $1106&255;
   $1108 = $1104 << $1107;
   $1109 = ((($12)) + 29|0);
   $1110 = HEAP8[$1109>>0]|0;
   $1111 = $1110&255;
   $1112 = $$01319 >>> $1111;
   $1113 = ((($12)) + 33|0);
   $1114 = HEAP8[$1113>>0]|0;
   $1115 = $1114&255;
   $1116 = $1112 << $1115;
   $1117 = $1116 | $1108;
   $1118 = ((($12)) + 30|0);
   $1119 = HEAP8[$1118>>0]|0;
   $1120 = $1119&255;
   $1121 = $$01320 >>> $1120;
   $1122 = ((($12)) + 34|0);
   $1123 = HEAP8[$1122>>0]|0;
   $1124 = $1123&255;
   $1125 = $1121 << $1124;
   $1126 = ((($12)) + 24|0);
   $1127 = HEAP32[$1126>>2]|0;
   $1128 = $1117 | $1127;
   $1129 = $1128 | $1125;
   $1130 = $1129&65535;
   $$013261550 = $2;$$013321549 = $1;$$013441547 = 0;$$113371548 = $$01336;
   while(1) {
    $1131 = Math_imul($1100, $$013261550)|0;
    $1132 = (($1098) + ($1131)|0);
    $1133 = $$013321549 << 1;
    $1134 = (($1132) + ($1133)|0);
    HEAP16[$1134>>1] = $1130;
    $1135 = ($$113371548|0)<(0);
    $$01335$$01334 = $1135 ? $$01335 : $$01334;
    $$$01330$$1479 = $1135 ? $$$01330 : $$1479;
    $$11325$$1 = $1135 ? $$11325 : $$1;
    $$11327 = (($$013261550) + ($$11325$$1))|0;
    $$11333 = (($$$01330$$1479) + ($$013321549))|0;
    $$21338 = (($$01335$$01334) + ($$113371548))|0;
    $1136 = (($$013441547) + 1)|0;
    $1137 = ($1136|0)<($$01339$in$$01339|0);
    if ($1137) {
     $$013261550 = $$11327;$$013321549 = $$11333;$$013441547 = $1136;$$113371548 = $$21338;
    } else {
     break;
    }
   }
   return;
  }
  }
 }
}
function _SDL_BlendLine_RGB555($0,$1,$2,$3,$4,$5,$6,$7,$8,$9,$10) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 $8 = $8|0;
 $9 = $9|0;
 $10 = $10|0;
 var $$ = 0, $$$01107 = 0, $$$01107$$1256 = 0, $$$01138 = 0, $$$01138$$1255 = 0, $$$01168 = 0, $$$01168$$1254 = 0, $$$01206 = 0, $$$01206$$1253 = 0, $$0 = 0, $$01096 = 0, $$01097 = 0, $$010991292 = 0, $$01101 = 0, $$011031327 = 0, $$01107 = 0, $$011091326 = 0, $$01111 = 0, $$01111$in = 0, $$01112 = 0;
 var $$01112$$01111 = 0, $$01113 = 0, $$01116 = 0, $$01116$in = 0, $$01116$in$$01116 = 0, $$011201295 = 0, $$011211324 = 0, $$011241298 = 0, $$011271290 = 0, $$01132 = 0, $$011341342 = 0, $$01138 = 0, $$011401341 = 0, $$01142 = 0, $$01142$in = 0, $$01143 = 0, $$01143$$01142 = 0, $$01144 = 0, $$01147 = 0, $$01147$in = 0;
 var $$01147$in$$01147 = 0, $$011491304 = 0, $$011521339 = 0, $$011531307 = 0, $$011561310 = 0, $$011591301 = 0, $$01162 = 0, $$011641337 = 0, $$01168 = 0, $$011701336 = 0, $$01172 = 0, $$01172$in = 0, $$01173 = 0, $$01173$$01172 = 0, $$01174 = 0, $$01177 = 0, $$01177$in = 0, $$01177$in$$01177 = 0, $$01181 = 0, $$01181$ = 0;
 var $$011831334 = 0, $$01190 = 0, $$01190$ = 0, $$01200 = 0, $$012021332 = 0, $$01206 = 0, $$012081331 = 0, $$01210 = 0, $$01210$in = 0, $$01211 = 0, $$01211$$01210 = 0, $$01212 = 0, $$01215 = 0, $$01215$in = 0, $$01215$in$$01215 = 0, $$01217 = 0, $$01217$ = 0, $$012221329 = 0, $$01226 = 0, $$01226$ = 0;
 var $$1 = 0, $$10 = 0, $$11 = 0, $$11102 = 0, $$11102$$1 = 0, $$11104 = 0, $$11110 = 0, $$111141325 = 0, $$11119$ph = 0, $$111191291 = 0, $$11123$ph = 0, $$111231294 = 0, $$11126$ph = 0, $$111261297 = 0, $$11129$ph = 0, $$111291289 = 0, $$11131 = 0, $$11133 = 0, $$11133$$11131 = 0, $$11135 = 0;
 var $$11141 = 0, $$111451340 = 0, $$11151$ph = 0, $$111511303 = 0, $$11155$ph = 0, $$111551306 = 0, $$11158$ph = 0, $$111581309 = 0, $$11161 = 0, $$11163 = 0, $$11163$$11161 = 0, $$11165 = 0, $$11171 = 0, $$111751335 = 0, $$11180$ph = 0, $$111801300 = 0, $$111821316 = 0, $$11188 = 0, $$111911319 = 0, $$11196 = 0;
 var $$11199 = 0, $$11201 = 0, $$11201$$11199 = 0, $$11203 = 0, $$11209 = 0, $$112131330 = 0, $$112181322 = 0, $$11224 = 0, $$112271313 = 0, $$11232 = 0, $$12 = 0, $$1234 = 0, $$1235 = 0, $$1236 = 0, $$1237 = 0, $$1238 = 0, $$1239 = 0, $$1240 = 0, $$1241 = 0, $$1243 = 0;
 var $$1246 = 0, $$1249 = 0, $$1252 = 0, $$1253 = 0, $$1254 = 0, $$1255 = 0, $$1256 = 0, $$2 = 0, $$21115 = 0, $$21146 = 0, $$21176 = 0, $$21186 = 0, $$211891315 = 0, $$21194 = 0, $$211971318 = 0, $$21214 = 0, $$21221 = 0, $$212251321 = 0, $$21230 = 0, $$212331312 = 0;
 var $$3 = 0, $$4 = 0, $$5 = 0, $$6 = 0, $$7 = 0, $$8 = 0, $$9 = 0, $$off = 0, $$pre = 0, $$pre1375 = 0, $$pre1376 = 0, $$pre1377 = 0, $$pre1378 = 0, $$pre1379 = 0, $$pre1380 = 0, $$pre1381 = 0, $$pre1382 = 0, $$pre1383 = 0, $$pre1384 = 0, $$pre1385 = 0;
 var $$pre1386 = 0, $$pre1387 = 0, $$pre1388 = 0, $$pre1389 = 0, $$pre1390 = 0, $$pre1391 = 0, $$sink = 0, $$sink1242 = 0, $$sink1244 = 0, $$sink1245 = 0, $$sink1247 = 0, $$sink1248 = 0, $$sink1250 = 0, $$sink1251 = 0, $$sink1344 = 0, $$sink1346 = 0, $$sink1348 = 0, $$sink1350 = 0, $$sink1352 = 0, $$sink1354 = 0;
 var $$sink1356 = 0, $$sink1358 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0;
 var $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0;
 var $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0;
 var $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0;
 var $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0;
 var $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0;
 var $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0;
 var $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0;
 var $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0;
 var $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0;
 var $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0;
 var $299 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0;
 var $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0;
 var $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0;
 var $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0;
 var $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0;
 var $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0;
 var $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0;
 var $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0;
 var $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0;
 var $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0;
 var $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0;
 var $499 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0;
 var $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0;
 var $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0;
 var $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0;
 var $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0;
 var $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0;
 var $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0;
 var $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0;
 var $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0;
 var $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0;
 var $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0;
 var $699 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0;
 var $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0;
 var $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0;
 var $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0;
 var $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0;
 var $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0;
 var $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = 0, $825 = 0;
 var $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = 0, $834 = 0, $835 = 0, $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = 0, $841 = 0, $842 = 0, $843 = 0;
 var $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0, $850 = 0, $851 = 0, $852 = 0, $853 = 0, $854 = 0, $855 = 0, $856 = 0, $857 = 0, $858 = 0, $859 = 0, $86 = 0, $860 = 0, $861 = 0;
 var $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0, $869 = 0, $87 = 0, $870 = 0, $871 = 0, $872 = 0, $873 = 0, $874 = 0, $875 = 0, $876 = 0, $877 = 0, $878 = 0, $879 = 0, $88 = 0;
 var $89 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $not$ = 0, $not$1257 = 0, $not$1258 = 0, $not$1259 = 0, $not$1260 = 0, $not$1261 = 0, $not$1262 = 0, $not$1263 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $$off = (($5) + -1)|0;
 $11 = ($$off>>>0)<(2);
 $12 = $6&255;
 $13 = $7&255;
 $14 = $9&255;
 $15 = $8&255;
 if ($11) {
  $16 = Math_imul($14, $15)|0;
  $17 = Math_imul($14, $13)|0;
  $18 = Math_imul($14, $12)|0;
  $19 = (($18>>>0) / 255)&-1;
  $20 = (($17>>>0) / 255)&-1;
  $21 = (($16>>>0) / 255)&-1;
  $$0 = $19;$$01096 = $20;$$01097 = $21;
 } else {
  $$0 = $12;$$01096 = $13;$$01097 = $15;
 }
 $22 = $14 ^ 255;
 $23 = ($4|0)==($2|0);
 if ($23) {
  switch ($5|0) {
  case 1:  {
   $24 = ((($0)) + 16|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = ((($0)) + 4|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = ((($27)) + 9|0);
   $29 = HEAP8[$28>>0]|0;
   $30 = $29&255;
   $31 = (($25|0) / ($30|0))&-1;
   $32 = ($3|0)<($1|0);
   $33 = ((($0)) + 20|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = Math_imul($31, $4)|0;
   $36 = (($34) + ($35<<1)|0);
   $37 = ($10|0)!=(0);
   if ($32) {
    $40 = (($36) + ($3<<1)|0);
    $41 = ((($40)) + 2|0);
    $$1234 = $37 ? $40 : $41;
    $42 = (($1) - ($3))|0;
    $$11119$ph = $$1234;$$sink1344 = $42;
   } else {
    $38 = (($36) + ($1<<1)|0);
    $39 = (($3) - ($1))|0;
    $$11119$ph = $38;$$sink1344 = $39;
   }
   $43 = $37&1;
   $44 = (($$sink1344) + ($43))|0;
   $45 = ($44|0)==(0);
   if ($45) {
    return;
   }
   $$pre1391 = HEAP32[(79224)>>2]|0;
   $$010991292 = $44;$$111191291 = $$11119$ph;
   while(1) {
    $46 = (($$010991292) + -1)|0;
    $47 = HEAP16[$$111191291>>1]|0;
    $48 = $47&65535;
    $49 = $48 >>> 10;
    $50 = $49 & 31;
    $51 = (($$pre1391) + ($50)|0);
    $52 = HEAP8[$51>>0]|0;
    $53 = $52&255;
    $54 = $48 >>> 5;
    $55 = $54 & 31;
    $56 = (($$pre1391) + ($55)|0);
    $57 = HEAP8[$56>>0]|0;
    $58 = $57&255;
    $59 = $48 & 31;
    $60 = (($$pre1391) + ($59)|0);
    $61 = HEAP8[$60>>0]|0;
    $62 = $61&255;
    $63 = Math_imul($53, $22)|0;
    $64 = (($63>>>0) / 255)&-1;
    $65 = (($64) + ($$0))|0;
    $66 = Math_imul($58, $22)|0;
    $67 = (($66>>>0) / 255)&-1;
    $68 = (($67) + ($$01096))|0;
    $69 = Math_imul($62, $22)|0;
    $70 = (($69>>>0) / 255)&-1;
    $71 = (($70) + ($$01097))|0;
    $72 = $65 >>> 3;
    $73 = $72 << 10;
    $74 = $68 >>> 3;
    $75 = $74 << 5;
    $76 = $75 | $73;
    $77 = $71 >>> 3;
    $78 = $76 | $77;
    $79 = $78&65535;
    HEAP16[$$111191291>>1] = $79;
    $80 = ((($$111191291)) + 2|0);
    $81 = ($46|0)==(0);
    if ($81) {
     break;
    } else {
     $$010991292 = $46;$$111191291 = $80;
    }
   }
   return;
   break;
  }
  case 2:  {
   $82 = ((($0)) + 16|0);
   $83 = HEAP32[$82>>2]|0;
   $84 = ((($0)) + 4|0);
   $85 = HEAP32[$84>>2]|0;
   $86 = ((($85)) + 9|0);
   $87 = HEAP8[$86>>0]|0;
   $88 = $87&255;
   $89 = (($83|0) / ($88|0))&-1;
   $90 = ($3|0)<($1|0);
   $91 = ((($0)) + 20|0);
   $92 = HEAP32[$91>>2]|0;
   $93 = Math_imul($89, $4)|0;
   $94 = (($92) + ($93<<1)|0);
   $95 = ($10|0)!=(0);
   if ($90) {
    $98 = (($94) + ($3<<1)|0);
    $99 = ((($98)) + 2|0);
    $$1235 = $95 ? $98 : $99;
    $100 = (($1) - ($3))|0;
    $$11123$ph = $$1235;$$sink1346 = $100;
   } else {
    $96 = (($94) + ($1<<1)|0);
    $97 = (($3) - ($1))|0;
    $$11123$ph = $96;$$sink1346 = $97;
   }
   $101 = $95&1;
   $102 = (($$sink1346) + ($101))|0;
   $103 = ($102|0)==(0);
   if ($103) {
    return;
   }
   $$pre1390 = HEAP32[(79224)>>2]|0;
   $$011201295 = $102;$$111231294 = $$11123$ph;
   while(1) {
    $104 = (($$011201295) + -1)|0;
    $105 = HEAP16[$$111231294>>1]|0;
    $106 = $105&65535;
    $107 = $106 >>> 10;
    $108 = $107 & 31;
    $109 = (($$pre1390) + ($108)|0);
    $110 = HEAP8[$109>>0]|0;
    $111 = $110&255;
    $112 = $106 >>> 5;
    $113 = $112 & 31;
    $114 = (($$pre1390) + ($113)|0);
    $115 = HEAP8[$114>>0]|0;
    $116 = $115&255;
    $117 = $106 & 31;
    $118 = (($$pre1390) + ($117)|0);
    $119 = HEAP8[$118>>0]|0;
    $120 = $119&255;
    $121 = (($111) + ($$0))|0;
    $122 = ($121>>>0)<(255);
    $$ = $122 ? $121 : 255;
    $123 = (($116) + ($$01096))|0;
    $124 = ($123>>>0)<(255);
    $$8 = $124 ? $123 : 255;
    $125 = (($120) + ($$01097))|0;
    $126 = ($125>>>0)<(255);
    $$2 = $126 ? $125 : 255;
    $127 = $$ >>> 3;
    $128 = $127 << 10;
    $129 = $$8 >>> 3;
    $130 = $129 << 5;
    $131 = $130 | $128;
    $132 = $$2 >>> 3;
    $133 = $131 | $132;
    $134 = $133&65535;
    HEAP16[$$111231294>>1] = $134;
    $135 = ((($$111231294)) + 2|0);
    $136 = ($104|0)==(0);
    if ($136) {
     break;
    } else {
     $$011201295 = $104;$$111231294 = $135;
    }
   }
   return;
   break;
  }
  case 4:  {
   $137 = ((($0)) + 16|0);
   $138 = HEAP32[$137>>2]|0;
   $139 = ((($0)) + 4|0);
   $140 = HEAP32[$139>>2]|0;
   $141 = ((($140)) + 9|0);
   $142 = HEAP8[$141>>0]|0;
   $143 = $142&255;
   $144 = (($138|0) / ($143|0))&-1;
   $145 = ($3|0)<($1|0);
   $146 = ((($0)) + 20|0);
   $147 = HEAP32[$146>>2]|0;
   $148 = Math_imul($144, $4)|0;
   $149 = (($147) + ($148<<1)|0);
   $150 = ($10|0)!=(0);
   if ($145) {
    $153 = (($149) + ($3<<1)|0);
    $154 = ((($153)) + 2|0);
    $$1236 = $150 ? $153 : $154;
    $155 = (($1) - ($3))|0;
    $$11126$ph = $$1236;$$sink1348 = $155;
   } else {
    $151 = (($149) + ($1<<1)|0);
    $152 = (($3) - ($1))|0;
    $$11126$ph = $151;$$sink1348 = $152;
   }
   $156 = $150&1;
   $157 = (($$sink1348) + ($156))|0;
   $158 = ($157|0)==(0);
   if ($158) {
    return;
   }
   $$pre1389 = HEAP32[(79224)>>2]|0;
   $$011241298 = $157;$$111261297 = $$11126$ph;
   while(1) {
    $159 = (($$011241298) + -1)|0;
    $160 = HEAP16[$$111261297>>1]|0;
    $161 = $160&65535;
    $162 = $161 >>> 10;
    $163 = $162 & 31;
    $164 = (($$pre1389) + ($163)|0);
    $165 = HEAP8[$164>>0]|0;
    $166 = $165&255;
    $167 = $161 >>> 5;
    $168 = $167 & 31;
    $169 = (($$pre1389) + ($168)|0);
    $170 = HEAP8[$169>>0]|0;
    $171 = $170&255;
    $172 = $161 & 31;
    $173 = (($$pre1389) + ($172)|0);
    $174 = HEAP8[$173>>0]|0;
    $175 = $174&255;
    $176 = Math_imul($166, $$0)|0;
    $177 = (($176>>>0) / 255)&-1;
    $178 = Math_imul($171, $$01096)|0;
    $179 = (($178>>>0) / 255)&-1;
    $180 = Math_imul($175, $$01097)|0;
    $181 = (($180>>>0) / 255)&-1;
    $182 = $177 >>> 3;
    $183 = $182 << 10;
    $184 = $179 >>> 3;
    $185 = $184 << 5;
    $186 = $185 | $183;
    $187 = $181 >>> 3;
    $188 = $186 | $187;
    $189 = $188&65535;
    HEAP16[$$111261297>>1] = $189;
    $190 = ((($$111261297)) + 2|0);
    $191 = ($159|0)==(0);
    if ($191) {
     break;
    } else {
     $$011241298 = $159;$$111261297 = $190;
    }
   }
   return;
   break;
  }
  default: {
   $192 = ((($0)) + 16|0);
   $193 = HEAP32[$192>>2]|0;
   $194 = ((($0)) + 4|0);
   $195 = HEAP32[$194>>2]|0;
   $196 = ((($195)) + 9|0);
   $197 = HEAP8[$196>>0]|0;
   $198 = $197&255;
   $199 = (($193|0) / ($198|0))&-1;
   $200 = ($3|0)<($1|0);
   $201 = ((($0)) + 20|0);
   $202 = HEAP32[$201>>2]|0;
   $203 = Math_imul($199, $4)|0;
   $204 = (($202) + ($203<<1)|0);
   $205 = ($10|0)!=(0);
   if ($200) {
    $208 = (($204) + ($3<<1)|0);
    $209 = ((($208)) + 2|0);
    $$1237 = $205 ? $208 : $209;
    $210 = (($1) - ($3))|0;
    $$11129$ph = $$1237;$$sink1350 = $210;
   } else {
    $206 = (($204) + ($1<<1)|0);
    $207 = (($3) - ($1))|0;
    $$11129$ph = $206;$$sink1350 = $207;
   }
   $211 = $205&1;
   $212 = (($$sink1350) + ($211))|0;
   $213 = ($212|0)==(0);
   if ($213) {
    return;
   }
   $214 = $$0 >>> 3;
   $215 = $214 << 10;
   $216 = $$01096 >>> 3;
   $217 = $216 << 5;
   $218 = $$01097 >>> 3;
   $219 = $217 | $218;
   $220 = $219 | $215;
   $221 = $220&65535;
   $$011271290 = $212;$$111291289 = $$11129$ph;
   while(1) {
    $222 = (($$011271290) + -1)|0;
    HEAP16[$$111291289>>1] = $221;
    $223 = ((($$111291289)) + 2|0);
    $224 = ($222|0)==(0);
    if ($224) {
     break;
    } else {
     $$011271290 = $222;$$111291289 = $223;
    }
   }
   return;
  }
  }
 }
 $225 = ($3|0)==($1|0);
 if ($225) {
  switch ($5|0) {
  case 1:  {
   $226 = ((($0)) + 16|0);
   $227 = HEAP32[$226>>2]|0;
   $228 = ((($0)) + 4|0);
   $229 = HEAP32[$228>>2]|0;
   $230 = ((($229)) + 9|0);
   $231 = HEAP8[$230>>0]|0;
   $232 = $231&255;
   $233 = (($227|0) / ($232|0))&-1;
   $234 = ($4|0)<($2|0);
   $235 = ((($0)) + 20|0);
   $236 = HEAP32[$235>>2]|0;
   $237 = ($10|0)!=(0);
   if ($234) {
    $242 = Math_imul($233, $4)|0;
    $243 = (($236) + ($242<<1)|0);
    $244 = (($243) + ($3<<1)|0);
    $245 = (($244) + ($233<<1)|0);
    $$1238 = $237 ? $244 : $245;
    $246 = (($2) - ($4))|0;
    $$11151$ph = $$1238;$$sink1352 = $246;
   } else {
    $238 = Math_imul($233, $2)|0;
    $239 = (($236) + ($238<<1)|0);
    $240 = (($239) + ($3<<1)|0);
    $241 = (($4) - ($2))|0;
    $$11151$ph = $240;$$sink1352 = $241;
   }
   $247 = $237&1;
   $248 = (($$sink1352) + ($247))|0;
   $249 = ($248|0)==(0);
   if ($249) {
    return;
   }
   $$pre1388 = HEAP32[(79224)>>2]|0;
   $$011491304 = $248;$$111511303 = $$11151$ph;
   while(1) {
    $250 = (($$011491304) + -1)|0;
    $251 = HEAP16[$$111511303>>1]|0;
    $252 = $251&65535;
    $253 = $252 >>> 10;
    $254 = $253 & 31;
    $255 = (($$pre1388) + ($254)|0);
    $256 = HEAP8[$255>>0]|0;
    $257 = $256&255;
    $258 = $252 >>> 5;
    $259 = $258 & 31;
    $260 = (($$pre1388) + ($259)|0);
    $261 = HEAP8[$260>>0]|0;
    $262 = $261&255;
    $263 = $252 & 31;
    $264 = (($$pre1388) + ($263)|0);
    $265 = HEAP8[$264>>0]|0;
    $266 = $265&255;
    $267 = Math_imul($257, $22)|0;
    $268 = (($267>>>0) / 255)&-1;
    $269 = (($268) + ($$0))|0;
    $270 = Math_imul($262, $22)|0;
    $271 = (($270>>>0) / 255)&-1;
    $272 = (($271) + ($$01096))|0;
    $273 = Math_imul($266, $22)|0;
    $274 = (($273>>>0) / 255)&-1;
    $275 = (($274) + ($$01097))|0;
    $276 = $269 >>> 3;
    $277 = $276 << 10;
    $278 = $272 >>> 3;
    $279 = $278 << 5;
    $280 = $279 | $277;
    $281 = $275 >>> 3;
    $282 = $280 | $281;
    $283 = $282&65535;
    HEAP16[$$111511303>>1] = $283;
    $284 = (($$111511303) + ($233<<1)|0);
    $285 = ($250|0)==(0);
    if ($285) {
     break;
    } else {
     $$011491304 = $250;$$111511303 = $284;
    }
   }
   return;
   break;
  }
  case 2:  {
   $286 = ((($0)) + 16|0);
   $287 = HEAP32[$286>>2]|0;
   $288 = ((($0)) + 4|0);
   $289 = HEAP32[$288>>2]|0;
   $290 = ((($289)) + 9|0);
   $291 = HEAP8[$290>>0]|0;
   $292 = $291&255;
   $293 = (($287|0) / ($292|0))&-1;
   $294 = ($4|0)<($2|0);
   $295 = ((($0)) + 20|0);
   $296 = HEAP32[$295>>2]|0;
   $297 = ($10|0)!=(0);
   if ($294) {
    $302 = Math_imul($293, $4)|0;
    $303 = (($296) + ($302<<1)|0);
    $304 = (($303) + ($3<<1)|0);
    $305 = (($304) + ($293<<1)|0);
    $$1239 = $297 ? $304 : $305;
    $306 = (($2) - ($4))|0;
    $$11155$ph = $$1239;$$sink1354 = $306;
   } else {
    $298 = Math_imul($293, $2)|0;
    $299 = (($296) + ($298<<1)|0);
    $300 = (($299) + ($3<<1)|0);
    $301 = (($4) - ($2))|0;
    $$11155$ph = $300;$$sink1354 = $301;
   }
   $307 = $297&1;
   $308 = (($$sink1354) + ($307))|0;
   $309 = ($308|0)==(0);
   if ($309) {
    return;
   }
   $$pre1387 = HEAP32[(79224)>>2]|0;
   $$011531307 = $308;$$111551306 = $$11155$ph;
   while(1) {
    $310 = (($$011531307) + -1)|0;
    $311 = HEAP16[$$111551306>>1]|0;
    $312 = $311&65535;
    $313 = $312 >>> 10;
    $314 = $313 & 31;
    $315 = (($$pre1387) + ($314)|0);
    $316 = HEAP8[$315>>0]|0;
    $317 = $316&255;
    $318 = $312 >>> 5;
    $319 = $318 & 31;
    $320 = (($$pre1387) + ($319)|0);
    $321 = HEAP8[$320>>0]|0;
    $322 = $321&255;
    $323 = $312 & 31;
    $324 = (($$pre1387) + ($323)|0);
    $325 = HEAP8[$324>>0]|0;
    $326 = $325&255;
    $327 = (($317) + ($$0))|0;
    $328 = ($327>>>0)<(255);
    $$3 = $328 ? $327 : 255;
    $329 = (($322) + ($$01096))|0;
    $330 = ($329>>>0)<(255);
    $$9 = $330 ? $329 : 255;
    $331 = (($326) + ($$01097))|0;
    $332 = ($331>>>0)<(255);
    $$4 = $332 ? $331 : 255;
    $333 = $$3 >>> 3;
    $334 = $333 << 10;
    $335 = $$9 >>> 3;
    $336 = $335 << 5;
    $337 = $336 | $334;
    $338 = $$4 >>> 3;
    $339 = $337 | $338;
    $340 = $339&65535;
    HEAP16[$$111551306>>1] = $340;
    $341 = (($$111551306) + ($293<<1)|0);
    $342 = ($310|0)==(0);
    if ($342) {
     break;
    } else {
     $$011531307 = $310;$$111551306 = $341;
    }
   }
   return;
   break;
  }
  case 4:  {
   $343 = ((($0)) + 16|0);
   $344 = HEAP32[$343>>2]|0;
   $345 = ((($0)) + 4|0);
   $346 = HEAP32[$345>>2]|0;
   $347 = ((($346)) + 9|0);
   $348 = HEAP8[$347>>0]|0;
   $349 = $348&255;
   $350 = (($344|0) / ($349|0))&-1;
   $351 = ($4|0)<($2|0);
   $352 = ((($0)) + 20|0);
   $353 = HEAP32[$352>>2]|0;
   $354 = ($10|0)!=(0);
   if ($351) {
    $359 = Math_imul($350, $4)|0;
    $360 = (($353) + ($359<<1)|0);
    $361 = (($360) + ($3<<1)|0);
    $362 = (($361) + ($350<<1)|0);
    $$1240 = $354 ? $361 : $362;
    $363 = (($2) - ($4))|0;
    $$11158$ph = $$1240;$$sink1356 = $363;
   } else {
    $355 = Math_imul($350, $2)|0;
    $356 = (($353) + ($355<<1)|0);
    $357 = (($356) + ($3<<1)|0);
    $358 = (($4) - ($2))|0;
    $$11158$ph = $357;$$sink1356 = $358;
   }
   $364 = $354&1;
   $365 = (($$sink1356) + ($364))|0;
   $366 = ($365|0)==(0);
   if ($366) {
    return;
   }
   $$pre1386 = HEAP32[(79224)>>2]|0;
   $$011561310 = $365;$$111581309 = $$11158$ph;
   while(1) {
    $367 = (($$011561310) + -1)|0;
    $368 = HEAP16[$$111581309>>1]|0;
    $369 = $368&65535;
    $370 = $369 >>> 10;
    $371 = $370 & 31;
    $372 = (($$pre1386) + ($371)|0);
    $373 = HEAP8[$372>>0]|0;
    $374 = $373&255;
    $375 = $369 >>> 5;
    $376 = $375 & 31;
    $377 = (($$pre1386) + ($376)|0);
    $378 = HEAP8[$377>>0]|0;
    $379 = $378&255;
    $380 = $369 & 31;
    $381 = (($$pre1386) + ($380)|0);
    $382 = HEAP8[$381>>0]|0;
    $383 = $382&255;
    $384 = Math_imul($374, $$0)|0;
    $385 = (($384>>>0) / 255)&-1;
    $386 = Math_imul($379, $$01096)|0;
    $387 = (($386>>>0) / 255)&-1;
    $388 = Math_imul($383, $$01097)|0;
    $389 = (($388>>>0) / 255)&-1;
    $390 = $385 >>> 3;
    $391 = $390 << 10;
    $392 = $387 >>> 3;
    $393 = $392 << 5;
    $394 = $393 | $391;
    $395 = $389 >>> 3;
    $396 = $394 | $395;
    $397 = $396&65535;
    HEAP16[$$111581309>>1] = $397;
    $398 = (($$111581309) + ($350<<1)|0);
    $399 = ($367|0)==(0);
    if ($399) {
     break;
    } else {
     $$011561310 = $367;$$111581309 = $398;
    }
   }
   return;
   break;
  }
  default: {
   $400 = ((($0)) + 16|0);
   $401 = HEAP32[$400>>2]|0;
   $402 = ((($0)) + 4|0);
   $403 = HEAP32[$402>>2]|0;
   $404 = ((($403)) + 9|0);
   $405 = HEAP8[$404>>0]|0;
   $406 = $405&255;
   $407 = (($401|0) / ($406|0))&-1;
   $408 = ($4|0)<($2|0);
   $409 = ((($0)) + 20|0);
   $410 = HEAP32[$409>>2]|0;
   $411 = ($10|0)!=(0);
   if ($408) {
    $416 = Math_imul($407, $4)|0;
    $417 = (($410) + ($416<<1)|0);
    $418 = (($417) + ($3<<1)|0);
    $419 = (($418) + ($407<<1)|0);
    $$1241 = $411 ? $418 : $419;
    $420 = (($2) - ($4))|0;
    $$11180$ph = $$1241;$$sink1358 = $420;
   } else {
    $412 = Math_imul($407, $2)|0;
    $413 = (($410) + ($412<<1)|0);
    $414 = (($413) + ($3<<1)|0);
    $415 = (($4) - ($2))|0;
    $$11180$ph = $414;$$sink1358 = $415;
   }
   $421 = $411&1;
   $422 = (($$sink1358) + ($421))|0;
   $423 = ($422|0)==(0);
   if ($423) {
    return;
   }
   $424 = $$0 >>> 3;
   $425 = $424 << 10;
   $426 = $$01096 >>> 3;
   $427 = $426 << 5;
   $428 = $$01097 >>> 3;
   $429 = $427 | $428;
   $430 = $429 | $425;
   $431 = $430&65535;
   $$011591301 = $422;$$111801300 = $$11180$ph;
   while(1) {
    $432 = (($$011591301) + -1)|0;
    HEAP16[$$111801300>>1] = $431;
    $433 = (($$111801300) + ($407<<1)|0);
    $434 = ($432|0)==(0);
    if ($434) {
     break;
    } else {
     $$011591301 = $432;$$111801300 = $433;
    }
   }
   return;
  }
  }
 }
 $435 = (($1) - ($3))|0;
 $436 = ($435|0)<(0);
 $437 = (0 - ($435))|0;
 $438 = $436 ? $437 : $435;
 $439 = (($2) - ($4))|0;
 $440 = ($439|0)<(0);
 $441 = (0 - ($439))|0;
 $442 = $440 ? $441 : $439;
 $443 = ($438|0)==($442|0);
 if ($443) {
  switch ($5|0) {
  case 1:  {
   $444 = ((($0)) + 16|0);
   $445 = HEAP32[$444>>2]|0;
   $446 = ((($0)) + 4|0);
   $447 = HEAP32[$446>>2]|0;
   $448 = ((($447)) + 9|0);
   $449 = HEAP8[$448>>0]|0;
   $450 = $449&255;
   $451 = (($445|0) / ($450|0))&-1;
   $452 = ($4|0)<($2|0);
   $453 = ((($0)) + 20|0);
   $454 = HEAP32[$453>>2]|0;
   if ($452) {
    $461 = Math_imul($451, $4)|0;
    $462 = (($454) + ($461<<1)|0);
    $463 = (($462) + ($3<<1)|0);
    $464 = ($3|0)>($1|0);
    $$sink1242 = $464 ? -1 : 1;
    $465 = (($451) + ($$sink1242))|0;
    $466 = ($10|0)==(0);
    $467 = (($463) + ($465<<1)|0);
    $$1243 = $466 ? $467 : $463;
    $$01181 = $439;$$11188 = $$1243;$$21186 = $465;
   } else {
    $455 = Math_imul($451, $2)|0;
    $456 = (($454) + ($455<<1)|0);
    $457 = (($456) + ($1<<1)|0);
    $458 = ($3|0)<($1|0);
    $$sink = $458 ? -1 : 1;
    $459 = (($451) + ($$sink))|0;
    $460 = (($4) - ($2))|0;
    $$01181 = $460;$$11188 = $457;$$21186 = $459;
   }
   $not$1262 = ($10|0)!=(0);
   $468 = $not$1262&1;
   $$01181$ = (($$01181) + ($468))|0;
   $469 = ($$01181$|0)==(0);
   if ($469) {
    return;
   }
   $$pre1385 = HEAP32[(79224)>>2]|0;
   $$111821316 = $$01181$;$$211891315 = $$11188;
   while(1) {
    $470 = (($$111821316) + -1)|0;
    $471 = HEAP16[$$211891315>>1]|0;
    $472 = $471&65535;
    $473 = $472 >>> 10;
    $474 = $473 & 31;
    $475 = (($$pre1385) + ($474)|0);
    $476 = HEAP8[$475>>0]|0;
    $477 = $476&255;
    $478 = $472 >>> 5;
    $479 = $478 & 31;
    $480 = (($$pre1385) + ($479)|0);
    $481 = HEAP8[$480>>0]|0;
    $482 = $481&255;
    $483 = $472 & 31;
    $484 = (($$pre1385) + ($483)|0);
    $485 = HEAP8[$484>>0]|0;
    $486 = $485&255;
    $487 = Math_imul($477, $22)|0;
    $488 = (($487>>>0) / 255)&-1;
    $489 = (($488) + ($$0))|0;
    $490 = Math_imul($482, $22)|0;
    $491 = (($490>>>0) / 255)&-1;
    $492 = (($491) + ($$01096))|0;
    $493 = Math_imul($486, $22)|0;
    $494 = (($493>>>0) / 255)&-1;
    $495 = (($494) + ($$01097))|0;
    $496 = $489 >>> 3;
    $497 = $496 << 10;
    $498 = $492 >>> 3;
    $499 = $498 << 5;
    $500 = $499 | $497;
    $501 = $495 >>> 3;
    $502 = $500 | $501;
    $503 = $502&65535;
    HEAP16[$$211891315>>1] = $503;
    $504 = (($$211891315) + ($$21186<<1)|0);
    $505 = ($470|0)==(0);
    if ($505) {
     break;
    } else {
     $$111821316 = $470;$$211891315 = $504;
    }
   }
   return;
   break;
  }
  case 2:  {
   $506 = ((($0)) + 16|0);
   $507 = HEAP32[$506>>2]|0;
   $508 = ((($0)) + 4|0);
   $509 = HEAP32[$508>>2]|0;
   $510 = ((($509)) + 9|0);
   $511 = HEAP8[$510>>0]|0;
   $512 = $511&255;
   $513 = (($507|0) / ($512|0))&-1;
   $514 = ($4|0)<($2|0);
   $515 = ((($0)) + 20|0);
   $516 = HEAP32[$515>>2]|0;
   if ($514) {
    $523 = Math_imul($513, $4)|0;
    $524 = (($516) + ($523<<1)|0);
    $525 = (($524) + ($3<<1)|0);
    $526 = ($3|0)>($1|0);
    $$sink1245 = $526 ? -1 : 1;
    $527 = (($513) + ($$sink1245))|0;
    $528 = ($10|0)==(0);
    $529 = (($525) + ($527<<1)|0);
    $$1246 = $528 ? $529 : $525;
    $$01190 = $439;$$11196 = $$1246;$$21194 = $527;
   } else {
    $517 = Math_imul($513, $2)|0;
    $518 = (($516) + ($517<<1)|0);
    $519 = (($518) + ($1<<1)|0);
    $520 = ($3|0)<($1|0);
    $$sink1244 = $520 ? -1 : 1;
    $521 = (($513) + ($$sink1244))|0;
    $522 = (($4) - ($2))|0;
    $$01190 = $522;$$11196 = $519;$$21194 = $521;
   }
   $not$1261 = ($10|0)!=(0);
   $530 = $not$1261&1;
   $$01190$ = (($$01190) + ($530))|0;
   $531 = ($$01190$|0)==(0);
   if ($531) {
    return;
   }
   $$pre1384 = HEAP32[(79224)>>2]|0;
   $$111911319 = $$01190$;$$211971318 = $$11196;
   while(1) {
    $532 = (($$111911319) + -1)|0;
    $533 = HEAP16[$$211971318>>1]|0;
    $534 = $533&65535;
    $535 = $534 >>> 10;
    $536 = $535 & 31;
    $537 = (($$pre1384) + ($536)|0);
    $538 = HEAP8[$537>>0]|0;
    $539 = $538&255;
    $540 = $534 >>> 5;
    $541 = $540 & 31;
    $542 = (($$pre1384) + ($541)|0);
    $543 = HEAP8[$542>>0]|0;
    $544 = $543&255;
    $545 = $534 & 31;
    $546 = (($$pre1384) + ($545)|0);
    $547 = HEAP8[$546>>0]|0;
    $548 = $547&255;
    $549 = (($539) + ($$0))|0;
    $550 = ($549>>>0)<(255);
    $$5 = $550 ? $549 : 255;
    $551 = (($544) + ($$01096))|0;
    $552 = ($551>>>0)<(255);
    $$10 = $552 ? $551 : 255;
    $553 = (($548) + ($$01097))|0;
    $554 = ($553>>>0)<(255);
    $$6 = $554 ? $553 : 255;
    $555 = $$5 >>> 3;
    $556 = $555 << 10;
    $557 = $$10 >>> 3;
    $558 = $557 << 5;
    $559 = $558 | $556;
    $560 = $$6 >>> 3;
    $561 = $559 | $560;
    $562 = $561&65535;
    HEAP16[$$211971318>>1] = $562;
    $563 = (($$211971318) + ($$21194<<1)|0);
    $564 = ($532|0)==(0);
    if ($564) {
     break;
    } else {
     $$111911319 = $532;$$211971318 = $563;
    }
   }
   return;
   break;
  }
  case 4:  {
   $565 = ((($0)) + 16|0);
   $566 = HEAP32[$565>>2]|0;
   $567 = ((($0)) + 4|0);
   $568 = HEAP32[$567>>2]|0;
   $569 = ((($568)) + 9|0);
   $570 = HEAP8[$569>>0]|0;
   $571 = $570&255;
   $572 = (($566|0) / ($571|0))&-1;
   $573 = ($4|0)<($2|0);
   $574 = ((($0)) + 20|0);
   $575 = HEAP32[$574>>2]|0;
   if ($573) {
    $582 = Math_imul($572, $4)|0;
    $583 = (($575) + ($582<<1)|0);
    $584 = (($583) + ($3<<1)|0);
    $585 = ($3|0)>($1|0);
    $$sink1248 = $585 ? -1 : 1;
    $586 = (($572) + ($$sink1248))|0;
    $587 = ($10|0)==(0);
    $588 = (($584) + ($586<<1)|0);
    $$1249 = $587 ? $588 : $584;
    $$01217 = $439;$$11224 = $$1249;$$21221 = $586;
   } else {
    $576 = Math_imul($572, $2)|0;
    $577 = (($575) + ($576<<1)|0);
    $578 = (($577) + ($1<<1)|0);
    $579 = ($3|0)<($1|0);
    $$sink1247 = $579 ? -1 : 1;
    $580 = (($572) + ($$sink1247))|0;
    $581 = (($4) - ($2))|0;
    $$01217 = $581;$$11224 = $578;$$21221 = $580;
   }
   $not$1260 = ($10|0)!=(0);
   $589 = $not$1260&1;
   $$01217$ = (($$01217) + ($589))|0;
   $590 = ($$01217$|0)==(0);
   if ($590) {
    return;
   }
   $$pre1383 = HEAP32[(79224)>>2]|0;
   $$112181322 = $$01217$;$$212251321 = $$11224;
   while(1) {
    $591 = (($$112181322) + -1)|0;
    $592 = HEAP16[$$212251321>>1]|0;
    $593 = $592&65535;
    $594 = $593 >>> 10;
    $595 = $594 & 31;
    $596 = (($$pre1383) + ($595)|0);
    $597 = HEAP8[$596>>0]|0;
    $598 = $597&255;
    $599 = $593 >>> 5;
    $600 = $599 & 31;
    $601 = (($$pre1383) + ($600)|0);
    $602 = HEAP8[$601>>0]|0;
    $603 = $602&255;
    $604 = $593 & 31;
    $605 = (($$pre1383) + ($604)|0);
    $606 = HEAP8[$605>>0]|0;
    $607 = $606&255;
    $608 = Math_imul($598, $$0)|0;
    $609 = (($608>>>0) / 255)&-1;
    $610 = Math_imul($603, $$01096)|0;
    $611 = (($610>>>0) / 255)&-1;
    $612 = Math_imul($607, $$01097)|0;
    $613 = (($612>>>0) / 255)&-1;
    $614 = $609 >>> 3;
    $615 = $614 << 10;
    $616 = $611 >>> 3;
    $617 = $616 << 5;
    $618 = $617 | $615;
    $619 = $613 >>> 3;
    $620 = $618 | $619;
    $621 = $620&65535;
    HEAP16[$$212251321>>1] = $621;
    $622 = (($$212251321) + ($$21221<<1)|0);
    $623 = ($591|0)==(0);
    if ($623) {
     break;
    } else {
     $$112181322 = $591;$$212251321 = $622;
    }
   }
   return;
   break;
  }
  default: {
   $624 = ((($0)) + 16|0);
   $625 = HEAP32[$624>>2]|0;
   $626 = ((($0)) + 4|0);
   $627 = HEAP32[$626>>2]|0;
   $628 = ((($627)) + 9|0);
   $629 = HEAP8[$628>>0]|0;
   $630 = $629&255;
   $631 = (($625|0) / ($630|0))&-1;
   $632 = ($4|0)<($2|0);
   $633 = ((($0)) + 20|0);
   $634 = HEAP32[$633>>2]|0;
   if ($632) {
    $641 = Math_imul($631, $4)|0;
    $642 = (($634) + ($641<<1)|0);
    $643 = (($642) + ($3<<1)|0);
    $644 = ($3|0)>($1|0);
    $$sink1251 = $644 ? -1 : 1;
    $645 = (($631) + ($$sink1251))|0;
    $646 = ($10|0)==(0);
    $647 = (($643) + ($645<<1)|0);
    $$1252 = $646 ? $647 : $643;
    $$01226 = $439;$$11232 = $$1252;$$21230 = $645;
   } else {
    $635 = Math_imul($631, $2)|0;
    $636 = (($634) + ($635<<1)|0);
    $637 = (($636) + ($1<<1)|0);
    $638 = ($3|0)<($1|0);
    $$sink1250 = $638 ? -1 : 1;
    $639 = (($631) + ($$sink1250))|0;
    $640 = (($4) - ($2))|0;
    $$01226 = $640;$$11232 = $637;$$21230 = $639;
   }
   $not$1263 = ($10|0)!=(0);
   $648 = $not$1263&1;
   $$01226$ = (($$01226) + ($648))|0;
   $649 = ($$01226$|0)==(0);
   if ($649) {
    return;
   }
   $650 = $$0 >>> 3;
   $651 = $650 << 10;
   $652 = $$01096 >>> 3;
   $653 = $652 << 5;
   $654 = $$01097 >>> 3;
   $655 = $653 | $654;
   $656 = $655 | $651;
   $657 = $656&65535;
   $$112271313 = $$01226$;$$212331312 = $$11232;
   while(1) {
    $658 = (($$112271313) + -1)|0;
    HEAP16[$$212331312>>1] = $657;
    $659 = (($$212331312) + ($$21230<<1)|0);
    $660 = ($658|0)==(0);
    if ($660) {
     break;
    } else {
     $$112271313 = $658;$$212331312 = $659;
    }
   }
   return;
  }
  }
 } else {
  switch ($5|0) {
  case 1:  {
   $661 = (($3) - ($1))|0;
   $662 = ($661|0)<(0);
   $663 = (0 - ($661))|0;
   $664 = $662 ? $663 : $661;
   $665 = (($4) - ($2))|0;
   $666 = ($665|0)<(0);
   $667 = (0 - ($665))|0;
   $668 = $666 ? $667 : $665;
   $669 = ($664|0)<($668|0);
   if ($669) {
    $673 = $664 << 1;
    $674 = (($673) - ($668))|0;
    $675 = (($664) - ($668))|0;
    $$01200 = 1;$$01206 = 0;$$01210$in = $675;$$01211 = $673;$$01212 = $674;$$01215$in = $668;
   } else {
    $670 = $668 << 1;
    $671 = (($670) - ($664))|0;
    $672 = (($668) - ($664))|0;
    $$01200 = 0;$$01206 = 1;$$01210$in = $672;$$01211 = $670;$$01212 = $671;$$01215$in = $664;
   }
   $$01210 = $$01210$in << 1;
   $676 = ($3|0)<($1|0);
   $677 = (0 - ($$01206))|0;
   $$$01206 = $676 ? $677 : $$01206;
   $$1253 = $676 ? -1 : 1;
   $678 = ($4|0)<($2|0);
   $679 = (0 - ($$01200))|0;
   $$11201 = $678 ? $679 : $$01200;
   $$11199 = $678 ? -1 : 1;
   $not$1258 = ($10|0)!=(0);
   $$01215 = $not$1258&1;
   $$01215$in$$01215 = (($$01215$in) + ($$01215))|0;
   $680 = ($$01215$in$$01215|0)>(0);
   if (!($680)) {
    return;
   }
   $681 = ((($0)) + 20|0);
   $682 = ((($0)) + 16|0);
   $$pre1380 = HEAP32[$681>>2]|0;
   $$pre1381 = HEAP32[$682>>2]|0;
   $$pre1382 = HEAP32[(79224)>>2]|0;
   $$012021332 = $2;$$012081331 = $1;$$012221329 = 0;$$112131330 = $$01212;
   while(1) {
    $683 = Math_imul($$pre1381, $$012021332)|0;
    $684 = (($$pre1380) + ($683)|0);
    $685 = $$012081331 << 1;
    $686 = (($684) + ($685)|0);
    $687 = HEAP16[$686>>1]|0;
    $688 = $687&65535;
    $689 = $688 >>> 10;
    $690 = $689 & 31;
    $691 = (($$pre1382) + ($690)|0);
    $692 = HEAP8[$691>>0]|0;
    $693 = $692&255;
    $694 = $688 >>> 5;
    $695 = $694 & 31;
    $696 = (($$pre1382) + ($695)|0);
    $697 = HEAP8[$696>>0]|0;
    $698 = $697&255;
    $699 = $688 & 31;
    $700 = (($$pre1382) + ($699)|0);
    $701 = HEAP8[$700>>0]|0;
    $702 = $701&255;
    $703 = Math_imul($693, $22)|0;
    $704 = (($703>>>0) / 255)&-1;
    $705 = (($704) + ($$0))|0;
    $706 = Math_imul($698, $22)|0;
    $707 = (($706>>>0) / 255)&-1;
    $708 = (($707) + ($$01096))|0;
    $709 = Math_imul($702, $22)|0;
    $710 = (($709>>>0) / 255)&-1;
    $711 = (($710) + ($$01097))|0;
    $712 = $705 >>> 3;
    $713 = $712 << 10;
    $714 = $708 >>> 3;
    $715 = $714 << 5;
    $716 = $715 | $713;
    $717 = $711 >>> 3;
    $718 = $716 | $717;
    $719 = $718&65535;
    HEAP16[$686>>1] = $719;
    $720 = ($$112131330|0)<(0);
    $$01211$$01210 = $720 ? $$01211 : $$01210;
    $$$01206$$1253 = $720 ? $$$01206 : $$1253;
    $$11201$$11199 = $720 ? $$11201 : $$11199;
    $$11203 = (($$012021332) + ($$11201$$11199))|0;
    $$11209 = (($$$01206$$1253) + ($$012081331))|0;
    $$21214 = (($$01211$$01210) + ($$112131330))|0;
    $721 = (($$012221329) + 1)|0;
    $722 = ($721|0)<($$01215$in$$01215|0);
    if ($722) {
     $$012021332 = $$11203;$$012081331 = $$11209;$$012221329 = $721;$$112131330 = $$21214;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 2:  {
   $723 = (($3) - ($1))|0;
   $724 = ($723|0)<(0);
   $725 = (0 - ($723))|0;
   $726 = $724 ? $725 : $723;
   $727 = (($4) - ($2))|0;
   $728 = ($727|0)<(0);
   $729 = (0 - ($727))|0;
   $730 = $728 ? $729 : $727;
   $731 = ($726|0)<($730|0);
   if ($731) {
    $735 = $726 << 1;
    $736 = (($735) - ($730))|0;
    $737 = (($726) - ($730))|0;
    $$01162 = 1;$$01168 = 0;$$01172$in = $737;$$01173 = $735;$$01174 = $736;$$01177$in = $730;
   } else {
    $732 = $730 << 1;
    $733 = (($732) - ($726))|0;
    $734 = (($730) - ($726))|0;
    $$01162 = 0;$$01168 = 1;$$01172$in = $734;$$01173 = $732;$$01174 = $733;$$01177$in = $726;
   }
   $$01172 = $$01172$in << 1;
   $738 = ($3|0)<($1|0);
   $739 = (0 - ($$01168))|0;
   $$$01168 = $738 ? $739 : $$01168;
   $$1254 = $738 ? -1 : 1;
   $740 = ($4|0)<($2|0);
   $741 = (0 - ($$01162))|0;
   $$11163 = $740 ? $741 : $$01162;
   $$11161 = $740 ? -1 : 1;
   $not$1257 = ($10|0)!=(0);
   $$01177 = $not$1257&1;
   $$01177$in$$01177 = (($$01177$in) + ($$01177))|0;
   $742 = ($$01177$in$$01177|0)>(0);
   if (!($742)) {
    return;
   }
   $743 = ((($0)) + 20|0);
   $744 = ((($0)) + 16|0);
   $$pre1377 = HEAP32[$743>>2]|0;
   $$pre1378 = HEAP32[$744>>2]|0;
   $$pre1379 = HEAP32[(79224)>>2]|0;
   $$011641337 = $2;$$011701336 = $1;$$011831334 = 0;$$111751335 = $$01174;
   while(1) {
    $745 = Math_imul($$pre1378, $$011641337)|0;
    $746 = (($$pre1377) + ($745)|0);
    $747 = $$011701336 << 1;
    $748 = (($746) + ($747)|0);
    $749 = HEAP16[$748>>1]|0;
    $750 = $749&65535;
    $751 = $750 >>> 10;
    $752 = $751 & 31;
    $753 = (($$pre1379) + ($752)|0);
    $754 = HEAP8[$753>>0]|0;
    $755 = $754&255;
    $756 = $750 >>> 5;
    $757 = $756 & 31;
    $758 = (($$pre1379) + ($757)|0);
    $759 = HEAP8[$758>>0]|0;
    $760 = $759&255;
    $761 = $750 & 31;
    $762 = (($$pre1379) + ($761)|0);
    $763 = HEAP8[$762>>0]|0;
    $764 = $763&255;
    $765 = (($755) + ($$0))|0;
    $766 = ($765>>>0)<(255);
    $$11 = $766 ? $765 : 255;
    $767 = (($760) + ($$01096))|0;
    $768 = ($767>>>0)<(255);
    $$7 = $768 ? $767 : 255;
    $769 = (($764) + ($$01097))|0;
    $770 = ($769>>>0)<(255);
    $$12 = $770 ? $769 : 255;
    $771 = $$11 >>> 3;
    $772 = $771 << 10;
    $773 = $$7 >>> 3;
    $774 = $773 << 5;
    $775 = $774 | $772;
    $776 = $$12 >>> 3;
    $777 = $775 | $776;
    $778 = $777&65535;
    HEAP16[$748>>1] = $778;
    $779 = ($$111751335|0)<(0);
    $$01173$$01172 = $779 ? $$01173 : $$01172;
    $$$01168$$1254 = $779 ? $$$01168 : $$1254;
    $$11163$$11161 = $779 ? $$11163 : $$11161;
    $$11165 = (($$011641337) + ($$11163$$11161))|0;
    $$11171 = (($$$01168$$1254) + ($$011701336))|0;
    $$21176 = (($$01173$$01172) + ($$111751335))|0;
    $780 = (($$011831334) + 1)|0;
    $781 = ($780|0)<($$01177$in$$01177|0);
    if ($781) {
     $$011641337 = $$11165;$$011701336 = $$11171;$$011831334 = $780;$$111751335 = $$21176;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 4:  {
   $782 = (($3) - ($1))|0;
   $783 = ($782|0)<(0);
   $784 = (0 - ($782))|0;
   $785 = $783 ? $784 : $782;
   $786 = (($4) - ($2))|0;
   $787 = ($786|0)<(0);
   $788 = (0 - ($786))|0;
   $789 = $787 ? $788 : $786;
   $790 = ($785|0)<($789|0);
   if ($790) {
    $794 = $785 << 1;
    $795 = (($794) - ($789))|0;
    $796 = (($785) - ($789))|0;
    $$01132 = 1;$$01138 = 0;$$01142$in = $796;$$01143 = $794;$$01144 = $795;$$01147$in = $789;
   } else {
    $791 = $789 << 1;
    $792 = (($791) - ($785))|0;
    $793 = (($789) - ($785))|0;
    $$01132 = 0;$$01138 = 1;$$01142$in = $793;$$01143 = $791;$$01144 = $792;$$01147$in = $785;
   }
   $$01142 = $$01142$in << 1;
   $797 = ($3|0)<($1|0);
   $798 = (0 - ($$01138))|0;
   $$$01138 = $797 ? $798 : $$01138;
   $$1255 = $797 ? -1 : 1;
   $799 = ($4|0)<($2|0);
   $800 = (0 - ($$01132))|0;
   $$11133 = $799 ? $800 : $$01132;
   $$11131 = $799 ? -1 : 1;
   $not$ = ($10|0)!=(0);
   $$01147 = $not$&1;
   $$01147$in$$01147 = (($$01147$in) + ($$01147))|0;
   $801 = ($$01147$in$$01147|0)>(0);
   if (!($801)) {
    return;
   }
   $802 = ((($0)) + 20|0);
   $803 = ((($0)) + 16|0);
   $$pre = HEAP32[$802>>2]|0;
   $$pre1375 = HEAP32[$803>>2]|0;
   $$pre1376 = HEAP32[(79224)>>2]|0;
   $$011341342 = $2;$$011401341 = $1;$$011521339 = 0;$$111451340 = $$01144;
   while(1) {
    $804 = Math_imul($$pre1375, $$011341342)|0;
    $805 = (($$pre) + ($804)|0);
    $806 = $$011401341 << 1;
    $807 = (($805) + ($806)|0);
    $808 = HEAP16[$807>>1]|0;
    $809 = $808&65535;
    $810 = $809 >>> 10;
    $811 = $810 & 31;
    $812 = (($$pre1376) + ($811)|0);
    $813 = HEAP8[$812>>0]|0;
    $814 = $813&255;
    $815 = $809 >>> 5;
    $816 = $815 & 31;
    $817 = (($$pre1376) + ($816)|0);
    $818 = HEAP8[$817>>0]|0;
    $819 = $818&255;
    $820 = $809 & 31;
    $821 = (($$pre1376) + ($820)|0);
    $822 = HEAP8[$821>>0]|0;
    $823 = $822&255;
    $824 = Math_imul($814, $$0)|0;
    $825 = (($824>>>0) / 255)&-1;
    $826 = Math_imul($819, $$01096)|0;
    $827 = (($826>>>0) / 255)&-1;
    $828 = Math_imul($823, $$01097)|0;
    $829 = (($828>>>0) / 255)&-1;
    $830 = $825 >>> 3;
    $831 = $830 << 10;
    $832 = $827 >>> 3;
    $833 = $832 << 5;
    $834 = $833 | $831;
    $835 = $829 >>> 3;
    $836 = $834 | $835;
    $837 = $836&65535;
    HEAP16[$807>>1] = $837;
    $838 = ($$111451340|0)<(0);
    $$01143$$01142 = $838 ? $$01143 : $$01142;
    $$$01138$$1255 = $838 ? $$$01138 : $$1255;
    $$11133$$11131 = $838 ? $$11133 : $$11131;
    $$11135 = (($$011341342) + ($$11133$$11131))|0;
    $$11141 = (($$$01138$$1255) + ($$011401341))|0;
    $$21146 = (($$01143$$01142) + ($$111451340))|0;
    $839 = (($$011521339) + 1)|0;
    $840 = ($839|0)<($$01147$in$$01147|0);
    if ($840) {
     $$011341342 = $$11135;$$011401341 = $$11141;$$011521339 = $839;$$111451340 = $$21146;
    } else {
     break;
    }
   }
   return;
   break;
  }
  default: {
   $841 = (($3) - ($1))|0;
   $842 = ($841|0)<(0);
   $843 = (0 - ($841))|0;
   $844 = $842 ? $843 : $841;
   $845 = (($4) - ($2))|0;
   $846 = ($845|0)<(0);
   $847 = (0 - ($845))|0;
   $848 = $846 ? $847 : $845;
   $849 = ($844|0)<($848|0);
   if ($849) {
    $853 = $844 << 1;
    $854 = (($853) - ($848))|0;
    $855 = (($844) - ($848))|0;
    $$01101 = 1;$$01107 = 0;$$01111$in = $855;$$01112 = $853;$$01113 = $854;$$01116$in = $848;
   } else {
    $850 = $848 << 1;
    $851 = (($850) - ($844))|0;
    $852 = (($848) - ($844))|0;
    $$01101 = 0;$$01107 = 1;$$01111$in = $852;$$01112 = $850;$$01113 = $851;$$01116$in = $844;
   }
   $$01111 = $$01111$in << 1;
   $856 = ($3|0)<($1|0);
   $857 = (0 - ($$01107))|0;
   $$$01107 = $856 ? $857 : $$01107;
   $$1256 = $856 ? -1 : 1;
   $858 = ($4|0)<($2|0);
   $859 = (0 - ($$01101))|0;
   $$11102 = $858 ? $859 : $$01101;
   $$1 = $858 ? -1 : 1;
   $not$1259 = ($10|0)!=(0);
   $$01116 = $not$1259&1;
   $$01116$in$$01116 = (($$01116$in) + ($$01116))|0;
   $860 = ($$01116$in$$01116|0)>(0);
   if (!($860)) {
    return;
   }
   $861 = ((($0)) + 20|0);
   $862 = HEAP32[$861>>2]|0;
   $863 = ((($0)) + 16|0);
   $864 = HEAP32[$863>>2]|0;
   $865 = $$0 >>> 3;
   $866 = $865 << 10;
   $867 = $$01096 >>> 3;
   $868 = $867 << 5;
   $869 = $$01097 >>> 3;
   $870 = $868 | $869;
   $871 = $870 | $866;
   $872 = $871&65535;
   $$011031327 = $2;$$011091326 = $1;$$011211324 = 0;$$111141325 = $$01113;
   while(1) {
    $873 = Math_imul($864, $$011031327)|0;
    $874 = (($862) + ($873)|0);
    $875 = $$011091326 << 1;
    $876 = (($874) + ($875)|0);
    HEAP16[$876>>1] = $872;
    $877 = ($$111141325|0)<(0);
    $$01112$$01111 = $877 ? $$01112 : $$01111;
    $$$01107$$1256 = $877 ? $$$01107 : $$1256;
    $$11102$$1 = $877 ? $$11102 : $$1;
    $$11104 = (($$011031327) + ($$11102$$1))|0;
    $$11110 = (($$$01107$$1256) + ($$011091326))|0;
    $$21115 = (($$01112$$01111) + ($$111141325))|0;
    $878 = (($$011211324) + 1)|0;
    $879 = ($878|0)<($$01116$in$$01116|0);
    if ($879) {
     $$011031327 = $$11104;$$011091326 = $$11110;$$011211324 = $878;$$111141325 = $$21115;
    } else {
     break;
    }
   }
   return;
  }
  }
 }
}
function _SDL_BlendLine_ARGB8888($0,$1,$2,$3,$4,$5,$6,$7,$8,$9,$10) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 $8 = $8|0;
 $9 = $9|0;
 $10 = $10|0;
 var $$ = 0, $$$01135 = 0, $$$01135$$1292 = 0, $$$01165 = 0, $$$01165$$1291 = 0, $$$01194 = 0, $$$01194$$1290 = 0, $$$01224 = 0, $$$01224$$1289 = 0, $$0 = 0, $$01124 = 0, $$01125 = 0, $$011271328 = 0, $$01129 = 0, $$011311363 = 0, $$01135 = 0, $$011371362 = 0, $$01139 = 0, $$01139$in = 0, $$01140 = 0;
 var $$01140$$01139 = 0, $$01141 = 0, $$01144 = 0, $$01144$in = 0, $$01144$in$$01144 = 0, $$011481331 = 0, $$011491360 = 0, $$011541334 = 0, $$01159 = 0, $$011611378 = 0, $$01165 = 0, $$011671377 = 0, $$01169 = 0, $$01169$in = 0, $$01170 = 0, $$01170$$01169 = 0, $$01171 = 0, $$01174 = 0, $$01174$in = 0, $$01174$in$$01174 = 0;
 var $$011771326 = 0, $$011781375 = 0, $$011821340 = 0, $$011851343 = 0, $$01188 = 0, $$011901373 = 0, $$01194 = 0, $$011961372 = 0, $$01198 = 0, $$01198$in = 0, $$01199 = 0, $$01199$$01198 = 0, $$01200 = 0, $$01203 = 0, $$01203$in = 0, $$01203$in$$01203 = 0, $$012081370 = 0, $$012091346 = 0, $$012131337 = 0, $$01218 = 0;
 var $$012201368 = 0, $$01224 = 0, $$012261367 = 0, $$01228 = 0, $$01228$in = 0, $$01229 = 0, $$01229$$01228 = 0, $$01230 = 0, $$01233 = 0, $$01233$in = 0, $$01233$in$$01233 = 0, $$01235 = 0, $$01235$ = 0, $$012401365 = 0, $$01244 = 0, $$01244$ = 0, $$01258 = 0, $$01258$ = 0, $$01262 = 0, $$01262$ = 0;
 var $$1 = 0, $$10 = 0, $$11 = 0, $$11130 = 0, $$11130$$1 = 0, $$11132 = 0, $$11138 = 0, $$111421361 = 0, $$11147$ph = 0, $$111471327 = 0, $$11152$ph = 0, $$111521330 = 0, $$11156$ph = 0, $$111561333 = 0, $$11158 = 0, $$11160 = 0, $$11160$$11158 = 0, $$11162 = 0, $$11168 = 0, $$111721376 = 0;
 var $$11181$ph = 0, $$111811325 = 0, $$11184$ph = 0, $$111841339 = 0, $$11187 = 0, $$11189 = 0, $$11189$$11187 = 0, $$11191 = 0, $$11197 = 0, $$112011371 = 0, $$11206$ph = 0, $$112061342 = 0, $$11211$ph = 0, $$112111345 = 0, $$11215$ph = 0, $$112151336 = 0, $$11217 = 0, $$11219 = 0, $$11219$$11217 = 0, $$11221 = 0;
 var $$11227 = 0, $$112311366 = 0, $$112361352 = 0, $$11242 = 0, $$112451355 = 0, $$11250 = 0, $$11253 = 0, $$112591348 = 0, $$112631358 = 0, $$11268 = 0, $$12 = 0, $$1270 = 0, $$1271 = 0, $$1272 = 0, $$1273 = 0, $$1274 = 0, $$1275 = 0, $$1276 = 0, $$1277 = 0, $$1279 = 0;
 var $$1282 = 0, $$1285 = 0, $$1288 = 0, $$1289 = 0, $$1290 = 0, $$1291 = 0, $$1292 = 0, $$2 = 0, $$21143 = 0, $$21173 = 0, $$21202 = 0, $$21232 = 0, $$21239 = 0, $$212431351 = 0, $$21248 = 0, $$212511354 = 0, $$212541349 = 0, $$21257 = 0, $$21266 = 0, $$212691357 = 0;
 var $$3 = 0, $$4 = 0, $$5 = 0, $$6 = 0, $$7 = 0, $$8 = 0, $$9 = 0, $$off = 0, $$sink = 0, $$sink1278 = 0, $$sink1280 = 0, $$sink1281 = 0, $$sink1283 = 0, $$sink1284 = 0, $$sink1286 = 0, $$sink1287 = 0, $$sink1380 = 0, $$sink1382 = 0, $$sink1384 = 0, $$sink1386 = 0;
 var $$sink1388 = 0, $$sink1390 = 0, $$sink1392 = 0, $$sink1394 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0;
 var $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0;
 var $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0;
 var $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0;
 var $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0;
 var $297 = 0, $298 = 0, $299 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0;
 var $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0;
 var $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0;
 var $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0;
 var $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0;
 var $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0;
 var $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0;
 var $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0;
 var $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0;
 var $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0;
 var $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0;
 var $497 = 0, $498 = 0, $499 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0;
 var $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0;
 var $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0;
 var $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0;
 var $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0;
 var $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0;
 var $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0;
 var $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0;
 var $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0;
 var $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0;
 var $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0;
 var $697 = 0, $698 = 0, $699 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0;
 var $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0;
 var $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $not$ = 0, $not$1293 = 0, $not$1294 = 0, $not$1295 = 0, $not$1296 = 0, $not$1297 = 0, $not$1298 = 0, $not$1299 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$off = (($5) + -1)|0;
 $11 = ($$off>>>0)<(2);
 $12 = $6&255;
 $13 = $7&255;
 $14 = $9&255;
 $15 = $8&255;
 if ($11) {
  $16 = Math_imul($14, $15)|0;
  $17 = Math_imul($14, $13)|0;
  $18 = Math_imul($14, $12)|0;
  $19 = (($18>>>0) / 255)&-1;
  $20 = (($17>>>0) / 255)&-1;
  $21 = (($16>>>0) / 255)&-1;
  $$0 = $19;$$01124 = $20;$$01125 = $21;
 } else {
  $$0 = $12;$$01124 = $13;$$01125 = $15;
 }
 $22 = $14 ^ 255;
 $23 = ($4|0)==($2|0);
 if ($23) {
  switch ($5|0) {
  case 1:  {
   $24 = ((($0)) + 16|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = ((($0)) + 4|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = ((($27)) + 9|0);
   $29 = HEAP8[$28>>0]|0;
   $30 = $29&255;
   $31 = (($25|0) / ($30|0))&-1;
   $32 = ($3|0)<($1|0);
   $33 = ((($0)) + 20|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = Math_imul($31, $4)|0;
   $36 = (($34) + ($35<<2)|0);
   $37 = ($10|0)!=(0);
   if ($32) {
    $40 = (($36) + ($3<<2)|0);
    $41 = ((($40)) + 4|0);
    $$1270 = $37 ? $40 : $41;
    $42 = (($1) - ($3))|0;
    $$11147$ph = $$1270;$$sink1380 = $42;
   } else {
    $38 = (($36) + ($1<<2)|0);
    $39 = (($3) - ($1))|0;
    $$11147$ph = $38;$$sink1380 = $39;
   }
   $43 = $37&1;
   $44 = (($$sink1380) + ($43))|0;
   $45 = ($44|0)==(0);
   if ($45) {
    return;
   } else {
    $$011271328 = $44;$$111471327 = $$11147$ph;
   }
   while(1) {
    $46 = (($$011271328) + -1)|0;
    $47 = HEAP32[$$111471327>>2]|0;
    $48 = $47 >>> 16;
    $49 = $48 & 255;
    $50 = $47 >>> 8;
    $51 = $50 & 255;
    $52 = $47 & 255;
    $53 = $47 >>> 24;
    $54 = Math_imul($49, $22)|0;
    $55 = (($54>>>0) / 255)&-1;
    $56 = (($55) + ($$0))|0;
    $57 = Math_imul($51, $22)|0;
    $58 = (($57>>>0) / 255)&-1;
    $59 = (($58) + ($$01124))|0;
    $60 = Math_imul($52, $22)|0;
    $61 = (($60>>>0) / 255)&-1;
    $62 = (($61) + ($$01125))|0;
    $63 = Math_imul($53, $22)|0;
    $64 = (($63>>>0) / 255)&-1;
    $65 = (($64) + ($14))|0;
    $66 = $65 << 24;
    $67 = $56 << 16;
    $68 = $59 << 8;
    $69 = $66 | $62;
    $70 = $69 | $67;
    $71 = $70 | $68;
    HEAP32[$$111471327>>2] = $71;
    $72 = ((($$111471327)) + 4|0);
    $73 = ($46|0)==(0);
    if ($73) {
     break;
    } else {
     $$011271328 = $46;$$111471327 = $72;
    }
   }
   return;
   break;
  }
  case 2:  {
   $74 = ((($0)) + 16|0);
   $75 = HEAP32[$74>>2]|0;
   $76 = ((($0)) + 4|0);
   $77 = HEAP32[$76>>2]|0;
   $78 = ((($77)) + 9|0);
   $79 = HEAP8[$78>>0]|0;
   $80 = $79&255;
   $81 = (($75|0) / ($80|0))&-1;
   $82 = ($3|0)<($1|0);
   $83 = ((($0)) + 20|0);
   $84 = HEAP32[$83>>2]|0;
   $85 = Math_imul($81, $4)|0;
   $86 = (($84) + ($85<<2)|0);
   $87 = ($10|0)!=(0);
   if ($82) {
    $90 = (($86) + ($3<<2)|0);
    $91 = ((($90)) + 4|0);
    $$1271 = $87 ? $90 : $91;
    $92 = (($1) - ($3))|0;
    $$11152$ph = $$1271;$$sink1382 = $92;
   } else {
    $88 = (($86) + ($1<<2)|0);
    $89 = (($3) - ($1))|0;
    $$11152$ph = $88;$$sink1382 = $89;
   }
   $93 = $87&1;
   $94 = (($$sink1382) + ($93))|0;
   $95 = ($94|0)==(0);
   if ($95) {
    return;
   } else {
    $$011481331 = $94;$$111521330 = $$11152$ph;
   }
   while(1) {
    $96 = (($$011481331) + -1)|0;
    $97 = HEAP32[$$111521330>>2]|0;
    $98 = $97 >>> 16;
    $99 = $98 & 255;
    $100 = $97 >>> 8;
    $101 = $100 & 255;
    $102 = $97 & 255;
    $103 = $97 & -16777216;
    $104 = (($99) + ($$0))|0;
    $105 = ($104>>>0)<(255);
    $$ = $105 ? $104 : 255;
    $106 = (($101) + ($$01124))|0;
    $107 = ($106>>>0)<(255);
    $$8 = $107 ? $106 : 255;
    $108 = (($102) + ($$01125))|0;
    $109 = ($108>>>0)<(255);
    $$2 = $109 ? $108 : 255;
    $110 = $$ << 16;
    $111 = $$8 << 8;
    $112 = $$2 | $103;
    $113 = $112 | $110;
    $114 = $113 | $111;
    HEAP32[$$111521330>>2] = $114;
    $115 = ((($$111521330)) + 4|0);
    $116 = ($96|0)==(0);
    if ($116) {
     break;
    } else {
     $$011481331 = $96;$$111521330 = $115;
    }
   }
   return;
   break;
  }
  case 4:  {
   $117 = ((($0)) + 16|0);
   $118 = HEAP32[$117>>2]|0;
   $119 = ((($0)) + 4|0);
   $120 = HEAP32[$119>>2]|0;
   $121 = ((($120)) + 9|0);
   $122 = HEAP8[$121>>0]|0;
   $123 = $122&255;
   $124 = (($118|0) / ($123|0))&-1;
   $125 = ($3|0)<($1|0);
   $126 = ((($0)) + 20|0);
   $127 = HEAP32[$126>>2]|0;
   $128 = Math_imul($124, $4)|0;
   $129 = (($127) + ($128<<2)|0);
   $130 = ($10|0)!=(0);
   if ($125) {
    $133 = (($129) + ($3<<2)|0);
    $134 = ((($133)) + 4|0);
    $$1272 = $130 ? $133 : $134;
    $135 = (($1) - ($3))|0;
    $$11156$ph = $$1272;$$sink1384 = $135;
   } else {
    $131 = (($129) + ($1<<2)|0);
    $132 = (($3) - ($1))|0;
    $$11156$ph = $131;$$sink1384 = $132;
   }
   $136 = $130&1;
   $137 = (($$sink1384) + ($136))|0;
   $138 = ($137|0)==(0);
   if ($138) {
    return;
   } else {
    $$011541334 = $137;$$111561333 = $$11156$ph;
   }
   while(1) {
    $139 = (($$011541334) + -1)|0;
    $140 = HEAP32[$$111561333>>2]|0;
    $141 = $140 >>> 16;
    $142 = $141 & 255;
    $143 = $140 >>> 8;
    $144 = $143 & 255;
    $145 = $140 & 255;
    $146 = $140 & -16777216;
    $147 = Math_imul($142, $$0)|0;
    $148 = (($147>>>0) / 255)&-1;
    $149 = Math_imul($144, $$01124)|0;
    $150 = (($149>>>0) / 255)&-1;
    $151 = Math_imul($145, $$01125)|0;
    $152 = (($151>>>0) / 255)&-1;
    $153 = $148 << 16;
    $154 = $150 << 8;
    $155 = $152 | $146;
    $156 = $155 | $153;
    $157 = $156 | $154;
    HEAP32[$$111561333>>2] = $157;
    $158 = ((($$111561333)) + 4|0);
    $159 = ($139|0)==(0);
    if ($159) {
     break;
    } else {
     $$011541334 = $139;$$111561333 = $158;
    }
   }
   return;
   break;
  }
  default: {
   $160 = ((($0)) + 16|0);
   $161 = HEAP32[$160>>2]|0;
   $162 = ((($0)) + 4|0);
   $163 = HEAP32[$162>>2]|0;
   $164 = ((($163)) + 9|0);
   $165 = HEAP8[$164>>0]|0;
   $166 = $165&255;
   $167 = (($161|0) / ($166|0))&-1;
   $168 = ($3|0)<($1|0);
   $169 = ((($0)) + 20|0);
   $170 = HEAP32[$169>>2]|0;
   $171 = Math_imul($167, $4)|0;
   $172 = (($170) + ($171<<2)|0);
   $173 = ($10|0)!=(0);
   if ($168) {
    $176 = (($172) + ($3<<2)|0);
    $177 = ((($176)) + 4|0);
    $$1273 = $173 ? $176 : $177;
    $178 = (($1) - ($3))|0;
    $$11181$ph = $$1273;$$sink1386 = $178;
   } else {
    $174 = (($172) + ($1<<2)|0);
    $175 = (($3) - ($1))|0;
    $$11181$ph = $174;$$sink1386 = $175;
   }
   $179 = $173&1;
   $180 = (($$sink1386) + ($179))|0;
   $181 = ($180|0)==(0);
   if ($181) {
    return;
   }
   $182 = $14 << 24;
   $183 = $$0 << 16;
   $184 = $$01124 << 8;
   $185 = $$01125 | $182;
   $186 = $185 | $184;
   $187 = $186 | $183;
   $$011771326 = $180;$$111811325 = $$11181$ph;
   while(1) {
    $188 = (($$011771326) + -1)|0;
    HEAP32[$$111811325>>2] = $187;
    $189 = ((($$111811325)) + 4|0);
    $190 = ($188|0)==(0);
    if ($190) {
     break;
    } else {
     $$011771326 = $188;$$111811325 = $189;
    }
   }
   return;
  }
  }
 }
 $191 = ($3|0)==($1|0);
 if ($191) {
  switch ($5|0) {
  case 1:  {
   $192 = ((($0)) + 16|0);
   $193 = HEAP32[$192>>2]|0;
   $194 = ((($0)) + 4|0);
   $195 = HEAP32[$194>>2]|0;
   $196 = ((($195)) + 9|0);
   $197 = HEAP8[$196>>0]|0;
   $198 = $197&255;
   $199 = (($193|0) / ($198|0))&-1;
   $200 = ($4|0)<($2|0);
   $201 = ((($0)) + 20|0);
   $202 = HEAP32[$201>>2]|0;
   $203 = ($10|0)!=(0);
   if ($200) {
    $208 = Math_imul($199, $4)|0;
    $209 = (($202) + ($208<<2)|0);
    $210 = (($209) + ($3<<2)|0);
    $211 = (($210) + ($199<<2)|0);
    $$1274 = $203 ? $210 : $211;
    $212 = (($2) - ($4))|0;
    $$11184$ph = $$1274;$$sink1388 = $212;
   } else {
    $204 = Math_imul($199, $2)|0;
    $205 = (($202) + ($204<<2)|0);
    $206 = (($205) + ($3<<2)|0);
    $207 = (($4) - ($2))|0;
    $$11184$ph = $206;$$sink1388 = $207;
   }
   $213 = $203&1;
   $214 = (($$sink1388) + ($213))|0;
   $215 = ($214|0)==(0);
   if ($215) {
    return;
   } else {
    $$011821340 = $214;$$111841339 = $$11184$ph;
   }
   while(1) {
    $216 = (($$011821340) + -1)|0;
    $217 = HEAP32[$$111841339>>2]|0;
    $218 = $217 >>> 16;
    $219 = $218 & 255;
    $220 = $217 >>> 8;
    $221 = $220 & 255;
    $222 = $217 & 255;
    $223 = $217 >>> 24;
    $224 = Math_imul($219, $22)|0;
    $225 = (($224>>>0) / 255)&-1;
    $226 = (($225) + ($$0))|0;
    $227 = Math_imul($221, $22)|0;
    $228 = (($227>>>0) / 255)&-1;
    $229 = (($228) + ($$01124))|0;
    $230 = Math_imul($222, $22)|0;
    $231 = (($230>>>0) / 255)&-1;
    $232 = (($231) + ($$01125))|0;
    $233 = Math_imul($223, $22)|0;
    $234 = (($233>>>0) / 255)&-1;
    $235 = (($234) + ($14))|0;
    $236 = $235 << 24;
    $237 = $226 << 16;
    $238 = $229 << 8;
    $239 = $236 | $232;
    $240 = $239 | $237;
    $241 = $240 | $238;
    HEAP32[$$111841339>>2] = $241;
    $242 = (($$111841339) + ($199<<2)|0);
    $243 = ($216|0)==(0);
    if ($243) {
     break;
    } else {
     $$011821340 = $216;$$111841339 = $242;
    }
   }
   return;
   break;
  }
  case 2:  {
   $244 = ((($0)) + 16|0);
   $245 = HEAP32[$244>>2]|0;
   $246 = ((($0)) + 4|0);
   $247 = HEAP32[$246>>2]|0;
   $248 = ((($247)) + 9|0);
   $249 = HEAP8[$248>>0]|0;
   $250 = $249&255;
   $251 = (($245|0) / ($250|0))&-1;
   $252 = ($4|0)<($2|0);
   $253 = ((($0)) + 20|0);
   $254 = HEAP32[$253>>2]|0;
   $255 = ($10|0)!=(0);
   if ($252) {
    $260 = Math_imul($251, $4)|0;
    $261 = (($254) + ($260<<2)|0);
    $262 = (($261) + ($3<<2)|0);
    $263 = (($262) + ($251<<2)|0);
    $$1275 = $255 ? $262 : $263;
    $264 = (($2) - ($4))|0;
    $$11206$ph = $$1275;$$sink1390 = $264;
   } else {
    $256 = Math_imul($251, $2)|0;
    $257 = (($254) + ($256<<2)|0);
    $258 = (($257) + ($3<<2)|0);
    $259 = (($4) - ($2))|0;
    $$11206$ph = $258;$$sink1390 = $259;
   }
   $265 = $255&1;
   $266 = (($$sink1390) + ($265))|0;
   $267 = ($266|0)==(0);
   if ($267) {
    return;
   } else {
    $$011851343 = $266;$$112061342 = $$11206$ph;
   }
   while(1) {
    $268 = (($$011851343) + -1)|0;
    $269 = HEAP32[$$112061342>>2]|0;
    $270 = $269 >>> 16;
    $271 = $270 & 255;
    $272 = $269 >>> 8;
    $273 = $272 & 255;
    $274 = $269 & 255;
    $275 = $269 & -16777216;
    $276 = (($271) + ($$0))|0;
    $277 = ($276>>>0)<(255);
    $$3 = $277 ? $276 : 255;
    $278 = (($273) + ($$01124))|0;
    $279 = ($278>>>0)<(255);
    $$9 = $279 ? $278 : 255;
    $280 = (($274) + ($$01125))|0;
    $281 = ($280>>>0)<(255);
    $$4 = $281 ? $280 : 255;
    $282 = $$3 << 16;
    $283 = $$9 << 8;
    $284 = $$4 | $275;
    $285 = $284 | $282;
    $286 = $285 | $283;
    HEAP32[$$112061342>>2] = $286;
    $287 = (($$112061342) + ($251<<2)|0);
    $288 = ($268|0)==(0);
    if ($288) {
     break;
    } else {
     $$011851343 = $268;$$112061342 = $287;
    }
   }
   return;
   break;
  }
  case 4:  {
   $289 = ((($0)) + 16|0);
   $290 = HEAP32[$289>>2]|0;
   $291 = ((($0)) + 4|0);
   $292 = HEAP32[$291>>2]|0;
   $293 = ((($292)) + 9|0);
   $294 = HEAP8[$293>>0]|0;
   $295 = $294&255;
   $296 = (($290|0) / ($295|0))&-1;
   $297 = ($4|0)<($2|0);
   $298 = ((($0)) + 20|0);
   $299 = HEAP32[$298>>2]|0;
   $300 = ($10|0)!=(0);
   if ($297) {
    $305 = Math_imul($296, $4)|0;
    $306 = (($299) + ($305<<2)|0);
    $307 = (($306) + ($3<<2)|0);
    $308 = (($307) + ($296<<2)|0);
    $$1276 = $300 ? $307 : $308;
    $309 = (($2) - ($4))|0;
    $$11211$ph = $$1276;$$sink1392 = $309;
   } else {
    $301 = Math_imul($296, $2)|0;
    $302 = (($299) + ($301<<2)|0);
    $303 = (($302) + ($3<<2)|0);
    $304 = (($4) - ($2))|0;
    $$11211$ph = $303;$$sink1392 = $304;
   }
   $310 = $300&1;
   $311 = (($$sink1392) + ($310))|0;
   $312 = ($311|0)==(0);
   if ($312) {
    return;
   } else {
    $$012091346 = $311;$$112111345 = $$11211$ph;
   }
   while(1) {
    $313 = (($$012091346) + -1)|0;
    $314 = HEAP32[$$112111345>>2]|0;
    $315 = $314 >>> 16;
    $316 = $315 & 255;
    $317 = $314 >>> 8;
    $318 = $317 & 255;
    $319 = $314 & 255;
    $320 = $314 & -16777216;
    $321 = Math_imul($316, $$0)|0;
    $322 = (($321>>>0) / 255)&-1;
    $323 = Math_imul($318, $$01124)|0;
    $324 = (($323>>>0) / 255)&-1;
    $325 = Math_imul($319, $$01125)|0;
    $326 = (($325>>>0) / 255)&-1;
    $327 = $322 << 16;
    $328 = $324 << 8;
    $329 = $326 | $320;
    $330 = $329 | $327;
    $331 = $330 | $328;
    HEAP32[$$112111345>>2] = $331;
    $332 = (($$112111345) + ($296<<2)|0);
    $333 = ($313|0)==(0);
    if ($333) {
     break;
    } else {
     $$012091346 = $313;$$112111345 = $332;
    }
   }
   return;
   break;
  }
  default: {
   $334 = ((($0)) + 16|0);
   $335 = HEAP32[$334>>2]|0;
   $336 = ((($0)) + 4|0);
   $337 = HEAP32[$336>>2]|0;
   $338 = ((($337)) + 9|0);
   $339 = HEAP8[$338>>0]|0;
   $340 = $339&255;
   $341 = (($335|0) / ($340|0))&-1;
   $342 = ($4|0)<($2|0);
   $343 = ((($0)) + 20|0);
   $344 = HEAP32[$343>>2]|0;
   $345 = ($10|0)!=(0);
   if ($342) {
    $350 = Math_imul($341, $4)|0;
    $351 = (($344) + ($350<<2)|0);
    $352 = (($351) + ($3<<2)|0);
    $353 = (($352) + ($341<<2)|0);
    $$1277 = $345 ? $352 : $353;
    $354 = (($2) - ($4))|0;
    $$11215$ph = $$1277;$$sink1394 = $354;
   } else {
    $346 = Math_imul($341, $2)|0;
    $347 = (($344) + ($346<<2)|0);
    $348 = (($347) + ($3<<2)|0);
    $349 = (($4) - ($2))|0;
    $$11215$ph = $348;$$sink1394 = $349;
   }
   $355 = $345&1;
   $356 = (($$sink1394) + ($355))|0;
   $357 = ($356|0)==(0);
   if ($357) {
    return;
   }
   $358 = $14 << 24;
   $359 = $$0 << 16;
   $360 = $$01124 << 8;
   $361 = $$01125 | $358;
   $362 = $361 | $360;
   $363 = $362 | $359;
   $$012131337 = $356;$$112151336 = $$11215$ph;
   while(1) {
    $364 = (($$012131337) + -1)|0;
    HEAP32[$$112151336>>2] = $363;
    $365 = (($$112151336) + ($341<<2)|0);
    $366 = ($364|0)==(0);
    if ($366) {
     break;
    } else {
     $$012131337 = $364;$$112151336 = $365;
    }
   }
   return;
  }
  }
 }
 $367 = (($1) - ($3))|0;
 $368 = ($367|0)<(0);
 $369 = (0 - ($367))|0;
 $370 = $368 ? $369 : $367;
 $371 = (($2) - ($4))|0;
 $372 = ($371|0)<(0);
 $373 = (0 - ($371))|0;
 $374 = $372 ? $373 : $371;
 $375 = ($370|0)==($374|0);
 if ($375) {
  switch ($5|0) {
  case 1:  {
   $376 = ((($0)) + 16|0);
   $377 = HEAP32[$376>>2]|0;
   $378 = ((($0)) + 4|0);
   $379 = HEAP32[$378>>2]|0;
   $380 = ((($379)) + 9|0);
   $381 = HEAP8[$380>>0]|0;
   $382 = $381&255;
   $383 = (($377|0) / ($382|0))&-1;
   $384 = ($4|0)<($2|0);
   $385 = ((($0)) + 20|0);
   $386 = HEAP32[$385>>2]|0;
   if ($384) {
    $393 = Math_imul($383, $4)|0;
    $394 = (($386) + ($393<<2)|0);
    $395 = (($394) + ($3<<2)|0);
    $396 = ($3|0)>($1|0);
    $$sink1278 = $396 ? -1 : 1;
    $397 = (($383) + ($$sink1278))|0;
    $398 = ($10|0)==(0);
    $399 = (($395) + ($397<<2)|0);
    $$1279 = $398 ? $399 : $395;
    $$01235 = $371;$$11242 = $$1279;$$21239 = $397;
   } else {
    $387 = Math_imul($383, $2)|0;
    $388 = (($386) + ($387<<2)|0);
    $389 = (($388) + ($1<<2)|0);
    $390 = ($3|0)<($1|0);
    $$sink = $390 ? -1 : 1;
    $391 = (($383) + ($$sink))|0;
    $392 = (($4) - ($2))|0;
    $$01235 = $392;$$11242 = $389;$$21239 = $391;
   }
   $not$1298 = ($10|0)!=(0);
   $400 = $not$1298&1;
   $$01235$ = (($$01235) + ($400))|0;
   $401 = ($$01235$|0)==(0);
   if ($401) {
    return;
   } else {
    $$112361352 = $$01235$;$$212431351 = $$11242;
   }
   while(1) {
    $402 = (($$112361352) + -1)|0;
    $403 = HEAP32[$$212431351>>2]|0;
    $404 = $403 >>> 16;
    $405 = $404 & 255;
    $406 = $403 >>> 8;
    $407 = $406 & 255;
    $408 = $403 & 255;
    $409 = $403 >>> 24;
    $410 = Math_imul($405, $22)|0;
    $411 = (($410>>>0) / 255)&-1;
    $412 = (($411) + ($$0))|0;
    $413 = Math_imul($407, $22)|0;
    $414 = (($413>>>0) / 255)&-1;
    $415 = (($414) + ($$01124))|0;
    $416 = Math_imul($408, $22)|0;
    $417 = (($416>>>0) / 255)&-1;
    $418 = (($417) + ($$01125))|0;
    $419 = Math_imul($409, $22)|0;
    $420 = (($419>>>0) / 255)&-1;
    $421 = (($420) + ($14))|0;
    $422 = $421 << 24;
    $423 = $412 << 16;
    $424 = $415 << 8;
    $425 = $422 | $418;
    $426 = $425 | $423;
    $427 = $426 | $424;
    HEAP32[$$212431351>>2] = $427;
    $428 = (($$212431351) + ($$21239<<2)|0);
    $429 = ($402|0)==(0);
    if ($429) {
     break;
    } else {
     $$112361352 = $402;$$212431351 = $428;
    }
   }
   return;
   break;
  }
  case 2:  {
   $430 = ((($0)) + 16|0);
   $431 = HEAP32[$430>>2]|0;
   $432 = ((($0)) + 4|0);
   $433 = HEAP32[$432>>2]|0;
   $434 = ((($433)) + 9|0);
   $435 = HEAP8[$434>>0]|0;
   $436 = $435&255;
   $437 = (($431|0) / ($436|0))&-1;
   $438 = ($4|0)<($2|0);
   $439 = ((($0)) + 20|0);
   $440 = HEAP32[$439>>2]|0;
   if ($438) {
    $447 = Math_imul($437, $4)|0;
    $448 = (($440) + ($447<<2)|0);
    $449 = (($448) + ($3<<2)|0);
    $450 = ($3|0)>($1|0);
    $$sink1281 = $450 ? -1 : 1;
    $451 = (($437) + ($$sink1281))|0;
    $452 = ($10|0)==(0);
    $453 = (($449) + ($451<<2)|0);
    $$1282 = $452 ? $453 : $449;
    $$01244 = $371;$$11250 = $$1282;$$21248 = $451;
   } else {
    $441 = Math_imul($437, $2)|0;
    $442 = (($440) + ($441<<2)|0);
    $443 = (($442) + ($1<<2)|0);
    $444 = ($3|0)<($1|0);
    $$sink1280 = $444 ? -1 : 1;
    $445 = (($437) + ($$sink1280))|0;
    $446 = (($4) - ($2))|0;
    $$01244 = $446;$$11250 = $443;$$21248 = $445;
   }
   $not$1297 = ($10|0)!=(0);
   $454 = $not$1297&1;
   $$01244$ = (($$01244) + ($454))|0;
   $455 = ($$01244$|0)==(0);
   if ($455) {
    return;
   } else {
    $$112451355 = $$01244$;$$212511354 = $$11250;
   }
   while(1) {
    $456 = (($$112451355) + -1)|0;
    $457 = HEAP32[$$212511354>>2]|0;
    $458 = $457 >>> 16;
    $459 = $458 & 255;
    $460 = $457 >>> 8;
    $461 = $460 & 255;
    $462 = $457 & 255;
    $463 = $457 & -16777216;
    $464 = (($459) + ($$0))|0;
    $465 = ($464>>>0)<(255);
    $$5 = $465 ? $464 : 255;
    $466 = (($461) + ($$01124))|0;
    $467 = ($466>>>0)<(255);
    $$10 = $467 ? $466 : 255;
    $468 = (($462) + ($$01125))|0;
    $469 = ($468>>>0)<(255);
    $$6 = $469 ? $468 : 255;
    $470 = $$5 << 16;
    $471 = $$10 << 8;
    $472 = $$6 | $463;
    $473 = $472 | $470;
    $474 = $473 | $471;
    HEAP32[$$212511354>>2] = $474;
    $475 = (($$212511354) + ($$21248<<2)|0);
    $476 = ($456|0)==(0);
    if ($476) {
     break;
    } else {
     $$112451355 = $456;$$212511354 = $475;
    }
   }
   return;
   break;
  }
  case 4:  {
   $477 = ((($0)) + 16|0);
   $478 = HEAP32[$477>>2]|0;
   $479 = ((($0)) + 4|0);
   $480 = HEAP32[$479>>2]|0;
   $481 = ((($480)) + 9|0);
   $482 = HEAP8[$481>>0]|0;
   $483 = $482&255;
   $484 = (($478|0) / ($483|0))&-1;
   $485 = ($4|0)<($2|0);
   $486 = ((($0)) + 20|0);
   $487 = HEAP32[$486>>2]|0;
   if ($485) {
    $494 = Math_imul($484, $4)|0;
    $495 = (($487) + ($494<<2)|0);
    $496 = (($495) + ($3<<2)|0);
    $497 = ($3|0)>($1|0);
    $$sink1284 = $497 ? -1 : 1;
    $498 = (($484) + ($$sink1284))|0;
    $499 = ($10|0)==(0);
    $500 = (($496) + ($498<<2)|0);
    $$1285 = $499 ? $500 : $496;
    $$01262 = $371;$$11268 = $$1285;$$21266 = $498;
   } else {
    $488 = Math_imul($484, $2)|0;
    $489 = (($487) + ($488<<2)|0);
    $490 = (($489) + ($1<<2)|0);
    $491 = ($3|0)<($1|0);
    $$sink1283 = $491 ? -1 : 1;
    $492 = (($484) + ($$sink1283))|0;
    $493 = (($4) - ($2))|0;
    $$01262 = $493;$$11268 = $490;$$21266 = $492;
   }
   $not$1296 = ($10|0)!=(0);
   $501 = $not$1296&1;
   $$01262$ = (($$01262) + ($501))|0;
   $502 = ($$01262$|0)==(0);
   if ($502) {
    return;
   } else {
    $$112631358 = $$01262$;$$212691357 = $$11268;
   }
   while(1) {
    $503 = (($$112631358) + -1)|0;
    $504 = HEAP32[$$212691357>>2]|0;
    $505 = $504 >>> 16;
    $506 = $505 & 255;
    $507 = $504 >>> 8;
    $508 = $507 & 255;
    $509 = $504 & 255;
    $510 = $504 & -16777216;
    $511 = Math_imul($506, $$0)|0;
    $512 = (($511>>>0) / 255)&-1;
    $513 = Math_imul($508, $$01124)|0;
    $514 = (($513>>>0) / 255)&-1;
    $515 = Math_imul($509, $$01125)|0;
    $516 = (($515>>>0) / 255)&-1;
    $517 = $512 << 16;
    $518 = $514 << 8;
    $519 = $516 | $510;
    $520 = $519 | $517;
    $521 = $520 | $518;
    HEAP32[$$212691357>>2] = $521;
    $522 = (($$212691357) + ($$21266<<2)|0);
    $523 = ($503|0)==(0);
    if ($523) {
     break;
    } else {
     $$112631358 = $503;$$212691357 = $522;
    }
   }
   return;
   break;
  }
  default: {
   $524 = ((($0)) + 16|0);
   $525 = HEAP32[$524>>2]|0;
   $526 = ((($0)) + 4|0);
   $527 = HEAP32[$526>>2]|0;
   $528 = ((($527)) + 9|0);
   $529 = HEAP8[$528>>0]|0;
   $530 = $529&255;
   $531 = (($525|0) / ($530|0))&-1;
   $532 = ($4|0)<($2|0);
   $533 = ((($0)) + 20|0);
   $534 = HEAP32[$533>>2]|0;
   if ($532) {
    $541 = Math_imul($531, $4)|0;
    $542 = (($534) + ($541<<2)|0);
    $543 = (($542) + ($3<<2)|0);
    $544 = ($3|0)>($1|0);
    $$sink1287 = $544 ? -1 : 1;
    $545 = (($531) + ($$sink1287))|0;
    $546 = ($10|0)==(0);
    $547 = (($543) + ($545<<2)|0);
    $$1288 = $546 ? $547 : $543;
    $$01258 = $371;$$11253 = $$1288;$$21257 = $545;
   } else {
    $535 = Math_imul($531, $2)|0;
    $536 = (($534) + ($535<<2)|0);
    $537 = (($536) + ($1<<2)|0);
    $538 = ($3|0)<($1|0);
    $$sink1286 = $538 ? -1 : 1;
    $539 = (($531) + ($$sink1286))|0;
    $540 = (($4) - ($2))|0;
    $$01258 = $540;$$11253 = $537;$$21257 = $539;
   }
   $not$1299 = ($10|0)!=(0);
   $548 = $not$1299&1;
   $$01258$ = (($$01258) + ($548))|0;
   $549 = ($$01258$|0)==(0);
   if ($549) {
    return;
   }
   $550 = $14 << 24;
   $551 = $$0 << 16;
   $552 = $$01124 << 8;
   $553 = $$01125 | $550;
   $554 = $553 | $552;
   $555 = $554 | $551;
   $$112591348 = $$01258$;$$212541349 = $$11253;
   while(1) {
    $556 = (($$112591348) + -1)|0;
    HEAP32[$$212541349>>2] = $555;
    $557 = (($$212541349) + ($$21257<<2)|0);
    $558 = ($556|0)==(0);
    if ($558) {
     break;
    } else {
     $$112591348 = $556;$$212541349 = $557;
    }
   }
   return;
  }
  }
 }
 switch ($5|0) {
 case 1:  {
  $559 = (($3) - ($1))|0;
  $560 = ($559|0)<(0);
  $561 = (0 - ($559))|0;
  $562 = $560 ? $561 : $559;
  $563 = (($4) - ($2))|0;
  $564 = ($563|0)<(0);
  $565 = (0 - ($563))|0;
  $566 = $564 ? $565 : $563;
  $567 = ($562|0)<($566|0);
  if ($567) {
   $571 = $562 << 1;
   $572 = (($571) - ($566))|0;
   $573 = (($562) - ($566))|0;
   $$01218 = 1;$$01224 = 0;$$01228$in = $573;$$01229 = $571;$$01230 = $572;$$01233$in = $566;
  } else {
   $568 = $566 << 1;
   $569 = (($568) - ($562))|0;
   $570 = (($566) - ($562))|0;
   $$01218 = 0;$$01224 = 1;$$01228$in = $570;$$01229 = $568;$$01230 = $569;$$01233$in = $562;
  }
  $$01228 = $$01228$in << 1;
  $574 = ($3|0)<($1|0);
  $575 = (0 - ($$01224))|0;
  $$$01224 = $574 ? $575 : $$01224;
  $$1289 = $574 ? -1 : 1;
  $576 = ($4|0)<($2|0);
  $577 = (0 - ($$01218))|0;
  $$11219 = $576 ? $577 : $$01218;
  $$11217 = $576 ? -1 : 1;
  $not$1294 = ($10|0)!=(0);
  $$01233 = $not$1294&1;
  $$01233$in$$01233 = (($$01233$in) + ($$01233))|0;
  $578 = ($$01233$in$$01233|0)>(0);
  if (!($578)) {
   return;
  }
  $579 = ((($0)) + 20|0);
  $580 = HEAP32[$579>>2]|0;
  $581 = ((($0)) + 16|0);
  $$012201368 = $2;$$012261367 = $1;$$012401365 = 0;$$112311366 = $$01230;
  while(1) {
   $582 = HEAP32[$581>>2]|0;
   $583 = Math_imul($582, $$012201368)|0;
   $584 = (($580) + ($583)|0);
   $585 = $$012261367 << 2;
   $586 = (($584) + ($585)|0);
   $587 = HEAP32[$586>>2]|0;
   $588 = $587 >>> 16;
   $589 = $588 & 255;
   $590 = $587 >>> 8;
   $591 = $590 & 255;
   $592 = $587 & 255;
   $593 = $587 >>> 24;
   $594 = Math_imul($589, $22)|0;
   $595 = (($594>>>0) / 255)&-1;
   $596 = (($595) + ($$0))|0;
   $597 = Math_imul($591, $22)|0;
   $598 = (($597>>>0) / 255)&-1;
   $599 = (($598) + ($$01124))|0;
   $600 = Math_imul($592, $22)|0;
   $601 = (($600>>>0) / 255)&-1;
   $602 = (($601) + ($$01125))|0;
   $603 = Math_imul($593, $22)|0;
   $604 = (($603>>>0) / 255)&-1;
   $605 = (($604) + ($14))|0;
   $606 = $605 << 24;
   $607 = $596 << 16;
   $608 = $599 << 8;
   $609 = $606 | $602;
   $610 = $609 | $607;
   $611 = $610 | $608;
   HEAP32[$586>>2] = $611;
   $612 = ($$112311366|0)<(0);
   $$01229$$01228 = $612 ? $$01229 : $$01228;
   $$$01224$$1289 = $612 ? $$$01224 : $$1289;
   $$11219$$11217 = $612 ? $$11219 : $$11217;
   $$11221 = (($$012201368) + ($$11219$$11217))|0;
   $$11227 = (($$$01224$$1289) + ($$012261367))|0;
   $$21232 = (($$01229$$01228) + ($$112311366))|0;
   $613 = (($$012401365) + 1)|0;
   $614 = ($613|0)<($$01233$in$$01233|0);
   if ($614) {
    $$012201368 = $$11221;$$012261367 = $$11227;$$012401365 = $613;$$112311366 = $$21232;
   } else {
    break;
   }
  }
  return;
  break;
 }
 case 2:  {
  $615 = (($3) - ($1))|0;
  $616 = ($615|0)<(0);
  $617 = (0 - ($615))|0;
  $618 = $616 ? $617 : $615;
  $619 = (($4) - ($2))|0;
  $620 = ($619|0)<(0);
  $621 = (0 - ($619))|0;
  $622 = $620 ? $621 : $619;
  $623 = ($618|0)<($622|0);
  if ($623) {
   $627 = $618 << 1;
   $628 = (($627) - ($622))|0;
   $629 = (($618) - ($622))|0;
   $$01188 = 1;$$01194 = 0;$$01198$in = $629;$$01199 = $627;$$01200 = $628;$$01203$in = $622;
  } else {
   $624 = $622 << 1;
   $625 = (($624) - ($618))|0;
   $626 = (($622) - ($618))|0;
   $$01188 = 0;$$01194 = 1;$$01198$in = $626;$$01199 = $624;$$01200 = $625;$$01203$in = $618;
  }
  $$01198 = $$01198$in << 1;
  $630 = ($3|0)<($1|0);
  $631 = (0 - ($$01194))|0;
  $$$01194 = $630 ? $631 : $$01194;
  $$1290 = $630 ? -1 : 1;
  $632 = ($4|0)<($2|0);
  $633 = (0 - ($$01188))|0;
  $$11189 = $632 ? $633 : $$01188;
  $$11187 = $632 ? -1 : 1;
  $not$1293 = ($10|0)!=(0);
  $$01203 = $not$1293&1;
  $$01203$in$$01203 = (($$01203$in) + ($$01203))|0;
  $634 = ($$01203$in$$01203|0)>(0);
  if (!($634)) {
   return;
  }
  $635 = ((($0)) + 20|0);
  $636 = HEAP32[$635>>2]|0;
  $637 = ((($0)) + 16|0);
  $$011901373 = $2;$$011961372 = $1;$$012081370 = 0;$$112011371 = $$01200;
  while(1) {
   $638 = HEAP32[$637>>2]|0;
   $639 = Math_imul($638, $$011901373)|0;
   $640 = (($636) + ($639)|0);
   $641 = $$011961372 << 2;
   $642 = (($640) + ($641)|0);
   $643 = HEAP32[$642>>2]|0;
   $644 = $643 >>> 16;
   $645 = $644 & 255;
   $646 = $643 >>> 8;
   $647 = $646 & 255;
   $648 = $643 & 255;
   $649 = $643 & -16777216;
   $650 = (($645) + ($$0))|0;
   $651 = ($650>>>0)<(255);
   $$11 = $651 ? $650 : 255;
   $652 = (($647) + ($$01124))|0;
   $653 = ($652>>>0)<(255);
   $$7 = $653 ? $652 : 255;
   $654 = (($648) + ($$01125))|0;
   $655 = ($654>>>0)<(255);
   $$12 = $655 ? $654 : 255;
   $656 = $$11 << 16;
   $657 = $$7 << 8;
   $658 = $$12 | $649;
   $659 = $658 | $656;
   $660 = $659 | $657;
   HEAP32[$642>>2] = $660;
   $661 = ($$112011371|0)<(0);
   $$01199$$01198 = $661 ? $$01199 : $$01198;
   $$$01194$$1290 = $661 ? $$$01194 : $$1290;
   $$11189$$11187 = $661 ? $$11189 : $$11187;
   $$11191 = (($$011901373) + ($$11189$$11187))|0;
   $$11197 = (($$$01194$$1290) + ($$011961372))|0;
   $$21202 = (($$01199$$01198) + ($$112011371))|0;
   $662 = (($$012081370) + 1)|0;
   $663 = ($662|0)<($$01203$in$$01203|0);
   if ($663) {
    $$011901373 = $$11191;$$011961372 = $$11197;$$012081370 = $662;$$112011371 = $$21202;
   } else {
    break;
   }
  }
  return;
  break;
 }
 case 4:  {
  $664 = (($3) - ($1))|0;
  $665 = ($664|0)<(0);
  $666 = (0 - ($664))|0;
  $667 = $665 ? $666 : $664;
  $668 = (($4) - ($2))|0;
  $669 = ($668|0)<(0);
  $670 = (0 - ($668))|0;
  $671 = $669 ? $670 : $668;
  $672 = ($667|0)<($671|0);
  if ($672) {
   $676 = $667 << 1;
   $677 = (($676) - ($671))|0;
   $678 = (($667) - ($671))|0;
   $$01159 = 1;$$01165 = 0;$$01169$in = $678;$$01170 = $676;$$01171 = $677;$$01174$in = $671;
  } else {
   $673 = $671 << 1;
   $674 = (($673) - ($667))|0;
   $675 = (($671) - ($667))|0;
   $$01159 = 0;$$01165 = 1;$$01169$in = $675;$$01170 = $673;$$01171 = $674;$$01174$in = $667;
  }
  $$01169 = $$01169$in << 1;
  $679 = ($3|0)<($1|0);
  $680 = (0 - ($$01165))|0;
  $$$01165 = $679 ? $680 : $$01165;
  $$1291 = $679 ? -1 : 1;
  $681 = ($4|0)<($2|0);
  $682 = (0 - ($$01159))|0;
  $$11160 = $681 ? $682 : $$01159;
  $$11158 = $681 ? -1 : 1;
  $not$ = ($10|0)!=(0);
  $$01174 = $not$&1;
  $$01174$in$$01174 = (($$01174$in) + ($$01174))|0;
  $683 = ($$01174$in$$01174|0)>(0);
  if (!($683)) {
   return;
  }
  $684 = ((($0)) + 20|0);
  $685 = HEAP32[$684>>2]|0;
  $686 = ((($0)) + 16|0);
  $$011611378 = $2;$$011671377 = $1;$$011781375 = 0;$$111721376 = $$01171;
  while(1) {
   $687 = HEAP32[$686>>2]|0;
   $688 = Math_imul($687, $$011611378)|0;
   $689 = (($685) + ($688)|0);
   $690 = $$011671377 << 2;
   $691 = (($689) + ($690)|0);
   $692 = HEAP32[$691>>2]|0;
   $693 = $692 >>> 16;
   $694 = $693 & 255;
   $695 = $692 >>> 8;
   $696 = $695 & 255;
   $697 = $692 & 255;
   $698 = $692 & -16777216;
   $699 = Math_imul($694, $$0)|0;
   $700 = (($699>>>0) / 255)&-1;
   $701 = Math_imul($696, $$01124)|0;
   $702 = (($701>>>0) / 255)&-1;
   $703 = Math_imul($697, $$01125)|0;
   $704 = (($703>>>0) / 255)&-1;
   $705 = $700 << 16;
   $706 = $702 << 8;
   $707 = $704 | $698;
   $708 = $707 | $705;
   $709 = $708 | $706;
   HEAP32[$691>>2] = $709;
   $710 = ($$111721376|0)<(0);
   $$01170$$01169 = $710 ? $$01170 : $$01169;
   $$$01165$$1291 = $710 ? $$$01165 : $$1291;
   $$11160$$11158 = $710 ? $$11160 : $$11158;
   $$11162 = (($$011611378) + ($$11160$$11158))|0;
   $$11168 = (($$$01165$$1291) + ($$011671377))|0;
   $$21173 = (($$01170$$01169) + ($$111721376))|0;
   $711 = (($$011781375) + 1)|0;
   $712 = ($711|0)<($$01174$in$$01174|0);
   if ($712) {
    $$011611378 = $$11162;$$011671377 = $$11168;$$011781375 = $711;$$111721376 = $$21173;
   } else {
    break;
   }
  }
  return;
  break;
 }
 default: {
  $713 = (($3) - ($1))|0;
  $714 = ($713|0)<(0);
  $715 = (0 - ($713))|0;
  $716 = $714 ? $715 : $713;
  $717 = (($4) - ($2))|0;
  $718 = ($717|0)<(0);
  $719 = (0 - ($717))|0;
  $720 = $718 ? $719 : $717;
  $721 = ($716|0)<($720|0);
  if ($721) {
   $725 = $716 << 1;
   $726 = (($725) - ($720))|0;
   $727 = (($716) - ($720))|0;
   $$01129 = 1;$$01135 = 0;$$01139$in = $727;$$01140 = $725;$$01141 = $726;$$01144$in = $720;
  } else {
   $722 = $720 << 1;
   $723 = (($722) - ($716))|0;
   $724 = (($720) - ($716))|0;
   $$01129 = 0;$$01135 = 1;$$01139$in = $724;$$01140 = $722;$$01141 = $723;$$01144$in = $716;
  }
  $$01139 = $$01139$in << 1;
  $728 = ($3|0)<($1|0);
  $729 = (0 - ($$01135))|0;
  $$$01135 = $728 ? $729 : $$01135;
  $$1292 = $728 ? -1 : 1;
  $730 = ($4|0)<($2|0);
  $731 = (0 - ($$01129))|0;
  $$11130 = $730 ? $731 : $$01129;
  $$1 = $730 ? -1 : 1;
  $not$1295 = ($10|0)!=(0);
  $$01144 = $not$1295&1;
  $$01144$in$$01144 = (($$01144$in) + ($$01144))|0;
  $732 = ($$01144$in$$01144|0)>(0);
  if (!($732)) {
   return;
  }
  $733 = ((($0)) + 20|0);
  $734 = HEAP32[$733>>2]|0;
  $735 = ((($0)) + 16|0);
  $736 = $14 << 24;
  $737 = $$0 << 16;
  $738 = $$01124 << 8;
  $739 = $$01125 | $736;
  $740 = $739 | $738;
  $741 = $740 | $737;
  $$011311363 = $2;$$011371362 = $1;$$011491360 = 0;$$111421361 = $$01141;
  while(1) {
   $742 = HEAP32[$735>>2]|0;
   $743 = Math_imul($742, $$011311363)|0;
   $744 = (($734) + ($743)|0);
   $745 = $$011371362 << 2;
   $746 = (($744) + ($745)|0);
   HEAP32[$746>>2] = $741;
   $747 = ($$111421361|0)<(0);
   $$01140$$01139 = $747 ? $$01140 : $$01139;
   $$$01135$$1292 = $747 ? $$$01135 : $$1292;
   $$11130$$1 = $747 ? $$11130 : $$1;
   $$11132 = (($$011311363) + ($$11130$$1))|0;
   $$11138 = (($$$01135$$1292) + ($$011371362))|0;
   $$21143 = (($$01140$$01139) + ($$111421361))|0;
   $748 = (($$011491360) + 1)|0;
   $749 = ($748|0)<($$01144$in$$01144|0);
   if ($749) {
    $$011311363 = $$11132;$$011371362 = $$11138;$$011491360 = $748;$$111421361 = $$21143;
   } else {
    break;
   }
  }
  return;
 }
 }
}
function _SDL_BlendLine_RGB888($0,$1,$2,$3,$4,$5,$6,$7,$8,$9,$10) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 $8 = $8|0;
 $9 = $9|0;
 $10 = $10|0;
 var $$ = 0, $$$01107 = 0, $$$01107$$1256 = 0, $$$01138 = 0, $$$01138$$1255 = 0, $$$01168 = 0, $$$01168$$1254 = 0, $$$01206 = 0, $$$01206$$1253 = 0, $$0 = 0, $$01096 = 0, $$01097 = 0, $$010991292 = 0, $$01101 = 0, $$011031327 = 0, $$01107 = 0, $$011091326 = 0, $$01111 = 0, $$01111$in = 0, $$01112 = 0;
 var $$01112$$01111 = 0, $$01113 = 0, $$01116 = 0, $$01116$in = 0, $$01116$in$$01116 = 0, $$011201295 = 0, $$011211324 = 0, $$011241298 = 0, $$011271290 = 0, $$01132 = 0, $$011341342 = 0, $$01138 = 0, $$011401341 = 0, $$01142 = 0, $$01142$in = 0, $$01143 = 0, $$01143$$01142 = 0, $$01144 = 0, $$01147 = 0, $$01147$in = 0;
 var $$01147$in$$01147 = 0, $$011491304 = 0, $$011521339 = 0, $$011531307 = 0, $$011561310 = 0, $$011591301 = 0, $$01162 = 0, $$011641337 = 0, $$01168 = 0, $$011701336 = 0, $$01172 = 0, $$01172$in = 0, $$01173 = 0, $$01173$$01172 = 0, $$01174 = 0, $$01177 = 0, $$01177$in = 0, $$01177$in$$01177 = 0, $$01181 = 0, $$01181$ = 0;
 var $$011831334 = 0, $$01190 = 0, $$01190$ = 0, $$01200 = 0, $$012021332 = 0, $$01206 = 0, $$012081331 = 0, $$01210 = 0, $$01210$in = 0, $$01211 = 0, $$01211$$01210 = 0, $$01212 = 0, $$01215 = 0, $$01215$in = 0, $$01215$in$$01215 = 0, $$01217 = 0, $$01217$ = 0, $$012221329 = 0, $$01226 = 0, $$01226$ = 0;
 var $$1 = 0, $$10 = 0, $$11 = 0, $$11102 = 0, $$11102$$1 = 0, $$11104 = 0, $$11110 = 0, $$111141325 = 0, $$11119$ph = 0, $$111191291 = 0, $$11123$ph = 0, $$111231294 = 0, $$11126$ph = 0, $$111261297 = 0, $$11129$ph = 0, $$111291289 = 0, $$11131 = 0, $$11133 = 0, $$11133$$11131 = 0, $$11135 = 0;
 var $$11141 = 0, $$111451340 = 0, $$11151$ph = 0, $$111511303 = 0, $$11155$ph = 0, $$111551306 = 0, $$11158$ph = 0, $$111581309 = 0, $$11161 = 0, $$11163 = 0, $$11163$$11161 = 0, $$11165 = 0, $$11171 = 0, $$111751335 = 0, $$11180$ph = 0, $$111801300 = 0, $$111821316 = 0, $$11188 = 0, $$111911319 = 0, $$11196 = 0;
 var $$11199 = 0, $$11201 = 0, $$11201$$11199 = 0, $$11203 = 0, $$11209 = 0, $$112131330 = 0, $$112181322 = 0, $$11224 = 0, $$112271313 = 0, $$11232 = 0, $$12 = 0, $$1234 = 0, $$1235 = 0, $$1236 = 0, $$1237 = 0, $$1238 = 0, $$1239 = 0, $$1240 = 0, $$1241 = 0, $$1243 = 0;
 var $$1246 = 0, $$1249 = 0, $$1252 = 0, $$1253 = 0, $$1254 = 0, $$1255 = 0, $$1256 = 0, $$2 = 0, $$21115 = 0, $$21146 = 0, $$21176 = 0, $$21186 = 0, $$211891315 = 0, $$21194 = 0, $$211971318 = 0, $$21214 = 0, $$21221 = 0, $$212251321 = 0, $$21230 = 0, $$212331312 = 0;
 var $$3 = 0, $$4 = 0, $$5 = 0, $$6 = 0, $$7 = 0, $$8 = 0, $$9 = 0, $$off = 0, $$sink = 0, $$sink1242 = 0, $$sink1244 = 0, $$sink1245 = 0, $$sink1247 = 0, $$sink1248 = 0, $$sink1250 = 0, $$sink1251 = 0, $$sink1344 = 0, $$sink1346 = 0, $$sink1348 = 0, $$sink1350 = 0;
 var $$sink1352 = 0, $$sink1354 = 0, $$sink1356 = 0, $$sink1358 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0;
 var $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0;
 var $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0;
 var $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0;
 var $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0;
 var $297 = 0, $298 = 0, $299 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0;
 var $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0;
 var $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0;
 var $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0;
 var $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0;
 var $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0;
 var $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0;
 var $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0;
 var $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0;
 var $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0;
 var $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0;
 var $497 = 0, $498 = 0, $499 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0;
 var $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0;
 var $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0;
 var $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0;
 var $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0;
 var $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0;
 var $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0;
 var $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0;
 var $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0;
 var $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0;
 var $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0;
 var $697 = 0, $698 = 0, $699 = 0, $70 = 0, $700 = 0, $701 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $not$ = 0, $not$1257 = 0, $not$1258 = 0, $not$1259 = 0, $not$1260 = 0;
 var $not$1261 = 0, $not$1262 = 0, $not$1263 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$off = (($5) + -1)|0;
 $11 = ($$off>>>0)<(2);
 $12 = $6&255;
 $13 = $7&255;
 $14 = $9&255;
 $15 = $8&255;
 if ($11) {
  $16 = Math_imul($14, $15)|0;
  $17 = Math_imul($14, $13)|0;
  $18 = Math_imul($14, $12)|0;
  $19 = (($18>>>0) / 255)&-1;
  $20 = (($17>>>0) / 255)&-1;
  $21 = (($16>>>0) / 255)&-1;
  $$0 = $19;$$01096 = $20;$$01097 = $21;
 } else {
  $$0 = $12;$$01096 = $13;$$01097 = $15;
 }
 $22 = $14 ^ 255;
 $23 = ($4|0)==($2|0);
 if ($23) {
  switch ($5|0) {
  case 1:  {
   $24 = ((($0)) + 16|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = ((($0)) + 4|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = ((($27)) + 9|0);
   $29 = HEAP8[$28>>0]|0;
   $30 = $29&255;
   $31 = (($25|0) / ($30|0))&-1;
   $32 = ($3|0)<($1|0);
   $33 = ((($0)) + 20|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = Math_imul($31, $4)|0;
   $36 = (($34) + ($35<<2)|0);
   $37 = ($10|0)!=(0);
   if ($32) {
    $40 = (($36) + ($3<<2)|0);
    $41 = ((($40)) + 4|0);
    $$1234 = $37 ? $40 : $41;
    $42 = (($1) - ($3))|0;
    $$11119$ph = $$1234;$$sink1344 = $42;
   } else {
    $38 = (($36) + ($1<<2)|0);
    $39 = (($3) - ($1))|0;
    $$11119$ph = $38;$$sink1344 = $39;
   }
   $43 = $37&1;
   $44 = (($$sink1344) + ($43))|0;
   $45 = ($44|0)==(0);
   if ($45) {
    return;
   } else {
    $$010991292 = $44;$$111191291 = $$11119$ph;
   }
   while(1) {
    $46 = (($$010991292) + -1)|0;
    $47 = HEAP32[$$111191291>>2]|0;
    $48 = $47 >>> 16;
    $49 = $48 & 255;
    $50 = $47 >>> 8;
    $51 = $50 & 255;
    $52 = $47 & 255;
    $53 = Math_imul($49, $22)|0;
    $54 = (($53>>>0) / 255)&-1;
    $55 = (($54) + ($$0))|0;
    $56 = Math_imul($51, $22)|0;
    $57 = (($56>>>0) / 255)&-1;
    $58 = (($57) + ($$01096))|0;
    $59 = Math_imul($52, $22)|0;
    $60 = (($59>>>0) / 255)&-1;
    $61 = (($60) + ($$01097))|0;
    $62 = $55 << 16;
    $63 = $58 << 8;
    $64 = $63 | $61;
    $65 = $64 | $62;
    HEAP32[$$111191291>>2] = $65;
    $66 = ((($$111191291)) + 4|0);
    $67 = ($46|0)==(0);
    if ($67) {
     break;
    } else {
     $$010991292 = $46;$$111191291 = $66;
    }
   }
   return;
   break;
  }
  case 2:  {
   $68 = ((($0)) + 16|0);
   $69 = HEAP32[$68>>2]|0;
   $70 = ((($0)) + 4|0);
   $71 = HEAP32[$70>>2]|0;
   $72 = ((($71)) + 9|0);
   $73 = HEAP8[$72>>0]|0;
   $74 = $73&255;
   $75 = (($69|0) / ($74|0))&-1;
   $76 = ($3|0)<($1|0);
   $77 = ((($0)) + 20|0);
   $78 = HEAP32[$77>>2]|0;
   $79 = Math_imul($75, $4)|0;
   $80 = (($78) + ($79<<2)|0);
   $81 = ($10|0)!=(0);
   if ($76) {
    $84 = (($80) + ($3<<2)|0);
    $85 = ((($84)) + 4|0);
    $$1235 = $81 ? $84 : $85;
    $86 = (($1) - ($3))|0;
    $$11123$ph = $$1235;$$sink1346 = $86;
   } else {
    $82 = (($80) + ($1<<2)|0);
    $83 = (($3) - ($1))|0;
    $$11123$ph = $82;$$sink1346 = $83;
   }
   $87 = $81&1;
   $88 = (($$sink1346) + ($87))|0;
   $89 = ($88|0)==(0);
   if ($89) {
    return;
   } else {
    $$011201295 = $88;$$111231294 = $$11123$ph;
   }
   while(1) {
    $90 = (($$011201295) + -1)|0;
    $91 = HEAP32[$$111231294>>2]|0;
    $92 = $91 >>> 16;
    $93 = $92 & 255;
    $94 = $91 >>> 8;
    $95 = $94 & 255;
    $96 = $91 & 255;
    $97 = (($93) + ($$0))|0;
    $98 = ($97>>>0)<(255);
    $$ = $98 ? $97 : 255;
    $99 = (($95) + ($$01096))|0;
    $100 = ($99>>>0)<(255);
    $$8 = $100 ? $99 : 255;
    $101 = (($96) + ($$01097))|0;
    $102 = ($101>>>0)<(255);
    $$2 = $102 ? $101 : 255;
    $103 = $$ << 16;
    $104 = $$8 << 8;
    $105 = $104 | $$2;
    $106 = $105 | $103;
    HEAP32[$$111231294>>2] = $106;
    $107 = ((($$111231294)) + 4|0);
    $108 = ($90|0)==(0);
    if ($108) {
     break;
    } else {
     $$011201295 = $90;$$111231294 = $107;
    }
   }
   return;
   break;
  }
  case 4:  {
   $109 = ((($0)) + 16|0);
   $110 = HEAP32[$109>>2]|0;
   $111 = ((($0)) + 4|0);
   $112 = HEAP32[$111>>2]|0;
   $113 = ((($112)) + 9|0);
   $114 = HEAP8[$113>>0]|0;
   $115 = $114&255;
   $116 = (($110|0) / ($115|0))&-1;
   $117 = ($3|0)<($1|0);
   $118 = ((($0)) + 20|0);
   $119 = HEAP32[$118>>2]|0;
   $120 = Math_imul($116, $4)|0;
   $121 = (($119) + ($120<<2)|0);
   $122 = ($10|0)!=(0);
   if ($117) {
    $125 = (($121) + ($3<<2)|0);
    $126 = ((($125)) + 4|0);
    $$1236 = $122 ? $125 : $126;
    $127 = (($1) - ($3))|0;
    $$11126$ph = $$1236;$$sink1348 = $127;
   } else {
    $123 = (($121) + ($1<<2)|0);
    $124 = (($3) - ($1))|0;
    $$11126$ph = $123;$$sink1348 = $124;
   }
   $128 = $122&1;
   $129 = (($$sink1348) + ($128))|0;
   $130 = ($129|0)==(0);
   if ($130) {
    return;
   } else {
    $$011241298 = $129;$$111261297 = $$11126$ph;
   }
   while(1) {
    $131 = (($$011241298) + -1)|0;
    $132 = HEAP32[$$111261297>>2]|0;
    $133 = $132 >>> 16;
    $134 = $133 & 255;
    $135 = $132 >>> 8;
    $136 = $135 & 255;
    $137 = $132 & 255;
    $138 = Math_imul($134, $$0)|0;
    $139 = (($138>>>0) / 255)&-1;
    $140 = Math_imul($136, $$01096)|0;
    $141 = (($140>>>0) / 255)&-1;
    $142 = Math_imul($137, $$01097)|0;
    $143 = (($142>>>0) / 255)&-1;
    $144 = $139 << 16;
    $145 = $141 << 8;
    $146 = $145 | $143;
    $147 = $146 | $144;
    HEAP32[$$111261297>>2] = $147;
    $148 = ((($$111261297)) + 4|0);
    $149 = ($131|0)==(0);
    if ($149) {
     break;
    } else {
     $$011241298 = $131;$$111261297 = $148;
    }
   }
   return;
   break;
  }
  default: {
   $150 = ((($0)) + 16|0);
   $151 = HEAP32[$150>>2]|0;
   $152 = ((($0)) + 4|0);
   $153 = HEAP32[$152>>2]|0;
   $154 = ((($153)) + 9|0);
   $155 = HEAP8[$154>>0]|0;
   $156 = $155&255;
   $157 = (($151|0) / ($156|0))&-1;
   $158 = ($3|0)<($1|0);
   $159 = ((($0)) + 20|0);
   $160 = HEAP32[$159>>2]|0;
   $161 = Math_imul($157, $4)|0;
   $162 = (($160) + ($161<<2)|0);
   $163 = ($10|0)!=(0);
   if ($158) {
    $166 = (($162) + ($3<<2)|0);
    $167 = ((($166)) + 4|0);
    $$1237 = $163 ? $166 : $167;
    $168 = (($1) - ($3))|0;
    $$11129$ph = $$1237;$$sink1350 = $168;
   } else {
    $164 = (($162) + ($1<<2)|0);
    $165 = (($3) - ($1))|0;
    $$11129$ph = $164;$$sink1350 = $165;
   }
   $169 = $163&1;
   $170 = (($$sink1350) + ($169))|0;
   $171 = ($170|0)==(0);
   if ($171) {
    return;
   }
   $172 = $$0 << 16;
   $173 = $$01096 << 8;
   $174 = $173 | $$01097;
   $175 = $174 | $172;
   $$011271290 = $170;$$111291289 = $$11129$ph;
   while(1) {
    $176 = (($$011271290) + -1)|0;
    HEAP32[$$111291289>>2] = $175;
    $177 = ((($$111291289)) + 4|0);
    $178 = ($176|0)==(0);
    if ($178) {
     break;
    } else {
     $$011271290 = $176;$$111291289 = $177;
    }
   }
   return;
  }
  }
 }
 $179 = ($3|0)==($1|0);
 if ($179) {
  switch ($5|0) {
  case 1:  {
   $180 = ((($0)) + 16|0);
   $181 = HEAP32[$180>>2]|0;
   $182 = ((($0)) + 4|0);
   $183 = HEAP32[$182>>2]|0;
   $184 = ((($183)) + 9|0);
   $185 = HEAP8[$184>>0]|0;
   $186 = $185&255;
   $187 = (($181|0) / ($186|0))&-1;
   $188 = ($4|0)<($2|0);
   $189 = ((($0)) + 20|0);
   $190 = HEAP32[$189>>2]|0;
   $191 = ($10|0)!=(0);
   if ($188) {
    $196 = Math_imul($187, $4)|0;
    $197 = (($190) + ($196<<2)|0);
    $198 = (($197) + ($3<<2)|0);
    $199 = (($198) + ($187<<2)|0);
    $$1238 = $191 ? $198 : $199;
    $200 = (($2) - ($4))|0;
    $$11151$ph = $$1238;$$sink1352 = $200;
   } else {
    $192 = Math_imul($187, $2)|0;
    $193 = (($190) + ($192<<2)|0);
    $194 = (($193) + ($3<<2)|0);
    $195 = (($4) - ($2))|0;
    $$11151$ph = $194;$$sink1352 = $195;
   }
   $201 = $191&1;
   $202 = (($$sink1352) + ($201))|0;
   $203 = ($202|0)==(0);
   if ($203) {
    return;
   } else {
    $$011491304 = $202;$$111511303 = $$11151$ph;
   }
   while(1) {
    $204 = (($$011491304) + -1)|0;
    $205 = HEAP32[$$111511303>>2]|0;
    $206 = $205 >>> 16;
    $207 = $206 & 255;
    $208 = $205 >>> 8;
    $209 = $208 & 255;
    $210 = $205 & 255;
    $211 = Math_imul($207, $22)|0;
    $212 = (($211>>>0) / 255)&-1;
    $213 = (($212) + ($$0))|0;
    $214 = Math_imul($209, $22)|0;
    $215 = (($214>>>0) / 255)&-1;
    $216 = (($215) + ($$01096))|0;
    $217 = Math_imul($210, $22)|0;
    $218 = (($217>>>0) / 255)&-1;
    $219 = (($218) + ($$01097))|0;
    $220 = $213 << 16;
    $221 = $216 << 8;
    $222 = $221 | $219;
    $223 = $222 | $220;
    HEAP32[$$111511303>>2] = $223;
    $224 = (($$111511303) + ($187<<2)|0);
    $225 = ($204|0)==(0);
    if ($225) {
     break;
    } else {
     $$011491304 = $204;$$111511303 = $224;
    }
   }
   return;
   break;
  }
  case 2:  {
   $226 = ((($0)) + 16|0);
   $227 = HEAP32[$226>>2]|0;
   $228 = ((($0)) + 4|0);
   $229 = HEAP32[$228>>2]|0;
   $230 = ((($229)) + 9|0);
   $231 = HEAP8[$230>>0]|0;
   $232 = $231&255;
   $233 = (($227|0) / ($232|0))&-1;
   $234 = ($4|0)<($2|0);
   $235 = ((($0)) + 20|0);
   $236 = HEAP32[$235>>2]|0;
   $237 = ($10|0)!=(0);
   if ($234) {
    $242 = Math_imul($233, $4)|0;
    $243 = (($236) + ($242<<2)|0);
    $244 = (($243) + ($3<<2)|0);
    $245 = (($244) + ($233<<2)|0);
    $$1239 = $237 ? $244 : $245;
    $246 = (($2) - ($4))|0;
    $$11155$ph = $$1239;$$sink1354 = $246;
   } else {
    $238 = Math_imul($233, $2)|0;
    $239 = (($236) + ($238<<2)|0);
    $240 = (($239) + ($3<<2)|0);
    $241 = (($4) - ($2))|0;
    $$11155$ph = $240;$$sink1354 = $241;
   }
   $247 = $237&1;
   $248 = (($$sink1354) + ($247))|0;
   $249 = ($248|0)==(0);
   if ($249) {
    return;
   } else {
    $$011531307 = $248;$$111551306 = $$11155$ph;
   }
   while(1) {
    $250 = (($$011531307) + -1)|0;
    $251 = HEAP32[$$111551306>>2]|0;
    $252 = $251 >>> 16;
    $253 = $252 & 255;
    $254 = $251 >>> 8;
    $255 = $254 & 255;
    $256 = $251 & 255;
    $257 = (($253) + ($$0))|0;
    $258 = ($257>>>0)<(255);
    $$3 = $258 ? $257 : 255;
    $259 = (($255) + ($$01096))|0;
    $260 = ($259>>>0)<(255);
    $$9 = $260 ? $259 : 255;
    $261 = (($256) + ($$01097))|0;
    $262 = ($261>>>0)<(255);
    $$4 = $262 ? $261 : 255;
    $263 = $$3 << 16;
    $264 = $$9 << 8;
    $265 = $264 | $$4;
    $266 = $265 | $263;
    HEAP32[$$111551306>>2] = $266;
    $267 = (($$111551306) + ($233<<2)|0);
    $268 = ($250|0)==(0);
    if ($268) {
     break;
    } else {
     $$011531307 = $250;$$111551306 = $267;
    }
   }
   return;
   break;
  }
  case 4:  {
   $269 = ((($0)) + 16|0);
   $270 = HEAP32[$269>>2]|0;
   $271 = ((($0)) + 4|0);
   $272 = HEAP32[$271>>2]|0;
   $273 = ((($272)) + 9|0);
   $274 = HEAP8[$273>>0]|0;
   $275 = $274&255;
   $276 = (($270|0) / ($275|0))&-1;
   $277 = ($4|0)<($2|0);
   $278 = ((($0)) + 20|0);
   $279 = HEAP32[$278>>2]|0;
   $280 = ($10|0)!=(0);
   if ($277) {
    $285 = Math_imul($276, $4)|0;
    $286 = (($279) + ($285<<2)|0);
    $287 = (($286) + ($3<<2)|0);
    $288 = (($287) + ($276<<2)|0);
    $$1240 = $280 ? $287 : $288;
    $289 = (($2) - ($4))|0;
    $$11158$ph = $$1240;$$sink1356 = $289;
   } else {
    $281 = Math_imul($276, $2)|0;
    $282 = (($279) + ($281<<2)|0);
    $283 = (($282) + ($3<<2)|0);
    $284 = (($4) - ($2))|0;
    $$11158$ph = $283;$$sink1356 = $284;
   }
   $290 = $280&1;
   $291 = (($$sink1356) + ($290))|0;
   $292 = ($291|0)==(0);
   if ($292) {
    return;
   } else {
    $$011561310 = $291;$$111581309 = $$11158$ph;
   }
   while(1) {
    $293 = (($$011561310) + -1)|0;
    $294 = HEAP32[$$111581309>>2]|0;
    $295 = $294 >>> 16;
    $296 = $295 & 255;
    $297 = $294 >>> 8;
    $298 = $297 & 255;
    $299 = $294 & 255;
    $300 = Math_imul($296, $$0)|0;
    $301 = (($300>>>0) / 255)&-1;
    $302 = Math_imul($298, $$01096)|0;
    $303 = (($302>>>0) / 255)&-1;
    $304 = Math_imul($299, $$01097)|0;
    $305 = (($304>>>0) / 255)&-1;
    $306 = $301 << 16;
    $307 = $303 << 8;
    $308 = $307 | $305;
    $309 = $308 | $306;
    HEAP32[$$111581309>>2] = $309;
    $310 = (($$111581309) + ($276<<2)|0);
    $311 = ($293|0)==(0);
    if ($311) {
     break;
    } else {
     $$011561310 = $293;$$111581309 = $310;
    }
   }
   return;
   break;
  }
  default: {
   $312 = ((($0)) + 16|0);
   $313 = HEAP32[$312>>2]|0;
   $314 = ((($0)) + 4|0);
   $315 = HEAP32[$314>>2]|0;
   $316 = ((($315)) + 9|0);
   $317 = HEAP8[$316>>0]|0;
   $318 = $317&255;
   $319 = (($313|0) / ($318|0))&-1;
   $320 = ($4|0)<($2|0);
   $321 = ((($0)) + 20|0);
   $322 = HEAP32[$321>>2]|0;
   $323 = ($10|0)!=(0);
   if ($320) {
    $328 = Math_imul($319, $4)|0;
    $329 = (($322) + ($328<<2)|0);
    $330 = (($329) + ($3<<2)|0);
    $331 = (($330) + ($319<<2)|0);
    $$1241 = $323 ? $330 : $331;
    $332 = (($2) - ($4))|0;
    $$11180$ph = $$1241;$$sink1358 = $332;
   } else {
    $324 = Math_imul($319, $2)|0;
    $325 = (($322) + ($324<<2)|0);
    $326 = (($325) + ($3<<2)|0);
    $327 = (($4) - ($2))|0;
    $$11180$ph = $326;$$sink1358 = $327;
   }
   $333 = $323&1;
   $334 = (($$sink1358) + ($333))|0;
   $335 = ($334|0)==(0);
   if ($335) {
    return;
   }
   $336 = $$0 << 16;
   $337 = $$01096 << 8;
   $338 = $337 | $$01097;
   $339 = $338 | $336;
   $$011591301 = $334;$$111801300 = $$11180$ph;
   while(1) {
    $340 = (($$011591301) + -1)|0;
    HEAP32[$$111801300>>2] = $339;
    $341 = (($$111801300) + ($319<<2)|0);
    $342 = ($340|0)==(0);
    if ($342) {
     break;
    } else {
     $$011591301 = $340;$$111801300 = $341;
    }
   }
   return;
  }
  }
 }
 $343 = (($1) - ($3))|0;
 $344 = ($343|0)<(0);
 $345 = (0 - ($343))|0;
 $346 = $344 ? $345 : $343;
 $347 = (($2) - ($4))|0;
 $348 = ($347|0)<(0);
 $349 = (0 - ($347))|0;
 $350 = $348 ? $349 : $347;
 $351 = ($346|0)==($350|0);
 if ($351) {
  switch ($5|0) {
  case 1:  {
   $352 = ((($0)) + 16|0);
   $353 = HEAP32[$352>>2]|0;
   $354 = ((($0)) + 4|0);
   $355 = HEAP32[$354>>2]|0;
   $356 = ((($355)) + 9|0);
   $357 = HEAP8[$356>>0]|0;
   $358 = $357&255;
   $359 = (($353|0) / ($358|0))&-1;
   $360 = ($4|0)<($2|0);
   $361 = ((($0)) + 20|0);
   $362 = HEAP32[$361>>2]|0;
   if ($360) {
    $369 = Math_imul($359, $4)|0;
    $370 = (($362) + ($369<<2)|0);
    $371 = (($370) + ($3<<2)|0);
    $372 = ($3|0)>($1|0);
    $$sink1242 = $372 ? -1 : 1;
    $373 = (($359) + ($$sink1242))|0;
    $374 = ($10|0)==(0);
    $375 = (($371) + ($373<<2)|0);
    $$1243 = $374 ? $375 : $371;
    $$01181 = $347;$$11188 = $$1243;$$21186 = $373;
   } else {
    $363 = Math_imul($359, $2)|0;
    $364 = (($362) + ($363<<2)|0);
    $365 = (($364) + ($1<<2)|0);
    $366 = ($3|0)<($1|0);
    $$sink = $366 ? -1 : 1;
    $367 = (($359) + ($$sink))|0;
    $368 = (($4) - ($2))|0;
    $$01181 = $368;$$11188 = $365;$$21186 = $367;
   }
   $not$1262 = ($10|0)!=(0);
   $376 = $not$1262&1;
   $$01181$ = (($$01181) + ($376))|0;
   $377 = ($$01181$|0)==(0);
   if ($377) {
    return;
   } else {
    $$111821316 = $$01181$;$$211891315 = $$11188;
   }
   while(1) {
    $378 = (($$111821316) + -1)|0;
    $379 = HEAP32[$$211891315>>2]|0;
    $380 = $379 >>> 16;
    $381 = $380 & 255;
    $382 = $379 >>> 8;
    $383 = $382 & 255;
    $384 = $379 & 255;
    $385 = Math_imul($381, $22)|0;
    $386 = (($385>>>0) / 255)&-1;
    $387 = (($386) + ($$0))|0;
    $388 = Math_imul($383, $22)|0;
    $389 = (($388>>>0) / 255)&-1;
    $390 = (($389) + ($$01096))|0;
    $391 = Math_imul($384, $22)|0;
    $392 = (($391>>>0) / 255)&-1;
    $393 = (($392) + ($$01097))|0;
    $394 = $387 << 16;
    $395 = $390 << 8;
    $396 = $395 | $393;
    $397 = $396 | $394;
    HEAP32[$$211891315>>2] = $397;
    $398 = (($$211891315) + ($$21186<<2)|0);
    $399 = ($378|0)==(0);
    if ($399) {
     break;
    } else {
     $$111821316 = $378;$$211891315 = $398;
    }
   }
   return;
   break;
  }
  case 2:  {
   $400 = ((($0)) + 16|0);
   $401 = HEAP32[$400>>2]|0;
   $402 = ((($0)) + 4|0);
   $403 = HEAP32[$402>>2]|0;
   $404 = ((($403)) + 9|0);
   $405 = HEAP8[$404>>0]|0;
   $406 = $405&255;
   $407 = (($401|0) / ($406|0))&-1;
   $408 = ($4|0)<($2|0);
   $409 = ((($0)) + 20|0);
   $410 = HEAP32[$409>>2]|0;
   if ($408) {
    $417 = Math_imul($407, $4)|0;
    $418 = (($410) + ($417<<2)|0);
    $419 = (($418) + ($3<<2)|0);
    $420 = ($3|0)>($1|0);
    $$sink1245 = $420 ? -1 : 1;
    $421 = (($407) + ($$sink1245))|0;
    $422 = ($10|0)==(0);
    $423 = (($419) + ($421<<2)|0);
    $$1246 = $422 ? $423 : $419;
    $$01190 = $347;$$11196 = $$1246;$$21194 = $421;
   } else {
    $411 = Math_imul($407, $2)|0;
    $412 = (($410) + ($411<<2)|0);
    $413 = (($412) + ($1<<2)|0);
    $414 = ($3|0)<($1|0);
    $$sink1244 = $414 ? -1 : 1;
    $415 = (($407) + ($$sink1244))|0;
    $416 = (($4) - ($2))|0;
    $$01190 = $416;$$11196 = $413;$$21194 = $415;
   }
   $not$1261 = ($10|0)!=(0);
   $424 = $not$1261&1;
   $$01190$ = (($$01190) + ($424))|0;
   $425 = ($$01190$|0)==(0);
   if ($425) {
    return;
   } else {
    $$111911319 = $$01190$;$$211971318 = $$11196;
   }
   while(1) {
    $426 = (($$111911319) + -1)|0;
    $427 = HEAP32[$$211971318>>2]|0;
    $428 = $427 >>> 16;
    $429 = $428 & 255;
    $430 = $427 >>> 8;
    $431 = $430 & 255;
    $432 = $427 & 255;
    $433 = (($429) + ($$0))|0;
    $434 = ($433>>>0)<(255);
    $$5 = $434 ? $433 : 255;
    $435 = (($431) + ($$01096))|0;
    $436 = ($435>>>0)<(255);
    $$10 = $436 ? $435 : 255;
    $437 = (($432) + ($$01097))|0;
    $438 = ($437>>>0)<(255);
    $$6 = $438 ? $437 : 255;
    $439 = $$5 << 16;
    $440 = $$10 << 8;
    $441 = $440 | $$6;
    $442 = $441 | $439;
    HEAP32[$$211971318>>2] = $442;
    $443 = (($$211971318) + ($$21194<<2)|0);
    $444 = ($426|0)==(0);
    if ($444) {
     break;
    } else {
     $$111911319 = $426;$$211971318 = $443;
    }
   }
   return;
   break;
  }
  case 4:  {
   $445 = ((($0)) + 16|0);
   $446 = HEAP32[$445>>2]|0;
   $447 = ((($0)) + 4|0);
   $448 = HEAP32[$447>>2]|0;
   $449 = ((($448)) + 9|0);
   $450 = HEAP8[$449>>0]|0;
   $451 = $450&255;
   $452 = (($446|0) / ($451|0))&-1;
   $453 = ($4|0)<($2|0);
   $454 = ((($0)) + 20|0);
   $455 = HEAP32[$454>>2]|0;
   if ($453) {
    $462 = Math_imul($452, $4)|0;
    $463 = (($455) + ($462<<2)|0);
    $464 = (($463) + ($3<<2)|0);
    $465 = ($3|0)>($1|0);
    $$sink1248 = $465 ? -1 : 1;
    $466 = (($452) + ($$sink1248))|0;
    $467 = ($10|0)==(0);
    $468 = (($464) + ($466<<2)|0);
    $$1249 = $467 ? $468 : $464;
    $$01217 = $347;$$11224 = $$1249;$$21221 = $466;
   } else {
    $456 = Math_imul($452, $2)|0;
    $457 = (($455) + ($456<<2)|0);
    $458 = (($457) + ($1<<2)|0);
    $459 = ($3|0)<($1|0);
    $$sink1247 = $459 ? -1 : 1;
    $460 = (($452) + ($$sink1247))|0;
    $461 = (($4) - ($2))|0;
    $$01217 = $461;$$11224 = $458;$$21221 = $460;
   }
   $not$1260 = ($10|0)!=(0);
   $469 = $not$1260&1;
   $$01217$ = (($$01217) + ($469))|0;
   $470 = ($$01217$|0)==(0);
   if ($470) {
    return;
   } else {
    $$112181322 = $$01217$;$$212251321 = $$11224;
   }
   while(1) {
    $471 = (($$112181322) + -1)|0;
    $472 = HEAP32[$$212251321>>2]|0;
    $473 = $472 >>> 16;
    $474 = $473 & 255;
    $475 = $472 >>> 8;
    $476 = $475 & 255;
    $477 = $472 & 255;
    $478 = Math_imul($474, $$0)|0;
    $479 = (($478>>>0) / 255)&-1;
    $480 = Math_imul($476, $$01096)|0;
    $481 = (($480>>>0) / 255)&-1;
    $482 = Math_imul($477, $$01097)|0;
    $483 = (($482>>>0) / 255)&-1;
    $484 = $479 << 16;
    $485 = $481 << 8;
    $486 = $485 | $483;
    $487 = $486 | $484;
    HEAP32[$$212251321>>2] = $487;
    $488 = (($$212251321) + ($$21221<<2)|0);
    $489 = ($471|0)==(0);
    if ($489) {
     break;
    } else {
     $$112181322 = $471;$$212251321 = $488;
    }
   }
   return;
   break;
  }
  default: {
   $490 = ((($0)) + 16|0);
   $491 = HEAP32[$490>>2]|0;
   $492 = ((($0)) + 4|0);
   $493 = HEAP32[$492>>2]|0;
   $494 = ((($493)) + 9|0);
   $495 = HEAP8[$494>>0]|0;
   $496 = $495&255;
   $497 = (($491|0) / ($496|0))&-1;
   $498 = ($4|0)<($2|0);
   $499 = ((($0)) + 20|0);
   $500 = HEAP32[$499>>2]|0;
   if ($498) {
    $507 = Math_imul($497, $4)|0;
    $508 = (($500) + ($507<<2)|0);
    $509 = (($508) + ($3<<2)|0);
    $510 = ($3|0)>($1|0);
    $$sink1251 = $510 ? -1 : 1;
    $511 = (($497) + ($$sink1251))|0;
    $512 = ($10|0)==(0);
    $513 = (($509) + ($511<<2)|0);
    $$1252 = $512 ? $513 : $509;
    $$01226 = $347;$$11232 = $$1252;$$21230 = $511;
   } else {
    $501 = Math_imul($497, $2)|0;
    $502 = (($500) + ($501<<2)|0);
    $503 = (($502) + ($1<<2)|0);
    $504 = ($3|0)<($1|0);
    $$sink1250 = $504 ? -1 : 1;
    $505 = (($497) + ($$sink1250))|0;
    $506 = (($4) - ($2))|0;
    $$01226 = $506;$$11232 = $503;$$21230 = $505;
   }
   $not$1263 = ($10|0)!=(0);
   $514 = $not$1263&1;
   $$01226$ = (($$01226) + ($514))|0;
   $515 = ($$01226$|0)==(0);
   if ($515) {
    return;
   }
   $516 = $$0 << 16;
   $517 = $$01096 << 8;
   $518 = $517 | $$01097;
   $519 = $518 | $516;
   $$112271313 = $$01226$;$$212331312 = $$11232;
   while(1) {
    $520 = (($$112271313) + -1)|0;
    HEAP32[$$212331312>>2] = $519;
    $521 = (($$212331312) + ($$21230<<2)|0);
    $522 = ($520|0)==(0);
    if ($522) {
     break;
    } else {
     $$112271313 = $520;$$212331312 = $521;
    }
   }
   return;
  }
  }
 }
 switch ($5|0) {
 case 1:  {
  $523 = (($3) - ($1))|0;
  $524 = ($523|0)<(0);
  $525 = (0 - ($523))|0;
  $526 = $524 ? $525 : $523;
  $527 = (($4) - ($2))|0;
  $528 = ($527|0)<(0);
  $529 = (0 - ($527))|0;
  $530 = $528 ? $529 : $527;
  $531 = ($526|0)<($530|0);
  if ($531) {
   $535 = $526 << 1;
   $536 = (($535) - ($530))|0;
   $537 = (($526) - ($530))|0;
   $$01200 = 1;$$01206 = 0;$$01210$in = $537;$$01211 = $535;$$01212 = $536;$$01215$in = $530;
  } else {
   $532 = $530 << 1;
   $533 = (($532) - ($526))|0;
   $534 = (($530) - ($526))|0;
   $$01200 = 0;$$01206 = 1;$$01210$in = $534;$$01211 = $532;$$01212 = $533;$$01215$in = $526;
  }
  $$01210 = $$01210$in << 1;
  $538 = ($3|0)<($1|0);
  $539 = (0 - ($$01206))|0;
  $$$01206 = $538 ? $539 : $$01206;
  $$1253 = $538 ? -1 : 1;
  $540 = ($4|0)<($2|0);
  $541 = (0 - ($$01200))|0;
  $$11201 = $540 ? $541 : $$01200;
  $$11199 = $540 ? -1 : 1;
  $not$1258 = ($10|0)!=(0);
  $$01215 = $not$1258&1;
  $$01215$in$$01215 = (($$01215$in) + ($$01215))|0;
  $542 = ($$01215$in$$01215|0)>(0);
  if (!($542)) {
   return;
  }
  $543 = ((($0)) + 20|0);
  $544 = HEAP32[$543>>2]|0;
  $545 = ((($0)) + 16|0);
  $$012021332 = $2;$$012081331 = $1;$$012221329 = 0;$$112131330 = $$01212;
  while(1) {
   $546 = HEAP32[$545>>2]|0;
   $547 = Math_imul($546, $$012021332)|0;
   $548 = (($544) + ($547)|0);
   $549 = $$012081331 << 2;
   $550 = (($548) + ($549)|0);
   $551 = HEAP32[$550>>2]|0;
   $552 = $551 >>> 16;
   $553 = $552 & 255;
   $554 = $551 >>> 8;
   $555 = $554 & 255;
   $556 = $551 & 255;
   $557 = Math_imul($553, $22)|0;
   $558 = (($557>>>0) / 255)&-1;
   $559 = (($558) + ($$0))|0;
   $560 = Math_imul($555, $22)|0;
   $561 = (($560>>>0) / 255)&-1;
   $562 = (($561) + ($$01096))|0;
   $563 = Math_imul($556, $22)|0;
   $564 = (($563>>>0) / 255)&-1;
   $565 = (($564) + ($$01097))|0;
   $566 = $559 << 16;
   $567 = $562 << 8;
   $568 = $567 | $565;
   $569 = $568 | $566;
   HEAP32[$550>>2] = $569;
   $570 = ($$112131330|0)<(0);
   $$01211$$01210 = $570 ? $$01211 : $$01210;
   $$$01206$$1253 = $570 ? $$$01206 : $$1253;
   $$11201$$11199 = $570 ? $$11201 : $$11199;
   $$11203 = (($$012021332) + ($$11201$$11199))|0;
   $$11209 = (($$$01206$$1253) + ($$012081331))|0;
   $$21214 = (($$01211$$01210) + ($$112131330))|0;
   $571 = (($$012221329) + 1)|0;
   $572 = ($571|0)<($$01215$in$$01215|0);
   if ($572) {
    $$012021332 = $$11203;$$012081331 = $$11209;$$012221329 = $571;$$112131330 = $$21214;
   } else {
    break;
   }
  }
  return;
  break;
 }
 case 2:  {
  $573 = (($3) - ($1))|0;
  $574 = ($573|0)<(0);
  $575 = (0 - ($573))|0;
  $576 = $574 ? $575 : $573;
  $577 = (($4) - ($2))|0;
  $578 = ($577|0)<(0);
  $579 = (0 - ($577))|0;
  $580 = $578 ? $579 : $577;
  $581 = ($576|0)<($580|0);
  if ($581) {
   $585 = $576 << 1;
   $586 = (($585) - ($580))|0;
   $587 = (($576) - ($580))|0;
   $$01162 = 1;$$01168 = 0;$$01172$in = $587;$$01173 = $585;$$01174 = $586;$$01177$in = $580;
  } else {
   $582 = $580 << 1;
   $583 = (($582) - ($576))|0;
   $584 = (($580) - ($576))|0;
   $$01162 = 0;$$01168 = 1;$$01172$in = $584;$$01173 = $582;$$01174 = $583;$$01177$in = $576;
  }
  $$01172 = $$01172$in << 1;
  $588 = ($3|0)<($1|0);
  $589 = (0 - ($$01168))|0;
  $$$01168 = $588 ? $589 : $$01168;
  $$1254 = $588 ? -1 : 1;
  $590 = ($4|0)<($2|0);
  $591 = (0 - ($$01162))|0;
  $$11163 = $590 ? $591 : $$01162;
  $$11161 = $590 ? -1 : 1;
  $not$1257 = ($10|0)!=(0);
  $$01177 = $not$1257&1;
  $$01177$in$$01177 = (($$01177$in) + ($$01177))|0;
  $592 = ($$01177$in$$01177|0)>(0);
  if (!($592)) {
   return;
  }
  $593 = ((($0)) + 20|0);
  $594 = HEAP32[$593>>2]|0;
  $595 = ((($0)) + 16|0);
  $$011641337 = $2;$$011701336 = $1;$$011831334 = 0;$$111751335 = $$01174;
  while(1) {
   $596 = HEAP32[$595>>2]|0;
   $597 = Math_imul($596, $$011641337)|0;
   $598 = (($594) + ($597)|0);
   $599 = $$011701336 << 2;
   $600 = (($598) + ($599)|0);
   $601 = HEAP32[$600>>2]|0;
   $602 = $601 >>> 16;
   $603 = $602 & 255;
   $604 = $601 >>> 8;
   $605 = $604 & 255;
   $606 = $601 & 255;
   $607 = (($603) + ($$0))|0;
   $608 = ($607>>>0)<(255);
   $$11 = $608 ? $607 : 255;
   $609 = (($605) + ($$01096))|0;
   $610 = ($609>>>0)<(255);
   $$7 = $610 ? $609 : 255;
   $611 = (($606) + ($$01097))|0;
   $612 = ($611>>>0)<(255);
   $$12 = $612 ? $611 : 255;
   $613 = $$11 << 16;
   $614 = $$7 << 8;
   $615 = $614 | $$12;
   $616 = $615 | $613;
   HEAP32[$600>>2] = $616;
   $617 = ($$111751335|0)<(0);
   $$01173$$01172 = $617 ? $$01173 : $$01172;
   $$$01168$$1254 = $617 ? $$$01168 : $$1254;
   $$11163$$11161 = $617 ? $$11163 : $$11161;
   $$11165 = (($$011641337) + ($$11163$$11161))|0;
   $$11171 = (($$$01168$$1254) + ($$011701336))|0;
   $$21176 = (($$01173$$01172) + ($$111751335))|0;
   $618 = (($$011831334) + 1)|0;
   $619 = ($618|0)<($$01177$in$$01177|0);
   if ($619) {
    $$011641337 = $$11165;$$011701336 = $$11171;$$011831334 = $618;$$111751335 = $$21176;
   } else {
    break;
   }
  }
  return;
  break;
 }
 case 4:  {
  $620 = (($3) - ($1))|0;
  $621 = ($620|0)<(0);
  $622 = (0 - ($620))|0;
  $623 = $621 ? $622 : $620;
  $624 = (($4) - ($2))|0;
  $625 = ($624|0)<(0);
  $626 = (0 - ($624))|0;
  $627 = $625 ? $626 : $624;
  $628 = ($623|0)<($627|0);
  if ($628) {
   $632 = $623 << 1;
   $633 = (($632) - ($627))|0;
   $634 = (($623) - ($627))|0;
   $$01132 = 1;$$01138 = 0;$$01142$in = $634;$$01143 = $632;$$01144 = $633;$$01147$in = $627;
  } else {
   $629 = $627 << 1;
   $630 = (($629) - ($623))|0;
   $631 = (($627) - ($623))|0;
   $$01132 = 0;$$01138 = 1;$$01142$in = $631;$$01143 = $629;$$01144 = $630;$$01147$in = $623;
  }
  $$01142 = $$01142$in << 1;
  $635 = ($3|0)<($1|0);
  $636 = (0 - ($$01138))|0;
  $$$01138 = $635 ? $636 : $$01138;
  $$1255 = $635 ? -1 : 1;
  $637 = ($4|0)<($2|0);
  $638 = (0 - ($$01132))|0;
  $$11133 = $637 ? $638 : $$01132;
  $$11131 = $637 ? -1 : 1;
  $not$ = ($10|0)!=(0);
  $$01147 = $not$&1;
  $$01147$in$$01147 = (($$01147$in) + ($$01147))|0;
  $639 = ($$01147$in$$01147|0)>(0);
  if (!($639)) {
   return;
  }
  $640 = ((($0)) + 20|0);
  $641 = HEAP32[$640>>2]|0;
  $642 = ((($0)) + 16|0);
  $$011341342 = $2;$$011401341 = $1;$$011521339 = 0;$$111451340 = $$01144;
  while(1) {
   $643 = HEAP32[$642>>2]|0;
   $644 = Math_imul($643, $$011341342)|0;
   $645 = (($641) + ($644)|0);
   $646 = $$011401341 << 2;
   $647 = (($645) + ($646)|0);
   $648 = HEAP32[$647>>2]|0;
   $649 = $648 >>> 16;
   $650 = $649 & 255;
   $651 = $648 >>> 8;
   $652 = $651 & 255;
   $653 = $648 & 255;
   $654 = Math_imul($650, $$0)|0;
   $655 = (($654>>>0) / 255)&-1;
   $656 = Math_imul($652, $$01096)|0;
   $657 = (($656>>>0) / 255)&-1;
   $658 = Math_imul($653, $$01097)|0;
   $659 = (($658>>>0) / 255)&-1;
   $660 = $655 << 16;
   $661 = $657 << 8;
   $662 = $661 | $659;
   $663 = $662 | $660;
   HEAP32[$647>>2] = $663;
   $664 = ($$111451340|0)<(0);
   $$01143$$01142 = $664 ? $$01143 : $$01142;
   $$$01138$$1255 = $664 ? $$$01138 : $$1255;
   $$11133$$11131 = $664 ? $$11133 : $$11131;
   $$11135 = (($$011341342) + ($$11133$$11131))|0;
   $$11141 = (($$$01138$$1255) + ($$011401341))|0;
   $$21146 = (($$01143$$01142) + ($$111451340))|0;
   $665 = (($$011521339) + 1)|0;
   $666 = ($665|0)<($$01147$in$$01147|0);
   if ($666) {
    $$011341342 = $$11135;$$011401341 = $$11141;$$011521339 = $665;$$111451340 = $$21146;
   } else {
    break;
   }
  }
  return;
  break;
 }
 default: {
  $667 = (($3) - ($1))|0;
  $668 = ($667|0)<(0);
  $669 = (0 - ($667))|0;
  $670 = $668 ? $669 : $667;
  $671 = (($4) - ($2))|0;
  $672 = ($671|0)<(0);
  $673 = (0 - ($671))|0;
  $674 = $672 ? $673 : $671;
  $675 = ($670|0)<($674|0);
  if ($675) {
   $679 = $670 << 1;
   $680 = (($679) - ($674))|0;
   $681 = (($670) - ($674))|0;
   $$01101 = 1;$$01107 = 0;$$01111$in = $681;$$01112 = $679;$$01113 = $680;$$01116$in = $674;
  } else {
   $676 = $674 << 1;
   $677 = (($676) - ($670))|0;
   $678 = (($674) - ($670))|0;
   $$01101 = 0;$$01107 = 1;$$01111$in = $678;$$01112 = $676;$$01113 = $677;$$01116$in = $670;
  }
  $$01111 = $$01111$in << 1;
  $682 = ($3|0)<($1|0);
  $683 = (0 - ($$01107))|0;
  $$$01107 = $682 ? $683 : $$01107;
  $$1256 = $682 ? -1 : 1;
  $684 = ($4|0)<($2|0);
  $685 = (0 - ($$01101))|0;
  $$11102 = $684 ? $685 : $$01101;
  $$1 = $684 ? -1 : 1;
  $not$1259 = ($10|0)!=(0);
  $$01116 = $not$1259&1;
  $$01116$in$$01116 = (($$01116$in) + ($$01116))|0;
  $686 = ($$01116$in$$01116|0)>(0);
  if (!($686)) {
   return;
  }
  $687 = ((($0)) + 20|0);
  $688 = HEAP32[$687>>2]|0;
  $689 = ((($0)) + 16|0);
  $690 = $$0 << 16;
  $691 = $$01096 << 8;
  $692 = $691 | $$01097;
  $693 = $692 | $690;
  $$011031327 = $2;$$011091326 = $1;$$011211324 = 0;$$111141325 = $$01113;
  while(1) {
   $694 = HEAP32[$689>>2]|0;
   $695 = Math_imul($694, $$011031327)|0;
   $696 = (($688) + ($695)|0);
   $697 = $$011091326 << 2;
   $698 = (($696) + ($697)|0);
   HEAP32[$698>>2] = $693;
   $699 = ($$111141325|0)<(0);
   $$01112$$01111 = $699 ? $$01112 : $$01111;
   $$$01107$$1256 = $699 ? $$$01107 : $$1256;
   $$11102$$1 = $699 ? $$11102 : $$1;
   $$11104 = (($$011031327) + ($$11102$$1))|0;
   $$11110 = (($$$01107$$1256) + ($$011091326))|0;
   $$21115 = (($$01112$$01111) + ($$111141325))|0;
   $700 = (($$011211324) + 1)|0;
   $701 = ($700|0)<($$01116$in$$01116|0);
   if ($701) {
    $$011031327 = $$11104;$$011091326 = $$11110;$$011211324 = $700;$$111141325 = $$21115;
   } else {
    break;
   }
  }
  return;
 }
 }
}
function _SDL_BlendLine_RGBA4($0,$1,$2,$3,$4,$5,$6,$7,$8,$9,$10) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 $8 = $8|0;
 $9 = $9|0;
 $10 = $10|0;
 var $$ = 0, $$$01410 = 0, $$$01410$$1567 = 0, $$$01440 = 0, $$$01440$$1566 = 0, $$$01469 = 0, $$$01469$$1565 = 0, $$$01499 = 0, $$$01499$$1564 = 0, $$0 = 0, $$01399 = 0, $$01400 = 0, $$014021603 = 0, $$01404 = 0, $$014061638 = 0, $$01410 = 0, $$014121637 = 0, $$01414 = 0, $$01414$in = 0, $$01415 = 0;
 var $$01415$$01414 = 0, $$01416 = 0, $$01419 = 0, $$01419$in = 0, $$01419$in$$01419 = 0, $$014231606 = 0, $$014241635 = 0, $$014291609 = 0, $$01434 = 0, $$014361653 = 0, $$01440 = 0, $$014421652 = 0, $$01444 = 0, $$01444$in = 0, $$01445 = 0, $$01445$$01444 = 0, $$01446 = 0, $$01449 = 0, $$01449$in = 0, $$01449$in$$01449 = 0;
 var $$014521601 = 0, $$014531650 = 0, $$014571615 = 0, $$014601618 = 0, $$01463 = 0, $$014651648 = 0, $$01469 = 0, $$014711647 = 0, $$01473 = 0, $$01473$in = 0, $$01474 = 0, $$01474$$01473 = 0, $$01475 = 0, $$01478 = 0, $$01478$in = 0, $$01478$in$$01478 = 0, $$014831645 = 0, $$014841621 = 0, $$014881612 = 0, $$01493 = 0;
 var $$014951643 = 0, $$01499 = 0, $$015011642 = 0, $$01503 = 0, $$01503$in = 0, $$01504 = 0, $$01504$$01503 = 0, $$01505 = 0, $$01508 = 0, $$01508$in = 0, $$01508$in$$01508 = 0, $$01510 = 0, $$01510$ = 0, $$015151640 = 0, $$01519 = 0, $$01519$ = 0, $$01533 = 0, $$01533$ = 0, $$01537 = 0, $$01537$ = 0;
 var $$1 = 0, $$10 = 0, $$11 = 0, $$11405 = 0, $$11405$$1 = 0, $$11407 = 0, $$11413 = 0, $$114171636 = 0, $$11422$ph = 0, $$114221602 = 0, $$11427$ph = 0, $$114271605 = 0, $$11431$ph = 0, $$114311608 = 0, $$11433 = 0, $$11435 = 0, $$11435$$11433 = 0, $$11437 = 0, $$11443 = 0, $$114471651 = 0;
 var $$11456$ph = 0, $$114561600 = 0, $$11459$ph = 0, $$114591614 = 0, $$11462 = 0, $$11464 = 0, $$11464$$11462 = 0, $$11466 = 0, $$11472 = 0, $$114761646 = 0, $$11481$ph = 0, $$114811617 = 0, $$11486$ph = 0, $$114861620 = 0, $$11490$ph = 0, $$114901611 = 0, $$11492 = 0, $$11494 = 0, $$11494$$11492 = 0, $$11496 = 0;
 var $$11502 = 0, $$115061641 = 0, $$115111627 = 0, $$11517 = 0, $$115201630 = 0, $$11525 = 0, $$11528 = 0, $$115341623 = 0, $$115381633 = 0, $$11543 = 0, $$12 = 0, $$1545 = 0, $$1546 = 0, $$1547 = 0, $$1548 = 0, $$1549 = 0, $$1550 = 0, $$1551 = 0, $$1552 = 0, $$1554 = 0;
 var $$1557 = 0, $$1560 = 0, $$1563 = 0, $$1564 = 0, $$1565 = 0, $$1566 = 0, $$1567 = 0, $$2 = 0, $$21418 = 0, $$21448 = 0, $$21477 = 0, $$21507 = 0, $$21514 = 0, $$215181626 = 0, $$21523 = 0, $$215261629 = 0, $$215291624 = 0, $$21532 = 0, $$21541 = 0, $$215441632 = 0;
 var $$3 = 0, $$4 = 0, $$5 = 0, $$6 = 0, $$7 = 0, $$8 = 0, $$9 = 0, $$off = 0, $$phi$trans$insert = 0, $$phi$trans$insert1687 = 0, $$phi$trans$insert1691 = 0, $$phi$trans$insert1692 = 0, $$phi$trans$insert1696 = 0, $$phi$trans$insert1697 = 0, $$phi$trans$insert1701 = 0, $$phi$trans$insert1702 = 0, $$phi$trans$insert1707 = 0, $$phi$trans$insert1708 = 0, $$phi$trans$insert1712 = 0, $$phi$trans$insert1713 = 0;
 var $$phi$trans$insert1717 = 0, $$phi$trans$insert1718 = 0, $$phi$trans$insert1722 = 0, $$phi$trans$insert1723 = 0, $$phi$trans$insert1728 = 0, $$phi$trans$insert1729 = 0, $$phi$trans$insert1733 = 0, $$phi$trans$insert1734 = 0, $$phi$trans$insert1738 = 0, $$phi$trans$insert1739 = 0, $$phi$trans$insert1743 = 0, $$phi$trans$insert1744 = 0, $$phi$trans$insert1748 = 0, $$phi$trans$insert1749 = 0, $$phi$trans$insert1753 = 0, $$phi$trans$insert1754 = 0, $$phi$trans$insert1758 = 0, $$phi$trans$insert1759 = 0, $$phi$trans$insert1763 = 0, $$phi$trans$insert1764 = 0;
 var $$phi$trans$insert1768 = 0, $$phi$trans$insert1769 = 0, $$phi$trans$insert1773 = 0, $$phi$trans$insert1774 = 0, $$phi$trans$insert1778 = 0, $$phi$trans$insert1779 = 0, $$phi$trans$insert1783 = 0, $$phi$trans$insert1784 = 0, $$phi$trans$insert1788 = 0, $$phi$trans$insert1789 = 0, $$phi$trans$insert1793 = 0, $$phi$trans$insert1794 = 0, $$phi$trans$insert1798 = 0, $$phi$trans$insert1799 = 0, $$phi$trans$insert1803 = 0, $$phi$trans$insert1804 = 0, $$phi$trans$insert1808 = 0, $$phi$trans$insert1809 = 0, $$phi$trans$insert1813 = 0, $$phi$trans$insert1814 = 0;
 var $$phi$trans$insert1818 = 0, $$phi$trans$insert1819 = 0, $$phi$trans$insert1823 = 0, $$phi$trans$insert1824 = 0, $$phi$trans$insert1828 = 0, $$phi$trans$insert1829 = 0, $$phi$trans$insert1833 = 0, $$phi$trans$insert1834 = 0, $$phi$trans$insert1838 = 0, $$phi$trans$insert1839 = 0, $$phi$trans$insert1843 = 0, $$phi$trans$insert1844 = 0, $$phi$trans$insert1848 = 0, $$phi$trans$insert1849 = 0, $$phi$trans$insert1853 = 0, $$phi$trans$insert1854 = 0, $$phi$trans$insert1858 = 0, $$phi$trans$insert1859 = 0, $$phi$trans$insert1863 = 0, $$phi$trans$insert1864 = 0;
 var $$phi$trans$insert1868 = 0, $$phi$trans$insert1869 = 0, $$phi$trans$insert1873 = 0, $$phi$trans$insert1874 = 0, $$phi$trans$insert1878 = 0, $$phi$trans$insert1879 = 0, $$phi$trans$insert1883 = 0, $$phi$trans$insert1884 = 0, $$phi$trans$insert1888 = 0, $$phi$trans$insert1889 = 0, $$phi$trans$insert1893 = 0, $$phi$trans$insert1894 = 0, $$phi$trans$insert1898 = 0, $$phi$trans$insert1899 = 0, $$phi$trans$insert1903 = 0, $$phi$trans$insert1904 = 0, $$phi$trans$insert1908 = 0, $$phi$trans$insert1909 = 0, $$phi$trans$insert1913 = 0, $$phi$trans$insert1914 = 0;
 var $$phi$trans$insert1918 = 0, $$phi$trans$insert1919 = 0, $$phi$trans$insert1923 = 0, $$phi$trans$insert1924 = 0, $$pre = 0, $$pre1686 = 0, $$pre1688 = 0, $$pre1689 = 0, $$pre1690 = 0, $$pre1693 = 0, $$pre1694 = 0, $$pre1695 = 0, $$pre1698 = 0, $$pre1699 = 0, $$pre1700 = 0, $$pre1703 = 0, $$pre1704 = 0, $$pre1705 = 0, $$pre1706 = 0, $$pre1709 = 0;
 var $$pre1710 = 0, $$pre1711 = 0, $$pre1714 = 0, $$pre1715 = 0, $$pre1716 = 0, $$pre1719 = 0, $$pre1720 = 0, $$pre1721 = 0, $$pre1724 = 0, $$pre1725 = 0, $$pre1726 = 0, $$pre1727 = 0, $$pre1730 = 0, $$pre1731 = 0, $$pre1732 = 0, $$pre1735 = 0, $$pre1736 = 0, $$pre1737 = 0, $$pre1740 = 0, $$pre1741 = 0;
 var $$pre1742 = 0, $$pre1745 = 0, $$pre1746 = 0, $$pre1747 = 0, $$pre1750 = 0, $$pre1751 = 0, $$pre1752 = 0, $$pre1755 = 0, $$pre1756 = 0, $$pre1757 = 0, $$pre1760 = 0, $$pre1761 = 0, $$pre1762 = 0, $$pre1765 = 0, $$pre1766 = 0, $$pre1767 = 0, $$pre1770 = 0, $$pre1771 = 0, $$pre1772 = 0, $$pre1775 = 0;
 var $$pre1776 = 0, $$pre1777 = 0, $$pre1780 = 0, $$pre1781 = 0, $$pre1782 = 0, $$pre1785 = 0, $$pre1786 = 0, $$pre1787 = 0, $$pre1790 = 0, $$pre1791 = 0, $$pre1792 = 0, $$pre1795 = 0, $$pre1796 = 0, $$pre1797 = 0, $$pre1800 = 0, $$pre1801 = 0, $$pre1802 = 0, $$pre1805 = 0, $$pre1806 = 0, $$pre1807 = 0;
 var $$pre1810 = 0, $$pre1811 = 0, $$pre1812 = 0, $$pre1815 = 0, $$pre1816 = 0, $$pre1817 = 0, $$pre1820 = 0, $$pre1821 = 0, $$pre1822 = 0, $$pre1825 = 0, $$pre1826 = 0, $$pre1827 = 0, $$pre1830 = 0, $$pre1831 = 0, $$pre1832 = 0, $$pre1835 = 0, $$pre1836 = 0, $$pre1837 = 0, $$pre1840 = 0, $$pre1841 = 0;
 var $$pre1842 = 0, $$pre1845 = 0, $$pre1846 = 0, $$pre1847 = 0, $$pre1850 = 0, $$pre1851 = 0, $$pre1852 = 0, $$pre1855 = 0, $$pre1856 = 0, $$pre1857 = 0, $$pre1860 = 0, $$pre1861 = 0, $$pre1862 = 0, $$pre1865 = 0, $$pre1866 = 0, $$pre1867 = 0, $$pre1870 = 0, $$pre1871 = 0, $$pre1872 = 0, $$pre1875 = 0;
 var $$pre1876 = 0, $$pre1877 = 0, $$pre1880 = 0, $$pre1881 = 0, $$pre1882 = 0, $$pre1885 = 0, $$pre1886 = 0, $$pre1887 = 0, $$pre1890 = 0, $$pre1891 = 0, $$pre1892 = 0, $$pre1895 = 0, $$pre1896 = 0, $$pre1897 = 0, $$pre1900 = 0, $$pre1901 = 0, $$pre1902 = 0, $$pre1905 = 0, $$pre1906 = 0, $$pre1907 = 0;
 var $$pre1910 = 0, $$pre1911 = 0, $$pre1912 = 0, $$pre1915 = 0, $$pre1916 = 0, $$pre1917 = 0, $$pre1920 = 0, $$pre1921 = 0, $$pre1922 = 0, $$pre1925 = 0, $$pre1926 = 0, $$sink = 0, $$sink1553 = 0, $$sink1555 = 0, $$sink1556 = 0, $$sink1558 = 0, $$sink1559 = 0, $$sink1561 = 0, $$sink1562 = 0, $$sink1655 = 0;
 var $$sink1657 = 0, $$sink1659 = 0, $$sink1661 = 0, $$sink1663 = 0, $$sink1665 = 0, $$sink1667 = 0, $$sink1669 = 0, $100 = 0, $1000 = 0, $1001 = 0, $1002 = 0, $1003 = 0, $1004 = 0, $1005 = 0, $1006 = 0, $1007 = 0, $1008 = 0, $1009 = 0, $101 = 0, $1010 = 0;
 var $1011 = 0, $1012 = 0, $1013 = 0, $1014 = 0, $1015 = 0, $1016 = 0, $1017 = 0, $1018 = 0, $1019 = 0, $102 = 0, $1020 = 0, $1021 = 0, $1022 = 0, $1023 = 0, $1024 = 0, $1025 = 0, $1026 = 0, $1027 = 0, $1028 = 0, $1029 = 0;
 var $103 = 0, $1030 = 0, $1031 = 0, $1032 = 0, $1033 = 0, $1034 = 0, $1035 = 0, $1036 = 0, $1037 = 0, $1038 = 0, $1039 = 0, $104 = 0, $1040 = 0, $1041 = 0, $1042 = 0, $1043 = 0, $1044 = 0, $1045 = 0, $1046 = 0, $1047 = 0;
 var $1048 = 0, $1049 = 0, $105 = 0, $1050 = 0, $1051 = 0, $1052 = 0, $1053 = 0, $1054 = 0, $1055 = 0, $1056 = 0, $1057 = 0, $1058 = 0, $1059 = 0, $106 = 0, $1060 = 0, $1061 = 0, $1062 = 0, $1063 = 0, $1064 = 0, $1065 = 0;
 var $1066 = 0, $1067 = 0, $1068 = 0, $1069 = 0, $107 = 0, $1070 = 0, $1071 = 0, $1072 = 0, $1073 = 0, $1074 = 0, $1075 = 0, $1076 = 0, $1077 = 0, $1078 = 0, $1079 = 0, $108 = 0, $1080 = 0, $1081 = 0, $1082 = 0, $1083 = 0;
 var $1084 = 0, $1085 = 0, $1086 = 0, $1087 = 0, $1088 = 0, $1089 = 0, $109 = 0, $1090 = 0, $1091 = 0, $1092 = 0, $1093 = 0, $1094 = 0, $1095 = 0, $1096 = 0, $1097 = 0, $1098 = 0, $1099 = 0, $11 = 0, $110 = 0, $1100 = 0;
 var $1101 = 0, $1102 = 0, $1103 = 0, $1104 = 0, $1105 = 0, $1106 = 0, $1107 = 0, $1108 = 0, $1109 = 0, $111 = 0, $1110 = 0, $1111 = 0, $1112 = 0, $1113 = 0, $1114 = 0, $1115 = 0, $1116 = 0, $1117 = 0, $1118 = 0, $1119 = 0;
 var $112 = 0, $1120 = 0, $1121 = 0, $1122 = 0, $1123 = 0, $1124 = 0, $1125 = 0, $1126 = 0, $1127 = 0, $1128 = 0, $1129 = 0, $113 = 0, $1130 = 0, $1131 = 0, $1132 = 0, $1133 = 0, $1134 = 0, $1135 = 0, $1136 = 0, $1137 = 0;
 var $1138 = 0, $1139 = 0, $114 = 0, $1140 = 0, $1141 = 0, $1142 = 0, $1143 = 0, $1144 = 0, $1145 = 0, $1146 = 0, $1147 = 0, $1148 = 0, $1149 = 0, $115 = 0, $1150 = 0, $1151 = 0, $1152 = 0, $1153 = 0, $1154 = 0, $1155 = 0;
 var $1156 = 0, $1157 = 0, $1158 = 0, $1159 = 0, $116 = 0, $1160 = 0, $1161 = 0, $1162 = 0, $1163 = 0, $1164 = 0, $1165 = 0, $1166 = 0, $1167 = 0, $1168 = 0, $1169 = 0, $117 = 0, $1170 = 0, $1171 = 0, $1172 = 0, $1173 = 0;
 var $1174 = 0, $1175 = 0, $1176 = 0, $1177 = 0, $1178 = 0, $1179 = 0, $118 = 0, $1180 = 0, $1181 = 0, $1182 = 0, $1183 = 0, $1184 = 0, $1185 = 0, $1186 = 0, $1187 = 0, $1188 = 0, $1189 = 0, $119 = 0, $1190 = 0, $1191 = 0;
 var $1192 = 0, $1193 = 0, $1194 = 0, $1195 = 0, $1196 = 0, $1197 = 0, $1198 = 0, $1199 = 0, $12 = 0, $120 = 0, $1200 = 0, $1201 = 0, $1202 = 0, $1203 = 0, $1204 = 0, $1205 = 0, $1206 = 0, $1207 = 0, $1208 = 0, $1209 = 0;
 var $121 = 0, $1210 = 0, $1211 = 0, $1212 = 0, $1213 = 0, $1214 = 0, $1215 = 0, $1216 = 0, $1217 = 0, $1218 = 0, $1219 = 0, $122 = 0, $1220 = 0, $1221 = 0, $1222 = 0, $1223 = 0, $1224 = 0, $1225 = 0, $1226 = 0, $1227 = 0;
 var $1228 = 0, $1229 = 0, $123 = 0, $1230 = 0, $1231 = 0, $1232 = 0, $1233 = 0, $1234 = 0, $1235 = 0, $1236 = 0, $1237 = 0, $1238 = 0, $1239 = 0, $124 = 0, $1240 = 0, $1241 = 0, $1242 = 0, $1243 = 0, $1244 = 0, $1245 = 0;
 var $1246 = 0, $1247 = 0, $1248 = 0, $1249 = 0, $125 = 0, $1250 = 0, $1251 = 0, $1252 = 0, $1253 = 0, $1254 = 0, $1255 = 0, $1256 = 0, $1257 = 0, $1258 = 0, $1259 = 0, $126 = 0, $1260 = 0, $1261 = 0, $1262 = 0, $1263 = 0;
 var $1264 = 0, $1265 = 0, $1266 = 0, $1267 = 0, $1268 = 0, $1269 = 0, $127 = 0, $1270 = 0, $1271 = 0, $1272 = 0, $1273 = 0, $1274 = 0, $1275 = 0, $1276 = 0, $1277 = 0, $1278 = 0, $1279 = 0, $128 = 0, $1280 = 0, $1281 = 0;
 var $1282 = 0, $1283 = 0, $1284 = 0, $1285 = 0, $1286 = 0, $1287 = 0, $1288 = 0, $1289 = 0, $129 = 0, $1290 = 0, $1291 = 0, $1292 = 0, $1293 = 0, $1294 = 0, $1295 = 0, $1296 = 0, $1297 = 0, $1298 = 0, $1299 = 0, $13 = 0;
 var $130 = 0, $1300 = 0, $1301 = 0, $1302 = 0, $1303 = 0, $1304 = 0, $1305 = 0, $1306 = 0, $1307 = 0, $1308 = 0, $1309 = 0, $131 = 0, $1310 = 0, $1311 = 0, $1312 = 0, $1313 = 0, $1314 = 0, $1315 = 0, $1316 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0;
 var $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0;
 var $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0;
 var $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0;
 var $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0;
 var $297 = 0, $298 = 0, $299 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0;
 var $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0;
 var $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0;
 var $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0;
 var $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0;
 var $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0;
 var $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0;
 var $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0;
 var $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0;
 var $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0;
 var $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0;
 var $497 = 0, $498 = 0, $499 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0;
 var $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0;
 var $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0;
 var $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0;
 var $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0;
 var $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0;
 var $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0;
 var $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0;
 var $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0;
 var $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0;
 var $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0;
 var $697 = 0, $698 = 0, $699 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0;
 var $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0;
 var $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0;
 var $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0;
 var $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0;
 var $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0;
 var $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0, $823 = 0;
 var $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = 0, $834 = 0, $835 = 0, $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = 0, $841 = 0;
 var $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0, $850 = 0, $851 = 0, $852 = 0, $853 = 0, $854 = 0, $855 = 0, $856 = 0, $857 = 0, $858 = 0, $859 = 0, $86 = 0;
 var $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0, $869 = 0, $87 = 0, $870 = 0, $871 = 0, $872 = 0, $873 = 0, $874 = 0, $875 = 0, $876 = 0, $877 = 0, $878 = 0;
 var $879 = 0, $88 = 0, $880 = 0, $881 = 0, $882 = 0, $883 = 0, $884 = 0, $885 = 0, $886 = 0, $887 = 0, $888 = 0, $889 = 0, $89 = 0, $890 = 0, $891 = 0, $892 = 0, $893 = 0, $894 = 0, $895 = 0, $896 = 0;
 var $897 = 0, $898 = 0, $899 = 0, $90 = 0, $900 = 0, $901 = 0, $902 = 0, $903 = 0, $904 = 0, $905 = 0, $906 = 0, $907 = 0, $908 = 0, $909 = 0, $91 = 0, $910 = 0, $911 = 0, $912 = 0, $913 = 0, $914 = 0;
 var $915 = 0, $916 = 0, $917 = 0, $918 = 0, $919 = 0, $92 = 0, $920 = 0, $921 = 0, $922 = 0, $923 = 0, $924 = 0, $925 = 0, $926 = 0, $927 = 0, $928 = 0, $929 = 0, $93 = 0, $930 = 0, $931 = 0, $932 = 0;
 var $933 = 0, $934 = 0, $935 = 0, $936 = 0, $937 = 0, $938 = 0, $939 = 0, $94 = 0, $940 = 0, $941 = 0, $942 = 0, $943 = 0, $944 = 0, $945 = 0, $946 = 0, $947 = 0, $948 = 0, $949 = 0, $95 = 0, $950 = 0;
 var $951 = 0, $952 = 0, $953 = 0, $954 = 0, $955 = 0, $956 = 0, $957 = 0, $958 = 0, $959 = 0, $96 = 0, $960 = 0, $961 = 0, $962 = 0, $963 = 0, $964 = 0, $965 = 0, $966 = 0, $967 = 0, $968 = 0, $969 = 0;
 var $97 = 0, $970 = 0, $971 = 0, $972 = 0, $973 = 0, $974 = 0, $975 = 0, $976 = 0, $977 = 0, $978 = 0, $979 = 0, $98 = 0, $980 = 0, $981 = 0, $982 = 0, $983 = 0, $984 = 0, $985 = 0, $986 = 0, $987 = 0;
 var $988 = 0, $989 = 0, $99 = 0, $990 = 0, $991 = 0, $992 = 0, $993 = 0, $994 = 0, $995 = 0, $996 = 0, $997 = 0, $998 = 0, $999 = 0, $not$ = 0, $not$1568 = 0, $not$1569 = 0, $not$1570 = 0, $not$1571 = 0, $not$1572 = 0, $not$1573 = 0;
 var $not$1574 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $11 = ((($0)) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $$off = (($5) + -1)|0;
 $13 = ($$off>>>0)<(2);
 $14 = $6&255;
 $15 = $7&255;
 $16 = $8&255;
 $17 = $9&255;
 if ($13) {
  $18 = Math_imul($17, $16)|0;
  $19 = Math_imul($17, $15)|0;
  $20 = Math_imul($17, $14)|0;
  $21 = (($20>>>0) / 255)&-1;
  $22 = (($19>>>0) / 255)&-1;
  $23 = (($18>>>0) / 255)&-1;
  $$0 = $21;$$01399 = $22;$$01400 = $23;
 } else {
  $$0 = $14;$$01399 = $15;$$01400 = $16;
 }
 $24 = $17 ^ 255;
 $25 = ($4|0)==($2|0);
 if ($25) {
  switch ($5|0) {
  case 1:  {
   $26 = ((($0)) + 16|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = ((($12)) + 9|0);
   $29 = HEAP8[$28>>0]|0;
   $30 = $29&255;
   $31 = (($27|0) / ($30|0))&-1;
   $32 = ($3|0)<($1|0);
   $33 = ((($0)) + 20|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = Math_imul($31, $4)|0;
   $36 = (($34) + ($35<<2)|0);
   $37 = ($10|0)!=(0);
   if ($32) {
    $40 = (($36) + ($3<<2)|0);
    $41 = ((($40)) + 4|0);
    $$1545 = $37 ? $40 : $41;
    $42 = (($1) - ($3))|0;
    $$11422$ph = $$1545;$$sink1655 = $42;
   } else {
    $38 = (($36) + ($1<<2)|0);
    $39 = (($3) - ($1))|0;
    $$11422$ph = $38;$$sink1655 = $39;
   }
   $43 = $37&1;
   $44 = (($$sink1655) + ($43))|0;
   $45 = ($44|0)==(0);
   if ($45) {
    return;
   }
   $46 = ((($12)) + 28|0);
   $47 = ((($12)) + 12|0);
   $48 = ((($12)) + 32|0);
   $49 = ((($12)) + 29|0);
   $50 = ((($12)) + 16|0);
   $51 = ((($12)) + 33|0);
   $52 = ((($12)) + 30|0);
   $53 = ((($12)) + 20|0);
   $54 = ((($12)) + 34|0);
   $55 = ((($12)) + 31|0);
   $56 = ((($12)) + 24|0);
   $57 = ((($12)) + 35|0);
   $$pre1907 = HEAP8[$46>>0]|0;
   $$phi$trans$insert1908 = $$pre1907&255;
   $$phi$trans$insert1909 = (79212 + ($$phi$trans$insert1908<<2)|0);
   $$pre1910 = HEAP32[$$phi$trans$insert1909>>2]|0;
   $$pre1911 = HEAP8[$48>>0]|0;
   $$pre1912 = HEAP8[$49>>0]|0;
   $$phi$trans$insert1913 = $$pre1912&255;
   $$phi$trans$insert1914 = (79212 + ($$phi$trans$insert1913<<2)|0);
   $$pre1915 = HEAP32[$$phi$trans$insert1914>>2]|0;
   $$pre1916 = HEAP8[$51>>0]|0;
   $$pre1917 = HEAP8[$52>>0]|0;
   $$phi$trans$insert1918 = $$pre1917&255;
   $$phi$trans$insert1919 = (79212 + ($$phi$trans$insert1918<<2)|0);
   $$pre1920 = HEAP32[$$phi$trans$insert1919>>2]|0;
   $$pre1921 = HEAP8[$54>>0]|0;
   $$pre1922 = HEAP8[$55>>0]|0;
   $$phi$trans$insert1923 = $$pre1922&255;
   $$phi$trans$insert1924 = (79212 + ($$phi$trans$insert1923<<2)|0);
   $$pre1925 = HEAP32[$$phi$trans$insert1924>>2]|0;
   $$pre1926 = HEAP8[$57>>0]|0;
   $58 = $$pre1911&255;
   $59 = $$pre1916&255;
   $60 = $$pre1921&255;
   $61 = $$pre1926&255;
   $$014021603 = $44;$$114221602 = $$11422$ph;
   while(1) {
    $62 = (($$014021603) + -1)|0;
    $63 = HEAP32[$$114221602>>2]|0;
    $64 = HEAP32[$47>>2]|0;
    $65 = $64 & $63;
    $66 = $65 >>> $58;
    $67 = (($$pre1910) + ($66)|0);
    $68 = HEAP8[$67>>0]|0;
    $69 = $68&255;
    $70 = HEAP32[$50>>2]|0;
    $71 = $70 & $63;
    $72 = $71 >>> $59;
    $73 = (($$pre1915) + ($72)|0);
    $74 = HEAP8[$73>>0]|0;
    $75 = $74&255;
    $76 = HEAP32[$53>>2]|0;
    $77 = $76 & $63;
    $78 = $77 >>> $60;
    $79 = (($$pre1920) + ($78)|0);
    $80 = HEAP8[$79>>0]|0;
    $81 = $80&255;
    $82 = HEAP32[$56>>2]|0;
    $83 = $82 & $63;
    $84 = $83 >>> $61;
    $85 = (($$pre1925) + ($84)|0);
    $86 = HEAP8[$85>>0]|0;
    $87 = $86&255;
    $88 = Math_imul($69, $24)|0;
    $89 = (($88>>>0) / 255)&-1;
    $90 = (($89) + ($$0))|0;
    $91 = Math_imul($75, $24)|0;
    $92 = (($91>>>0) / 255)&-1;
    $93 = (($92) + ($$01399))|0;
    $94 = Math_imul($81, $24)|0;
    $95 = (($94>>>0) / 255)&-1;
    $96 = (($95) + ($$01400))|0;
    $97 = Math_imul($87, $24)|0;
    $98 = (($97>>>0) / 255)&-1;
    $99 = (($98) + ($17))|0;
    $100 = $90 >>> $$phi$trans$insert1908;
    $101 = $100 << $58;
    $102 = $93 >>> $$phi$trans$insert1913;
    $103 = $102 << $59;
    $104 = $103 | $101;
    $105 = $96 >>> $$phi$trans$insert1918;
    $106 = $105 << $60;
    $107 = $104 | $106;
    $108 = $99 >>> $$phi$trans$insert1923;
    $109 = $108 << $61;
    $110 = $107 | $109;
    HEAP32[$$114221602>>2] = $110;
    $111 = ((($$114221602)) + 4|0);
    $112 = ($62|0)==(0);
    if ($112) {
     break;
    } else {
     $$014021603 = $62;$$114221602 = $111;
    }
   }
   return;
   break;
  }
  case 2:  {
   $113 = ((($0)) + 16|0);
   $114 = HEAP32[$113>>2]|0;
   $115 = ((($12)) + 9|0);
   $116 = HEAP8[$115>>0]|0;
   $117 = $116&255;
   $118 = (($114|0) / ($117|0))&-1;
   $119 = ($3|0)<($1|0);
   $120 = ((($0)) + 20|0);
   $121 = HEAP32[$120>>2]|0;
   $122 = Math_imul($118, $4)|0;
   $123 = (($121) + ($122<<2)|0);
   $124 = ($10|0)!=(0);
   if ($119) {
    $127 = (($123) + ($3<<2)|0);
    $128 = ((($127)) + 4|0);
    $$1546 = $124 ? $127 : $128;
    $129 = (($1) - ($3))|0;
    $$11427$ph = $$1546;$$sink1657 = $129;
   } else {
    $125 = (($123) + ($1<<2)|0);
    $126 = (($3) - ($1))|0;
    $$11427$ph = $125;$$sink1657 = $126;
   }
   $130 = $124&1;
   $131 = (($$sink1657) + ($130))|0;
   $132 = ($131|0)==(0);
   if ($132) {
    return;
   }
   $133 = ((($12)) + 28|0);
   $134 = ((($12)) + 12|0);
   $135 = ((($12)) + 32|0);
   $136 = ((($12)) + 29|0);
   $137 = ((($12)) + 16|0);
   $138 = ((($12)) + 33|0);
   $139 = ((($12)) + 30|0);
   $140 = ((($12)) + 20|0);
   $141 = ((($12)) + 34|0);
   $142 = ((($12)) + 31|0);
   $143 = ((($12)) + 24|0);
   $144 = ((($12)) + 35|0);
   $$pre1887 = HEAP8[$133>>0]|0;
   $$phi$trans$insert1888 = $$pre1887&255;
   $$phi$trans$insert1889 = (79212 + ($$phi$trans$insert1888<<2)|0);
   $$pre1890 = HEAP32[$$phi$trans$insert1889>>2]|0;
   $$pre1891 = HEAP8[$135>>0]|0;
   $$pre1892 = HEAP8[$136>>0]|0;
   $$phi$trans$insert1893 = $$pre1892&255;
   $$phi$trans$insert1894 = (79212 + ($$phi$trans$insert1893<<2)|0);
   $$pre1895 = HEAP32[$$phi$trans$insert1894>>2]|0;
   $$pre1896 = HEAP8[$138>>0]|0;
   $$pre1897 = HEAP8[$139>>0]|0;
   $$phi$trans$insert1898 = $$pre1897&255;
   $$phi$trans$insert1899 = (79212 + ($$phi$trans$insert1898<<2)|0);
   $$pre1900 = HEAP32[$$phi$trans$insert1899>>2]|0;
   $$pre1901 = HEAP8[$141>>0]|0;
   $$pre1902 = HEAP8[$142>>0]|0;
   $$phi$trans$insert1903 = $$pre1902&255;
   $$phi$trans$insert1904 = (79212 + ($$phi$trans$insert1903<<2)|0);
   $$pre1905 = HEAP32[$$phi$trans$insert1904>>2]|0;
   $$pre1906 = HEAP8[$144>>0]|0;
   $145 = $$pre1891&255;
   $146 = $$pre1896&255;
   $147 = $$pre1901&255;
   $148 = $$pre1906&255;
   $$014231606 = $131;$$114271605 = $$11427$ph;
   while(1) {
    $149 = (($$014231606) + -1)|0;
    $150 = HEAP32[$$114271605>>2]|0;
    $151 = HEAP32[$134>>2]|0;
    $152 = $151 & $150;
    $153 = $152 >>> $145;
    $154 = (($$pre1890) + ($153)|0);
    $155 = HEAP8[$154>>0]|0;
    $156 = $155&255;
    $157 = HEAP32[$137>>2]|0;
    $158 = $157 & $150;
    $159 = $158 >>> $146;
    $160 = (($$pre1895) + ($159)|0);
    $161 = HEAP8[$160>>0]|0;
    $162 = $161&255;
    $163 = HEAP32[$140>>2]|0;
    $164 = $163 & $150;
    $165 = $164 >>> $147;
    $166 = (($$pre1900) + ($165)|0);
    $167 = HEAP8[$166>>0]|0;
    $168 = $167&255;
    $169 = HEAP32[$143>>2]|0;
    $170 = $169 & $150;
    $171 = $170 >>> $148;
    $172 = (($$pre1905) + ($171)|0);
    $173 = HEAP8[$172>>0]|0;
    $174 = $173&255;
    $175 = (($156) + ($$0))|0;
    $176 = ($175>>>0)<(255);
    $$ = $176 ? $175 : 255;
    $177 = (($162) + ($$01399))|0;
    $178 = ($177>>>0)<(255);
    $$8 = $178 ? $177 : 255;
    $179 = (($168) + ($$01400))|0;
    $180 = ($179>>>0)<(255);
    $$2 = $180 ? $179 : 255;
    $181 = $$ >>> $$phi$trans$insert1888;
    $182 = $181 << $145;
    $183 = $$8 >>> $$phi$trans$insert1893;
    $184 = $183 << $146;
    $185 = $184 | $182;
    $186 = $$2 >>> $$phi$trans$insert1898;
    $187 = $186 << $147;
    $188 = $185 | $187;
    $189 = $174 >>> $$phi$trans$insert1903;
    $190 = $189 << $148;
    $191 = $188 | $190;
    HEAP32[$$114271605>>2] = $191;
    $192 = ((($$114271605)) + 4|0);
    $193 = ($149|0)==(0);
    if ($193) {
     break;
    } else {
     $$014231606 = $149;$$114271605 = $192;
    }
   }
   return;
   break;
  }
  case 4:  {
   $194 = ((($0)) + 16|0);
   $195 = HEAP32[$194>>2]|0;
   $196 = ((($12)) + 9|0);
   $197 = HEAP8[$196>>0]|0;
   $198 = $197&255;
   $199 = (($195|0) / ($198|0))&-1;
   $200 = ($3|0)<($1|0);
   $201 = ((($0)) + 20|0);
   $202 = HEAP32[$201>>2]|0;
   $203 = Math_imul($199, $4)|0;
   $204 = (($202) + ($203<<2)|0);
   $205 = ($10|0)!=(0);
   if ($200) {
    $208 = (($204) + ($3<<2)|0);
    $209 = ((($208)) + 4|0);
    $$1547 = $205 ? $208 : $209;
    $210 = (($1) - ($3))|0;
    $$11431$ph = $$1547;$$sink1659 = $210;
   } else {
    $206 = (($204) + ($1<<2)|0);
    $207 = (($3) - ($1))|0;
    $$11431$ph = $206;$$sink1659 = $207;
   }
   $211 = $205&1;
   $212 = (($$sink1659) + ($211))|0;
   $213 = ($212|0)==(0);
   if ($213) {
    return;
   }
   $214 = ((($12)) + 28|0);
   $215 = ((($12)) + 12|0);
   $216 = ((($12)) + 32|0);
   $217 = ((($12)) + 29|0);
   $218 = ((($12)) + 16|0);
   $219 = ((($12)) + 33|0);
   $220 = ((($12)) + 30|0);
   $221 = ((($12)) + 20|0);
   $222 = ((($12)) + 34|0);
   $223 = ((($12)) + 31|0);
   $224 = ((($12)) + 24|0);
   $225 = ((($12)) + 35|0);
   $$pre1867 = HEAP8[$214>>0]|0;
   $$phi$trans$insert1868 = $$pre1867&255;
   $$phi$trans$insert1869 = (79212 + ($$phi$trans$insert1868<<2)|0);
   $$pre1870 = HEAP32[$$phi$trans$insert1869>>2]|0;
   $$pre1871 = HEAP8[$216>>0]|0;
   $$pre1872 = HEAP8[$217>>0]|0;
   $$phi$trans$insert1873 = $$pre1872&255;
   $$phi$trans$insert1874 = (79212 + ($$phi$trans$insert1873<<2)|0);
   $$pre1875 = HEAP32[$$phi$trans$insert1874>>2]|0;
   $$pre1876 = HEAP8[$219>>0]|0;
   $$pre1877 = HEAP8[$220>>0]|0;
   $$phi$trans$insert1878 = $$pre1877&255;
   $$phi$trans$insert1879 = (79212 + ($$phi$trans$insert1878<<2)|0);
   $$pre1880 = HEAP32[$$phi$trans$insert1879>>2]|0;
   $$pre1881 = HEAP8[$222>>0]|0;
   $$pre1882 = HEAP8[$223>>0]|0;
   $$phi$trans$insert1883 = $$pre1882&255;
   $$phi$trans$insert1884 = (79212 + ($$phi$trans$insert1883<<2)|0);
   $$pre1885 = HEAP32[$$phi$trans$insert1884>>2]|0;
   $$pre1886 = HEAP8[$225>>0]|0;
   $226 = $$pre1871&255;
   $227 = $$pre1876&255;
   $228 = $$pre1881&255;
   $229 = $$pre1886&255;
   $$014291609 = $212;$$114311608 = $$11431$ph;
   while(1) {
    $230 = (($$014291609) + -1)|0;
    $231 = HEAP32[$$114311608>>2]|0;
    $232 = HEAP32[$215>>2]|0;
    $233 = $232 & $231;
    $234 = $233 >>> $226;
    $235 = (($$pre1870) + ($234)|0);
    $236 = HEAP8[$235>>0]|0;
    $237 = $236&255;
    $238 = HEAP32[$218>>2]|0;
    $239 = $238 & $231;
    $240 = $239 >>> $227;
    $241 = (($$pre1875) + ($240)|0);
    $242 = HEAP8[$241>>0]|0;
    $243 = $242&255;
    $244 = HEAP32[$221>>2]|0;
    $245 = $244 & $231;
    $246 = $245 >>> $228;
    $247 = (($$pre1880) + ($246)|0);
    $248 = HEAP8[$247>>0]|0;
    $249 = $248&255;
    $250 = HEAP32[$224>>2]|0;
    $251 = $250 & $231;
    $252 = $251 >>> $229;
    $253 = (($$pre1885) + ($252)|0);
    $254 = HEAP8[$253>>0]|0;
    $255 = $254&255;
    $256 = Math_imul($237, $$0)|0;
    $257 = (($256>>>0) / 255)&-1;
    $258 = Math_imul($243, $$01399)|0;
    $259 = (($258>>>0) / 255)&-1;
    $260 = Math_imul($249, $$01400)|0;
    $261 = (($260>>>0) / 255)&-1;
    $262 = $257 >>> $$phi$trans$insert1868;
    $263 = $262 << $226;
    $264 = $259 >>> $$phi$trans$insert1873;
    $265 = $264 << $227;
    $266 = $265 | $263;
    $267 = $261 >>> $$phi$trans$insert1878;
    $268 = $267 << $228;
    $269 = $266 | $268;
    $270 = $255 >>> $$phi$trans$insert1883;
    $271 = $270 << $229;
    $272 = $269 | $271;
    HEAP32[$$114311608>>2] = $272;
    $273 = ((($$114311608)) + 4|0);
    $274 = ($230|0)==(0);
    if ($274) {
     break;
    } else {
     $$014291609 = $230;$$114311608 = $273;
    }
   }
   return;
   break;
  }
  default: {
   $275 = ((($0)) + 16|0);
   $276 = HEAP32[$275>>2]|0;
   $277 = ((($12)) + 9|0);
   $278 = HEAP8[$277>>0]|0;
   $279 = $278&255;
   $280 = (($276|0) / ($279|0))&-1;
   $281 = ($3|0)<($1|0);
   $282 = ((($0)) + 20|0);
   $283 = HEAP32[$282>>2]|0;
   $284 = Math_imul($280, $4)|0;
   $285 = (($283) + ($284<<2)|0);
   $286 = ($10|0)!=(0);
   if ($281) {
    $289 = (($285) + ($3<<2)|0);
    $290 = ((($289)) + 4|0);
    $$1548 = $286 ? $289 : $290;
    $291 = (($1) - ($3))|0;
    $$11456$ph = $$1548;$$sink1661 = $291;
   } else {
    $287 = (($285) + ($1<<2)|0);
    $288 = (($3) - ($1))|0;
    $$11456$ph = $287;$$sink1661 = $288;
   }
   $292 = $286&1;
   $293 = (($$sink1661) + ($292))|0;
   $294 = ($293|0)==(0);
   if ($294) {
    return;
   }
   $295 = ((($12)) + 28|0);
   $296 = HEAP8[$295>>0]|0;
   $297 = $296&255;
   $298 = $$0 >>> $297;
   $299 = ((($12)) + 32|0);
   $300 = HEAP8[$299>>0]|0;
   $301 = $300&255;
   $302 = $298 << $301;
   $303 = ((($12)) + 29|0);
   $304 = HEAP8[$303>>0]|0;
   $305 = $304&255;
   $306 = $$01399 >>> $305;
   $307 = ((($12)) + 33|0);
   $308 = HEAP8[$307>>0]|0;
   $309 = $308&255;
   $310 = $306 << $309;
   $311 = $310 | $302;
   $312 = ((($12)) + 30|0);
   $313 = HEAP8[$312>>0]|0;
   $314 = $313&255;
   $315 = $$01400 >>> $314;
   $316 = ((($12)) + 34|0);
   $317 = HEAP8[$316>>0]|0;
   $318 = $317&255;
   $319 = $315 << $318;
   $320 = $311 | $319;
   $321 = ((($12)) + 31|0);
   $322 = HEAP8[$321>>0]|0;
   $323 = $322&255;
   $324 = $17 >>> $323;
   $325 = ((($12)) + 35|0);
   $326 = HEAP8[$325>>0]|0;
   $327 = $326&255;
   $328 = $324 << $327;
   $329 = $320 | $328;
   $$014521601 = $293;$$114561600 = $$11456$ph;
   while(1) {
    $330 = (($$014521601) + -1)|0;
    HEAP32[$$114561600>>2] = $329;
    $331 = ((($$114561600)) + 4|0);
    $332 = ($330|0)==(0);
    if ($332) {
     break;
    } else {
     $$014521601 = $330;$$114561600 = $331;
    }
   }
   return;
  }
  }
 }
 $333 = ($3|0)==($1|0);
 if ($333) {
  switch ($5|0) {
  case 1:  {
   $334 = ((($0)) + 16|0);
   $335 = HEAP32[$334>>2]|0;
   $336 = ((($12)) + 9|0);
   $337 = HEAP8[$336>>0]|0;
   $338 = $337&255;
   $339 = (($335|0) / ($338|0))&-1;
   $340 = ($4|0)<($2|0);
   $341 = ((($0)) + 20|0);
   $342 = HEAP32[$341>>2]|0;
   $343 = ($10|0)!=(0);
   if ($340) {
    $348 = Math_imul($339, $4)|0;
    $349 = (($342) + ($348<<2)|0);
    $350 = (($349) + ($3<<2)|0);
    $351 = (($350) + ($339<<2)|0);
    $$1549 = $343 ? $350 : $351;
    $352 = (($2) - ($4))|0;
    $$11459$ph = $$1549;$$sink1663 = $352;
   } else {
    $344 = Math_imul($339, $2)|0;
    $345 = (($342) + ($344<<2)|0);
    $346 = (($345) + ($3<<2)|0);
    $347 = (($4) - ($2))|0;
    $$11459$ph = $346;$$sink1663 = $347;
   }
   $353 = $343&1;
   $354 = (($$sink1663) + ($353))|0;
   $355 = ($354|0)==(0);
   if ($355) {
    return;
   }
   $356 = ((($12)) + 28|0);
   $357 = ((($12)) + 12|0);
   $358 = ((($12)) + 32|0);
   $359 = ((($12)) + 29|0);
   $360 = ((($12)) + 16|0);
   $361 = ((($12)) + 33|0);
   $362 = ((($12)) + 30|0);
   $363 = ((($12)) + 20|0);
   $364 = ((($12)) + 34|0);
   $365 = ((($12)) + 31|0);
   $366 = ((($12)) + 24|0);
   $367 = ((($12)) + 35|0);
   $$pre1847 = HEAP8[$356>>0]|0;
   $$phi$trans$insert1848 = $$pre1847&255;
   $$phi$trans$insert1849 = (79212 + ($$phi$trans$insert1848<<2)|0);
   $$pre1850 = HEAP32[$$phi$trans$insert1849>>2]|0;
   $$pre1851 = HEAP8[$358>>0]|0;
   $$pre1852 = HEAP8[$359>>0]|0;
   $$phi$trans$insert1853 = $$pre1852&255;
   $$phi$trans$insert1854 = (79212 + ($$phi$trans$insert1853<<2)|0);
   $$pre1855 = HEAP32[$$phi$trans$insert1854>>2]|0;
   $$pre1856 = HEAP8[$361>>0]|0;
   $$pre1857 = HEAP8[$362>>0]|0;
   $$phi$trans$insert1858 = $$pre1857&255;
   $$phi$trans$insert1859 = (79212 + ($$phi$trans$insert1858<<2)|0);
   $$pre1860 = HEAP32[$$phi$trans$insert1859>>2]|0;
   $$pre1861 = HEAP8[$364>>0]|0;
   $$pre1862 = HEAP8[$365>>0]|0;
   $$phi$trans$insert1863 = $$pre1862&255;
   $$phi$trans$insert1864 = (79212 + ($$phi$trans$insert1863<<2)|0);
   $$pre1865 = HEAP32[$$phi$trans$insert1864>>2]|0;
   $$pre1866 = HEAP8[$367>>0]|0;
   $368 = $$pre1851&255;
   $369 = $$pre1856&255;
   $370 = $$pre1861&255;
   $371 = $$pre1866&255;
   $$014571615 = $354;$$114591614 = $$11459$ph;
   while(1) {
    $372 = (($$014571615) + -1)|0;
    $373 = HEAP32[$$114591614>>2]|0;
    $374 = HEAP32[$357>>2]|0;
    $375 = $374 & $373;
    $376 = $375 >>> $368;
    $377 = (($$pre1850) + ($376)|0);
    $378 = HEAP8[$377>>0]|0;
    $379 = $378&255;
    $380 = HEAP32[$360>>2]|0;
    $381 = $380 & $373;
    $382 = $381 >>> $369;
    $383 = (($$pre1855) + ($382)|0);
    $384 = HEAP8[$383>>0]|0;
    $385 = $384&255;
    $386 = HEAP32[$363>>2]|0;
    $387 = $386 & $373;
    $388 = $387 >>> $370;
    $389 = (($$pre1860) + ($388)|0);
    $390 = HEAP8[$389>>0]|0;
    $391 = $390&255;
    $392 = HEAP32[$366>>2]|0;
    $393 = $392 & $373;
    $394 = $393 >>> $371;
    $395 = (($$pre1865) + ($394)|0);
    $396 = HEAP8[$395>>0]|0;
    $397 = $396&255;
    $398 = Math_imul($379, $24)|0;
    $399 = (($398>>>0) / 255)&-1;
    $400 = (($399) + ($$0))|0;
    $401 = Math_imul($385, $24)|0;
    $402 = (($401>>>0) / 255)&-1;
    $403 = (($402) + ($$01399))|0;
    $404 = Math_imul($391, $24)|0;
    $405 = (($404>>>0) / 255)&-1;
    $406 = (($405) + ($$01400))|0;
    $407 = Math_imul($397, $24)|0;
    $408 = (($407>>>0) / 255)&-1;
    $409 = (($408) + ($17))|0;
    $410 = $400 >>> $$phi$trans$insert1848;
    $411 = $410 << $368;
    $412 = $403 >>> $$phi$trans$insert1853;
    $413 = $412 << $369;
    $414 = $413 | $411;
    $415 = $406 >>> $$phi$trans$insert1858;
    $416 = $415 << $370;
    $417 = $414 | $416;
    $418 = $409 >>> $$phi$trans$insert1863;
    $419 = $418 << $371;
    $420 = $417 | $419;
    HEAP32[$$114591614>>2] = $420;
    $421 = (($$114591614) + ($339<<2)|0);
    $422 = ($372|0)==(0);
    if ($422) {
     break;
    } else {
     $$014571615 = $372;$$114591614 = $421;
    }
   }
   return;
   break;
  }
  case 2:  {
   $423 = ((($0)) + 16|0);
   $424 = HEAP32[$423>>2]|0;
   $425 = ((($12)) + 9|0);
   $426 = HEAP8[$425>>0]|0;
   $427 = $426&255;
   $428 = (($424|0) / ($427|0))&-1;
   $429 = ($4|0)<($2|0);
   $430 = ((($0)) + 20|0);
   $431 = HEAP32[$430>>2]|0;
   $432 = ($10|0)!=(0);
   if ($429) {
    $437 = Math_imul($428, $4)|0;
    $438 = (($431) + ($437<<2)|0);
    $439 = (($438) + ($3<<2)|0);
    $440 = (($439) + ($428<<2)|0);
    $$1550 = $432 ? $439 : $440;
    $441 = (($2) - ($4))|0;
    $$11481$ph = $$1550;$$sink1665 = $441;
   } else {
    $433 = Math_imul($428, $2)|0;
    $434 = (($431) + ($433<<2)|0);
    $435 = (($434) + ($3<<2)|0);
    $436 = (($4) - ($2))|0;
    $$11481$ph = $435;$$sink1665 = $436;
   }
   $442 = $432&1;
   $443 = (($$sink1665) + ($442))|0;
   $444 = ($443|0)==(0);
   if ($444) {
    return;
   }
   $445 = ((($12)) + 28|0);
   $446 = ((($12)) + 12|0);
   $447 = ((($12)) + 32|0);
   $448 = ((($12)) + 29|0);
   $449 = ((($12)) + 16|0);
   $450 = ((($12)) + 33|0);
   $451 = ((($12)) + 30|0);
   $452 = ((($12)) + 20|0);
   $453 = ((($12)) + 34|0);
   $454 = ((($12)) + 31|0);
   $455 = ((($12)) + 24|0);
   $456 = ((($12)) + 35|0);
   $$pre1827 = HEAP8[$445>>0]|0;
   $$phi$trans$insert1828 = $$pre1827&255;
   $$phi$trans$insert1829 = (79212 + ($$phi$trans$insert1828<<2)|0);
   $$pre1830 = HEAP32[$$phi$trans$insert1829>>2]|0;
   $$pre1831 = HEAP8[$447>>0]|0;
   $$pre1832 = HEAP8[$448>>0]|0;
   $$phi$trans$insert1833 = $$pre1832&255;
   $$phi$trans$insert1834 = (79212 + ($$phi$trans$insert1833<<2)|0);
   $$pre1835 = HEAP32[$$phi$trans$insert1834>>2]|0;
   $$pre1836 = HEAP8[$450>>0]|0;
   $$pre1837 = HEAP8[$451>>0]|0;
   $$phi$trans$insert1838 = $$pre1837&255;
   $$phi$trans$insert1839 = (79212 + ($$phi$trans$insert1838<<2)|0);
   $$pre1840 = HEAP32[$$phi$trans$insert1839>>2]|0;
   $$pre1841 = HEAP8[$453>>0]|0;
   $$pre1842 = HEAP8[$454>>0]|0;
   $$phi$trans$insert1843 = $$pre1842&255;
   $$phi$trans$insert1844 = (79212 + ($$phi$trans$insert1843<<2)|0);
   $$pre1845 = HEAP32[$$phi$trans$insert1844>>2]|0;
   $$pre1846 = HEAP8[$456>>0]|0;
   $457 = $$pre1831&255;
   $458 = $$pre1836&255;
   $459 = $$pre1841&255;
   $460 = $$pre1846&255;
   $$014601618 = $443;$$114811617 = $$11481$ph;
   while(1) {
    $461 = (($$014601618) + -1)|0;
    $462 = HEAP32[$$114811617>>2]|0;
    $463 = HEAP32[$446>>2]|0;
    $464 = $463 & $462;
    $465 = $464 >>> $457;
    $466 = (($$pre1830) + ($465)|0);
    $467 = HEAP8[$466>>0]|0;
    $468 = $467&255;
    $469 = HEAP32[$449>>2]|0;
    $470 = $469 & $462;
    $471 = $470 >>> $458;
    $472 = (($$pre1835) + ($471)|0);
    $473 = HEAP8[$472>>0]|0;
    $474 = $473&255;
    $475 = HEAP32[$452>>2]|0;
    $476 = $475 & $462;
    $477 = $476 >>> $459;
    $478 = (($$pre1840) + ($477)|0);
    $479 = HEAP8[$478>>0]|0;
    $480 = $479&255;
    $481 = HEAP32[$455>>2]|0;
    $482 = $481 & $462;
    $483 = $482 >>> $460;
    $484 = (($$pre1845) + ($483)|0);
    $485 = HEAP8[$484>>0]|0;
    $486 = $485&255;
    $487 = (($468) + ($$0))|0;
    $488 = ($487>>>0)<(255);
    $$3 = $488 ? $487 : 255;
    $489 = (($474) + ($$01399))|0;
    $490 = ($489>>>0)<(255);
    $$9 = $490 ? $489 : 255;
    $491 = (($480) + ($$01400))|0;
    $492 = ($491>>>0)<(255);
    $$4 = $492 ? $491 : 255;
    $493 = $$3 >>> $$phi$trans$insert1828;
    $494 = $493 << $457;
    $495 = $$9 >>> $$phi$trans$insert1833;
    $496 = $495 << $458;
    $497 = $496 | $494;
    $498 = $$4 >>> $$phi$trans$insert1838;
    $499 = $498 << $459;
    $500 = $497 | $499;
    $501 = $486 >>> $$phi$trans$insert1843;
    $502 = $501 << $460;
    $503 = $500 | $502;
    HEAP32[$$114811617>>2] = $503;
    $504 = (($$114811617) + ($428<<2)|0);
    $505 = ($461|0)==(0);
    if ($505) {
     break;
    } else {
     $$014601618 = $461;$$114811617 = $504;
    }
   }
   return;
   break;
  }
  case 4:  {
   $506 = ((($0)) + 16|0);
   $507 = HEAP32[$506>>2]|0;
   $508 = ((($12)) + 9|0);
   $509 = HEAP8[$508>>0]|0;
   $510 = $509&255;
   $511 = (($507|0) / ($510|0))&-1;
   $512 = ($4|0)<($2|0);
   $513 = ((($0)) + 20|0);
   $514 = HEAP32[$513>>2]|0;
   $515 = ($10|0)!=(0);
   if ($512) {
    $520 = Math_imul($511, $4)|0;
    $521 = (($514) + ($520<<2)|0);
    $522 = (($521) + ($3<<2)|0);
    $523 = (($522) + ($511<<2)|0);
    $$1551 = $515 ? $522 : $523;
    $524 = (($2) - ($4))|0;
    $$11486$ph = $$1551;$$sink1667 = $524;
   } else {
    $516 = Math_imul($511, $2)|0;
    $517 = (($514) + ($516<<2)|0);
    $518 = (($517) + ($3<<2)|0);
    $519 = (($4) - ($2))|0;
    $$11486$ph = $518;$$sink1667 = $519;
   }
   $525 = $515&1;
   $526 = (($$sink1667) + ($525))|0;
   $527 = ($526|0)==(0);
   if ($527) {
    return;
   }
   $528 = ((($12)) + 28|0);
   $529 = ((($12)) + 12|0);
   $530 = ((($12)) + 32|0);
   $531 = ((($12)) + 29|0);
   $532 = ((($12)) + 16|0);
   $533 = ((($12)) + 33|0);
   $534 = ((($12)) + 30|0);
   $535 = ((($12)) + 20|0);
   $536 = ((($12)) + 34|0);
   $537 = ((($12)) + 31|0);
   $538 = ((($12)) + 24|0);
   $539 = ((($12)) + 35|0);
   $$pre1807 = HEAP8[$528>>0]|0;
   $$phi$trans$insert1808 = $$pre1807&255;
   $$phi$trans$insert1809 = (79212 + ($$phi$trans$insert1808<<2)|0);
   $$pre1810 = HEAP32[$$phi$trans$insert1809>>2]|0;
   $$pre1811 = HEAP8[$530>>0]|0;
   $$pre1812 = HEAP8[$531>>0]|0;
   $$phi$trans$insert1813 = $$pre1812&255;
   $$phi$trans$insert1814 = (79212 + ($$phi$trans$insert1813<<2)|0);
   $$pre1815 = HEAP32[$$phi$trans$insert1814>>2]|0;
   $$pre1816 = HEAP8[$533>>0]|0;
   $$pre1817 = HEAP8[$534>>0]|0;
   $$phi$trans$insert1818 = $$pre1817&255;
   $$phi$trans$insert1819 = (79212 + ($$phi$trans$insert1818<<2)|0);
   $$pre1820 = HEAP32[$$phi$trans$insert1819>>2]|0;
   $$pre1821 = HEAP8[$536>>0]|0;
   $$pre1822 = HEAP8[$537>>0]|0;
   $$phi$trans$insert1823 = $$pre1822&255;
   $$phi$trans$insert1824 = (79212 + ($$phi$trans$insert1823<<2)|0);
   $$pre1825 = HEAP32[$$phi$trans$insert1824>>2]|0;
   $$pre1826 = HEAP8[$539>>0]|0;
   $540 = $$pre1811&255;
   $541 = $$pre1816&255;
   $542 = $$pre1821&255;
   $543 = $$pre1826&255;
   $$014841621 = $526;$$114861620 = $$11486$ph;
   while(1) {
    $544 = (($$014841621) + -1)|0;
    $545 = HEAP32[$$114861620>>2]|0;
    $546 = HEAP32[$529>>2]|0;
    $547 = $546 & $545;
    $548 = $547 >>> $540;
    $549 = (($$pre1810) + ($548)|0);
    $550 = HEAP8[$549>>0]|0;
    $551 = $550&255;
    $552 = HEAP32[$532>>2]|0;
    $553 = $552 & $545;
    $554 = $553 >>> $541;
    $555 = (($$pre1815) + ($554)|0);
    $556 = HEAP8[$555>>0]|0;
    $557 = $556&255;
    $558 = HEAP32[$535>>2]|0;
    $559 = $558 & $545;
    $560 = $559 >>> $542;
    $561 = (($$pre1820) + ($560)|0);
    $562 = HEAP8[$561>>0]|0;
    $563 = $562&255;
    $564 = HEAP32[$538>>2]|0;
    $565 = $564 & $545;
    $566 = $565 >>> $543;
    $567 = (($$pre1825) + ($566)|0);
    $568 = HEAP8[$567>>0]|0;
    $569 = $568&255;
    $570 = Math_imul($551, $$0)|0;
    $571 = (($570>>>0) / 255)&-1;
    $572 = Math_imul($557, $$01399)|0;
    $573 = (($572>>>0) / 255)&-1;
    $574 = Math_imul($563, $$01400)|0;
    $575 = (($574>>>0) / 255)&-1;
    $576 = $571 >>> $$phi$trans$insert1808;
    $577 = $576 << $540;
    $578 = $573 >>> $$phi$trans$insert1813;
    $579 = $578 << $541;
    $580 = $579 | $577;
    $581 = $575 >>> $$phi$trans$insert1818;
    $582 = $581 << $542;
    $583 = $580 | $582;
    $584 = $569 >>> $$phi$trans$insert1823;
    $585 = $584 << $543;
    $586 = $583 | $585;
    HEAP32[$$114861620>>2] = $586;
    $587 = (($$114861620) + ($511<<2)|0);
    $588 = ($544|0)==(0);
    if ($588) {
     break;
    } else {
     $$014841621 = $544;$$114861620 = $587;
    }
   }
   return;
   break;
  }
  default: {
   $589 = ((($0)) + 16|0);
   $590 = HEAP32[$589>>2]|0;
   $591 = ((($12)) + 9|0);
   $592 = HEAP8[$591>>0]|0;
   $593 = $592&255;
   $594 = (($590|0) / ($593|0))&-1;
   $595 = ($4|0)<($2|0);
   $596 = ((($0)) + 20|0);
   $597 = HEAP32[$596>>2]|0;
   $598 = ($10|0)!=(0);
   if ($595) {
    $603 = Math_imul($594, $4)|0;
    $604 = (($597) + ($603<<2)|0);
    $605 = (($604) + ($3<<2)|0);
    $606 = (($605) + ($594<<2)|0);
    $$1552 = $598 ? $605 : $606;
    $607 = (($2) - ($4))|0;
    $$11490$ph = $$1552;$$sink1669 = $607;
   } else {
    $599 = Math_imul($594, $2)|0;
    $600 = (($597) + ($599<<2)|0);
    $601 = (($600) + ($3<<2)|0);
    $602 = (($4) - ($2))|0;
    $$11490$ph = $601;$$sink1669 = $602;
   }
   $608 = $598&1;
   $609 = (($$sink1669) + ($608))|0;
   $610 = ($609|0)==(0);
   if ($610) {
    return;
   }
   $611 = ((($12)) + 28|0);
   $612 = HEAP8[$611>>0]|0;
   $613 = $612&255;
   $614 = $$0 >>> $613;
   $615 = ((($12)) + 32|0);
   $616 = HEAP8[$615>>0]|0;
   $617 = $616&255;
   $618 = $614 << $617;
   $619 = ((($12)) + 29|0);
   $620 = HEAP8[$619>>0]|0;
   $621 = $620&255;
   $622 = $$01399 >>> $621;
   $623 = ((($12)) + 33|0);
   $624 = HEAP8[$623>>0]|0;
   $625 = $624&255;
   $626 = $622 << $625;
   $627 = $626 | $618;
   $628 = ((($12)) + 30|0);
   $629 = HEAP8[$628>>0]|0;
   $630 = $629&255;
   $631 = $$01400 >>> $630;
   $632 = ((($12)) + 34|0);
   $633 = HEAP8[$632>>0]|0;
   $634 = $633&255;
   $635 = $631 << $634;
   $636 = $627 | $635;
   $637 = ((($12)) + 31|0);
   $638 = HEAP8[$637>>0]|0;
   $639 = $638&255;
   $640 = $17 >>> $639;
   $641 = ((($12)) + 35|0);
   $642 = HEAP8[$641>>0]|0;
   $643 = $642&255;
   $644 = $640 << $643;
   $645 = $636 | $644;
   $$014881612 = $609;$$114901611 = $$11490$ph;
   while(1) {
    $646 = (($$014881612) + -1)|0;
    HEAP32[$$114901611>>2] = $645;
    $647 = (($$114901611) + ($594<<2)|0);
    $648 = ($646|0)==(0);
    if ($648) {
     break;
    } else {
     $$014881612 = $646;$$114901611 = $647;
    }
   }
   return;
  }
  }
 }
 $649 = (($1) - ($3))|0;
 $650 = ($649|0)<(0);
 $651 = (0 - ($649))|0;
 $652 = $650 ? $651 : $649;
 $653 = (($2) - ($4))|0;
 $654 = ($653|0)<(0);
 $655 = (0 - ($653))|0;
 $656 = $654 ? $655 : $653;
 $657 = ($652|0)==($656|0);
 if ($657) {
  switch ($5|0) {
  case 1:  {
   $658 = ((($0)) + 16|0);
   $659 = HEAP32[$658>>2]|0;
   $660 = ((($12)) + 9|0);
   $661 = HEAP8[$660>>0]|0;
   $662 = $661&255;
   $663 = (($659|0) / ($662|0))&-1;
   $664 = ($4|0)<($2|0);
   $665 = ((($0)) + 20|0);
   $666 = HEAP32[$665>>2]|0;
   if ($664) {
    $673 = Math_imul($663, $4)|0;
    $674 = (($666) + ($673<<2)|0);
    $675 = (($674) + ($3<<2)|0);
    $676 = ($3|0)>($1|0);
    $$sink1553 = $676 ? -1 : 1;
    $677 = (($663) + ($$sink1553))|0;
    $678 = ($10|0)==(0);
    $679 = (($675) + ($677<<2)|0);
    $$1554 = $678 ? $679 : $675;
    $$01510 = $653;$$11517 = $$1554;$$21514 = $677;
   } else {
    $667 = Math_imul($663, $2)|0;
    $668 = (($666) + ($667<<2)|0);
    $669 = (($668) + ($1<<2)|0);
    $670 = ($3|0)<($1|0);
    $$sink = $670 ? -1 : 1;
    $671 = (($663) + ($$sink))|0;
    $672 = (($4) - ($2))|0;
    $$01510 = $672;$$11517 = $669;$$21514 = $671;
   }
   $not$1573 = ($10|0)!=(0);
   $680 = $not$1573&1;
   $$01510$ = (($$01510) + ($680))|0;
   $681 = ($$01510$|0)==(0);
   if ($681) {
    return;
   }
   $682 = ((($12)) + 28|0);
   $683 = ((($12)) + 12|0);
   $684 = ((($12)) + 32|0);
   $685 = ((($12)) + 29|0);
   $686 = ((($12)) + 16|0);
   $687 = ((($12)) + 33|0);
   $688 = ((($12)) + 30|0);
   $689 = ((($12)) + 20|0);
   $690 = ((($12)) + 34|0);
   $691 = ((($12)) + 31|0);
   $692 = ((($12)) + 24|0);
   $693 = ((($12)) + 35|0);
   $$pre1787 = HEAP8[$682>>0]|0;
   $$phi$trans$insert1788 = $$pre1787&255;
   $$phi$trans$insert1789 = (79212 + ($$phi$trans$insert1788<<2)|0);
   $$pre1790 = HEAP32[$$phi$trans$insert1789>>2]|0;
   $$pre1791 = HEAP8[$684>>0]|0;
   $$pre1792 = HEAP8[$685>>0]|0;
   $$phi$trans$insert1793 = $$pre1792&255;
   $$phi$trans$insert1794 = (79212 + ($$phi$trans$insert1793<<2)|0);
   $$pre1795 = HEAP32[$$phi$trans$insert1794>>2]|0;
   $$pre1796 = HEAP8[$687>>0]|0;
   $$pre1797 = HEAP8[$688>>0]|0;
   $$phi$trans$insert1798 = $$pre1797&255;
   $$phi$trans$insert1799 = (79212 + ($$phi$trans$insert1798<<2)|0);
   $$pre1800 = HEAP32[$$phi$trans$insert1799>>2]|0;
   $$pre1801 = HEAP8[$690>>0]|0;
   $$pre1802 = HEAP8[$691>>0]|0;
   $$phi$trans$insert1803 = $$pre1802&255;
   $$phi$trans$insert1804 = (79212 + ($$phi$trans$insert1803<<2)|0);
   $$pre1805 = HEAP32[$$phi$trans$insert1804>>2]|0;
   $$pre1806 = HEAP8[$693>>0]|0;
   $694 = $$pre1791&255;
   $695 = $$pre1796&255;
   $696 = $$pre1801&255;
   $697 = $$pre1806&255;
   $$115111627 = $$01510$;$$215181626 = $$11517;
   while(1) {
    $698 = (($$115111627) + -1)|0;
    $699 = HEAP32[$$215181626>>2]|0;
    $700 = HEAP32[$683>>2]|0;
    $701 = $700 & $699;
    $702 = $701 >>> $694;
    $703 = (($$pre1790) + ($702)|0);
    $704 = HEAP8[$703>>0]|0;
    $705 = $704&255;
    $706 = HEAP32[$686>>2]|0;
    $707 = $706 & $699;
    $708 = $707 >>> $695;
    $709 = (($$pre1795) + ($708)|0);
    $710 = HEAP8[$709>>0]|0;
    $711 = $710&255;
    $712 = HEAP32[$689>>2]|0;
    $713 = $712 & $699;
    $714 = $713 >>> $696;
    $715 = (($$pre1800) + ($714)|0);
    $716 = HEAP8[$715>>0]|0;
    $717 = $716&255;
    $718 = HEAP32[$692>>2]|0;
    $719 = $718 & $699;
    $720 = $719 >>> $697;
    $721 = (($$pre1805) + ($720)|0);
    $722 = HEAP8[$721>>0]|0;
    $723 = $722&255;
    $724 = Math_imul($705, $24)|0;
    $725 = (($724>>>0) / 255)&-1;
    $726 = (($725) + ($$0))|0;
    $727 = Math_imul($711, $24)|0;
    $728 = (($727>>>0) / 255)&-1;
    $729 = (($728) + ($$01399))|0;
    $730 = Math_imul($717, $24)|0;
    $731 = (($730>>>0) / 255)&-1;
    $732 = (($731) + ($$01400))|0;
    $733 = Math_imul($723, $24)|0;
    $734 = (($733>>>0) / 255)&-1;
    $735 = (($734) + ($17))|0;
    $736 = $726 >>> $$phi$trans$insert1788;
    $737 = $736 << $694;
    $738 = $729 >>> $$phi$trans$insert1793;
    $739 = $738 << $695;
    $740 = $739 | $737;
    $741 = $732 >>> $$phi$trans$insert1798;
    $742 = $741 << $696;
    $743 = $740 | $742;
    $744 = $735 >>> $$phi$trans$insert1803;
    $745 = $744 << $697;
    $746 = $743 | $745;
    HEAP32[$$215181626>>2] = $746;
    $747 = (($$215181626) + ($$21514<<2)|0);
    $748 = ($698|0)==(0);
    if ($748) {
     break;
    } else {
     $$115111627 = $698;$$215181626 = $747;
    }
   }
   return;
   break;
  }
  case 2:  {
   $749 = ((($0)) + 16|0);
   $750 = HEAP32[$749>>2]|0;
   $751 = ((($12)) + 9|0);
   $752 = HEAP8[$751>>0]|0;
   $753 = $752&255;
   $754 = (($750|0) / ($753|0))&-1;
   $755 = ($4|0)<($2|0);
   $756 = ((($0)) + 20|0);
   $757 = HEAP32[$756>>2]|0;
   if ($755) {
    $764 = Math_imul($754, $4)|0;
    $765 = (($757) + ($764<<2)|0);
    $766 = (($765) + ($3<<2)|0);
    $767 = ($3|0)>($1|0);
    $$sink1556 = $767 ? -1 : 1;
    $768 = (($754) + ($$sink1556))|0;
    $769 = ($10|0)==(0);
    $770 = (($766) + ($768<<2)|0);
    $$1557 = $769 ? $770 : $766;
    $$01519 = $653;$$11525 = $$1557;$$21523 = $768;
   } else {
    $758 = Math_imul($754, $2)|0;
    $759 = (($757) + ($758<<2)|0);
    $760 = (($759) + ($1<<2)|0);
    $761 = ($3|0)<($1|0);
    $$sink1555 = $761 ? -1 : 1;
    $762 = (($754) + ($$sink1555))|0;
    $763 = (($4) - ($2))|0;
    $$01519 = $763;$$11525 = $760;$$21523 = $762;
   }
   $not$1572 = ($10|0)!=(0);
   $771 = $not$1572&1;
   $$01519$ = (($$01519) + ($771))|0;
   $772 = ($$01519$|0)==(0);
   if ($772) {
    return;
   }
   $773 = ((($12)) + 28|0);
   $774 = ((($12)) + 12|0);
   $775 = ((($12)) + 32|0);
   $776 = ((($12)) + 29|0);
   $777 = ((($12)) + 16|0);
   $778 = ((($12)) + 33|0);
   $779 = ((($12)) + 30|0);
   $780 = ((($12)) + 20|0);
   $781 = ((($12)) + 34|0);
   $782 = ((($12)) + 31|0);
   $783 = ((($12)) + 24|0);
   $784 = ((($12)) + 35|0);
   $$pre1767 = HEAP8[$773>>0]|0;
   $$phi$trans$insert1768 = $$pre1767&255;
   $$phi$trans$insert1769 = (79212 + ($$phi$trans$insert1768<<2)|0);
   $$pre1770 = HEAP32[$$phi$trans$insert1769>>2]|0;
   $$pre1771 = HEAP8[$775>>0]|0;
   $$pre1772 = HEAP8[$776>>0]|0;
   $$phi$trans$insert1773 = $$pre1772&255;
   $$phi$trans$insert1774 = (79212 + ($$phi$trans$insert1773<<2)|0);
   $$pre1775 = HEAP32[$$phi$trans$insert1774>>2]|0;
   $$pre1776 = HEAP8[$778>>0]|0;
   $$pre1777 = HEAP8[$779>>0]|0;
   $$phi$trans$insert1778 = $$pre1777&255;
   $$phi$trans$insert1779 = (79212 + ($$phi$trans$insert1778<<2)|0);
   $$pre1780 = HEAP32[$$phi$trans$insert1779>>2]|0;
   $$pre1781 = HEAP8[$781>>0]|0;
   $$pre1782 = HEAP8[$782>>0]|0;
   $$phi$trans$insert1783 = $$pre1782&255;
   $$phi$trans$insert1784 = (79212 + ($$phi$trans$insert1783<<2)|0);
   $$pre1785 = HEAP32[$$phi$trans$insert1784>>2]|0;
   $$pre1786 = HEAP8[$784>>0]|0;
   $785 = $$pre1771&255;
   $786 = $$pre1776&255;
   $787 = $$pre1781&255;
   $788 = $$pre1786&255;
   $$115201630 = $$01519$;$$215261629 = $$11525;
   while(1) {
    $789 = (($$115201630) + -1)|0;
    $790 = HEAP32[$$215261629>>2]|0;
    $791 = HEAP32[$774>>2]|0;
    $792 = $791 & $790;
    $793 = $792 >>> $785;
    $794 = (($$pre1770) + ($793)|0);
    $795 = HEAP8[$794>>0]|0;
    $796 = $795&255;
    $797 = HEAP32[$777>>2]|0;
    $798 = $797 & $790;
    $799 = $798 >>> $786;
    $800 = (($$pre1775) + ($799)|0);
    $801 = HEAP8[$800>>0]|0;
    $802 = $801&255;
    $803 = HEAP32[$780>>2]|0;
    $804 = $803 & $790;
    $805 = $804 >>> $787;
    $806 = (($$pre1780) + ($805)|0);
    $807 = HEAP8[$806>>0]|0;
    $808 = $807&255;
    $809 = HEAP32[$783>>2]|0;
    $810 = $809 & $790;
    $811 = $810 >>> $788;
    $812 = (($$pre1785) + ($811)|0);
    $813 = HEAP8[$812>>0]|0;
    $814 = $813&255;
    $815 = (($796) + ($$0))|0;
    $816 = ($815>>>0)<(255);
    $$5 = $816 ? $815 : 255;
    $817 = (($802) + ($$01399))|0;
    $818 = ($817>>>0)<(255);
    $$10 = $818 ? $817 : 255;
    $819 = (($808) + ($$01400))|0;
    $820 = ($819>>>0)<(255);
    $$6 = $820 ? $819 : 255;
    $821 = $$5 >>> $$phi$trans$insert1768;
    $822 = $821 << $785;
    $823 = $$10 >>> $$phi$trans$insert1773;
    $824 = $823 << $786;
    $825 = $824 | $822;
    $826 = $$6 >>> $$phi$trans$insert1778;
    $827 = $826 << $787;
    $828 = $825 | $827;
    $829 = $814 >>> $$phi$trans$insert1783;
    $830 = $829 << $788;
    $831 = $828 | $830;
    HEAP32[$$215261629>>2] = $831;
    $832 = (($$215261629) + ($$21523<<2)|0);
    $833 = ($789|0)==(0);
    if ($833) {
     break;
    } else {
     $$115201630 = $789;$$215261629 = $832;
    }
   }
   return;
   break;
  }
  case 4:  {
   $834 = ((($0)) + 16|0);
   $835 = HEAP32[$834>>2]|0;
   $836 = ((($12)) + 9|0);
   $837 = HEAP8[$836>>0]|0;
   $838 = $837&255;
   $839 = (($835|0) / ($838|0))&-1;
   $840 = ($4|0)<($2|0);
   $841 = ((($0)) + 20|0);
   $842 = HEAP32[$841>>2]|0;
   if ($840) {
    $849 = Math_imul($839, $4)|0;
    $850 = (($842) + ($849<<2)|0);
    $851 = (($850) + ($3<<2)|0);
    $852 = ($3|0)>($1|0);
    $$sink1559 = $852 ? -1 : 1;
    $853 = (($839) + ($$sink1559))|0;
    $854 = ($10|0)==(0);
    $855 = (($851) + ($853<<2)|0);
    $$1560 = $854 ? $855 : $851;
    $$01537 = $653;$$11543 = $$1560;$$21541 = $853;
   } else {
    $843 = Math_imul($839, $2)|0;
    $844 = (($842) + ($843<<2)|0);
    $845 = (($844) + ($1<<2)|0);
    $846 = ($3|0)<($1|0);
    $$sink1558 = $846 ? -1 : 1;
    $847 = (($839) + ($$sink1558))|0;
    $848 = (($4) - ($2))|0;
    $$01537 = $848;$$11543 = $845;$$21541 = $847;
   }
   $not$1571 = ($10|0)!=(0);
   $856 = $not$1571&1;
   $$01537$ = (($$01537) + ($856))|0;
   $857 = ($$01537$|0)==(0);
   if ($857) {
    return;
   }
   $858 = ((($12)) + 28|0);
   $859 = ((($12)) + 12|0);
   $860 = ((($12)) + 32|0);
   $861 = ((($12)) + 29|0);
   $862 = ((($12)) + 16|0);
   $863 = ((($12)) + 33|0);
   $864 = ((($12)) + 30|0);
   $865 = ((($12)) + 20|0);
   $866 = ((($12)) + 34|0);
   $867 = ((($12)) + 31|0);
   $868 = ((($12)) + 24|0);
   $869 = ((($12)) + 35|0);
   $$pre1747 = HEAP8[$858>>0]|0;
   $$phi$trans$insert1748 = $$pre1747&255;
   $$phi$trans$insert1749 = (79212 + ($$phi$trans$insert1748<<2)|0);
   $$pre1750 = HEAP32[$$phi$trans$insert1749>>2]|0;
   $$pre1751 = HEAP8[$860>>0]|0;
   $$pre1752 = HEAP8[$861>>0]|0;
   $$phi$trans$insert1753 = $$pre1752&255;
   $$phi$trans$insert1754 = (79212 + ($$phi$trans$insert1753<<2)|0);
   $$pre1755 = HEAP32[$$phi$trans$insert1754>>2]|0;
   $$pre1756 = HEAP8[$863>>0]|0;
   $$pre1757 = HEAP8[$864>>0]|0;
   $$phi$trans$insert1758 = $$pre1757&255;
   $$phi$trans$insert1759 = (79212 + ($$phi$trans$insert1758<<2)|0);
   $$pre1760 = HEAP32[$$phi$trans$insert1759>>2]|0;
   $$pre1761 = HEAP8[$866>>0]|0;
   $$pre1762 = HEAP8[$867>>0]|0;
   $$phi$trans$insert1763 = $$pre1762&255;
   $$phi$trans$insert1764 = (79212 + ($$phi$trans$insert1763<<2)|0);
   $$pre1765 = HEAP32[$$phi$trans$insert1764>>2]|0;
   $$pre1766 = HEAP8[$869>>0]|0;
   $870 = $$pre1751&255;
   $871 = $$pre1756&255;
   $872 = $$pre1761&255;
   $873 = $$pre1766&255;
   $$115381633 = $$01537$;$$215441632 = $$11543;
   while(1) {
    $874 = (($$115381633) + -1)|0;
    $875 = HEAP32[$$215441632>>2]|0;
    $876 = HEAP32[$859>>2]|0;
    $877 = $876 & $875;
    $878 = $877 >>> $870;
    $879 = (($$pre1750) + ($878)|0);
    $880 = HEAP8[$879>>0]|0;
    $881 = $880&255;
    $882 = HEAP32[$862>>2]|0;
    $883 = $882 & $875;
    $884 = $883 >>> $871;
    $885 = (($$pre1755) + ($884)|0);
    $886 = HEAP8[$885>>0]|0;
    $887 = $886&255;
    $888 = HEAP32[$865>>2]|0;
    $889 = $888 & $875;
    $890 = $889 >>> $872;
    $891 = (($$pre1760) + ($890)|0);
    $892 = HEAP8[$891>>0]|0;
    $893 = $892&255;
    $894 = HEAP32[$868>>2]|0;
    $895 = $894 & $875;
    $896 = $895 >>> $873;
    $897 = (($$pre1765) + ($896)|0);
    $898 = HEAP8[$897>>0]|0;
    $899 = $898&255;
    $900 = Math_imul($881, $$0)|0;
    $901 = (($900>>>0) / 255)&-1;
    $902 = Math_imul($887, $$01399)|0;
    $903 = (($902>>>0) / 255)&-1;
    $904 = Math_imul($893, $$01400)|0;
    $905 = (($904>>>0) / 255)&-1;
    $906 = $901 >>> $$phi$trans$insert1748;
    $907 = $906 << $870;
    $908 = $903 >>> $$phi$trans$insert1753;
    $909 = $908 << $871;
    $910 = $909 | $907;
    $911 = $905 >>> $$phi$trans$insert1758;
    $912 = $911 << $872;
    $913 = $910 | $912;
    $914 = $899 >>> $$phi$trans$insert1763;
    $915 = $914 << $873;
    $916 = $913 | $915;
    HEAP32[$$215441632>>2] = $916;
    $917 = (($$215441632) + ($$21541<<2)|0);
    $918 = ($874|0)==(0);
    if ($918) {
     break;
    } else {
     $$115381633 = $874;$$215441632 = $917;
    }
   }
   return;
   break;
  }
  default: {
   $919 = ((($0)) + 16|0);
   $920 = HEAP32[$919>>2]|0;
   $921 = ((($12)) + 9|0);
   $922 = HEAP8[$921>>0]|0;
   $923 = $922&255;
   $924 = (($920|0) / ($923|0))&-1;
   $925 = ($4|0)<($2|0);
   $926 = ((($0)) + 20|0);
   $927 = HEAP32[$926>>2]|0;
   if ($925) {
    $934 = Math_imul($924, $4)|0;
    $935 = (($927) + ($934<<2)|0);
    $936 = (($935) + ($3<<2)|0);
    $937 = ($3|0)>($1|0);
    $$sink1562 = $937 ? -1 : 1;
    $938 = (($924) + ($$sink1562))|0;
    $939 = ($10|0)==(0);
    $940 = (($936) + ($938<<2)|0);
    $$1563 = $939 ? $940 : $936;
    $$01533 = $653;$$11528 = $$1563;$$21532 = $938;
   } else {
    $928 = Math_imul($924, $2)|0;
    $929 = (($927) + ($928<<2)|0);
    $930 = (($929) + ($1<<2)|0);
    $931 = ($3|0)<($1|0);
    $$sink1561 = $931 ? -1 : 1;
    $932 = (($924) + ($$sink1561))|0;
    $933 = (($4) - ($2))|0;
    $$01533 = $933;$$11528 = $930;$$21532 = $932;
   }
   $not$1574 = ($10|0)!=(0);
   $941 = $not$1574&1;
   $$01533$ = (($$01533) + ($941))|0;
   $942 = ($$01533$|0)==(0);
   if ($942) {
    return;
   }
   $943 = ((($12)) + 28|0);
   $944 = HEAP8[$943>>0]|0;
   $945 = $944&255;
   $946 = $$0 >>> $945;
   $947 = ((($12)) + 32|0);
   $948 = HEAP8[$947>>0]|0;
   $949 = $948&255;
   $950 = $946 << $949;
   $951 = ((($12)) + 29|0);
   $952 = HEAP8[$951>>0]|0;
   $953 = $952&255;
   $954 = $$01399 >>> $953;
   $955 = ((($12)) + 33|0);
   $956 = HEAP8[$955>>0]|0;
   $957 = $956&255;
   $958 = $954 << $957;
   $959 = $958 | $950;
   $960 = ((($12)) + 30|0);
   $961 = HEAP8[$960>>0]|0;
   $962 = $961&255;
   $963 = $$01400 >>> $962;
   $964 = ((($12)) + 34|0);
   $965 = HEAP8[$964>>0]|0;
   $966 = $965&255;
   $967 = $963 << $966;
   $968 = $959 | $967;
   $969 = ((($12)) + 31|0);
   $970 = HEAP8[$969>>0]|0;
   $971 = $970&255;
   $972 = $17 >>> $971;
   $973 = ((($12)) + 35|0);
   $974 = HEAP8[$973>>0]|0;
   $975 = $974&255;
   $976 = $972 << $975;
   $977 = $968 | $976;
   $$115341623 = $$01533$;$$215291624 = $$11528;
   while(1) {
    $978 = (($$115341623) + -1)|0;
    HEAP32[$$215291624>>2] = $977;
    $979 = (($$215291624) + ($$21532<<2)|0);
    $980 = ($978|0)==(0);
    if ($980) {
     break;
    } else {
     $$115341623 = $978;$$215291624 = $979;
    }
   }
   return;
  }
  }
 } else {
  switch ($5|0) {
  case 1:  {
   $981 = (($3) - ($1))|0;
   $982 = ($981|0)<(0);
   $983 = (0 - ($981))|0;
   $984 = $982 ? $983 : $981;
   $985 = (($4) - ($2))|0;
   $986 = ($985|0)<(0);
   $987 = (0 - ($985))|0;
   $988 = $986 ? $987 : $985;
   $989 = ($984|0)<($988|0);
   if ($989) {
    $993 = $984 << 1;
    $994 = (($993) - ($988))|0;
    $995 = (($984) - ($988))|0;
    $$01493 = 1;$$01499 = 0;$$01503$in = $995;$$01504 = $993;$$01505 = $994;$$01508$in = $988;
   } else {
    $990 = $988 << 1;
    $991 = (($990) - ($984))|0;
    $992 = (($988) - ($984))|0;
    $$01493 = 0;$$01499 = 1;$$01503$in = $992;$$01504 = $990;$$01505 = $991;$$01508$in = $984;
   }
   $$01503 = $$01503$in << 1;
   $996 = ($3|0)<($1|0);
   $997 = (0 - ($$01499))|0;
   $$$01499 = $996 ? $997 : $$01499;
   $$1564 = $996 ? -1 : 1;
   $998 = ($4|0)<($2|0);
   $999 = (0 - ($$01493))|0;
   $$11494 = $998 ? $999 : $$01493;
   $$11492 = $998 ? -1 : 1;
   $not$1569 = ($10|0)!=(0);
   $$01508 = $not$1569&1;
   $$01508$in$$01508 = (($$01508$in) + ($$01508))|0;
   $1000 = ($$01508$in$$01508|0)>(0);
   if (!($1000)) {
    return;
   }
   $1001 = ((($0)) + 20|0);
   $1002 = ((($0)) + 16|0);
   $1003 = ((($12)) + 28|0);
   $1004 = ((($12)) + 12|0);
   $1005 = ((($12)) + 32|0);
   $1006 = ((($12)) + 29|0);
   $1007 = ((($12)) + 16|0);
   $1008 = ((($12)) + 33|0);
   $1009 = ((($12)) + 30|0);
   $1010 = ((($12)) + 20|0);
   $1011 = ((($12)) + 34|0);
   $1012 = ((($12)) + 31|0);
   $1013 = ((($12)) + 24|0);
   $1014 = ((($12)) + 35|0);
   $$pre1726 = HEAP32[$1001>>2]|0;
   $$pre1727 = HEAP8[$1003>>0]|0;
   $$phi$trans$insert1728 = $$pre1727&255;
   $$phi$trans$insert1729 = (79212 + ($$phi$trans$insert1728<<2)|0);
   $$pre1730 = HEAP32[$$phi$trans$insert1729>>2]|0;
   $$pre1731 = HEAP8[$1005>>0]|0;
   $$pre1732 = HEAP8[$1006>>0]|0;
   $$phi$trans$insert1733 = $$pre1732&255;
   $$phi$trans$insert1734 = (79212 + ($$phi$trans$insert1733<<2)|0);
   $$pre1735 = HEAP32[$$phi$trans$insert1734>>2]|0;
   $$pre1736 = HEAP8[$1008>>0]|0;
   $$pre1737 = HEAP8[$1009>>0]|0;
   $$phi$trans$insert1738 = $$pre1737&255;
   $$phi$trans$insert1739 = (79212 + ($$phi$trans$insert1738<<2)|0);
   $$pre1740 = HEAP32[$$phi$trans$insert1739>>2]|0;
   $$pre1741 = HEAP8[$1011>>0]|0;
   $$pre1742 = HEAP8[$1012>>0]|0;
   $$phi$trans$insert1743 = $$pre1742&255;
   $$phi$trans$insert1744 = (79212 + ($$phi$trans$insert1743<<2)|0);
   $$pre1745 = HEAP32[$$phi$trans$insert1744>>2]|0;
   $$pre1746 = HEAP8[$1014>>0]|0;
   $1015 = $$pre1731&255;
   $1016 = $$pre1736&255;
   $1017 = $$pre1741&255;
   $1018 = $$pre1746&255;
   $$014951643 = $2;$$015011642 = $1;$$015151640 = 0;$$115061641 = $$01505;
   while(1) {
    $1019 = HEAP32[$1002>>2]|0;
    $1020 = Math_imul($1019, $$014951643)|0;
    $1021 = (($$pre1726) + ($1020)|0);
    $1022 = $$015011642 << 2;
    $1023 = (($1021) + ($1022)|0);
    $1024 = HEAP32[$1023>>2]|0;
    $1025 = HEAP32[$1004>>2]|0;
    $1026 = $1025 & $1024;
    $1027 = $1026 >>> $1015;
    $1028 = (($$pre1730) + ($1027)|0);
    $1029 = HEAP8[$1028>>0]|0;
    $1030 = $1029&255;
    $1031 = HEAP32[$1007>>2]|0;
    $1032 = $1031 & $1024;
    $1033 = $1032 >>> $1016;
    $1034 = (($$pre1735) + ($1033)|0);
    $1035 = HEAP8[$1034>>0]|0;
    $1036 = $1035&255;
    $1037 = HEAP32[$1010>>2]|0;
    $1038 = $1037 & $1024;
    $1039 = $1038 >>> $1017;
    $1040 = (($$pre1740) + ($1039)|0);
    $1041 = HEAP8[$1040>>0]|0;
    $1042 = $1041&255;
    $1043 = HEAP32[$1013>>2]|0;
    $1044 = $1043 & $1024;
    $1045 = $1044 >>> $1018;
    $1046 = (($$pre1745) + ($1045)|0);
    $1047 = HEAP8[$1046>>0]|0;
    $1048 = $1047&255;
    $1049 = Math_imul($1030, $24)|0;
    $1050 = (($1049>>>0) / 255)&-1;
    $1051 = (($1050) + ($$0))|0;
    $1052 = Math_imul($1036, $24)|0;
    $1053 = (($1052>>>0) / 255)&-1;
    $1054 = (($1053) + ($$01399))|0;
    $1055 = Math_imul($1042, $24)|0;
    $1056 = (($1055>>>0) / 255)&-1;
    $1057 = (($1056) + ($$01400))|0;
    $1058 = Math_imul($1048, $24)|0;
    $1059 = (($1058>>>0) / 255)&-1;
    $1060 = (($1059) + ($17))|0;
    $1061 = $1051 >>> $$phi$trans$insert1728;
    $1062 = $1061 << $1015;
    $1063 = $1054 >>> $$phi$trans$insert1733;
    $1064 = $1063 << $1016;
    $1065 = $1064 | $1062;
    $1066 = $1057 >>> $$phi$trans$insert1738;
    $1067 = $1066 << $1017;
    $1068 = $1065 | $1067;
    $1069 = $1060 >>> $$phi$trans$insert1743;
    $1070 = $1069 << $1018;
    $1071 = $1068 | $1070;
    HEAP32[$1023>>2] = $1071;
    $1072 = ($$115061641|0)<(0);
    $$01504$$01503 = $1072 ? $$01504 : $$01503;
    $$$01499$$1564 = $1072 ? $$$01499 : $$1564;
    $$11494$$11492 = $1072 ? $$11494 : $$11492;
    $$11496 = (($$014951643) + ($$11494$$11492))|0;
    $$11502 = (($$$01499$$1564) + ($$015011642))|0;
    $$21507 = (($$01504$$01503) + ($$115061641))|0;
    $1073 = (($$015151640) + 1)|0;
    $1074 = ($1073|0)<($$01508$in$$01508|0);
    if ($1074) {
     $$014951643 = $$11496;$$015011642 = $$11502;$$015151640 = $1073;$$115061641 = $$21507;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 2:  {
   $1075 = (($3) - ($1))|0;
   $1076 = ($1075|0)<(0);
   $1077 = (0 - ($1075))|0;
   $1078 = $1076 ? $1077 : $1075;
   $1079 = (($4) - ($2))|0;
   $1080 = ($1079|0)<(0);
   $1081 = (0 - ($1079))|0;
   $1082 = $1080 ? $1081 : $1079;
   $1083 = ($1078|0)<($1082|0);
   if ($1083) {
    $1087 = $1078 << 1;
    $1088 = (($1087) - ($1082))|0;
    $1089 = (($1078) - ($1082))|0;
    $$01463 = 1;$$01469 = 0;$$01473$in = $1089;$$01474 = $1087;$$01475 = $1088;$$01478$in = $1082;
   } else {
    $1084 = $1082 << 1;
    $1085 = (($1084) - ($1078))|0;
    $1086 = (($1082) - ($1078))|0;
    $$01463 = 0;$$01469 = 1;$$01473$in = $1086;$$01474 = $1084;$$01475 = $1085;$$01478$in = $1078;
   }
   $$01473 = $$01473$in << 1;
   $1090 = ($3|0)<($1|0);
   $1091 = (0 - ($$01469))|0;
   $$$01469 = $1090 ? $1091 : $$01469;
   $$1565 = $1090 ? -1 : 1;
   $1092 = ($4|0)<($2|0);
   $1093 = (0 - ($$01463))|0;
   $$11464 = $1092 ? $1093 : $$01463;
   $$11462 = $1092 ? -1 : 1;
   $not$1568 = ($10|0)!=(0);
   $$01478 = $not$1568&1;
   $$01478$in$$01478 = (($$01478$in) + ($$01478))|0;
   $1094 = ($$01478$in$$01478|0)>(0);
   if (!($1094)) {
    return;
   }
   $1095 = ((($0)) + 20|0);
   $1096 = ((($0)) + 16|0);
   $1097 = ((($12)) + 28|0);
   $1098 = ((($12)) + 12|0);
   $1099 = ((($12)) + 32|0);
   $1100 = ((($12)) + 29|0);
   $1101 = ((($12)) + 16|0);
   $1102 = ((($12)) + 33|0);
   $1103 = ((($12)) + 30|0);
   $1104 = ((($12)) + 20|0);
   $1105 = ((($12)) + 34|0);
   $1106 = ((($12)) + 31|0);
   $1107 = ((($12)) + 24|0);
   $1108 = ((($12)) + 35|0);
   $$pre1705 = HEAP32[$1095>>2]|0;
   $$pre1706 = HEAP8[$1097>>0]|0;
   $$phi$trans$insert1707 = $$pre1706&255;
   $$phi$trans$insert1708 = (79212 + ($$phi$trans$insert1707<<2)|0);
   $$pre1709 = HEAP32[$$phi$trans$insert1708>>2]|0;
   $$pre1710 = HEAP8[$1099>>0]|0;
   $$pre1711 = HEAP8[$1100>>0]|0;
   $$phi$trans$insert1712 = $$pre1711&255;
   $$phi$trans$insert1713 = (79212 + ($$phi$trans$insert1712<<2)|0);
   $$pre1714 = HEAP32[$$phi$trans$insert1713>>2]|0;
   $$pre1715 = HEAP8[$1102>>0]|0;
   $$pre1716 = HEAP8[$1103>>0]|0;
   $$phi$trans$insert1717 = $$pre1716&255;
   $$phi$trans$insert1718 = (79212 + ($$phi$trans$insert1717<<2)|0);
   $$pre1719 = HEAP32[$$phi$trans$insert1718>>2]|0;
   $$pre1720 = HEAP8[$1105>>0]|0;
   $$pre1721 = HEAP8[$1106>>0]|0;
   $$phi$trans$insert1722 = $$pre1721&255;
   $$phi$trans$insert1723 = (79212 + ($$phi$trans$insert1722<<2)|0);
   $$pre1724 = HEAP32[$$phi$trans$insert1723>>2]|0;
   $$pre1725 = HEAP8[$1108>>0]|0;
   $1109 = $$pre1710&255;
   $1110 = $$pre1715&255;
   $1111 = $$pre1720&255;
   $1112 = $$pre1725&255;
   $$014651648 = $2;$$014711647 = $1;$$014831645 = 0;$$114761646 = $$01475;
   while(1) {
    $1113 = HEAP32[$1096>>2]|0;
    $1114 = Math_imul($1113, $$014651648)|0;
    $1115 = (($$pre1705) + ($1114)|0);
    $1116 = $$014711647 << 2;
    $1117 = (($1115) + ($1116)|0);
    $1118 = HEAP32[$1117>>2]|0;
    $1119 = HEAP32[$1098>>2]|0;
    $1120 = $1119 & $1118;
    $1121 = $1120 >>> $1109;
    $1122 = (($$pre1709) + ($1121)|0);
    $1123 = HEAP8[$1122>>0]|0;
    $1124 = $1123&255;
    $1125 = HEAP32[$1101>>2]|0;
    $1126 = $1125 & $1118;
    $1127 = $1126 >>> $1110;
    $1128 = (($$pre1714) + ($1127)|0);
    $1129 = HEAP8[$1128>>0]|0;
    $1130 = $1129&255;
    $1131 = HEAP32[$1104>>2]|0;
    $1132 = $1131 & $1118;
    $1133 = $1132 >>> $1111;
    $1134 = (($$pre1719) + ($1133)|0);
    $1135 = HEAP8[$1134>>0]|0;
    $1136 = $1135&255;
    $1137 = HEAP32[$1107>>2]|0;
    $1138 = $1137 & $1118;
    $1139 = $1138 >>> $1112;
    $1140 = (($$pre1724) + ($1139)|0);
    $1141 = HEAP8[$1140>>0]|0;
    $1142 = $1141&255;
    $1143 = (($1124) + ($$0))|0;
    $1144 = ($1143>>>0)<(255);
    $$11 = $1144 ? $1143 : 255;
    $1145 = (($1130) + ($$01399))|0;
    $1146 = ($1145>>>0)<(255);
    $$7 = $1146 ? $1145 : 255;
    $1147 = (($1136) + ($$01400))|0;
    $1148 = ($1147>>>0)<(255);
    $$12 = $1148 ? $1147 : 255;
    $1149 = $$11 >>> $$phi$trans$insert1707;
    $1150 = $1149 << $1109;
    $1151 = $$7 >>> $$phi$trans$insert1712;
    $1152 = $1151 << $1110;
    $1153 = $1152 | $1150;
    $1154 = $$12 >>> $$phi$trans$insert1717;
    $1155 = $1154 << $1111;
    $1156 = $1153 | $1155;
    $1157 = $1142 >>> $$phi$trans$insert1722;
    $1158 = $1157 << $1112;
    $1159 = $1156 | $1158;
    HEAP32[$1117>>2] = $1159;
    $1160 = ($$114761646|0)<(0);
    $$01474$$01473 = $1160 ? $$01474 : $$01473;
    $$$01469$$1565 = $1160 ? $$$01469 : $$1565;
    $$11464$$11462 = $1160 ? $$11464 : $$11462;
    $$11466 = (($$014651648) + ($$11464$$11462))|0;
    $$11472 = (($$$01469$$1565) + ($$014711647))|0;
    $$21477 = (($$01474$$01473) + ($$114761646))|0;
    $1161 = (($$014831645) + 1)|0;
    $1162 = ($1161|0)<($$01478$in$$01478|0);
    if ($1162) {
     $$014651648 = $$11466;$$014711647 = $$11472;$$014831645 = $1161;$$114761646 = $$21477;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 4:  {
   $1163 = (($3) - ($1))|0;
   $1164 = ($1163|0)<(0);
   $1165 = (0 - ($1163))|0;
   $1166 = $1164 ? $1165 : $1163;
   $1167 = (($4) - ($2))|0;
   $1168 = ($1167|0)<(0);
   $1169 = (0 - ($1167))|0;
   $1170 = $1168 ? $1169 : $1167;
   $1171 = ($1166|0)<($1170|0);
   if ($1171) {
    $1175 = $1166 << 1;
    $1176 = (($1175) - ($1170))|0;
    $1177 = (($1166) - ($1170))|0;
    $$01434 = 1;$$01440 = 0;$$01444$in = $1177;$$01445 = $1175;$$01446 = $1176;$$01449$in = $1170;
   } else {
    $1172 = $1170 << 1;
    $1173 = (($1172) - ($1166))|0;
    $1174 = (($1170) - ($1166))|0;
    $$01434 = 0;$$01440 = 1;$$01444$in = $1174;$$01445 = $1172;$$01446 = $1173;$$01449$in = $1166;
   }
   $$01444 = $$01444$in << 1;
   $1178 = ($3|0)<($1|0);
   $1179 = (0 - ($$01440))|0;
   $$$01440 = $1178 ? $1179 : $$01440;
   $$1566 = $1178 ? -1 : 1;
   $1180 = ($4|0)<($2|0);
   $1181 = (0 - ($$01434))|0;
   $$11435 = $1180 ? $1181 : $$01434;
   $$11433 = $1180 ? -1 : 1;
   $not$ = ($10|0)!=(0);
   $$01449 = $not$&1;
   $$01449$in$$01449 = (($$01449$in) + ($$01449))|0;
   $1182 = ($$01449$in$$01449|0)>(0);
   if (!($1182)) {
    return;
   }
   $1183 = ((($0)) + 20|0);
   $1184 = ((($0)) + 16|0);
   $1185 = ((($12)) + 28|0);
   $1186 = ((($12)) + 12|0);
   $1187 = ((($12)) + 32|0);
   $1188 = ((($12)) + 29|0);
   $1189 = ((($12)) + 16|0);
   $1190 = ((($12)) + 33|0);
   $1191 = ((($12)) + 30|0);
   $1192 = ((($12)) + 20|0);
   $1193 = ((($12)) + 34|0);
   $1194 = ((($12)) + 31|0);
   $1195 = ((($12)) + 24|0);
   $1196 = ((($12)) + 35|0);
   $$pre = HEAP32[$1183>>2]|0;
   $$pre1686 = HEAP8[$1185>>0]|0;
   $$phi$trans$insert = $$pre1686&255;
   $$phi$trans$insert1687 = (79212 + ($$phi$trans$insert<<2)|0);
   $$pre1688 = HEAP32[$$phi$trans$insert1687>>2]|0;
   $$pre1689 = HEAP8[$1187>>0]|0;
   $$pre1690 = HEAP8[$1188>>0]|0;
   $$phi$trans$insert1691 = $$pre1690&255;
   $$phi$trans$insert1692 = (79212 + ($$phi$trans$insert1691<<2)|0);
   $$pre1693 = HEAP32[$$phi$trans$insert1692>>2]|0;
   $$pre1694 = HEAP8[$1190>>0]|0;
   $$pre1695 = HEAP8[$1191>>0]|0;
   $$phi$trans$insert1696 = $$pre1695&255;
   $$phi$trans$insert1697 = (79212 + ($$phi$trans$insert1696<<2)|0);
   $$pre1698 = HEAP32[$$phi$trans$insert1697>>2]|0;
   $$pre1699 = HEAP8[$1193>>0]|0;
   $$pre1700 = HEAP8[$1194>>0]|0;
   $$phi$trans$insert1701 = $$pre1700&255;
   $$phi$trans$insert1702 = (79212 + ($$phi$trans$insert1701<<2)|0);
   $$pre1703 = HEAP32[$$phi$trans$insert1702>>2]|0;
   $$pre1704 = HEAP8[$1196>>0]|0;
   $1197 = $$pre1689&255;
   $1198 = $$pre1694&255;
   $1199 = $$pre1699&255;
   $1200 = $$pre1704&255;
   $$014361653 = $2;$$014421652 = $1;$$014531650 = 0;$$114471651 = $$01446;
   while(1) {
    $1201 = HEAP32[$1184>>2]|0;
    $1202 = Math_imul($1201, $$014361653)|0;
    $1203 = (($$pre) + ($1202)|0);
    $1204 = $$014421652 << 2;
    $1205 = (($1203) + ($1204)|0);
    $1206 = HEAP32[$1205>>2]|0;
    $1207 = HEAP32[$1186>>2]|0;
    $1208 = $1207 & $1206;
    $1209 = $1208 >>> $1197;
    $1210 = (($$pre1688) + ($1209)|0);
    $1211 = HEAP8[$1210>>0]|0;
    $1212 = $1211&255;
    $1213 = HEAP32[$1189>>2]|0;
    $1214 = $1213 & $1206;
    $1215 = $1214 >>> $1198;
    $1216 = (($$pre1693) + ($1215)|0);
    $1217 = HEAP8[$1216>>0]|0;
    $1218 = $1217&255;
    $1219 = HEAP32[$1192>>2]|0;
    $1220 = $1219 & $1206;
    $1221 = $1220 >>> $1199;
    $1222 = (($$pre1698) + ($1221)|0);
    $1223 = HEAP8[$1222>>0]|0;
    $1224 = $1223&255;
    $1225 = HEAP32[$1195>>2]|0;
    $1226 = $1225 & $1206;
    $1227 = $1226 >>> $1200;
    $1228 = (($$pre1703) + ($1227)|0);
    $1229 = HEAP8[$1228>>0]|0;
    $1230 = $1229&255;
    $1231 = Math_imul($1212, $$0)|0;
    $1232 = (($1231>>>0) / 255)&-1;
    $1233 = Math_imul($1218, $$01399)|0;
    $1234 = (($1233>>>0) / 255)&-1;
    $1235 = Math_imul($1224, $$01400)|0;
    $1236 = (($1235>>>0) / 255)&-1;
    $1237 = $1232 >>> $$phi$trans$insert;
    $1238 = $1237 << $1197;
    $1239 = $1234 >>> $$phi$trans$insert1691;
    $1240 = $1239 << $1198;
    $1241 = $1240 | $1238;
    $1242 = $1236 >>> $$phi$trans$insert1696;
    $1243 = $1242 << $1199;
    $1244 = $1241 | $1243;
    $1245 = $1230 >>> $$phi$trans$insert1701;
    $1246 = $1245 << $1200;
    $1247 = $1244 | $1246;
    HEAP32[$1205>>2] = $1247;
    $1248 = ($$114471651|0)<(0);
    $$01445$$01444 = $1248 ? $$01445 : $$01444;
    $$$01440$$1566 = $1248 ? $$$01440 : $$1566;
    $$11435$$11433 = $1248 ? $$11435 : $$11433;
    $$11437 = (($$014361653) + ($$11435$$11433))|0;
    $$11443 = (($$$01440$$1566) + ($$014421652))|0;
    $$21448 = (($$01445$$01444) + ($$114471651))|0;
    $1249 = (($$014531650) + 1)|0;
    $1250 = ($1249|0)<($$01449$in$$01449|0);
    if ($1250) {
     $$014361653 = $$11437;$$014421652 = $$11443;$$014531650 = $1249;$$114471651 = $$21448;
    } else {
     break;
    }
   }
   return;
   break;
  }
  default: {
   $1251 = (($3) - ($1))|0;
   $1252 = ($1251|0)<(0);
   $1253 = (0 - ($1251))|0;
   $1254 = $1252 ? $1253 : $1251;
   $1255 = (($4) - ($2))|0;
   $1256 = ($1255|0)<(0);
   $1257 = (0 - ($1255))|0;
   $1258 = $1256 ? $1257 : $1255;
   $1259 = ($1254|0)<($1258|0);
   if ($1259) {
    $1263 = $1254 << 1;
    $1264 = (($1263) - ($1258))|0;
    $1265 = (($1254) - ($1258))|0;
    $$01404 = 1;$$01410 = 0;$$01414$in = $1265;$$01415 = $1263;$$01416 = $1264;$$01419$in = $1258;
   } else {
    $1260 = $1258 << 1;
    $1261 = (($1260) - ($1254))|0;
    $1262 = (($1258) - ($1254))|0;
    $$01404 = 0;$$01410 = 1;$$01414$in = $1262;$$01415 = $1260;$$01416 = $1261;$$01419$in = $1254;
   }
   $$01414 = $$01414$in << 1;
   $1266 = ($3|0)<($1|0);
   $1267 = (0 - ($$01410))|0;
   $$$01410 = $1266 ? $1267 : $$01410;
   $$1567 = $1266 ? -1 : 1;
   $1268 = ($4|0)<($2|0);
   $1269 = (0 - ($$01404))|0;
   $$11405 = $1268 ? $1269 : $$01404;
   $$1 = $1268 ? -1 : 1;
   $not$1570 = ($10|0)!=(0);
   $$01419 = $not$1570&1;
   $$01419$in$$01419 = (($$01419$in) + ($$01419))|0;
   $1270 = ($$01419$in$$01419|0)>(0);
   if (!($1270)) {
    return;
   }
   $1271 = ((($0)) + 20|0);
   $1272 = HEAP32[$1271>>2]|0;
   $1273 = ((($0)) + 16|0);
   $1274 = ((($12)) + 28|0);
   $1275 = HEAP8[$1274>>0]|0;
   $1276 = $1275&255;
   $1277 = $$0 >>> $1276;
   $1278 = ((($12)) + 32|0);
   $1279 = HEAP8[$1278>>0]|0;
   $1280 = $1279&255;
   $1281 = $1277 << $1280;
   $1282 = ((($12)) + 29|0);
   $1283 = HEAP8[$1282>>0]|0;
   $1284 = $1283&255;
   $1285 = $$01399 >>> $1284;
   $1286 = ((($12)) + 33|0);
   $1287 = HEAP8[$1286>>0]|0;
   $1288 = $1287&255;
   $1289 = $1285 << $1288;
   $1290 = $1289 | $1281;
   $1291 = ((($12)) + 30|0);
   $1292 = HEAP8[$1291>>0]|0;
   $1293 = $1292&255;
   $1294 = $$01400 >>> $1293;
   $1295 = ((($12)) + 34|0);
   $1296 = HEAP8[$1295>>0]|0;
   $1297 = $1296&255;
   $1298 = $1294 << $1297;
   $1299 = $1290 | $1298;
   $1300 = ((($12)) + 31|0);
   $1301 = HEAP8[$1300>>0]|0;
   $1302 = $1301&255;
   $1303 = $17 >>> $1302;
   $1304 = ((($12)) + 35|0);
   $1305 = HEAP8[$1304>>0]|0;
   $1306 = $1305&255;
   $1307 = $1303 << $1306;
   $1308 = $1299 | $1307;
   $$014061638 = $2;$$014121637 = $1;$$014241635 = 0;$$114171636 = $$01416;
   while(1) {
    $1309 = HEAP32[$1273>>2]|0;
    $1310 = Math_imul($1309, $$014061638)|0;
    $1311 = (($1272) + ($1310)|0);
    $1312 = $$014121637 << 2;
    $1313 = (($1311) + ($1312)|0);
    HEAP32[$1313>>2] = $1308;
    $1314 = ($$114171636|0)<(0);
    $$01415$$01414 = $1314 ? $$01415 : $$01414;
    $$$01410$$1567 = $1314 ? $$$01410 : $$1567;
    $$11405$$1 = $1314 ? $$11405 : $$1;
    $$11407 = (($$014061638) + ($$11405$$1))|0;
    $$11413 = (($$$01410$$1567) + ($$014121637))|0;
    $$21418 = (($$01415$$01414) + ($$114171636))|0;
    $1315 = (($$014241635) + 1)|0;
    $1316 = ($1315|0)<($$01419$in$$01419|0);
    if ($1316) {
     $$014061638 = $$11407;$$014121637 = $$11413;$$014241635 = $1315;$$114171636 = $$21418;
    } else {
     break;
    }
   }
   return;
  }
  }
 }
}
function _SDL_BlendLine_RGB4($0,$1,$2,$3,$4,$5,$6,$7,$8,$9,$10) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 $8 = $8|0;
 $9 = $9|0;
 $10 = $10|0;
 var $$ = 0, $$$01330 = 0, $$$01330$$1479 = 0, $$$01361 = 0, $$$01361$$1478 = 0, $$$01391 = 0, $$$01391$$1477 = 0, $$$01429 = 0, $$$01429$$1476 = 0, $$0 = 0, $$01319 = 0, $$01320 = 0, $$013221515 = 0, $$01324 = 0, $$013261550 = 0, $$01330 = 0, $$013321549 = 0, $$01334 = 0, $$01334$in = 0, $$01335 = 0;
 var $$01335$$01334 = 0, $$01336 = 0, $$01339 = 0, $$01339$in = 0, $$01339$in$$01339 = 0, $$013431518 = 0, $$013441547 = 0, $$013471521 = 0, $$013501513 = 0, $$01355 = 0, $$013571565 = 0, $$01361 = 0, $$013631564 = 0, $$01365 = 0, $$01365$in = 0, $$01366 = 0, $$01366$$01365 = 0, $$01367 = 0, $$01370 = 0, $$01370$in = 0;
 var $$01370$in$$01370 = 0, $$013721527 = 0, $$013751562 = 0, $$013761530 = 0, $$013791533 = 0, $$013821524 = 0, $$01385 = 0, $$013871560 = 0, $$01391 = 0, $$013931559 = 0, $$01395 = 0, $$01395$in = 0, $$01396 = 0, $$01396$$01395 = 0, $$01397 = 0, $$01400 = 0, $$01400$in = 0, $$01400$in$$01400 = 0, $$01404 = 0, $$01404$ = 0;
 var $$014061557 = 0, $$01413 = 0, $$01413$ = 0, $$01423 = 0, $$014251555 = 0, $$01429 = 0, $$014311554 = 0, $$01433 = 0, $$01433$in = 0, $$01434 = 0, $$01434$$01433 = 0, $$01435 = 0, $$01438 = 0, $$01438$in = 0, $$01438$in$$01438 = 0, $$01440 = 0, $$01440$ = 0, $$014451552 = 0, $$01449 = 0, $$01449$ = 0;
 var $$1 = 0, $$10 = 0, $$11 = 0, $$11325 = 0, $$11325$$1 = 0, $$11327 = 0, $$11333 = 0, $$113371548 = 0, $$11342$ph = 0, $$113421514 = 0, $$11346$ph = 0, $$113461517 = 0, $$11349$ph = 0, $$113491520 = 0, $$11352$ph = 0, $$113521512 = 0, $$11354 = 0, $$11356 = 0, $$11356$$11354 = 0, $$11358 = 0;
 var $$11364 = 0, $$113681563 = 0, $$11374$ph = 0, $$113741526 = 0, $$11378$ph = 0, $$113781529 = 0, $$11381$ph = 0, $$113811532 = 0, $$11384 = 0, $$11386 = 0, $$11386$$11384 = 0, $$11388 = 0, $$11394 = 0, $$113981558 = 0, $$11403$ph = 0, $$114031523 = 0, $$114051539 = 0, $$11411 = 0, $$114141542 = 0, $$11419 = 0;
 var $$11422 = 0, $$11424 = 0, $$11424$$11422 = 0, $$11426 = 0, $$11432 = 0, $$114361553 = 0, $$114411545 = 0, $$11447 = 0, $$114501536 = 0, $$11455 = 0, $$12 = 0, $$1457 = 0, $$1458 = 0, $$1459 = 0, $$1460 = 0, $$1461 = 0, $$1462 = 0, $$1463 = 0, $$1464 = 0, $$1466 = 0;
 var $$1469 = 0, $$1472 = 0, $$1475 = 0, $$1476 = 0, $$1477 = 0, $$1478 = 0, $$1479 = 0, $$2 = 0, $$21338 = 0, $$21369 = 0, $$21399 = 0, $$21409 = 0, $$214121538 = 0, $$21417 = 0, $$214201541 = 0, $$21437 = 0, $$21444 = 0, $$214481544 = 0, $$21453 = 0, $$214561535 = 0;
 var $$3 = 0, $$4 = 0, $$5 = 0, $$6 = 0, $$7 = 0, $$8 = 0, $$9 = 0, $$off = 0, $$phi$trans$insert = 0, $$phi$trans$insert1599 = 0, $$phi$trans$insert1603 = 0, $$phi$trans$insert1604 = 0, $$phi$trans$insert1608 = 0, $$phi$trans$insert1609 = 0, $$phi$trans$insert1614 = 0, $$phi$trans$insert1615 = 0, $$phi$trans$insert1619 = 0, $$phi$trans$insert1620 = 0, $$phi$trans$insert1624 = 0, $$phi$trans$insert1625 = 0;
 var $$phi$trans$insert1630 = 0, $$phi$trans$insert1631 = 0, $$phi$trans$insert1635 = 0, $$phi$trans$insert1636 = 0, $$phi$trans$insert1640 = 0, $$phi$trans$insert1641 = 0, $$phi$trans$insert1645 = 0, $$phi$trans$insert1646 = 0, $$phi$trans$insert1650 = 0, $$phi$trans$insert1651 = 0, $$phi$trans$insert1655 = 0, $$phi$trans$insert1656 = 0, $$phi$trans$insert1660 = 0, $$phi$trans$insert1661 = 0, $$phi$trans$insert1665 = 0, $$phi$trans$insert1666 = 0, $$phi$trans$insert1670 = 0, $$phi$trans$insert1671 = 0, $$phi$trans$insert1675 = 0, $$phi$trans$insert1676 = 0;
 var $$phi$trans$insert1680 = 0, $$phi$trans$insert1681 = 0, $$phi$trans$insert1685 = 0, $$phi$trans$insert1686 = 0, $$phi$trans$insert1690 = 0, $$phi$trans$insert1691 = 0, $$phi$trans$insert1695 = 0, $$phi$trans$insert1696 = 0, $$phi$trans$insert1700 = 0, $$phi$trans$insert1701 = 0, $$phi$trans$insert1705 = 0, $$phi$trans$insert1706 = 0, $$phi$trans$insert1710 = 0, $$phi$trans$insert1711 = 0, $$phi$trans$insert1715 = 0, $$phi$trans$insert1716 = 0, $$phi$trans$insert1720 = 0, $$phi$trans$insert1721 = 0, $$phi$trans$insert1725 = 0, $$phi$trans$insert1726 = 0;
 var $$phi$trans$insert1730 = 0, $$phi$trans$insert1731 = 0, $$phi$trans$insert1735 = 0, $$phi$trans$insert1736 = 0, $$phi$trans$insert1740 = 0, $$phi$trans$insert1741 = 0, $$phi$trans$insert1745 = 0, $$phi$trans$insert1746 = 0, $$phi$trans$insert1750 = 0, $$phi$trans$insert1751 = 0, $$phi$trans$insert1755 = 0, $$phi$trans$insert1756 = 0, $$phi$trans$insert1760 = 0, $$phi$trans$insert1761 = 0, $$phi$trans$insert1765 = 0, $$phi$trans$insert1766 = 0, $$phi$trans$insert1770 = 0, $$phi$trans$insert1771 = 0, $$phi$trans$insert1775 = 0, $$phi$trans$insert1776 = 0;
 var $$pre = 0, $$pre1598 = 0, $$pre1600 = 0, $$pre1601 = 0, $$pre1602 = 0, $$pre1605 = 0, $$pre1606 = 0, $$pre1607 = 0, $$pre1610 = 0, $$pre1611 = 0, $$pre1612 = 0, $$pre1613 = 0, $$pre1616 = 0, $$pre1617 = 0, $$pre1618 = 0, $$pre1621 = 0, $$pre1622 = 0, $$pre1623 = 0, $$pre1626 = 0, $$pre1627 = 0;
 var $$pre1628 = 0, $$pre1629 = 0, $$pre1632 = 0, $$pre1633 = 0, $$pre1634 = 0, $$pre1637 = 0, $$pre1638 = 0, $$pre1639 = 0, $$pre1642 = 0, $$pre1643 = 0, $$pre1644 = 0, $$pre1647 = 0, $$pre1648 = 0, $$pre1649 = 0, $$pre1652 = 0, $$pre1653 = 0, $$pre1654 = 0, $$pre1657 = 0, $$pre1658 = 0, $$pre1659 = 0;
 var $$pre1662 = 0, $$pre1663 = 0, $$pre1664 = 0, $$pre1667 = 0, $$pre1668 = 0, $$pre1669 = 0, $$pre1672 = 0, $$pre1673 = 0, $$pre1674 = 0, $$pre1677 = 0, $$pre1678 = 0, $$pre1679 = 0, $$pre1682 = 0, $$pre1683 = 0, $$pre1684 = 0, $$pre1687 = 0, $$pre1688 = 0, $$pre1689 = 0, $$pre1692 = 0, $$pre1693 = 0;
 var $$pre1694 = 0, $$pre1697 = 0, $$pre1698 = 0, $$pre1699 = 0, $$pre1702 = 0, $$pre1703 = 0, $$pre1704 = 0, $$pre1707 = 0, $$pre1708 = 0, $$pre1709 = 0, $$pre1712 = 0, $$pre1713 = 0, $$pre1714 = 0, $$pre1717 = 0, $$pre1718 = 0, $$pre1719 = 0, $$pre1722 = 0, $$pre1723 = 0, $$pre1724 = 0, $$pre1727 = 0;
 var $$pre1728 = 0, $$pre1729 = 0, $$pre1732 = 0, $$pre1733 = 0, $$pre1734 = 0, $$pre1737 = 0, $$pre1738 = 0, $$pre1739 = 0, $$pre1742 = 0, $$pre1743 = 0, $$pre1744 = 0, $$pre1747 = 0, $$pre1748 = 0, $$pre1749 = 0, $$pre1752 = 0, $$pre1753 = 0, $$pre1754 = 0, $$pre1757 = 0, $$pre1758 = 0, $$pre1759 = 0;
 var $$pre1762 = 0, $$pre1763 = 0, $$pre1764 = 0, $$pre1767 = 0, $$pre1768 = 0, $$pre1769 = 0, $$pre1772 = 0, $$pre1773 = 0, $$pre1774 = 0, $$pre1777 = 0, $$pre1778 = 0, $$sink = 0, $$sink1465 = 0, $$sink1467 = 0, $$sink1468 = 0, $$sink1470 = 0, $$sink1471 = 0, $$sink1473 = 0, $$sink1474 = 0, $$sink1567 = 0;
 var $$sink1569 = 0, $$sink1571 = 0, $$sink1573 = 0, $$sink1575 = 0, $$sink1577 = 0, $$sink1579 = 0, $$sink1581 = 0, $100 = 0, $1000 = 0, $1001 = 0, $1002 = 0, $1003 = 0, $1004 = 0, $1005 = 0, $1006 = 0, $1007 = 0, $1008 = 0, $1009 = 0, $101 = 0, $1010 = 0;
 var $1011 = 0, $1012 = 0, $1013 = 0, $1014 = 0, $1015 = 0, $1016 = 0, $1017 = 0, $1018 = 0, $1019 = 0, $102 = 0, $1020 = 0, $1021 = 0, $1022 = 0, $1023 = 0, $1024 = 0, $1025 = 0, $1026 = 0, $1027 = 0, $1028 = 0, $1029 = 0;
 var $103 = 0, $1030 = 0, $1031 = 0, $1032 = 0, $1033 = 0, $1034 = 0, $1035 = 0, $1036 = 0, $1037 = 0, $1038 = 0, $1039 = 0, $104 = 0, $1040 = 0, $1041 = 0, $1042 = 0, $1043 = 0, $1044 = 0, $1045 = 0, $1046 = 0, $1047 = 0;
 var $1048 = 0, $1049 = 0, $105 = 0, $1050 = 0, $1051 = 0, $1052 = 0, $1053 = 0, $1054 = 0, $1055 = 0, $1056 = 0, $1057 = 0, $1058 = 0, $1059 = 0, $106 = 0, $1060 = 0, $1061 = 0, $1062 = 0, $1063 = 0, $1064 = 0, $1065 = 0;
 var $1066 = 0, $1067 = 0, $1068 = 0, $1069 = 0, $107 = 0, $1070 = 0, $1071 = 0, $1072 = 0, $1073 = 0, $1074 = 0, $1075 = 0, $1076 = 0, $1077 = 0, $1078 = 0, $1079 = 0, $108 = 0, $1080 = 0, $1081 = 0, $1082 = 0, $1083 = 0;
 var $1084 = 0, $1085 = 0, $1086 = 0, $1087 = 0, $1088 = 0, $1089 = 0, $109 = 0, $1090 = 0, $1091 = 0, $1092 = 0, $1093 = 0, $1094 = 0, $1095 = 0, $1096 = 0, $1097 = 0, $1098 = 0, $1099 = 0, $11 = 0, $110 = 0, $1100 = 0;
 var $1101 = 0, $1102 = 0, $1103 = 0, $1104 = 0, $1105 = 0, $1106 = 0, $1107 = 0, $1108 = 0, $1109 = 0, $111 = 0, $1110 = 0, $1111 = 0, $1112 = 0, $1113 = 0, $1114 = 0, $1115 = 0, $1116 = 0, $1117 = 0, $1118 = 0, $1119 = 0;
 var $112 = 0, $1120 = 0, $1121 = 0, $1122 = 0, $1123 = 0, $1124 = 0, $1125 = 0, $1126 = 0, $1127 = 0, $1128 = 0, $1129 = 0, $113 = 0, $1130 = 0, $1131 = 0, $1132 = 0, $1133 = 0, $1134 = 0, $1135 = 0, $1136 = 0, $1137 = 0;
 var $1138 = 0, $1139 = 0, $114 = 0, $1140 = 0, $1141 = 0, $1142 = 0, $1143 = 0, $1144 = 0, $1145 = 0, $1146 = 0, $1147 = 0, $1148 = 0, $1149 = 0, $115 = 0, $1150 = 0, $1151 = 0, $1152 = 0, $1153 = 0, $1154 = 0, $1155 = 0;
 var $1156 = 0, $1157 = 0, $1158 = 0, $1159 = 0, $116 = 0, $1160 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0;
 var $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0;
 var $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0;
 var $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0;
 var $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0;
 var $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0;
 var $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0;
 var $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0;
 var $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0;
 var $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0;
 var $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0;
 var $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $40 = 0, $400 = 0, $401 = 0;
 var $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0;
 var $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0;
 var $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0;
 var $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0;
 var $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0;
 var $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0;
 var $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0;
 var $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0;
 var $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0;
 var $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0;
 var $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $60 = 0, $600 = 0, $601 = 0;
 var $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0;
 var $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0;
 var $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0;
 var $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0;
 var $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0;
 var $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0;
 var $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0;
 var $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0;
 var $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0;
 var $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0;
 var $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $80 = 0, $800 = 0, $801 = 0;
 var $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0;
 var $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = 0, $834 = 0, $835 = 0, $836 = 0, $837 = 0, $838 = 0;
 var $839 = 0, $84 = 0, $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0, $850 = 0, $851 = 0, $852 = 0, $853 = 0, $854 = 0, $855 = 0, $856 = 0;
 var $857 = 0, $858 = 0, $859 = 0, $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0, $869 = 0, $87 = 0, $870 = 0, $871 = 0, $872 = 0, $873 = 0, $874 = 0;
 var $875 = 0, $876 = 0, $877 = 0, $878 = 0, $879 = 0, $88 = 0, $880 = 0, $881 = 0, $882 = 0, $883 = 0, $884 = 0, $885 = 0, $886 = 0, $887 = 0, $888 = 0, $889 = 0, $89 = 0, $890 = 0, $891 = 0, $892 = 0;
 var $893 = 0, $894 = 0, $895 = 0, $896 = 0, $897 = 0, $898 = 0, $899 = 0, $90 = 0, $900 = 0, $901 = 0, $902 = 0, $903 = 0, $904 = 0, $905 = 0, $906 = 0, $907 = 0, $908 = 0, $909 = 0, $91 = 0, $910 = 0;
 var $911 = 0, $912 = 0, $913 = 0, $914 = 0, $915 = 0, $916 = 0, $917 = 0, $918 = 0, $919 = 0, $92 = 0, $920 = 0, $921 = 0, $922 = 0, $923 = 0, $924 = 0, $925 = 0, $926 = 0, $927 = 0, $928 = 0, $929 = 0;
 var $93 = 0, $930 = 0, $931 = 0, $932 = 0, $933 = 0, $934 = 0, $935 = 0, $936 = 0, $937 = 0, $938 = 0, $939 = 0, $94 = 0, $940 = 0, $941 = 0, $942 = 0, $943 = 0, $944 = 0, $945 = 0, $946 = 0, $947 = 0;
 var $948 = 0, $949 = 0, $95 = 0, $950 = 0, $951 = 0, $952 = 0, $953 = 0, $954 = 0, $955 = 0, $956 = 0, $957 = 0, $958 = 0, $959 = 0, $96 = 0, $960 = 0, $961 = 0, $962 = 0, $963 = 0, $964 = 0, $965 = 0;
 var $966 = 0, $967 = 0, $968 = 0, $969 = 0, $97 = 0, $970 = 0, $971 = 0, $972 = 0, $973 = 0, $974 = 0, $975 = 0, $976 = 0, $977 = 0, $978 = 0, $979 = 0, $98 = 0, $980 = 0, $981 = 0, $982 = 0, $983 = 0;
 var $984 = 0, $985 = 0, $986 = 0, $987 = 0, $988 = 0, $989 = 0, $99 = 0, $990 = 0, $991 = 0, $992 = 0, $993 = 0, $994 = 0, $995 = 0, $996 = 0, $997 = 0, $998 = 0, $999 = 0, $not$ = 0, $not$1480 = 0, $not$1481 = 0;
 var $not$1482 = 0, $not$1483 = 0, $not$1484 = 0, $not$1485 = 0, $not$1486 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $11 = ((($0)) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $$off = (($5) + -1)|0;
 $13 = ($$off>>>0)<(2);
 $14 = $6&255;
 $15 = $7&255;
 $16 = $8&255;
 $17 = $9&255;
 if ($13) {
  $18 = Math_imul($17, $16)|0;
  $19 = Math_imul($17, $15)|0;
  $20 = Math_imul($17, $14)|0;
  $21 = (($20>>>0) / 255)&-1;
  $22 = (($19>>>0) / 255)&-1;
  $23 = (($18>>>0) / 255)&-1;
  $$0 = $21;$$01319 = $22;$$01320 = $23;
 } else {
  $$0 = $14;$$01319 = $15;$$01320 = $16;
 }
 $24 = $17 ^ 255;
 $25 = ($4|0)==($2|0);
 if ($25) {
  switch ($5|0) {
  case 1:  {
   $26 = ((($0)) + 16|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = ((($12)) + 9|0);
   $29 = HEAP8[$28>>0]|0;
   $30 = $29&255;
   $31 = (($27|0) / ($30|0))&-1;
   $32 = ($3|0)<($1|0);
   $33 = ((($0)) + 20|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = Math_imul($31, $4)|0;
   $36 = (($34) + ($35<<2)|0);
   $37 = ($10|0)!=(0);
   if ($32) {
    $40 = (($36) + ($3<<2)|0);
    $41 = ((($40)) + 4|0);
    $$1457 = $37 ? $40 : $41;
    $42 = (($1) - ($3))|0;
    $$11342$ph = $$1457;$$sink1567 = $42;
   } else {
    $38 = (($36) + ($1<<2)|0);
    $39 = (($3) - ($1))|0;
    $$11342$ph = $38;$$sink1567 = $39;
   }
   $43 = $37&1;
   $44 = (($$sink1567) + ($43))|0;
   $45 = ($44|0)==(0);
   if ($45) {
    return;
   }
   $46 = ((($12)) + 28|0);
   $47 = ((($12)) + 12|0);
   $48 = ((($12)) + 32|0);
   $49 = ((($12)) + 29|0);
   $50 = ((($12)) + 16|0);
   $51 = ((($12)) + 33|0);
   $52 = ((($12)) + 30|0);
   $53 = ((($12)) + 20|0);
   $54 = ((($12)) + 34|0);
   $55 = ((($12)) + 24|0);
   $$pre1764 = HEAP8[$46>>0]|0;
   $$phi$trans$insert1765 = $$pre1764&255;
   $$phi$trans$insert1766 = (79212 + ($$phi$trans$insert1765<<2)|0);
   $$pre1767 = HEAP32[$$phi$trans$insert1766>>2]|0;
   $$pre1768 = HEAP8[$48>>0]|0;
   $$pre1769 = HEAP8[$49>>0]|0;
   $$phi$trans$insert1770 = $$pre1769&255;
   $$phi$trans$insert1771 = (79212 + ($$phi$trans$insert1770<<2)|0);
   $$pre1772 = HEAP32[$$phi$trans$insert1771>>2]|0;
   $$pre1773 = HEAP8[$51>>0]|0;
   $$pre1774 = HEAP8[$52>>0]|0;
   $$phi$trans$insert1775 = $$pre1774&255;
   $$phi$trans$insert1776 = (79212 + ($$phi$trans$insert1775<<2)|0);
   $$pre1777 = HEAP32[$$phi$trans$insert1776>>2]|0;
   $$pre1778 = HEAP8[$54>>0]|0;
   $56 = $$pre1768&255;
   $57 = $$pre1773&255;
   $58 = $$pre1778&255;
   $$013221515 = $44;$$113421514 = $$11342$ph;
   while(1) {
    $59 = (($$013221515) + -1)|0;
    $60 = HEAP32[$$113421514>>2]|0;
    $61 = HEAP32[$47>>2]|0;
    $62 = $61 & $60;
    $63 = $62 >>> $56;
    $64 = (($$pre1767) + ($63)|0);
    $65 = HEAP8[$64>>0]|0;
    $66 = $65&255;
    $67 = HEAP32[$50>>2]|0;
    $68 = $67 & $60;
    $69 = $68 >>> $57;
    $70 = (($$pre1772) + ($69)|0);
    $71 = HEAP8[$70>>0]|0;
    $72 = $71&255;
    $73 = HEAP32[$53>>2]|0;
    $74 = $73 & $60;
    $75 = $74 >>> $58;
    $76 = (($$pre1777) + ($75)|0);
    $77 = HEAP8[$76>>0]|0;
    $78 = $77&255;
    $79 = Math_imul($66, $24)|0;
    $80 = (($79>>>0) / 255)&-1;
    $81 = (($80) + ($$0))|0;
    $82 = Math_imul($72, $24)|0;
    $83 = (($82>>>0) / 255)&-1;
    $84 = (($83) + ($$01319))|0;
    $85 = Math_imul($78, $24)|0;
    $86 = (($85>>>0) / 255)&-1;
    $87 = (($86) + ($$01320))|0;
    $88 = $81 >>> $$phi$trans$insert1765;
    $89 = $88 << $56;
    $90 = $84 >>> $$phi$trans$insert1770;
    $91 = $90 << $57;
    $92 = $91 | $89;
    $93 = $87 >>> $$phi$trans$insert1775;
    $94 = $93 << $58;
    $95 = HEAP32[$55>>2]|0;
    $96 = $92 | $95;
    $97 = $96 | $94;
    HEAP32[$$113421514>>2] = $97;
    $98 = ((($$113421514)) + 4|0);
    $99 = ($59|0)==(0);
    if ($99) {
     break;
    } else {
     $$013221515 = $59;$$113421514 = $98;
    }
   }
   return;
   break;
  }
  case 2:  {
   $100 = ((($0)) + 16|0);
   $101 = HEAP32[$100>>2]|0;
   $102 = ((($12)) + 9|0);
   $103 = HEAP8[$102>>0]|0;
   $104 = $103&255;
   $105 = (($101|0) / ($104|0))&-1;
   $106 = ($3|0)<($1|0);
   $107 = ((($0)) + 20|0);
   $108 = HEAP32[$107>>2]|0;
   $109 = Math_imul($105, $4)|0;
   $110 = (($108) + ($109<<2)|0);
   $111 = ($10|0)!=(0);
   if ($106) {
    $114 = (($110) + ($3<<2)|0);
    $115 = ((($114)) + 4|0);
    $$1458 = $111 ? $114 : $115;
    $116 = (($1) - ($3))|0;
    $$11346$ph = $$1458;$$sink1569 = $116;
   } else {
    $112 = (($110) + ($1<<2)|0);
    $113 = (($3) - ($1))|0;
    $$11346$ph = $112;$$sink1569 = $113;
   }
   $117 = $111&1;
   $118 = (($$sink1569) + ($117))|0;
   $119 = ($118|0)==(0);
   if ($119) {
    return;
   }
   $120 = ((($12)) + 28|0);
   $121 = ((($12)) + 12|0);
   $122 = ((($12)) + 32|0);
   $123 = ((($12)) + 29|0);
   $124 = ((($12)) + 16|0);
   $125 = ((($12)) + 33|0);
   $126 = ((($12)) + 30|0);
   $127 = ((($12)) + 20|0);
   $128 = ((($12)) + 34|0);
   $129 = ((($12)) + 24|0);
   $$pre1749 = HEAP8[$120>>0]|0;
   $$phi$trans$insert1750 = $$pre1749&255;
   $$phi$trans$insert1751 = (79212 + ($$phi$trans$insert1750<<2)|0);
   $$pre1752 = HEAP32[$$phi$trans$insert1751>>2]|0;
   $$pre1753 = HEAP8[$122>>0]|0;
   $$pre1754 = HEAP8[$123>>0]|0;
   $$phi$trans$insert1755 = $$pre1754&255;
   $$phi$trans$insert1756 = (79212 + ($$phi$trans$insert1755<<2)|0);
   $$pre1757 = HEAP32[$$phi$trans$insert1756>>2]|0;
   $$pre1758 = HEAP8[$125>>0]|0;
   $$pre1759 = HEAP8[$126>>0]|0;
   $$phi$trans$insert1760 = $$pre1759&255;
   $$phi$trans$insert1761 = (79212 + ($$phi$trans$insert1760<<2)|0);
   $$pre1762 = HEAP32[$$phi$trans$insert1761>>2]|0;
   $$pre1763 = HEAP8[$128>>0]|0;
   $130 = $$pre1753&255;
   $131 = $$pre1758&255;
   $132 = $$pre1763&255;
   $$013431518 = $118;$$113461517 = $$11346$ph;
   while(1) {
    $133 = (($$013431518) + -1)|0;
    $134 = HEAP32[$$113461517>>2]|0;
    $135 = HEAP32[$121>>2]|0;
    $136 = $135 & $134;
    $137 = $136 >>> $130;
    $138 = (($$pre1752) + ($137)|0);
    $139 = HEAP8[$138>>0]|0;
    $140 = $139&255;
    $141 = HEAP32[$124>>2]|0;
    $142 = $141 & $134;
    $143 = $142 >>> $131;
    $144 = (($$pre1757) + ($143)|0);
    $145 = HEAP8[$144>>0]|0;
    $146 = $145&255;
    $147 = HEAP32[$127>>2]|0;
    $148 = $147 & $134;
    $149 = $148 >>> $132;
    $150 = (($$pre1762) + ($149)|0);
    $151 = HEAP8[$150>>0]|0;
    $152 = $151&255;
    $153 = (($140) + ($$0))|0;
    $154 = ($153>>>0)<(255);
    $$ = $154 ? $153 : 255;
    $155 = (($146) + ($$01319))|0;
    $156 = ($155>>>0)<(255);
    $$8 = $156 ? $155 : 255;
    $157 = (($152) + ($$01320))|0;
    $158 = ($157>>>0)<(255);
    $$2 = $158 ? $157 : 255;
    $159 = $$ >>> $$phi$trans$insert1750;
    $160 = $159 << $130;
    $161 = $$8 >>> $$phi$trans$insert1755;
    $162 = $161 << $131;
    $163 = $162 | $160;
    $164 = $$2 >>> $$phi$trans$insert1760;
    $165 = $164 << $132;
    $166 = HEAP32[$129>>2]|0;
    $167 = $163 | $166;
    $168 = $167 | $165;
    HEAP32[$$113461517>>2] = $168;
    $169 = ((($$113461517)) + 4|0);
    $170 = ($133|0)==(0);
    if ($170) {
     break;
    } else {
     $$013431518 = $133;$$113461517 = $169;
    }
   }
   return;
   break;
  }
  case 4:  {
   $171 = ((($0)) + 16|0);
   $172 = HEAP32[$171>>2]|0;
   $173 = ((($12)) + 9|0);
   $174 = HEAP8[$173>>0]|0;
   $175 = $174&255;
   $176 = (($172|0) / ($175|0))&-1;
   $177 = ($3|0)<($1|0);
   $178 = ((($0)) + 20|0);
   $179 = HEAP32[$178>>2]|0;
   $180 = Math_imul($176, $4)|0;
   $181 = (($179) + ($180<<2)|0);
   $182 = ($10|0)!=(0);
   if ($177) {
    $185 = (($181) + ($3<<2)|0);
    $186 = ((($185)) + 4|0);
    $$1459 = $182 ? $185 : $186;
    $187 = (($1) - ($3))|0;
    $$11349$ph = $$1459;$$sink1571 = $187;
   } else {
    $183 = (($181) + ($1<<2)|0);
    $184 = (($3) - ($1))|0;
    $$11349$ph = $183;$$sink1571 = $184;
   }
   $188 = $182&1;
   $189 = (($$sink1571) + ($188))|0;
   $190 = ($189|0)==(0);
   if ($190) {
    return;
   }
   $191 = ((($12)) + 28|0);
   $192 = ((($12)) + 12|0);
   $193 = ((($12)) + 32|0);
   $194 = ((($12)) + 29|0);
   $195 = ((($12)) + 16|0);
   $196 = ((($12)) + 33|0);
   $197 = ((($12)) + 30|0);
   $198 = ((($12)) + 20|0);
   $199 = ((($12)) + 34|0);
   $200 = ((($12)) + 24|0);
   $$pre1734 = HEAP8[$191>>0]|0;
   $$phi$trans$insert1735 = $$pre1734&255;
   $$phi$trans$insert1736 = (79212 + ($$phi$trans$insert1735<<2)|0);
   $$pre1737 = HEAP32[$$phi$trans$insert1736>>2]|0;
   $$pre1738 = HEAP8[$193>>0]|0;
   $$pre1739 = HEAP8[$194>>0]|0;
   $$phi$trans$insert1740 = $$pre1739&255;
   $$phi$trans$insert1741 = (79212 + ($$phi$trans$insert1740<<2)|0);
   $$pre1742 = HEAP32[$$phi$trans$insert1741>>2]|0;
   $$pre1743 = HEAP8[$196>>0]|0;
   $$pre1744 = HEAP8[$197>>0]|0;
   $$phi$trans$insert1745 = $$pre1744&255;
   $$phi$trans$insert1746 = (79212 + ($$phi$trans$insert1745<<2)|0);
   $$pre1747 = HEAP32[$$phi$trans$insert1746>>2]|0;
   $$pre1748 = HEAP8[$199>>0]|0;
   $201 = $$pre1738&255;
   $202 = $$pre1743&255;
   $203 = $$pre1748&255;
   $$013471521 = $189;$$113491520 = $$11349$ph;
   while(1) {
    $204 = (($$013471521) + -1)|0;
    $205 = HEAP32[$$113491520>>2]|0;
    $206 = HEAP32[$192>>2]|0;
    $207 = $206 & $205;
    $208 = $207 >>> $201;
    $209 = (($$pre1737) + ($208)|0);
    $210 = HEAP8[$209>>0]|0;
    $211 = $210&255;
    $212 = HEAP32[$195>>2]|0;
    $213 = $212 & $205;
    $214 = $213 >>> $202;
    $215 = (($$pre1742) + ($214)|0);
    $216 = HEAP8[$215>>0]|0;
    $217 = $216&255;
    $218 = HEAP32[$198>>2]|0;
    $219 = $218 & $205;
    $220 = $219 >>> $203;
    $221 = (($$pre1747) + ($220)|0);
    $222 = HEAP8[$221>>0]|0;
    $223 = $222&255;
    $224 = Math_imul($211, $$0)|0;
    $225 = (($224>>>0) / 255)&-1;
    $226 = Math_imul($217, $$01319)|0;
    $227 = (($226>>>0) / 255)&-1;
    $228 = Math_imul($223, $$01320)|0;
    $229 = (($228>>>0) / 255)&-1;
    $230 = $225 >>> $$phi$trans$insert1735;
    $231 = $230 << $201;
    $232 = $227 >>> $$phi$trans$insert1740;
    $233 = $232 << $202;
    $234 = $233 | $231;
    $235 = $229 >>> $$phi$trans$insert1745;
    $236 = $235 << $203;
    $237 = HEAP32[$200>>2]|0;
    $238 = $234 | $237;
    $239 = $238 | $236;
    HEAP32[$$113491520>>2] = $239;
    $240 = ((($$113491520)) + 4|0);
    $241 = ($204|0)==(0);
    if ($241) {
     break;
    } else {
     $$013471521 = $204;$$113491520 = $240;
    }
   }
   return;
   break;
  }
  default: {
   $242 = ((($0)) + 16|0);
   $243 = HEAP32[$242>>2]|0;
   $244 = ((($12)) + 9|0);
   $245 = HEAP8[$244>>0]|0;
   $246 = $245&255;
   $247 = (($243|0) / ($246|0))&-1;
   $248 = ($3|0)<($1|0);
   $249 = ((($0)) + 20|0);
   $250 = HEAP32[$249>>2]|0;
   $251 = Math_imul($247, $4)|0;
   $252 = (($250) + ($251<<2)|0);
   $253 = ($10|0)!=(0);
   if ($248) {
    $256 = (($252) + ($3<<2)|0);
    $257 = ((($256)) + 4|0);
    $$1460 = $253 ? $256 : $257;
    $258 = (($1) - ($3))|0;
    $$11352$ph = $$1460;$$sink1573 = $258;
   } else {
    $254 = (($252) + ($1<<2)|0);
    $255 = (($3) - ($1))|0;
    $$11352$ph = $254;$$sink1573 = $255;
   }
   $259 = $253&1;
   $260 = (($$sink1573) + ($259))|0;
   $261 = ($260|0)==(0);
   if ($261) {
    return;
   }
   $262 = ((($12)) + 28|0);
   $263 = HEAP8[$262>>0]|0;
   $264 = $263&255;
   $265 = $$0 >>> $264;
   $266 = ((($12)) + 32|0);
   $267 = HEAP8[$266>>0]|0;
   $268 = $267&255;
   $269 = $265 << $268;
   $270 = ((($12)) + 29|0);
   $271 = HEAP8[$270>>0]|0;
   $272 = $271&255;
   $273 = $$01319 >>> $272;
   $274 = ((($12)) + 33|0);
   $275 = HEAP8[$274>>0]|0;
   $276 = $275&255;
   $277 = $273 << $276;
   $278 = $277 | $269;
   $279 = ((($12)) + 30|0);
   $280 = HEAP8[$279>>0]|0;
   $281 = $280&255;
   $282 = $$01320 >>> $281;
   $283 = ((($12)) + 34|0);
   $284 = HEAP8[$283>>0]|0;
   $285 = $284&255;
   $286 = $282 << $285;
   $287 = ((($12)) + 24|0);
   $$013501513 = $260;$$113521512 = $$11352$ph;
   while(1) {
    $288 = (($$013501513) + -1)|0;
    $289 = HEAP32[$287>>2]|0;
    $290 = $278 | $289;
    $291 = $290 | $286;
    HEAP32[$$113521512>>2] = $291;
    $292 = ((($$113521512)) + 4|0);
    $293 = ($288|0)==(0);
    if ($293) {
     break;
    } else {
     $$013501513 = $288;$$113521512 = $292;
    }
   }
   return;
  }
  }
 }
 $294 = ($3|0)==($1|0);
 if ($294) {
  switch ($5|0) {
  case 1:  {
   $295 = ((($0)) + 16|0);
   $296 = HEAP32[$295>>2]|0;
   $297 = ((($12)) + 9|0);
   $298 = HEAP8[$297>>0]|0;
   $299 = $298&255;
   $300 = (($296|0) / ($299|0))&-1;
   $301 = ($4|0)<($2|0);
   $302 = ((($0)) + 20|0);
   $303 = HEAP32[$302>>2]|0;
   $304 = ($10|0)!=(0);
   if ($301) {
    $309 = Math_imul($300, $4)|0;
    $310 = (($303) + ($309<<2)|0);
    $311 = (($310) + ($3<<2)|0);
    $312 = (($311) + ($300<<2)|0);
    $$1461 = $304 ? $311 : $312;
    $313 = (($2) - ($4))|0;
    $$11374$ph = $$1461;$$sink1575 = $313;
   } else {
    $305 = Math_imul($300, $2)|0;
    $306 = (($303) + ($305<<2)|0);
    $307 = (($306) + ($3<<2)|0);
    $308 = (($4) - ($2))|0;
    $$11374$ph = $307;$$sink1575 = $308;
   }
   $314 = $304&1;
   $315 = (($$sink1575) + ($314))|0;
   $316 = ($315|0)==(0);
   if ($316) {
    return;
   }
   $317 = ((($12)) + 28|0);
   $318 = ((($12)) + 12|0);
   $319 = ((($12)) + 32|0);
   $320 = ((($12)) + 29|0);
   $321 = ((($12)) + 16|0);
   $322 = ((($12)) + 33|0);
   $323 = ((($12)) + 30|0);
   $324 = ((($12)) + 20|0);
   $325 = ((($12)) + 34|0);
   $326 = ((($12)) + 24|0);
   $$pre1719 = HEAP8[$317>>0]|0;
   $$phi$trans$insert1720 = $$pre1719&255;
   $$phi$trans$insert1721 = (79212 + ($$phi$trans$insert1720<<2)|0);
   $$pre1722 = HEAP32[$$phi$trans$insert1721>>2]|0;
   $$pre1723 = HEAP8[$319>>0]|0;
   $$pre1724 = HEAP8[$320>>0]|0;
   $$phi$trans$insert1725 = $$pre1724&255;
   $$phi$trans$insert1726 = (79212 + ($$phi$trans$insert1725<<2)|0);
   $$pre1727 = HEAP32[$$phi$trans$insert1726>>2]|0;
   $$pre1728 = HEAP8[$322>>0]|0;
   $$pre1729 = HEAP8[$323>>0]|0;
   $$phi$trans$insert1730 = $$pre1729&255;
   $$phi$trans$insert1731 = (79212 + ($$phi$trans$insert1730<<2)|0);
   $$pre1732 = HEAP32[$$phi$trans$insert1731>>2]|0;
   $$pre1733 = HEAP8[$325>>0]|0;
   $327 = $$pre1723&255;
   $328 = $$pre1728&255;
   $329 = $$pre1733&255;
   $$013721527 = $315;$$113741526 = $$11374$ph;
   while(1) {
    $330 = (($$013721527) + -1)|0;
    $331 = HEAP32[$$113741526>>2]|0;
    $332 = HEAP32[$318>>2]|0;
    $333 = $332 & $331;
    $334 = $333 >>> $327;
    $335 = (($$pre1722) + ($334)|0);
    $336 = HEAP8[$335>>0]|0;
    $337 = $336&255;
    $338 = HEAP32[$321>>2]|0;
    $339 = $338 & $331;
    $340 = $339 >>> $328;
    $341 = (($$pre1727) + ($340)|0);
    $342 = HEAP8[$341>>0]|0;
    $343 = $342&255;
    $344 = HEAP32[$324>>2]|0;
    $345 = $344 & $331;
    $346 = $345 >>> $329;
    $347 = (($$pre1732) + ($346)|0);
    $348 = HEAP8[$347>>0]|0;
    $349 = $348&255;
    $350 = Math_imul($337, $24)|0;
    $351 = (($350>>>0) / 255)&-1;
    $352 = (($351) + ($$0))|0;
    $353 = Math_imul($343, $24)|0;
    $354 = (($353>>>0) / 255)&-1;
    $355 = (($354) + ($$01319))|0;
    $356 = Math_imul($349, $24)|0;
    $357 = (($356>>>0) / 255)&-1;
    $358 = (($357) + ($$01320))|0;
    $359 = $352 >>> $$phi$trans$insert1720;
    $360 = $359 << $327;
    $361 = $355 >>> $$phi$trans$insert1725;
    $362 = $361 << $328;
    $363 = $362 | $360;
    $364 = $358 >>> $$phi$trans$insert1730;
    $365 = $364 << $329;
    $366 = HEAP32[$326>>2]|0;
    $367 = $363 | $366;
    $368 = $367 | $365;
    HEAP32[$$113741526>>2] = $368;
    $369 = (($$113741526) + ($300<<2)|0);
    $370 = ($330|0)==(0);
    if ($370) {
     break;
    } else {
     $$013721527 = $330;$$113741526 = $369;
    }
   }
   return;
   break;
  }
  case 2:  {
   $371 = ((($0)) + 16|0);
   $372 = HEAP32[$371>>2]|0;
   $373 = ((($12)) + 9|0);
   $374 = HEAP8[$373>>0]|0;
   $375 = $374&255;
   $376 = (($372|0) / ($375|0))&-1;
   $377 = ($4|0)<($2|0);
   $378 = ((($0)) + 20|0);
   $379 = HEAP32[$378>>2]|0;
   $380 = ($10|0)!=(0);
   if ($377) {
    $385 = Math_imul($376, $4)|0;
    $386 = (($379) + ($385<<2)|0);
    $387 = (($386) + ($3<<2)|0);
    $388 = (($387) + ($376<<2)|0);
    $$1462 = $380 ? $387 : $388;
    $389 = (($2) - ($4))|0;
    $$11378$ph = $$1462;$$sink1577 = $389;
   } else {
    $381 = Math_imul($376, $2)|0;
    $382 = (($379) + ($381<<2)|0);
    $383 = (($382) + ($3<<2)|0);
    $384 = (($4) - ($2))|0;
    $$11378$ph = $383;$$sink1577 = $384;
   }
   $390 = $380&1;
   $391 = (($$sink1577) + ($390))|0;
   $392 = ($391|0)==(0);
   if ($392) {
    return;
   }
   $393 = ((($12)) + 28|0);
   $394 = ((($12)) + 12|0);
   $395 = ((($12)) + 32|0);
   $396 = ((($12)) + 29|0);
   $397 = ((($12)) + 16|0);
   $398 = ((($12)) + 33|0);
   $399 = ((($12)) + 30|0);
   $400 = ((($12)) + 20|0);
   $401 = ((($12)) + 34|0);
   $402 = ((($12)) + 24|0);
   $$pre1704 = HEAP8[$393>>0]|0;
   $$phi$trans$insert1705 = $$pre1704&255;
   $$phi$trans$insert1706 = (79212 + ($$phi$trans$insert1705<<2)|0);
   $$pre1707 = HEAP32[$$phi$trans$insert1706>>2]|0;
   $$pre1708 = HEAP8[$395>>0]|0;
   $$pre1709 = HEAP8[$396>>0]|0;
   $$phi$trans$insert1710 = $$pre1709&255;
   $$phi$trans$insert1711 = (79212 + ($$phi$trans$insert1710<<2)|0);
   $$pre1712 = HEAP32[$$phi$trans$insert1711>>2]|0;
   $$pre1713 = HEAP8[$398>>0]|0;
   $$pre1714 = HEAP8[$399>>0]|0;
   $$phi$trans$insert1715 = $$pre1714&255;
   $$phi$trans$insert1716 = (79212 + ($$phi$trans$insert1715<<2)|0);
   $$pre1717 = HEAP32[$$phi$trans$insert1716>>2]|0;
   $$pre1718 = HEAP8[$401>>0]|0;
   $403 = $$pre1708&255;
   $404 = $$pre1713&255;
   $405 = $$pre1718&255;
   $$013761530 = $391;$$113781529 = $$11378$ph;
   while(1) {
    $406 = (($$013761530) + -1)|0;
    $407 = HEAP32[$$113781529>>2]|0;
    $408 = HEAP32[$394>>2]|0;
    $409 = $408 & $407;
    $410 = $409 >>> $403;
    $411 = (($$pre1707) + ($410)|0);
    $412 = HEAP8[$411>>0]|0;
    $413 = $412&255;
    $414 = HEAP32[$397>>2]|0;
    $415 = $414 & $407;
    $416 = $415 >>> $404;
    $417 = (($$pre1712) + ($416)|0);
    $418 = HEAP8[$417>>0]|0;
    $419 = $418&255;
    $420 = HEAP32[$400>>2]|0;
    $421 = $420 & $407;
    $422 = $421 >>> $405;
    $423 = (($$pre1717) + ($422)|0);
    $424 = HEAP8[$423>>0]|0;
    $425 = $424&255;
    $426 = (($413) + ($$0))|0;
    $427 = ($426>>>0)<(255);
    $$3 = $427 ? $426 : 255;
    $428 = (($419) + ($$01319))|0;
    $429 = ($428>>>0)<(255);
    $$9 = $429 ? $428 : 255;
    $430 = (($425) + ($$01320))|0;
    $431 = ($430>>>0)<(255);
    $$4 = $431 ? $430 : 255;
    $432 = $$3 >>> $$phi$trans$insert1705;
    $433 = $432 << $403;
    $434 = $$9 >>> $$phi$trans$insert1710;
    $435 = $434 << $404;
    $436 = $435 | $433;
    $437 = $$4 >>> $$phi$trans$insert1715;
    $438 = $437 << $405;
    $439 = HEAP32[$402>>2]|0;
    $440 = $436 | $439;
    $441 = $440 | $438;
    HEAP32[$$113781529>>2] = $441;
    $442 = (($$113781529) + ($376<<2)|0);
    $443 = ($406|0)==(0);
    if ($443) {
     break;
    } else {
     $$013761530 = $406;$$113781529 = $442;
    }
   }
   return;
   break;
  }
  case 4:  {
   $444 = ((($0)) + 16|0);
   $445 = HEAP32[$444>>2]|0;
   $446 = ((($12)) + 9|0);
   $447 = HEAP8[$446>>0]|0;
   $448 = $447&255;
   $449 = (($445|0) / ($448|0))&-1;
   $450 = ($4|0)<($2|0);
   $451 = ((($0)) + 20|0);
   $452 = HEAP32[$451>>2]|0;
   $453 = ($10|0)!=(0);
   if ($450) {
    $458 = Math_imul($449, $4)|0;
    $459 = (($452) + ($458<<2)|0);
    $460 = (($459) + ($3<<2)|0);
    $461 = (($460) + ($449<<2)|0);
    $$1463 = $453 ? $460 : $461;
    $462 = (($2) - ($4))|0;
    $$11381$ph = $$1463;$$sink1579 = $462;
   } else {
    $454 = Math_imul($449, $2)|0;
    $455 = (($452) + ($454<<2)|0);
    $456 = (($455) + ($3<<2)|0);
    $457 = (($4) - ($2))|0;
    $$11381$ph = $456;$$sink1579 = $457;
   }
   $463 = $453&1;
   $464 = (($$sink1579) + ($463))|0;
   $465 = ($464|0)==(0);
   if ($465) {
    return;
   }
   $466 = ((($12)) + 28|0);
   $467 = ((($12)) + 12|0);
   $468 = ((($12)) + 32|0);
   $469 = ((($12)) + 29|0);
   $470 = ((($12)) + 16|0);
   $471 = ((($12)) + 33|0);
   $472 = ((($12)) + 30|0);
   $473 = ((($12)) + 20|0);
   $474 = ((($12)) + 34|0);
   $475 = ((($12)) + 24|0);
   $$pre1689 = HEAP8[$466>>0]|0;
   $$phi$trans$insert1690 = $$pre1689&255;
   $$phi$trans$insert1691 = (79212 + ($$phi$trans$insert1690<<2)|0);
   $$pre1692 = HEAP32[$$phi$trans$insert1691>>2]|0;
   $$pre1693 = HEAP8[$468>>0]|0;
   $$pre1694 = HEAP8[$469>>0]|0;
   $$phi$trans$insert1695 = $$pre1694&255;
   $$phi$trans$insert1696 = (79212 + ($$phi$trans$insert1695<<2)|0);
   $$pre1697 = HEAP32[$$phi$trans$insert1696>>2]|0;
   $$pre1698 = HEAP8[$471>>0]|0;
   $$pre1699 = HEAP8[$472>>0]|0;
   $$phi$trans$insert1700 = $$pre1699&255;
   $$phi$trans$insert1701 = (79212 + ($$phi$trans$insert1700<<2)|0);
   $$pre1702 = HEAP32[$$phi$trans$insert1701>>2]|0;
   $$pre1703 = HEAP8[$474>>0]|0;
   $476 = $$pre1693&255;
   $477 = $$pre1698&255;
   $478 = $$pre1703&255;
   $$013791533 = $464;$$113811532 = $$11381$ph;
   while(1) {
    $479 = (($$013791533) + -1)|0;
    $480 = HEAP32[$$113811532>>2]|0;
    $481 = HEAP32[$467>>2]|0;
    $482 = $481 & $480;
    $483 = $482 >>> $476;
    $484 = (($$pre1692) + ($483)|0);
    $485 = HEAP8[$484>>0]|0;
    $486 = $485&255;
    $487 = HEAP32[$470>>2]|0;
    $488 = $487 & $480;
    $489 = $488 >>> $477;
    $490 = (($$pre1697) + ($489)|0);
    $491 = HEAP8[$490>>0]|0;
    $492 = $491&255;
    $493 = HEAP32[$473>>2]|0;
    $494 = $493 & $480;
    $495 = $494 >>> $478;
    $496 = (($$pre1702) + ($495)|0);
    $497 = HEAP8[$496>>0]|0;
    $498 = $497&255;
    $499 = Math_imul($486, $$0)|0;
    $500 = (($499>>>0) / 255)&-1;
    $501 = Math_imul($492, $$01319)|0;
    $502 = (($501>>>0) / 255)&-1;
    $503 = Math_imul($498, $$01320)|0;
    $504 = (($503>>>0) / 255)&-1;
    $505 = $500 >>> $$phi$trans$insert1690;
    $506 = $505 << $476;
    $507 = $502 >>> $$phi$trans$insert1695;
    $508 = $507 << $477;
    $509 = $508 | $506;
    $510 = $504 >>> $$phi$trans$insert1700;
    $511 = $510 << $478;
    $512 = HEAP32[$475>>2]|0;
    $513 = $509 | $512;
    $514 = $513 | $511;
    HEAP32[$$113811532>>2] = $514;
    $515 = (($$113811532) + ($449<<2)|0);
    $516 = ($479|0)==(0);
    if ($516) {
     break;
    } else {
     $$013791533 = $479;$$113811532 = $515;
    }
   }
   return;
   break;
  }
  default: {
   $517 = ((($0)) + 16|0);
   $518 = HEAP32[$517>>2]|0;
   $519 = ((($12)) + 9|0);
   $520 = HEAP8[$519>>0]|0;
   $521 = $520&255;
   $522 = (($518|0) / ($521|0))&-1;
   $523 = ($4|0)<($2|0);
   $524 = ((($0)) + 20|0);
   $525 = HEAP32[$524>>2]|0;
   $526 = ($10|0)!=(0);
   if ($523) {
    $531 = Math_imul($522, $4)|0;
    $532 = (($525) + ($531<<2)|0);
    $533 = (($532) + ($3<<2)|0);
    $534 = (($533) + ($522<<2)|0);
    $$1464 = $526 ? $533 : $534;
    $535 = (($2) - ($4))|0;
    $$11403$ph = $$1464;$$sink1581 = $535;
   } else {
    $527 = Math_imul($522, $2)|0;
    $528 = (($525) + ($527<<2)|0);
    $529 = (($528) + ($3<<2)|0);
    $530 = (($4) - ($2))|0;
    $$11403$ph = $529;$$sink1581 = $530;
   }
   $536 = $526&1;
   $537 = (($$sink1581) + ($536))|0;
   $538 = ($537|0)==(0);
   if ($538) {
    return;
   }
   $539 = ((($12)) + 28|0);
   $540 = HEAP8[$539>>0]|0;
   $541 = $540&255;
   $542 = $$0 >>> $541;
   $543 = ((($12)) + 32|0);
   $544 = HEAP8[$543>>0]|0;
   $545 = $544&255;
   $546 = $542 << $545;
   $547 = ((($12)) + 29|0);
   $548 = HEAP8[$547>>0]|0;
   $549 = $548&255;
   $550 = $$01319 >>> $549;
   $551 = ((($12)) + 33|0);
   $552 = HEAP8[$551>>0]|0;
   $553 = $552&255;
   $554 = $550 << $553;
   $555 = $554 | $546;
   $556 = ((($12)) + 30|0);
   $557 = HEAP8[$556>>0]|0;
   $558 = $557&255;
   $559 = $$01320 >>> $558;
   $560 = ((($12)) + 34|0);
   $561 = HEAP8[$560>>0]|0;
   $562 = $561&255;
   $563 = $559 << $562;
   $564 = ((($12)) + 24|0);
   $$013821524 = $537;$$114031523 = $$11403$ph;
   while(1) {
    $565 = (($$013821524) + -1)|0;
    $566 = HEAP32[$564>>2]|0;
    $567 = $555 | $566;
    $568 = $567 | $563;
    HEAP32[$$114031523>>2] = $568;
    $569 = (($$114031523) + ($522<<2)|0);
    $570 = ($565|0)==(0);
    if ($570) {
     break;
    } else {
     $$013821524 = $565;$$114031523 = $569;
    }
   }
   return;
  }
  }
 }
 $571 = (($1) - ($3))|0;
 $572 = ($571|0)<(0);
 $573 = (0 - ($571))|0;
 $574 = $572 ? $573 : $571;
 $575 = (($2) - ($4))|0;
 $576 = ($575|0)<(0);
 $577 = (0 - ($575))|0;
 $578 = $576 ? $577 : $575;
 $579 = ($574|0)==($578|0);
 if ($579) {
  switch ($5|0) {
  case 1:  {
   $580 = ((($0)) + 16|0);
   $581 = HEAP32[$580>>2]|0;
   $582 = ((($12)) + 9|0);
   $583 = HEAP8[$582>>0]|0;
   $584 = $583&255;
   $585 = (($581|0) / ($584|0))&-1;
   $586 = ($4|0)<($2|0);
   $587 = ((($0)) + 20|0);
   $588 = HEAP32[$587>>2]|0;
   if ($586) {
    $595 = Math_imul($585, $4)|0;
    $596 = (($588) + ($595<<2)|0);
    $597 = (($596) + ($3<<2)|0);
    $598 = ($3|0)>($1|0);
    $$sink1465 = $598 ? -1 : 1;
    $599 = (($585) + ($$sink1465))|0;
    $600 = ($10|0)==(0);
    $601 = (($597) + ($599<<2)|0);
    $$1466 = $600 ? $601 : $597;
    $$01404 = $575;$$11411 = $$1466;$$21409 = $599;
   } else {
    $589 = Math_imul($585, $2)|0;
    $590 = (($588) + ($589<<2)|0);
    $591 = (($590) + ($1<<2)|0);
    $592 = ($3|0)<($1|0);
    $$sink = $592 ? -1 : 1;
    $593 = (($585) + ($$sink))|0;
    $594 = (($4) - ($2))|0;
    $$01404 = $594;$$11411 = $591;$$21409 = $593;
   }
   $not$1485 = ($10|0)!=(0);
   $602 = $not$1485&1;
   $$01404$ = (($$01404) + ($602))|0;
   $603 = ($$01404$|0)==(0);
   if ($603) {
    return;
   }
   $604 = ((($12)) + 28|0);
   $605 = ((($12)) + 12|0);
   $606 = ((($12)) + 32|0);
   $607 = ((($12)) + 29|0);
   $608 = ((($12)) + 16|0);
   $609 = ((($12)) + 33|0);
   $610 = ((($12)) + 30|0);
   $611 = ((($12)) + 20|0);
   $612 = ((($12)) + 34|0);
   $613 = ((($12)) + 24|0);
   $$pre1674 = HEAP8[$604>>0]|0;
   $$phi$trans$insert1675 = $$pre1674&255;
   $$phi$trans$insert1676 = (79212 + ($$phi$trans$insert1675<<2)|0);
   $$pre1677 = HEAP32[$$phi$trans$insert1676>>2]|0;
   $$pre1678 = HEAP8[$606>>0]|0;
   $$pre1679 = HEAP8[$607>>0]|0;
   $$phi$trans$insert1680 = $$pre1679&255;
   $$phi$trans$insert1681 = (79212 + ($$phi$trans$insert1680<<2)|0);
   $$pre1682 = HEAP32[$$phi$trans$insert1681>>2]|0;
   $$pre1683 = HEAP8[$609>>0]|0;
   $$pre1684 = HEAP8[$610>>0]|0;
   $$phi$trans$insert1685 = $$pre1684&255;
   $$phi$trans$insert1686 = (79212 + ($$phi$trans$insert1685<<2)|0);
   $$pre1687 = HEAP32[$$phi$trans$insert1686>>2]|0;
   $$pre1688 = HEAP8[$612>>0]|0;
   $614 = $$pre1678&255;
   $615 = $$pre1683&255;
   $616 = $$pre1688&255;
   $$114051539 = $$01404$;$$214121538 = $$11411;
   while(1) {
    $617 = (($$114051539) + -1)|0;
    $618 = HEAP32[$$214121538>>2]|0;
    $619 = HEAP32[$605>>2]|0;
    $620 = $619 & $618;
    $621 = $620 >>> $614;
    $622 = (($$pre1677) + ($621)|0);
    $623 = HEAP8[$622>>0]|0;
    $624 = $623&255;
    $625 = HEAP32[$608>>2]|0;
    $626 = $625 & $618;
    $627 = $626 >>> $615;
    $628 = (($$pre1682) + ($627)|0);
    $629 = HEAP8[$628>>0]|0;
    $630 = $629&255;
    $631 = HEAP32[$611>>2]|0;
    $632 = $631 & $618;
    $633 = $632 >>> $616;
    $634 = (($$pre1687) + ($633)|0);
    $635 = HEAP8[$634>>0]|0;
    $636 = $635&255;
    $637 = Math_imul($624, $24)|0;
    $638 = (($637>>>0) / 255)&-1;
    $639 = (($638) + ($$0))|0;
    $640 = Math_imul($630, $24)|0;
    $641 = (($640>>>0) / 255)&-1;
    $642 = (($641) + ($$01319))|0;
    $643 = Math_imul($636, $24)|0;
    $644 = (($643>>>0) / 255)&-1;
    $645 = (($644) + ($$01320))|0;
    $646 = $639 >>> $$phi$trans$insert1675;
    $647 = $646 << $614;
    $648 = $642 >>> $$phi$trans$insert1680;
    $649 = $648 << $615;
    $650 = $649 | $647;
    $651 = $645 >>> $$phi$trans$insert1685;
    $652 = $651 << $616;
    $653 = HEAP32[$613>>2]|0;
    $654 = $650 | $653;
    $655 = $654 | $652;
    HEAP32[$$214121538>>2] = $655;
    $656 = (($$214121538) + ($$21409<<2)|0);
    $657 = ($617|0)==(0);
    if ($657) {
     break;
    } else {
     $$114051539 = $617;$$214121538 = $656;
    }
   }
   return;
   break;
  }
  case 2:  {
   $658 = ((($0)) + 16|0);
   $659 = HEAP32[$658>>2]|0;
   $660 = ((($12)) + 9|0);
   $661 = HEAP8[$660>>0]|0;
   $662 = $661&255;
   $663 = (($659|0) / ($662|0))&-1;
   $664 = ($4|0)<($2|0);
   $665 = ((($0)) + 20|0);
   $666 = HEAP32[$665>>2]|0;
   if ($664) {
    $673 = Math_imul($663, $4)|0;
    $674 = (($666) + ($673<<2)|0);
    $675 = (($674) + ($3<<2)|0);
    $676 = ($3|0)>($1|0);
    $$sink1468 = $676 ? -1 : 1;
    $677 = (($663) + ($$sink1468))|0;
    $678 = ($10|0)==(0);
    $679 = (($675) + ($677<<2)|0);
    $$1469 = $678 ? $679 : $675;
    $$01413 = $575;$$11419 = $$1469;$$21417 = $677;
   } else {
    $667 = Math_imul($663, $2)|0;
    $668 = (($666) + ($667<<2)|0);
    $669 = (($668) + ($1<<2)|0);
    $670 = ($3|0)<($1|0);
    $$sink1467 = $670 ? -1 : 1;
    $671 = (($663) + ($$sink1467))|0;
    $672 = (($4) - ($2))|0;
    $$01413 = $672;$$11419 = $669;$$21417 = $671;
   }
   $not$1484 = ($10|0)!=(0);
   $680 = $not$1484&1;
   $$01413$ = (($$01413) + ($680))|0;
   $681 = ($$01413$|0)==(0);
   if ($681) {
    return;
   }
   $682 = ((($12)) + 28|0);
   $683 = ((($12)) + 12|0);
   $684 = ((($12)) + 32|0);
   $685 = ((($12)) + 29|0);
   $686 = ((($12)) + 16|0);
   $687 = ((($12)) + 33|0);
   $688 = ((($12)) + 30|0);
   $689 = ((($12)) + 20|0);
   $690 = ((($12)) + 34|0);
   $691 = ((($12)) + 24|0);
   $$pre1659 = HEAP8[$682>>0]|0;
   $$phi$trans$insert1660 = $$pre1659&255;
   $$phi$trans$insert1661 = (79212 + ($$phi$trans$insert1660<<2)|0);
   $$pre1662 = HEAP32[$$phi$trans$insert1661>>2]|0;
   $$pre1663 = HEAP8[$684>>0]|0;
   $$pre1664 = HEAP8[$685>>0]|0;
   $$phi$trans$insert1665 = $$pre1664&255;
   $$phi$trans$insert1666 = (79212 + ($$phi$trans$insert1665<<2)|0);
   $$pre1667 = HEAP32[$$phi$trans$insert1666>>2]|0;
   $$pre1668 = HEAP8[$687>>0]|0;
   $$pre1669 = HEAP8[$688>>0]|0;
   $$phi$trans$insert1670 = $$pre1669&255;
   $$phi$trans$insert1671 = (79212 + ($$phi$trans$insert1670<<2)|0);
   $$pre1672 = HEAP32[$$phi$trans$insert1671>>2]|0;
   $$pre1673 = HEAP8[$690>>0]|0;
   $692 = $$pre1663&255;
   $693 = $$pre1668&255;
   $694 = $$pre1673&255;
   $$114141542 = $$01413$;$$214201541 = $$11419;
   while(1) {
    $695 = (($$114141542) + -1)|0;
    $696 = HEAP32[$$214201541>>2]|0;
    $697 = HEAP32[$683>>2]|0;
    $698 = $697 & $696;
    $699 = $698 >>> $692;
    $700 = (($$pre1662) + ($699)|0);
    $701 = HEAP8[$700>>0]|0;
    $702 = $701&255;
    $703 = HEAP32[$686>>2]|0;
    $704 = $703 & $696;
    $705 = $704 >>> $693;
    $706 = (($$pre1667) + ($705)|0);
    $707 = HEAP8[$706>>0]|0;
    $708 = $707&255;
    $709 = HEAP32[$689>>2]|0;
    $710 = $709 & $696;
    $711 = $710 >>> $694;
    $712 = (($$pre1672) + ($711)|0);
    $713 = HEAP8[$712>>0]|0;
    $714 = $713&255;
    $715 = (($702) + ($$0))|0;
    $716 = ($715>>>0)<(255);
    $$5 = $716 ? $715 : 255;
    $717 = (($708) + ($$01319))|0;
    $718 = ($717>>>0)<(255);
    $$10 = $718 ? $717 : 255;
    $719 = (($714) + ($$01320))|0;
    $720 = ($719>>>0)<(255);
    $$6 = $720 ? $719 : 255;
    $721 = $$5 >>> $$phi$trans$insert1660;
    $722 = $721 << $692;
    $723 = $$10 >>> $$phi$trans$insert1665;
    $724 = $723 << $693;
    $725 = $724 | $722;
    $726 = $$6 >>> $$phi$trans$insert1670;
    $727 = $726 << $694;
    $728 = HEAP32[$691>>2]|0;
    $729 = $725 | $728;
    $730 = $729 | $727;
    HEAP32[$$214201541>>2] = $730;
    $731 = (($$214201541) + ($$21417<<2)|0);
    $732 = ($695|0)==(0);
    if ($732) {
     break;
    } else {
     $$114141542 = $695;$$214201541 = $731;
    }
   }
   return;
   break;
  }
  case 4:  {
   $733 = ((($0)) + 16|0);
   $734 = HEAP32[$733>>2]|0;
   $735 = ((($12)) + 9|0);
   $736 = HEAP8[$735>>0]|0;
   $737 = $736&255;
   $738 = (($734|0) / ($737|0))&-1;
   $739 = ($4|0)<($2|0);
   $740 = ((($0)) + 20|0);
   $741 = HEAP32[$740>>2]|0;
   if ($739) {
    $748 = Math_imul($738, $4)|0;
    $749 = (($741) + ($748<<2)|0);
    $750 = (($749) + ($3<<2)|0);
    $751 = ($3|0)>($1|0);
    $$sink1471 = $751 ? -1 : 1;
    $752 = (($738) + ($$sink1471))|0;
    $753 = ($10|0)==(0);
    $754 = (($750) + ($752<<2)|0);
    $$1472 = $753 ? $754 : $750;
    $$01440 = $575;$$11447 = $$1472;$$21444 = $752;
   } else {
    $742 = Math_imul($738, $2)|0;
    $743 = (($741) + ($742<<2)|0);
    $744 = (($743) + ($1<<2)|0);
    $745 = ($3|0)<($1|0);
    $$sink1470 = $745 ? -1 : 1;
    $746 = (($738) + ($$sink1470))|0;
    $747 = (($4) - ($2))|0;
    $$01440 = $747;$$11447 = $744;$$21444 = $746;
   }
   $not$1483 = ($10|0)!=(0);
   $755 = $not$1483&1;
   $$01440$ = (($$01440) + ($755))|0;
   $756 = ($$01440$|0)==(0);
   if ($756) {
    return;
   }
   $757 = ((($12)) + 28|0);
   $758 = ((($12)) + 12|0);
   $759 = ((($12)) + 32|0);
   $760 = ((($12)) + 29|0);
   $761 = ((($12)) + 16|0);
   $762 = ((($12)) + 33|0);
   $763 = ((($12)) + 30|0);
   $764 = ((($12)) + 20|0);
   $765 = ((($12)) + 34|0);
   $766 = ((($12)) + 24|0);
   $$pre1644 = HEAP8[$757>>0]|0;
   $$phi$trans$insert1645 = $$pre1644&255;
   $$phi$trans$insert1646 = (79212 + ($$phi$trans$insert1645<<2)|0);
   $$pre1647 = HEAP32[$$phi$trans$insert1646>>2]|0;
   $$pre1648 = HEAP8[$759>>0]|0;
   $$pre1649 = HEAP8[$760>>0]|0;
   $$phi$trans$insert1650 = $$pre1649&255;
   $$phi$trans$insert1651 = (79212 + ($$phi$trans$insert1650<<2)|0);
   $$pre1652 = HEAP32[$$phi$trans$insert1651>>2]|0;
   $$pre1653 = HEAP8[$762>>0]|0;
   $$pre1654 = HEAP8[$763>>0]|0;
   $$phi$trans$insert1655 = $$pre1654&255;
   $$phi$trans$insert1656 = (79212 + ($$phi$trans$insert1655<<2)|0);
   $$pre1657 = HEAP32[$$phi$trans$insert1656>>2]|0;
   $$pre1658 = HEAP8[$765>>0]|0;
   $767 = $$pre1648&255;
   $768 = $$pre1653&255;
   $769 = $$pre1658&255;
   $$114411545 = $$01440$;$$214481544 = $$11447;
   while(1) {
    $770 = (($$114411545) + -1)|0;
    $771 = HEAP32[$$214481544>>2]|0;
    $772 = HEAP32[$758>>2]|0;
    $773 = $772 & $771;
    $774 = $773 >>> $767;
    $775 = (($$pre1647) + ($774)|0);
    $776 = HEAP8[$775>>0]|0;
    $777 = $776&255;
    $778 = HEAP32[$761>>2]|0;
    $779 = $778 & $771;
    $780 = $779 >>> $768;
    $781 = (($$pre1652) + ($780)|0);
    $782 = HEAP8[$781>>0]|0;
    $783 = $782&255;
    $784 = HEAP32[$764>>2]|0;
    $785 = $784 & $771;
    $786 = $785 >>> $769;
    $787 = (($$pre1657) + ($786)|0);
    $788 = HEAP8[$787>>0]|0;
    $789 = $788&255;
    $790 = Math_imul($777, $$0)|0;
    $791 = (($790>>>0) / 255)&-1;
    $792 = Math_imul($783, $$01319)|0;
    $793 = (($792>>>0) / 255)&-1;
    $794 = Math_imul($789, $$01320)|0;
    $795 = (($794>>>0) / 255)&-1;
    $796 = $791 >>> $$phi$trans$insert1645;
    $797 = $796 << $767;
    $798 = $793 >>> $$phi$trans$insert1650;
    $799 = $798 << $768;
    $800 = $799 | $797;
    $801 = $795 >>> $$phi$trans$insert1655;
    $802 = $801 << $769;
    $803 = HEAP32[$766>>2]|0;
    $804 = $800 | $803;
    $805 = $804 | $802;
    HEAP32[$$214481544>>2] = $805;
    $806 = (($$214481544) + ($$21444<<2)|0);
    $807 = ($770|0)==(0);
    if ($807) {
     break;
    } else {
     $$114411545 = $770;$$214481544 = $806;
    }
   }
   return;
   break;
  }
  default: {
   $808 = ((($0)) + 16|0);
   $809 = HEAP32[$808>>2]|0;
   $810 = ((($12)) + 9|0);
   $811 = HEAP8[$810>>0]|0;
   $812 = $811&255;
   $813 = (($809|0) / ($812|0))&-1;
   $814 = ($4|0)<($2|0);
   $815 = ((($0)) + 20|0);
   $816 = HEAP32[$815>>2]|0;
   if ($814) {
    $823 = Math_imul($813, $4)|0;
    $824 = (($816) + ($823<<2)|0);
    $825 = (($824) + ($3<<2)|0);
    $826 = ($3|0)>($1|0);
    $$sink1474 = $826 ? -1 : 1;
    $827 = (($813) + ($$sink1474))|0;
    $828 = ($10|0)==(0);
    $829 = (($825) + ($827<<2)|0);
    $$1475 = $828 ? $829 : $825;
    $$01449 = $575;$$11455 = $$1475;$$21453 = $827;
   } else {
    $817 = Math_imul($813, $2)|0;
    $818 = (($816) + ($817<<2)|0);
    $819 = (($818) + ($1<<2)|0);
    $820 = ($3|0)<($1|0);
    $$sink1473 = $820 ? -1 : 1;
    $821 = (($813) + ($$sink1473))|0;
    $822 = (($4) - ($2))|0;
    $$01449 = $822;$$11455 = $819;$$21453 = $821;
   }
   $not$1486 = ($10|0)!=(0);
   $830 = $not$1486&1;
   $$01449$ = (($$01449) + ($830))|0;
   $831 = ($$01449$|0)==(0);
   if ($831) {
    return;
   }
   $832 = ((($12)) + 28|0);
   $833 = HEAP8[$832>>0]|0;
   $834 = $833&255;
   $835 = $$0 >>> $834;
   $836 = ((($12)) + 32|0);
   $837 = HEAP8[$836>>0]|0;
   $838 = $837&255;
   $839 = $835 << $838;
   $840 = ((($12)) + 29|0);
   $841 = HEAP8[$840>>0]|0;
   $842 = $841&255;
   $843 = $$01319 >>> $842;
   $844 = ((($12)) + 33|0);
   $845 = HEAP8[$844>>0]|0;
   $846 = $845&255;
   $847 = $843 << $846;
   $848 = $847 | $839;
   $849 = ((($12)) + 30|0);
   $850 = HEAP8[$849>>0]|0;
   $851 = $850&255;
   $852 = $$01320 >>> $851;
   $853 = ((($12)) + 34|0);
   $854 = HEAP8[$853>>0]|0;
   $855 = $854&255;
   $856 = $852 << $855;
   $857 = ((($12)) + 24|0);
   $$114501536 = $$01449$;$$214561535 = $$11455;
   while(1) {
    $858 = (($$114501536) + -1)|0;
    $859 = HEAP32[$857>>2]|0;
    $860 = $848 | $859;
    $861 = $860 | $856;
    HEAP32[$$214561535>>2] = $861;
    $862 = (($$214561535) + ($$21453<<2)|0);
    $863 = ($858|0)==(0);
    if ($863) {
     break;
    } else {
     $$114501536 = $858;$$214561535 = $862;
    }
   }
   return;
  }
  }
 } else {
  switch ($5|0) {
  case 1:  {
   $864 = (($3) - ($1))|0;
   $865 = ($864|0)<(0);
   $866 = (0 - ($864))|0;
   $867 = $865 ? $866 : $864;
   $868 = (($4) - ($2))|0;
   $869 = ($868|0)<(0);
   $870 = (0 - ($868))|0;
   $871 = $869 ? $870 : $868;
   $872 = ($867|0)<($871|0);
   if ($872) {
    $876 = $867 << 1;
    $877 = (($876) - ($871))|0;
    $878 = (($867) - ($871))|0;
    $$01423 = 1;$$01429 = 0;$$01433$in = $878;$$01434 = $876;$$01435 = $877;$$01438$in = $871;
   } else {
    $873 = $871 << 1;
    $874 = (($873) - ($867))|0;
    $875 = (($871) - ($867))|0;
    $$01423 = 0;$$01429 = 1;$$01433$in = $875;$$01434 = $873;$$01435 = $874;$$01438$in = $867;
   }
   $$01433 = $$01433$in << 1;
   $879 = ($3|0)<($1|0);
   $880 = (0 - ($$01429))|0;
   $$$01429 = $879 ? $880 : $$01429;
   $$1476 = $879 ? -1 : 1;
   $881 = ($4|0)<($2|0);
   $882 = (0 - ($$01423))|0;
   $$11424 = $881 ? $882 : $$01423;
   $$11422 = $881 ? -1 : 1;
   $not$1481 = ($10|0)!=(0);
   $$01438 = $not$1481&1;
   $$01438$in$$01438 = (($$01438$in) + ($$01438))|0;
   $883 = ($$01438$in$$01438|0)>(0);
   if (!($883)) {
    return;
   }
   $884 = ((($0)) + 20|0);
   $885 = ((($0)) + 16|0);
   $886 = ((($12)) + 28|0);
   $887 = ((($12)) + 12|0);
   $888 = ((($12)) + 32|0);
   $889 = ((($12)) + 29|0);
   $890 = ((($12)) + 16|0);
   $891 = ((($12)) + 33|0);
   $892 = ((($12)) + 30|0);
   $893 = ((($12)) + 20|0);
   $894 = ((($12)) + 34|0);
   $895 = ((($12)) + 24|0);
   $$pre1628 = HEAP32[$884>>2]|0;
   $$pre1629 = HEAP8[$886>>0]|0;
   $$phi$trans$insert1630 = $$pre1629&255;
   $$phi$trans$insert1631 = (79212 + ($$phi$trans$insert1630<<2)|0);
   $$pre1632 = HEAP32[$$phi$trans$insert1631>>2]|0;
   $$pre1633 = HEAP8[$888>>0]|0;
   $$pre1634 = HEAP8[$889>>0]|0;
   $$phi$trans$insert1635 = $$pre1634&255;
   $$phi$trans$insert1636 = (79212 + ($$phi$trans$insert1635<<2)|0);
   $$pre1637 = HEAP32[$$phi$trans$insert1636>>2]|0;
   $$pre1638 = HEAP8[$891>>0]|0;
   $$pre1639 = HEAP8[$892>>0]|0;
   $$phi$trans$insert1640 = $$pre1639&255;
   $$phi$trans$insert1641 = (79212 + ($$phi$trans$insert1640<<2)|0);
   $$pre1642 = HEAP32[$$phi$trans$insert1641>>2]|0;
   $$pre1643 = HEAP8[$894>>0]|0;
   $896 = $$pre1633&255;
   $897 = $$pre1638&255;
   $898 = $$pre1643&255;
   $$014251555 = $2;$$014311554 = $1;$$014451552 = 0;$$114361553 = $$01435;
   while(1) {
    $899 = HEAP32[$885>>2]|0;
    $900 = Math_imul($899, $$014251555)|0;
    $901 = (($$pre1628) + ($900)|0);
    $902 = $$014311554 << 2;
    $903 = (($901) + ($902)|0);
    $904 = HEAP32[$903>>2]|0;
    $905 = HEAP32[$887>>2]|0;
    $906 = $905 & $904;
    $907 = $906 >>> $896;
    $908 = (($$pre1632) + ($907)|0);
    $909 = HEAP8[$908>>0]|0;
    $910 = $909&255;
    $911 = HEAP32[$890>>2]|0;
    $912 = $911 & $904;
    $913 = $912 >>> $897;
    $914 = (($$pre1637) + ($913)|0);
    $915 = HEAP8[$914>>0]|0;
    $916 = $915&255;
    $917 = HEAP32[$893>>2]|0;
    $918 = $917 & $904;
    $919 = $918 >>> $898;
    $920 = (($$pre1642) + ($919)|0);
    $921 = HEAP8[$920>>0]|0;
    $922 = $921&255;
    $923 = Math_imul($910, $24)|0;
    $924 = (($923>>>0) / 255)&-1;
    $925 = (($924) + ($$0))|0;
    $926 = Math_imul($916, $24)|0;
    $927 = (($926>>>0) / 255)&-1;
    $928 = (($927) + ($$01319))|0;
    $929 = Math_imul($922, $24)|0;
    $930 = (($929>>>0) / 255)&-1;
    $931 = (($930) + ($$01320))|0;
    $932 = $925 >>> $$phi$trans$insert1630;
    $933 = $932 << $896;
    $934 = $928 >>> $$phi$trans$insert1635;
    $935 = $934 << $897;
    $936 = $935 | $933;
    $937 = $931 >>> $$phi$trans$insert1640;
    $938 = $937 << $898;
    $939 = HEAP32[$895>>2]|0;
    $940 = $936 | $939;
    $941 = $940 | $938;
    HEAP32[$903>>2] = $941;
    $942 = ($$114361553|0)<(0);
    $$01434$$01433 = $942 ? $$01434 : $$01433;
    $$$01429$$1476 = $942 ? $$$01429 : $$1476;
    $$11424$$11422 = $942 ? $$11424 : $$11422;
    $$11426 = (($$014251555) + ($$11424$$11422))|0;
    $$11432 = (($$$01429$$1476) + ($$014311554))|0;
    $$21437 = (($$01434$$01433) + ($$114361553))|0;
    $943 = (($$014451552) + 1)|0;
    $944 = ($943|0)<($$01438$in$$01438|0);
    if ($944) {
     $$014251555 = $$11426;$$014311554 = $$11432;$$014451552 = $943;$$114361553 = $$21437;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 2:  {
   $945 = (($3) - ($1))|0;
   $946 = ($945|0)<(0);
   $947 = (0 - ($945))|0;
   $948 = $946 ? $947 : $945;
   $949 = (($4) - ($2))|0;
   $950 = ($949|0)<(0);
   $951 = (0 - ($949))|0;
   $952 = $950 ? $951 : $949;
   $953 = ($948|0)<($952|0);
   if ($953) {
    $957 = $948 << 1;
    $958 = (($957) - ($952))|0;
    $959 = (($948) - ($952))|0;
    $$01385 = 1;$$01391 = 0;$$01395$in = $959;$$01396 = $957;$$01397 = $958;$$01400$in = $952;
   } else {
    $954 = $952 << 1;
    $955 = (($954) - ($948))|0;
    $956 = (($952) - ($948))|0;
    $$01385 = 0;$$01391 = 1;$$01395$in = $956;$$01396 = $954;$$01397 = $955;$$01400$in = $948;
   }
   $$01395 = $$01395$in << 1;
   $960 = ($3|0)<($1|0);
   $961 = (0 - ($$01391))|0;
   $$$01391 = $960 ? $961 : $$01391;
   $$1477 = $960 ? -1 : 1;
   $962 = ($4|0)<($2|0);
   $963 = (0 - ($$01385))|0;
   $$11386 = $962 ? $963 : $$01385;
   $$11384 = $962 ? -1 : 1;
   $not$1480 = ($10|0)!=(0);
   $$01400 = $not$1480&1;
   $$01400$in$$01400 = (($$01400$in) + ($$01400))|0;
   $964 = ($$01400$in$$01400|0)>(0);
   if (!($964)) {
    return;
   }
   $965 = ((($0)) + 20|0);
   $966 = ((($0)) + 16|0);
   $967 = ((($12)) + 28|0);
   $968 = ((($12)) + 12|0);
   $969 = ((($12)) + 32|0);
   $970 = ((($12)) + 29|0);
   $971 = ((($12)) + 16|0);
   $972 = ((($12)) + 33|0);
   $973 = ((($12)) + 30|0);
   $974 = ((($12)) + 20|0);
   $975 = ((($12)) + 34|0);
   $976 = ((($12)) + 24|0);
   $$pre1612 = HEAP32[$965>>2]|0;
   $$pre1613 = HEAP8[$967>>0]|0;
   $$phi$trans$insert1614 = $$pre1613&255;
   $$phi$trans$insert1615 = (79212 + ($$phi$trans$insert1614<<2)|0);
   $$pre1616 = HEAP32[$$phi$trans$insert1615>>2]|0;
   $$pre1617 = HEAP8[$969>>0]|0;
   $$pre1618 = HEAP8[$970>>0]|0;
   $$phi$trans$insert1619 = $$pre1618&255;
   $$phi$trans$insert1620 = (79212 + ($$phi$trans$insert1619<<2)|0);
   $$pre1621 = HEAP32[$$phi$trans$insert1620>>2]|0;
   $$pre1622 = HEAP8[$972>>0]|0;
   $$pre1623 = HEAP8[$973>>0]|0;
   $$phi$trans$insert1624 = $$pre1623&255;
   $$phi$trans$insert1625 = (79212 + ($$phi$trans$insert1624<<2)|0);
   $$pre1626 = HEAP32[$$phi$trans$insert1625>>2]|0;
   $$pre1627 = HEAP8[$975>>0]|0;
   $977 = $$pre1617&255;
   $978 = $$pre1622&255;
   $979 = $$pre1627&255;
   $$013871560 = $2;$$013931559 = $1;$$014061557 = 0;$$113981558 = $$01397;
   while(1) {
    $980 = HEAP32[$966>>2]|0;
    $981 = Math_imul($980, $$013871560)|0;
    $982 = (($$pre1612) + ($981)|0);
    $983 = $$013931559 << 2;
    $984 = (($982) + ($983)|0);
    $985 = HEAP32[$984>>2]|0;
    $986 = HEAP32[$968>>2]|0;
    $987 = $986 & $985;
    $988 = $987 >>> $977;
    $989 = (($$pre1616) + ($988)|0);
    $990 = HEAP8[$989>>0]|0;
    $991 = $990&255;
    $992 = HEAP32[$971>>2]|0;
    $993 = $992 & $985;
    $994 = $993 >>> $978;
    $995 = (($$pre1621) + ($994)|0);
    $996 = HEAP8[$995>>0]|0;
    $997 = $996&255;
    $998 = HEAP32[$974>>2]|0;
    $999 = $998 & $985;
    $1000 = $999 >>> $979;
    $1001 = (($$pre1626) + ($1000)|0);
    $1002 = HEAP8[$1001>>0]|0;
    $1003 = $1002&255;
    $1004 = (($991) + ($$0))|0;
    $1005 = ($1004>>>0)<(255);
    $$11 = $1005 ? $1004 : 255;
    $1006 = (($997) + ($$01319))|0;
    $1007 = ($1006>>>0)<(255);
    $$7 = $1007 ? $1006 : 255;
    $1008 = (($1003) + ($$01320))|0;
    $1009 = ($1008>>>0)<(255);
    $$12 = $1009 ? $1008 : 255;
    $1010 = $$11 >>> $$phi$trans$insert1614;
    $1011 = $1010 << $977;
    $1012 = $$7 >>> $$phi$trans$insert1619;
    $1013 = $1012 << $978;
    $1014 = $1013 | $1011;
    $1015 = $$12 >>> $$phi$trans$insert1624;
    $1016 = $1015 << $979;
    $1017 = HEAP32[$976>>2]|0;
    $1018 = $1014 | $1017;
    $1019 = $1018 | $1016;
    HEAP32[$984>>2] = $1019;
    $1020 = ($$113981558|0)<(0);
    $$01396$$01395 = $1020 ? $$01396 : $$01395;
    $$$01391$$1477 = $1020 ? $$$01391 : $$1477;
    $$11386$$11384 = $1020 ? $$11386 : $$11384;
    $$11388 = (($$013871560) + ($$11386$$11384))|0;
    $$11394 = (($$$01391$$1477) + ($$013931559))|0;
    $$21399 = (($$01396$$01395) + ($$113981558))|0;
    $1021 = (($$014061557) + 1)|0;
    $1022 = ($1021|0)<($$01400$in$$01400|0);
    if ($1022) {
     $$013871560 = $$11388;$$013931559 = $$11394;$$014061557 = $1021;$$113981558 = $$21399;
    } else {
     break;
    }
   }
   return;
   break;
  }
  case 4:  {
   $1023 = (($3) - ($1))|0;
   $1024 = ($1023|0)<(0);
   $1025 = (0 - ($1023))|0;
   $1026 = $1024 ? $1025 : $1023;
   $1027 = (($4) - ($2))|0;
   $1028 = ($1027|0)<(0);
   $1029 = (0 - ($1027))|0;
   $1030 = $1028 ? $1029 : $1027;
   $1031 = ($1026|0)<($1030|0);
   if ($1031) {
    $1035 = $1026 << 1;
    $1036 = (($1035) - ($1030))|0;
    $1037 = (($1026) - ($1030))|0;
    $$01355 = 1;$$01361 = 0;$$01365$in = $1037;$$01366 = $1035;$$01367 = $1036;$$01370$in = $1030;
   } else {
    $1032 = $1030 << 1;
    $1033 = (($1032) - ($1026))|0;
    $1034 = (($1030) - ($1026))|0;
    $$01355 = 0;$$01361 = 1;$$01365$in = $1034;$$01366 = $1032;$$01367 = $1033;$$01370$in = $1026;
   }
   $$01365 = $$01365$in << 1;
   $1038 = ($3|0)<($1|0);
   $1039 = (0 - ($$01361))|0;
   $$$01361 = $1038 ? $1039 : $$01361;
   $$1478 = $1038 ? -1 : 1;
   $1040 = ($4|0)<($2|0);
   $1041 = (0 - ($$01355))|0;
   $$11356 = $1040 ? $1041 : $$01355;
   $$11354 = $1040 ? -1 : 1;
   $not$ = ($10|0)!=(0);
   $$01370 = $not$&1;
   $$01370$in$$01370 = (($$01370$in) + ($$01370))|0;
   $1042 = ($$01370$in$$01370|0)>(0);
   if (!($1042)) {
    return;
   }
   $1043 = ((($0)) + 20|0);
   $1044 = ((($0)) + 16|0);
   $1045 = ((($12)) + 28|0);
   $1046 = ((($12)) + 12|0);
   $1047 = ((($12)) + 32|0);
   $1048 = ((($12)) + 29|0);
   $1049 = ((($12)) + 16|0);
   $1050 = ((($12)) + 33|0);
   $1051 = ((($12)) + 30|0);
   $1052 = ((($12)) + 20|0);
   $1053 = ((($12)) + 34|0);
   $1054 = ((($12)) + 24|0);
   $$pre = HEAP32[$1043>>2]|0;
   $$pre1598 = HEAP8[$1045>>0]|0;
   $$phi$trans$insert = $$pre1598&255;
   $$phi$trans$insert1599 = (79212 + ($$phi$trans$insert<<2)|0);
   $$pre1600 = HEAP32[$$phi$trans$insert1599>>2]|0;
   $$pre1601 = HEAP8[$1047>>0]|0;
   $$pre1602 = HEAP8[$1048>>0]|0;
   $$phi$trans$insert1603 = $$pre1602&255;
   $$phi$trans$insert1604 = (79212 + ($$phi$trans$insert1603<<2)|0);
   $$pre1605 = HEAP32[$$phi$trans$insert1604>>2]|0;
   $$pre1606 = HEAP8[$1050>>0]|0;
   $$pre1607 = HEAP8[$1051>>0]|0;
   $$phi$trans$insert1608 = $$pre1607&255;
   $$phi$trans$insert1609 = (79212 + ($$phi$trans$insert1608<<2)|0);
   $$pre1610 = HEAP32[$$phi$trans$insert1609>>2]|0;
   $$pre1611 = HEAP8[$1053>>0]|0;
   $1055 = $$pre1601&255;
   $1056 = $$pre1606&255;
   $1057 = $$pre1611&255;
   $$013571565 = $2;$$013631564 = $1;$$013751562 = 0;$$113681563 = $$01367;
   while(1) {
    $1058 = HEAP32[$1044>>2]|0;
    $1059 = Math_imul($1058, $$013571565)|0;
    $1060 = (($$pre) + ($1059)|0);
    $1061 = $$013631564 << 2;
    $1062 = (($1060) + ($1061)|0);
    $1063 = HEAP32[$1062>>2]|0;
    $1064 = HEAP32[$1046>>2]|0;
    $1065 = $1064 & $1063;
    $1066 = $1065 >>> $1055;
    $1067 = (($$pre1600) + ($1066)|0);
    $1068 = HEAP8[$1067>>0]|0;
    $1069 = $1068&255;
    $1070 = HEAP32[$1049>>2]|0;
    $1071 = $1070 & $1063;
    $1072 = $1071 >>> $1056;
    $1073 = (($$pre1605) + ($1072)|0);
    $1074 = HEAP8[$1073>>0]|0;
    $1075 = $1074&255;
    $1076 = HEAP32[$1052>>2]|0;
    $1077 = $1076 & $1063;
    $1078 = $1077 >>> $1057;
    $1079 = (($$pre1610) + ($1078)|0);
    $1080 = HEAP8[$1079>>0]|0;
    $1081 = $1080&255;
    $1082 = Math_imul($1069, $$0)|0;
    $1083 = (($1082>>>0) / 255)&-1;
    $1084 = Math_imul($1075, $$01319)|0;
    $1085 = (($1084>>>0) / 255)&-1;
    $1086 = Math_imul($1081, $$01320)|0;
    $1087 = (($1086>>>0) / 255)&-1;
    $1088 = $1083 >>> $$phi$trans$insert;
    $1089 = $1088 << $1055;
    $1090 = $1085 >>> $$phi$trans$insert1603;
    $1091 = $1090 << $1056;
    $1092 = $1091 | $1089;
    $1093 = $1087 >>> $$phi$trans$insert1608;
    $1094 = $1093 << $1057;
    $1095 = HEAP32[$1054>>2]|0;
    $1096 = $1092 | $1095;
    $1097 = $1096 | $1094;
    HEAP32[$1062>>2] = $1097;
    $1098 = ($$113681563|0)<(0);
    $$01366$$01365 = $1098 ? $$01366 : $$01365;
    $$$01361$$1478 = $1098 ? $$$01361 : $$1478;
    $$11356$$11354 = $1098 ? $$11356 : $$11354;
    $$11358 = (($$013571565) + ($$11356$$11354))|0;
    $$11364 = (($$$01361$$1478) + ($$013631564))|0;
    $$21369 = (($$01366$$01365) + ($$113681563))|0;
    $1099 = (($$013751562) + 1)|0;
    $1100 = ($1099|0)<($$01370$in$$01370|0);
    if ($1100) {
     $$013571565 = $$11358;$$013631564 = $$11364;$$013751562 = $1099;$$113681563 = $$21369;
    } else {
     break;
    }
   }
   return;
   break;
  }
  default: {
   $1101 = (($3) - ($1))|0;
   $1102 = ($1101|0)<(0);
   $1103 = (0 - ($1101))|0;
   $1104 = $1102 ? $1103 : $1101;
   $1105 = (($4) - ($2))|0;
   $1106 = ($1105|0)<(0);
   $1107 = (0 - ($1105))|0;
   $1108 = $1106 ? $1107 : $1105;
   $1109 = ($1104|0)<($1108|0);
   if ($1109) {
    $1113 = $1104 << 1;
    $1114 = (($1113) - ($1108))|0;
    $1115 = (($1104) - ($1108))|0;
    $$01324 = 1;$$01330 = 0;$$01334$in = $1115;$$01335 = $1113;$$01336 = $1114;$$01339$in = $1108;
   } else {
    $1110 = $1108 << 1;
    $1111 = (($1110) - ($1104))|0;
    $1112 = (($1108) - ($1104))|0;
    $$01324 = 0;$$01330 = 1;$$01334$in = $1112;$$01335 = $1110;$$01336 = $1111;$$01339$in = $1104;
   }
   $$01334 = $$01334$in << 1;
   $1116 = ($3|0)<($1|0);
   $1117 = (0 - ($$01330))|0;
   $$$01330 = $1116 ? $1117 : $$01330;
   $$1479 = $1116 ? -1 : 1;
   $1118 = ($4|0)<($2|0);
   $1119 = (0 - ($$01324))|0;
   $$11325 = $1118 ? $1119 : $$01324;
   $$1 = $1118 ? -1 : 1;
   $not$1482 = ($10|0)!=(0);
   $$01339 = $not$1482&1;
   $$01339$in$$01339 = (($$01339$in) + ($$01339))|0;
   $1120 = ($$01339$in$$01339|0)>(0);
   if (!($1120)) {
    return;
   }
   $1121 = ((($0)) + 20|0);
   $1122 = HEAP32[$1121>>2]|0;
   $1123 = ((($0)) + 16|0);
   $1124 = ((($12)) + 28|0);
   $1125 = HEAP8[$1124>>0]|0;
   $1126 = $1125&255;
   $1127 = $$0 >>> $1126;
   $1128 = ((($12)) + 32|0);
   $1129 = HEAP8[$1128>>0]|0;
   $1130 = $1129&255;
   $1131 = $1127 << $1130;
   $1132 = ((($12)) + 29|0);
   $1133 = HEAP8[$1132>>0]|0;
   $1134 = $1133&255;
   $1135 = $$01319 >>> $1134;
   $1136 = ((($12)) + 33|0);
   $1137 = HEAP8[$1136>>0]|0;
   $1138 = $1137&255;
   $1139 = $1135 << $1138;
   $1140 = $1139 | $1131;
   $1141 = ((($12)) + 30|0);
   $1142 = HEAP8[$1141>>0]|0;
   $1143 = $1142&255;
   $1144 = $$01320 >>> $1143;
   $1145 = ((($12)) + 34|0);
   $1146 = HEAP8[$1145>>0]|0;
   $1147 = $1146&255;
   $1148 = $1144 << $1147;
   $1149 = ((($12)) + 24|0);
   $$013261550 = $2;$$013321549 = $1;$$013441547 = 0;$$113371548 = $$01336;
   while(1) {
    $1150 = HEAP32[$1123>>2]|0;
    $1151 = Math_imul($1150, $$013261550)|0;
    $1152 = (($1122) + ($1151)|0);
    $1153 = $$013321549 << 2;
    $1154 = (($1152) + ($1153)|0);
    $1155 = HEAP32[$1149>>2]|0;
    $1156 = $1140 | $1155;
    $1157 = $1156 | $1148;
    HEAP32[$1154>>2] = $1157;
    $1158 = ($$113371548|0)<(0);
    $$01335$$01334 = $1158 ? $$01335 : $$01334;
    $$$01330$$1479 = $1158 ? $$$01330 : $$1479;
    $$11325$$1 = $1158 ? $$11325 : $$1;
    $$11327 = (($$013261550) + ($$11325$$1))|0;
    $$11333 = (($$$01330$$1479) + ($$013321549))|0;
    $$21338 = (($$01335$$01334) + ($$113371548))|0;
    $1159 = (($$013441547) + 1)|0;
    $1160 = ($1159|0)<($$01339$in$$01339|0);
    if ($1160) {
     $$013261550 = $$11327;$$013321549 = $$11333;$$013441547 = $1159;$$113371548 = $$21338;
    } else {
     break;
    }
   }
   return;
  }
  }
 }
}
function _SDL_IntersectRectAndLine($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$$$i247 = 0, $$$i$us = 0, $$$i237 = 0, $$$i242 = 0, $$$i247 = 0, $$0$$i$us = 0, $$0$$i239 = 0, $$0$$i244 = 0, $$0$$i249 = 0, $$0$be$us = 0, $$0$i$us = 0, $$0$i238 = 0, $$0$i243 = 0, $$0$ph = 0, $$0207$ph$be = 0, $$0208 = 0, $$0209$ph293 = 0, $$0209277$us = 0, $$0210$ph292 = 0, $$0210276$us = 0;
 var $$0213$ph$lcssa272 = 0, $$0213$ph290 = 0, $$0214$lcssa = 0, $$0214275$us = 0, $$0215$lcssa = 0, $$0215274$us = 0, $$0216$ph$lcssa273 = 0, $$0216$ph286 = 0, $$0278$us = 0, $$1 = 0, $$1211 = 0, $$2$us = 0, $$2212$us = 0, $$in = 0, $$mux = 0, $$mux235 = 0, $$mux254 = 0, $$mux257 = 0, $$not226 = 0, $$not255 = 0;
 var $$not258 = 0, $$not259 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $brmerge234 = 0, $brmerge253 = 0;
 var $brmerge256 = 0, $not$$i$us = 0, $not$$i236 = 0, $not$$i241 = 0, $notlhs = 0, $notrhs = 0, $or$cond = 0, $or$cond$not = 0, $or$cond217 = 0, $or$cond218$not = 0, $or$cond219 = 0, $or$cond220$not = 0, $or$cond221 = 0, $or$cond221$not = 0, $or$cond222 = 0, $or$cond223 = 0, $or$cond224$not = 0, $or$cond225 = 0, $or$cond227 = 0, $or$cond251 = 0;
 var $or$cond251$not = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer10 = 0, $vararg_buffer4 = 0, $vararg_buffer7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $vararg_buffer10 = sp + 32|0;
 $vararg_buffer7 = sp + 24|0;
 $vararg_buffer4 = sp + 16|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $5 = ($0|0)==(0|0);
 if ($5) {
  HEAP32[$vararg_buffer>>2] = 183437;
  (_SDL_SetError(194740,$vararg_buffer)|0);
  $$0208 = 0;
  STACKTOP = sp;return ($$0208|0);
 }
 $6 = ($1|0)==(0|0);
 if ($6) {
  HEAP32[$vararg_buffer1>>2] = 183442;
  (_SDL_SetError(194740,$vararg_buffer1)|0);
  $$0208 = 0;
  STACKTOP = sp;return ($$0208|0);
 }
 $7 = ($2|0)==(0|0);
 if ($7) {
  HEAP32[$vararg_buffer4>>2] = 183445;
  (_SDL_SetError(194740,$vararg_buffer4)|0);
  $$0208 = 0;
  STACKTOP = sp;return ($$0208|0);
 }
 $8 = ($3|0)==(0|0);
 if ($8) {
  HEAP32[$vararg_buffer7>>2] = 183448;
  (_SDL_SetError(194740,$vararg_buffer7)|0);
  $$0208 = 0;
  STACKTOP = sp;return ($$0208|0);
 }
 $9 = ($4|0)==(0|0);
 if ($9) {
  HEAP32[$vararg_buffer10>>2] = 183451;
  (_SDL_SetError(194740,$vararg_buffer10)|0);
  $$0208 = 0;
  STACKTOP = sp;return ($$0208|0);
 }
 $10 = ((($0)) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)<(1);
 if ($12) {
  $$0208 = 0;
  STACKTOP = sp;return ($$0208|0);
 }
 $13 = ((($0)) + 12|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)<(1);
 if ($15) {
  $$0208 = 0;
  STACKTOP = sp;return ($$0208|0);
 }
 $16 = HEAP32[$1>>2]|0;
 $17 = HEAP32[$2>>2]|0;
 $18 = HEAP32[$3>>2]|0;
 $19 = HEAP32[$4>>2]|0;
 $20 = HEAP32[$0>>2]|0;
 $21 = ((($0)) + 4|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($11) + ($20))|0;
 $24 = (($23) + -1)|0;
 $25 = (($14) + ($22))|0;
 $26 = (($25) + -1)|0;
 $notlhs = ($16|0)<($20|0);
 $notrhs = ($16|0)>=($23|0);
 $or$cond$not = $notlhs | $notrhs;
 $27 = ($18|0)<($20|0);
 $or$cond217 = $27 | $or$cond$not;
 $28 = ($18|0)<($23|0);
 $$not258 = $28 ^ 1;
 $or$cond218$not = $or$cond217 | $$not258;
 $29 = ($17|0)<($22|0);
 $or$cond219 = $29 | $or$cond218$not;
 $$not259 = ($17|0)>=($25|0);
 $or$cond220$not = $$not259 | $or$cond219;
 $30 = ($19|0)<($22|0);
 $or$cond221 = $30 | $or$cond220$not;
 $or$cond221$not = $or$cond221 ^ 1;
 $31 = ($19|0)<($25|0);
 $or$cond222 = $31 & $or$cond221$not;
 if ($or$cond222) {
  $$0208 = 1;
  STACKTOP = sp;return ($$0208|0);
 }
 $or$cond223 = $notlhs & $27;
 if ($or$cond223) {
  $$0208 = 0;
  STACKTOP = sp;return ($$0208|0);
 }
 $or$cond224$not = $notrhs & $$not258;
 $or$cond225 = $29 & $30;
 $or$cond251 = $or$cond225 | $or$cond224$not;
 $or$cond251$not = $or$cond251 ^ 1;
 $$not226 = $$not259 ^ 1;
 $or$cond227 = $31 | $$not226;
 $or$cond = $or$cond227 & $or$cond251$not;
 if (!($or$cond)) {
  $$0208 = 0;
  STACKTOP = sp;return ($$0208|0);
 }
 $32 = ($17|0)==($19|0);
 if ($32) {
  if ($or$cond$not) {
   $$mux = $notlhs ? $20 : $24;
   HEAP32[$1>>2] = $$mux;
  }
  $brmerge253 = $27 | $$not258;
  if (!($brmerge253)) {
   $$0208 = 1;
   STACKTOP = sp;return ($$0208|0);
  }
  $$mux254 = $27 ? $20 : $24;
  HEAP32[$3>>2] = $$mux254;
  $$0208 = 1;
  STACKTOP = sp;return ($$0208|0);
 }
 $33 = ($16|0)==($18|0);
 if ($33) {
  $brmerge234 = $29 | $$not259;
  if ($brmerge234) {
   $$mux235 = $29 ? $22 : $26;
   HEAP32[$2>>2] = $$mux235;
  }
  $$not255 = $31 ^ 1;
  $brmerge256 = $30 | $$not255;
  if (!($brmerge256)) {
   $$0208 = 1;
   STACKTOP = sp;return ($$0208|0);
  }
  $$mux257 = $30 ? $22 : $26;
  HEAP32[$4>>2] = $$mux257;
  $$0208 = 1;
  STACKTOP = sp;return ($$0208|0);
 }
 $$$i247 = $$not259&1;
 $$$$i247 = $29 ? 2 : $$$i247;
 if ($notlhs) {
  $34 = $$$$i247 | 4;
  $40 = $34;
 } else {
  $35 = ($23|0)>($16|0);
  $36 = $$$$i247 | 8;
  $$0$$i249 = $35 ? $$$$i247 : $36;
  $40 = $$0$$i249;
 }
 $not$$i241 = ($25|0)<=($19|0);
 $$$i242 = $not$$i241&1;
 $$0$i243 = $30 ? 2 : $$$i242;
 $37 = $$0$i243 | 4;
 $38 = $$0$i243 | 8;
 $$0$$i244 = $28 ? $$0$i243 : $38;
 $$0$ph = $27 ? $37 : $$0$$i244;
 $39 = $$0$ph | $40;
 $41 = ($39|0)==(0);
 L60: do {
  if ($41) {
   $$0213$ph$lcssa272 = $16;$$0214$lcssa = $19;$$0215$lcssa = $18;$$0216$ph$lcssa273 = $17;
  } else {
   $$0209$ph293 = 0;$$0210$ph292 = 0;$$0213$ph290 = $16;$$0216$ph286 = $17;$$in = $40;
   while(1) {
    $42 = ($$in|0)==(0);
    $43 = (($24) - ($$0213$ph290))|0;
    $44 = (($20) - ($$0213$ph290))|0;
    $45 = (($26) - ($$0216$ph286))|0;
    $46 = (($22) - ($$0216$ph286))|0;
    if ($42) {
     $$0209277$us = $$0209$ph293;$$0210276$us = $$0210$ph292;$$0214275$us = $19;$$0215274$us = $18;$$0278$us = $$0$ph;
     break;
    }
    $84 = $$0$ph & $$in;
    $85 = ($84|0)==(0);
    if (!($85)) {
     $$0208 = 0;
     label = 58;
     break;
    }
    $86 = $$in & 2;
    $87 = ($86|0)==(0);
    do {
     if ($87) {
      $93 = $$in & 1;
      $94 = ($93|0)==(0);
      if (!($94)) {
       $95 = (($18) - ($$0213$ph290))|0;
       $96 = Math_imul($95, $45)|0;
       $97 = (($19) - ($$0216$ph286))|0;
       $98 = (($96|0) / ($97|0))&-1;
       $99 = (($98) + ($$0213$ph290))|0;
       $$1 = $99;$$1211 = $26;
       break;
      }
      $100 = $$in & 4;
      $101 = ($100|0)==(0);
      if (!($101)) {
       $102 = (($19) - ($$0216$ph286))|0;
       $103 = Math_imul($44, $102)|0;
       $104 = (($18) - ($$0213$ph290))|0;
       $105 = (($103|0) / ($104|0))&-1;
       $106 = (($105) + ($$0216$ph286))|0;
       $$1 = $20;$$1211 = $106;
       break;
      }
      $107 = $$in & 8;
      $108 = ($107|0)==(0);
      if ($108) {
       $$1 = $$0209$ph293;$$1211 = $$0210$ph292;
       break;
      }
      $109 = (($18) - ($$0213$ph290))|0;
      $110 = (($19) - ($$0216$ph286))|0;
      $111 = Math_imul($43, $110)|0;
      $112 = (($111|0) / ($109|0))&-1;
      $113 = (($112) + ($$0216$ph286))|0;
      $$1 = $24;$$1211 = $113;
     } else {
      $88 = (($18) - ($$0213$ph290))|0;
      $89 = Math_imul($88, $46)|0;
      $90 = (($19) - ($$0216$ph286))|0;
      $91 = (($89|0) / ($90|0))&-1;
      $92 = (($91) + ($$0213$ph290))|0;
      $$1 = $92;$$1211 = $22;
     }
    } while(0);
    $114 = ($22|0)>($$1211|0);
    $not$$i236 = ($25|0)<=($$1211|0);
    $$$i237 = $not$$i236&1;
    $$0$i238 = $114 ? 2 : $$$i237;
    $115 = ($20|0)>($$1|0);
    if ($115) {
     $116 = $$0$i238 | 4;
     $$0207$ph$be = $116;
    } else {
     $117 = ($23|0)>($$1|0);
     $118 = $$0$i238 | 8;
     $$0$$i239 = $117 ? $$0$i238 : $118;
     $$0207$ph$be = $$0$$i239;
    }
    $119 = $$0$ph | $$0207$ph$be;
    $120 = ($119|0)==(0);
    if ($120) {
     $$0213$ph$lcssa272 = $$1;$$0214$lcssa = $19;$$0215$lcssa = $18;$$0216$ph$lcssa273 = $$1211;
     break L60;
    } else {
     $$0209$ph293 = $$1;$$0210$ph292 = $$1211;$$0213$ph290 = $$1;$$0216$ph286 = $$1211;$$in = $$0207$ph$be;
    }
   }
   if ((label|0) == 58) {
    STACKTOP = sp;return ($$0208|0);
   }
   while(1) {
    $47 = $$0278$us & $$in;
    $48 = ($47|0)==(0);
    if (!($48)) {
     $$0208 = 0;
     break;
    }
    $49 = $$0278$us & 2;
    $50 = ($49|0)==(0);
    do {
     if ($50) {
      $56 = $$0278$us & 1;
      $57 = ($56|0)==(0);
      if (!($57)) {
       $58 = (($$0215274$us) - ($$0213$ph290))|0;
       $59 = Math_imul($58, $45)|0;
       $60 = (($$0214275$us) - ($$0216$ph286))|0;
       $61 = (($59|0) / ($60|0))&-1;
       $62 = (($61) + ($$0213$ph290))|0;
       $$2$us = $62;$$2212$us = $26;
       break;
      }
      $63 = $$0278$us & 4;
      $64 = ($63|0)==(0);
      if (!($64)) {
       $65 = (($$0214275$us) - ($$0216$ph286))|0;
       $66 = Math_imul($44, $65)|0;
       $67 = (($$0215274$us) - ($$0213$ph290))|0;
       $68 = (($66|0) / ($67|0))&-1;
       $69 = (($68) + ($$0216$ph286))|0;
       $$2$us = $20;$$2212$us = $69;
       break;
      }
      $70 = $$0278$us & 8;
      $71 = ($70|0)==(0);
      if ($71) {
       $$2$us = $$0209277$us;$$2212$us = $$0210276$us;
       break;
      }
      $72 = (($$0215274$us) - ($$0213$ph290))|0;
      $73 = (($$0214275$us) - ($$0216$ph286))|0;
      $74 = Math_imul($43, $73)|0;
      $75 = (($74|0) / ($72|0))&-1;
      $76 = (($75) + ($$0216$ph286))|0;
      $$2$us = $24;$$2212$us = $76;
     } else {
      $51 = (($$0215274$us) - ($$0213$ph290))|0;
      $52 = Math_imul($51, $46)|0;
      $53 = (($$0214275$us) - ($$0216$ph286))|0;
      $54 = (($52|0) / ($53|0))&-1;
      $55 = (($54) + ($$0213$ph290))|0;
      $$2$us = $55;$$2212$us = $22;
     }
    } while(0);
    $77 = ($22|0)>($$2212$us|0);
    $not$$i$us = ($25|0)<=($$2212$us|0);
    $$$i$us = $not$$i$us&1;
    $$0$i$us = $77 ? 2 : $$$i$us;
    $78 = ($20|0)>($$2$us|0);
    if ($78) {
     $81 = $$0$i$us | 4;
     $$0$be$us = $81;
    } else {
     $79 = ($23|0)>($$2$us|0);
     $80 = $$0$i$us | 8;
     $$0$$i$us = $79 ? $$0$i$us : $80;
     $$0$be$us = $$0$$i$us;
    }
    $82 = $$0$be$us | $$in;
    $83 = ($82|0)==(0);
    if ($83) {
     $$0213$ph$lcssa272 = $$0213$ph290;$$0214$lcssa = $$2212$us;$$0215$lcssa = $$2$us;$$0216$ph$lcssa273 = $$0216$ph286;
     break L60;
    } else {
     $$0209277$us = $$2$us;$$0210276$us = $$2212$us;$$0214275$us = $$2212$us;$$0215274$us = $$2$us;$$0278$us = $$0$be$us;
    }
   }
   STACKTOP = sp;return ($$0208|0);
  }
 } while(0);
 HEAP32[$1>>2] = $$0213$ph$lcssa272;
 HEAP32[$2>>2] = $$0216$ph$lcssa273;
 HEAP32[$3>>2] = $$0215$lcssa;
 HEAP32[$4>>2] = $$0214$lcssa;
 $$0208 = 1;
 STACKTOP = sp;return ($$0208|0);
}
function _SDL_BlendPoint($0,$1,$2,$3,$4,$5,$6,$7) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 var $$0 = 0, $$061 = 0, $$062 = 0, $$063 = 0, $$off = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $8 = 0, $9 = 0, $cond = 0, $cond1 = 0, $cond2 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $8 = ($0|0)==(0|0);
 if ($8) {
  $9 = (_SDL_SetError(183547,$vararg_buffer)|0);
  $$0 = $9;
  STACKTOP = sp;return ($$0|0);
 }
 $10 = ((($0)) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11)) + 8|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = ($13&255)<(8);
 if ($14) {
  $15 = (_SDL_SetError(183392,$vararg_buffer1)|0);
  $$0 = $15;
  STACKTOP = sp;return ($$0|0);
 }
 $16 = ((($0)) + 36|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)>($1|0);
 if ($18) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $19 = ((($0)) + 40|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)>($2|0);
 if ($21) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $22 = ((($0)) + 44|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($23) + ($17))|0;
 $25 = ($24|0)>($1|0);
 if (!($25)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $26 = ((($0)) + 48|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (($27) + ($20))|0;
 $29 = ($28|0)>($2|0);
 if (!($29)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $$off = (($3) + -1)|0;
 $30 = ($$off>>>0)<(2);
 if ($30) {
  $31 = $4&255;
  $32 = $7&255;
  $33 = Math_imul($32, $31)|0;
  $34 = (($33>>>0) / 255)&-1;
  $35 = $34&255;
  $36 = $5&255;
  $37 = Math_imul($32, $36)|0;
  $38 = (($37>>>0) / 255)&-1;
  $39 = $38&255;
  $40 = $6&255;
  $41 = Math_imul($32, $40)|0;
  $42 = (($41>>>0) / 255)&-1;
  $43 = $42&255;
  $$061 = $43;$$062 = $39;$$063 = $35;
 } else {
  $$061 = $6;$$062 = $5;$$063 = $4;
 }
 switch ($13<<24>>24) {
 case 15:  {
  $44 = ((($11)) + 12|0);
  $45 = HEAP32[$44>>2]|0;
  $cond2 = ($45|0)==(31744);
  if ($cond2) {
   (_SDL_BlendPoint_RGB555($0,$1,$2,$3,$$063,$$062,$$061,$7)|0);
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  break;
 }
 case 16:  {
  $46 = ((($11)) + 12|0);
  $47 = HEAP32[$46>>2]|0;
  $cond1 = ($47|0)==(63488);
  if ($cond1) {
   (_SDL_BlendPoint_RGB565($0,$1,$2,$3,$$063,$$062,$$061,$7)|0);
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  break;
 }
 case 32:  {
  $48 = ((($11)) + 12|0);
  $49 = HEAP32[$48>>2]|0;
  $cond = ($49|0)==(16711680);
  if ($cond) {
   $50 = ((($11)) + 24|0);
   $51 = HEAP32[$50>>2]|0;
   $52 = ($51|0)==(0);
   if ($52) {
    (_SDL_BlendPoint_RGB888($0,$1,$2,$3,$$063,$$062,$$061,$7)|0);
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   } else {
    (_SDL_BlendPoint_ARGB8888($0,$1,$2,$3,$$063,$$062,$$061,$7)|0);
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
  }
  break;
 }
 default: {
 }
 }
 $53 = ((($11)) + 24|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = ($54|0)==(0);
 if ($55) {
  $56 = (_SDL_BlendPoint_RGB($0,$1,$2,$3,$$063,$$062,$$061,$7)|0);
  $$0 = $56;
  STACKTOP = sp;return ($$0|0);
 } else {
  $57 = (_SDL_BlendPoint_RGBA($0,$1,$2,$3,$$063,$$062,$$061,$7)|0);
  $$0 = $57;
  STACKTOP = sp;return ($$0|0);
 }
 return (0)|0;
}
function _SDL_BlendPoint_RGB555($0,$1,$2,$3,$4,$5,$6,$7) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 var $$ = 0, $$1 = 0, $$2 = 0, $$sink119 = 0, $$sink122 = 0, $$sink125 = 0, $$sink126 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $8 = $7 ^ -1;
 $9 = $8&255;
 switch ($3|0) {
 case 1:  {
  $10 = ((($0)) + 20|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ((($0)) + 16|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = Math_imul($13, $2)|0;
  $15 = (($11) + ($14)|0);
  $16 = $1 << 1;
  $17 = (($15) + ($16)|0);
  $18 = HEAP32[(79224)>>2]|0;
  $19 = HEAP16[$17>>1]|0;
  $20 = $19&65535;
  $21 = $20 >>> 10;
  $22 = $21 & 31;
  $23 = (($18) + ($22)|0);
  $24 = HEAP8[$23>>0]|0;
  $25 = $24&255;
  $26 = $20 >>> 5;
  $27 = $26 & 31;
  $28 = (($18) + ($27)|0);
  $29 = HEAP8[$28>>0]|0;
  $30 = $29&255;
  $31 = $20 & 31;
  $32 = (($18) + ($31)|0);
  $33 = HEAP8[$32>>0]|0;
  $34 = $33&255;
  $35 = Math_imul($25, $9)|0;
  $36 = (($35>>>0) / 255)&-1;
  $37 = $4&255;
  $38 = (($36) + ($37))|0;
  $39 = Math_imul($30, $9)|0;
  $40 = (($39>>>0) / 255)&-1;
  $41 = $5&255;
  $42 = (($40) + ($41))|0;
  $43 = Math_imul($34, $9)|0;
  $44 = (($43>>>0) / 255)&-1;
  $45 = $6&255;
  $46 = (($44) + ($45))|0;
  $$sink119 = $17;$$sink122 = $46;$$sink125 = $42;$$sink126 = $38;
  break;
 }
 case 2:  {
  $47 = ((($0)) + 20|0);
  $48 = HEAP32[$47>>2]|0;
  $49 = ((($0)) + 16|0);
  $50 = HEAP32[$49>>2]|0;
  $51 = Math_imul($50, $2)|0;
  $52 = (($48) + ($51)|0);
  $53 = $1 << 1;
  $54 = (($52) + ($53)|0);
  $55 = HEAP32[(79224)>>2]|0;
  $56 = HEAP16[$54>>1]|0;
  $57 = $56&65535;
  $58 = $57 >>> 10;
  $59 = $58 & 31;
  $60 = (($55) + ($59)|0);
  $61 = HEAP8[$60>>0]|0;
  $62 = $61&255;
  $63 = $57 >>> 5;
  $64 = $63 & 31;
  $65 = (($55) + ($64)|0);
  $66 = HEAP8[$65>>0]|0;
  $67 = $66&255;
  $68 = $57 & 31;
  $69 = (($55) + ($68)|0);
  $70 = HEAP8[$69>>0]|0;
  $71 = $70&255;
  $72 = $4&255;
  $73 = (($62) + ($72))|0;
  $74 = ($73>>>0)<(255);
  $$1 = $74 ? $73 : 255;
  $75 = $5&255;
  $76 = (($67) + ($75))|0;
  $77 = ($76>>>0)<(255);
  $$ = $77 ? $76 : 255;
  $78 = $6&255;
  $79 = (($71) + ($78))|0;
  $80 = ($79>>>0)<(255);
  $$2 = $80 ? $79 : 255;
  $$sink119 = $54;$$sink122 = $$2;$$sink125 = $$;$$sink126 = $$1;
  break;
 }
 case 4:  {
  $81 = ((($0)) + 20|0);
  $82 = HEAP32[$81>>2]|0;
  $83 = ((($0)) + 16|0);
  $84 = HEAP32[$83>>2]|0;
  $85 = Math_imul($84, $2)|0;
  $86 = (($82) + ($85)|0);
  $87 = $1 << 1;
  $88 = (($86) + ($87)|0);
  $89 = HEAP32[(79224)>>2]|0;
  $90 = HEAP16[$88>>1]|0;
  $91 = $90&65535;
  $92 = $91 >>> 10;
  $93 = $92 & 31;
  $94 = (($89) + ($93)|0);
  $95 = HEAP8[$94>>0]|0;
  $96 = $95&255;
  $97 = $91 >>> 5;
  $98 = $97 & 31;
  $99 = (($89) + ($98)|0);
  $100 = HEAP8[$99>>0]|0;
  $101 = $100&255;
  $102 = $91 & 31;
  $103 = (($89) + ($102)|0);
  $104 = HEAP8[$103>>0]|0;
  $105 = $104&255;
  $106 = $4&255;
  $107 = Math_imul($96, $106)|0;
  $108 = (($107>>>0) / 255)&-1;
  $109 = $5&255;
  $110 = Math_imul($101, $109)|0;
  $111 = (($110>>>0) / 255)&-1;
  $112 = $6&255;
  $113 = Math_imul($105, $112)|0;
  $114 = (($113>>>0) / 255)&-1;
  $$sink119 = $88;$$sink122 = $114;$$sink125 = $111;$$sink126 = $108;
  break;
 }
 default: {
  $115 = ((($0)) + 20|0);
  $116 = HEAP32[$115>>2]|0;
  $117 = ((($0)) + 16|0);
  $118 = HEAP32[$117>>2]|0;
  $119 = Math_imul($118, $2)|0;
  $120 = (($116) + ($119)|0);
  $121 = $1 << 1;
  $122 = (($120) + ($121)|0);
  $123 = $4&255;
  $124 = $5&255;
  $125 = $6&255;
  $$sink119 = $122;$$sink122 = $125;$$sink125 = $124;$$sink126 = $123;
 }
 }
 $126 = $$sink126 >>> 3;
 $127 = $126 << 10;
 $128 = $$sink125 >>> 3;
 $129 = $128 << 5;
 $130 = $129 | $127;
 $131 = $$sink122 >>> 3;
 $132 = $130 | $131;
 $133 = $132&65535;
 HEAP16[$$sink119>>1] = $133;
 return 0;
}
function _SDL_BlendPoint_RGB565($0,$1,$2,$3,$4,$5,$6,$7) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 var $$ = 0, $$1 = 0, $$2 = 0, $$sink119 = 0, $$sink122 = 0, $$sink125 = 0, $$sink126 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $8 = $7 ^ -1;
 $9 = $8&255;
 switch ($3|0) {
 case 1:  {
  $10 = ((($0)) + 20|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ((($0)) + 16|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = Math_imul($13, $2)|0;
  $15 = (($11) + ($14)|0);
  $16 = $1 << 1;
  $17 = (($15) + ($16)|0);
  $18 = HEAP32[(79224)>>2]|0;
  $19 = HEAP16[$17>>1]|0;
  $20 = $19&65535;
  $21 = $20 >>> 11;
  $22 = (($18) + ($21)|0);
  $23 = HEAP8[$22>>0]|0;
  $24 = $23&255;
  $25 = HEAP32[(79220)>>2]|0;
  $26 = $20 >>> 5;
  $27 = $26 & 63;
  $28 = (($25) + ($27)|0);
  $29 = HEAP8[$28>>0]|0;
  $30 = $29&255;
  $31 = $20 & 31;
  $32 = (($18) + ($31)|0);
  $33 = HEAP8[$32>>0]|0;
  $34 = $33&255;
  $35 = Math_imul($24, $9)|0;
  $36 = (($35>>>0) / 255)&-1;
  $37 = $4&255;
  $38 = (($36) + ($37))|0;
  $39 = Math_imul($30, $9)|0;
  $40 = (($39>>>0) / 255)&-1;
  $41 = $5&255;
  $42 = (($40) + ($41))|0;
  $43 = Math_imul($34, $9)|0;
  $44 = (($43>>>0) / 255)&-1;
  $45 = $6&255;
  $46 = (($44) + ($45))|0;
  $$sink119 = $17;$$sink122 = $46;$$sink125 = $42;$$sink126 = $38;
  break;
 }
 case 2:  {
  $47 = ((($0)) + 20|0);
  $48 = HEAP32[$47>>2]|0;
  $49 = ((($0)) + 16|0);
  $50 = HEAP32[$49>>2]|0;
  $51 = Math_imul($50, $2)|0;
  $52 = (($48) + ($51)|0);
  $53 = $1 << 1;
  $54 = (($52) + ($53)|0);
  $55 = HEAP32[(79224)>>2]|0;
  $56 = HEAP16[$54>>1]|0;
  $57 = $56&65535;
  $58 = $57 >>> 11;
  $59 = (($55) + ($58)|0);
  $60 = HEAP8[$59>>0]|0;
  $61 = $60&255;
  $62 = HEAP32[(79220)>>2]|0;
  $63 = $57 >>> 5;
  $64 = $63 & 63;
  $65 = (($62) + ($64)|0);
  $66 = HEAP8[$65>>0]|0;
  $67 = $66&255;
  $68 = $57 & 31;
  $69 = (($55) + ($68)|0);
  $70 = HEAP8[$69>>0]|0;
  $71 = $70&255;
  $72 = $4&255;
  $73 = (($61) + ($72))|0;
  $74 = ($73>>>0)<(255);
  $$1 = $74 ? $73 : 255;
  $75 = $5&255;
  $76 = (($67) + ($75))|0;
  $77 = ($76>>>0)<(255);
  $$ = $77 ? $76 : 255;
  $78 = $6&255;
  $79 = (($71) + ($78))|0;
  $80 = ($79>>>0)<(255);
  $$2 = $80 ? $79 : 255;
  $$sink119 = $54;$$sink122 = $$2;$$sink125 = $$;$$sink126 = $$1;
  break;
 }
 case 4:  {
  $81 = ((($0)) + 20|0);
  $82 = HEAP32[$81>>2]|0;
  $83 = ((($0)) + 16|0);
  $84 = HEAP32[$83>>2]|0;
  $85 = Math_imul($84, $2)|0;
  $86 = (($82) + ($85)|0);
  $87 = $1 << 1;
  $88 = (($86) + ($87)|0);
  $89 = HEAP32[(79224)>>2]|0;
  $90 = HEAP16[$88>>1]|0;
  $91 = $90&65535;
  $92 = $91 >>> 11;
  $93 = (($89) + ($92)|0);
  $94 = HEAP8[$93>>0]|0;
  $95 = $94&255;
  $96 = HEAP32[(79220)>>2]|0;
  $97 = $91 >>> 5;
  $98 = $97 & 63;
  $99 = (($96) + ($98)|0);
  $100 = HEAP8[$99>>0]|0;
  $101 = $100&255;
  $102 = $91 & 31;
  $103 = (($89) + ($102)|0);
  $104 = HEAP8[$103>>0]|0;
  $105 = $104&255;
  $106 = $4&255;
  $107 = Math_imul($95, $106)|0;
  $108 = (($107>>>0) / 255)&-1;
  $109 = $5&255;
  $110 = Math_imul($101, $109)|0;
  $111 = (($110>>>0) / 255)&-1;
  $112 = $6&255;
  $113 = Math_imul($105, $112)|0;
  $114 = (($113>>>0) / 255)&-1;
  $$sink119 = $88;$$sink122 = $114;$$sink125 = $111;$$sink126 = $108;
  break;
 }
 default: {
  $115 = ((($0)) + 20|0);
  $116 = HEAP32[$115>>2]|0;
  $117 = ((($0)) + 16|0);
  $118 = HEAP32[$117>>2]|0;
  $119 = Math_imul($118, $2)|0;
  $120 = (($116) + ($119)|0);
  $121 = $1 << 1;
  $122 = (($120) + ($121)|0);
  $123 = $4&255;
  $124 = $5&255;
  $125 = $6&255;
  $$sink119 = $122;$$sink122 = $125;$$sink125 = $124;$$sink126 = $123;
 }
 }
 $126 = $$sink126 >>> 3;
 $127 = $126 << 11;
 $128 = $$sink125 >>> 2;
 $129 = $128 << 5;
 $130 = $129 | $127;
 $131 = $$sink122 >>> 3;
 $132 = $130 | $131;
 $133 = $132&65535;
 HEAP16[$$sink119>>1] = $133;
 return 0;
}
function _SDL_BlendPoint_RGB888($0,$1,$2,$3,$4,$5,$6,$7) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 var $$ = 0, $$1 = 0, $$2 = 0, $$sink119 = 0, $$sink121 = 0, $$sink123 = 0, $$sink124 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $8 = $7 ^ -1;
 $9 = $8&255;
 switch ($3|0) {
 case 1:  {
  $10 = ((($0)) + 20|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ((($0)) + 16|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = Math_imul($13, $2)|0;
  $15 = (($11) + ($14)|0);
  $16 = $1 << 2;
  $17 = (($15) + ($16)|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = $18 >>> 16;
  $20 = $19 & 255;
  $21 = $18 >>> 8;
  $22 = $21 & 255;
  $23 = $18 & 255;
  $24 = Math_imul($20, $9)|0;
  $25 = (($24>>>0) / 255)&-1;
  $26 = $4&255;
  $27 = (($25) + ($26))|0;
  $28 = Math_imul($22, $9)|0;
  $29 = (($28>>>0) / 255)&-1;
  $30 = $5&255;
  $31 = (($29) + ($30))|0;
  $32 = Math_imul($23, $9)|0;
  $33 = (($32>>>0) / 255)&-1;
  $34 = $6&255;
  $35 = (($33) + ($34))|0;
  $$sink119 = $17;$$sink121 = $35;$$sink123 = $31;$$sink124 = $27;
  $93 = $$sink124 << 16;
  $94 = $$sink123 << 8;
  $95 = $94 | $93;
  $96 = $95 | $$sink121;
  HEAP32[$$sink119>>2] = $96;
  return 0;
  break;
 }
 case 2:  {
  $36 = ((($0)) + 20|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = ((($0)) + 16|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = Math_imul($39, $2)|0;
  $41 = (($37) + ($40)|0);
  $42 = $1 << 2;
  $43 = (($41) + ($42)|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = $44 >>> 16;
  $46 = $45 & 255;
  $47 = $44 >>> 8;
  $48 = $47 & 255;
  $49 = $44 & 255;
  $50 = $4&255;
  $51 = (($46) + ($50))|0;
  $52 = ($51>>>0)<(255);
  $$1 = $52 ? $51 : 255;
  $53 = $5&255;
  $54 = (($48) + ($53))|0;
  $55 = ($54>>>0)<(255);
  $$ = $55 ? $54 : 255;
  $56 = $6&255;
  $57 = (($49) + ($56))|0;
  $58 = ($57>>>0)<(255);
  $$2 = $58 ? $57 : 255;
  $$sink119 = $43;$$sink121 = $$2;$$sink123 = $$;$$sink124 = $$1;
  $93 = $$sink124 << 16;
  $94 = $$sink123 << 8;
  $95 = $94 | $93;
  $96 = $95 | $$sink121;
  HEAP32[$$sink119>>2] = $96;
  return 0;
  break;
 }
 case 4:  {
  $59 = ((($0)) + 20|0);
  $60 = HEAP32[$59>>2]|0;
  $61 = ((($0)) + 16|0);
  $62 = HEAP32[$61>>2]|0;
  $63 = Math_imul($62, $2)|0;
  $64 = (($60) + ($63)|0);
  $65 = $1 << 2;
  $66 = (($64) + ($65)|0);
  $67 = HEAP32[$66>>2]|0;
  $68 = $67 >>> 16;
  $69 = $68 & 255;
  $70 = $67 >>> 8;
  $71 = $70 & 255;
  $72 = $67 & 255;
  $73 = $4&255;
  $74 = Math_imul($69, $73)|0;
  $75 = (($74>>>0) / 255)&-1;
  $76 = $5&255;
  $77 = Math_imul($71, $76)|0;
  $78 = (($77>>>0) / 255)&-1;
  $79 = $6&255;
  $80 = Math_imul($72, $79)|0;
  $81 = (($80>>>0) / 255)&-1;
  $$sink119 = $66;$$sink121 = $81;$$sink123 = $78;$$sink124 = $75;
  $93 = $$sink124 << 16;
  $94 = $$sink123 << 8;
  $95 = $94 | $93;
  $96 = $95 | $$sink121;
  HEAP32[$$sink119>>2] = $96;
  return 0;
  break;
 }
 default: {
  $82 = ((($0)) + 20|0);
  $83 = HEAP32[$82>>2]|0;
  $84 = ((($0)) + 16|0);
  $85 = HEAP32[$84>>2]|0;
  $86 = Math_imul($85, $2)|0;
  $87 = (($83) + ($86)|0);
  $88 = $1 << 2;
  $89 = (($87) + ($88)|0);
  $90 = $4&255;
  $91 = $5&255;
  $92 = $6&255;
  $$sink119 = $89;$$sink121 = $92;$$sink123 = $91;$$sink124 = $90;
  $93 = $$sink124 << 16;
  $94 = $$sink123 << 8;
  $95 = $94 | $93;
  $96 = $95 | $$sink121;
  HEAP32[$$sink119>>2] = $96;
  return 0;
 }
 }
 return (0)|0;
}
function _SDL_BlendPoint_ARGB8888($0,$1,$2,$3,$4,$5,$6,$7) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 var $$ = 0, $$1 = 0, $$2 = 0, $$sink = 0, $$sink126 = 0, $$sink128 = 0, $$sink130 = 0, $$sink131 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $8 = $7&255;
 $9 = $8 ^ 255;
 switch ($3|0) {
 case 1:  {
  $10 = ((($0)) + 20|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ((($0)) + 16|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = Math_imul($13, $2)|0;
  $15 = (($11) + ($14)|0);
  $16 = $1 << 2;
  $17 = (($15) + ($16)|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = $18 >>> 16;
  $20 = $19 & 255;
  $21 = $18 >>> 8;
  $22 = $21 & 255;
  $23 = $18 & 255;
  $24 = $18 >>> 24;
  $25 = Math_imul($20, $9)|0;
  $26 = (($25>>>0) / 255)&-1;
  $27 = $4&255;
  $28 = (($26) + ($27))|0;
  $29 = Math_imul($22, $9)|0;
  $30 = (($29>>>0) / 255)&-1;
  $31 = $5&255;
  $32 = (($30) + ($31))|0;
  $33 = Math_imul($23, $9)|0;
  $34 = (($33>>>0) / 255)&-1;
  $35 = $6&255;
  $36 = (($34) + ($35))|0;
  $37 = Math_imul($24, $9)|0;
  $38 = (($37>>>0) / 255)&-1;
  $39 = (($38) + ($8))|0;
  $40 = $39 << 24;
  $$sink = $28;$$sink126 = $17;$$sink128 = $36;$$sink130 = $32;$$sink131 = $40;
  break;
 }
 case 2:  {
  $41 = ((($0)) + 20|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = ((($0)) + 16|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = Math_imul($44, $2)|0;
  $46 = (($42) + ($45)|0);
  $47 = $1 << 2;
  $48 = (($46) + ($47)|0);
  $49 = HEAP32[$48>>2]|0;
  $50 = $49 >>> 16;
  $51 = $50 & 255;
  $52 = $49 >>> 8;
  $53 = $52 & 255;
  $54 = $49 & 255;
  $55 = $49 & -16777216;
  $56 = $4&255;
  $57 = (($51) + ($56))|0;
  $58 = ($57>>>0)<(255);
  $$1 = $58 ? $57 : 255;
  $59 = $5&255;
  $60 = (($53) + ($59))|0;
  $61 = ($60>>>0)<(255);
  $$ = $61 ? $60 : 255;
  $62 = $6&255;
  $63 = (($54) + ($62))|0;
  $64 = ($63>>>0)<(255);
  $$2 = $64 ? $63 : 255;
  $$sink = $$1;$$sink126 = $48;$$sink128 = $$2;$$sink130 = $$;$$sink131 = $55;
  break;
 }
 case 4:  {
  $65 = ((($0)) + 20|0);
  $66 = HEAP32[$65>>2]|0;
  $67 = ((($0)) + 16|0);
  $68 = HEAP32[$67>>2]|0;
  $69 = Math_imul($68, $2)|0;
  $70 = (($66) + ($69)|0);
  $71 = $1 << 2;
  $72 = (($70) + ($71)|0);
  $73 = HEAP32[$72>>2]|0;
  $74 = $73 >>> 16;
  $75 = $74 & 255;
  $76 = $73 >>> 8;
  $77 = $76 & 255;
  $78 = $73 & 255;
  $79 = $73 & -16777216;
  $80 = $4&255;
  $81 = Math_imul($75, $80)|0;
  $82 = (($81>>>0) / 255)&-1;
  $83 = $5&255;
  $84 = Math_imul($77, $83)|0;
  $85 = (($84>>>0) / 255)&-1;
  $86 = $6&255;
  $87 = Math_imul($78, $86)|0;
  $88 = (($87>>>0) / 255)&-1;
  $$sink = $82;$$sink126 = $72;$$sink128 = $88;$$sink130 = $85;$$sink131 = $79;
  break;
 }
 default: {
  $89 = ((($0)) + 20|0);
  $90 = HEAP32[$89>>2]|0;
  $91 = ((($0)) + 16|0);
  $92 = HEAP32[$91>>2]|0;
  $93 = Math_imul($92, $2)|0;
  $94 = (($90) + ($93)|0);
  $95 = $1 << 2;
  $96 = (($94) + ($95)|0);
  $97 = $4&255;
  $98 = $5&255;
  $99 = $6&255;
  $100 = $8 << 24;
  $$sink = $97;$$sink126 = $96;$$sink128 = $99;$$sink130 = $98;$$sink131 = $100;
 }
 }
 $101 = $$sink << 16;
 $102 = $$sink131 | $101;
 $103 = $$sink130 << 8;
 $104 = $102 | $103;
 $105 = $104 | $$sink128;
 HEAP32[$$sink126>>2] = $105;
 return 0;
}
function _SDL_BlendPoint_RGB($0,$1,$2,$3,$4,$5,$6,$7) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 var $$ = 0, $$0 = 0, $$1 = 0, $$2 = 0, $$3 = 0, $$4 = 0, $$5 = 0, $$sink = 0, $$sink353 = 0, $$sink357 = 0, $$sink358 = 0, $$sink359 = 0, $$sink362 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0;
 var $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0;
 var $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0;
 var $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0;
 var $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0;
 var $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0;
 var $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0;
 var $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0;
 var $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0;
 var $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0;
 var $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0;
 var $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0;
 var $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0;
 var $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0;
 var $397 = 0, $398 = 0, $399 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0;
 var $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0;
 var $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0;
 var $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0;
 var $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0;
 var $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0;
 var $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0;
 var $524 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $8 = ((($0)) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $7 ^ -1;
 $11 = $10&255;
 $12 = ((($9)) + 9|0);
 $13 = HEAP8[$12>>0]|0;
 switch ($13<<24>>24) {
 case 2:  {
  switch ($3|0) {
  case 1:  {
   $14 = ((($0)) + 20|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = ((($0)) + 16|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = Math_imul($17, $2)|0;
   $19 = (($15) + ($18)|0);
   $20 = $1 << 1;
   $21 = (($19) + ($20)|0);
   $22 = ((($9)) + 28|0);
   $23 = HEAP8[$22>>0]|0;
   $24 = $23&255;
   $25 = (79212 + ($24<<2)|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = HEAP16[$21>>1]|0;
   $28 = $27&65535;
   $29 = ((($9)) + 12|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = $28 & $30;
   $32 = ((($9)) + 32|0);
   $33 = HEAP8[$32>>0]|0;
   $34 = $33&255;
   $35 = $31 >>> $34;
   $36 = (($26) + ($35)|0);
   $37 = HEAP8[$36>>0]|0;
   $38 = $37&255;
   $39 = ((($9)) + 29|0);
   $40 = HEAP8[$39>>0]|0;
   $41 = $40&255;
   $42 = (79212 + ($41<<2)|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = ((($9)) + 16|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = $45 & $28;
   $47 = ((($9)) + 33|0);
   $48 = HEAP8[$47>>0]|0;
   $49 = $48&255;
   $50 = $46 >>> $49;
   $51 = (($43) + ($50)|0);
   $52 = HEAP8[$51>>0]|0;
   $53 = $52&255;
   $54 = ((($9)) + 30|0);
   $55 = HEAP8[$54>>0]|0;
   $56 = $55&255;
   $57 = (79212 + ($56<<2)|0);
   $58 = HEAP32[$57>>2]|0;
   $59 = ((($9)) + 20|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = $60 & $28;
   $62 = ((($9)) + 34|0);
   $63 = HEAP8[$62>>0]|0;
   $64 = $63&255;
   $65 = $61 >>> $64;
   $66 = (($58) + ($65)|0);
   $67 = HEAP8[$66>>0]|0;
   $68 = $67&255;
   $69 = Math_imul($38, $11)|0;
   $70 = (($69>>>0) / 255)&-1;
   $71 = $4&255;
   $72 = (($70) + ($71))|0;
   $73 = Math_imul($53, $11)|0;
   $74 = (($73>>>0) / 255)&-1;
   $75 = $5&255;
   $76 = (($74) + ($75))|0;
   $77 = Math_imul($68, $11)|0;
   $78 = (($77>>>0) / 255)&-1;
   $79 = $6&255;
   $80 = (($78) + ($79))|0;
   $81 = $72 >>> $24;
   $82 = $81 << $34;
   $83 = $76 >>> $41;
   $84 = $83 << $49;
   $85 = $84 | $82;
   $86 = $80 >>> $56;
   $87 = $86 << $64;
   $$sink353 = $21;$$sink357 = $85;$$sink358 = $87;
   break;
  }
  case 2:  {
   $88 = ((($0)) + 20|0);
   $89 = HEAP32[$88>>2]|0;
   $90 = ((($0)) + 16|0);
   $91 = HEAP32[$90>>2]|0;
   $92 = Math_imul($91, $2)|0;
   $93 = (($89) + ($92)|0);
   $94 = $1 << 1;
   $95 = (($93) + ($94)|0);
   $96 = ((($9)) + 28|0);
   $97 = HEAP8[$96>>0]|0;
   $98 = $97&255;
   $99 = (79212 + ($98<<2)|0);
   $100 = HEAP32[$99>>2]|0;
   $101 = HEAP16[$95>>1]|0;
   $102 = $101&65535;
   $103 = ((($9)) + 12|0);
   $104 = HEAP32[$103>>2]|0;
   $105 = $102 & $104;
   $106 = ((($9)) + 32|0);
   $107 = HEAP8[$106>>0]|0;
   $108 = $107&255;
   $109 = $105 >>> $108;
   $110 = (($100) + ($109)|0);
   $111 = HEAP8[$110>>0]|0;
   $112 = $111&255;
   $113 = ((($9)) + 29|0);
   $114 = HEAP8[$113>>0]|0;
   $115 = $114&255;
   $116 = (79212 + ($115<<2)|0);
   $117 = HEAP32[$116>>2]|0;
   $118 = ((($9)) + 16|0);
   $119 = HEAP32[$118>>2]|0;
   $120 = $119 & $102;
   $121 = ((($9)) + 33|0);
   $122 = HEAP8[$121>>0]|0;
   $123 = $122&255;
   $124 = $120 >>> $123;
   $125 = (($117) + ($124)|0);
   $126 = HEAP8[$125>>0]|0;
   $127 = $126&255;
   $128 = ((($9)) + 30|0);
   $129 = HEAP8[$128>>0]|0;
   $130 = $129&255;
   $131 = (79212 + ($130<<2)|0);
   $132 = HEAP32[$131>>2]|0;
   $133 = ((($9)) + 20|0);
   $134 = HEAP32[$133>>2]|0;
   $135 = $134 & $102;
   $136 = ((($9)) + 34|0);
   $137 = HEAP8[$136>>0]|0;
   $138 = $137&255;
   $139 = $135 >>> $138;
   $140 = (($132) + ($139)|0);
   $141 = HEAP8[$140>>0]|0;
   $142 = $141&255;
   $143 = $4&255;
   $144 = (($112) + ($143))|0;
   $145 = ($144>>>0)<(255);
   $$2 = $145 ? $144 : 255;
   $146 = $5&255;
   $147 = (($127) + ($146))|0;
   $148 = ($147>>>0)<(255);
   $$ = $148 ? $147 : 255;
   $149 = $6&255;
   $150 = (($142) + ($149))|0;
   $151 = ($150>>>0)<(255);
   $$4 = $151 ? $150 : 255;
   $152 = $$2 >>> $98;
   $153 = $152 << $108;
   $154 = $$ >>> $115;
   $155 = $154 << $123;
   $156 = $155 | $153;
   $157 = $$4 >>> $130;
   $158 = $157 << $138;
   $$sink353 = $95;$$sink357 = $156;$$sink358 = $158;
   break;
  }
  case 4:  {
   $159 = ((($0)) + 20|0);
   $160 = HEAP32[$159>>2]|0;
   $161 = ((($0)) + 16|0);
   $162 = HEAP32[$161>>2]|0;
   $163 = Math_imul($162, $2)|0;
   $164 = (($160) + ($163)|0);
   $165 = $1 << 1;
   $166 = (($164) + ($165)|0);
   $167 = ((($9)) + 28|0);
   $168 = HEAP8[$167>>0]|0;
   $169 = $168&255;
   $170 = (79212 + ($169<<2)|0);
   $171 = HEAP32[$170>>2]|0;
   $172 = HEAP16[$166>>1]|0;
   $173 = $172&65535;
   $174 = ((($9)) + 12|0);
   $175 = HEAP32[$174>>2]|0;
   $176 = $173 & $175;
   $177 = ((($9)) + 32|0);
   $178 = HEAP8[$177>>0]|0;
   $179 = $178&255;
   $180 = $176 >>> $179;
   $181 = (($171) + ($180)|0);
   $182 = HEAP8[$181>>0]|0;
   $183 = $182&255;
   $184 = ((($9)) + 29|0);
   $185 = HEAP8[$184>>0]|0;
   $186 = $185&255;
   $187 = (79212 + ($186<<2)|0);
   $188 = HEAP32[$187>>2]|0;
   $189 = ((($9)) + 16|0);
   $190 = HEAP32[$189>>2]|0;
   $191 = $190 & $173;
   $192 = ((($9)) + 33|0);
   $193 = HEAP8[$192>>0]|0;
   $194 = $193&255;
   $195 = $191 >>> $194;
   $196 = (($188) + ($195)|0);
   $197 = HEAP8[$196>>0]|0;
   $198 = $197&255;
   $199 = ((($9)) + 30|0);
   $200 = HEAP8[$199>>0]|0;
   $201 = $200&255;
   $202 = (79212 + ($201<<2)|0);
   $203 = HEAP32[$202>>2]|0;
   $204 = ((($9)) + 20|0);
   $205 = HEAP32[$204>>2]|0;
   $206 = $205 & $173;
   $207 = ((($9)) + 34|0);
   $208 = HEAP8[$207>>0]|0;
   $209 = $208&255;
   $210 = $206 >>> $209;
   $211 = (($203) + ($210)|0);
   $212 = HEAP8[$211>>0]|0;
   $213 = $212&255;
   $214 = $4&255;
   $215 = Math_imul($183, $214)|0;
   $216 = (($215>>>0) / 255)&-1;
   $217 = $5&255;
   $218 = Math_imul($198, $217)|0;
   $219 = (($218>>>0) / 255)&-1;
   $220 = $6&255;
   $221 = Math_imul($213, $220)|0;
   $222 = (($221>>>0) / 255)&-1;
   $223 = $216 >>> $169;
   $224 = $223 << $179;
   $225 = $219 >>> $186;
   $226 = $225 << $194;
   $227 = $226 | $224;
   $228 = $222 >>> $201;
   $229 = $228 << $209;
   $$sink353 = $166;$$sink357 = $227;$$sink358 = $229;
   break;
  }
  default: {
   $230 = ((($0)) + 20|0);
   $231 = HEAP32[$230>>2]|0;
   $232 = ((($0)) + 16|0);
   $233 = HEAP32[$232>>2]|0;
   $234 = Math_imul($233, $2)|0;
   $235 = (($231) + ($234)|0);
   $236 = $1 << 1;
   $237 = (($235) + ($236)|0);
   $238 = $4&255;
   $239 = $5&255;
   $240 = $6&255;
   $241 = ((($9)) + 28|0);
   $242 = HEAP8[$241>>0]|0;
   $243 = $242&255;
   $244 = $238 >>> $243;
   $245 = ((($9)) + 32|0);
   $246 = HEAP8[$245>>0]|0;
   $247 = $246&255;
   $248 = $244 << $247;
   $249 = ((($9)) + 29|0);
   $250 = HEAP8[$249>>0]|0;
   $251 = $250&255;
   $252 = $239 >>> $251;
   $253 = ((($9)) + 33|0);
   $254 = HEAP8[$253>>0]|0;
   $255 = $254&255;
   $256 = $252 << $255;
   $257 = $256 | $248;
   $258 = ((($9)) + 30|0);
   $259 = HEAP8[$258>>0]|0;
   $260 = $259&255;
   $261 = $240 >>> $260;
   $262 = ((($9)) + 34|0);
   $263 = HEAP8[$262>>0]|0;
   $264 = $263&255;
   $265 = $261 << $264;
   $$sink353 = $237;$$sink357 = $257;$$sink358 = $265;
  }
  }
  $266 = $$sink357 | $$sink358;
  $267 = ((($9)) + 24|0);
  $268 = HEAP32[$267>>2]|0;
  $269 = $266 | $268;
  $270 = $269&65535;
  HEAP16[$$sink353>>1] = $270;
  $$0 = 0;
  return ($$0|0);
  break;
 }
 case 4:  {
  switch ($3|0) {
  case 1:  {
   $271 = ((($0)) + 20|0);
   $272 = HEAP32[$271>>2]|0;
   $273 = ((($0)) + 16|0);
   $274 = HEAP32[$273>>2]|0;
   $275 = Math_imul($274, $2)|0;
   $276 = (($272) + ($275)|0);
   $277 = $1 << 2;
   $278 = (($276) + ($277)|0);
   $279 = ((($9)) + 28|0);
   $280 = HEAP8[$279>>0]|0;
   $281 = $280&255;
   $282 = (79212 + ($281<<2)|0);
   $283 = HEAP32[$282>>2]|0;
   $284 = HEAP32[$278>>2]|0;
   $285 = ((($9)) + 12|0);
   $286 = HEAP32[$285>>2]|0;
   $287 = $286 & $284;
   $288 = ((($9)) + 32|0);
   $289 = HEAP8[$288>>0]|0;
   $290 = $289&255;
   $291 = $287 >>> $290;
   $292 = (($283) + ($291)|0);
   $293 = HEAP8[$292>>0]|0;
   $294 = $293&255;
   $295 = ((($9)) + 29|0);
   $296 = HEAP8[$295>>0]|0;
   $297 = $296&255;
   $298 = (79212 + ($297<<2)|0);
   $299 = HEAP32[$298>>2]|0;
   $300 = ((($9)) + 16|0);
   $301 = HEAP32[$300>>2]|0;
   $302 = $301 & $284;
   $303 = ((($9)) + 33|0);
   $304 = HEAP8[$303>>0]|0;
   $305 = $304&255;
   $306 = $302 >>> $305;
   $307 = (($299) + ($306)|0);
   $308 = HEAP8[$307>>0]|0;
   $309 = $308&255;
   $310 = ((($9)) + 30|0);
   $311 = HEAP8[$310>>0]|0;
   $312 = $311&255;
   $313 = (79212 + ($312<<2)|0);
   $314 = HEAP32[$313>>2]|0;
   $315 = ((($9)) + 20|0);
   $316 = HEAP32[$315>>2]|0;
   $317 = $316 & $284;
   $318 = ((($9)) + 34|0);
   $319 = HEAP8[$318>>0]|0;
   $320 = $319&255;
   $321 = $317 >>> $320;
   $322 = (($314) + ($321)|0);
   $323 = HEAP8[$322>>0]|0;
   $324 = $323&255;
   $325 = Math_imul($294, $11)|0;
   $326 = (($325>>>0) / 255)&-1;
   $327 = $4&255;
   $328 = (($326) + ($327))|0;
   $329 = Math_imul($309, $11)|0;
   $330 = (($329>>>0) / 255)&-1;
   $331 = $5&255;
   $332 = (($330) + ($331))|0;
   $333 = Math_imul($324, $11)|0;
   $334 = (($333>>>0) / 255)&-1;
   $335 = $6&255;
   $336 = (($334) + ($335))|0;
   $337 = $328 >>> $281;
   $338 = $337 << $290;
   $339 = $332 >>> $297;
   $340 = $339 << $305;
   $341 = $340 | $338;
   $342 = $336 >>> $312;
   $343 = $342 << $320;
   $$sink = $341;$$sink359 = $278;$$sink362 = $343;
   break;
  }
  case 2:  {
   $344 = ((($0)) + 20|0);
   $345 = HEAP32[$344>>2]|0;
   $346 = ((($0)) + 16|0);
   $347 = HEAP32[$346>>2]|0;
   $348 = Math_imul($347, $2)|0;
   $349 = (($345) + ($348)|0);
   $350 = $1 << 2;
   $351 = (($349) + ($350)|0);
   $352 = ((($9)) + 28|0);
   $353 = HEAP8[$352>>0]|0;
   $354 = $353&255;
   $355 = (79212 + ($354<<2)|0);
   $356 = HEAP32[$355>>2]|0;
   $357 = HEAP32[$351>>2]|0;
   $358 = ((($9)) + 12|0);
   $359 = HEAP32[$358>>2]|0;
   $360 = $359 & $357;
   $361 = ((($9)) + 32|0);
   $362 = HEAP8[$361>>0]|0;
   $363 = $362&255;
   $364 = $360 >>> $363;
   $365 = (($356) + ($364)|0);
   $366 = HEAP8[$365>>0]|0;
   $367 = $366&255;
   $368 = ((($9)) + 29|0);
   $369 = HEAP8[$368>>0]|0;
   $370 = $369&255;
   $371 = (79212 + ($370<<2)|0);
   $372 = HEAP32[$371>>2]|0;
   $373 = ((($9)) + 16|0);
   $374 = HEAP32[$373>>2]|0;
   $375 = $374 & $357;
   $376 = ((($9)) + 33|0);
   $377 = HEAP8[$376>>0]|0;
   $378 = $377&255;
   $379 = $375 >>> $378;
   $380 = (($372) + ($379)|0);
   $381 = HEAP8[$380>>0]|0;
   $382 = $381&255;
   $383 = ((($9)) + 30|0);
   $384 = HEAP8[$383>>0]|0;
   $385 = $384&255;
   $386 = (79212 + ($385<<2)|0);
   $387 = HEAP32[$386>>2]|0;
   $388 = ((($9)) + 20|0);
   $389 = HEAP32[$388>>2]|0;
   $390 = $389 & $357;
   $391 = ((($9)) + 34|0);
   $392 = HEAP8[$391>>0]|0;
   $393 = $392&255;
   $394 = $390 >>> $393;
   $395 = (($387) + ($394)|0);
   $396 = HEAP8[$395>>0]|0;
   $397 = $396&255;
   $398 = $4&255;
   $399 = (($367) + ($398))|0;
   $400 = ($399>>>0)<(255);
   $$3 = $400 ? $399 : 255;
   $401 = $5&255;
   $402 = (($382) + ($401))|0;
   $403 = ($402>>>0)<(255);
   $$1 = $403 ? $402 : 255;
   $404 = $6&255;
   $405 = (($397) + ($404))|0;
   $406 = ($405>>>0)<(255);
   $$5 = $406 ? $405 : 255;
   $407 = $$3 >>> $354;
   $408 = $407 << $363;
   $409 = $$1 >>> $370;
   $410 = $409 << $378;
   $411 = $410 | $408;
   $412 = $$5 >>> $385;
   $413 = $412 << $393;
   $$sink = $411;$$sink359 = $351;$$sink362 = $413;
   break;
  }
  case 4:  {
   $414 = ((($0)) + 20|0);
   $415 = HEAP32[$414>>2]|0;
   $416 = ((($0)) + 16|0);
   $417 = HEAP32[$416>>2]|0;
   $418 = Math_imul($417, $2)|0;
   $419 = (($415) + ($418)|0);
   $420 = $1 << 2;
   $421 = (($419) + ($420)|0);
   $422 = ((($9)) + 28|0);
   $423 = HEAP8[$422>>0]|0;
   $424 = $423&255;
   $425 = (79212 + ($424<<2)|0);
   $426 = HEAP32[$425>>2]|0;
   $427 = HEAP32[$421>>2]|0;
   $428 = ((($9)) + 12|0);
   $429 = HEAP32[$428>>2]|0;
   $430 = $429 & $427;
   $431 = ((($9)) + 32|0);
   $432 = HEAP8[$431>>0]|0;
   $433 = $432&255;
   $434 = $430 >>> $433;
   $435 = (($426) + ($434)|0);
   $436 = HEAP8[$435>>0]|0;
   $437 = $436&255;
   $438 = ((($9)) + 29|0);
   $439 = HEAP8[$438>>0]|0;
   $440 = $439&255;
   $441 = (79212 + ($440<<2)|0);
   $442 = HEAP32[$441>>2]|0;
   $443 = ((($9)) + 16|0);
   $444 = HEAP32[$443>>2]|0;
   $445 = $444 & $427;
   $446 = ((($9)) + 33|0);
   $447 = HEAP8[$446>>0]|0;
   $448 = $447&255;
   $449 = $445 >>> $448;
   $450 = (($442) + ($449)|0);
   $451 = HEAP8[$450>>0]|0;
   $452 = $451&255;
   $453 = ((($9)) + 30|0);
   $454 = HEAP8[$453>>0]|0;
   $455 = $454&255;
   $456 = (79212 + ($455<<2)|0);
   $457 = HEAP32[$456>>2]|0;
   $458 = ((($9)) + 20|0);
   $459 = HEAP32[$458>>2]|0;
   $460 = $459 & $427;
   $461 = ((($9)) + 34|0);
   $462 = HEAP8[$461>>0]|0;
   $463 = $462&255;
   $464 = $460 >>> $463;
   $465 = (($457) + ($464)|0);
   $466 = HEAP8[$465>>0]|0;
   $467 = $466&255;
   $468 = $4&255;
   $469 = Math_imul($437, $468)|0;
   $470 = (($469>>>0) / 255)&-1;
   $471 = $5&255;
   $472 = Math_imul($452, $471)|0;
   $473 = (($472>>>0) / 255)&-1;
   $474 = $6&255;
   $475 = Math_imul($467, $474)|0;
   $476 = (($475>>>0) / 255)&-1;
   $477 = $470 >>> $424;
   $478 = $477 << $433;
   $479 = $473 >>> $440;
   $480 = $479 << $448;
   $481 = $480 | $478;
   $482 = $476 >>> $455;
   $483 = $482 << $463;
   $$sink = $481;$$sink359 = $421;$$sink362 = $483;
   break;
  }
  default: {
   $484 = ((($0)) + 20|0);
   $485 = HEAP32[$484>>2]|0;
   $486 = ((($0)) + 16|0);
   $487 = HEAP32[$486>>2]|0;
   $488 = Math_imul($487, $2)|0;
   $489 = (($485) + ($488)|0);
   $490 = $1 << 2;
   $491 = (($489) + ($490)|0);
   $492 = $4&255;
   $493 = $5&255;
   $494 = $6&255;
   $495 = ((($9)) + 28|0);
   $496 = HEAP8[$495>>0]|0;
   $497 = $496&255;
   $498 = $492 >>> $497;
   $499 = ((($9)) + 32|0);
   $500 = HEAP8[$499>>0]|0;
   $501 = $500&255;
   $502 = $498 << $501;
   $503 = ((($9)) + 29|0);
   $504 = HEAP8[$503>>0]|0;
   $505 = $504&255;
   $506 = $493 >>> $505;
   $507 = ((($9)) + 33|0);
   $508 = HEAP8[$507>>0]|0;
   $509 = $508&255;
   $510 = $506 << $509;
   $511 = $510 | $502;
   $512 = ((($9)) + 30|0);
   $513 = HEAP8[$512>>0]|0;
   $514 = $513&255;
   $515 = $494 >>> $514;
   $516 = ((($9)) + 34|0);
   $517 = HEAP8[$516>>0]|0;
   $518 = $517&255;
   $519 = $515 << $518;
   $$sink = $511;$$sink359 = $491;$$sink362 = $519;
  }
  }
  $520 = $$sink | $$sink362;
  $521 = ((($9)) + 24|0);
  $522 = HEAP32[$521>>2]|0;
  $523 = $520 | $522;
  HEAP32[$$sink359>>2] = $523;
  $$0 = 0;
  return ($$0|0);
  break;
 }
 default: {
  $524 = (_SDL_Error(4)|0);
  $$0 = $524;
  return ($$0|0);
 }
 }
 return (0)|0;
}
function _SDL_BlendPoint_RGBA($0,$1,$2,$3,$4,$5,$6,$7) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 var $$ = 0, $$0 = 0, $$1 = 0, $$2 = 0, $$sink199 = 0, $$sink200 = 0, $$sink201 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0;
 var $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0;
 var $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0;
 var $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0;
 var $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0;
 var $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0;
 var $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0;
 var $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0;
 var $33 = 0, $330 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $8 = ((($0)) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $7&255;
 $11 = $10 ^ 255;
 $12 = ((($9)) + 9|0);
 $13 = HEAP8[$12>>0]|0;
 $cond = ($13<<24>>24)==(4);
 if (!($cond)) {
  $330 = (_SDL_Error(4)|0);
  $$0 = $330;
  return ($$0|0);
 }
 switch ($3|0) {
 case 1:  {
  $14 = ((($0)) + 20|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = ((($0)) + 16|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = Math_imul($17, $2)|0;
  $19 = (($15) + ($18)|0);
  $20 = $1 << 2;
  $21 = (($19) + ($20)|0);
  $22 = ((($9)) + 28|0);
  $23 = HEAP8[$22>>0]|0;
  $24 = $23&255;
  $25 = (79212 + ($24<<2)|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = HEAP32[$21>>2]|0;
  $28 = ((($9)) + 12|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = $29 & $27;
  $31 = ((($9)) + 32|0);
  $32 = HEAP8[$31>>0]|0;
  $33 = $32&255;
  $34 = $30 >>> $33;
  $35 = (($26) + ($34)|0);
  $36 = HEAP8[$35>>0]|0;
  $37 = $36&255;
  $38 = ((($9)) + 29|0);
  $39 = HEAP8[$38>>0]|0;
  $40 = $39&255;
  $41 = (79212 + ($40<<2)|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = ((($9)) + 16|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = $44 & $27;
  $46 = ((($9)) + 33|0);
  $47 = HEAP8[$46>>0]|0;
  $48 = $47&255;
  $49 = $45 >>> $48;
  $50 = (($42) + ($49)|0);
  $51 = HEAP8[$50>>0]|0;
  $52 = $51&255;
  $53 = ((($9)) + 30|0);
  $54 = HEAP8[$53>>0]|0;
  $55 = $54&255;
  $56 = (79212 + ($55<<2)|0);
  $57 = HEAP32[$56>>2]|0;
  $58 = ((($9)) + 20|0);
  $59 = HEAP32[$58>>2]|0;
  $60 = $59 & $27;
  $61 = ((($9)) + 34|0);
  $62 = HEAP8[$61>>0]|0;
  $63 = $62&255;
  $64 = $60 >>> $63;
  $65 = (($57) + ($64)|0);
  $66 = HEAP8[$65>>0]|0;
  $67 = $66&255;
  $68 = ((($9)) + 31|0);
  $69 = HEAP8[$68>>0]|0;
  $70 = $69&255;
  $71 = (79212 + ($70<<2)|0);
  $72 = HEAP32[$71>>2]|0;
  $73 = ((($9)) + 24|0);
  $74 = HEAP32[$73>>2]|0;
  $75 = $74 & $27;
  $76 = ((($9)) + 35|0);
  $77 = HEAP8[$76>>0]|0;
  $78 = $77&255;
  $79 = $75 >>> $78;
  $80 = (($72) + ($79)|0);
  $81 = HEAP8[$80>>0]|0;
  $82 = $81&255;
  $83 = Math_imul($37, $11)|0;
  $84 = (($83>>>0) / 255)&-1;
  $85 = $4&255;
  $86 = (($84) + ($85))|0;
  $87 = Math_imul($52, $11)|0;
  $88 = (($87>>>0) / 255)&-1;
  $89 = $5&255;
  $90 = (($88) + ($89))|0;
  $91 = Math_imul($67, $11)|0;
  $92 = (($91>>>0) / 255)&-1;
  $93 = $6&255;
  $94 = (($92) + ($93))|0;
  $95 = Math_imul($82, $11)|0;
  $96 = (($95>>>0) / 255)&-1;
  $97 = (($96) + ($10))|0;
  $98 = $86 >>> $24;
  $99 = $98 << $33;
  $100 = $90 >>> $40;
  $101 = $100 << $48;
  $102 = $101 | $99;
  $103 = $94 >>> $55;
  $104 = $103 << $63;
  $105 = $102 | $104;
  $106 = $97 >>> $70;
  $107 = $106 << $78;
  $$sink199 = $21;$$sink200 = $105;$$sink201 = $107;
  break;
 }
 case 2:  {
  $108 = ((($0)) + 20|0);
  $109 = HEAP32[$108>>2]|0;
  $110 = ((($0)) + 16|0);
  $111 = HEAP32[$110>>2]|0;
  $112 = Math_imul($111, $2)|0;
  $113 = (($109) + ($112)|0);
  $114 = $1 << 2;
  $115 = (($113) + ($114)|0);
  $116 = ((($9)) + 28|0);
  $117 = HEAP8[$116>>0]|0;
  $118 = $117&255;
  $119 = (79212 + ($118<<2)|0);
  $120 = HEAP32[$119>>2]|0;
  $121 = HEAP32[$115>>2]|0;
  $122 = ((($9)) + 12|0);
  $123 = HEAP32[$122>>2]|0;
  $124 = $123 & $121;
  $125 = ((($9)) + 32|0);
  $126 = HEAP8[$125>>0]|0;
  $127 = $126&255;
  $128 = $124 >>> $127;
  $129 = (($120) + ($128)|0);
  $130 = HEAP8[$129>>0]|0;
  $131 = $130&255;
  $132 = ((($9)) + 29|0);
  $133 = HEAP8[$132>>0]|0;
  $134 = $133&255;
  $135 = (79212 + ($134<<2)|0);
  $136 = HEAP32[$135>>2]|0;
  $137 = ((($9)) + 16|0);
  $138 = HEAP32[$137>>2]|0;
  $139 = $138 & $121;
  $140 = ((($9)) + 33|0);
  $141 = HEAP8[$140>>0]|0;
  $142 = $141&255;
  $143 = $139 >>> $142;
  $144 = (($136) + ($143)|0);
  $145 = HEAP8[$144>>0]|0;
  $146 = $145&255;
  $147 = ((($9)) + 30|0);
  $148 = HEAP8[$147>>0]|0;
  $149 = $148&255;
  $150 = (79212 + ($149<<2)|0);
  $151 = HEAP32[$150>>2]|0;
  $152 = ((($9)) + 20|0);
  $153 = HEAP32[$152>>2]|0;
  $154 = $153 & $121;
  $155 = ((($9)) + 34|0);
  $156 = HEAP8[$155>>0]|0;
  $157 = $156&255;
  $158 = $154 >>> $157;
  $159 = (($151) + ($158)|0);
  $160 = HEAP8[$159>>0]|0;
  $161 = $160&255;
  $162 = ((($9)) + 31|0);
  $163 = HEAP8[$162>>0]|0;
  $164 = $163&255;
  $165 = (79212 + ($164<<2)|0);
  $166 = HEAP32[$165>>2]|0;
  $167 = ((($9)) + 24|0);
  $168 = HEAP32[$167>>2]|0;
  $169 = $168 & $121;
  $170 = ((($9)) + 35|0);
  $171 = HEAP8[$170>>0]|0;
  $172 = $171&255;
  $173 = $169 >>> $172;
  $174 = (($166) + ($173)|0);
  $175 = HEAP8[$174>>0]|0;
  $176 = $175&255;
  $177 = $4&255;
  $178 = (($131) + ($177))|0;
  $179 = ($178>>>0)<(255);
  $$1 = $179 ? $178 : 255;
  $180 = $5&255;
  $181 = (($146) + ($180))|0;
  $182 = ($181>>>0)<(255);
  $$ = $182 ? $181 : 255;
  $183 = $6&255;
  $184 = (($161) + ($183))|0;
  $185 = ($184>>>0)<(255);
  $$2 = $185 ? $184 : 255;
  $186 = $$1 >>> $118;
  $187 = $186 << $127;
  $188 = $$ >>> $134;
  $189 = $188 << $142;
  $190 = $189 | $187;
  $191 = $$2 >>> $149;
  $192 = $191 << $157;
  $193 = $190 | $192;
  $194 = $176 >>> $164;
  $195 = $194 << $172;
  $$sink199 = $115;$$sink200 = $193;$$sink201 = $195;
  break;
 }
 case 4:  {
  $196 = ((($0)) + 20|0);
  $197 = HEAP32[$196>>2]|0;
  $198 = ((($0)) + 16|0);
  $199 = HEAP32[$198>>2]|0;
  $200 = Math_imul($199, $2)|0;
  $201 = (($197) + ($200)|0);
  $202 = $1 << 2;
  $203 = (($201) + ($202)|0);
  $204 = ((($9)) + 28|0);
  $205 = HEAP8[$204>>0]|0;
  $206 = $205&255;
  $207 = (79212 + ($206<<2)|0);
  $208 = HEAP32[$207>>2]|0;
  $209 = HEAP32[$203>>2]|0;
  $210 = ((($9)) + 12|0);
  $211 = HEAP32[$210>>2]|0;
  $212 = $211 & $209;
  $213 = ((($9)) + 32|0);
  $214 = HEAP8[$213>>0]|0;
  $215 = $214&255;
  $216 = $212 >>> $215;
  $217 = (($208) + ($216)|0);
  $218 = HEAP8[$217>>0]|0;
  $219 = $218&255;
  $220 = ((($9)) + 29|0);
  $221 = HEAP8[$220>>0]|0;
  $222 = $221&255;
  $223 = (79212 + ($222<<2)|0);
  $224 = HEAP32[$223>>2]|0;
  $225 = ((($9)) + 16|0);
  $226 = HEAP32[$225>>2]|0;
  $227 = $226 & $209;
  $228 = ((($9)) + 33|0);
  $229 = HEAP8[$228>>0]|0;
  $230 = $229&255;
  $231 = $227 >>> $230;
  $232 = (($224) + ($231)|0);
  $233 = HEAP8[$232>>0]|0;
  $234 = $233&255;
  $235 = ((($9)) + 30|0);
  $236 = HEAP8[$235>>0]|0;
  $237 = $236&255;
  $238 = (79212 + ($237<<2)|0);
  $239 = HEAP32[$238>>2]|0;
  $240 = ((($9)) + 20|0);
  $241 = HEAP32[$240>>2]|0;
  $242 = $241 & $209;
  $243 = ((($9)) + 34|0);
  $244 = HEAP8[$243>>0]|0;
  $245 = $244&255;
  $246 = $242 >>> $245;
  $247 = (($239) + ($246)|0);
  $248 = HEAP8[$247>>0]|0;
  $249 = $248&255;
  $250 = ((($9)) + 31|0);
  $251 = HEAP8[$250>>0]|0;
  $252 = $251&255;
  $253 = (79212 + ($252<<2)|0);
  $254 = HEAP32[$253>>2]|0;
  $255 = ((($9)) + 24|0);
  $256 = HEAP32[$255>>2]|0;
  $257 = $256 & $209;
  $258 = ((($9)) + 35|0);
  $259 = HEAP8[$258>>0]|0;
  $260 = $259&255;
  $261 = $257 >>> $260;
  $262 = (($254) + ($261)|0);
  $263 = HEAP8[$262>>0]|0;
  $264 = $263&255;
  $265 = $4&255;
  $266 = Math_imul($219, $265)|0;
  $267 = (($266>>>0) / 255)&-1;
  $268 = $5&255;
  $269 = Math_imul($234, $268)|0;
  $270 = (($269>>>0) / 255)&-1;
  $271 = $6&255;
  $272 = Math_imul($249, $271)|0;
  $273 = (($272>>>0) / 255)&-1;
  $274 = $267 >>> $206;
  $275 = $274 << $215;
  $276 = $270 >>> $222;
  $277 = $276 << $230;
  $278 = $277 | $275;
  $279 = $273 >>> $237;
  $280 = $279 << $245;
  $281 = $278 | $280;
  $282 = $264 >>> $252;
  $283 = $282 << $260;
  $$sink199 = $203;$$sink200 = $281;$$sink201 = $283;
  break;
 }
 default: {
  $284 = ((($0)) + 20|0);
  $285 = HEAP32[$284>>2]|0;
  $286 = ((($0)) + 16|0);
  $287 = HEAP32[$286>>2]|0;
  $288 = Math_imul($287, $2)|0;
  $289 = (($285) + ($288)|0);
  $290 = $1 << 2;
  $291 = (($289) + ($290)|0);
  $292 = $4&255;
  $293 = $5&255;
  $294 = $6&255;
  $295 = ((($9)) + 28|0);
  $296 = HEAP8[$295>>0]|0;
  $297 = $296&255;
  $298 = $292 >>> $297;
  $299 = ((($9)) + 32|0);
  $300 = HEAP8[$299>>0]|0;
  $301 = $300&255;
  $302 = $298 << $301;
  $303 = ((($9)) + 29|0);
  $304 = HEAP8[$303>>0]|0;
  $305 = $304&255;
  $306 = $293 >>> $305;
  $307 = ((($9)) + 33|0);
  $308 = HEAP8[$307>>0]|0;
  $309 = $308&255;
  $310 = $306 << $309;
  $311 = $310 | $302;
  $312 = ((($9)) + 30|0);
  $313 = HEAP8[$312>>0]|0;
  $314 = $313&255;
  $315 = $294 >>> $314;
  $316 = ((($9)) + 34|0);
  $317 = HEAP8[$316>>0]|0;
  $318 = $317&255;
  $319 = $315 << $318;
  $320 = $311 | $319;
  $321 = ((($9)) + 31|0);
  $322 = HEAP8[$321>>0]|0;
  $323 = $322&255;
  $324 = $10 >>> $323;
  $325 = ((($9)) + 35|0);
  $326 = HEAP8[$325>>0]|0;
  $327 = $326&255;
  $328 = $324 << $327;
  $$sink199 = $291;$$sink200 = $320;$$sink201 = $328;
 }
 }
 $329 = $$sink200 | $$sink201;
 HEAP32[$$sink199>>2] = $329;
 $$0 = 0;
 return ($$0|0);
}
function _SDL_DrawLine2($0,$1,$2,$3,$4,$5,$6) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 var $$ = 0, $$$0361 = 0, $$$0361$$431 = 0, $$$0383 = 0, $$$0383$$430 = 0, $$$0406 = 0, $$$0406$$429 = 0, $$0355 = 0, $$0357455 = 0, $$0361 = 0, $$0363454 = 0, $$0365 = 0, $$0365$in = 0, $$0366 = 0, $$0366$$0365 = 0, $$0367 = 0, $$0369 = 0, $$0369$in = 0, $$0369$in$$0369 = 0, $$0371445 = 0;
 var $$0374452 = 0, $$0377 = 0, $$0379465 = 0, $$0383 = 0, $$0385464 = 0, $$0387 = 0, $$0387$in = 0, $$0388 = 0, $$0388$$0387 = 0, $$0389 = 0, $$0392 = 0, $$0392$in = 0, $$0392$in$$0392 = 0, $$0394447 = 0, $$0397462 = 0, $$0400 = 0, $$0402460 = 0, $$0406 = 0, $$0408459 = 0, $$0410 = 0;
 var $$0410$in = 0, $$0411 = 0, $$0411$$0410 = 0, $$0412 = 0, $$0415 = 0, $$0415$in = 0, $$0415$in$$0415 = 0, $$0417 = 0, $$0417$ = 0, $$0422457 = 0, $$1 = 0, $$1356 = 0, $$1356$$1 = 0, $$1358 = 0, $$1364 = 0, $$1368453 = 0, $$1373$ph = 0, $$1373444 = 0, $$1376 = 0, $$1378 = 0;
 var $$1378$$1376 = 0, $$1380 = 0, $$1386 = 0, $$1390463 = 0, $$1396$ph = 0, $$1396446 = 0, $$1399 = 0, $$1401 = 0, $$1401$$1399 = 0, $$1403 = 0, $$1409 = 0, $$1413458 = 0, $$1418450 = 0, $$1424 = 0, $$2 = 0, $$2391 = 0, $$2414 = 0, $$2421 = 0, $$2425449 = 0, $$426 = 0;
 var $$428 = 0, $$429 = 0, $$430 = 0, $$431 = 0, $$neg = 0, $$neg435 = 0, $$neg435$sink = 0, $$neg436 = 0, $$neg437 = 0, $$neg437$sink = 0, $$sink = 0, $$sink427 = 0, $$sink469 = 0, $$sink472 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0;
 var $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0;
 var $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0;
 var $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $not$ = 0, $not$432 = 0, $not$433 = 0, $not$434 = 0, $switch$split2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $7 = sp + 3|0;
 $8 = sp + 2|0;
 $9 = sp + 1|0;
 $10 = sp;
 $11 = ($4|0)==($2|0);
 if ($11) {
  $12 = ((($0)) + 16|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ((($0)) + 4|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = ((($15)) + 9|0);
  $17 = HEAP8[$16>>0]|0;
  $18 = $17&255;
  $19 = (($13|0) / ($18|0))&-1;
  $20 = ($1|0)>($3|0);
  $21 = ((($0)) + 20|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = Math_imul($19, $4)|0;
  $24 = (($22) + ($23<<1)|0);
  $25 = ($6|0)!=(0);
  if ($20) {
   $27 = (($24) + ($3<<1)|0);
   $28 = ((($27)) + 2|0);
   $$ = $25 ? $27 : $28;
   $$neg437 = (0 - ($3))|0;
   $$1373$ph = $$;$$neg437$sink = $$neg437;$$sink469 = $1;
  } else {
   $26 = (($24) + ($1<<1)|0);
   $$neg436 = (0 - ($1))|0;
   $$1373$ph = $26;$$neg437$sink = $3;$$sink469 = $$neg436;
  }
  $29 = (($$neg437$sink) + ($$sink469))|0;
  $30 = $25&1;
  $31 = (($29) + ($30))|0;
  $32 = ($31|0)==(0);
  if ($32) {
   STACKTOP = sp;return;
  }
  $33 = $5&65535;
  $$0371445 = $31;$$1373444 = $$1373$ph;
  while(1) {
   $34 = (($$0371445) + -1)|0;
   HEAP16[$$1373444>>1] = $33;
   $35 = ((($$1373444)) + 2|0);
   $36 = ($34|0)==(0);
   if ($36) {
    break;
   } else {
    $$0371445 = $34;$$1373444 = $35;
   }
  }
  STACKTOP = sp;return;
 }
 $37 = ($1|0)==($3|0);
 if ($37) {
  $38 = ((($0)) + 16|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = ((($0)) + 4|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = ((($41)) + 9|0);
  $43 = HEAP8[$42>>0]|0;
  $44 = $43&255;
  $45 = (($39|0) / ($44|0))&-1;
  $46 = ($4|0)<($2|0);
  $47 = ((($0)) + 20|0);
  $48 = HEAP32[$47>>2]|0;
  $49 = ($6|0)!=(0);
  if ($46) {
   $53 = Math_imul($45, $4)|0;
   $54 = (($48) + ($53<<1)|0);
   $55 = (($54) + ($1<<1)|0);
   $56 = (($55) + ($45<<1)|0);
   $$426 = $49 ? $55 : $56;
   $$neg435 = (0 - ($4))|0;
   $$1396$ph = $$426;$$neg435$sink = $$neg435;$$sink472 = $2;
  } else {
   $50 = Math_imul($45, $2)|0;
   $51 = (($48) + ($50<<1)|0);
   $52 = (($51) + ($1<<1)|0);
   $$neg = (0 - ($2))|0;
   $$1396$ph = $52;$$neg435$sink = $4;$$sink472 = $$neg;
  }
  $57 = (($$neg435$sink) + ($$sink472))|0;
  $58 = $49&1;
  $59 = (($57) + ($58))|0;
  $60 = ($59|0)==(0);
  if ($60) {
   STACKTOP = sp;return;
  }
  $61 = $5&65535;
  $$0394447 = $59;$$1396446 = $$1396$ph;
  while(1) {
   $62 = (($$0394447) + -1)|0;
   HEAP16[$$1396446>>1] = $61;
   $63 = (($$1396446) + ($45<<1)|0);
   $64 = ($62|0)==(0);
   if ($64) {
    break;
   } else {
    $$0394447 = $62;$$1396446 = $63;
   }
  }
  STACKTOP = sp;return;
 }
 $65 = (($1) - ($3))|0;
 $66 = ($65|0)<(0);
 $67 = (0 - ($65))|0;
 $68 = $66 ? $67 : $65;
 $69 = (($2) - ($4))|0;
 $70 = ($69|0)<(0);
 $71 = (0 - ($69))|0;
 $72 = $70 ? $71 : $69;
 $73 = ($68|0)==($72|0);
 if ($73) {
  $74 = ((($0)) + 16|0);
  $75 = HEAP32[$74>>2]|0;
  $76 = ((($0)) + 4|0);
  $77 = HEAP32[$76>>2]|0;
  $78 = ((($77)) + 9|0);
  $79 = HEAP8[$78>>0]|0;
  $80 = $79&255;
  $81 = (($75|0) / ($80|0))&-1;
  $82 = ($4|0)<($2|0);
  $83 = ((($0)) + 20|0);
  $84 = HEAP32[$83>>2]|0;
  if ($82) {
   $91 = Math_imul($81, $4)|0;
   $92 = (($84) + ($91<<1)|0);
   $93 = (($92) + ($3<<1)|0);
   $94 = ($3|0)>($1|0);
   $$sink427 = $94 ? -1 : 1;
   $95 = (($81) + ($$sink427))|0;
   $96 = ($6|0)==(0);
   $97 = (($93) + ($95<<1)|0);
   $$428 = $96 ? $97 : $93;
   $$0417 = $69;$$1424 = $$428;$$2421 = $95;
  } else {
   $85 = Math_imul($81, $2)|0;
   $86 = (($84) + ($85<<1)|0);
   $87 = (($86) + ($1<<1)|0);
   $88 = ($1|0)>($3|0);
   $$sink = $88 ? -1 : 1;
   $89 = (($81) + ($$sink))|0;
   $90 = (($4) - ($2))|0;
   $$0417 = $90;$$1424 = $87;$$2421 = $89;
  }
  $not$434 = ($6|0)!=(0);
  $98 = $not$434&1;
  $$0417$ = (($$0417) + ($98))|0;
  $99 = ($$0417$|0)==(0);
  if ($99) {
   STACKTOP = sp;return;
  }
  $100 = $5&65535;
  $$1418450 = $$0417$;$$2425449 = $$1424;
  while(1) {
   $101 = (($$1418450) + -1)|0;
   HEAP16[$$2425449>>1] = $100;
   $102 = (($$2425449) + ($$2421<<1)|0);
   $103 = ($101|0)==(0);
   if ($103) {
    break;
   } else {
    $$1418450 = $101;$$2425449 = $102;
   }
  }
  STACKTOP = sp;return;
 }
 $104 = ((($0)) + 4|0);
 $105 = HEAP32[$104>>2]|0;
 _SDL_GetRGBA($5,$105,$7,$8,$9,$10);
 $106 = ((($105)) + 12|0);
 $107 = HEAP32[$106>>2]|0;
 $108 = (($3) - ($1))|0;
 $109 = (($4) - ($2))|0;
 $110 = (0 - ($108))|0;
 $111 = ($109|0)<(0);
 $112 = ($108|0)<(0);
 $113 = (0 - ($109))|0;
 $114 = $112 ? $110 : $108;
 $115 = $111 ? $113 : $109;
 $116 = ($114|0)>=($115|0);
 $switch$split2D = ($107|0)<(63488);
 L40: do {
  if ($switch$split2D) {
   switch ($107|0) {
   case 31744:  {
    break;
   }
   default: {
    label = 35;
    break L40;
   }
   }
   if ($116) {
    $117 = $115 << 1;
    $118 = (($117) - ($114))|0;
    $119 = (($115) - ($114))|0;
    $$0400 = 0;$$0406 = 1;$$0410$in = $119;$$0411 = $117;$$0412 = $118;$$0415$in = $114;
   } else {
    $120 = $114 << 1;
    $121 = (($120) - ($115))|0;
    $122 = (($114) - ($115))|0;
    $$0400 = 1;$$0406 = 0;$$0410$in = $122;$$0411 = $120;$$0412 = $121;$$0415$in = $115;
   }
   $$0410 = $$0410$in << 1;
   $123 = ($1|0)>($3|0);
   $124 = (0 - ($$0406))|0;
   $$$0406 = $123 ? $124 : $$0406;
   $$429 = $123 ? -1 : 1;
   $125 = ($4|0)<($2|0);
   $126 = (0 - ($$0400))|0;
   $$1401 = $125 ? $126 : $$0400;
   $$1399 = $125 ? -1 : 1;
   $not$432 = ($6|0)!=(0);
   $$0415 = $not$432&1;
   $$0415$in$$0415 = (($$0415$in) + ($$0415))|0;
   $127 = ($$0415$in$$0415|0)>(0);
   if ($127) {
    $128 = $5&65535;
    $129 = ((($0)) + 20|0);
    $130 = HEAP32[$129>>2]|0;
    $131 = ((($0)) + 16|0);
    $132 = HEAP32[$131>>2]|0;
    $$0402460 = $2;$$0408459 = $1;$$0422457 = 0;$$1413458 = $$0412;
    while(1) {
     $133 = Math_imul($132, $$0402460)|0;
     $134 = (($130) + ($133)|0);
     $135 = $$0408459 << 1;
     $136 = (($134) + ($135)|0);
     HEAP16[$136>>1] = $128;
     $137 = ($$1413458|0)<(0);
     $$0411$$0410 = $137 ? $$0411 : $$0410;
     $$$0406$$429 = $137 ? $$$0406 : $$429;
     $$1401$$1399 = $137 ? $$1401 : $$1399;
     $$1403 = (($$0402460) + ($$1401$$1399))|0;
     $$1409 = (($$$0406$$429) + ($$0408459))|0;
     $$2414 = (($$0411$$0410) + ($$1413458))|0;
     $138 = (($$0422457) + 1)|0;
     $139 = ($138|0)<($$0415$in$$0415|0);
     if ($139) {
      $$0402460 = $$1403;$$0408459 = $$1409;$$0422457 = $138;$$1413458 = $$2414;
     } else {
      break;
     }
    }
   }
  } else {
   switch ($107|0) {
   case 63488:  {
    break;
   }
   default: {
    label = 35;
    break L40;
   }
   }
   if ($116) {
    $140 = $115 << 1;
    $141 = (($140) - ($114))|0;
    $142 = (($115) - ($114))|0;
    $$0377 = 0;$$0383 = 1;$$0387$in = $142;$$0388 = $140;$$0389 = $141;$$0392$in = $114;
   } else {
    $143 = $114 << 1;
    $144 = (($143) - ($115))|0;
    $145 = (($114) - ($115))|0;
    $$0377 = 1;$$0383 = 0;$$0387$in = $145;$$0388 = $143;$$0389 = $144;$$0392$in = $115;
   }
   $$0387 = $$0387$in << 1;
   $146 = ($1|0)>($3|0);
   $147 = (0 - ($$0383))|0;
   $$$0383 = $146 ? $147 : $$0383;
   $$430 = $146 ? -1 : 1;
   $148 = ($4|0)<($2|0);
   $149 = (0 - ($$0377))|0;
   $$1378 = $148 ? $149 : $$0377;
   $$1376 = $148 ? -1 : 1;
   $not$ = ($6|0)!=(0);
   $$0392 = $not$&1;
   $$0392$in$$0392 = (($$0392$in) + ($$0392))|0;
   $150 = ($$0392$in$$0392|0)>(0);
   if ($150) {
    $151 = $5&65535;
    $152 = ((($0)) + 20|0);
    $153 = HEAP32[$152>>2]|0;
    $154 = ((($0)) + 16|0);
    $155 = HEAP32[$154>>2]|0;
    $$0379465 = $2;$$0385464 = $1;$$0397462 = 0;$$1390463 = $$0389;
    while(1) {
     $156 = Math_imul($155, $$0379465)|0;
     $157 = (($153) + ($156)|0);
     $158 = $$0385464 << 1;
     $159 = (($157) + ($158)|0);
     HEAP16[$159>>1] = $151;
     $160 = ($$1390463|0)<(0);
     $$0388$$0387 = $160 ? $$0388 : $$0387;
     $$$0383$$430 = $160 ? $$$0383 : $$430;
     $$1378$$1376 = $160 ? $$1378 : $$1376;
     $$1380 = (($$0379465) + ($$1378$$1376))|0;
     $$1386 = (($$$0383$$430) + ($$0385464))|0;
     $$2391 = (($$0388$$0387) + ($$1390463))|0;
     $161 = (($$0397462) + 1)|0;
     $162 = ($161|0)<($$0392$in$$0392|0);
     if ($162) {
      $$0379465 = $$1380;$$0385464 = $$1386;$$0397462 = $161;$$1390463 = $$2391;
     } else {
      break;
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 35) {
  if ($116) {
   $163 = $115 << 1;
   $164 = (($163) - ($114))|0;
   $165 = (($115) - ($114))|0;
   $$0355 = 0;$$0361 = 1;$$0365$in = $165;$$0366 = $163;$$0367 = $164;$$0369$in = $114;
  } else {
   $166 = $114 << 1;
   $167 = (($166) - ($115))|0;
   $168 = (($114) - ($115))|0;
   $$0355 = 1;$$0361 = 0;$$0365$in = $168;$$0366 = $166;$$0367 = $167;$$0369$in = $115;
  }
  $$0365 = $$0365$in << 1;
  $169 = ($1|0)>($3|0);
  $170 = (0 - ($$0361))|0;
  $$$0361 = $169 ? $170 : $$0361;
  $$431 = $169 ? -1 : 1;
  $171 = ($4|0)<($2|0);
  $172 = (0 - ($$0355))|0;
  $$1356 = $171 ? $172 : $$0355;
  $$1 = $171 ? -1 : 1;
  $not$433 = ($6|0)!=(0);
  $$0369 = $not$433&1;
  $$0369$in$$0369 = (($$0369$in) + ($$0369))|0;
  $173 = ($$0369$in$$0369|0)>(0);
  if ($173) {
   $174 = $5&65535;
   $175 = ((($0)) + 20|0);
   $176 = HEAP32[$175>>2]|0;
   $177 = ((($0)) + 16|0);
   $178 = HEAP32[$177>>2]|0;
   $$0357455 = $2;$$0363454 = $1;$$0374452 = 0;$$1368453 = $$0367;
   while(1) {
    $179 = Math_imul($178, $$0357455)|0;
    $180 = (($176) + ($179)|0);
    $181 = $$0363454 << 1;
    $182 = (($180) + ($181)|0);
    HEAP16[$182>>1] = $174;
    $183 = ($$1368453|0)<(0);
    $$0366$$0365 = $183 ? $$0366 : $$0365;
    $$$0361$$431 = $183 ? $$$0361 : $$431;
    $$1356$$1 = $183 ? $$1356 : $$1;
    $$1358 = (($$0357455) + ($$1356$$1))|0;
    $$1364 = (($$$0361$$431) + ($$0363454))|0;
    $$2 = (($$0366$$0365) + ($$1368453))|0;
    $184 = (($$0374452) + 1)|0;
    $185 = ($184|0)<($$0369$in$$0369|0);
    if ($185) {
     $$0357455 = $$1358;$$0363454 = $$1364;$$0374452 = $184;$$1368453 = $$2;
    } else {
     break;
    }
   }
  }
 }
 STACKTOP = sp;return;
}
function _SDL_DrawLine1($0,$1,$2,$3,$4,$5,$6) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 var $$ = 0, $$$0191 = 0, $$$0191$$221 = 0, $$0185 = 0, $$0187234 = 0, $$0191 = 0, $$0193233 = 0, $$0195 = 0, $$0195$in = 0, $$0196 = 0, $$0196$$0195 = 0, $$0197 = 0, $$0199 = 0, $$0199$in = 0, $$0199$in$$0199 = 0, $$0204231 = 0, $$0211 = 0, $$0211$ = 0, $$0215226 = 0, $$1 = 0;
 var $$1186 = 0, $$1186$$1 = 0, $$1188 = 0, $$1194 = 0, $$1198232 = 0, $$1203 = 0, $$1206 = 0, $$1212228 = 0, $$1214$ph = 0, $$1214227 = 0, $$2 = 0, $$217 = 0, $$220 = 0, $$2207229 = 0, $$221 = 0, $$2210 = 0, $$neg = 0, $$neg223 = 0, $$neg223$sink = 0, $$sink = 0;
 var $$sink218 = 0, $$sink219 = 0, $$sink238 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $not$ = 0, $not$222 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $7 = ($4|0)==($2|0);
 if ($7) {
  $8 = ((($0)) + 16|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ((($0)) + 4|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ((($11)) + 9|0);
  $13 = HEAP8[$12>>0]|0;
  $14 = $13&255;
  $15 = (($9|0) / ($14|0))&-1;
  $16 = ($1|0)>($3|0);
  $17 = ((($0)) + 20|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = Math_imul($15, $4)|0;
  $20 = (($18) + ($19)|0);
  $21 = ($6|0)!=(0);
  $22 = (($20) + ($3)|0);
  $23 = ((($22)) + 1|0);
  $$ = $21 ? $22 : $23;
  $24 = (($1) - ($3))|0;
  $25 = (($20) + ($1)|0);
  $26 = (($3) - ($1))|0;
  $$sink = $16 ? $24 : $26;
  $$1203 = $16 ? $$ : $25;
  $27 = $21&1;
  $28 = (($27) + ($$sink))|0;
  (_SDL_memset($$1203,$5,$28)|0);
  return;
 }
 $29 = ($1|0)==($3|0);
 if ($29) {
  $30 = ((($0)) + 16|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = ((($0)) + 4|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = ((($33)) + 9|0);
  $35 = HEAP8[$34>>0]|0;
  $36 = $35&255;
  $37 = (($31|0) / ($36|0))&-1;
  $38 = ($4|0)<($2|0);
  $39 = ((($0)) + 20|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = ($6|0)!=(0);
  if ($38) {
   $45 = Math_imul($37, $4)|0;
   $46 = (($40) + ($45)|0);
   $47 = (($46) + ($1)|0);
   $48 = (($47) + ($37)|0);
   $$217 = $41 ? $47 : $48;
   $$neg223 = (0 - ($4))|0;
   $$1214$ph = $$217;$$neg223$sink = $$neg223;$$sink238 = $2;
  } else {
   $42 = Math_imul($37, $2)|0;
   $43 = (($40) + ($42)|0);
   $44 = (($43) + ($1)|0);
   $$neg = (0 - ($2))|0;
   $$1214$ph = $44;$$neg223$sink = $4;$$sink238 = $$neg;
  }
  $49 = (($$neg223$sink) + ($$sink238))|0;
  $50 = $41&1;
  $51 = (($49) + ($50))|0;
  $52 = ($51|0)==(0);
  if ($52) {
   return;
  }
  $53 = $5&255;
  $$0215226 = $51;$$1214227 = $$1214$ph;
  while(1) {
   $54 = (($$0215226) + -1)|0;
   HEAP8[$$1214227>>0] = $53;
   $55 = (($$1214227) + ($37)|0);
   $56 = ($54|0)==(0);
   if ($56) {
    break;
   } else {
    $$0215226 = $54;$$1214227 = $55;
   }
  }
  return;
 }
 $57 = (($1) - ($3))|0;
 $58 = ($57|0)<(0);
 $59 = (0 - ($57))|0;
 $60 = $58 ? $59 : $57;
 $61 = (($2) - ($4))|0;
 $62 = ($61|0)<(0);
 $63 = (0 - ($61))|0;
 $64 = $62 ? $63 : $61;
 $65 = ($60|0)==($64|0);
 if ($65) {
  $66 = ((($0)) + 16|0);
  $67 = HEAP32[$66>>2]|0;
  $68 = ((($0)) + 4|0);
  $69 = HEAP32[$68>>2]|0;
  $70 = ((($69)) + 9|0);
  $71 = HEAP8[$70>>0]|0;
  $72 = $71&255;
  $73 = (($67|0) / ($72|0))&-1;
  $74 = ($4|0)<($2|0);
  $75 = ((($0)) + 20|0);
  $76 = HEAP32[$75>>2]|0;
  if ($74) {
   $83 = Math_imul($73, $4)|0;
   $84 = (($76) + ($83)|0);
   $85 = (($84) + ($3)|0);
   $86 = ($3|0)>($1|0);
   $$sink219 = $86 ? -1 : 1;
   $87 = (($73) + ($$sink219))|0;
   $88 = ($6|0)==(0);
   $89 = (($85) + ($87)|0);
   $$220 = $88 ? $89 : $85;
   $$0211 = $61;$$1206 = $$220;$$2210 = $87;
  } else {
   $77 = Math_imul($73, $2)|0;
   $78 = (($76) + ($77)|0);
   $79 = (($78) + ($1)|0);
   $80 = ($1|0)>($3|0);
   $$sink218 = $80 ? -1 : 1;
   $81 = (($73) + ($$sink218))|0;
   $82 = (($4) - ($2))|0;
   $$0211 = $82;$$1206 = $79;$$2210 = $81;
  }
  $not$222 = ($6|0)!=(0);
  $90 = $not$222&1;
  $$0211$ = (($$0211) + ($90))|0;
  $91 = ($$0211$|0)==(0);
  if ($91) {
   return;
  }
  $92 = $5&255;
  $$1212228 = $$0211$;$$2207229 = $$1206;
  while(1) {
   $93 = (($$1212228) + -1)|0;
   HEAP8[$$2207229>>0] = $92;
   $94 = (($$2207229) + ($$2210)|0);
   $95 = ($93|0)==(0);
   if ($95) {
    break;
   } else {
    $$1212228 = $93;$$2207229 = $94;
   }
  }
  return;
 } else {
  $96 = (($3) - ($1))|0;
  $97 = ($96|0)<(0);
  $98 = (0 - ($96))|0;
  $99 = $97 ? $98 : $96;
  $100 = (($4) - ($2))|0;
  $101 = ($100|0)<(0);
  $102 = (0 - ($100))|0;
  $103 = $101 ? $102 : $100;
  $104 = ($99|0)<($103|0);
  if ($104) {
   $108 = $99 << 1;
   $109 = (($108) - ($103))|0;
   $110 = (($99) - ($103))|0;
   $$0185 = 1;$$0191 = 0;$$0195$in = $110;$$0196 = $108;$$0197 = $109;$$0199$in = $103;
  } else {
   $105 = $103 << 1;
   $106 = (($105) - ($99))|0;
   $107 = (($103) - ($99))|0;
   $$0185 = 0;$$0191 = 1;$$0195$in = $107;$$0196 = $105;$$0197 = $106;$$0199$in = $99;
  }
  $$0195 = $$0195$in << 1;
  $111 = ($1|0)>($3|0);
  $112 = (0 - ($$0191))|0;
  $$$0191 = $111 ? $112 : $$0191;
  $$221 = $111 ? -1 : 1;
  $113 = ($4|0)<($2|0);
  $114 = (0 - ($$0185))|0;
  $$1186 = $113 ? $114 : $$0185;
  $$1 = $113 ? -1 : 1;
  $not$ = ($6|0)!=(0);
  $$0199 = $not$&1;
  $$0199$in$$0199 = (($$0199$in) + ($$0199))|0;
  $115 = ($$0199$in$$0199|0)>(0);
  if (!($115)) {
   return;
  }
  $116 = $5&255;
  $117 = ((($0)) + 20|0);
  $118 = ((($0)) + 16|0);
  $$0187234 = $2;$$0193233 = $1;$$0204231 = 0;$$1198232 = $$0197;
  while(1) {
   $119 = HEAP32[$117>>2]|0;
   $120 = HEAP32[$118>>2]|0;
   $121 = Math_imul($120, $$0187234)|0;
   $122 = (($119) + ($121)|0);
   $123 = (($122) + ($$0193233)|0);
   HEAP8[$123>>0] = $116;
   $124 = ($$1198232|0)<(0);
   $$0196$$0195 = $124 ? $$0196 : $$0195;
   $$$0191$$221 = $124 ? $$$0191 : $$221;
   $$1186$$1 = $124 ? $$1186 : $$1;
   $$1188 = (($$0187234) + ($$1186$$1))|0;
   $$1194 = (($$$0191$$221) + ($$0193233))|0;
   $$2 = (($$0196$$0195) + ($$1198232))|0;
   $125 = (($$0204231) + 1)|0;
   $126 = ($125|0)<($$0199$in$$0199|0);
   if ($126) {
    $$0187234 = $$1188;$$0193233 = $$1194;$$0204231 = $125;$$1198232 = $$2;
   } else {
    break;
   }
  }
  return;
 }
}
function _SDL_DrawLine4($0,$1,$2,$3,$4,$5,$6) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 var $$ = 0, $$$0361 = 0, $$$0361$$431 = 0, $$$0383 = 0, $$$0383$$430 = 0, $$$0406 = 0, $$$0406$$429 = 0, $$0355 = 0, $$0357465 = 0, $$0361 = 0, $$0363464 = 0, $$0365 = 0, $$0365$in = 0, $$0366 = 0, $$0366$$0365 = 0, $$0367 = 0, $$0369 = 0, $$0369$in = 0, $$0369$in$$0369 = 0, $$0371445 = 0;
 var $$0374462 = 0, $$0377 = 0, $$0379460 = 0, $$0383 = 0, $$0385459 = 0, $$0387 = 0, $$0387$in = 0, $$0388 = 0, $$0388$$0387 = 0, $$0389 = 0, $$0392 = 0, $$0392$in = 0, $$0392$in$$0392 = 0, $$0394447 = 0, $$0397457 = 0, $$0400 = 0, $$0402455 = 0, $$0406 = 0, $$0408454 = 0, $$0410 = 0;
 var $$0410$in = 0, $$0411 = 0, $$0411$$0410 = 0, $$0412 = 0, $$0415 = 0, $$0415$in = 0, $$0415$in$$0415 = 0, $$0417 = 0, $$0417$ = 0, $$0422452 = 0, $$1 = 0, $$1356 = 0, $$1356$$1 = 0, $$1358 = 0, $$1364 = 0, $$1368463 = 0, $$1373$ph = 0, $$1373444 = 0, $$1376 = 0, $$1378 = 0;
 var $$1378$$1376 = 0, $$1380 = 0, $$1386 = 0, $$1390458 = 0, $$1396$ph = 0, $$1396446 = 0, $$1399 = 0, $$1401 = 0, $$1401$$1399 = 0, $$1403 = 0, $$1409 = 0, $$1413453 = 0, $$1418450 = 0, $$1424 = 0, $$2 = 0, $$2391 = 0, $$2414 = 0, $$2421 = 0, $$2425449 = 0, $$426 = 0;
 var $$428 = 0, $$429 = 0, $$430 = 0, $$431 = 0, $$neg = 0, $$neg435 = 0, $$neg435$sink = 0, $$neg436 = 0, $$neg437 = 0, $$neg437$sink = 0, $$sink = 0, $$sink427 = 0, $$sink469 = 0, $$sink472 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0;
 var $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0;
 var $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0;
 var $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $not$ = 0, $not$432 = 0, $not$433 = 0, $not$434 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $7 = sp + 3|0;
 $8 = sp + 2|0;
 $9 = sp + 1|0;
 $10 = sp;
 $11 = ($4|0)==($2|0);
 if ($11) {
  $12 = ((($0)) + 16|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ((($0)) + 4|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = ((($15)) + 9|0);
  $17 = HEAP8[$16>>0]|0;
  $18 = $17&255;
  $19 = (($13|0) / ($18|0))&-1;
  $20 = ($1|0)>($3|0);
  $21 = ((($0)) + 20|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = Math_imul($19, $4)|0;
  $24 = (($22) + ($23<<2)|0);
  $25 = ($6|0)!=(0);
  if ($20) {
   $27 = (($24) + ($3<<2)|0);
   $28 = ((($27)) + 4|0);
   $$ = $25 ? $27 : $28;
   $$neg437 = (0 - ($3))|0;
   $$1373$ph = $$;$$neg437$sink = $$neg437;$$sink469 = $1;
  } else {
   $26 = (($24) + ($1<<2)|0);
   $$neg436 = (0 - ($1))|0;
   $$1373$ph = $26;$$neg437$sink = $3;$$sink469 = $$neg436;
  }
  $29 = (($$neg437$sink) + ($$sink469))|0;
  $30 = $25&1;
  $31 = (($29) + ($30))|0;
  $32 = ($31|0)==(0);
  if ($32) {
   STACKTOP = sp;return;
  } else {
   $$0371445 = $31;$$1373444 = $$1373$ph;
  }
  while(1) {
   $33 = (($$0371445) + -1)|0;
   HEAP32[$$1373444>>2] = $5;
   $34 = ((($$1373444)) + 4|0);
   $35 = ($33|0)==(0);
   if ($35) {
    break;
   } else {
    $$0371445 = $33;$$1373444 = $34;
   }
  }
  STACKTOP = sp;return;
 }
 $36 = ($1|0)==($3|0);
 if ($36) {
  $37 = ((($0)) + 16|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = ((($0)) + 4|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = ((($40)) + 9|0);
  $42 = HEAP8[$41>>0]|0;
  $43 = $42&255;
  $44 = (($38|0) / ($43|0))&-1;
  $45 = ($4|0)<($2|0);
  $46 = ((($0)) + 20|0);
  $47 = HEAP32[$46>>2]|0;
  $48 = ($6|0)!=(0);
  if ($45) {
   $52 = Math_imul($44, $4)|0;
   $53 = (($47) + ($52<<2)|0);
   $54 = (($53) + ($1<<2)|0);
   $55 = (($54) + ($44<<2)|0);
   $$426 = $48 ? $54 : $55;
   $$neg435 = (0 - ($4))|0;
   $$1396$ph = $$426;$$neg435$sink = $$neg435;$$sink472 = $2;
  } else {
   $49 = Math_imul($44, $2)|0;
   $50 = (($47) + ($49<<2)|0);
   $51 = (($50) + ($1<<2)|0);
   $$neg = (0 - ($2))|0;
   $$1396$ph = $51;$$neg435$sink = $4;$$sink472 = $$neg;
  }
  $56 = (($$neg435$sink) + ($$sink472))|0;
  $57 = $48&1;
  $58 = (($56) + ($57))|0;
  $59 = ($58|0)==(0);
  if ($59) {
   STACKTOP = sp;return;
  } else {
   $$0394447 = $58;$$1396446 = $$1396$ph;
  }
  while(1) {
   $60 = (($$0394447) + -1)|0;
   HEAP32[$$1396446>>2] = $5;
   $61 = (($$1396446) + ($44<<2)|0);
   $62 = ($60|0)==(0);
   if ($62) {
    break;
   } else {
    $$0394447 = $60;$$1396446 = $61;
   }
  }
  STACKTOP = sp;return;
 }
 $63 = (($1) - ($3))|0;
 $64 = ($63|0)<(0);
 $65 = (0 - ($63))|0;
 $66 = $64 ? $65 : $63;
 $67 = (($2) - ($4))|0;
 $68 = ($67|0)<(0);
 $69 = (0 - ($67))|0;
 $70 = $68 ? $69 : $67;
 $71 = ($66|0)==($70|0);
 if ($71) {
  $72 = ((($0)) + 16|0);
  $73 = HEAP32[$72>>2]|0;
  $74 = ((($0)) + 4|0);
  $75 = HEAP32[$74>>2]|0;
  $76 = ((($75)) + 9|0);
  $77 = HEAP8[$76>>0]|0;
  $78 = $77&255;
  $79 = (($73|0) / ($78|0))&-1;
  $80 = ($4|0)<($2|0);
  $81 = ((($0)) + 20|0);
  $82 = HEAP32[$81>>2]|0;
  if ($80) {
   $89 = Math_imul($79, $4)|0;
   $90 = (($82) + ($89<<2)|0);
   $91 = (($90) + ($3<<2)|0);
   $92 = ($3|0)>($1|0);
   $$sink427 = $92 ? -1 : 1;
   $93 = (($79) + ($$sink427))|0;
   $94 = ($6|0)==(0);
   $95 = (($91) + ($93<<2)|0);
   $$428 = $94 ? $95 : $91;
   $$0417 = $67;$$1424 = $$428;$$2421 = $93;
  } else {
   $83 = Math_imul($79, $2)|0;
   $84 = (($82) + ($83<<2)|0);
   $85 = (($84) + ($1<<2)|0);
   $86 = ($1|0)>($3|0);
   $$sink = $86 ? -1 : 1;
   $87 = (($79) + ($$sink))|0;
   $88 = (($4) - ($2))|0;
   $$0417 = $88;$$1424 = $85;$$2421 = $87;
  }
  $not$434 = ($6|0)!=(0);
  $96 = $not$434&1;
  $$0417$ = (($$0417) + ($96))|0;
  $97 = ($$0417$|0)==(0);
  if ($97) {
   STACKTOP = sp;return;
  } else {
   $$1418450 = $$0417$;$$2425449 = $$1424;
  }
  while(1) {
   $98 = (($$1418450) + -1)|0;
   HEAP32[$$2425449>>2] = $5;
   $99 = (($$2425449) + ($$2421<<2)|0);
   $100 = ($98|0)==(0);
   if ($100) {
    break;
   } else {
    $$1418450 = $98;$$2425449 = $99;
   }
  }
  STACKTOP = sp;return;
 }
 $101 = ((($0)) + 4|0);
 $102 = HEAP32[$101>>2]|0;
 _SDL_GetRGBA($5,$102,$7,$8,$9,$10);
 $103 = ((($102)) + 12|0);
 $104 = HEAP32[$103>>2]|0;
 $105 = ($104|0)==(16711680);
 $106 = (($3) - ($1))|0;
 $107 = (($4) - ($2))|0;
 $108 = (0 - ($107))|0;
 $109 = (0 - ($106))|0;
 $110 = ($106|0)<(0);
 $111 = ($107|0)<(0);
 $112 = $110 ? $109 : $106;
 $113 = $111 ? $108 : $107;
 $114 = ($112|0)>=($113|0);
 do {
  if ($105) {
   $115 = ((($102)) + 24|0);
   $116 = HEAP32[$115>>2]|0;
   $117 = ($116|0)==(0);
   if ($117) {
    if ($114) {
     $118 = $113 << 1;
     $119 = (($118) - ($112))|0;
     $120 = (($113) - ($112))|0;
     $$0400 = 0;$$0406 = 1;$$0410$in = $120;$$0411 = $118;$$0412 = $119;$$0415$in = $112;
    } else {
     $121 = $112 << 1;
     $122 = (($121) - ($113))|0;
     $123 = (($112) - ($113))|0;
     $$0400 = 1;$$0406 = 0;$$0410$in = $123;$$0411 = $121;$$0412 = $122;$$0415$in = $113;
    }
    $$0410 = $$0410$in << 1;
    $124 = ($1|0)>($3|0);
    $125 = (0 - ($$0406))|0;
    $$$0406 = $124 ? $125 : $$0406;
    $$429 = $124 ? -1 : 1;
    $126 = ($4|0)<($2|0);
    $127 = (0 - ($$0400))|0;
    $$1401 = $126 ? $127 : $$0400;
    $$1399 = $126 ? -1 : 1;
    $not$433 = ($6|0)!=(0);
    $$0415 = $not$433&1;
    $$0415$in$$0415 = (($$0415$in) + ($$0415))|0;
    $128 = ($$0415$in$$0415|0)>(0);
    if (!($128)) {
     break;
    }
    $129 = ((($0)) + 20|0);
    $130 = HEAP32[$129>>2]|0;
    $131 = ((($0)) + 16|0);
    $$0402455 = $2;$$0408454 = $1;$$0422452 = 0;$$1413453 = $$0412;
    while(1) {
     $132 = HEAP32[$131>>2]|0;
     $133 = Math_imul($132, $$0402455)|0;
     $134 = (($130) + ($133)|0);
     $135 = $$0408454 << 2;
     $136 = (($134) + ($135)|0);
     HEAP32[$136>>2] = $5;
     $137 = ($$1413453|0)<(0);
     $$0411$$0410 = $137 ? $$0411 : $$0410;
     $$$0406$$429 = $137 ? $$$0406 : $$429;
     $$1401$$1399 = $137 ? $$1401 : $$1399;
     $$1403 = (($$0402455) + ($$1401$$1399))|0;
     $$1409 = (($$$0406$$429) + ($$0408454))|0;
     $$2414 = (($$0411$$0410) + ($$1413453))|0;
     $138 = (($$0422452) + 1)|0;
     $139 = ($138|0)<($$0415$in$$0415|0);
     if ($139) {
      $$0402455 = $$1403;$$0408454 = $$1409;$$0422452 = $138;$$1413453 = $$2414;
     } else {
      break;
     }
    }
   } else {
    if ($114) {
     $140 = $113 << 1;
     $141 = (($140) - ($112))|0;
     $142 = (($113) - ($112))|0;
     $$0377 = 0;$$0383 = 1;$$0387$in = $142;$$0388 = $140;$$0389 = $141;$$0392$in = $112;
    } else {
     $143 = $112 << 1;
     $144 = (($143) - ($113))|0;
     $145 = (($112) - ($113))|0;
     $$0377 = 1;$$0383 = 0;$$0387$in = $145;$$0388 = $143;$$0389 = $144;$$0392$in = $113;
    }
    $$0387 = $$0387$in << 1;
    $146 = ($1|0)>($3|0);
    $147 = (0 - ($$0383))|0;
    $$$0383 = $146 ? $147 : $$0383;
    $$430 = $146 ? -1 : 1;
    $148 = ($4|0)<($2|0);
    $149 = (0 - ($$0377))|0;
    $$1378 = $148 ? $149 : $$0377;
    $$1376 = $148 ? -1 : 1;
    $not$432 = ($6|0)!=(0);
    $$0392 = $not$432&1;
    $$0392$in$$0392 = (($$0392$in) + ($$0392))|0;
    $150 = ($$0392$in$$0392|0)>(0);
    if (!($150)) {
     break;
    }
    $151 = ((($0)) + 20|0);
    $152 = HEAP32[$151>>2]|0;
    $153 = ((($0)) + 16|0);
    $$0379460 = $2;$$0385459 = $1;$$0397457 = 0;$$1390458 = $$0389;
    while(1) {
     $154 = HEAP32[$153>>2]|0;
     $155 = Math_imul($154, $$0379460)|0;
     $156 = (($152) + ($155)|0);
     $157 = $$0385459 << 2;
     $158 = (($156) + ($157)|0);
     HEAP32[$158>>2] = $5;
     $159 = ($$1390458|0)<(0);
     $$0388$$0387 = $159 ? $$0388 : $$0387;
     $$$0383$$430 = $159 ? $$$0383 : $$430;
     $$1378$$1376 = $159 ? $$1378 : $$1376;
     $$1380 = (($$0379460) + ($$1378$$1376))|0;
     $$1386 = (($$$0383$$430) + ($$0385459))|0;
     $$2391 = (($$0388$$0387) + ($$1390458))|0;
     $160 = (($$0397457) + 1)|0;
     $161 = ($160|0)<($$0392$in$$0392|0);
     if ($161) {
      $$0379460 = $$1380;$$0385459 = $$1386;$$0397457 = $160;$$1390458 = $$2391;
     } else {
      break;
     }
    }
   }
  } else {
   if ($114) {
    $162 = $113 << 1;
    $163 = (($162) - ($112))|0;
    $164 = (($113) - ($112))|0;
    $$0355 = 0;$$0361 = 1;$$0365$in = $164;$$0366 = $162;$$0367 = $163;$$0369$in = $112;
   } else {
    $165 = $112 << 1;
    $166 = (($165) - ($113))|0;
    $167 = (($112) - ($113))|0;
    $$0355 = 1;$$0361 = 0;$$0365$in = $167;$$0366 = $165;$$0367 = $166;$$0369$in = $113;
   }
   $$0365 = $$0365$in << 1;
   $168 = ($1|0)>($3|0);
   $169 = (0 - ($$0361))|0;
   $$$0361 = $168 ? $169 : $$0361;
   $$431 = $168 ? -1 : 1;
   $170 = ($4|0)<($2|0);
   $171 = (0 - ($$0355))|0;
   $$1356 = $170 ? $171 : $$0355;
   $$1 = $170 ? -1 : 1;
   $not$ = ($6|0)!=(0);
   $$0369 = $not$&1;
   $$0369$in$$0369 = (($$0369$in) + ($$0369))|0;
   $172 = ($$0369$in$$0369|0)>(0);
   if ($172) {
    $173 = ((($0)) + 20|0);
    $174 = HEAP32[$173>>2]|0;
    $175 = ((($0)) + 16|0);
    $$0357465 = $2;$$0363464 = $1;$$0374462 = 0;$$1368463 = $$0367;
    while(1) {
     $176 = HEAP32[$175>>2]|0;
     $177 = Math_imul($176, $$0357465)|0;
     $178 = (($174) + ($177)|0);
     $179 = $$0363464 << 2;
     $180 = (($178) + ($179)|0);
     HEAP32[$180>>2] = $5;
     $181 = ($$1368463|0)<(0);
     $$0366$$0365 = $181 ? $$0366 : $$0365;
     $$$0361$$431 = $181 ? $$$0361 : $$431;
     $$1356$$1 = $181 ? $$1356 : $$1;
     $$1358 = (($$0357465) + ($$1356$$1))|0;
     $$1364 = (($$$0361$$431) + ($$0363464))|0;
     $$2 = (($$0366$$0365) + ($$1368463))|0;
     $182 = (($$0374462) + 1)|0;
     $183 = ($182|0)<($$0369$in$$0369|0);
     if ($183) {
      $$0357465 = $$1358;$$0363464 = $$1364;$$0374462 = $182;$$1368463 = $$2;
     } else {
      break;
     }
    }
   }
  }
 } while(0);
 STACKTOP = sp;return;
}
function _SDL_DrawPoint($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $4 = ($0|0)==(0|0);
 L1: do {
  if ($4) {
   $5 = (_SDL_SetError(183547,$vararg_buffer)|0);
   $$0 = $5;
  } else {
   $6 = ((($0)) + 4|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ((($7)) + 8|0);
   $9 = HEAP8[$8>>0]|0;
   $10 = ($9&255)<(8);
   if ($10) {
    $11 = (_SDL_SetError(183579,$vararg_buffer1)|0);
    $$0 = $11;
    break;
   }
   $12 = ((($0)) + 36|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = ($13|0)>($1|0);
   if ($14) {
    $$0 = 0;
   } else {
    $15 = ((($0)) + 40|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = ($16|0)>($2|0);
    if ($17) {
     $$0 = 0;
    } else {
     $18 = ((($0)) + 44|0);
     $19 = HEAP32[$18>>2]|0;
     $20 = (($19) + ($13))|0;
     $21 = ($20|0)>($1|0);
     if ($21) {
      $22 = ((($0)) + 48|0);
      $23 = HEAP32[$22>>2]|0;
      $24 = (($23) + ($16))|0;
      $25 = ($24|0)>($2|0);
      if ($25) {
       $26 = ((($7)) + 9|0);
       $27 = HEAP8[$26>>0]|0;
       switch ($27<<24>>24) {
       case 1:  {
        $28 = $3&255;
        $29 = ((($0)) + 20|0);
        $30 = HEAP32[$29>>2]|0;
        $31 = ((($0)) + 16|0);
        $32 = HEAP32[$31>>2]|0;
        $33 = Math_imul($32, $2)|0;
        $34 = (($30) + ($33)|0);
        $35 = (($34) + ($1)|0);
        HEAP8[$35>>0] = $28;
        $$0 = 0;
        break L1;
        break;
       }
       case 2:  {
        $36 = $3&65535;
        $37 = ((($0)) + 20|0);
        $38 = HEAP32[$37>>2]|0;
        $39 = ((($0)) + 16|0);
        $40 = HEAP32[$39>>2]|0;
        $41 = Math_imul($40, $2)|0;
        $42 = (($38) + ($41)|0);
        $43 = $1 << 1;
        $44 = (($42) + ($43)|0);
        HEAP16[$44>>1] = $36;
        $$0 = 0;
        break L1;
        break;
       }
       case 3:  {
        $45 = (_SDL_Error(4)|0);
        $$0 = $45;
        break L1;
        break;
       }
       case 4:  {
        $46 = ((($0)) + 20|0);
        $47 = HEAP32[$46>>2]|0;
        $48 = ((($0)) + 16|0);
        $49 = HEAP32[$48>>2]|0;
        $50 = Math_imul($49, $2)|0;
        $51 = (($47) + ($50)|0);
        $52 = $1 << 2;
        $53 = (($51) + ($52)|0);
        HEAP32[$53>>2] = $3;
        $$0 = 0;
        break L1;
        break;
       }
       default: {
        $$0 = 0;
        break L1;
       }
       }
      } else {
       $$0 = 0;
      }
     } else {
      $$0 = 0;
     }
    }
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function _SDL_DrawPoints($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $$05255 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $notlhs = 0, $notrhs = 0, $or$cond$not = 0, $or$cond53 = 0, $or$cond53$not = 0, $or$cond54 = 0;
 var $vararg_buffer = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $4 = ($0|0)==(0|0);
 if ($4) {
  $5 = (_SDL_SetError(183547,$vararg_buffer)|0);
  $$0 = $5;
  STACKTOP = sp;return ($$0|0);
 }
 $6 = ((($0)) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($7)) + 8|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = ($9&255)<(8);
 if ($10) {
  $11 = (_SDL_SetError(183669,$vararg_buffer1)|0);
  $$0 = $11;
  STACKTOP = sp;return ($$0|0);
 }
 $12 = ((($0)) + 36|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($0)) + 44|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($15) + ($13))|0;
 $17 = ((($0)) + 40|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ((($0)) + 48|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($20) + ($18))|0;
 $22 = ($2|0)>(0);
 if (!($22)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $23 = $3&255;
 $24 = ((($0)) + 20|0);
 $25 = ((($0)) + 16|0);
 $26 = $3&65535;
 $$05255 = 0;
 L12: while(1) {
  $27 = (($1) + ($$05255<<3)|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (((($1) + ($$05255<<3)|0)) + 4|0);
  $30 = HEAP32[$29>>2]|0;
  $notlhs = ($28|0)<($13|0);
  $notrhs = ($28|0)>=($16|0);
  $or$cond$not = $notrhs | $notlhs;
  $31 = ($30|0)<($18|0);
  $or$cond53 = $or$cond$not | $31;
  $or$cond53$not = $or$cond53 ^ 1;
  $32 = ($30|0)<($21|0);
  $or$cond54 = $32 & $or$cond53$not;
  L14: do {
   if ($or$cond54) {
    $33 = HEAP32[$6>>2]|0;
    $34 = ((($33)) + 9|0);
    $35 = HEAP8[$34>>0]|0;
    switch ($35<<24>>24) {
    case 3:  {
     break L12;
     break;
    }
    case 1:  {
     $36 = HEAP32[$24>>2]|0;
     $37 = HEAP32[$25>>2]|0;
     $38 = Math_imul($37, $30)|0;
     $39 = (($36) + ($38)|0);
     $40 = (($39) + ($28)|0);
     HEAP8[$40>>0] = $23;
     break L14;
     break;
    }
    case 2:  {
     $41 = HEAP32[$24>>2]|0;
     $42 = HEAP32[$25>>2]|0;
     $43 = Math_imul($42, $30)|0;
     $44 = (($41) + ($43)|0);
     $45 = $28 << 1;
     $46 = (($44) + ($45)|0);
     HEAP16[$46>>1] = $26;
     break L14;
     break;
    }
    case 4:  {
     $48 = HEAP32[$24>>2]|0;
     $49 = HEAP32[$25>>2]|0;
     $50 = Math_imul($49, $30)|0;
     $51 = (($48) + ($50)|0);
     $52 = $28 << 2;
     $53 = (($51) + ($52)|0);
     HEAP32[$53>>2] = $3;
     break L14;
     break;
    }
    default: {
     break L14;
    }
    }
   }
  } while(0);
  $54 = (($$05255) + 1)|0;
  $55 = ($54|0)<($2|0);
  if ($55) {
   $$05255 = $54;
  } else {
   $$0 = 0;
   label = 14;
   break;
  }
 }
 if ((label|0) == 14) {
  STACKTOP = sp;return ($$0|0);
 }
 $47 = (_SDL_Error(4)|0);
 $$0 = $47;
 STACKTOP = sp;return ($$0|0);
}
function _SDL_BlendPoints($0,$1,$2,$3,$4,$5,$6,$7) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 var $$070 = 0, $$071 = 0, $$07280 = 0, $$073 = 0, $$074 = 0, $$081 = 0, $$1 = 0, $$169 = 0, $$off = 0, $$sink = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $8 = 0, $9 = 0, $SDL_BlendPoint_RGB$SDL_BlendPoint_RGBA = 0, $SDL_BlendPoint_RGB888$SDL_BlendPoint_ARGB8888 = 0, $cond = 0, $cond1 = 0, $cond2 = 0, $exitcond = 0, $notlhs = 0, $notrhs = 0, $or$cond$not = 0, $or$cond75 = 0, $or$cond75$not = 0, $or$cond76 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $8 = ($0|0)==(0|0);
 if ($8) {
  $$sink = 183547;
 } else {
  $9 = ((($0)) + 4|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ((($10)) + 8|0);
  $12 = HEAP8[$11>>0]|0;
  $13 = ($12&255)<(8);
  if ($13) {
   $$sink = 183623;
  } else {
   $$off = (($3) + -1)|0;
   $14 = ($$off>>>0)<(2);
   if ($14) {
    $15 = $4&255;
    $16 = $7&255;
    $17 = Math_imul($16, $15)|0;
    $18 = (($17>>>0) / 255)&-1;
    $19 = $18&255;
    $20 = $5&255;
    $21 = Math_imul($16, $20)|0;
    $22 = (($21>>>0) / 255)&-1;
    $23 = $22&255;
    $24 = $6&255;
    $25 = Math_imul($16, $24)|0;
    $26 = (($25>>>0) / 255)&-1;
    $27 = $26&255;
    $$071 = $19;$$073 = $23;$$074 = $27;
   } else {
    $$071 = $4;$$073 = $5;$$074 = $6;
   }
   switch ($12<<24>>24) {
   case 15:  {
    $28 = ((($10)) + 12|0);
    $29 = HEAP32[$28>>2]|0;
    $cond2 = ($29|0)==(31744);
    if ($cond2) {
     $$169 = 4368;
    } else {
     label = 10;
    }
    break;
   }
   case 16:  {
    $30 = ((($10)) + 12|0);
    $31 = HEAP32[$30>>2]|0;
    $cond1 = ($31|0)==(63488);
    if ($cond1) {
     $$169 = 4369;
    } else {
     label = 10;
    }
    break;
   }
   case 32:  {
    $32 = ((($10)) + 12|0);
    $33 = HEAP32[$32>>2]|0;
    $cond = ($33|0)==(16711680);
    if ($cond) {
     $34 = ((($10)) + 24|0);
     $35 = HEAP32[$34>>2]|0;
     $36 = ($35|0)==(0);
     $SDL_BlendPoint_RGB888$SDL_BlendPoint_ARGB8888 = $36 ? 4365 : 4364;
     $$169 = $SDL_BlendPoint_RGB888$SDL_BlendPoint_ARGB8888;
    } else {
     label = 10;
    }
    break;
   }
   default: {
    label = 10;
   }
   }
   if ((label|0) == 10) {
    $37 = ((($10)) + 24|0);
    $38 = HEAP32[$37>>2]|0;
    $39 = ($38|0)==(0);
    $SDL_BlendPoint_RGB$SDL_BlendPoint_RGBA = $39 ? 4367 : 4366;
    $$169 = $SDL_BlendPoint_RGB$SDL_BlendPoint_RGBA;
   }
   $40 = ((($0)) + 36|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = ((($0)) + 44|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = (($43) + ($41))|0;
   $45 = ((($0)) + 40|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = ((($0)) + 48|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = (($48) + ($46))|0;
   $50 = ($2|0)>(0);
   if ($50) {
    $$07280 = 0;$$081 = 0;
   } else {
    $$070 = 0;
    STACKTOP = sp;return ($$070|0);
   }
   while(1) {
    $51 = (($1) + ($$07280<<3)|0);
    $52 = HEAP32[$51>>2]|0;
    $53 = (((($1) + ($$07280<<3)|0)) + 4|0);
    $54 = HEAP32[$53>>2]|0;
    $notlhs = ($52|0)<($41|0);
    $notrhs = ($52|0)>=($44|0);
    $or$cond$not = $notrhs | $notlhs;
    $55 = ($54|0)<($46|0);
    $or$cond75 = $or$cond$not | $55;
    $or$cond75$not = $or$cond75 ^ 1;
    $56 = ($54|0)<($49|0);
    $or$cond76 = $56 & $or$cond75$not;
    if ($or$cond76) {
     $57 = (FUNCTION_TABLE_iiiiiiiii[$$169 & 8191]($0,$52,$54,$3,$$071,$$073,$$074,$7)|0);
     $$1 = $57;
    } else {
     $$1 = $$081;
    }
    $58 = (($$07280) + 1)|0;
    $exitcond = ($58|0)==($2|0);
    if ($exitcond) {
     $$070 = $$1;
     break;
    } else {
     $$07280 = $58;$$081 = $$1;
    }
   }
   STACKTOP = sp;return ($$070|0);
  }
 }
 $59 = (_SDL_SetError($$sink,$vararg_buffer)|0);
 $$070 = $59;
 STACKTOP = sp;return ($$070|0);
}
function _SDL_CreateRGBSurfaceFrom($0,$1,$2,$3,$4,$5,$6,$7,$8) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 $8 = $8|0;
 var $$0$i25 = 0, $$sroa$0$0$$sroa_idx = 0, $$sroa$4$0$$sroa_idx19 = 0, $$sroa$5$0$$sroa_idx21 = 0, $$sroa$6$0$$sroa_idx23 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $9 = (_SDL_MasksToPixelFormatEnum($3,$5,$6,$7,$8)|0);
 $10 = ($9|0)==(0);
 if ($10) {
  (_SDL_SetError(182955,$vararg_buffer)|0);
  $$0$i25 = 0;
  STACKTOP = sp;return ($$0$i25|0);
 }
 $11 = (_SDL_CreateRGBSurfaceWithFormat(0,0,0,0,$9)|0);
 $12 = ($11|0)==(0|0);
 if ($12) {
  $$0$i25 = 0;
  STACKTOP = sp;return ($$0$i25|0);
 }
 $13 = HEAP32[$11>>2]|0;
 $14 = $13 | 1;
 HEAP32[$11>>2] = $14;
 $15 = ((($11)) + 20|0);
 HEAP32[$15>>2] = $0;
 $16 = ((($11)) + 8|0);
 HEAP32[$16>>2] = $1;
 $17 = ((($11)) + 12|0);
 HEAP32[$17>>2] = $2;
 $18 = ((($11)) + 16|0);
 HEAP32[$18>>2] = $4;
 $$sroa$0$0$$sroa_idx = ((($11)) + 36|0);
 HEAP32[$$sroa$0$0$$sroa_idx>>2] = 0;
 $$sroa$4$0$$sroa_idx19 = ((($11)) + 40|0);
 HEAP32[$$sroa$4$0$$sroa_idx19>>2] = 0;
 $$sroa$5$0$$sroa_idx21 = ((($11)) + 44|0);
 HEAP32[$$sroa$5$0$$sroa_idx21>>2] = $1;
 $$sroa$6$0$$sroa_idx23 = ((($11)) + 48|0);
 HEAP32[$$sroa$6$0$$sroa_idx23>>2] = $2;
 $$0$i25 = $11;
 STACKTOP = sp;return ($$0$i25|0);
}
function _Emscripten_Available() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 1;
}
function _Emscripten_CreateDevice($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (_SDL_calloc(1,688)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  (_SDL_Error(0)|0);
  $$0 = 0;
  return ($$0|0);
 } else {
  (_SDL_SetHint(183814,183847)|0);
  $3 = ((($1)) + 4|0);
  HEAP32[$3>>2] = 4370;
  $4 = ((($1)) + 8|0);
  HEAP32[$4>>2] = 4371;
  $5 = ((($1)) + 28|0);
  HEAP32[$5>>2] = 4372;
  $6 = ((($1)) + 204|0);
  HEAP32[$6>>2] = 4373;
  $7 = ((($1)) + 32|0);
  HEAP32[$7>>2] = 4374;
  $8 = ((($1)) + 40|0);
  HEAP32[$8>>2] = 4375;
  $9 = ((($1)) + 52|0);
  HEAP32[$9>>2] = 4376;
  $10 = ((($1)) + 128|0);
  HEAP32[$10>>2] = 4377;
  $11 = ((($1)) + 112|0);
  HEAP32[$11>>2] = 4378;
  $12 = ((($1)) + 132|0);
  HEAP32[$12>>2] = 4379;
  $13 = ((($1)) + 136|0);
  HEAP32[$13>>2] = 4380;
  $14 = ((($1)) + 140|0);
  HEAP32[$14>>2] = 4381;
  $15 = ((($1)) + 164|0);
  HEAP32[$15>>2] = 4382;
  $16 = ((($1)) + 168|0);
  HEAP32[$16>>2] = 4383;
  $17 = ((($1)) + 172|0);
  HEAP32[$17>>2] = 4384;
  $18 = ((($1)) + 176|0);
  HEAP32[$18>>2] = 4385;
  $19 = ((($1)) + 180|0);
  HEAP32[$19>>2] = 4386;
  $20 = ((($1)) + 188|0);
  HEAP32[$20>>2] = 4387;
  $21 = ((($1)) + 192|0);
  HEAP32[$21>>2] = 4388;
  $22 = ((($1)) + 196|0);
  HEAP32[$22>>2] = 4389;
  $23 = ((($1)) + 200|0);
  HEAP32[$23>>2] = 4390;
  $24 = ((($1)) + 184|0);
  HEAP32[$24>>2] = 4391;
  $25 = ((($1)) + 684|0);
  HEAP32[$25>>2] = 4392;
  $$0 = $1;
  return ($$0|0);
 }
 return (0)|0;
}
function _SDL_SetHint($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_SDL_SetHintWithPriority($0,$1,1)|0);
 return ($2|0);
}
function _Emscripten_VideoInit($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $1 = sp;
 HEAP32[$1>>2] = 370546692;
 $2 = _emscripten_asm_const_i(0)|0;
 $3 = ((($1)) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = _emscripten_asm_const_i(1)|0;
 $5 = ((($1)) + 8|0);
 HEAP32[$5>>2] = $4;
 $6 = ((($1)) + 12|0);
 HEAP32[$6>>2] = 0;
 $7 = ((($1)) + 16|0);
 HEAP32[$7>>2] = 0;
 $8 = (_SDL_AddBasicVideoDisplay($1)|0);
 $9 = ($8|0)<(0);
 if ($9) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 (_SDL_memset($1,0,20)|0);
 $10 = ((($0)) + 268|0);
 $11 = HEAP32[$10>>2]|0;
 (_SDL_AddDisplayMode($11,$1)|0);
 _Emscripten_InitMouse();
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _Emscripten_VideoQuit($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 _Emscripten_FiniMouse();
 return;
}
function _Emscripten_SetDisplayMode($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function _Emscripten_PumpEvents($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function _Emscripten_CreateWindow($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$not = 0, $$pre = 0, $$sink = 0.0, $10 = 0, $11 = 0.0, $12 = 0.0, $13 = 0, $14 = 0, $15 = 0, $16 = 0.0, $17 = 0.0, $18 = 0.0, $19 = 0.0, $2 = 0, $20 = 0, $21 = 0, $22 = 0.0, $23 = 0.0, $24 = 0.0;
 var $25 = 0.0, $26 = 0.0, $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0.0, $31 = 0, $32 = 0.0, $33 = 0.0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0.0, $42 = 0.0;
 var $43 = 0.0, $44 = 0.0, $45 = 0.0, $46 = 0.0, $47 = 0, $48 = 0, $49 = 0.0, $5 = 0, $50 = 0, $51 = 0.0, $52 = 0, $53 = 0, $54 = 0, $55 = 0.0, $56 = 0, $57 = 0, $58 = 0.0, $59 = 0, $6 = 0, $60 = 0.0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0, $9 = 0, $brmerge = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $vararg_buffer = sp + 16|0;
 $2 = sp + 8|0;
 $3 = sp;
 $4 = (_SDL_calloc(1,40)|0);
 $5 = ($4|0)==(0|0);
 if ($5) {
  $6 = (_SDL_Error(0)|0);
  $$0 = $6;
  STACKTOP = sp;return ($$0|0);
 }
 $7 = ((($1)) + 48|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 & 8192;
 $10 = ($9|0)==(0);
 if ($10) {
  $$sink = 1.0;
 } else {
  $11 = (+_emscripten_get_device_pixel_ratio());
  $12 = $11;
  $$sink = $12;
 }
 $13 = ((($4)) + 12|0);
 HEAPF32[$13>>2] = $$sink;
 $14 = ((($1)) + 24|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (+($15|0));
 $17 = $$sink * $16;
 $18 = $17;
 $19 = (+_SDL_floor($18));
 $20 = ((($1)) + 28|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (+($21|0));
 $23 = +HEAPF32[$13>>2];
 $24 = $22 * $23;
 $25 = $24;
 $26 = (+_SDL_floor($25));
 $27 = (~~(($19)));
 $28 = (~~(($26)));
 _emscripten_set_canvas_size(($27|0),($28|0));
 (_emscripten_get_element_css_size((0|0),($2|0),($3|0))|0);
 $29 = +HEAPF64[$2>>3];
 $30 = (+_SDL_floor($29));
 $31 = $30 != $19;
 if ($31) {
  $36 = 1;
 } else {
  $32 = +HEAPF64[$3>>3];
  $33 = (+_SDL_floor($32));
  $34 = $33 != $26;
  $36 = $34;
 }
 $35 = $36&1;
 $37 = ((($4)) + 16|0);
 HEAP32[$37>>2] = $35;
 $38 = HEAP32[$7>>2]|0;
 $39 = $38 & 32;
 $40 = ($39|0)==(0);
 $$not = $36 ^ 1;
 $brmerge = $40 | $$not;
 if ($brmerge) {
  $53 = $35;
 } else {
  $41 = +HEAPF64[$2>>3];
  $42 = +HEAPF32[$13>>2];
  $43 = $42;
  $44 = $41 * $43;
  $45 = +HEAPF64[$3>>3];
  $46 = $45 * $43;
  $47 = (~~(($44)));
  $48 = (~~(($46)));
  _emscripten_set_canvas_size(($47|0),($48|0));
  $49 = +HEAPF64[$2>>3];
  $50 = (~~(($49)));
  $51 = +HEAPF64[$3>>3];
  $52 = (~~(($51)));
  (_SDL_SendWindowEvent($1,5,$50,$52)|0);
  $$pre = HEAP32[$37>>2]|0;
  $53 = $$pre;
 }
 $54 = ($53|0)==(0);
 if ($54) {
  $55 = +HEAPF32[$13>>2];
  $56 = $55 != 1.0;
  if ($56) {
   $57 = HEAP32[$14>>2]|0;
   $58 = (+($57|0));
   $59 = HEAP32[$20>>2]|0;
   $60 = (+($59|0));
   (_emscripten_set_element_css_size((0|0),(+$58),(+$60))|0);
  }
 }
 $61 = HEAP32[$7>>2]|0;
 $62 = $61 & 2;
 $63 = ($62|0)==(0);
 if (!($63)) {
  $64 = ((($0)) + 676|0);
  $65 = HEAP32[$64>>2]|0;
  $66 = ($65|0)==(0|0);
  if ($66) {
   $67 = (_SDL_GL_LoadLibrary(0)|0);
   $68 = ($67|0)<(0);
   if ($68) {
    $$0 = -1;
    STACKTOP = sp;return ($$0|0);
   }
  }
  $69 = (_SDL_EGL_CreateSurface($0,0)|0);
  HEAP32[$4>>2] = $69;
  $70 = ($69|0)==(0|0);
  if ($70) {
   $71 = (_SDL_SetError(185856,$vararg_buffer)|0);
   $$0 = $71;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $72 = ((($4)) + 4|0);
 HEAP32[$72>>2] = $1;
 $73 = ((($1)) + 144|0);
 HEAP32[$73>>2] = $4;
 _SDL_SetMouseFocus($1);
 _SDL_SetKeyboardFocus($1);
 _Emscripten_RegisterEventHandlers($4);
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _Emscripten_SetWindowTitle($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = _emscripten_asm_const_ii(2, ($3|0))|0;
 return;
}
function _Emscripten_SetWindowSize($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$phi$trans$insert = 0, $$pre = 0.0, $$pre$phi14Z2D = 0, $10 = 0.0, $11 = 0, $12 = 0, $13 = 0, $14 = 0.0, $15 = 0.0, $16 = 0.0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0.0, $21 = 0.0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0.0, $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0.0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 144|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  return;
 }
 $5 = ((($1)) + 48|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $6 & 8192;
 $8 = ($7|0)==(0);
 if ($8) {
  $$phi$trans$insert = ((($3)) + 12|0);
  $$pre = +HEAPF32[$$phi$trans$insert>>2];
  $$pre$phi14Z2D = $$phi$trans$insert;$16 = $$pre;
 } else {
  $9 = (+_emscripten_get_device_pixel_ratio());
  $10 = $9;
  $11 = ((($3)) + 12|0);
  HEAPF32[$11>>2] = $10;
  $$pre$phi14Z2D = $11;$16 = $10;
 }
 $12 = ((($1)) + 24|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (+($13|0));
 $15 = $14 * $16;
 $17 = (~~(($15)));
 $18 = ((($1)) + 28|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (+($19|0));
 $21 = $16 * $20;
 $22 = (~~(($21)));
 _emscripten_set_canvas_size(($17|0),($22|0));
 $23 = ((($3)) + 16|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)==(0);
 if (!($25)) {
  return;
 }
 $26 = +HEAPF32[$$pre$phi14Z2D>>2];
 $27 = $26 != 1.0;
 if (!($27)) {
  return;
 }
 $28 = HEAP32[$12>>2]|0;
 $29 = (+($28|0));
 $30 = HEAP32[$18>>2]|0;
 $31 = (+($30|0));
 (_emscripten_set_element_css_size((0|0),(+$29),(+$31))|0);
 return;
}
function _Emscripten_DestroyWindow($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 144|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  return;
 }
 _Emscripten_UnregisterEventHandlers($3);
 $5 = HEAP32[$3>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  _SDL_EGL_DestroySurface($0,$5);
  HEAP32[$3>>2] = 0;
 }
 $7 = HEAP32[$2>>2]|0;
 _SDL_free($7);
 HEAP32[$2>>2] = 0;
 return;
}
function _Emscripten_SetWindowFullscreen($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$ = 0, $$cmp = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $4 = sp;
 $5 = ((($1)) + 144|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  STACKTOP = sp;return;
 }
 $8 = ($3|0)==(0);
 if ($8) {
  (_emscripten_exit_fullscreen()|0);
  STACKTOP = sp;return;
 }
 $9 = ((($1)) + 48|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10 & 4097;
 $12 = ($11|0)==(4097);
 $13 = $12&1;
 $14 = $12 ? 1 : 2;
 HEAP32[$4>>2] = $14;
 $15 = ((($4)) + 4|0);
 $16 = $10 >>> 13;
 $17 = $16 & 1;
 $18 = (($17) + 1)|0;
 $$ = $12 ? $18 : 0;
 HEAP32[$15>>2] = $$;
 $19 = ((($4)) + 8|0);
 HEAP32[$19>>2] = 0;
 $20 = ((($4)) + 12|0);
 HEAP32[$20>>2] = 4393;
 $21 = ((($4)) + 16|0);
 HEAP32[$21>>2] = $6;
 $22 = ((($6)) + 20|0);
 HEAP32[$22>>2] = $11;
 $23 = ((($6)) + 24|0);
 HEAP32[$23>>2] = $13;
 $24 = (_emscripten_request_fullscreen_strategy((0|0),1,($4|0))|0);
 $$cmp = ($24>>>0)>(1);
 if ($$cmp) {
  $25 = HEAP32[$9>>2]|0;
  $26 = $25 & -4098;
  HEAP32[$9>>2] = $26;
 }
 STACKTOP = sp;return;
}
function _Emscripten_CreateWindowFramebuffer($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $5 = sp + 24|0;
 $6 = sp + 20|0;
 $7 = sp + 16|0;
 $8 = sp + 12|0;
 $9 = sp + 8|0;
 $10 = sp + 4|0;
 $11 = sp;
 $12 = ((($1)) + 144|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($13)) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 _SDL_FreeSurface($15);
 (_SDL_PixelFormatEnumToMasks(374740996,$7,$8,$9,$10,$11)|0);
 _SDL_GetWindowSize($1,$5,$6);
 $16 = HEAP32[$5>>2]|0;
 $17 = HEAP32[$6>>2]|0;
 $18 = HEAP32[$7>>2]|0;
 $19 = HEAP32[$8>>2]|0;
 $20 = HEAP32[$9>>2]|0;
 $21 = HEAP32[$10>>2]|0;
 $22 = HEAP32[$11>>2]|0;
 $23 = (_SDL_CreateRGBSurface(0,$16,$17,$18,$19,$20,$21,$22)|0);
 $24 = ($23|0)==(0|0);
 if ($24) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$14>>2] = $23;
 HEAP32[$2>>2] = 374740996;
 $25 = ((($23)) + 20|0);
 $26 = HEAP32[$25>>2]|0;
 HEAP32[$3>>2] = $26;
 $27 = ((($23)) + 16|0);
 $28 = HEAP32[$27>>2]|0;
 HEAP32[$4>>2] = $28;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _Emscripten_UpdateWindowFramebuffer($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $4 = ((($1)) + 144|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($5)) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if ($8) {
  $9 = (_SDL_SetError(184168,$vararg_buffer)|0);
  $$0 = $9;
  STACKTOP = sp;return ($$0|0);
 } else {
  $10 = ((($7)) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ((($7)) + 12|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ((($7)) + 20|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = _emscripten_asm_const_iiii(3, ($11|0), ($13|0), ($15|0))|0;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 return (0)|0;
}
function _Emscripten_DestroyWindowFramebuffer($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 144|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 _SDL_FreeSurface($5);
 HEAP32[$4>>2] = 0;
 return;
}
function _Emscripten_GLES_LoadLibrary($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $2 = (_SDL_calloc(1,88)|0);
 $3 = ((($0)) + 676|0);
 HEAP32[$3>>2] = $2;
 $4 = ($2|0)==(0|0);
 if ($4) {
  $5 = (_SDL_Error(0)|0);
  $$0 = $5;
  STACKTOP = sp;return ($$0|0);
 }
 $6 = ((($2)) + 20|0);
 HEAP32[$6>>2] = 4394;
 $7 = ((($2)) + 24|0);
 HEAP32[$7>>2] = 4395;
 $8 = ((($2)) + 28|0);
 HEAP32[$8>>2] = 4396;
 $9 = ((($2)) + 32|0);
 HEAP32[$9>>2] = 3796;
 $10 = ((($2)) + 36|0);
 HEAP32[$10>>2] = 4397;
 $11 = ((($2)) + 72|0);
 HEAP32[$11>>2] = 4398;
 $12 = ((($2)) + 40|0);
 HEAP32[$12>>2] = 4399;
 $13 = ((($2)) + 44|0);
 HEAP32[$13>>2] = 4400;
 $14 = ((($2)) + 48|0);
 HEAP32[$14>>2] = 4401;
 $15 = ((($2)) + 52|0);
 HEAP32[$15>>2] = 4402;
 $16 = ((($2)) + 56|0);
 HEAP32[$16>>2] = 4403;
 $17 = ((($2)) + 60|0);
 HEAP32[$17>>2] = 4404;
 $18 = ((($2)) + 64|0);
 HEAP32[$18>>2] = 4405;
 $19 = ((($2)) + 76|0);
 HEAP32[$19>>2] = 4406;
 $20 = ((($2)) + 80|0);
 HEAP32[$20>>2] = 4407;
 $21 = ((($2)) + 84|0);
 HEAP32[$21>>2] = 4408;
 $22 = ((($2)) + 20|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (FUNCTION_TABLE_ii[$23 & 8191](0)|0);
 $25 = HEAP32[$3>>2]|0;
 $26 = ((($25)) + 8|0);
 HEAP32[$26>>2] = $24;
 $27 = ($24|0)==(0|0);
 if ($27) {
  $28 = (_SDL_SetError(184117,$vararg_buffer)|0);
  $$0 = $28;
  STACKTOP = sp;return ($$0|0);
 }
 $29 = ((($25)) + 24|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (FUNCTION_TABLE_iiii[$30 & 8191]($24,0,0)|0);
 $32 = ($31|0)==(1);
 if (!($32)) {
  $33 = (_SDL_SetError(184143,$vararg_buffer1)|0);
  $$0 = $33;
  STACKTOP = sp;return ($$0|0);
 }
 $34 = ((($0)) + 388|0);
 HEAP32[$34>>2] = 1;
 $35 = ($1|0)==(0|0);
 $36 = ((($0)) + 392|0);
 if ($35) {
  HEAP8[$36>>0] = 0;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  (_SDL_strlcpy($36,$1,255)|0);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 return (0)|0;
}
function _SDL_EGL_GetProcAddress($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$014 = 0, $$pre = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 676|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + 32|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 do {
  if ($6) {
   $10 = $3;
  } else {
   $7 = (FUNCTION_TABLE_ii[$5 & 8191]($1)|0);
   $8 = ($7|0)==(0|0);
   if ($8) {
    $$pre = HEAP32[$2>>2]|0;
    $10 = $$pre;
    break;
   } else {
    $$014 = $7;
    return ($$014|0);
   }
  }
 } while(0);
 $9 = HEAP32[$10>>2]|0;
 $11 = (_SDL_LoadFunction($9,$1)|0);
 $12 = ($11|0)==(0|0);
 if (!($12)) {
  $$014 = $11;
  return ($$014|0);
 }
 $13 = (_SDL_strlen($1)|0);
 $14 = ($13>>>0)<(1023);
 if (!($14)) {
  $$014 = 0;
  return ($$014|0);
 }
 HEAP8[218402] = 95;
 (_SDL_strlcpy((218403),$1,1022)|0);
 $15 = HEAP32[$2>>2]|0;
 $16 = HEAP32[$15>>2]|0;
 $17 = (_SDL_LoadFunction($16,218402)|0);
 $$014 = $17;
 return ($$014|0);
}
function _SDL_EGL_UnloadLibrary($0) {
 $0 = $0|0;
 var $$in = 0, $$in13 = 0, $$in14 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 676|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  return;
 }
 $4 = ((($2)) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $$in = $2;
 } else {
  $7 = ((($2)) + 28|0);
  $8 = HEAP32[$7>>2]|0;
  (FUNCTION_TABLE_ii[$8 & 8191]($5)|0);
  $9 = HEAP32[$1>>2]|0;
  $10 = ((($9)) + 8|0);
  HEAP32[$10>>2] = 0;
  $$in = $9;
 }
 $11 = ((($$in)) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0|0);
 if ($13) {
  $$in13 = $$in;
 } else {
  _SDL_UnloadObject($12);
  $14 = HEAP32[$1>>2]|0;
  $15 = ((($14)) + 4|0);
  HEAP32[$15>>2] = 0;
  $$in13 = $14;
 }
 $16 = HEAP32[$$in13>>2]|0;
 $17 = ($16|0)==(0|0);
 if ($17) {
  $$in14 = $$in13;
 } else {
  _SDL_UnloadObject($16);
  $18 = HEAP32[$1>>2]|0;
  HEAP32[$18>>2] = 0;
  $$in14 = $18;
 }
 _SDL_free($$in14);
 HEAP32[$1>>2] = 0;
 return;
}
function _Emscripten_GLES_CreateContext($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 144|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = (_SDL_EGL_CreateContext($0,$4)|0);
 return ($5|0);
}
function _Emscripten_GLES_MakeCurrent($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($1|0)!=(0|0);
 $4 = ($2|0)!=(0|0);
 $or$cond = $3 & $4;
 if ($or$cond) {
  $5 = ((($1)) + 144|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = HEAP32[$6>>2]|0;
  $8 = (_SDL_EGL_MakeCurrent($0,$7,$2)|0);
  $$0 = $8;
  return ($$0|0);
 } else {
  $9 = (_SDL_EGL_MakeCurrent($0,0,0)|0);
  $$0 = $9;
  return ($$0|0);
 }
 return (0)|0;
}
function _SDL_EGL_SetSwapInterval($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $2 = ((($0)) + 676|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $5 = (_SDL_SetError(183849,$vararg_buffer)|0);
  $$0 = $5;
  STACKTOP = sp;return ($$0|0);
 }
 $6 = ((($3)) + 64|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($3)) + 8|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (FUNCTION_TABLE_iii[$7 & 8191]($9,$1)|0);
 $11 = ($10|0)==(1);
 if ($11) {
  $12 = HEAP32[$2>>2]|0;
  $13 = ((($12)) + 16|0);
  HEAP32[$13>>2] = $1;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  $14 = (_SDL_SetError(183869,$vararg_buffer1)|0);
  $$0 = $14;
  STACKTOP = sp;return ($$0|0);
 }
 return (0)|0;
}
function _SDL_EGL_GetSwapInterval($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $1 = ((($0)) + 676|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  (_SDL_SetError(183849,$vararg_buffer)|0);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  $4 = ((($2)) + 16|0);
  $5 = HEAP32[$4>>2]|0;
  $$0 = $5;
  STACKTOP = sp;return ($$0|0);
 }
 return (0)|0;
}
function _Emscripten_GLES_SwapWindow($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 144|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 _SDL_EGL_SwapBuffers($0,$4);
 return;
}
function _Emscripten_GLES_DeleteContext($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 _glClear(17664);
 _SDL_EGL_DeleteContext($0,$1);
 return;
}
function _Emscripten_GLES_GetDrawableSize($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $10 = 0.0, $11 = 0, $12 = 0.0, $13 = 0.0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0.0, $19 = 0, $20 = 0.0, $21 = 0.0, $22 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $4 = ((($1)) + 144|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  return;
 }
 $7 = ($2|0)==(0|0);
 if (!($7)) {
  $8 = ((($1)) + 24|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (+($9|0));
  $11 = ((($5)) + 12|0);
  $12 = +HEAPF32[$11>>2];
  $13 = $10 * $12;
  $14 = (~~(($13)));
  HEAP32[$2>>2] = $14;
 }
 $15 = ($3|0)==(0|0);
 if ($15) {
  return;
 }
 $16 = ((($1)) + 28|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (+($17|0));
 $19 = ((($5)) + 12|0);
 $20 = +HEAPF32[$19>>2];
 $21 = $18 * $20;
 $22 = (~~(($21)));
 HEAP32[$3>>2] = $22;
 return;
}
function _Emscripten_DeleteDevice($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 _SDL_free($0);
 return;
}
function _SDL_EGL_DeleteContext($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$phi$trans$insert = 0, $$phi$trans$insert11 = 0, $$pre = 0, $$pre10 = 0, $$pre12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 676|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = ($1|0)==(0|0);
 $or$cond = $5 | $4;
 if ($or$cond) {
  return;
 }
 $6 = ((($3)) + 56|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($3)) + 8|0);
 $9 = HEAP32[$8>>2]|0;
 (FUNCTION_TABLE_iiiii[$7 & 8191]($9,0,0,0)|0);
 $$pre = HEAP32[$2>>2]|0;
 $$phi$trans$insert = ((($$pre)) + 44|0);
 $$pre10 = HEAP32[$$phi$trans$insert>>2]|0;
 $$phi$trans$insert11 = ((($$pre)) + 8|0);
 $$pre12 = HEAP32[$$phi$trans$insert11>>2]|0;
 (FUNCTION_TABLE_iii[$$pre10 & 8191]($$pre12,$1)|0);
 return;
}
function _SDL_EGL_SwapBuffers($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 676|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + 60|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($3)) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 (FUNCTION_TABLE_iii[$5 & 8191]($7,$1)|0);
 return;
}
function _SDL_EGL_MakeCurrent($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $3 = ((($0)) + 676|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  $6 = (_SDL_SetError(183905,$vararg_buffer)|0);
  $$0 = $6;
  STACKTOP = sp;return ($$0|0);
 }
 $7 = ($2|0)!=(0|0);
 $8 = ($1|0)!=(0|0);
 $or$cond = $8 & $7;
 $9 = ((($4)) + 56|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ((($4)) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 if (!($or$cond)) {
  (FUNCTION_TABLE_iiiii[$10 & 8191]($12,0,0,0)|0);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $13 = (FUNCTION_TABLE_iiiii[$10 & 8191]($12,$1,$1,$2)|0);
 $14 = ($13|0)==(0);
 if (!($14)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $15 = (_SDL_SetError(183928,$vararg_buffer1)|0);
 $$0 = $15;
 STACKTOP = sp;return ($$0|0);
}
function _SDL_EGL_CreateContext($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$049 = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert11$i = 0, $$pre$i = 0, $$pre10$i = 0, $$pre12$i = 0, $$sink = 0, $$sink54 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond50 = 0, $or$cond52 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer3 = 0, $vararg_buffer5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(96|0);
 $vararg_buffer5 = sp + 24|0;
 $vararg_buffer3 = sp + 16|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $2 = sp + 28|0;
 $3 = ((($0)) + 368|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 356|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($0)) + 360|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($4|0)==(4);
 $10 = ((($0)) + 676|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0|0);
 if ($12) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $13 = ((($0)) + 372|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(0);
 if ($15) {
  $$049 = 0;
 } else {
  $16 = (_SDL_GL_GetCurrentContext()|0);
  $$049 = $16;
 }
 $17 = ($6|0)<(3);
 $18 = ($8|0)==(0);
 $or$cond = $9 & $18;
 $or$cond50 = $17 | $or$cond;
 if ($or$cond50) {
  $19 = ((($0)) + 364|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = ($20|0)==(0);
  $22 = $4 | 4;
  $23 = ($22|0)==(4);
  $or$cond52 = $23 & $21;
  if ($or$cond52) {
   if ($9) {
    $24 = ((($2)) + 4|0);
    $25 = ($6|0)>(1);
    $26 = $25 ? $6 : 1;
    HEAP32[$24>>2] = $26;
    $27 = ((($2)) + 8|0);
    HEAP32[$27>>2] = 12344;
    $28 = HEAP32[$10>>2]|0;
    $29 = ((($28)) + 84|0);
    $30 = HEAP32[$29>>2]|0;
    (FUNCTION_TABLE_ii[$30 & 8191](12448)|0);
    $$sink54 = 12440;
   } else {
    $31 = HEAP32[$10>>2]|0;
    $32 = ((($31)) + 84|0);
    $33 = HEAP32[$32>>2]|0;
    (FUNCTION_TABLE_ii[$33 & 8191](12450)|0);
    $$sink54 = 12344;
   }
   HEAP32[$2>>2] = $$sink54;
   $34 = HEAP32[$10>>2]|0;
   $35 = ((($34)) + 40|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = ((($34)) + 8|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = ((($34)) + 12|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = (FUNCTION_TABLE_iiiii[$36 & 8191]($38,$40,$$049,$2)|0);
   $42 = ($41|0)==(0|0);
   if ($42) {
    (_SDL_SetError(184031,$vararg_buffer1)|0);
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $43 = HEAP32[$10>>2]|0;
   $44 = ((($43)) + 16|0);
   HEAP32[$44>>2] = 0;
   $45 = ($43|0)==(0|0);
   do {
    if ($45) {
     $$sink = 183905;
    } else {
     $46 = ($1|0)==(0|0);
     $47 = ((($43)) + 56|0);
     $48 = HEAP32[$47>>2]|0;
     $49 = ((($43)) + 8|0);
     $50 = HEAP32[$49>>2]|0;
     if ($46) {
      (FUNCTION_TABLE_iiiii[$48 & 8191]($50,0,0,0)|0);
      $$0 = $41;
      STACKTOP = sp;return ($$0|0);
     } else {
      $51 = (FUNCTION_TABLE_iiiii[$48 & 8191]($50,$1,$1,$41)|0);
      $52 = ($51|0)==(0);
      if ($52) {
       $$sink = 183928;
       break;
      } else {
       $$0 = $41;
      }
      STACKTOP = sp;return ($$0|0);
     }
    }
   } while(0);
   $53 = (_SDL_SetError($$sink,$vararg_buffer3)|0);
   $54 = ($53|0)<(0);
   if (!($54)) {
    $$0 = $41;
    STACKTOP = sp;return ($$0|0);
   }
   $55 = HEAP32[$10>>2]|0;
   $56 = ($55|0)==(0|0);
   if (!($56)) {
    $57 = ((($55)) + 56|0);
    $58 = HEAP32[$57>>2]|0;
    $59 = ((($55)) + 8|0);
    $60 = HEAP32[$59>>2]|0;
    (FUNCTION_TABLE_iiiii[$58 & 8191]($60,0,0,0)|0);
    $$pre$i = HEAP32[$10>>2]|0;
    $$phi$trans$insert$i = ((($$pre$i)) + 44|0);
    $$pre10$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $$phi$trans$insert11$i = ((($$pre$i)) + 8|0);
    $$pre12$i = HEAP32[$$phi$trans$insert11$i>>2]|0;
    (FUNCTION_TABLE_iii[$$pre10$i & 8191]($$pre12$i,$41)|0);
   }
   (_SDL_SetError(184060,$vararg_buffer5)|0);
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 (_SDL_SetError(183963,$vararg_buffer)|0);
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _SDL_GL_GetCurrentContext() {
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $0 = HEAP32[52375]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  (_SDL_SetError(175439,$vararg_buffer)|0);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  $2 = ((($0)) + 664|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = (_SDL_TLSGet($3)|0);
  $$0 = $4;
  STACKTOP = sp;return ($$0|0);
 }
 return (0)|0;
}
function _SDL_UnloadObject($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ($0|0)==(0|0);
 if ($1) {
  return;
 }
 (_dlclose(($0|0))|0);
 return;
}
function _SDL_LoadFunction($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$alloca_mul = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $2 = (_dlsym(($0|0),($1|0))|0);
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $$0 = $2;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = (_SDL_strlen($1)|0);
 $5 = (($4) + 2)|0;
 $$alloca_mul = $5;
 $6 = STACKTOP; STACKTOP = STACKTOP + ((((1*$$alloca_mul)|0)+15)&-16)|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(((((1*$$alloca_mul)|0)+15)&-16)|0);;
 HEAP8[$6>>0] = 95;
 $7 = ((($6)) + 1|0);
 (_SDL_strlcpy($7,$1,$5)|0);
 $8 = (_dlsym(($0|0),($6|0))|0);
 $9 = ($8|0)==(0|0);
 if (!($9)) {
  $$0 = $8;
  STACKTOP = sp;return ($$0|0);
 }
 $10 = (_dlerror()|0);
 HEAP32[$vararg_buffer>>2] = $1;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $10;
 (_SDL_SetError(184095,$vararg_buffer)|0);
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _Emscripten_HandleCanvasResize($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0.0, $11 = 0, $12 = 0.0, $13 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp + 8|0;
 $4 = sp;
 $5 = ((($2)) + 24|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  STACKTOP = sp;return 0;
 }
 (_emscripten_get_element_css_size((0|0),($3|0),($4|0))|0);
 $8 = ((($2)) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = +HEAPF64[$3>>3];
 $11 = (~~(($10)));
 $12 = +HEAPF64[$4>>3];
 $13 = (~~(($12)));
 (_SDL_SendWindowEvent($9,5,$11,$13)|0);
 STACKTOP = sp;return 0;
}
function _Emscripten_UnregisterEventHandlers($0) {
 $0 = $0|0;
 var $$ = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (_emscripten_set_mousemove_callback((185668|0),(0|0),0,(0|0))|0);
 (_emscripten_set_mousedown_callback((185668|0),(0|0),0,(0|0))|0);
 (_emscripten_set_mouseup_callback((185676|0),(0|0),0,(0|0))|0);
 (_emscripten_set_mouseenter_callback((185668|0),(0|0),0,(0|0))|0);
 (_emscripten_set_mouseleave_callback((185668|0),(0|0),0,(0|0))|0);
 (_emscripten_set_wheel_callback((185668|0),(0|0),0,(0|0))|0);
 (_emscripten_set_focus_callback((185686|0),(0|0),0,(0|0))|0);
 (_emscripten_set_blur_callback((185686|0),(0|0),0,(0|0))|0);
 (_emscripten_set_touchstart_callback((185668|0),(0|0),0,(0|0))|0);
 (_emscripten_set_touchend_callback((185668|0),(0|0),0,(0|0))|0);
 (_emscripten_set_touchmove_callback((185668|0),(0|0),0,(0|0))|0);
 (_emscripten_set_touchcancel_callback((185668|0),(0|0),0,(0|0))|0);
 $1 = (_SDL_GetHint(185694)|0);
 $2 = ($1|0)!=(0|0);
 $$ = $2 ? $1 : 185686;
 (_emscripten_set_keydown_callback(($$|0),(0|0),0,(0|0))|0);
 (_emscripten_set_keyup_callback(($$|0),(0|0),0,(0|0))|0);
 (_emscripten_set_keypress_callback(($$|0),(0|0),0,(0|0))|0);
 (_emscripten_set_fullscreenchange_callback((185676|0),(0|0),0,(0|0))|0);
 (_emscripten_set_resize_callback((185686|0),(0|0),0,(0|0))|0);
 (_emscripten_set_visibilitychange_callback((0|0),0,(0|0))|0);
 return;
}
function _SDL_EGL_DestroySurface($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 676|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)!=(0|0);
 $5 = ($1|0)!=(0|0);
 $or$cond = $5 & $4;
 if (!($or$cond)) {
  return;
 }
 $6 = ((($3)) + 52|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($3)) + 8|0);
 $9 = HEAP32[$8>>2]|0;
 (FUNCTION_TABLE_iii[$7 & 8191]($9,$1)|0);
 return;
}
function _SDL_GL_LoadLibrary($0) {
 $0 = $0|0;
 var $$06 = 0, $$pre = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $vararg_buffer3 = sp + 16|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $1 = HEAP32[52375]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $3 = (_SDL_SetError(175439,$vararg_buffer)|0);
  $$06 = $3;
  STACKTOP = sp;return ($$06|0);
 }
 $4 = ((($1)) + 388|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 do {
  if ($6) {
   $12 = ((($1)) + 164|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = ($13|0)==(0|0);
   if ($14) {
    $15 = (_SDL_SetError(181719,$vararg_buffer3)|0);
    $$06 = $15;
    STACKTOP = sp;return ($$06|0);
   }
   $16 = (FUNCTION_TABLE_iii[$13 & 8191]($1,$0)|0);
   $17 = ($16|0)==(0);
   $18 = HEAP32[52375]|0;
   if ($17) {
    $20 = $18;
   } else {
    $23 = ((($18)) + 172|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = ($24|0)==(0|0);
    if ($25) {
     $$06 = $16;
     STACKTOP = sp;return ($$06|0);
    }
    FUNCTION_TABLE_vi[$24 & 8191]($18);
    $$06 = $16;
    STACKTOP = sp;return ($$06|0);
   }
  } else {
   $7 = ($0|0)==(0|0);
   if ($7) {
    $20 = $1;
   } else {
    $8 = ((($1)) + 392|0);
    $9 = (_SDL_strcmp($0,$8)|0);
    $10 = ($9|0)==(0);
    if ($10) {
     $$pre = HEAP32[52375]|0;
     $20 = $$pre;
     break;
    }
    $11 = (_SDL_SetError(186029,$vararg_buffer1)|0);
    $$06 = $11;
    STACKTOP = sp;return ($$06|0);
   }
  }
 } while(0);
 $19 = ((($20)) + 388|0);
 $21 = HEAP32[$19>>2]|0;
 $22 = (($21) + 1)|0;
 HEAP32[$19>>2] = $22;
 $$06 = 0;
 STACKTOP = sp;return ($$06|0);
}
function _SDL_EGL_CreateSurface($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_SDL_EGL_ChooseConfig($0)|0);
 $3 = ($2|0)==(0);
 if (!($3)) {
  $$0 = 0;
  return ($$0|0);
 }
 $4 = ((($0)) + 676|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($5)) + 48|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($5)) + 8|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($5)) + 12|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (FUNCTION_TABLE_iiiii[$7 & 8191]($9,$11,$1,0)|0);
 $$0 = $12;
 return ($$0|0);
}
function _SDL_SetKeyboardFocus($0) {
 $0 = $0|0;
 var $$07$i = 0, $$pre = 0, $$pre26 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i = 0, $or$cond = 0, $or$cond25 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[52673]|0;
 $2 = ($1|0)==(0|0);
 $3 = ($0|0)!=(0|0);
 $or$cond = $3 | $2;
 if ($or$cond) {
  $8 = $1;
 } else {
  $$07$i = 0;
  while(1) {
   $4 = (210698 + ($$07$i)|0);
   $5 = HEAP8[$4>>0]|0;
   $6 = ($5<<24>>24)==(1);
   if ($6) {
    (_SDL_SendKeyboardKey(0,$$07$i)|0);
   }
   $7 = (($$07$i) + 1)|0;
   $exitcond$i = ($7|0)==(512);
   if ($exitcond$i) {
    break;
   } else {
    $$07$i = $7;
   }
  }
  $$pre = HEAP32[52673]|0;
  $8 = $$pre;
 }
 $9 = ($8|0)==(0|0);
 $10 = ($8|0)==($0|0);
 $or$cond25 = $9 | $10;
 if (!($or$cond25)) {
  $11 = ((($8)) + 48|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = $12 & 16384;
  $14 = ($13|0)==(0);
  if ($14) {
   $15 = $8;
  } else {
   (_SDL_CaptureMouse(0)|0);
   $$pre26 = HEAP32[52673]|0;
   $15 = $$pre26;
  }
  (_SDL_SendWindowEvent($15,13,0,0)|0);
  $16 = (_SDL_EventState(771,-1)|0);
  $17 = ($16<<24>>24)==(0);
  if (!($17)) {
   $18 = (_SDL_GetVideoDevice()|0);
   $19 = ($18|0)==(0|0);
   if (!($19)) {
    $20 = ((($18)) + 216|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = ($21|0)==(0|0);
    if (!($22)) {
     FUNCTION_TABLE_vi[$21 & 8191]($18);
    }
   }
  }
 }
 HEAP32[52673] = $0;
 if (!($3)) {
  return;
 }
 (_SDL_SendWindowEvent($0,12,0,0)|0);
 $23 = (_SDL_EventState(771,-1)|0);
 $24 = ($23<<24>>24)==(0);
 if ($24) {
  return;
 }
 $25 = (_SDL_GetVideoDevice()|0);
 $26 = ($25|0)==(0|0);
 if ($26) {
  return;
 }
 $27 = ((($25)) + 212|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = ($28|0)==(0|0);
 if ($29) {
  return;
 }
 FUNCTION_TABLE_vi[$28 & 8191]($25);
 return;
}
function _Emscripten_RegisterEventHandlers($0) {
 $0 = $0|0;
 var $$ = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (_emscripten_set_mousemove_callback((185668|0),($0|0),0,(4409|0))|0);
 (_emscripten_set_mousedown_callback((185668|0),($0|0),0,(4410|0))|0);
 (_emscripten_set_mouseup_callback((185676|0),($0|0),0,(4410|0))|0);
 (_emscripten_set_mouseenter_callback((185668|0),($0|0),0,(4411|0))|0);
 (_emscripten_set_mouseleave_callback((185668|0),($0|0),0,(4411|0))|0);
 (_emscripten_set_wheel_callback((185668|0),($0|0),0,(4412|0))|0);
 (_emscripten_set_focus_callback((185686|0),($0|0),0,(4413|0))|0);
 (_emscripten_set_blur_callback((185686|0),($0|0),0,(4413|0))|0);
 (_emscripten_set_touchstart_callback((185668|0),($0|0),0,(4414|0))|0);
 (_emscripten_set_touchend_callback((185668|0),($0|0),0,(4414|0))|0);
 (_emscripten_set_touchmove_callback((185668|0),($0|0),0,(4414|0))|0);
 (_emscripten_set_touchcancel_callback((185668|0),($0|0),0,(4414|0))|0);
 $1 = (_SDL_GetHint(185694)|0);
 $2 = ($1|0)!=(0|0);
 $$ = $2 ? $1 : 185686;
 (_emscripten_set_keydown_callback(($$|0),($0|0),0,(4415|0))|0);
 (_emscripten_set_keyup_callback(($$|0),($0|0),0,(4415|0))|0);
 (_emscripten_set_keypress_callback(($$|0),($0|0),0,(4416|0))|0);
 (_emscripten_set_fullscreenchange_callback((185676|0),($0|0),0,(4417|0))|0);
 (_emscripten_set_resize_callback((185686|0),($0|0),0,(4418|0))|0);
 (_emscripten_set_visibilitychange_callback(($0|0),0,(4419|0))|0);
 return;
}
function _Emscripten_HandleMouseMove($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$030 = 0, $10 = 0.0, $11 = 0.0, $12 = 0.0, $13 = 0, $14 = 0, $15 = 0.0, $16 = 0.0, $17 = 0.0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0.0, $26 = 0.0, $27 = 0.0;
 var $28 = 0.0, $29 = 0, $3 = 0, $30 = 0, $31 = 0.0, $32 = 0.0, $33 = 0.0, $34 = 0.0, $35 = 0, $36 = 0.0, $37 = 0.0, $38 = 0, $39 = 0.0, $4 = 0, $40 = 0.0, $41 = 0, $42 = 0, $43 = 0.0, $44 = 0.0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0.0, $49 = 0.0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 288|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(288|0);
 $3 = sp + 16|0;
 $4 = sp + 8|0;
 $5 = sp;
 (_emscripten_get_element_css_size((0|0),($4|0),($5|0))|0);
 $6 = ((($2)) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($7)) + 24|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (+($9|0));
 $11 = +HEAPF64[$4>>3];
 $12 = $10 / $11;
 $13 = ((($7)) + 28|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (+($14|0));
 $16 = +HEAPF64[$5>>3];
 $17 = $15 / $16;
 $18 = (_emscripten_get_pointerlock_status(($3|0))|0);
 $19 = ($18|0)==(0);
 $20 = HEAP32[$3>>2]|0;
 $21 = $19 ? $20 : 0;
 $22 = ($21|0)==(0);
 if ($22) {
  $41 = ((($1)) + 60|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = (+($42|0));
  $44 = $12 * $43;
  $45 = (~~(($44)));
  $46 = ((($1)) + 64|0);
  $47 = HEAP32[$46>>2]|0;
  $48 = (+($47|0));
  $49 = $17 * $48;
  $50 = (~~(($49)));
  $$0 = $45;$$030 = $50;
  $51 = HEAP32[$6>>2]|0;
  (_SDL_SendMouseMotion($51,0,$21,$$0,$$030)|0);
  STACKTOP = sp;return 0;
 } else {
  $23 = ((($1)) + 44|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = (+($24|0));
  $26 = $12 * $25;
  $27 = +HEAPF64[25876];
  $28 = $27 + $26;
  $29 = ((($1)) + 48|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (+($30|0));
  $32 = $17 * $31;
  $33 = +HEAPF64[25877];
  $34 = $33 + $32;
  $35 = (~~(($28)));
  $36 = (+($35|0));
  $37 = $28 - $36;
  HEAPF64[25876] = $37;
  $38 = (~~(($34)));
  $39 = (+($38|0));
  $40 = $34 - $39;
  HEAPF64[25877] = $40;
  $$0 = $35;$$030 = $38;
  $51 = HEAP32[$6>>2]|0;
  (_SDL_SendMouseMotion($51,0,$21,$$0,$$030)|0);
  STACKTOP = sp;return 0;
 }
 return (0)|0;
}
function _Emscripten_HandleMouseButton($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $switch$idx$cast = 0, $switch$offset = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($1)) + 40|0);
 $4 = HEAP16[$3>>1]|0;
 $5 = ($4&65535)<(3);
 if (!($5)) {
  $$0 = 0;
  return ($$0|0);
 }
 $switch$idx$cast = $4&255;
 $switch$offset = (($switch$idx$cast) + 1)<<24>>24;
 $6 = ($0|0)==(5);
 $7 = $6&1;
 $8 = ((($2)) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $6&1;
 (_SDL_SendMouseButton($9,0,$10,$switch$offset)|0);
 $11 = (_SDL_EventState($7,-1)|0);
 $12 = ($11<<24>>24)==(1);
 $13 = $12&1;
 $$0 = $13;
 return ($$0|0);
}
function _Emscripten_HandleMouseFocus($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0.0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0.0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0, $24 = 0.0, $25 = 0, $26 = 0, $27 = 0.0, $28 = 0.0, $29 = 0.0;
 var $3 = 0, $30 = 0.0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $not$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 288|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(288|0);
 $3 = sp + 16|0;
 $4 = sp + 8|0;
 $5 = sp;
 $6 = ((($1)) + 60|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($1)) + 64|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (_emscripten_get_pointerlock_status(($3|0))|0);
 $11 = HEAP32[$3>>2]|0;
 $12 = ($11|0)==(0);
 $not$ = ($10|0)!=(0);
 $13 = $12 | $not$;
 if ($13) {
  (_emscripten_get_element_css_size((0|0),($4|0),($5|0))|0);
  $14 = (+($7|0));
  $15 = ((($2)) + 4|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ((($16)) + 24|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (+($18|0));
  $20 = +HEAPF64[$4>>3];
  $21 = $19 / $20;
  $22 = $14 * $21;
  $23 = (~~(($22)));
  $24 = (+($9|0));
  $25 = ((($16)) + 28|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (+($26|0));
  $28 = +HEAPF64[$5>>3];
  $29 = $27 / $28;
  $30 = $24 * $29;
  $31 = (~~(($30)));
  (_SDL_SendMouseMotion($16,0,0,$23,$31)|0);
 }
 $32 = ($0|0)==(33);
 if (!($32)) {
  $35 = 0;
  _SDL_SetMouseFocus($35);
  $36 = (_SDL_EventState(512,-1)|0);
  $37 = ($36<<24>>24)==(1);
  $38 = $37&1;
  STACKTOP = sp;return ($38|0);
 }
 $33 = ((($2)) + 4|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = $34;
 _SDL_SetMouseFocus($35);
 $36 = (_SDL_EventState(512,-1)|0);
 $37 = ($36<<24>>24)==(1);
 $38 = $37&1;
 STACKTOP = sp;return ($38|0);
}
function _Emscripten_HandleWheel($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0.0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0.0, $7 = 0, $8 = 0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($2)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($1)) + 72|0);
 $6 = +HEAPF64[$5>>3];
 $7 = (~~(($6)));
 $8 = ((($1)) + 80|0);
 $9 = +HEAPF64[$8>>3];
 $10 = -$9;
 $11 = (~~(($10)));
 (_SDL_SendMouseWheel($4,0,$7,$11,0)|0);
 $12 = (_SDL_EventState(1027,-1)|0);
 $13 = ($12<<24>>24)==(1);
 $14 = $13&1;
 return ($14|0);
}
function _Emscripten_HandleFocus($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($0|0)==(12);
 if ($3) {
  _SDL_ResetKeyboard();
 }
 $4 = ((($2)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($0|0)==(13);
 $7 = $6 ? 12 : 13;
 (_SDL_SendWindowEvent($5,$7,0,0)|0);
 $8 = (_SDL_EventState(512,-1)|0);
 $9 = ($8<<24>>24)==(1);
 $10 = $9&1;
 return ($10|0);
}
function _Emscripten_HandleTouch($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$$064 = 0, $$$06466 = 0, $$$06467 = 0, $$0 = 0, $$06369 = 0, $$06468 = 0, $$2 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0.0, $22 = 0.0;
 var $23 = 0.0, $24 = 0.0, $25 = 0, $26 = 0, $27 = 0.0, $28 = 0.0, $29 = 0.0, $3 = 0, $30 = 0.0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp + 8|0;
 $4 = sp;
 $5 = (_SDL_AddTouch(1,0,221531)|0);
 $6 = ($5|0)<(0);
 if ($6) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 (_emscripten_get_element_css_size((0|0),($3|0),($4|0))|0);
 $7 = HEAP32[$1>>2]|0;
 $8 = ($7|0)>(0);
 if (!($8)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $9 = ((($2)) + 28|0);
 $10 = ((($2)) + 32|0);
 $11 = ((($2)) + 4|0);
 $$06369 = 0;$$06468 = 0;
 while(1) {
  $12 = (((((($1)) + 20|0) + (($$06369*52)|0)|0)) + 28|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($13|0)==(0);
  L9: do {
   if ($14) {
    $$2 = $$06468;
   } else {
    $15 = (((($1)) + 20|0) + (($$06369*52)|0)|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = ($16|0)<(0);
    $18 = $17 << 31 >> 31;
    $19 = (((((($1)) + 20|0) + (($$06369*52)|0)|0)) + 44|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = (+($20|0));
    $22 = +HEAPF64[$3>>3];
    $23 = $21 / $22;
    $24 = $23;
    $25 = (((((($1)) + 20|0) + (($$06369*52)|0)|0)) + 48|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = (+($26|0));
    $28 = +HEAPF64[$4>>3];
    $29 = $27 / $28;
    $30 = $29;
    $31 = HEAP32[$9>>2]|0;
    $32 = ($31|0)!=(0);
    switch ($0|0) {
    case 22:  {
     if (!($32)) {
      HEAP32[$9>>2] = 1;
      $33 = $10;
      $34 = $33;
      HEAP32[$34>>2] = $16;
      $35 = (($33) + 4)|0;
      $36 = $35;
      HEAP32[$36>>2] = $18;
      $37 = HEAP32[$11>>2]|0;
      $38 = (~~(($24)));
      $39 = (~~(($30)));
      (_SDL_SendMouseMotion($37,-1,0,$38,$39)|0);
      $40 = HEAP32[$11>>2]|0;
      (_SDL_SendMouseButton($40,-1,1,1)|0);
     }
     (_SDL_SendTouch(1,0,$16,$18,1,$24,$30,1.0)|0);
     $41 = ($$06468|0)==(0);
     if (!($41)) {
      $$2 = $$06468;
      break L9;
     }
     $42 = (_SDL_EventState(1792,-1)|0);
     $43 = ($42<<24>>24)==(1);
     $$$064 = $43&1;
     $$2 = $$$064;
     break L9;
     break;
    }
    case 24:  {
     if ($32) {
      $44 = $10;
      $45 = $44;
      $46 = HEAP32[$45>>2]|0;
      $47 = (($44) + 4)|0;
      $48 = $47;
      $49 = HEAP32[$48>>2]|0;
      $50 = ($46|0)==($16|0);
      $51 = ($49|0)==($18|0);
      $52 = $50 & $51;
      if ($52) {
       $53 = (~~(($30)));
       $54 = (~~(($24)));
       $55 = HEAP32[$11>>2]|0;
       (_SDL_SendMouseMotion($55,-1,0,$54,$53)|0);
      }
     }
     (_SDL_SendTouchMotion(1,0,$16,$18,$24,$30,1.0)|0);
     $56 = ($$06468|0)==(0);
     if (!($56)) {
      $$2 = $$06468;
      break L9;
     }
     $57 = (_SDL_EventState(1794,-1)|0);
     $58 = ($57<<24>>24)==(1);
     $$$06466 = $58&1;
     $$2 = $$$06466;
     break L9;
     break;
    }
    default: {
     if ($32) {
      $59 = $10;
      $60 = $59;
      $61 = HEAP32[$60>>2]|0;
      $62 = (($59) + 4)|0;
      $63 = $62;
      $64 = HEAP32[$63>>2]|0;
      $65 = ($61|0)==($16|0);
      $66 = ($64|0)==($18|0);
      $67 = $65 & $66;
      if ($67) {
       $68 = HEAP32[$11>>2]|0;
       (_SDL_SendMouseButton($68,-1,0,1)|0);
       HEAP32[$9>>2] = 0;
      }
     }
     (_SDL_SendTouch(1,0,$16,$18,0,$24,$30,1.0)|0);
     $69 = ($$06468|0)==(0);
     if (!($69)) {
      $$2 = $$06468;
      break L9;
     }
     $70 = (_SDL_EventState(1793,-1)|0);
     $71 = ($70<<24>>24)==(1);
     $$$06467 = $71&1;
     $$2 = $$$06467;
     break L9;
    }
    }
   }
  } while(0);
  $72 = (($$06369) + 1)|0;
  $73 = HEAP32[$1>>2]|0;
  $74 = ($72|0)<($73|0);
  if ($74) {
   $$06369 = $72;$$06468 = $$2;
  } else {
   $$0 = $$2;
   break;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function _Emscripten_HandleKey($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$ = 0, $$014 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $narrow = 0, $switch = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($1)) + 156|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4>>>0)<(223);
 if ($5) {
  $6 = (88764 + ($4<<2)|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)==(0);
  if (!($8)) {
   $9 = ((($1)) + 64|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($10|0)==(2);
   L4: do {
    if ($11) {
     switch ($7|0) {
     case 225:  {
      $$014 = 229;
      break L4;
      break;
     }
     case 224:  {
      $$014 = 228;
      break L4;
      break;
     }
     case 226:  {
      $$014 = 230;
      break L4;
      break;
     }
     case 227:  {
      $$014 = 231;
      break L4;
      break;
     }
     default: {
      $$014 = $7;
      break L4;
     }
     }
    } else {
     $$014 = $7;
    }
   } while(0);
   $12 = ($0|0)==(2);
   $13 = $12&1;
   (_SDL_SendKeyboardKey($13,$$014)|0);
  }
 }
 $14 = ($0|0)==(2);
 $15 = $14 ? 768 : 769;
 $16 = (_SDL_EventState($15,-1)|0);
 $17 = ($16<<24>>24)==(1);
 $18 = $17&1;
 if (!($14)) {
  return ($18|0);
 }
 $19 = (_SDL_EventState(771,-1)|0);
 $20 = ($19<<24>>24)==(1);
 if ($20) {
  $21 = HEAP32[$3>>2]|0;
  $22 = $21 & -2;
  $switch = ($22|0)==(8);
  $narrow = $17 & $switch;
  $$ = $narrow&1;
  return ($$|0);
 } else {
  return ($18|0);
 }
 return (0)|0;
}
function _Emscripten_HandleKeyPress($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$sink25$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = ((($1)) + 152|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5>>>0)<(128);
 do {
  if ($6) {
   $7 = $5&255;
   HEAP8[$3>>0] = $7;
   $$sink25$i = 1;
  } else {
   $8 = ($5>>>0)<(2048);
   if ($8) {
    $9 = $5 >>> 6;
    $10 = $9 & 31;
    $11 = $10 | 192;
    $12 = $11&255;
    HEAP8[$3>>0] = $12;
    $13 = $5 & 63;
    $14 = $13 | 128;
    $15 = $14&255;
    $16 = ((($3)) + 1|0);
    HEAP8[$16>>0] = $15;
    $$sink25$i = 2;
    break;
   }
   $17 = ($5>>>0)<(65536);
   if ($17) {
    $18 = $5 >>> 12;
    $19 = $18 & 15;
    $20 = $19 | 224;
    $21 = $20&255;
    HEAP8[$3>>0] = $21;
    $22 = $5 >>> 6;
    $23 = $22 & 63;
    $24 = $23 | 128;
    $25 = $24&255;
    $26 = ((($3)) + 1|0);
    HEAP8[$26>>0] = $25;
    $27 = $5 & 63;
    $28 = $27 | 128;
    $29 = $28&255;
    $30 = ((($3)) + 2|0);
    HEAP8[$30>>0] = $29;
    $$sink25$i = 3;
    break;
   }
   $31 = ($5>>>0)<(1114112);
   if ($31) {
    $32 = $5 >>> 18;
    $33 = $32 | 240;
    $34 = $33&255;
    HEAP8[$3>>0] = $34;
    $35 = $5 >>> 12;
    $36 = $35 & 63;
    $37 = $36 | 128;
    $38 = $37&255;
    $39 = ((($3)) + 1|0);
    HEAP8[$39>>0] = $38;
    $40 = $5 >>> 6;
    $41 = $40 & 63;
    $42 = $41 | 128;
    $43 = $42&255;
    $44 = ((($3)) + 2|0);
    HEAP8[$44>>0] = $43;
    $45 = $5 & 63;
    $46 = $45 | 128;
    $47 = $46&255;
    $48 = ((($3)) + 3|0);
    HEAP8[$48>>0] = $47;
    $$sink25$i = 4;
    break;
   } else {
    $50 = (_SDL_EventState(771,-1)|0);
    $51 = ($50<<24>>24)==(1);
    $52 = $51&1;
    STACKTOP = sp;return ($52|0);
   }
  }
 } while(0);
 $49 = (($3) + ($$sink25$i)|0);
 HEAP8[$49>>0] = 0;
 (_SDL_SendKeyboardText($3)|0);
 $50 = (_SDL_EventState(771,-1)|0);
 $51 = ($50<<24>>24)==(1);
 $52 = $51&1;
 STACKTOP = sp;return ($52|0);
}
function _Emscripten_HandleFullscreenChange($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = HEAP32[$1>>2]|0;
 $4 = ($3|0)==(0);
 $5 = ((($2)) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 if ($4) {
  $13 = ((($6)) + 48|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = $14 & -4098;
  HEAP32[$13>>2] = $15;
  return 0;
 } else {
  $7 = ((($2)) + 20|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ((($6)) + 48|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = $10 | $8;
  HEAP32[$7>>2] = 0;
  $12 = $11 | 1;
  HEAP32[$9>>2] = $12;
  return 0;
 }
 return (0)|0;
}
function _Emscripten_HandleResize($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$phi$trans$insert = 0, $$pre = 0, $$pre15 = 0, $$pre16 = 0.0, $$pre17 = 0.0, $10 = 0, $11 = 0.0, $12 = 0.0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0.0, $21 = 0, $22 = 0, $23 = 0.0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0.0, $29 = 0.0, $3 = 0, $30 = 0.0, $31 = 0.0, $32 = 0, $33 = 0.0, $34 = 0.0, $35 = 0, $36 = 0, $37 = 0, $38 = 0.0, $39 = 0, $4 = 0, $40 = 0.0, $41 = 0.0, $42 = 0;
 var $43 = 0.0, $44 = 0, $45 = 0.0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp + 8|0;
 $4 = sp;
 $5 = ((($2)) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($6)) + 48|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 & 8192;
 $10 = ($9|0)==(0);
 if ($10) {
  $15 = $8;$18 = $6;
 } else {
  $11 = (+_emscripten_get_device_pixel_ratio());
  $12 = $11;
  $13 = ((($2)) + 12|0);
  HEAPF32[$13>>2] = $12;
  $$pre = HEAP32[$5>>2]|0;
  $$phi$trans$insert = ((($$pre)) + 48|0);
  $$pre15 = HEAP32[$$phi$trans$insert>>2]|0;
  $15 = $$pre15;$18 = $$pre;
 }
 $14 = $15 & 4129;
 $16 = ($14|0)==(32);
 if (!($16)) {
  STACKTOP = sp;return 0;
 }
 $17 = ((($18)) + 24|0);
 $19 = HEAP32[$17>>2]|0;
 $20 = (+($19|0));
 HEAPF64[$3>>3] = $20;
 $21 = ((($18)) + 28|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (+($22|0));
 HEAPF64[$4>>3] = $23;
 $24 = ((($2)) + 16|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)==(0);
 if ($26) {
  $31 = $20;$34 = $23;
 } else {
  (_emscripten_get_element_css_size((0|0),($3|0),($4|0))|0);
  $$pre16 = +HEAPF64[$3>>3];
  $$pre17 = +HEAPF64[$4>>3];
  $31 = $$pre16;$34 = $$pre17;
 }
 $27 = ((($2)) + 12|0);
 $28 = +HEAPF32[$27>>2];
 $29 = $28;
 $30 = $31 * $29;
 $32 = (~~(($30)));
 $33 = $34 * $29;
 $35 = (~~(($33)));
 _emscripten_set_canvas_size(($32|0),($35|0));
 $36 = HEAP32[$24>>2]|0;
 $37 = ($36|0)==(0);
 if ($37) {
  $38 = +HEAPF32[$27>>2];
  $39 = $38 != 1.0;
  if ($39) {
   $40 = +HEAPF64[$3>>3];
   $41 = +HEAPF64[$4>>3];
   (_emscripten_set_element_css_size((0|0),(+$40),(+$41))|0);
  }
 }
 $42 = HEAP32[$5>>2]|0;
 $43 = +HEAPF64[$3>>3];
 $44 = (~~(($43)));
 $45 = +HEAPF64[$4>>3];
 $46 = (~~(($45)));
 (_SDL_SendWindowEvent($42,5,$44,$46)|0);
 STACKTOP = sp;return 0;
}
function _Emscripten_HandleVisibilityChange($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($2)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$1>>2]|0;
 $6 = ($5|0)!=(0);
 $7 = $6 ? 2 : 1;
 (_SDL_SendWindowEvent($4,$7,0,0)|0);
 return 0;
}
function _SDL_SendKeyboardText($0) {
 $0 = $0|0;
 var $$09 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(64|0);
 $1 = sp;
 $2 = HEAP8[$0>>0]|0;
 $3 = ($2&255)<(32);
 $4 = ($2<<24>>24)==(127);
 $or$cond = $3 | $4;
 if ($or$cond) {
  $$09 = 0;
  STACKTOP = sp;return ($$09|0);
 }
 $5 = (_SDL_EventState(771,-1)|0);
 $6 = ($5<<24>>24)==(1);
 if (!($6)) {
  $$09 = 0;
  STACKTOP = sp;return ($$09|0);
 }
 HEAP32[$1>>2] = 771;
 $7 = HEAP32[52673]|0;
 $8 = ($7|0)==(0|0);
 if ($8) {
  $12 = 0;
 } else {
  $9 = ((($7)) + 4|0);
  $10 = HEAP32[$9>>2]|0;
  $12 = $10;
 }
 $11 = ((($1)) + 8|0);
 HEAP32[$11>>2] = $12;
 $13 = ((($1)) + 12|0);
 (_SDL_utf8strlcpy($13,$0,32)|0);
 $14 = (_SDL_PushEvent($1)|0);
 $15 = ($14|0)>(0);
 $16 = $15&1;
 $$09 = $16;
 STACKTOP = sp;return ($$09|0);
}
function _SDL_utf8strlcpy($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$$0 = 0, $$034 = 0, $$037$lcssa = 0, $$03742 = 0, $$1 = 0, $$off = 0, $$off$i = 0, $$ph = 0, $$phi$trans$insert = 0, $$pre = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $notlhs = 0, $notrhs = 0, $or$cond = 0, $or$cond35$not = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (_strlen($1)|0);
 $4 = (($2) + -1)|0;
 $5 = ($3>>>0)<($4>>>0);
 $6 = $5 ? $3 : $4;
 $7 = ($6|0)==(0);
 if ($7) {
  $$1 = 0;
  $25 = (($0) + ($$1)|0);
  HEAP8[$25>>0] = 0;
  return ($$1|0);
 }
 $8 = (($6) + -1)|0;
 $9 = (($1) + ($8)|0);
 $10 = HEAP8[$9>>0]|0;
 $$off = (($10) + 64)<<24>>24;
 $11 = ($$off&255)<(53);
 L4: do {
  if ($11) {
   $$034 = $8;
  } else {
   $notlhs = ($10<<24>>24)>(-1);
   $notrhs = ($10&255)>(191);
   $or$cond35$not = $notrhs | $notlhs;
   $12 = ($8|0)==(0);
   $or$cond = $or$cond35$not | $12;
   if ($or$cond) {
    $$034 = $6;
   } else {
    $13 = $10 & -32;
    $14 = ($13<<24>>24)==(-64);
    L7: do {
     if ($14) {
      $$037$lcssa = $8;$$ph = 2;
     } else {
      $$03742 = $8;$16 = $10;
      while(1) {
       $15 = $16 & -16;
       $17 = ($15<<24>>24)==(-32);
       if ($17) {
        $$037$lcssa = $$03742;$$ph = 3;
        break L7;
       }
       $$off$i = (($16) + 16)<<24>>24;
       $18 = ($$off$i&255)<(5);
       if ($18) {
        $$037$lcssa = $$03742;$$ph = 4;
        break L7;
       }
       $21 = (($$03742) + -1)|0;
       $22 = ($21|0)==(0);
       if ($22) {
        $$034 = $6;
        break L4;
       }
       $$phi$trans$insert = (($1) + ($21)|0);
       $$pre = HEAP8[$$phi$trans$insert>>0]|0;
       $23 = $$pre & -32;
       $24 = ($23<<24>>24)==(-64);
       if ($24) {
        $$037$lcssa = $21;$$ph = 2;
        break;
       } else {
        $$03742 = $21;$16 = $$pre;
       }
      }
     }
    } while(0);
    $19 = (($6) - ($$037$lcssa))|0;
    $20 = ($19|0)==($$ph|0);
    $$$0 = $20 ? $6 : $$037$lcssa;
    $$034 = $$$0;
   }
  }
 } while(0);
 _memcpy(($0|0),($1|0),($$034|0))|0;
 $$1 = $$034;
 $25 = (($0) + ($$1)|0);
 HEAP8[$25>>0] = 0;
 return ($$1|0);
}
function _SDL_SendKeyboardKey($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$049 = 0, $$050 = 0, $$052 = 0, $$sink3 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $narrow = 0, $not$ = 0, $or$cond = 0, $storemerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(64|0);
 $2 = sp;
 $3 = ($1|0)==(0);
 if ($3) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 switch ($0<<24>>24) {
 case 1:  {
  $$049 = 768;
  break;
 }
 case 0:  {
  $$049 = 769;
  break;
 }
 default: {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 }
 $4 = (210698 + ($1)|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)!=(0);
 $not$ = ($0<<24>>24)!=(0);
 $narrow = $not$ & $6;
 $7 = $narrow&1;
 $8 = ($5<<24>>24)!=($0<<24>>24);
 $or$cond = $8 | $narrow;
 if (!($or$cond)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP8[$4>>0] = $0;
 $9 = (211212 + ($1<<2)|0);
 $10 = HEAP32[$9>>2]|0;
 switch ($10|0) {
 case 1073742048:  {
  $$052 = 64;
  break;
 }
 case 1073742052:  {
  $$052 = 128;
  break;
 }
 case 1073742049:  {
  $$052 = 1;
  break;
 }
 case 1073742053:  {
  $$052 = 2;
  break;
 }
 case 1073742050:  {
  $$052 = 256;
  break;
 }
 case 1073742054:  {
  $$052 = 512;
  break;
 }
 case 1073742051:  {
  $$052 = 1024;
  break;
 }
 case 1073742055:  {
  $$052 = 2048;
  break;
 }
 case 1073742081:  {
  $$052 = 16384;
  break;
 }
 default: {
  $$052 = 0;
 }
 }
 $11 = ($$049|0)==(768);
 $12 = HEAP16[(210696)>>1]|0;
 if ($11) {
  switch ($10|0) {
  case 1073741907:  {
   $13 = $12 ^ 4096;
   $14 = $13&65535;
   $$sink3 = $14;
   break;
  }
  case 1073741881:  {
   $15 = $12 ^ 8192;
   $16 = $15&65535;
   $$sink3 = $16;
   break;
  }
  default: {
   $17 = $12&65535;
   $18 = $17 | $$052;
   $$sink3 = $18;
  }
  }
  $19 = $$sink3&65535;
  $$050 = $12;$storemerge = $19;
 } else {
  $20 = $$052 ^ 65535;
  $21 = $12&65535;
  $22 = $21 & $20;
  $23 = $22&65535;
  $$050 = $23;$storemerge = $23;
 }
 HEAP16[(210696)>>1] = $storemerge;
 $24 = (_SDL_EventState($$049,-1)|0);
 $25 = ($24<<24>>24)==(1);
 if (!($25)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$2>>2] = $$049;
 $26 = ((($2)) + 12|0);
 HEAP8[$26>>0] = $0;
 $27 = ((($2)) + 13|0);
 HEAP8[$27>>0] = $7;
 $28 = ((($2)) + 16|0);
 HEAP32[$28>>2] = $1;
 $29 = ((($28)) + 4|0);
 HEAP32[$29>>2] = $10;
 $30 = ((($28)) + 8|0);
 HEAP16[$30>>1] = $$050;
 $31 = HEAP32[52673]|0;
 $32 = ($31|0)==(0|0);
 if ($32) {
  $36 = 0;
 } else {
  $33 = ((($31)) + 4|0);
  $34 = HEAP32[$33>>2]|0;
  $36 = $34;
 }
 $35 = ((($2)) + 8|0);
 HEAP32[$35>>2] = $36;
 $37 = (_SDL_PushEvent($2)|0);
 $38 = ($37|0)>(0);
 $39 = $38&1;
 $$0 = $39;
 STACKTOP = sp;return ($$0|0);
}
function _SDL_AddTouch($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$089$i = 0, $$pre = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = HEAP32[53315]|0;
 $4 = ($3|0)>(0);
 L1: do {
  if ($4) {
   $5 = HEAP32[53316]|0;
   $$089$i = 0;
   while(1) {
    $6 = (($5) + ($$089$i<<2)|0);
    $7 = HEAP32[$6>>2]|0;
    $8 = $7;
    $9 = $8;
    $10 = HEAP32[$9>>2]|0;
    $11 = (($8) + 4)|0;
    $12 = $11;
    $13 = HEAP32[$12>>2]|0;
    $14 = ($10|0)==($0|0);
    $15 = ($13|0)==($1|0);
    $16 = $14 & $15;
    if ($16) {
     break;
    }
    $17 = (($$089$i) + 1)|0;
    $18 = ($17|0)<($3|0);
    if ($18) {
     $$089$i = $17;
    } else {
     $22 = $5;
     break L1;
    }
   }
   $19 = ($$089$i|0)>(-1);
   if ($19) {
    $$0 = $$089$i;
    return ($$0|0);
   } else {
    $22 = $5;
   }
  } else {
   $$pre = HEAP32[53316]|0;
   $22 = $$pre;
  }
 } while(0);
 $20 = $3 << 2;
 $21 = (($20) + 4)|0;
 $23 = (_SDL_realloc($22,$21)|0);
 $24 = ($23|0)==(0|0);
 if ($24) {
  $25 = (_SDL_Error(0)|0);
  $$0 = $25;
  return ($$0|0);
 }
 HEAP32[53316] = $23;
 $26 = HEAP32[53315]|0;
 $27 = (_SDL_malloc(24)|0);
 $28 = HEAP32[53316]|0;
 $29 = (($28) + ($26<<2)|0);
 HEAP32[$29>>2] = $27;
 $30 = ($27|0)==(0|0);
 if ($30) {
  $31 = (_SDL_Error(0)|0);
  $$0 = $31;
  return ($$0|0);
 } else {
  $32 = HEAP32[53315]|0;
  $33 = (($32) + 1)|0;
  HEAP32[53315] = $33;
  $34 = $27;
  $35 = $34;
  HEAP32[$35>>2] = $0;
  $36 = (($34) + 4)|0;
  $37 = $36;
  HEAP32[$37>>2] = $1;
  $38 = ((($27)) + 8|0);
  HEAP32[$38>>2] = 0;
  $39 = ((($27)) + 12|0);
  HEAP32[$39>>2] = 0;
  $40 = ((($27)) + 16|0);
  HEAP32[$40>>2] = 0;
  (_SDL_GestureAddTouch($0,$1)|0);
  $$0 = $26;
  return ($$0|0);
 }
 return (0)|0;
}
function _SDL_SendMouseMotion($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$1 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $not$ = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = ($0|0)==(0|0);
 $6 = ($2|0)!=(0);
 $or$cond = $5 | $6;
 if (!($or$cond)) {
  $7 = (_SDL_UpdateMouseFocus($0,$3,$4)|0);
  $not$ = ($7|0)==(0);
  if ($not$) {
   $$1 = 0;
   return ($$1|0);
  }
 }
 $8 = (_SDL_PrivateSendMouseMotion($0,$1,$2,$3,$4)|0);
 $$1 = $8;
 return ($$1|0);
}
function _SDL_SendMouseButton($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = (_SDL_PrivateSendMouseButton($0,$1,$2,$3,-1)|0);
 return ($4|0);
}
function _SDL_SendTouch($0,$1,$2,$3,$4,$5,$6,$7) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = +$5;
 $6 = +$6;
 $7 = +$7;
 var $$0 = 0, $$029 = 0, $$08$i$i = 0, $$08$i$i33 = 0, $$089$i$i = 0, $$lcssa$$i = 0, $$pre$i = 0, $$pre27$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond$i = 0, $or$cond$i31 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(128|0);
 $vararg_buffer = sp + 112|0;
 $8 = sp + 56|0;
 $9 = sp;
 $10 = HEAP32[53315]|0;
 $11 = ($10|0)>(0);
 L1: do {
  if ($11) {
   $12 = HEAP32[53316]|0;
   $$089$i$i = 0;
   while(1) {
    $13 = (($12) + ($$089$i$i<<2)|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = $14;
    $16 = $15;
    $17 = HEAP32[$16>>2]|0;
    $18 = (($15) + 4)|0;
    $19 = $18;
    $20 = HEAP32[$19>>2]|0;
    $21 = ($17|0)==($0|0);
    $22 = ($20|0)==($1|0);
    $23 = $21 & $22;
    if ($23) {
     break;
    }
    $24 = (($$089$i$i) + 1)|0;
    $25 = ($24|0)<($10|0);
    if ($25) {
     $$089$i$i = $24;
    } else {
     break L1;
    }
   }
   $26 = ($$089$i$i|0)>(-1);
   $27 = ($$089$i$i|0)<($10|0);
   $or$cond$i = $26 & $27;
   if ($or$cond$i) {
    $28 = ($14|0)==(0|0);
    if ($28) {
     $$0 = -1;
     STACKTOP = sp;return ($$0|0);
    }
    $29 = ((($14)) + 8|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = ($30|0)>(0);
    L11: do {
     if ($31) {
      $32 = ((($14)) + 16|0);
      $33 = HEAP32[$32>>2]|0;
      $$08$i$i = 0;
      while(1) {
       $34 = (($33) + ($$08$i$i<<2)|0);
       $35 = HEAP32[$34>>2]|0;
       $36 = $35;
       $37 = $36;
       $38 = HEAP32[$37>>2]|0;
       $39 = (($36) + 4)|0;
       $40 = $39;
       $41 = HEAP32[$40>>2]|0;
       $42 = ($38|0)==($2|0);
       $43 = ($41|0)==($3|0);
       $44 = $42 & $43;
       if ($44) {
        break;
       }
       $45 = (($$08$i$i) + 1)|0;
       $46 = ($45|0)<($30|0);
       if ($46) {
        $$08$i$i = $45;
       } else {
        $50 = 0;
        break L11;
       }
      }
      $47 = ($$08$i$i|0)>(-1);
      $48 = ($$08$i$i|0)<($30|0);
      $or$cond$i31 = $47 & $48;
      $$lcssa$$i = $or$cond$i31 ? $35 : 0;
      $50 = $$lcssa$$i;
     } else {
      $50 = 0;
     }
    } while(0);
    $49 = ($4|0)==(0);
    $51 = ($50|0)!=(0|0);
    if ($49) {
     if (!($51)) {
      $$0 = 0;
      STACKTOP = sp;return ($$0|0);
     }
     $104 = (_SDL_EventState(1793,-1)|0);
     $105 = ($104<<24>>24)==(1);
     if ($105) {
      HEAP32[$9>>2] = 1793;
      $106 = ((($9)) + 8|0);
      $107 = $106;
      $108 = $107;
      HEAP32[$108>>2] = $0;
      $109 = (($107) + 4)|0;
      $110 = $109;
      HEAP32[$110>>2] = $1;
      $111 = ((($9)) + 16|0);
      $112 = $111;
      $113 = $112;
      HEAP32[$113>>2] = $2;
      $114 = (($112) + 4)|0;
      $115 = $114;
      HEAP32[$115>>2] = $3;
      $116 = ((($50)) + 8|0);
      $117 = HEAP32[$116>>2]|0;
      $118 = ((($9)) + 24|0);
      HEAP32[$118>>2] = $117;
      $119 = ((($50)) + 12|0);
      $120 = HEAP32[$119>>2]|0;
      $121 = ((($9)) + 28|0);
      HEAP32[$121>>2] = $120;
      $122 = ((($9)) + 32|0);
      HEAPF32[$122>>2] = 0.0;
      $123 = ((($9)) + 36|0);
      HEAPF32[$123>>2] = 0.0;
      $124 = ((($9)) + 40|0);
      HEAPF32[$124>>2] = $7;
      $125 = (_SDL_PushEvent($9)|0);
      $126 = ($125|0)>(0);
      $127 = $126&1;
      $$029 = $127;
     } else {
      $$029 = 0;
     }
     $128 = HEAP32[$29>>2]|0;
     $129 = ($128|0)>(0);
     if (!($129)) {
      $$0 = $$029;
      STACKTOP = sp;return ($$0|0);
     }
     $130 = ((($14)) + 16|0);
     $131 = HEAP32[$130>>2]|0;
     $$08$i$i33 = 0;
     while(1) {
      $132 = (($131) + ($$08$i$i33<<2)|0);
      $133 = HEAP32[$132>>2]|0;
      $134 = $133;
      $135 = $134;
      $136 = HEAP32[$135>>2]|0;
      $137 = (($134) + 4)|0;
      $138 = $137;
      $139 = HEAP32[$138>>2]|0;
      $140 = ($136|0)==($2|0);
      $141 = ($139|0)==($3|0);
      $142 = $140 & $141;
      if ($142) {
       break;
      }
      $143 = (($$08$i$i33) + 1)|0;
      $144 = ($143|0)<($128|0);
      if ($144) {
       $$08$i$i33 = $143;
      } else {
       $$0 = $$029;
       label = 33;
       break;
      }
     }
     if ((label|0) == 33) {
      STACKTOP = sp;return ($$0|0);
     }
     $145 = ($$08$i$i33|0)<(0);
     if ($145) {
      $$0 = $$029;
      STACKTOP = sp;return ($$0|0);
     }
     $146 = $133;
     $147 = (($128) + -1)|0;
     HEAP32[$29>>2] = $147;
     $148 = (($131) + ($147<<2)|0);
     $149 = HEAP32[$148>>2]|0;
     HEAP32[$132>>2] = $149;
     $150 = HEAP32[$130>>2]|0;
     $151 = (($150) + ($147<<2)|0);
     HEAP32[$151>>2] = $146;
     $$0 = $$029;
     STACKTOP = sp;return ($$0|0);
    } else {
     if ($51) {
      $$0 = 0;
      STACKTOP = sp;return ($$0|0);
     }
     $52 = ((($14)) + 12|0);
     $53 = HEAP32[$52>>2]|0;
     $54 = ($30|0)==($53|0);
     $55 = ((($14)) + 16|0);
     do {
      if ($54) {
       $56 = HEAP32[$55>>2]|0;
       $57 = $30 << 2;
       $58 = (($57) + 4)|0;
       $59 = (_SDL_realloc($56,$58)|0);
       $60 = ($59|0)==(0|0);
       if (!($60)) {
        HEAP32[$55>>2] = $59;
        $61 = (_SDL_malloc(24)|0);
        $62 = HEAP32[$55>>2]|0;
        $63 = HEAP32[$52>>2]|0;
        $64 = (($62) + ($63<<2)|0);
        HEAP32[$64>>2] = $61;
        $65 = HEAP32[$55>>2]|0;
        $66 = (($65) + ($63<<2)|0);
        $67 = HEAP32[$66>>2]|0;
        $68 = ($67|0)==(0|0);
        if (!($68)) {
         $69 = (($63) + 1)|0;
         HEAP32[$52>>2] = $69;
         $$pre27$i = HEAP32[$29>>2]|0;
         $71 = $$pre27$i;$73 = $65;
         label = 20;
         break;
        }
       }
       $82 = (_SDL_Error(0)|0);
       $83 = ($82|0)<(0);
       if ($83) {
        $$0 = 0;
        STACKTOP = sp;return ($$0|0);
       }
      } else {
       $$pre$i = HEAP32[$55>>2]|0;
       $71 = $30;$73 = $$pre$i;
       label = 20;
      }
     } while(0);
     if ((label|0) == 20) {
      $70 = (($71) + 1)|0;
      HEAP32[$29>>2] = $70;
      $72 = (($73) + ($71<<2)|0);
      $74 = HEAP32[$72>>2]|0;
      $75 = $74;
      $76 = $75;
      HEAP32[$76>>2] = $2;
      $77 = (($75) + 4)|0;
      $78 = $77;
      HEAP32[$78>>2] = $3;
      $79 = ((($74)) + 8|0);
      HEAPF32[$79>>2] = $5;
      $80 = ((($74)) + 12|0);
      HEAPF32[$80>>2] = $6;
      $81 = ((($74)) + 16|0);
      HEAPF32[$81>>2] = $7;
     }
     $84 = (_SDL_EventState(1792,-1)|0);
     $85 = ($84<<24>>24)==(1);
     if (!($85)) {
      $$0 = 0;
      STACKTOP = sp;return ($$0|0);
     }
     HEAP32[$8>>2] = 1792;
     $86 = ((($8)) + 8|0);
     $87 = $86;
     $88 = $87;
     HEAP32[$88>>2] = $0;
     $89 = (($87) + 4)|0;
     $90 = $89;
     HEAP32[$90>>2] = $1;
     $91 = ((($8)) + 16|0);
     $92 = $91;
     $93 = $92;
     HEAP32[$93>>2] = $2;
     $94 = (($92) + 4)|0;
     $95 = $94;
     HEAP32[$95>>2] = $3;
     $96 = ((($8)) + 24|0);
     HEAPF32[$96>>2] = $5;
     $97 = ((($8)) + 28|0);
     HEAPF32[$97>>2] = $6;
     $98 = ((($8)) + 32|0);
     HEAPF32[$98>>2] = 0.0;
     $99 = ((($8)) + 36|0);
     HEAPF32[$99>>2] = 0.0;
     $100 = ((($8)) + 40|0);
     HEAPF32[$100>>2] = $7;
     $101 = (_SDL_PushEvent($8)|0);
     $102 = ($101|0)>(0);
     $103 = $102&1;
     $$0 = $103;
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 } while(0);
 (_SDL_SetError(185893,$vararg_buffer)|0);
 $$0 = -1;
 STACKTOP = sp;return ($$0|0);
}
function _SDL_SendTouchMotion($0,$1,$2,$3,$4,$5,$6) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = +$4;
 $5 = +$5;
 $6 = +$6;
 var $$0 = 0, $$08$i$i = 0, $$089$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0.0, $49 = 0.0, $50 = 0, $51 = 0.0, $52 = 0.0, $53 = 0, $54 = 0.0, $55 = 0.0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $8 = 0, $9 = 0, $notlhs = 0, $notrhs = 0, $or$cond = 0, $or$cond$i = 0, $or$cond$i49$not = 0;
 var $or$cond3 = 0, $or$cond50 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(64|0);
 $vararg_buffer = sp + 56|0;
 $7 = sp;
 $8 = HEAP32[53315]|0;
 $9 = ($8|0)>(0);
 L1: do {
  if ($9) {
   $10 = HEAP32[53316]|0;
   $$089$i$i = 0;
   while(1) {
    $11 = (($10) + ($$089$i$i<<2)|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = $12;
    $14 = $13;
    $15 = HEAP32[$14>>2]|0;
    $16 = (($13) + 4)|0;
    $17 = $16;
    $18 = HEAP32[$17>>2]|0;
    $19 = ($15|0)==($0|0);
    $20 = ($18|0)==($1|0);
    $21 = $19 & $20;
    if ($21) {
     break;
    }
    $22 = (($$089$i$i) + 1)|0;
    $23 = ($22|0)<($8|0);
    if ($23) {
     $$089$i$i = $22;
    } else {
     break L1;
    }
   }
   $24 = ($$089$i$i|0)>(-1);
   $25 = ($$089$i$i|0)<($8|0);
   $or$cond$i = $24 & $25;
   if ($or$cond$i) {
    $26 = ($12|0)==(0|0);
    if ($26) {
     $$0 = -1;
     STACKTOP = sp;return ($$0|0);
    }
    $27 = ((($12)) + 8|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = ($28|0)>(0);
    L11: do {
     if ($29) {
      $30 = ((($12)) + 16|0);
      $31 = HEAP32[$30>>2]|0;
      $$08$i$i = 0;
      while(1) {
       $32 = (($31) + ($$08$i$i<<2)|0);
       $33 = HEAP32[$32>>2]|0;
       $34 = $33;
       $35 = $34;
       $36 = HEAP32[$35>>2]|0;
       $37 = (($34) + 4)|0;
       $38 = $37;
       $39 = HEAP32[$38>>2]|0;
       $40 = ($36|0)==($2|0);
       $41 = ($39|0)==($3|0);
       $42 = $40 & $41;
       if ($42) {
        break;
       }
       $43 = (($$08$i$i) + 1)|0;
       $44 = ($43|0)<($28|0);
       if ($44) {
        $$08$i$i = $43;
       } else {
        break L11;
       }
      }
      $notlhs = ($$08$i$i|0)<(0);
      $notrhs = ($$08$i$i|0)>=($28|0);
      $or$cond$i49$not = $notrhs | $notlhs;
      $45 = ($33|0)==(0|0);
      $or$cond50 = $or$cond$i49$not | $45;
      if (!($or$cond50)) {
       $47 = ((($33)) + 8|0);
       $48 = +HEAPF32[$47>>2];
       $49 = $4 - $48;
       $50 = ((($33)) + 12|0);
       $51 = +HEAPF32[$50>>2];
       $52 = $5 - $51;
       $53 = ((($33)) + 16|0);
       $54 = +HEAPF32[$53>>2];
       $55 = $6 - $54;
       $56 = $49 != 0.0;
       $57 = $52 != 0.0;
       $or$cond = $56 | $57;
       $58 = $55 != 0.0;
       $or$cond3 = $or$cond | $58;
       if (!($or$cond3)) {
        $$0 = 0;
        STACKTOP = sp;return ($$0|0);
       }
       HEAPF32[$47>>2] = $4;
       HEAPF32[$50>>2] = $5;
       HEAPF32[$53>>2] = $6;
       $59 = (_SDL_EventState(1794,-1)|0);
       $60 = ($59<<24>>24)==(1);
       if (!($60)) {
        $$0 = 0;
        STACKTOP = sp;return ($$0|0);
       }
       HEAP32[$7>>2] = 1794;
       $61 = ((($7)) + 8|0);
       $62 = $61;
       $63 = $62;
       HEAP32[$63>>2] = $0;
       $64 = (($62) + 4)|0;
       $65 = $64;
       HEAP32[$65>>2] = $1;
       $66 = ((($7)) + 16|0);
       $67 = $66;
       $68 = $67;
       HEAP32[$68>>2] = $2;
       $69 = (($67) + 4)|0;
       $70 = $69;
       HEAP32[$70>>2] = $3;
       $71 = ((($7)) + 24|0);
       HEAPF32[$71>>2] = $4;
       $72 = ((($7)) + 28|0);
       HEAPF32[$72>>2] = $5;
       $73 = ((($7)) + 32|0);
       HEAPF32[$73>>2] = $49;
       $74 = ((($7)) + 36|0);
       HEAPF32[$74>>2] = $52;
       $75 = ((($7)) + 40|0);
       HEAPF32[$75>>2] = $6;
       $76 = (_SDL_PushEvent($7)|0);
       $77 = ($76|0)>(0);
       $78 = $77&1;
       $$0 = $78;
       STACKTOP = sp;return ($$0|0);
      }
     }
    } while(0);
    $46 = (_SDL_SendTouch($0,$1,$2,$3,1,$4,$5,$6)|0);
    $$0 = $46;
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 (_SDL_SetError(185893,$vararg_buffer)|0);
 $$0 = -1;
 STACKTOP = sp;return ($$0|0);
}
function _SDL_PrivateSendMouseButton($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0 = 0, $$0251$i74 = 0, $$06773 = 0, $$06872 = 0, $$069 = 0, $$1 = 0, $$phi$trans$insert = 0, $$phi$trans$insert77 = 0, $$pre = 0, $$pre$i = 0, $$pre$phi8287Z2D = 0, $$pre75 = 0, $$pre78 = 0, $$pre79$pre$phiZZ2D = 0, $$pre80 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $exitcond = 0, $or$cond70 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(64|0);
 $5 = sp;
 $6 = HEAP32[(209596)>>2]|0;
 switch ($2<<24>>24) {
 case 1:  {
  $13 = $3&255;
  $14 = (($13) + -1)|0;
  $15 = 1 << $14;
  $16 = $6 | $15;
  $17 = ($0|0)==(0|0);
  if ($17) {
   $$06773 = $16;$$06872 = 1025;$21 = $6;$91 = 0;$94 = 1;
  } else {
   $18 = HEAP32[(209572)>>2]|0;
   $19 = HEAP32[(209576)>>2]|0;
   (_SDL_UpdateMouseFocus($0,$18,$19)|0);
   $$pre = HEAP32[(209596)>>2]|0;
   $$06773 = $16;$$06872 = 1025;$21 = $$pre;$91 = 1;$94 = 1;
  }
  break;
 }
 case 0:  {
  $7 = $3&255;
  $8 = (($7) + -1)|0;
  $9 = 1 << $8;
  $10 = $9 ^ -1;
  $11 = $6 & $10;
  $12 = ($0|0)!=(0|0);
  $$06773 = $11;$$06872 = 1026;$21 = $6;$91 = $12;$94 = 0;
  break;
 }
 default: {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 }
 $20 = ($$06773|0)==($21|0);
 if ($20) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[(209596)>>2] = $$06773;
 $22 = ($4|0)<(0);
 do {
  if ($22) {
   $23 = $3&255;
   $24 = HEAP32[(209608)>>2]|0;
   $25 = ($23|0)<($24|0);
   if (!($25)) {
    $26 = (($23) + 1)|0;
    $27 = HEAP32[(209612)>>2]|0;
    $28 = $26 << 4;
    $29 = (_SDL_realloc($27,$28)|0);
    $30 = ($29|0)==(0|0);
    if ($30) {
     $$1 = 1;
     break;
    }
    HEAP32[(209612)>>2] = $29;
    $31 = HEAP32[(209608)>>2]|0;
    $32 = ($31|0)>($23|0);
    if (!($32)) {
     $33 = (($29) + ($31<<4)|0);
     (_SDL_memset($33,0,16)|0);
     $34 = ($31|0)<($23|0);
     if ($34) {
      $$0251$i74 = $31;
      while(1) {
       $35 = (($$0251$i74) + 1)|0;
       $$pre$i = HEAP32[(209612)>>2]|0;
       $36 = (($$pre$i) + ($35<<4)|0);
       (_SDL_memset($36,0,16)|0);
       $exitcond = ($35|0)==($23|0);
       if ($exitcond) {
        break;
       } else {
        $$0251$i74 = $35;
       }
      }
     }
    }
    HEAP32[(209608)>>2] = $26;
   }
   $37 = HEAP32[(209612)>>2]|0;
   $38 = (($37) + ($23<<4)|0);
   $39 = ($38|0)==(0|0);
   if ($39) {
    $$1 = 1;
   } else {
    do {
     if ($94) {
      $40 = (_SDL_GetTicks()|0);
      $41 = (((($37) + ($23<<4)|0)) + 8|0);
      $42 = HEAP32[$41>>2]|0;
      $43 = HEAP32[22414]|0;
      $44 = (($42) - ($40))|0;
      $45 = (($44) + ($43))|0;
      $46 = ($45|0)<(1);
      if ($46) {
       $$pre79$pre$phiZZ2D = $38;
       label = 20;
      } else {
       $47 = HEAP32[(209572)>>2]|0;
       $48 = HEAP32[$38>>2]|0;
       $49 = (($47) - ($48))|0;
       $50 = (_SDL_abs($49)|0);
       $51 = ($50|0)>(1);
       if ($51) {
        $$pre79$pre$phiZZ2D = $38;
        label = 20;
       } else {
        $52 = HEAP32[(209576)>>2]|0;
        $53 = (((($37) + ($23<<4)|0)) + 4|0);
        $54 = HEAP32[$53>>2]|0;
        $55 = (($52) - ($54))|0;
        $56 = (_SDL_abs($55)|0);
        $57 = ($56|0)>(1);
        if ($57) {
         $$pre79$pre$phiZZ2D = $38;
         label = 20;
        } else {
         $$phi$trans$insert = (((($37) + ($23<<4)|0)) + 12|0);
         $$pre75 = HEAP8[$$phi$trans$insert>>0]|0;
         HEAP32[$41>>2] = $40;
         $61 = HEAP32[(209572)>>2]|0;
         HEAP32[$38>>2] = $61;
         $62 = HEAP32[(209576)>>2]|0;
         HEAP32[$53>>2] = $62;
         $63 = ($$pre75<<24>>24)==(-1);
         if ($63) {
          $67 = -1;
          break;
         } else {
          $$pre$phi8287Z2D = $$phi$trans$insert;$65 = $$pre75;
         }
        }
       }
      }
      if ((label|0) == 20) {
       $58 = (((($37) + ($23<<4)|0)) + 12|0);
       HEAP8[$58>>0] = 0;
       $$pre80 = (((($37) + ($23<<4)|0)) + 4|0);
       HEAP32[$41>>2] = $40;
       $59 = HEAP32[(209572)>>2]|0;
       HEAP32[$$pre79$pre$phiZZ2D>>2] = $59;
       $60 = HEAP32[(209576)>>2]|0;
       HEAP32[$$pre80>>2] = $60;
       $$pre$phi8287Z2D = $58;$65 = 0;
      }
      $64 = (($65) + 1)<<24>>24;
      HEAP8[$$pre$phi8287Z2D>>0] = $64;
      $67 = $64;
     } else {
      $$phi$trans$insert77 = (((($37) + ($23<<4)|0)) + 12|0);
      $$pre78 = HEAP8[$$phi$trans$insert77>>0]|0;
      $67 = $$pre78;
     }
    } while(0);
    $66 = $67&255;
    $$1 = $66;
   }
  } else {
   $$1 = $4;
  }
 } while(0);
 $68 = (_SDL_EventState($$06872,-1)|0);
 $69 = ($68<<24>>24)==(1);
 if ($69) {
  HEAP32[$5>>2] = $$06872;
  $70 = HEAP32[(209568)>>2]|0;
  $71 = ($70|0)==(0|0);
  if ($71) {
   $75 = 0;
  } else {
   $72 = ((($70)) + 4|0);
   $73 = HEAP32[$72>>2]|0;
   $75 = $73;
  }
  $74 = ((($5)) + 8|0);
  HEAP32[$74>>2] = $75;
  $76 = ((($5)) + 12|0);
  HEAP32[$76>>2] = $1;
  $77 = ((($5)) + 17|0);
  HEAP8[$77>>0] = $2;
  $78 = ((($5)) + 16|0);
  HEAP8[$78>>0] = $3;
  $79 = ($$1|0)<(255);
  $80 = $79 ? $$1 : 255;
  $81 = $80&255;
  $82 = ((($5)) + 18|0);
  HEAP8[$82>>0] = $81;
  $83 = HEAP32[(209572)>>2]|0;
  $84 = ((($5)) + 20|0);
  HEAP32[$84>>2] = $83;
  $85 = HEAP32[(209576)>>2]|0;
  $86 = ((($5)) + 24|0);
  HEAP32[$86>>2] = $85;
  $87 = (_SDL_PushEvent($5)|0);
  $88 = ($87|0)>(0);
  $89 = $88&1;
  $$069 = $89;
 } else {
  $$069 = 0;
 }
 $90 = ($2<<24>>24)==(0);
 $or$cond70 = $90 & $91;
 if (!($or$cond70)) {
  $$0 = $$069;
  STACKTOP = sp;return ($$0|0);
 }
 $92 = HEAP32[(209572)>>2]|0;
 $93 = HEAP32[(209576)>>2]|0;
 (_SDL_UpdateMouseFocus($0,$92,$93)|0);
 $$0 = $$069;
 STACKTOP = sp;return ($$0|0);
}
function _SDL_abs($0) {
 $0 = $0|0;
 var $1 = 0, $ispos = 0, $neg = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $ispos = ($0|0)>(-1);
 $neg = (0 - ($0))|0;
 $1 = $ispos ? $0 : $neg;
 return ($1|0);
}
function _SDL_GestureAddTouch($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[52373]|0;
 $3 = HEAP32[52371]|0;
 $4 = ($3*8232)|0;
 $5 = (($4) + 8232)|0;
 $6 = (_SDL_realloc($2,$5)|0);
 $7 = ($6|0)==(0|0);
 if ($7) {
  $8 = (_SDL_Error(0)|0);
  $$0 = $8;
  return ($$0|0);
 } else {
  HEAP32[52373] = $6;
  $9 = HEAP32[52371]|0;
  $10 = (($6) + (($9*8232)|0)|0);
  (_SDL_memset($10,0,8232)|0);
  $11 = HEAP32[52373]|0;
  $12 = HEAP32[52371]|0;
  $13 = (($11) + (($12*8232)|0)|0);
  $14 = $13;
  $15 = $14;
  HEAP32[$15>>2] = $0;
  $16 = (($14) + 4)|0;
  $17 = $16;
  HEAP32[$17>>2] = $1;
  $18 = (($12) + 1)|0;
  HEAP32[52371] = $18;
  $$0 = 0;
  return ($$0|0);
 }
 return (0)|0;
}
function _SDL_ResetKeyboard() {
 var $$07 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $exitcond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$07 = 0;
 while(1) {
  $0 = (210698 + ($$07)|0);
  $1 = HEAP8[$0>>0]|0;
  $2 = ($1<<24>>24)==(1);
  if ($2) {
   (_SDL_SendKeyboardKey(0,$$07)|0);
  }
  $3 = (($$07) + 1)|0;
  $exitcond = ($3|0)==(512);
  if ($exitcond) {
   break;
  } else {
   $$07 = $3;
  }
 }
 return;
}
function _SDL_SendMouseWheel($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$015 = 0, $$pr$i = 0, $$val = 0, $$val16 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $notlhs$i$i = 0, $notrhs$i$i = 0, $or$cond27$not$i$i = 0, $or$cond29$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(64|0);
 $5 = sp;
 $6 = ($0|0)==(0|0);
 do {
  if (!($6)) {
   $7 = HEAP32[(209568)>>2]|0;
   $8 = ($7|0)==($0|0);
   if (!($8)) {
    $9 = ($7|0)==(0|0);
    if (!($9)) {
     (_SDL_SendWindowEvent($7,11,0,0)|0);
    }
    HEAP32[(209568)>>2] = $0;
    (_SDL_SendWindowEvent($0,10,0,0)|0);
    $$pr$i = HEAP32[(209568)>>2]|0;
    $10 = ($$pr$i|0)==(0|0);
    $$val = HEAP32[(209620)>>2]|0;
    $$val16 = HEAP32[(209624)>>2]|0;
    $11 = $10 ? $$val : $$val16;
    $12 = HEAP32[(209628)>>2]|0;
    $notlhs$i$i = ($11|0)!=(0|0);
    $notrhs$i$i = ($12|0)!=(0);
    $or$cond27$not$i$i = $notlhs$i$i & $notrhs$i$i;
    $13 = HEAP32[(209600)>>2]|0;
    $14 = ($13|0)==(0);
    $or$cond29$i$i = $or$cond27$not$i$i & $14;
    $15 = HEAP32[(209532)>>2]|0;
    $16 = ($15|0)==(0|0);
    if ($or$cond29$i$i) {
     if ($16) {
      break;
     }
     (FUNCTION_TABLE_ii[$15 & 8191]($11)|0);
     break;
    } else {
     if ($16) {
      break;
     }
     (FUNCTION_TABLE_ii[$15 & 8191](0)|0);
     break;
    }
   }
  }
 } while(0);
 $17 = $3 | $2;
 $18 = ($17|0)==(0);
 if ($18) {
  $$015 = 0;
  STACKTOP = sp;return ($$015|0);
 }
 $19 = (_SDL_EventState(1027,-1)|0);
 $20 = ($19<<24>>24)==(1);
 if (!($20)) {
  $$015 = 0;
  STACKTOP = sp;return ($$015|0);
 }
 HEAP32[$5>>2] = 1027;
 $21 = HEAP32[(209568)>>2]|0;
 $22 = ($21|0)==(0|0);
 if ($22) {
  $26 = 0;
 } else {
  $23 = ((($21)) + 4|0);
  $24 = HEAP32[$23>>2]|0;
  $26 = $24;
 }
 $25 = ((($5)) + 8|0);
 HEAP32[$25>>2] = $26;
 $27 = ((($5)) + 12|0);
 HEAP32[$27>>2] = $1;
 $28 = ((($5)) + 16|0);
 HEAP32[$28>>2] = $2;
 $29 = ((($5)) + 20|0);
 HEAP32[$29>>2] = $3;
 $30 = ((($5)) + 24|0);
 HEAP32[$30>>2] = $4;
 $31 = (_SDL_PushEvent($5)|0);
 $32 = ($31|0)>(0);
 $33 = $32&1;
 $$015 = $33;
 STACKTOP = sp;return ($$015|0);
}
function _SDL_CaptureMouse($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $1 = HEAP32[(209556)>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   $3 = (_SDL_Error(4)|0);
   $$0 = $3;
  } else {
   $4 = (_SDL_GetKeyboardFocus()|0);
   $5 = ($4|0)!=(0|0);
   if ($5) {
    $6 = ((($4)) + 48|0);
    $7 = HEAP32[$6>>2]|0;
    $8 = $7 & 16384;
    $9 = ($8|0)!=(0);
    $11 = $9;
   } else {
    $11 = 0;
   }
   $10 = $11&1;
   $12 = ($10|0)==($0|0);
   if ($12) {
    $$0 = 0;
   } else {
    $13 = ($0|0)==(0);
    if ($13) {
     $21 = HEAP32[(209556)>>2]|0;
     $22 = (FUNCTION_TABLE_ii[$21 & 8191](0)|0);
     $23 = ($22|0)==(-1);
     if ($23) {
      $$0 = -1;
      break;
     }
     $24 = ((($4)) + 48|0);
     $25 = HEAP32[$24>>2]|0;
     $26 = $25 & -16385;
     HEAP32[$24>>2] = $26;
     $$0 = 0;
     break;
    }
    if (!($5)) {
     $14 = (_SDL_SetError(185914,$vararg_buffer)|0);
     $$0 = $14;
     break;
    }
    $15 = HEAP32[(209556)>>2]|0;
    $16 = (FUNCTION_TABLE_ii[$15 & 8191]($4)|0);
    $17 = ($16|0)==(-1);
    if ($17) {
     $$0 = -1;
    } else {
     $18 = ((($4)) + 48|0);
     $19 = HEAP32[$18>>2]|0;
     $20 = $19 | 16384;
     HEAP32[$18>>2] = $20;
     $$0 = 0;
    }
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function _SDL_GetVideoDevice() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[52375]|0;
 return ($0|0);
}
function _SDL_GetKeyboardFocus() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[52673]|0;
 return ($0|0);
}
function _SDL_EGL_ChooseConfig($0) {
 $0 = $0|0;
 var $$0$lcssa = 0, $$07990 = 0, $$08187 = 0, $$082 = 0, $$084 = 0, $$088 = 0, $$1 = 0, $$180 = 0, $$183 = 0, $$2 = 0, $$3 = 0, $$4 = 0, $$689 = 0, $$off = 0, $$sink = 0, $$sink$sink = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0;
 var $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $or$cond3 = 0, $or$cond85 = 0, $or$cond93 = 0, $switch = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 800|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(800|0);
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $1 = sp + 536|0;
 $2 = sp + 532|0;
 $3 = sp + 528|0;
 $4 = sp + 16|0;
 HEAP32[$2>>2] = 0;
 $5 = ((($0)) + 676|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $$084 = -1;
  STACKTOP = sp;return ($$084|0);
 }
 HEAP32[$1>>2] = 12324;
 $8 = ((($0)) + 292|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($1)) + 4|0);
 HEAP32[$10>>2] = $9;
 $11 = ((($1)) + 8|0);
 HEAP32[$11>>2] = 12323;
 $12 = ((($0)) + 296|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($1)) + 12|0);
 HEAP32[$14>>2] = $13;
 $15 = ((($1)) + 16|0);
 HEAP32[$15>>2] = 12322;
 $16 = ((($0)) + 300|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ((($1)) + 20|0);
 HEAP32[$18>>2] = $17;
 $19 = ((($0)) + 304|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)==(0);
 if ($21) {
  $$082 = 6;
 } else {
  $22 = ((($1)) + 24|0);
  HEAP32[$22>>2] = 12321;
  $23 = ((($1)) + 28|0);
  HEAP32[$23>>2] = $20;
  $$082 = 8;
 }
 $24 = ((($0)) + 312|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)==(0);
 $27 = $$082 | 1;
 if ($26) {
  $$183 = $$082;
 } else {
  $28 = (($1) + ($27<<2)|0);
  $29 = (($27) + 1)|0;
  $30 = (($1) + ($$082<<2)|0);
  HEAP32[$30>>2] = 12320;
  HEAP32[$28>>2] = $25;
  $$183 = $29;
 }
 $31 = (($$183) + 1)|0;
 $32 = (($1) + ($$183<<2)|0);
 HEAP32[$32>>2] = 12325;
 $33 = ((($0)) + 308|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = (($$183) + 2)|0;
 $36 = (($1) + ($31<<2)|0);
 HEAP32[$36>>2] = $34;
 $37 = ((($0)) + 316|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = ($38|0)==(0);
 if ($39) {
  $$2 = $35;
 } else {
  $40 = (($$183) + 3)|0;
  $41 = (($1) + ($40<<2)|0);
  $42 = (($$183) + 4)|0;
  $43 = (($1) + ($35<<2)|0);
  HEAP32[$43>>2] = 12326;
  HEAP32[$41>>2] = $38;
  $$2 = $42;
 }
 $44 = ((($0)) + 344|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = ($45|0)==(0);
 if ($46) {
  $$3 = $$2;
 } else {
  $47 = (($$2) + 1)|0;
  $48 = (($1) + ($47<<2)|0);
  $49 = (($$2) + 2)|0;
  $50 = (($1) + ($$2<<2)|0);
  HEAP32[$50>>2] = 12338;
  HEAP32[$48>>2] = $45;
  $$3 = $49;
 }
 $51 = ((($0)) + 348|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = ($52|0)==(0);
 if ($53) {
  $$4 = $$3;
 } else {
  $54 = (($$3) + 1)|0;
  $55 = (($1) + ($54<<2)|0);
  $56 = (($$3) + 2)|0;
  $57 = (($1) + ($$3<<2)|0);
  HEAP32[$57>>2] = 12337;
  HEAP32[$55>>2] = $52;
  $$4 = $56;
 }
 $58 = ((($0)) + 380|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = ($59|0)==(0);
 if (!($60)) {
  $61 = (_SDL_SetError(185934,$vararg_buffer)|0);
  $$084 = $61;
  STACKTOP = sp;return ($$084|0);
 }
 $62 = (($$4) + 1)|0;
 $63 = (($1) + ($$4<<2)|0);
 HEAP32[$63>>2] = 12352;
 $64 = ((($0)) + 368|0);
 $65 = HEAP32[$64>>2]|0;
 $66 = ($65|0)==(4);
 $67 = (($$4) + 2)|0;
 if ($66) {
  $68 = ((($0)) + 356|0);
  $69 = HEAP32[$68>>2]|0;
  $70 = ($69|0)>(1);
  $$sink = $70 ? 4 : 1;
  $71 = ((($6)) + 84|0);
  $72 = HEAP32[$71>>2]|0;
  (FUNCTION_TABLE_ii[$72 & 8191](12448)|0);
  $$sink$sink = $$sink;
 } else {
  $73 = ((($6)) + 84|0);
  $74 = HEAP32[$73>>2]|0;
  (FUNCTION_TABLE_ii[$74 & 8191](12450)|0);
  $$sink$sink = 8;
 }
 $75 = (($1) + ($62<<2)|0);
 HEAP32[$75>>2] = $$sink$sink;
 $76 = (($1) + ($67<<2)|0);
 HEAP32[$76>>2] = 12344;
 $77 = HEAP32[$5>>2]|0;
 $78 = ((($77)) + 36|0);
 $79 = HEAP32[$78>>2]|0;
 $80 = ((($77)) + 8|0);
 $81 = HEAP32[$80>>2]|0;
 $82 = (FUNCTION_TABLE_iiiiii[$79 & 8191]($81,$1,$4,128,$2)|0);
 $83 = ($82|0)==(0);
 $84 = HEAP32[$2>>2]|0;
 $85 = ($84|0)==(0);
 $or$cond = $83 | $85;
 if ($or$cond) {
  $87 = (_SDL_SetError(185995,$vararg_buffer1)|0);
  $$084 = $87;
  STACKTOP = sp;return ($$084|0);
 }
 $86 = ($84|0)>(0);
 if ($86) {
  $$07990 = -1;$$689 = 0;
 } else {
  $$084 = 0;
  STACKTOP = sp;return ($$084|0);
 }
 while(1) {
  $88 = (($4) + ($$689<<2)|0);
  $$08187 = 0;$$088 = 0;
  while(1) {
   $89 = (($1) + ($$08187<<2)|0);
   $90 = HEAP32[$89>>2]|0;
   $91 = ($90|0)==(12344);
   if ($91) {
    $$0$lcssa = $$088;
    break;
   }
   $92 = $$08187 | 1;
   $93 = (($1) + ($92<<2)|0);
   $94 = HEAP32[$93>>2]|0;
   $95 = ($94|0)!=(-1);
   $$off = (($90) + -12321)|0;
   $switch = ($$off>>>0)<(6);
   $or$cond85 = $switch & $95;
   if ($or$cond85) {
    $96 = HEAP32[$5>>2]|0;
    $97 = ((($96)) + 72|0);
    $98 = HEAP32[$97>>2]|0;
    $99 = ((($96)) + 8|0);
    $100 = HEAP32[$99>>2]|0;
    $101 = HEAP32[$88>>2]|0;
    (FUNCTION_TABLE_iiiii[$98 & 8191]($100,$101,$90,$3)|0);
    $102 = HEAP32[$3>>2]|0;
    $103 = HEAP32[$93>>2]|0;
    $104 = (($102) + ($$088))|0;
    $105 = (($104) - ($103))|0;
    $$1 = $105;
   } else {
    $$1 = $$088;
   }
   $106 = (($$08187) + 2)|0;
   $107 = ($106>>>0)<(63);
   if ($107) {
    $$08187 = $106;$$088 = $$1;
   } else {
    $$0$lcssa = $$1;
    break;
   }
  }
  $108 = ($$0$lcssa|0)<($$07990|0);
  $109 = ($$07990|0)==(-1);
  $or$cond3 = $109 | $108;
  if ($or$cond3) {
   $110 = HEAP32[$88>>2]|0;
   $111 = HEAP32[$5>>2]|0;
   $112 = ((($111)) + 12|0);
   HEAP32[$112>>2] = $110;
   $$180 = $$0$lcssa;
  } else {
   $$180 = $$07990;
  }
  $113 = ($$0$lcssa|0)!=(0);
  $114 = (($$689) + 1)|0;
  $115 = HEAP32[$2>>2]|0;
  $116 = ($114|0)<($115|0);
  $or$cond93 = $113 & $116;
  if ($or$cond93) {
   $$07990 = $$180;$$689 = $114;
  } else {
   $$084 = 0;
   break;
  }
 }
 STACKTOP = sp;return ($$084|0);
}
function _Emscripten_FiniMouse() {
 var $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_SDL_GetMouse()|0);
 $1 = ((($0)) + 96|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = ((($2)) + 4|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0|0);
  if (!($6)) {
   $7 = ((($5)) + 4|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ($8|0)==(0);
   if ($9) {
    $11 = $5;
   } else {
    $10 = HEAP32[$5>>2]|0;
    _SDL_free($10);
    $$pre$i = HEAP32[$4>>2]|0;
    $11 = $$pre$i;
   }
   _SDL_free($11);
  }
  _SDL_free($2);
 }
 HEAP32[$1>>2] = 0;
 HEAP32[$0>>2] = 0;
 $12 = ((($0)) + 8|0);
 HEAP32[$12>>2] = 0;
 $13 = ((($0)) + 16|0);
 HEAP32[$13>>2] = 0;
 $14 = ((($0)) + 20|0);
 HEAP32[$14>>2] = 0;
 $15 = ((($0)) + 4|0);
 HEAP32[$15>>2] = 0;
 $16 = ((($0)) + 28|0);
 HEAP32[$16>>2] = 0;
 return;
}
function _SDL_AddBasicVideoDisplay($0) {
 $0 = $0|0;
 var $$pre = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(80|0);
 $1 = sp;
 (_SDL_memset($1,0,68)|0);
 $2 = ($0|0)==(0|0);
 $$pre = ((($1)) + 16|0);
 if (!($2)) {
  ;HEAP32[$$pre>>2]=HEAP32[$0>>2]|0;HEAP32[$$pre+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$pre+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$$pre+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$$pre+16>>2]=HEAP32[$0+16>>2]|0;
 }
 $3 = ((($1)) + 36|0);
 ;HEAP32[$3>>2]=HEAP32[$$pre>>2]|0;HEAP32[$3+4>>2]=HEAP32[$$pre+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$$pre+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$$pre+12>>2]|0;HEAP32[$3+16>>2]=HEAP32[$$pre+16>>2]|0;
 $4 = (_SDL_AddVideoDisplay($1)|0);
 STACKTOP = sp;return ($4|0);
}
function _SDL_AddDisplayMode($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$02729 = 0, $$028 = 0, $$pre$phiZ2D = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)>(0);
 L1: do {
  if ($6) {
   $7 = ((($1)) + 4|0);
   $8 = ((($1)) + 8|0);
   $9 = ((($1)) + 12|0);
   $$02729 = 0;
   L3: while(1) {
    $12 = (($3) + (($$02729*20)|0)|0);
    $13 = ($12|0)==($1|0);
    if ($13) {
     $$0 = 0;
     label = 20;
     break;
    }
    $14 = HEAP32[$7>>2]|0;
    $15 = (((($3) + (($$02729*20)|0)|0)) + 4|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = ($16|0)==($14|0);
    do {
     if ($17) {
      $19 = HEAP32[$8>>2]|0;
      $20 = (((($3) + (($$02729*20)|0)|0)) + 8|0);
      $21 = HEAP32[$20>>2]|0;
      $22 = ($21|0)==($19|0);
      if (!($22)) {
       $23 = (($21) - ($19))|0;
       $43 = $23;
       break;
      }
      $24 = HEAP32[$1>>2]|0;
      $25 = $24 >>> 8;
      $26 = $25 & 255;
      $27 = HEAP32[$12>>2]|0;
      $28 = $27 >>> 8;
      $29 = $28 & 255;
      $30 = ($29|0)==($26|0);
      if (!($30)) {
       $31 = (($29) - ($26))|0;
       $43 = $31;
       break;
      }
      $32 = $24 >>> 16;
      $33 = $32 & 15;
      $34 = $27 >>> 16;
      $35 = $34 & 15;
      $36 = ($35|0)==($33|0);
      if ($36) {
       $38 = HEAP32[$9>>2]|0;
       $39 = (((($3) + (($$02729*20)|0)|0)) + 12|0);
       $40 = HEAP32[$39>>2]|0;
       $41 = ($40|0)==($38|0);
       $42 = (($40) - ($38))|0;
       if ($41) {
        $$0 = 0;
        label = 20;
        break L3;
       } else {
        $43 = $42;
        break;
       }
      } else {
       $37 = (($35) - ($33))|0;
       $43 = $37;
       break;
      }
     } else {
      $18 = (($16) - ($14))|0;
      $43 = $18;
     }
    } while(0);
    $44 = ($43|0)==(0);
    $10 = (($$02729) + 1)|0;
    if ($44) {
     $$0 = 0;
     label = 20;
     break;
    }
    $11 = ($10|0)<($5|0);
    if ($11) {
     $$02729 = $10;
    } else {
     break L1;
    }
   }
   if ((label|0) == 20) {
    return ($$0|0);
   }
  }
 } while(0);
 $45 = ((($0)) + 4|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = ($5|0)==($46|0);
 do {
  if ($47) {
   $48 = ($5*20)|0;
   $49 = (($48) + 640)|0;
   $50 = (_SDL_realloc($3,$49)|0);
   $51 = ($50|0)==(0|0);
   if ($51) {
    $$0 = 0;
    return ($$0|0);
   } else {
    HEAP32[$2>>2] = $50;
    $52 = HEAP32[$45>>2]|0;
    $53 = (($52) + 32)|0;
    HEAP32[$45>>2] = $53;
    $$028 = $50;$$pre$phiZ2D = $2;
    break;
   }
  } else {
   $$028 = $3;$$pre$phiZ2D = $2;
  }
 } while(0);
 $54 = (($$028) + (($5*20)|0)|0);
 ;HEAP32[$54>>2]=HEAP32[$1>>2]|0;HEAP32[$54+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$54+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$54+12>>2]=HEAP32[$1+12>>2]|0;HEAP32[$54+16>>2]=HEAP32[$1+16>>2]|0;
 $55 = HEAP32[$4>>2]|0;
 $56 = (($55) + 1)|0;
 HEAP32[$4>>2] = $56;
 $57 = HEAP32[$$pre$phiZ2D>>2]|0;
 _SDL_qsort($57,$56,20,4325);
 $$0 = 1;
 return ($$0|0);
}
function _Emscripten_InitMouse() {
 var $$0$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_SDL_GetMouse()|0);
 HEAP32[$0>>2] = 4420;
 $1 = ((($0)) + 8|0);
 HEAP32[$1>>2] = 4421;
 $2 = ((($0)) + 16|0);
 HEAP32[$2>>2] = 4422;
 $3 = ((($0)) + 20|0);
 HEAP32[$3>>2] = 4423;
 $4 = ((($0)) + 4|0);
 HEAP32[$4>>2] = 4424;
 $5 = ((($0)) + 28|0);
 HEAP32[$5>>2] = 4425;
 $6 = (_SDL_calloc(1,8)|0);
 $7 = ($6|0)==(0|0);
 if ($7) {
  (_SDL_Error(0)|0);
  $$0$i$i = $6;
  _SDL_SetDefaultCursor($$0$i$i);
  return;
 }
 $8 = (_SDL_calloc(1,8)|0);
 $9 = ($8|0)==(0|0);
 if ($9) {
  (_SDL_Error(0)|0);
  _SDL_free($6);
  $$0$i$i = 0;
  _SDL_SetDefaultCursor($$0$i$i);
  return;
 } else {
  HEAP32[$8>>2] = 186110;
  $10 = ((($8)) + 4|0);
  HEAP32[$10>>2] = 0;
  $11 = ((($6)) + 4|0);
  HEAP32[$11>>2] = $8;
  $$0$i$i = $6;
  _SDL_SetDefaultCursor($$0$i$i);
  return;
 }
}
function _Emscripten_CreateCursor($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (_SDL_ConvertSurfaceFormat($0,376840196,0)|0);
 $4 = ($3|0)==(0|0);
 if ($4) {
  $$0 = 0;
  return ($$0|0);
 }
 $5 = ((($0)) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($0)) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($3)) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = _emscripten_asm_const_iiii(4, ($6|0), ($8|0), ($10|0))|0;
 $12 = $11;
 _SDL_FreeSurface($3);
 $13 = (_SDL_calloc(1,8)|0);
 $14 = ($13|0)==(0|0);
 if ($14) {
  (_SDL_Error(0)|0);
  $$0 = $13;
  return ($$0|0);
 }
 $15 = (_SDL_calloc(1,8)|0);
 $16 = ($15|0)==(0|0);
 if ($16) {
  (_SDL_Error(0)|0);
  _SDL_free($13);
  $$0 = 0;
  return ($$0|0);
 } else {
  HEAP32[$15>>2] = $12;
  $17 = ((($15)) + 4|0);
  HEAP32[$17>>2] = 1;
  $18 = ((($13)) + 4|0);
  HEAP32[$18>>2] = $15;
  $$0 = $13;
  return ($$0|0);
 }
 return (0)|0;
}
function _Emscripten_ShowCursor($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (_SDL_GetMouseFocus()|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  return 0;
 }
 $3 = ($0|0)==(0|0);
 if (!($3)) {
  $4 = ((($0)) + 4|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0|0);
  if (!($6)) {
   $7 = HEAP32[$5>>2]|0;
   $8 = ($7|0)==(0|0);
   if ($8) {
    return 0;
   }
   $9 = _emscripten_asm_const_ii(5, ($7|0))|0;
   return 0;
  }
 }
 $10 = _emscripten_asm_const_i(6)|0;
 return 0;
}
function _Emscripten_FreeCursor($0) {
 $0 = $0|0;
 var $$pre = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ($0|0)==(0|0);
 if ($1) {
  return;
 }
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = ((($3)) + 4|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==(0);
  if ($7) {
   $9 = $3;
  } else {
   $8 = HEAP32[$3>>2]|0;
   _SDL_free($8);
   $$pre = HEAP32[$2>>2]|0;
   $9 = $$pre;
  }
  _SDL_free($9);
 }
 _SDL_free($0);
 return;
}
function _Emscripten_WarpMouse($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (_SDL_Error(4)|0);
 return;
}
function _Emscripten_CreateSystemCursor($0) {
 $0 = $0|0;
 var $$0 = 0, $$03 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 do {
  switch ($0|0) {
  case 0:  {
   $$0 = 186110;
   break;
  }
  case 1:  {
   $$0 = 186206;
   break;
  }
  case 2:  {
   $$0 = 186201;
   break;
  }
  case 3:  {
   $$0 = 186191;
   break;
  }
  case 4:  {
   $$0 = 186182;
   break;
  }
  case 5:  {
   $$0 = 186170;
   break;
  }
  case 6:  {
   $$0 = 186158;
   break;
  }
  case 7:  {
   $$0 = 186148;
   break;
  }
  case 8:  {
   $$0 = 186138;
   break;
  }
  case 9:  {
   $$0 = 0;
   break;
  }
  case 10:  {
   $$0 = 186126;
   break;
  }
  case 11:  {
   $$0 = 186118;
   break;
  }
  default: {
   $$03 = 0;
   return ($$03|0);
  }
  }
 } while(0);
 $1 = (_SDL_calloc(1,8)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  (_SDL_Error(0)|0);
  $$03 = $1;
  return ($$03|0);
 }
 $3 = (_SDL_calloc(1,8)|0);
 $4 = ($3|0)==(0|0);
 if ($4) {
  (_SDL_Error(0)|0);
  _SDL_free($1);
  $$03 = 0;
  return ($$03|0);
 } else {
  HEAP32[$3>>2] = $$0;
  $5 = ((($3)) + 4|0);
  HEAP32[$5>>2] = 0;
  $6 = ((($1)) + 4|0);
  HEAP32[$6>>2] = $3;
  $$03 = $1;
  return ($$03|0);
 }
 return (0)|0;
}
function _Emscripten_SetRelativeMouseMode($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ($0|0)==(0);
 if ($1) {
  $4 = (_emscripten_exit_pointerlock()|0);
  $5 = ($4|0)>(-1);
  if ($5) {
   $$0 = 0;
   return ($$0|0);
  }
 } else {
  $2 = (_emscripten_request_pointerlock((0|0),1)|0);
  $3 = ($2|0)>(-1);
  if ($3) {
   $$0 = 0;
   return ($$0|0);
  }
 }
 $$0 = -1;
 return ($$0|0);
}
function _SDL_SetDefaultCursor($0) {
 $0 = $0|0;
 var $$025$i = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $notlhs$i = 0, $notrhs$i = 0, $or$cond27$not$i = 0, $or$cond29$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[(209620)>>2] = $0;
 $1 = HEAP32[(209624)>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  return;
 }
 $3 = ($0|0)==(0|0);
 if ($3) {
  $$025$i = 0;
 } else {
  HEAP32[(209624)>>2] = $0;
  $$025$i = $0;
 }
 $4 = HEAP32[(209628)>>2]|0;
 $notlhs$i = ($$025$i|0)!=(0|0);
 $notrhs$i = ($4|0)!=(0);
 $or$cond27$not$i = $notlhs$i & $notrhs$i;
 $5 = HEAP32[(209600)>>2]|0;
 $6 = ($5|0)==(0);
 $or$cond29$i = $or$cond27$not$i & $6;
 $7 = HEAP32[(209532)>>2]|0;
 $8 = ($7|0)==(0|0);
 if ($or$cond29$i) {
  if ($8) {
   return;
  }
  (FUNCTION_TABLE_ii[$7 & 8191]($$025$i)|0);
  return;
 } else {
  if ($8) {
   return;
  }
  (FUNCTION_TABLE_ii[$7 & 8191](0)|0);
  return;
 }
}
function _SDL_AddVideoDisplay($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $1 = sp;
 $2 = HEAP32[52375]|0;
 $3 = ((($2)) + 268|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($2)) + 264|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6*68)|0;
 $8 = (($7) + 68)|0;
 $9 = (_SDL_realloc($4,$8)|0);
 $10 = ($9|0)==(0|0);
 if ($10) {
  (_SDL_Error(0)|0);
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 $11 = HEAP32[52375]|0;
 $12 = ((($11)) + 264|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($13) + 1)|0;
 HEAP32[$12>>2] = $14;
 $15 = (($9) + (($13*68)|0)|0);
 dest=$15; src=$0; stop=dest+68|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $16 = $11;
 $17 = (((($9) + (($13*68)|0)|0)) + 60|0);
 HEAP32[$17>>2] = $16;
 $18 = ((($11)) + 268|0);
 HEAP32[$18>>2] = $9;
 $19 = HEAP32[$0>>2]|0;
 $20 = ($19|0)==(0|0);
 if ($20) {
  (_SDL_itoa($13,$1,10)|0);
  $22 = (_SDL_strdup($1)|0);
  HEAP32[$15>>2] = $22;
  $$0 = $13;
  STACKTOP = sp;return ($$0|0);
 } else {
  $21 = (_SDL_strdup($19)|0);
  HEAP32[$15>>2] = $21;
  $$0 = $13;
  STACKTOP = sp;return ($$0|0);
 }
 return (0)|0;
}
function _SDL_strdup($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (___strdup($0)|0);
 return ($1|0);
}
function _SDL_itoa($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (_SDL_ltoa($0,$1,$2)|0);
 return ($3|0);
}
function _SDL_ltoa($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$01213$i = 0, $$01213$i11 = 0, $$014$i = 0, $$014$i10 = 0, $$01619$i$i = 0, $$01619$i$i17 = 0, $$01718$i$i = 0, $$01718$i$i18 = 0, $$020$i$i = 0, $$020$i$i16 = 0, $$1$i13 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($0|0)<(0);
 if ($3) {
  $4 = ((($1)) + 1|0);
  HEAP8[$1>>0] = 45;
  $5 = (0 - ($0))|0;
  $$01213$i = $5;$$014$i = $4;
  while(1) {
   $6 = (($$01213$i>>>0) % ($2>>>0))&-1;
   $7 = (187246 + ($6)|0);
   $8 = HEAP8[$7>>0]|0;
   $9 = ((($$014$i)) + 1|0);
   HEAP8[$$014$i>>0] = $8;
   $10 = (($$01213$i>>>0) / ($2>>>0))&-1;
   $11 = ($$01213$i>>>0)<($2>>>0);
   if ($11) {
    break;
   } else {
    $$01213$i = $10;$$014$i = $9;
   }
  }
  HEAP8[$9>>0] = 0;
  $12 = (_strlen($4)|0);
  $13 = $12 >>> 1;
  $14 = ($13|0)==(0);
  if ($14) {
   return ($1|0);
  }
  $15 = (($12) + -1)|0;
  $16 = (($4) + ($15)|0);
  $$01619$i$i = $16;$$01718$i$i = $4;$$020$i$i = $13;
  while(1) {
   $17 = (($$020$i$i) + -1)|0;
   $18 = HEAP8[$$01718$i$i>>0]|0;
   $19 = HEAP8[$$01619$i$i>>0]|0;
   $20 = ((($$01718$i$i)) + 1|0);
   HEAP8[$$01718$i$i>>0] = $19;
   $21 = ((($$01619$i$i)) + -1|0);
   HEAP8[$$01619$i$i>>0] = $18;
   $22 = ($17|0)==(0);
   if ($22) {
    break;
   } else {
    $$01619$i$i = $21;$$01718$i$i = $20;$$020$i$i = $17;
   }
  }
  return ($1|0);
 }
 $23 = ($0|0)==(0);
 if ($23) {
  $30 = ((($1)) + 1|0);
  HEAP8[$1>>0] = 48;
  $$1$i13 = $30;
 } else {
  $$01213$i11 = $0;$$014$i10 = $1;
  while(1) {
   $24 = (($$01213$i11>>>0) % ($2>>>0))&-1;
   $25 = (187246 + ($24)|0);
   $26 = HEAP8[$25>>0]|0;
   $27 = ((($$014$i10)) + 1|0);
   HEAP8[$$014$i10>>0] = $26;
   $28 = (($$01213$i11>>>0) / ($2>>>0))&-1;
   $29 = ($$01213$i11>>>0)<($2>>>0);
   if ($29) {
    $$1$i13 = $27;
    break;
   } else {
    $$01213$i11 = $28;$$014$i10 = $27;
   }
  }
 }
 HEAP8[$$1$i13>>0] = 0;
 $31 = (_strlen($1)|0);
 $32 = $31 >>> 1;
 $33 = ($32|0)==(0);
 if ($33) {
  return ($1|0);
 }
 $34 = (($31) + -1)|0;
 $35 = (($1) + ($34)|0);
 $$01619$i$i17 = $35;$$01718$i$i18 = $1;$$020$i$i16 = $32;
 while(1) {
  $36 = (($$020$i$i16) + -1)|0;
  $37 = HEAP8[$$01718$i$i18>>0]|0;
  $38 = HEAP8[$$01619$i$i17>>0]|0;
  $39 = ((($$01718$i$i18)) + 1|0);
  HEAP8[$$01718$i$i18>>0] = $38;
  $40 = ((($$01619$i$i17)) + -1|0);
  HEAP8[$$01619$i$i17>>0] = $37;
  $41 = ($36|0)==(0);
  if ($41) {
   break;
  } else {
   $$01619$i$i17 = $40;$$01718$i$i18 = $39;$$020$i$i16 = $36;
  }
 }
 return ($1|0);
}
function _SDL_SetHintWithPriority($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$05356 = 0, $$054 = 0, $$05457 = 0, $$05458 = 0, $$lcssa = 0, $$pre = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($0|0)!=(0|0);
 $4 = ($1|0)!=(0|0);
 $or$cond = $3 & $4;
 if (!($or$cond)) {
  $$0 = 0;
  return ($$0|0);
 }
 $5 = (_SDL_getenv($0)|0);
 $6 = ($5|0)!=(0|0);
 $7 = ($2>>>0)<(2);
 $or$cond3 = $7 & $6;
 if ($or$cond3) {
  $$0 = 0;
  return ($$0|0);
 }
 $$05457 = HEAP32[52378]|0;
 $8 = ($$05457|0)==(0|0);
 L7: do {
  if (!($8)) {
   $$05458 = $$05457;
   while(1) {
    $9 = HEAP32[$$05458>>2]|0;
    $10 = (_SDL_strcmp($0,$9)|0);
    $11 = ($10|0)==(0);
    if ($11) {
     break;
    }
    $32 = ((($$05458)) + 16|0);
    $$054 = HEAP32[$32>>2]|0;
    $33 = ($$054|0)==(0|0);
    if ($33) {
     break L7;
    } else {
     $$05458 = $$054;
    }
   }
   $12 = ((($$05458)) + 8|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = ($13>>>0)>($2>>>0);
   if ($14) {
    $$0 = 0;
    return ($$0|0);
   }
   $15 = ((($$05458)) + 4|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ($16|0)==(0|0);
   if ($17) {
    $43 = 0;
    label = 9;
   } else {
    $18 = (_SDL_strcmp($16,$1)|0);
    $19 = ($18|0)==(0);
    if (!($19)) {
     $$pre = HEAP32[$15>>2]|0;
     $43 = $$pre;
     label = 9;
    }
   }
   if ((label|0) == 9) {
    $20 = ((($$05458)) + 12|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = ($21|0)==(0|0);
    if ($22) {
     $$lcssa = $43;
    } else {
     $$05356 = $21;$28 = $43;
     while(1) {
      $23 = ((($$05356)) + 8|0);
      $24 = HEAP32[$23>>2]|0;
      $25 = HEAP32[$$05356>>2]|0;
      $26 = ((($$05356)) + 4|0);
      $27 = HEAP32[$26>>2]|0;
      FUNCTION_TABLE_viiii[$25 & 8191]($27,$0,$28,$1);
      $29 = ($24|0)==(0|0);
      $30 = HEAP32[$15>>2]|0;
      if ($29) {
       $$lcssa = $30;
       break;
      } else {
       $$05356 = $24;$28 = $30;
      }
     }
    }
    _SDL_free($$lcssa);
    $31 = (_SDL_strdup($1)|0);
    HEAP32[$15>>2] = $31;
   }
   HEAP32[$12>>2] = $2;
   $$0 = 1;
   return ($$0|0);
  }
 } while(0);
 $34 = (_SDL_malloc(20)|0);
 $35 = ($34|0)==(0|0);
 if ($35) {
  $$0 = 0;
  return ($$0|0);
 }
 $36 = (_SDL_strdup($0)|0);
 HEAP32[$34>>2] = $36;
 $37 = (_SDL_strdup($1)|0);
 $38 = ((($34)) + 4|0);
 HEAP32[$38>>2] = $37;
 $39 = ((($34)) + 8|0);
 HEAP32[$39>>2] = $2;
 $40 = ((($34)) + 12|0);
 HEAP32[$40>>2] = 0;
 $41 = HEAP32[52378]|0;
 $42 = ((($34)) + 16|0);
 HEAP32[$42>>2] = $41;
 HEAP32[52378] = $34;
 $$0 = 1;
 return ($$0|0);
}
function _EMSCRIPTENAUDIO_Init($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $1 = ((($0)) + 4|0);
 HEAP32[$1>>2] = 4426;
 $2 = ((($0)) + 40|0);
 HEAP32[$2>>2] = 4427;
 $3 = ((($0)) + 72|0);
 HEAP32[$3>>2] = 1;
 $4 = ((($0)) + 64|0);
 HEAP32[$4>>2] = 1;
 $5 = ((($0)) + 60|0);
 HEAP32[$5>>2] = 1;
 $6 = _emscripten_asm_const_i(7)|0;
 $7 = ($6|0)==(0);
 if ($7) {
  (_SDL_SetError(187447,$vararg_buffer)|0);
  $11 = 0;
 } else {
  $8 = _emscripten_asm_const_i(8)|0;
  $9 = ($8|0)!=(0);
  $11 = $9;
 }
 $10 = $11&1;
 $12 = ((($0)) + 68|0);
 HEAP32[$12>>2] = $10;
 $13 = ((($0)) + 76|0);
 HEAP32[$13>>2] = $10;
 STACKTOP = sp;return ($6|0);
}
function _EMSCRIPTENAUDIO_OpenDevice($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $$04347 = 0, $$0444660 = 0, $$lcssa = 0.0, $$pre = 0, $$pre54 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0.0, $25 = 0.0, $26 = 0.0, $27 = 0.0, $28 = 0.0, $29 = 0.0, $30 = 0.0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0.0, $36 = 0.0, $37 = 0.0, $38 = 0.0, $39 = 0.0, $4 = 0, $40 = 0.0, $41 = 0, $42 = 0.0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $cond = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $4 = _emscripten_asm_const_ii(9, ($3|0))|0;
 $5 = ($4|0)<(0);
 if ($5) {
  $6 = (_SDL_SetError(189219,$vararg_buffer)|0);
  $$0 = $6;
  STACKTOP = sp;return ($$0|0);
 }
 $7 = ((($0)) + 4|0);
 $8 = ((($0)) + 8|0);
 $9 = HEAP16[$8>>1]|0;
 $10 = (_SDL_FirstAudioFormat($9)|0);
 $11 = ($10<<16>>16)==(0);
 L5: do {
  if (!($11)) {
   $$04347 = $10;
   while(1) {
    $cond = ($$04347<<16>>16)==(-32480);
    if ($cond) {
     break;
    }
    $12 = (_SDL_NextAudioFormat()|0);
    $13 = ($12<<16>>16)==(0);
    if ($13) {
     break L5;
    } else {
     $$04347 = $12;
    }
   }
   HEAP16[$8>>1] = -32480;
   (_SDL_NextAudioFormat()|0);
   $15 = (_SDL_malloc(20)|0);
   $16 = ((($0)) + 180|0);
   HEAP32[$16>>2] = $15;
   $17 = ($15|0)==(0|0);
   if ($17) {
    $18 = (_SDL_Error(0)|0);
    $$0 = $18;
    STACKTOP = sp;return ($$0|0);
   }
   (_SDL_memset($15,0,20)|0);
   $19 = _emscripten_asm_const_i(10)|0;
   $20 = HEAP32[$7>>2]|0;
   $21 = ($20|0)==($19|0);
   $$pre54 = ((($0)) + 12|0);
   if (!($21)) {
    $22 = HEAP16[$$pre54>>1]|0;
    $23 = ($22<<16>>16)==(0);
    L16: do {
     if (!($23)) {
      $24 = (+($19|0));
      $25 = (+($22&65535));
      $26 = $25 / $24;
      $27 = (+($20|0));
      $28 = $26 * $27;
      $29 = $28;
      $30 = (+_SDL_floor($29));
      $31 = $30 == $29;
      if ($31) {
       $$lcssa = $29;
      } else {
       $32 = $22&65535;
       $$0444660 = $32;
       while(1) {
        $33 = ($$0444660|0)>(1);
        if (!($33)) {
         break L16;
        }
        $34 = (($$0444660) + -1)|0;
        $$pre = HEAP32[$7>>2]|0;
        $35 = (+($34|0));
        $36 = $35 / $24;
        $37 = (+($$pre|0));
        $38 = $36 * $37;
        $39 = $38;
        $40 = (+_SDL_floor($39));
        $41 = $40 == $39;
        if ($41) {
         $$lcssa = $39;
         break;
        } else {
         $$0444660 = $34;
        }
       }
      }
      $42 = (+_SDL_floor($$lcssa));
      $43 = (~~(($42))>>>0);
      $44 = HEAP32[$16>>2]|0;
      $45 = ((($44)) + 8|0);
      HEAP32[$45>>2] = $43;
     }
    } while(0);
    HEAP32[$7>>2] = $19;
   }
   _SDL_CalculateAudioSpec($7);
   $46 = ($3|0)==(0);
   $47 = ((($0)) + 10|0);
   $48 = HEAP8[$47>>0]|0;
   $49 = $48&255;
   $50 = HEAP16[$$pre54>>1]|0;
   $51 = $50&65535;
   if ($46) {
    $53 = _emscripten_asm_const_iiiii(12, ($49|0), ($51|0), (4429|0), ($0|0))|0;
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   } else {
    $52 = _emscripten_asm_const_iiiii(11, ($49|0), ($51|0), (4428|0), ($0|0))|0;
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $14 = (_SDL_SetError(189251,$vararg_buffer1)|0);
 $$0 = $14;
 STACKTOP = sp;return ($$0|0);
}
function _EMSCRIPTENAUDIO_CloseDevice($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 144|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = _emscripten_asm_const_ii(13, ($2|0))|0;
 $4 = ((($0)) + 180|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 _SDL_free($6);
 $7 = HEAP32[$4>>2]|0;
 _SDL_free($7);
 return;
}
function _SDL_FirstAudioFormat($0) {
 $0 = $0|0;
 var $$0$i = 0, $$ph = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[53317] = 0;
 $1 = ($0<<16>>16)==(8);
 if ($1) {
  $$ph = 0;
 } else {
  HEAP32[53317] = 1;
  $2 = ($0<<16>>16)==(-32760);
  if ($2) {
   $$ph = 1;
  } else {
   HEAP32[53317] = 2;
   $5 = ($0<<16>>16)==(-32752);
   if ($5) {
    $$ph = 2;
   } else {
    HEAP32[53317] = 3;
    $6 = ($0<<16>>16)==(-28656);
    if ($6) {
     $$ph = 3;
    } else {
     HEAP32[53317] = 4;
     $7 = ($0<<16>>16)==(16);
     if ($7) {
      $$ph = 4;
     } else {
      HEAP32[53317] = 5;
      $8 = ($0<<16>>16)==(4112);
      if ($8) {
       $$ph = 5;
      } else {
       HEAP32[53317] = 6;
       $9 = ($0<<16>>16)==(-32736);
       if ($9) {
        $$ph = 6;
       } else {
        HEAP32[53317] = 7;
        $10 = ($0<<16>>16)==(-28640);
        if ($10) {
         $$ph = 7;
        } else {
         HEAP32[53317] = 8;
         $11 = ($0<<16>>16)==(-32480);
         if ($11) {
          $$ph = 8;
         } else {
          HEAP32[53317] = 9;
          $12 = ($0<<16>>16)==(-28384);
          if ($12) {
           $$ph = 9;
          } else {
           HEAP32[53317] = 10;
           HEAP32[53318] = 0;
           $$0$i = 0;
           return ($$0$i|0);
          }
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $3 = (99936 + (($$ph*20)|0)|0);
 HEAP32[53318] = 1;
 $4 = HEAP16[$3>>1]|0;
 $$0$i = $4;
 return ($$0$i|0);
}
function _SDL_NextAudioFormat() {
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[53317]|0;
 $1 = ($0|0)==(10);
 $2 = HEAP32[53318]|0;
 $3 = ($2|0)==(10);
 $or$cond = $1 | $3;
 if ($or$cond) {
  $$0 = 0;
  return ($$0|0);
 }
 $4 = ((99936 + (($0*20)|0)|0) + ($2<<1)|0);
 $5 = (($2) + 1)|0;
 HEAP32[53318] = $5;
 $6 = HEAP16[$4>>1]|0;
 $$0 = $6;
 return ($$0|0);
}
function _SDL_CalculateAudioSpec($0) {
 $0 = $0|0;
 var $$sink = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $cond = 0, $div = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 4|0);
 $2 = HEAP16[$1>>1]|0;
 $cond = ($2<<16>>16)==(8);
 $3 = ((($0)) + 7|0);
 $$sink = $cond ? -128 : 0;
 HEAP8[$3>>0] = $$sink;
 $4 = ($2&65535) >>> 3;
 $div = $4 & 31;
 $5 = $div&65535;
 $6 = ((($0)) + 12|0);
 $7 = ((($0)) + 6|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = $8&255;
 $10 = Math_imul($9, $5)|0;
 $11 = ((($0)) + 8|0);
 $12 = HEAP16[$11>>1]|0;
 $13 = $12&65535;
 $14 = Math_imul($13, $10)|0;
 HEAP32[$6>>2] = $14;
 return;
}
function _HandleCaptureProcess($0) {
 $0 = $0|0;
 var $$0 = 0, $$0$in = 0, $$021 = 0, $$021$pre = 0, $$pre = 0, $$pre$phiZ2D = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 136|0);
 $2 = (_SDL_AtomicGet($1)|0);
 $3 = ($2|0)==(0);
 if ($3) {
  return;
 }
 $4 = ((($0)) + 140|0);
 $5 = (_SDL_AtomicGet($4)|0);
 $6 = ($5|0)==(0);
 if (!($6)) {
  return;
 }
 $7 = ((($0)) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0);
 if ($9) {
  $12 = ((($0)) + 180|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = HEAP32[$13>>2]|0;
  $15 = ($14|0)==(0|0);
  $16 = ((($0)) + 16|0);
  if ($15) {
   $17 = HEAP32[$16>>2]|0;
   $18 = (_SDL_malloc($17)|0);
   $19 = HEAP32[$12>>2]|0;
   HEAP32[$19>>2] = $18;
   $20 = ($18|0)==(0|0);
   if ($20) {
    return;
   } else {
    $$0$in = $16;$$021 = $18;$$pre$phiZ2D = $16;
   }
  } else {
   $$0$in = $16;$$021 = $14;$$pre$phiZ2D = $16;
  }
 } else {
  $10 = ((($0)) + 44|0);
  $11 = ((($0)) + 52|0);
  $$021$pre = HEAP32[$10>>2]|0;
  $$pre = ((($0)) + 16|0);
  $$0$in = $11;$$021 = $$021$pre;$$pre$phiZ2D = $$pre;
 }
 $$0 = HEAP32[$$0$in>>2]|0;
 $21 = HEAP32[$$pre$phiZ2D>>2]|0;
 $22 = $21 >>> 2;
 $23 = ((($0)) + 10|0);
 $24 = HEAP8[$23>>0]|0;
 $25 = $24&255;
 $26 = (($22>>>0) / ($25>>>0))&-1;
 $27 = _emscripten_asm_const_iii(14, ($$021|0), ($26|0))|0;
 $28 = HEAP32[$7>>2]|0;
 $29 = ($28|0)==(0);
 if (!($29)) {
  (_SDL_ConvertAudio($7)|0);
 }
 $30 = ((($0)) + 20|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ((($0)) + 24|0);
 $33 = HEAP32[$32>>2]|0;
 FUNCTION_TABLE_viii[$31 & 8191]($33,$$021,$$0);
 return;
}
function _HandleAudioProcess($0) {
 $0 = $0|0;
 var $$ = 0, $$1 = 0, $$2 = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre$i = 0, $$pre$phiZ2D = 0, $$pre$pre$i = 0, $$pre65 = 0, $$sink$i = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $div = 0, $div64 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 8|0);
 $2 = HEAP16[$1>>1]|0;
 $3 = ($2&65535) >>> 3;
 $div = $3 & 31;
 $4 = $div&65535;
 $5 = ((($0)) + 136|0);
 $6 = (_SDL_AtomicGet($5)|0);
 $7 = ($6|0)==(0);
 if ($7) {
  return;
 }
 $8 = ((($0)) + 140|0);
 $9 = (_SDL_AtomicGet($8)|0);
 $10 = ($9|0)==(0);
 if (!($10)) {
  return;
 }
 $11 = ((($0)) + 28|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0);
 $14 = ((($0)) + 180|0);
 $15 = HEAP32[$14>>2]|0;
 if ($13) {
  $96 = HEAP32[$15>>2]|0;
  $97 = ($96|0)==(0|0);
  if ($97) {
   $98 = ((($0)) + 16|0);
   $99 = HEAP32[$98>>2]|0;
   $100 = ((($15)) + 4|0);
   HEAP32[$100>>2] = $99;
   $101 = (_SDL_malloc($99)|0);
   $102 = HEAP32[$14>>2]|0;
   HEAP32[$102>>2] = $101;
   $108 = $102;$110 = $101;
  } else {
   $108 = $15;$110 = $96;
  }
  $103 = ((($0)) + 20|0);
  $104 = HEAP32[$103>>2]|0;
  $105 = ((($0)) + 24|0);
  $106 = HEAP32[$105>>2]|0;
  $107 = ((($108)) + 4|0);
  $109 = HEAP32[$107>>2]|0;
  FUNCTION_TABLE_viii[$104 & 8191]($106,$110,$109);
  $111 = HEAP32[$14>>2]|0;
  $112 = HEAP32[$111>>2]|0;
  $113 = ((($111)) + 4|0);
  $114 = HEAP32[$113>>2]|0;
  $$1 = $112;$$2 = $114;
 } else {
  $16 = ((($15)) + 8|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = ($17|0)==(0);
  if ($18) {
   $$phi$trans$insert = ((($0)) + 48|0);
   $$pre = HEAP32[$$phi$trans$insert>>2]|0;
   $$pre$phiZ2D = $$phi$trans$insert;$35 = $$pre;
  } else {
   $19 = ((($0)) + 32|0);
   $20 = HEAP16[$19>>1]|0;
   $21 = ($20&65535) >>> 3;
   $div64 = $21 & 31;
   $22 = $div64&65535;
   $23 = ((($0)) + 10|0);
   $24 = HEAP8[$23>>0]|0;
   $25 = $24&255;
   $26 = Math_imul($25, $17)|0;
   $27 = Math_imul($26, $22)|0;
   $28 = ((($0)) + 48|0);
   HEAP32[$28>>2] = $27;
   $$pre$phiZ2D = $28;$35 = $27;
  }
  $29 = ((($0)) + 20|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = ((($0)) + 24|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = ((($0)) + 44|0);
  $34 = HEAP32[$33>>2]|0;
  FUNCTION_TABLE_viii[$30 & 8191]($32,$34,$35);
  (_SDL_ConvertAudio($11)|0);
  $36 = HEAP32[$33>>2]|0;
  $37 = ((($0)) + 52|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = ((($0)) + 16|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = ($38|0)==($40|0);
  if ($41) {
   $$1 = $36;$$2 = $38;
  } else {
   $42 = HEAP32[$14>>2]|0;
   $43 = HEAP32[$42>>2]|0;
   $44 = ($43|0)==(0|0);
   if ($44) {
    $45 = ($40>>>0)>($38>>>0);
    $$ = $45 ? $40 : $38;
    $46 = $$ << 1;
    $47 = ((($42)) + 4|0);
    HEAP32[$47>>2] = $46;
    $48 = (_SDL_malloc($46)|0);
    $49 = HEAP32[$14>>2]|0;
    HEAP32[$49>>2] = $48;
    $51 = $49;
   } else {
    $51 = $42;
   }
   while(1) {
    $50 = ((($51)) + 12|0);
    $52 = HEAP32[$50>>2]|0;
    $53 = HEAP32[$37>>2]|0;
    $54 = (($53) + ($52))|0;
    $55 = ((($51)) + 4|0);
    $56 = HEAP32[$55>>2]|0;
    $57 = ($54>>>0)>($56>>>0);
    if ($57) {
     $58 = ((($51)) + 16|0);
     $59 = HEAP32[$58>>2]|0;
     $60 = ($52>>>0)>($59>>>0);
     if ($60) {
      $61 = HEAP32[$51>>2]|0;
      $62 = (($61) + ($59)|0);
      $63 = (($56) - ($59))|0;
      (_SDL_memmove($61,$62,$63)|0);
      $64 = HEAP32[$14>>2]|0;
      $65 = ((($64)) + 12|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = ((($64)) + 16|0);
      $68 = HEAP32[$67>>2]|0;
      $69 = (($66) - ($68))|0;
      $$pre$pre$i = HEAP32[$37>>2]|0;
      $$pre$i = $$pre$pre$i;$$sink$i = $69;$71 = $64;
     } else {
      $$pre$i = $53;$$sink$i = 0;$71 = $51;
     }
     $70 = ((($71)) + 12|0);
     HEAP32[$70>>2] = $$sink$i;
     $72 = ((($71)) + 16|0);
     HEAP32[$72>>2] = 0;
     $74 = $71;$76 = $$sink$i;$78 = $$pre$i;
    } else {
     $74 = $51;$76 = $52;$78 = $53;
    }
    $73 = HEAP32[$74>>2]|0;
    $75 = (($73) + ($76)|0);
    $77 = HEAP32[$33>>2]|0;
    (_SDL_memcpy($75,$77,$78)|0);
    $79 = HEAP32[$37>>2]|0;
    $80 = HEAP32[$14>>2]|0;
    $81 = ((($80)) + 12|0);
    $82 = HEAP32[$81>>2]|0;
    $83 = (($82) + ($79))|0;
    HEAP32[$81>>2] = $83;
    $84 = ((($80)) + 16|0);
    $85 = HEAP32[$84>>2]|0;
    $86 = (($83) - ($85))|0;
    $87 = HEAP32[$39>>2]|0;
    $88 = ($86>>>0)<($87>>>0);
    if (!($88)) {
     break;
    }
    $89 = HEAP32[$29>>2]|0;
    $90 = HEAP32[$31>>2]|0;
    $91 = HEAP32[$33>>2]|0;
    $92 = HEAP32[$$pre$phiZ2D>>2]|0;
    FUNCTION_TABLE_viii[$89 & 8191]($90,$91,$92);
    (_SDL_ConvertAudio($11)|0);
    $$pre65 = HEAP32[$14>>2]|0;
    $51 = $$pre65;
   }
   $93 = HEAP32[$80>>2]|0;
   $94 = (($93) + ($85)|0);
   $95 = (($85) + ($87))|0;
   HEAP32[$84>>2] = $95;
   $$1 = $94;$$2 = $87;
  }
 }
 $115 = ($$1|0)==(0|0);
 if ($115) {
  return;
 }
 $116 = (($$2|0) / ($4|0))&-1;
 $117 = ((($0)) + 10|0);
 $118 = HEAP8[$117>>0]|0;
 $119 = $118&255;
 $120 = (($116|0) / ($119|0))&-1;
 $121 = _emscripten_asm_const_iii(15, ($$1|0), ($120|0))|0;
 return;
}
function _SDL_ConvertAudio($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $1 = ((($0)) + 16|0);
 $2 = HEAPU8[$1>>0]|(HEAPU8[$1+1>>0]<<8)|(HEAPU8[$1+2>>0]<<16)|(HEAPU8[$1+3>>0]<<24);
 $3 = ($2|0)==(0|0);
 if ($3) {
  (_SDL_SetError(191805,$vararg_buffer)|0);
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = ((($0)) + 20|0);
 $5 = HEAPU8[$4>>0]|(HEAPU8[$4+1>>0]<<8)|(HEAPU8[$4+2>>0]<<16)|(HEAPU8[$4+3>>0]<<24);
 $6 = ((($0)) + 24|0);
 HEAP8[$6>>0]=$5&255;HEAP8[$6+1>>0]=($5>>8)&255;HEAP8[$6+2>>0]=($5>>16)&255;HEAP8[$6+3>>0]=$5>>24;
 $7 = ((($0)) + 40|0);
 $8 = HEAPU8[$7>>0]|(HEAPU8[$7+1>>0]<<8)|(HEAPU8[$7+2>>0]<<16)|(HEAPU8[$7+3>>0]<<24);
 $9 = ($8|0)==(0|0);
 if ($9) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $10 = ((($0)) + 80|0);
 HEAP8[$10>>0]=0&255;HEAP8[$10+1>>0]=(0>>8)&255;HEAP8[$10+2>>0]=(0>>16)&255;HEAP8[$10+3>>0]=0>>24;
 $11 = ((($0)) + 4|0);
 $12 = HEAPU8[$11>>0]|(HEAPU8[$11+1>>0]<<8);
 FUNCTION_TABLE_vii[$8 & 8191]($0,$12);
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _DUMMY_Available() {
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_SDL_getenv(194412)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (_SDL_strcmp($0,193157)|0);
  $3 = ($2|0)==(0);
  if ($3) {
   $$0 = 1;
   return ($$0|0);
  }
 }
 $$0 = 0;
 return ($$0|0);
}
function _DUMMY_CreateDevice($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (_SDL_calloc(1,688)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  (_SDL_Error(0)|0);
  $$0 = 0;
  return ($$0|0);
 } else {
  $3 = ((($1)) + 4|0);
  HEAP32[$3>>2] = 4430;
  $4 = ((($1)) + 8|0);
  HEAP32[$4>>2] = 4431;
  $5 = ((($1)) + 28|0);
  HEAP32[$5>>2] = 4432;
  $6 = ((($1)) + 204|0);
  HEAP32[$6>>2] = 4433;
  $7 = ((($1)) + 132|0);
  HEAP32[$7>>2] = 4434;
  $8 = ((($1)) + 136|0);
  HEAP32[$8>>2] = 4435;
  $9 = ((($1)) + 140|0);
  HEAP32[$9>>2] = 4436;
  $10 = ((($1)) + 684|0);
  HEAP32[$10>>2] = 4437;
  $$0 = $1;
  return ($$0|0);
 }
 return (0)|0;
}
function _DUMMY_VideoInit($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $1 = sp;
 HEAP32[$1>>2] = 370546692;
 $2 = ((($1)) + 4|0);
 HEAP32[$2>>2] = 1024;
 $3 = ((($1)) + 8|0);
 HEAP32[$3>>2] = 768;
 $4 = ((($1)) + 12|0);
 HEAP32[$4>>2] = 0;
 $5 = ((($1)) + 16|0);
 HEAP32[$5>>2] = 0;
 $6 = (_SDL_AddBasicVideoDisplay($1)|0);
 $7 = ($6|0)<(0);
 if ($7) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 (_SDL_memset($1,0,20)|0);
 $8 = ((($0)) + 268|0);
 $9 = HEAP32[$8>>2]|0;
 (_SDL_AddDisplayMode($9,$1)|0);
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _DUMMY_VideoQuit($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function _DUMMY_SetDisplayMode($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function _DUMMY_PumpEvents($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function _SDL_DUMMY_CreateWindowFramebuffer($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $5 = sp + 24|0;
 $6 = sp + 20|0;
 $7 = sp + 16|0;
 $8 = sp + 12|0;
 $9 = sp + 8|0;
 $10 = sp + 4|0;
 $11 = sp;
 $12 = (_SDL_GetWindowData($1,192682)|0);
 _SDL_FreeSurface($12);
 (_SDL_PixelFormatEnumToMasks(370546692,$7,$8,$9,$10,$11)|0);
 _SDL_GetWindowSize($1,$5,$6);
 $13 = HEAP32[$5>>2]|0;
 $14 = HEAP32[$6>>2]|0;
 $15 = HEAP32[$7>>2]|0;
 $16 = HEAP32[$8>>2]|0;
 $17 = HEAP32[$9>>2]|0;
 $18 = HEAP32[$10>>2]|0;
 $19 = HEAP32[$11>>2]|0;
 $20 = (_SDL_CreateRGBSurface(0,$13,$14,$15,$16,$17,$18,$19)|0);
 $21 = ($20|0)==(0|0);
 if ($21) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 (_SDL_SetWindowData($1,192682,$20)|0);
 HEAP32[$2>>2] = 370546692;
 $22 = ((($20)) + 20|0);
 $23 = HEAP32[$22>>2]|0;
 HEAP32[$3>>2] = $23;
 $24 = ((($20)) + 16|0);
 $25 = HEAP32[$24>>2]|0;
 HEAP32[$4>>2] = $25;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _SDL_DUMMY_UpdateWindowFramebuffer($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_ptr3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(144|0);
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $4 = sp + 16|0;
 $5 = (_SDL_GetWindowData($1,192682)|0);
 $6 = ($5|0)==(0|0);
 if ($6) {
  $7 = (_SDL_SetError(192700,$vararg_buffer)|0);
  $$0 = $7;
  STACKTOP = sp;return ($$0|0);
 }
 $8 = (_SDL_getenv(192739)|0);
 $9 = ($8|0)==(0|0);
 if ($9) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $10 = (_SDL_GetWindowID($1)|0);
 $11 = HEAP32[53319]|0;
 $12 = (($11) + 1)|0;
 HEAP32[53319] = $12;
 HEAP32[$vararg_buffer1>>2] = $10;
 $vararg_ptr3 = ((($vararg_buffer1)) + 4|0);
 HEAP32[$vararg_ptr3>>2] = $12;
 (_SDL_snprintf($4,128,192767,$vararg_buffer1)|0);
 $13 = (_SDL_RWFromFile($4,193060)|0);
 (_SDL_SaveBMP_RW($5,$13,1)|0);
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _SDL_DUMMY_DestroyWindowFramebuffer($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_SDL_SetWindowData($1,192682,0)|0);
 _SDL_FreeSurface($2);
 return;
}
function _DUMMY_DeleteDevice($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 _SDL_free($0);
 return;
}
function _SDL_SetWindowData($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$037 = 0, $$03741 = 0, $$03743 = 0, $$03842 = 0, $$03842$phi = 0, $$sink = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0;
 var $vararg_buffer3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $vararg_buffer3 = sp + 16|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $3 = HEAP32[52375]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  (_SDL_SetError(175439,$vararg_buffer)|0);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = ($0|0)==(0|0);
 if (!($5)) {
  $6 = HEAP32[$0>>2]|0;
  $7 = ((($3)) + 280|0);
  $8 = ($6|0)==($7|0);
  if ($8) {
   $9 = ($1|0)==(0|0);
   if (!($9)) {
    $10 = HEAP8[$1>>0]|0;
    $11 = ($10<<24>>24)==(0);
    if (!($11)) {
     $12 = ((($0)) + 140|0);
     $$03741 = HEAP32[$12>>2]|0;
     $13 = ($$03741|0)==(0|0);
     L11: do {
      if (!($13)) {
       $$03743 = $$03741;$$03842 = 0;
       while(1) {
        $14 = HEAP32[$$03743>>2]|0;
        $15 = ($14|0)==(0|0);
        if (!($15)) {
         $16 = (_SDL_strcmp($14,$1)|0);
         $17 = ($16|0)==(0);
         if ($17) {
          break;
         }
        }
        $26 = ((($$03743)) + 8|0);
        $$037 = HEAP32[$26>>2]|0;
        $27 = ($$037|0)==(0|0);
        if ($27) {
         break L11;
        } else {
         $$03842$phi = $$03743;$$03743 = $$037;$$03842 = $$03842$phi;
        }
       }
       $18 = ((($$03743)) + 4|0);
       $19 = HEAP32[$18>>2]|0;
       $20 = ($2|0)==(0|0);
       if ($20) {
        $21 = ($$03842|0)!=(0|0);
        $22 = ((($$03743)) + 8|0);
        $23 = HEAP32[$22>>2]|0;
        $24 = ((($$03842)) + 8|0);
        $$sink = $21 ? $24 : $12;
        HEAP32[$$sink>>2] = $23;
        $25 = HEAP32[$$03743>>2]|0;
        _SDL_free($25);
        _SDL_free($$03743);
        $$0 = $19;
        STACKTOP = sp;return ($$0|0);
       } else {
        HEAP32[$18>>2] = $2;
        $$0 = $19;
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     $28 = ($2|0)==(0|0);
     if ($28) {
      $$0 = 0;
      STACKTOP = sp;return ($$0|0);
     }
     $29 = (_SDL_malloc(12)|0);
     $30 = (_SDL_strdup($1)|0);
     HEAP32[$29>>2] = $30;
     $31 = ((($29)) + 4|0);
     HEAP32[$31>>2] = $2;
     $32 = HEAP32[$12>>2]|0;
     $33 = ((($29)) + 8|0);
     HEAP32[$33>>2] = $32;
     HEAP32[$12>>2] = $29;
     $$0 = 0;
     STACKTOP = sp;return ($$0|0);
    }
   }
   HEAP32[$vararg_buffer3>>2] = 194235;
   (_SDL_SetError(194740,$vararg_buffer3)|0);
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 (_SDL_SetError(195204,$vararg_buffer1)|0);
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _SDL_GetWindowData($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$013 = 0, $$015 = 0, $$016 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $vararg_buffer3 = sp + 16|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $2 = HEAP32[52375]|0;
 $3 = ($2|0)==(0|0);
 L1: do {
  if ($3) {
   (_SDL_SetError(175439,$vararg_buffer)|0);
   $$013 = 0;
  } else {
   $4 = ($0|0)==(0|0);
   if (!($4)) {
    $5 = HEAP32[$0>>2]|0;
    $6 = ((($2)) + 280|0);
    $7 = ($5|0)==($6|0);
    if ($7) {
     $8 = ($1|0)==(0|0);
     if (!($8)) {
      $9 = HEAP8[$1>>0]|0;
      $10 = ($9<<24>>24)==(0);
      if (!($10)) {
       $11 = ((($0)) + 140|0);
       $$015 = HEAP32[$11>>2]|0;
       $12 = ($$015|0)==(0|0);
       if ($12) {
        $$013 = 0;
        break;
       } else {
        $$016 = $$015;
       }
       while(1) {
        $13 = HEAP32[$$016>>2]|0;
        $14 = ($13|0)==(0|0);
        if (!($14)) {
         $15 = (_SDL_strcmp($13,$1)|0);
         $16 = ($15|0)==(0);
         if ($16) {
          break;
         }
        }
        $19 = ((($$016)) + 8|0);
        $$0 = HEAP32[$19>>2]|0;
        $20 = ($$0|0)==(0|0);
        if ($20) {
         $$013 = 0;
         break L1;
        } else {
         $$016 = $$0;
        }
       }
       $17 = ((($$016)) + 4|0);
       $18 = HEAP32[$17>>2]|0;
       $$013 = $18;
       break;
      }
     }
     HEAP32[$vararg_buffer3>>2] = 194235;
     (_SDL_SetError(194740,$vararg_buffer3)|0);
     $$013 = 0;
     break;
    }
   }
   (_SDL_SetError(195204,$vararg_buffer1)|0);
   $$013 = 0;
  }
 } while(0);
 STACKTOP = sp;return ($$013|0);
}
function _SDL_GetWindowID($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $1 = HEAP32[52375]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  (_SDL_SetError(175439,$vararg_buffer)|0);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = ($0|0)==(0|0);
 if (!($3)) {
  $4 = HEAP32[$0>>2]|0;
  $5 = ((($1)) + 280|0);
  $6 = ($4|0)==($5|0);
  if ($6) {
   $7 = ((($0)) + 4|0);
   $8 = HEAP32[$7>>2]|0;
   $$0 = $8;
   STACKTOP = sp;return ($$0|0);
  }
 }
 (_SDL_SetError(195204,$vararg_buffer1)|0);
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _SDL_RWFromFile($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $vararg_buffer = 0;
 var $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $2 = ($0|0)==(0|0);
 if (!($2)) {
  $3 = HEAP8[$0>>0]|0;
  $4 = ($3<<24>>24)!=(0);
  $5 = ($1|0)!=(0|0);
  $or$cond = $5 & $4;
  if ($or$cond) {
   $6 = HEAP8[$1>>0]|0;
   $7 = ($6<<24>>24)==(0);
   if (!($7)) {
    $8 = (_fopen($0,$1)|0);
    $9 = ($8|0)==(0|0);
    if ($9) {
     HEAP32[$vararg_buffer1>>2] = $0;
     (_SDL_SetError(192928,$vararg_buffer1)|0);
     $$0 = 0;
     STACKTOP = sp;return ($$0|0);
    }
    $10 = (_SDL_malloc(36)|0);
    $11 = ($10|0)==(0|0);
    if ($11) {
     (_SDL_Error(0)|0);
     $$0 = $10;
     STACKTOP = sp;return ($$0|0);
    } else {
     $12 = ((($10)) + 20|0);
     HEAP32[$10>>2] = 4438;
     $13 = ((($10)) + 4|0);
     HEAP32[$13>>2] = 4439;
     $14 = ((($10)) + 8|0);
     HEAP32[$14>>2] = 4440;
     $15 = ((($10)) + 12|0);
     HEAP32[$15>>2] = 4441;
     $16 = ((($10)) + 16|0);
     HEAP32[$16>>2] = 4442;
     $17 = ((($10)) + 24|0);
     $18 = ((($10)) + 28|0);
     HEAP32[$18>>2] = $8;
     HEAP32[$17>>2] = 1;
     HEAP32[$12>>2] = 2;
     $$0 = $10;
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 }
 (_SDL_SetError(192881,$vararg_buffer)|0);
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _SDL_SaveBMP_RW($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$ = 0, $$0 = 0, $$0234267271 = 0, $$0244 = 0, $$0245257265272 = 0, $$0245258261263 = 0, $$0246 = 0, $$0246273 = 0, $$1284 = 0, $$2275$us280 = 0, $$249 = 0, $$255 = 0, $$pre = 0, $$pre294 = 0, $$pre295 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0;
 var $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0;
 var $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0;
 var $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0;
 var $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0;
 var $177 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $exitcond292 = 0, $not$ = 0, $or$cond5 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(64|0);
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $3 = sp + 56|0;
 $4 = sp + 12|0;
 $5 = sp + 58|0;
 HEAP16[$3>>1] = 19778;
 $6 = ($1|0)==(0|0);
 if ($6) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 $7 = ((($0)) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($8)) + 8|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = ($10&255)>(7);
 do {
  if ($12) {
   $13 = ((($8)) + 24|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = ($14|0)==(0);
   if ($15) {
    $16 = ((($0)) + 52|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = ((($17)) + 68|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = $19 & 256;
    $21 = ($20|0)==(0);
    if ($21) {
     label = 6;
     break;
    }
   }
   (_SDL_InitFormat($4,372645892)|0);
   $$0245258261263 = 1;$176 = $4;$177 = 1;
   label = 14;
  } else {
   label = 6;
  }
 } while(0);
 do {
  if ((label|0) == 6) {
   $22 = ((($8)) + 4|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = ($23|0)==(0|0);
   if (!($24)) {
    $25 = ($10<<24>>24)==(8);
    if ($25) {
     $$0234267271 = $0;$$0245257265272 = 0;$$0246273 = 0;
     label = 19;
     break;
    }
    HEAP32[$vararg_buffer>>2] = $11;
    (_SDL_SetError(192790,$vararg_buffer)|0);
    break;
   }
   $26 = ($10<<24>>24)==(24);
   if ($26) {
    $27 = ((($8)) + 12|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = ($28|0)==(16711680);
    if ($29) {
     $30 = ((($8)) + 16|0);
     $31 = HEAP32[$30>>2]|0;
     $32 = ($31|0)==(65280);
     if ($32) {
      $33 = ((($8)) + 20|0);
      $34 = HEAP32[$33>>2]|0;
      $35 = ($34|0)==(255);
      if ($35) {
       $$0234267271 = $0;$$0245257265272 = 0;$$0246273 = 0;
       label = 19;
       break;
      }
     }
    }
   }
   (_SDL_InitFormat($4,390076419)|0);
   $$0245258261263 = 0;$176 = $4;$177 = 0;
   label = 14;
  }
 } while(0);
 if ((label|0) == 14) {
  $36 = (_SDL_ConvertSurface($0,$4,0)|0);
  $37 = ($36|0)==(0|0);
  if ($37) {
   $38 = ((($4)) + 8|0);
   $39 = HEAP8[$38>>0]|0;
   $40 = $39&255;
   HEAP32[$vararg_buffer1>>2] = $40;
   (_SDL_SetError(192821,$vararg_buffer1)|0);
  }
  if ($177) {
   $41 = (_SDL_GetHintBoolean(192854,0)|0);
   $$0246 = $41;
  } else {
   $$0246 = 0;
  }
  if (!($37)) {
   $$0234267271 = $36;$$0245257265272 = $$0245258261263;$$0246273 = $$0246;
   label = 19;
  }
 }
 if ((label|0) == 19) {
  $42 = (_SDL_LockSurface($$0234267271)|0);
  $43 = ($42|0)==(0);
  if ($43) {
   $44 = ((($$0234267271)) + 8|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = ((($$0234267271)) + 4|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = ((($47)) + 9|0);
   $49 = HEAP8[$48>>0]|0;
   $50 = $49&255;
   $51 = Math_imul($50, $45)|0;
   $52 = ((($1)) + 4|0);
   $53 = HEAP32[$52>>2]|0;
   $54 = (FUNCTION_TABLE_iiiii[$53 & 8191]($1,0,0,1)|0);
   $55 = tempRet0;
   _SDL_ClearError();
   $56 = ((($1)) + 12|0);
   $57 = HEAP32[$56>>2]|0;
   (FUNCTION_TABLE_iiiii[$57 & 8191]($1,$3,2,1)|0);
   (_SDL_WriteLE32($1,0)|0);
   (_SDL_WriteLE16($1,0)|0);
   (_SDL_WriteLE16($1,0)|0);
   (_SDL_WriteLE32($1,0)|0);
   $58 = HEAP32[$44>>2]|0;
   $59 = ((($$0234267271)) + 12|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = HEAP32[$46>>2]|0;
   $62 = ((($61)) + 8|0);
   $63 = HEAP8[$62>>0]|0;
   $64 = $63&255;
   $65 = ((($$0234267271)) + 16|0);
   $66 = HEAP32[$65>>2]|0;
   $67 = Math_imul($66, $60)|0;
   $68 = ((($61)) + 4|0);
   $69 = HEAP32[$68>>2]|0;
   $70 = ($69|0)==(0|0);
   if ($70) {
    $$0244 = 0;
   } else {
    $71 = HEAP32[$69>>2]|0;
    $$0244 = $71;
   }
   $72 = ($$0245257265272|0)==(0);
   $73 = ($$0246273|0)!=(0);
   $or$cond5 = $73 | $72;
   $$ = $or$cond5 ? 40 : 108;
   $$249 = $or$cond5 ? 0 : 3;
   (_SDL_WriteLE32($1,$$)|0);
   (_SDL_WriteLE32($1,$58)|0);
   (_SDL_WriteLE32($1,$60)|0);
   (_SDL_WriteLE16($1,1)|0);
   (_SDL_WriteLE16($1,$64)|0);
   (_SDL_WriteLE32($1,$$249)|0);
   (_SDL_WriteLE32($1,$67)|0);
   (_SDL_WriteLE32($1,0)|0);
   (_SDL_WriteLE32($1,0)|0);
   (_SDL_WriteLE32($1,$$0244)|0);
   (_SDL_WriteLE32($1,0)|0);
   if (!($or$cond5)) {
    (_SDL_WriteLE32($1,16711680)|0);
    (_SDL_WriteLE32($1,65280)|0);
    (_SDL_WriteLE32($1,255)|0);
    (_SDL_WriteLE32($1,-16777216)|0);
    (_SDL_WriteLE32($1,1466527264)|0);
    (_SDL_WriteLE32($1,0)|0);
    (_SDL_WriteLE32($1,0)|0);
    (_SDL_WriteLE32($1,0)|0);
    (_SDL_WriteLE32($1,0)|0);
    (_SDL_WriteLE32($1,0)|0);
    (_SDL_WriteLE32($1,0)|0);
    (_SDL_WriteLE32($1,0)|0);
    (_SDL_WriteLE32($1,0)|0);
    (_SDL_WriteLE32($1,0)|0);
    (_SDL_WriteLE32($1,0)|0);
    (_SDL_WriteLE32($1,0)|0);
    (_SDL_WriteLE32($1,0)|0);
   }
   $74 = HEAP32[$46>>2]|0;
   $75 = ((($74)) + 4|0);
   $76 = HEAP32[$75>>2]|0;
   $77 = ($76|0)==(0|0);
   if (!($77)) {
    $78 = ((($76)) + 4|0);
    $79 = HEAP32[$78>>2]|0;
    $80 = HEAP32[$76>>2]|0;
    $81 = ($80|0)>(0);
    if ($81) {
     $$1284 = 0;
     while(1) {
      $82 = HEAP32[$56>>2]|0;
      $83 = (((($79) + ($$1284<<2)|0)) + 2|0);
      (FUNCTION_TABLE_iiiii[$82 & 8191]($1,$83,1,1)|0);
      $84 = HEAP32[$56>>2]|0;
      $85 = (((($79) + ($$1284<<2)|0)) + 1|0);
      (FUNCTION_TABLE_iiiii[$84 & 8191]($1,$85,1,1)|0);
      $86 = HEAP32[$56>>2]|0;
      $87 = (($79) + ($$1284<<2)|0);
      (FUNCTION_TABLE_iiiii[$86 & 8191]($1,$87,1,1)|0);
      $88 = HEAP32[$56>>2]|0;
      $89 = (((($79) + ($$1284<<2)|0)) + 3|0);
      (FUNCTION_TABLE_iiiii[$88 & 8191]($1,$89,1,1)|0);
      $90 = (($$1284) + 1)|0;
      $exitcond292 = ($90|0)==($80|0);
      if ($exitcond292) {
       break;
      } else {
       $$1284 = $90;
      }
     }
    }
   }
   $91 = HEAP32[$52>>2]|0;
   $92 = (FUNCTION_TABLE_iiiii[$91 & 8191]($1,0,0,1)|0);
   $93 = tempRet0;
   $94 = (_i64Subtract(($92|0),($93|0),($54|0),($55|0))|0);
   $95 = tempRet0;
   $96 = HEAP32[$52>>2]|0;
   $97 = (_i64Add(($54|0),($55|0),10,0)|0);
   $98 = tempRet0;
   (FUNCTION_TABLE_iiiii[$96 & 8191]($1,$97,$98,0)|0);
   $99 = tempRet0;
   $100 = ($99|0)<(0);
   if ($100) {
    (_SDL_Error(3)|0);
   }
   (_SDL_WriteLE32($1,$94)|0);
   $101 = HEAP32[$52>>2]|0;
   $102 = (_i64Add(($94|0),0,($54|0),($55|0))|0);
   $103 = tempRet0;
   (FUNCTION_TABLE_iiiii[$101 & 8191]($1,$102,$103,0)|0);
   $104 = tempRet0;
   $105 = ($104|0)<(0);
   if ($105) {
    (_SDL_Error(3)|0);
   }
   $106 = ((($$0234267271)) + 20|0);
   $107 = HEAP32[$106>>2]|0;
   $108 = HEAP32[$59>>2]|0;
   $109 = HEAP32[$65>>2]|0;
   $110 = Math_imul($109, $108)|0;
   $111 = (($107) + ($110)|0);
   $112 = (($51|0) % 4)&-1;
   $113 = ($112|0)==(0);
   $114 = (4 - ($112))|0;
   $$255 = $113 ? 0 : $114;
   $115 = ($110|0)>(0);
   L48: do {
    if ($115) {
     $116 = ($$255|0)==(0);
     L50: do {
      if ($116) {
       $117 = (0 - ($109))|0;
       $118 = (($111) + ($117)|0);
       $119 = HEAP32[$56>>2]|0;
       $120 = (FUNCTION_TABLE_iiiii[$119 & 8191]($1,$118,1,$51)|0);
       $121 = ($120|0)==($51|0);
       if ($121) {
        $123 = $118;
        while(1) {
         $122 = HEAP32[$106>>2]|0;
         $124 = ($123>>>0)>($122>>>0);
         if (!($124)) {
          break L48;
         }
         $$pre295 = HEAP32[$65>>2]|0;
         $125 = (0 - ($$pre295))|0;
         $126 = (($123) + ($125)|0);
         $127 = HEAP32[$56>>2]|0;
         $128 = (FUNCTION_TABLE_iiiii[$127 & 8191]($1,$126,1,$51)|0);
         $129 = ($128|0)==($51|0);
         if ($129) {
          $123 = $126;
         } else {
          break;
         }
        }
       }
      } else {
       $130 = ($$255|0)>(0);
       $131 = (0 - ($109))|0;
       $132 = (($111) + ($131)|0);
       $133 = HEAP32[$56>>2]|0;
       $134 = (FUNCTION_TABLE_iiiii[$133 & 8191]($1,$132,1,$51)|0);
       $135 = ($134|0)==($51|0);
       if (!($130)) {
        if ($135) {
         $147 = $132;
        } else {
         break;
        }
        while(1) {
         $146 = HEAP32[$106>>2]|0;
         $148 = ($147>>>0)>($146>>>0);
         if (!($148)) {
          break L48;
         }
         $$pre = HEAP32[$65>>2]|0;
         $149 = (0 - ($$pre))|0;
         $150 = (($147) + ($149)|0);
         $151 = HEAP32[$56>>2]|0;
         $152 = (FUNCTION_TABLE_iiiii[$151 & 8191]($1,$150,1,$51)|0);
         $153 = ($152|0)==($51|0);
         if ($153) {
          $147 = $150;
         } else {
          break L50;
         }
        }
       }
       if ($135) {
        $139 = $132;
        while(1) {
         HEAP8[$5>>0] = 0;
         $$2275$us280 = 0;
         while(1) {
          $136 = HEAP32[$56>>2]|0;
          (FUNCTION_TABLE_iiiii[$136 & 8191]($1,$5,1,1)|0);
          $137 = (($$2275$us280) + 1)|0;
          $exitcond = ($137|0)==($$255|0);
          if ($exitcond) {
           break;
          } else {
           $$2275$us280 = $137;
          }
         }
         $138 = HEAP32[$106>>2]|0;
         $140 = ($139>>>0)>($138>>>0);
         if (!($140)) {
          break L48;
         }
         $$pre294 = HEAP32[$65>>2]|0;
         $141 = (0 - ($$pre294))|0;
         $142 = (($139) + ($141)|0);
         $143 = HEAP32[$56>>2]|0;
         $144 = (FUNCTION_TABLE_iiiii[$143 & 8191]($1,$142,1,$51)|0);
         $145 = ($144|0)==($51|0);
         if ($145) {
          $139 = $142;
         } else {
          break;
         }
        }
       }
      }
     } while(0);
     (_SDL_Error(2)|0);
    }
   } while(0);
   $154 = HEAP32[$52>>2]|0;
   $155 = (FUNCTION_TABLE_iiiii[$154 & 8191]($1,0,0,1)|0);
   $156 = tempRet0;
   $157 = (_i64Subtract(($155|0),($156|0),($54|0),($55|0))|0);
   $158 = tempRet0;
   $159 = HEAP32[$52>>2]|0;
   $160 = (_i64Add(($54|0),($55|0),2,0)|0);
   $161 = tempRet0;
   (FUNCTION_TABLE_iiiii[$159 & 8191]($1,$160,$161,0)|0);
   $162 = tempRet0;
   $163 = ($162|0)<(0);
   if ($163) {
    (_SDL_Error(3)|0);
   }
   (_SDL_WriteLE32($1,$157)|0);
   $164 = HEAP32[$52>>2]|0;
   $165 = (_i64Add(($157|0),0,($54|0),($55|0))|0);
   $166 = tempRet0;
   (FUNCTION_TABLE_iiiii[$164 & 8191]($1,$165,$166,0)|0);
   $167 = tempRet0;
   $168 = ($167|0)<(0);
   if ($168) {
    (_SDL_Error(3)|0);
   }
   _SDL_UnlockSurface($$0234267271);
   $169 = ($$0234267271|0)==($0|0);
   if (!($169)) {
    _SDL_FreeSurface($$0234267271);
   }
  }
 }
 $170 = ($2|0)==(0);
 if (!($170)) {
  $171 = ((($1)) + 16|0);
  $172 = HEAP32[$171>>2]|0;
  (FUNCTION_TABLE_ii[$172 & 8191]($1)|0);
 }
 $173 = (_SDL_GetError()|0);
 $174 = (_SDL_strcmp($173,221531)|0);
 $not$ = ($174|0)!=(0);
 $175 = $not$ << 31 >> 31;
 $$0 = $175;
 STACKTOP = sp;return ($$0|0);
}
function _SDL_ClearError() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[51558] = 0;
 return;
}
function _SDL_WriteLE32($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 HEAP32[$2>>2] = $1;
 $3 = ((($0)) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_iiiii[$4 & 8191]($0,$2,4,1)|0);
 STACKTOP = sp;return ($5|0);
}
function _SDL_WriteLE16($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 HEAP16[$2>>1] = $1;
 $3 = ((($0)) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_iiiii[$4 & 8191]($0,$2,2,1)|0);
 STACKTOP = sp;return ($5|0);
}
function _stdio_size($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_iiiii[$2 & 8191]($0,0,0,1)|0);
 $4 = tempRet0;
 $5 = ($4|0)<(0);
 if ($5) {
  $11 = -1;$12 = -1;
  tempRet0 = ($11);
  return ($12|0);
 }
 $6 = HEAP32[$1>>2]|0;
 $7 = (FUNCTION_TABLE_iiiii[$6 & 8191]($0,0,0,2)|0);
 $8 = tempRet0;
 $9 = HEAP32[$1>>2]|0;
 (FUNCTION_TABLE_iiiii[$9 & 8191]($0,$3,$4,0)|0);
 $10 = tempRet0;
 $11 = $8;$12 = $7;
 tempRet0 = ($11);
 return ($12|0);
}
function _stdio_seek($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0$in = 0, $10 = 0, $11 = 0, $12 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ((($0)) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (___fseeko($5,$1,$3)|0);
 $7 = ($6|0)==(0);
 if ($7) {
  $8 = HEAP32[$4>>2]|0;
  $9 = (___ftello($8)|0);
  $$0$in = $9;
 } else {
  $10 = (_SDL_Error(3)|0);
  $$0$in = $10;
 }
 $11 = ($$0$in|0)<(0);
 $12 = $11 << 31 >> 31;
 tempRet0 = ($12);
 return ($$0$in|0);
}
function _stdio_read($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $10 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ((($0)) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (_fread($1,$2,$3,$5)|0);
 $7 = ($6|0)==(0);
 if (!($7)) {
  return ($6|0);
 }
 $8 = HEAP32[$4>>2]|0;
 $9 = (_ferror($8)|0);
 $10 = ($9|0)==(0);
 if ($10) {
  return ($6|0);
 }
 (_SDL_Error(1)|0);
 return ($6|0);
}
function _stdio_write($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $10 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ((($0)) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (_fwrite($1,$2,$3,$5)|0);
 $7 = ($6|0)==(0);
 if (!($7)) {
  return ($6|0);
 }
 $8 = HEAP32[$4>>2]|0;
 $9 = (_ferror($8)|0);
 $10 = ($9|0)==(0);
 if ($10) {
  return ($6|0);
 }
 (_SDL_Error(2)|0);
 return ($6|0);
}
function _stdio_close($0) {
 $0 = $0|0;
 var $$0 = 0, $$1 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ($0|0)==(0|0);
 if ($1) {
  $$1 = 0;
  return ($$1|0);
 }
 $2 = ((($0)) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  $$0 = 0;
 } else {
  $5 = ((($0)) + 28|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (_fclose($6)|0);
  $8 = ($7|0)==(0);
  if ($8) {
   $$0 = 0;
  } else {
   $9 = (_SDL_Error(2)|0);
   $$0 = $9;
  }
 }
 _SDL_free($0);
 $$1 = $$0;
 return ($$1|0);
}
function _DISKAUDIO_Init($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 4|0);
 HEAP32[$1>>2] = 4443;
 $2 = ((($0)) + 12|0);
 HEAP32[$2>>2] = 4444;
 $3 = ((($0)) + 16|0);
 HEAP32[$3>>2] = 4445;
 $4 = ((($0)) + 24|0);
 HEAP32[$4>>2] = 4446;
 $5 = ((($0)) + 28|0);
 HEAP32[$5>>2] = 4447;
 $6 = ((($0)) + 32|0);
 HEAP32[$6>>2] = 4448;
 $7 = ((($0)) + 40|0);
 HEAP32[$7>>2] = 4449;
 HEAP32[$0>>2] = 4450;
 $8 = ((($0)) + 80|0);
 HEAP32[$8>>2] = 1;
 $9 = ((($0)) + 68|0);
 HEAP32[$9>>2] = 1;
 return 1;
}
function _DISKAUDIO_OpenDevice($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$$i = 0, $$0 = 0, $$sink = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $4 = ($1|0)!=(0|0);
 $5 = $4 ? 0 : $2;
 $6 = ($5|0)==(0|0);
 $7 = ($3|0)!=(0);
 if ($6) {
  $8 = $7 ? 192971 : 192987;
  $9 = $7 ? 193000 : 193020;
  $10 = (_SDL_getenv($9)|0);
  $11 = ($10|0)==(0|0);
  $$$i = $11 ? $8 : $10;
  $29 = $$$i;
 } else {
  $29 = $5;
 }
 $12 = (_SDL_getenv(193038)|0);
 $13 = (_SDL_malloc(12)|0);
 $14 = ((($0)) + 180|0);
 HEAP32[$14>>2] = $13;
 $15 = ($13|0)==(0|0);
 if ($15) {
  $16 = (_SDL_Error(0)|0);
  $$0 = $16;
  STACKTOP = sp;return ($$0|0);
 }
 (_SDL_memset($13,0,12)|0);
 $17 = ($12|0)==(0|0);
 if ($17) {
  $19 = ((($0)) + 12|0);
  $20 = HEAP16[$19>>1]|0;
  $21 = $20&65535;
  $22 = ($21*1000)|0;
  $23 = ((($0)) + 4|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = (($22|0) / ($24|0))&-1;
  $$sink = $25;
 } else {
  $18 = (_SDL_atoi($12)|0);
  $$sink = $18;
 }
 $26 = HEAP32[$14>>2]|0;
 $27 = ((($26)) + 4|0);
 HEAP32[$27>>2] = $$sink;
 $28 = $7 ? 193057 : 193060;
 $30 = (_SDL_RWFromFile($29,$28)|0);
 $31 = HEAP32[$14>>2]|0;
 HEAP32[$31>>2] = $30;
 $32 = ($30|0)==(0|0);
 if ($32) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 do {
  if (!($7)) {
   $33 = ((($0)) + 16|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = (_SDL_malloc($34)|0);
   $36 = HEAP32[$14>>2]|0;
   $37 = ((($36)) + 8|0);
   HEAP32[$37>>2] = $35;
   $38 = ($35|0)==(0|0);
   if (!($38)) {
    $40 = ((($0)) + 11|0);
    $41 = HEAP8[$40>>0]|0;
    $42 = $41&255;
    $43 = HEAP32[$33>>2]|0;
    (_SDL_memset($35,$42,$43)|0);
    break;
   }
   $39 = (_SDL_Error(0)|0);
   $$0 = $39;
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 $44 = HEAP32[23152]|0;
 $45 = $7 ? 193063 : 193076;
 HEAP32[$vararg_buffer>>2] = $45;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $29;
 (_fprintf($44,193087,$vararg_buffer)|0);
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _DISKAUDIO_WaitDevice($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 180|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 _SDL_Delay($4);
 return;
}
function _DISKAUDIO_PlayDevice($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 180|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($2)) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($0)) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (FUNCTION_TABLE_iiiii[$5 & 8191]($3,$7,1,$9)|0);
 $11 = HEAP32[$8>>2]|0;
 $12 = ($10|0)==($11|0);
 if ($12) {
  return;
 }
 _SDL_OpenedAudioDeviceDisconnected($0);
 return;
}
function _DISKAUDIO_GetDeviceBuf($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 180|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 return ($4|0);
}
function _DISKAUDIO_CaptureFromDevice($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$024 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 180|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($4)) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 _SDL_Delay($6);
 $7 = HEAP32[$4>>2]|0;
 $8 = ($7|0)==(0|0);
 if ($8) {
  $$0 = $1;$$024 = $2;
 } else {
  $9 = ((($7)) + 8|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (FUNCTION_TABLE_iiiii[$10 & 8191]($7,$1,1,$2)|0);
  $12 = (($2) - ($11))|0;
  $13 = (($1) + ($11)|0);
  $14 = ($12|0)>(0);
  if ($14) {
   $15 = HEAP32[$4>>2]|0;
   $16 = ((($15)) + 16|0);
   $17 = HEAP32[$16>>2]|0;
   (FUNCTION_TABLE_ii[$17 & 8191]($15)|0);
   HEAP32[$4>>2] = 0;
   $$0 = $13;$$024 = $12;
  } else {
   $$0 = $13;$$024 = $12;
  }
 }
 $18 = ((($0)) + 11|0);
 $19 = HEAP8[$18>>0]|0;
 $20 = $19&255;
 (_SDL_memset($$0,$20,$$024)|0);
 return ($2|0);
}
function _DISKAUDIO_FlushCapture($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function _DISKAUDIO_CloseDevice($0) {
 $0 = $0|0;
 var $$pre = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 180|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $8 = $2;
 } else {
  $5 = ((($3)) + 16|0);
  $6 = HEAP32[$5>>2]|0;
  (FUNCTION_TABLE_ii[$6 & 8191]($3)|0);
  $$pre = HEAP32[$1>>2]|0;
  $8 = $$pre;
 }
 $7 = ((($8)) + 8|0);
 $9 = HEAP32[$7>>2]|0;
 _SDL_free($9);
 $10 = HEAP32[$1>>2]|0;
 _SDL_free($10);
 return;
}
function _DISKAUDIO_DetectDevices() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 _SDL_AddAudioDevice(0,194323,(1));
 _SDL_AddAudioDevice(1,194350,(2));
 return;
}
function _SDL_AddAudioDevice($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(64|0);
 $3 = sp;
 $4 = ($0|0)==(0);
 $5 = (_SDL_strlen($1)|0);
 $6 = (($5) + 9)|0;
 $7 = (_SDL_malloc($6)|0);
 $8 = ($7|0)==(0|0);
 do {
  if ($4) {
   if ($8) {
    STACKTOP = sp;return;
   } else {
    HEAP32[$7>>2] = $2;
    $15 = ((($7)) + 8|0);
    $16 = (($5) + 1)|0;
    (_SDL_strlcpy($15,$1,$16)|0);
    $17 = HEAP32[(213392)>>2]|0;
    $18 = ((($7)) + 4|0);
    HEAP32[$18>>2] = $17;
    HEAP32[(213392)>>2] = $7;
    $19 = HEAP32[(213384)>>2]|0;
    $20 = (($19) + 1)|0;
    HEAP32[(213384)>>2] = $20;
    $21 = $19;
    break;
   }
  } else {
   if ($8) {
    STACKTOP = sp;return;
   } else {
    HEAP32[$7>>2] = $2;
    $9 = ((($7)) + 8|0);
    $10 = (($5) + 1)|0;
    (_SDL_strlcpy($9,$1,$10)|0);
    $11 = HEAP32[(213396)>>2]|0;
    $12 = ((($7)) + 4|0);
    HEAP32[$12>>2] = $11;
    HEAP32[(213396)>>2] = $7;
    $13 = HEAP32[(213388)>>2]|0;
    $14 = (($13) + 1)|0;
    HEAP32[(213388)>>2] = $14;
    $21 = $13;
    break;
   }
  }
 } while(0);
 $22 = ($21|0)==(-1);
 if ($22) {
  STACKTOP = sp;return;
 }
 $23 = (_SDL_EventState(4352,-1)|0);
 $24 = ($23<<24>>24)==(1);
 if (!($24)) {
  STACKTOP = sp;return;
 }
 (_SDL_memset($3,0,56)|0);
 HEAP32[$3>>2] = 4352;
 $25 = ((($3)) + 8|0);
 HEAP32[$25>>2] = $21;
 $26 = $0&255;
 $27 = ((($3)) + 12|0);
 HEAP8[$27>>0] = $26;
 (_SDL_PushEvent($3)|0);
 STACKTOP = sp;return;
}
function _SDL_OpenedAudioDeviceDisconnected($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(64|0);
 $1 = sp;
 $2 = ((($0)) + 136|0);
 $3 = (_SDL_AtomicGet($2)|0);
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = HEAP32[(213332)>>2]|0;
 FUNCTION_TABLE_vi[$5 & 8191]($0);
 (_SDL_AtomicSet($2,0)|0);
 $6 = HEAP32[(213336)>>2]|0;
 FUNCTION_TABLE_vi[$6 & 8191]($0);
 $7 = (_SDL_EventState(4353,-1)|0);
 $8 = ($7<<24>>24)==(1);
 if (!($8)) {
  STACKTOP = sp;return;
 }
 (_SDL_memset($1,0,56)|0);
 HEAP32[$1>>2] = 4353;
 $9 = HEAP32[$0>>2]|0;
 $10 = ((($1)) + 8|0);
 HEAP32[$10>>2] = $9;
 $11 = ((($0)) + 144|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)!=(0);
 $14 = $13&1;
 $15 = ((($1)) + 12|0);
 HEAP8[$15>>0] = $14;
 (_SDL_PushEvent($1)|0);
 STACKTOP = sp;return;
}
function _SDL_AtomicSet($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;HEAP32[$0>>2] = $1;
 return ($2|0);
}
function _SDL_atoi($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (_atoi($0)|0);
 return ($1|0);
}
function _DUMMYAUDIO_Init($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 4|0);
 HEAP32[$1>>2] = 4451;
 $2 = ((($0)) + 28|0);
 HEAP32[$2>>2] = 4452;
 $3 = ((($0)) + 72|0);
 HEAP32[$3>>2] = 1;
 $4 = ((($0)) + 76|0);
 HEAP32[$4>>2] = 1;
 $5 = ((($0)) + 68|0);
 HEAP32[$5>>2] = 1;
 return 1;
}
function _DUMMYAUDIO_OpenDevice($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function _DUMMYAUDIO_CaptureFromDevice($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 12|0);
 $4 = HEAP16[$3>>1]|0;
 $5 = $4&65535;
 $6 = ($5*1000)|0;
 $7 = ((($0)) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($6|0) / ($8|0))&-1;
 _SDL_Delay($9);
 $10 = ((($0)) + 11|0);
 $11 = HEAP8[$10>>0]|0;
 $12 = $11&255;
 (_SDL_memset($1,$12,$2)|0);
 return ($2|0);
}
function _SDL_InitSubSystem($0) {
 $0 = $0|0;
 var $$0$ = 0, $$012 = 0, $$pre = 0, $$pre13 = 0, $$pre15 = 0, $$pre17 = 0, $$pre19 = 0, $$pre21 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 _SDL_ClearError();
 $1 = $0 >>> 4;
 $2 = $1 & 512;
 $3 = $2 | $0;
 $4 = $3 & 544;
 $5 = ($4|0)==(0);
 $6 = $3 | 16384;
 $$0$ = $5 ? $3 : $6;
 _SDL_TicksInit();
 $7 = $$0$ & 16384;
 $8 = ($7|0)==(0);
 if (!($8)) {
  $9 = HEAP8[(219440)>>0]|0;
  $10 = ($9<<24>>24)==(0);
  do {
   if ($10) {
    $11 = (_SDL_StartEventLoop()|0);
    $12 = ($11|0)<(0);
    if ($12) {
     $$012 = -1;
     STACKTOP = sp;return ($$012|0);
    } else {
     (_SDL_QuitInit()|0);
     $$pre = HEAP8[(219440)>>0]|0;
     $14 = $$pre;
     break;
    }
   } else {
    $14 = $9;
   }
  } while(0);
  $13 = (($14) + 1)<<24>>24;
  HEAP8[(219440)>>0] = $13;
 }
 $15 = $$0$ & 1;
 $16 = ($15|0)==(0);
 if (!($16)) {
  $17 = HEAP8[219426]|0;
  $18 = ($17<<24>>24)==(0);
  do {
   if ($18) {
    $19 = (_SDL_TimerInit()|0);
    $20 = ($19|0)<(0);
    if ($20) {
     $$012 = -1;
     STACKTOP = sp;return ($$012|0);
    } else {
     $$pre13 = HEAP8[219426]|0;
     $22 = $$pre13;
     break;
    }
   } else {
    $22 = $17;
   }
  } while(0);
  $21 = (($22) + 1)<<24>>24;
  HEAP8[219426] = $21;
 }
 $23 = $$0$ & 32;
 $24 = ($23|0)==(0);
 if (!($24)) {
  $25 = HEAP8[(219431)>>0]|0;
  $26 = ($25<<24>>24)==(0);
  do {
   if ($26) {
    $27 = (_SDL_VideoInit(0)|0);
    $28 = ($27|0)<(0);
    if ($28) {
     $$012 = -1;
     STACKTOP = sp;return ($$012|0);
    } else {
     $$pre15 = HEAP8[(219431)>>0]|0;
     $30 = $$pre15;
     break;
    }
   } else {
    $30 = $25;
   }
  } while(0);
  $29 = (($30) + 1)<<24>>24;
  HEAP8[(219431)>>0] = $29;
 }
 $31 = $$0$ & 16;
 $32 = ($31|0)==(0);
 if (!($32)) {
  $33 = HEAP8[(219430)>>0]|0;
  $34 = ($33<<24>>24)==(0);
  do {
   if ($34) {
    $35 = (_SDL_AudioInit(0)|0);
    $36 = ($35|0)<(0);
    if ($36) {
     $$012 = -1;
     STACKTOP = sp;return ($$012|0);
    } else {
     $$pre17 = HEAP8[(219430)>>0]|0;
     $38 = $$pre17;
     break;
    }
   } else {
    $38 = $33;
   }
  } while(0);
  $37 = (($38) + 1)<<24>>24;
  HEAP8[(219430)>>0] = $37;
 }
 $39 = $$0$ & 512;
 $40 = ($39|0)==(0);
 if (!($40)) {
  $41 = HEAP8[(219435)>>0]|0;
  $42 = ($41<<24>>24)==(0);
  do {
   if ($42) {
    $43 = (_SDL_JoystickInit()|0);
    $44 = ($43|0)<(0);
    if ($44) {
     $$012 = -1;
     STACKTOP = sp;return ($$012|0);
    } else {
     $$pre19 = HEAP8[(219435)>>0]|0;
     $46 = $$pre19;
     break;
    }
   } else {
    $46 = $41;
   }
  } while(0);
  $45 = (($46) + 1)<<24>>24;
  HEAP8[(219435)>>0] = $45;
 }
 $47 = $$0$ & 8192;
 $48 = ($47|0)==(0);
 if (!($48)) {
  $49 = HEAP8[(219439)>>0]|0;
  $50 = ($49<<24>>24)==(0);
  do {
   if ($50) {
    $51 = (_SDL_GameControllerInit()|0);
    $52 = ($51|0)<(0);
    if ($52) {
     $$012 = -1;
     STACKTOP = sp;return ($$012|0);
    } else {
     $$pre21 = HEAP8[(219439)>>0]|0;
     $54 = $$pre21;
     break;
    }
   } else {
    $54 = $49;
   }
  } while(0);
  $53 = (($54) + 1)<<24>>24;
  HEAP8[(219439)>>0] = $53;
 }
 $55 = $$0$ & 4096;
 $56 = ($55|0)==(0);
 if ($56) {
  $$012 = 0;
  STACKTOP = sp;return ($$012|0);
 }
 $57 = (_SDL_SetError(193186,$vararg_buffer)|0);
 $$012 = $57;
 STACKTOP = sp;return ($$012|0);
}
function _SDL_TicksInit() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[52667]|0;
 $1 = ($0|0)==(0);
 if (!($1)) {
  return;
 }
 HEAP32[52667] = 1;
 $2 = (_clock_gettime(4,(210672|0))|0);
 $3 = ($2|0)==(0);
 if ($3) {
  HEAP32[52670] = 1;
  return;
 } else {
  (_gettimeofday((210684|0),(0|0))|0);
  return;
 }
}
function _SDL_StartEventLoop() {
 var $$pr$pre = 0, $$pre = 0, $$pre15 = 0, $$pre17 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[(209652)>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  $5 = (_SDL_calloc(1,32)|0);
  HEAP32[(209652)>>2] = $5;
  $6 = ($5|0)==(0|0);
  if ($6) {
   $10 = $5;
   label = 6;
  } else {
   $$pre = HEAP32[$5>>2]|0;
   $8 = $$pre;$9 = $5;
   label = 5;
  }
 } else {
  $2 = HEAP32[$0>>2]|0;
  $3 = $2 & 8;
  $4 = ($3|0)==(0);
  if ($4) {
   $8 = $2;$9 = $0;
   label = 5;
  } else {
   $13 = $0;
   label = 7;
  }
 }
 if ((label|0) == 5) {
  $7 = $8 | 8;
  HEAP32[$9>>2] = $7;
  _SDL_FlushEvents(771,771);
  $$pr$pre = HEAP32[(209652)>>2]|0;
  $10 = $$pr$pre;
  label = 6;
 }
 if ((label|0) == 6) {
  $11 = ($10|0)==(0|0);
  if ($11) {
   $16 = (_SDL_calloc(1,32)|0);
   HEAP32[(209652)>>2] = $16;
   $17 = ($16|0)==(0|0);
   if (!($17)) {
    $$pre15 = HEAP32[$16>>2]|0;
    $19 = $$pre15;$20 = $16;
    label = 10;
   }
  } else {
   $13 = $10;
   label = 7;
  }
 }
 if ((label|0) == 7) {
  $12 = HEAP32[$13>>2]|0;
  $14 = $12 & 4;
  $15 = ($14|0)==(0);
  if ($15) {
   $19 = $12;$20 = $13;
   label = 10;
  }
 }
 if ((label|0) == 10) {
  $18 = $19 | 4;
  HEAP32[$20>>2] = $18;
  _SDL_FlushEvents(770,770);
 }
 $21 = HEAP32[(209648)>>2]|0;
 $22 = ($21|0)==(0|0);
 do {
  if ($22) {
   $26 = (_SDL_calloc(1,32)|0);
   HEAP32[(209648)>>2] = $26;
   $27 = ($26|0)==(0|0);
   if ($27) {
    (_SDL_AtomicSet((88628),1)|0);
    return 0;
   } else {
    $$pre17 = HEAP32[$26>>2]|0;
    $29 = $$pre17;$30 = $26;
    break;
   }
  } else {
   $23 = HEAP32[$21>>2]|0;
   $24 = $23 & 2;
   $25 = ($24|0)==(0);
   if ($25) {
    $29 = $23;$30 = $21;
   } else {
    (_SDL_AtomicSet((88628),1)|0);
    return 0;
   }
  }
 } while(0);
 $28 = $29 | 2;
 HEAP32[$30>>2] = $28;
 _SDL_FlushEvents(513,513);
 (_SDL_AtomicSet((88628),1)|0);
 return 0;
}
function _SDL_QuitInit() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(144|0);
 $0 = sp;
 $1 = (_SDL_GetHintBoolean(195535,0)|0);
 $2 = ($1|0)==(0);
 if (!($2)) {
  STACKTOP = sp;return 0;
 }
 (_sigaction(2,(0|0),($0|0))|0);
 $3 = HEAP32[$0>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  HEAP32[$0>>2] = 4453;
  (_sigaction(2,($0|0),(0|0))|0);
 }
 (_sigaction(15,(0|0),($0|0))|0);
 $5 = HEAP32[$0>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  HEAP32[$0>>2] = 4453;
  (_sigaction(15,($0|0),(0|0))|0);
 }
 STACKTOP = sp;return 0;
}
function _SDL_TimerInit() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function _SDL_VideoInit($0) {
 $0 = $0|0;
 var $$0$i$i = 0, $$026 = 0, $$03032$ph = 0, $$045$lcssa = 0, $$06$i$i = 0, $$07$i$i = 0, $$22937 = 0, $$238 = 0, $$lcssa = 0, $$pr = 0, $$pr$i = 0, $$pr$pre$i = 0, $$pr8$i = 0, $$pre = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0;
 var $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0;
 var $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $not$$i = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $vararg_buffer3 = sp + 16|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $1 = HEAP32[52375]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  _SDL_VideoQuit();
 }
 _SDL_TicksInit();
 $3 = (_SDL_InitSubSystem(16384)|0);
 $4 = ($3|0)<(0);
 if ($4) {
  $$026 = -1;
  STACKTOP = sp;return ($$026|0);
 }
 $5 = (_SDL_KeyboardInit()|0);
 $6 = ($5|0)<(0);
 if ($6) {
  $$026 = -1;
  STACKTOP = sp;return ($$026|0);
 }
 $7 = (_SDL_MouseInit()|0);
 $8 = ($7|0)<(0);
 if ($8) {
  $$026 = -1;
  STACKTOP = sp;return ($$026|0);
 }
 $9 = (_SDL_TouchInit()|0);
 $10 = ($9|0)<(0);
 if ($10) {
  $$026 = -1;
  STACKTOP = sp;return ($$026|0);
 }
 $11 = ($0|0)==(0|0);
 do {
  if ($11) {
   $12 = (_SDL_getenv(194412)|0);
   $13 = ($12|0)==(0|0);
   if ($13) {
    $14 = HEAP32[(88756)>>2]|0;
    $15 = (FUNCTION_TABLE_i[$14 & 8191]()|0);
    $16 = ($15|0)==(0);
    if (!($16)) {
     $28 = HEAP32[(88760)>>2]|0;
     $29 = (FUNCTION_TABLE_ii[$28 & 8191](0)|0);
     $30 = ($29|0)==(0|0);
     if (!($30)) {
      $$22937 = $29;$$238 = 0;
      break;
     }
    }
    $31 = HEAP32[(89684)>>2]|0;
    $32 = (FUNCTION_TABLE_i[$31 & 8191]()|0);
    $33 = ($32|0)==(0);
    if (!($33)) {
     $134 = HEAP32[(89688)>>2]|0;
     $135 = (FUNCTION_TABLE_ii[$134 & 8191](0)|0);
     $136 = ($135|0)==(0|0);
     if (!($136)) {
      $$22937 = $135;$$238 = 1;
      break;
     }
    }
    $40 = (_SDL_SetError(194445,$vararg_buffer1)|0);
    $$026 = $40;
    STACKTOP = sp;return ($$026|0);
   } else {
    $$03032$ph = $12;
    label = 10;
   }
  } else {
   $$03032$ph = $0;
   label = 10;
  }
 } while(0);
 do {
  if ((label|0) == 10) {
   $17 = HEAP32[22187]|0;
   $18 = (_SDL_strlen($$03032$ph)|0);
   $19 = (_SDL_strncasecmp($17,$$03032$ph,$18)|0);
   $20 = ($19|0)==(0);
   if ($20) {
    $21 = HEAP32[(88756)>>2]|0;
    $22 = (FUNCTION_TABLE_i[$21 & 8191]()|0);
    $23 = ($22|0)==(0);
    if ($23) {
     label = 12;
    } else {
     $$045$lcssa = 0;$$lcssa = 89740;
     label = 15;
    }
   } else {
    label = 12;
   }
   if ((label|0) == 12) {
    $24 = HEAP32[22419]|0;
    $25 = (_SDL_strlen($$03032$ph)|0);
    $26 = (_SDL_strncasecmp($24,$$03032$ph,$25)|0);
    $27 = ($26|0)==(0);
    if ($27) {
     $131 = HEAP32[(89684)>>2]|0;
     $132 = (FUNCTION_TABLE_i[$131 & 8191]()|0);
     $133 = ($132|0)==(0);
     if (!($133)) {
      $$045$lcssa = 1;$$lcssa = (89744);
      label = 15;
     }
    }
   }
   if ((label|0) == 15) {
    $34 = HEAP32[$$lcssa>>2]|0;
    $35 = ((($34)) + 12|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = (FUNCTION_TABLE_ii[$36 & 8191](0)|0);
    $38 = ($37|0)==(0|0);
    if (!($38)) {
     $$22937 = $37;$$238 = $$045$lcssa;
     break;
    }
   }
   HEAP32[$vararg_buffer>>2] = $$03032$ph;
   $39 = (_SDL_SetError(194428,$vararg_buffer)|0);
   $$026 = $39;
   STACKTOP = sp;return ($$026|0);
  }
 } while(0);
 HEAP32[52375] = $$22937;
 $41 = (89740 + ($$238<<2)|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = HEAP32[$42>>2]|0;
 HEAP32[$$22937>>2] = $43;
 $44 = HEAP32[52375]|0;
 $45 = ((($44)) + 284|0);
 HEAP32[$45>>2] = 1;
 $46 = ((($44)) + 388|0);
 HEAP32[$46>>2] = 0;
 $47 = ((($44)) + 648|0);
 HEAP32[$47>>2] = 0;
 $48 = ($44|0)==(0|0);
 if (!($48)) {
  $49 = ((($44)) + 292|0);
  HEAP32[$49>>2] = 3;
  $50 = ((($44)) + 296|0);
  HEAP32[$50>>2] = 3;
  $51 = ((($44)) + 300|0);
  HEAP32[$51>>2] = 2;
  $52 = ((($44)) + 304|0);
  HEAP32[$52>>2] = 0;
  $53 = ((($44)) + 312|0);
  HEAP32[$53>>2] = 0;
  $54 = ((($44)) + 308|0);
  HEAP32[$54>>2] = 16;
  $55 = ((($44)) + 316|0);
  HEAP32[$55>>2] = 0;
  $56 = ((($44)) + 320|0);
  HEAP32[$56>>2] = 1;
  $57 = ((($44)) + 324|0);
  $58 = ((($44)) + 384|0);
  ;HEAP32[$57>>2]=0|0;HEAP32[$57+4>>2]=0|0;HEAP32[$57+8>>2]=0|0;HEAP32[$57+12>>2]=0|0;HEAP32[$57+16>>2]=0|0;HEAP32[$57+20>>2]=0|0;HEAP32[$57+24>>2]=0|0;
  HEAP32[$58>>2] = 1;
  $59 = ((($44)) + 352|0);
  HEAP32[$59>>2] = -1;
  $60 = ((($44)) + 368|0);
  $61 = ((($44)) + 356|0);
  HEAP32[$61>>2] = 2;
  $62 = ((($44)) + 360|0);
  HEAP32[$62>>2] = 0;
  HEAP32[$60>>2] = 4;
  $63 = ((($44)) + 364|0);
  HEAP32[$63>>2] = 0;
  $64 = ((($44)) + 380|0);
  HEAP32[$64>>2] = 0;
  $65 = ((($44)) + 376|0);
  HEAP32[$65>>2] = 1;
  $66 = ((($44)) + 372|0);
  HEAP32[$66>>2] = 0;
 }
 $67 = (_SDL_TLSCreate()|0);
 $68 = HEAP32[52375]|0;
 $69 = ((($68)) + 660|0);
 HEAP32[$69>>2] = $67;
 $70 = (_SDL_TLSCreate()|0);
 $71 = HEAP32[52375]|0;
 $72 = ((($71)) + 664|0);
 HEAP32[$72>>2] = $70;
 $73 = ((($71)) + 4|0);
 $74 = HEAP32[$73>>2]|0;
 $75 = (FUNCTION_TABLE_ii[$74 & 8191]($71)|0);
 $76 = ($75|0)<(0);
 if ($76) {
  _SDL_VideoQuit();
  $$026 = -1;
  STACKTOP = sp;return ($$026|0);
 }
 $77 = HEAP32[52375]|0;
 $78 = ((($77)) + 264|0);
 $79 = HEAP32[$78>>2]|0;
 $80 = ($79|0)==(0);
 if ($80) {
  _SDL_VideoQuit();
  $81 = (_SDL_SetError(194471,$vararg_buffer3)|0);
  $$026 = $81;
  STACKTOP = sp;return ($$026|0);
 }
 $82 = ((($77)) + 132|0);
 $83 = HEAP32[$82>>2]|0;
 $84 = ($83|0)==(0|0);
 do {
  if ($84) {
   $95 = $77;
   label = 31;
  } else {
   $85 = (_SDL_GetHint(195276)|0);
   $86 = ($85|0)==(0|0);
   if (!($86)) {
    $87 = (_SDL_strcasecmp($85,194513)|0);
    $88 = ($87|0)==(0);
    if ($88) {
     break;
    }
   }
   $89 = (_SDL_GetHint(194522)|0);
   $90 = ($89|0)==(0|0);
   if (!($90)) {
    $91 = HEAP8[$89>>0]|0;
    $92 = ($91<<24>>24)==(48);
    if (!($92)) {
     $93 = (_SDL_strcasecmp($89,204742)|0);
     $not$$i = ($93|0)==(0);
     if (!($not$$i)) {
      $$pre = HEAP32[52375]|0;
      $95 = $$pre;
      label = 31;
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 31) {
  $94 = ((($95)) + 132|0);
  HEAP32[$94>>2] = 4454;
  $96 = ((($95)) + 136|0);
  HEAP32[$96>>2] = 4455;
  $97 = ((($95)) + 140|0);
  HEAP32[$97>>2] = 4456;
 }
 $98 = (_SDL_GetHintBoolean(194551,0)|0);
 $99 = ($98|0)==(0);
 if ($99) {
  $100 = HEAP32[52375]|0;
  $101 = ($100|0)==(0|0);
  if (!($101)) {
   $102 = ((($100)) + 260|0);
   $103 = HEAP32[$102>>2]|0;
   $104 = ($103|0)==(0);
   if ($104) {
    HEAP32[$102>>2] = 1;
    $105 = ((($100)) + 208|0);
    $106 = HEAP32[$105>>2]|0;
    $107 = ($106|0)==(0|0);
    if ($107) {
     label = 37;
    } else {
     FUNCTION_TABLE_vi[$106 & 8191]($100);
     label = 37;
    }
   } else {
    label = 37;
   }
  }
 } else {
  label = 37;
 }
 if ((label|0) == 37) {
  $$pr = HEAP32[52375]|0;
  $108 = ($$pr|0)==(0|0);
  if (!($108)) {
   $109 = ((($$pr)) + 224|0);
   $110 = HEAP32[$109>>2]|0;
   $111 = ($110|0)==(0|0);
   if (!($111)) {
    $112 = (FUNCTION_TABLE_ii[$110 & 8191]($$pr)|0);
    $113 = ($112|0)==(0);
    if (!($113)) {
     $$026 = 0;
     STACKTOP = sp;return ($$026|0);
    }
   }
  }
 }
 (_SDL_EventState(771,1)|0);
 (_SDL_EventState(770,1)|0);
 $114 = HEAP32[52375]|0;
 $115 = ($114|0)==(0|0);
 if ($115) {
  $$026 = 0;
  STACKTOP = sp;return ($$026|0);
 }
 $116 = ((($114)) + 272|0);
 $$06$i$i = HEAP32[$116>>2]|0;
 $117 = ($$06$i$i|0)==(0|0);
 do {
  if ($117) {
   $$pr8$i = $114;
  } else {
   $$07$i$i = $$06$i$i;
   while(1) {
    $118 = ((($$07$i$i)) + 48|0);
    $119 = HEAP32[$118>>2]|0;
    $120 = $119 & 512;
    $121 = ($120|0)==(0);
    if (!($121)) {
     label = 44;
     break;
    }
    $122 = ((($$07$i$i)) + 152|0);
    $$0$i$i = HEAP32[$122>>2]|0;
    $123 = ($$0$i$i|0)==(0|0);
    if ($123) {
     $$pr$i = $114;
     break;
    } else {
     $$07$i$i = $$0$i$i;
    }
   }
   if ((label|0) == 44) {
    $124 = ((($114)) + 228|0);
    $125 = HEAP32[$124>>2]|0;
    $126 = ($125|0)==(0|0);
    if ($126) {
     $$pr8$i = $114;
     break;
    }
    FUNCTION_TABLE_vii[$125 & 8191]($114,$$07$i$i);
    $$pr$pre$i = HEAP32[52375]|0;
    $$pr$i = $$pr$pre$i;
   }
   $127 = ($$pr$i|0)==(0|0);
   if ($127) {
    $$026 = 0;
    STACKTOP = sp;return ($$026|0);
   } else {
    $$pr8$i = $$pr$i;
   }
  }
 } while(0);
 $128 = ((($$pr8$i)) + 212|0);
 $129 = HEAP32[$128>>2]|0;
 $130 = ($129|0)==(0|0);
 if ($130) {
  $$026 = 0;
  STACKTOP = sp;return ($$026|0);
 }
 FUNCTION_TABLE_vi[$129 & 8191]($$pr8$i);
 $$026 = 0;
 STACKTOP = sp;return ($$026|0);
}
function _SDL_AudioInit($0) {
 $0 = $0|0;
 var $$026 = 0, $$027$lcssa34 = 0, $$02736$ph = 0, $$02736$us$ph = 0, $$03035$ph = 0, $$03035$ph$pn = 0, $$03035$us$ph = 0, $$03035$us$ph$pn = 0, $$03141 = 0, $$03142 = 0, $$in = 0, $$in66 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $1 = (_SDL_WasInit(16)|0);
 $2 = ($1|0)==(0);
 if (!($2)) {
  _SDL_AudioQuit();
 }
 (_SDL_memset(213280,0,120)|0);
 (_SDL_memset(213436,0,64)|0);
 $3 = ($0|0)==(0|0);
 L4: do {
  if ($3) {
   $4 = (_SDL_getenv(194249)|0);
   $5 = ($4|0)==(0|0);
   if ($5) {
    $$02736$us$ph = 0;$$03035$us$ph = 0;
    while(1) {
     $20 = ($$03035$us$ph|0)==(3);
     if ($20) {
      $$027$lcssa34 = $$02736$us$ph;$$03141 = $4;$76 = $5;
      label = 14;
      break L4;
     } else {
      $$03035$us$ph$pn = $$03035$us$ph;
     }
     while(1) {
      $$in66 = (89724 + ($$03035$us$ph$pn<<2)|0);
      $6 = HEAP32[$$in66>>2]|0;
      $7 = ((($6)) + 12|0);
      $8 = HEAP32[$7>>2]|0;
      $9 = ($8|0)==(0);
      if ($9) {
       break;
      }
      $10 = (($$03035$us$ph$pn) + 1)|0;
      $11 = ($10|0)==(3);
      if ($11) {
       $$027$lcssa34 = $$02736$us$ph;$$03141 = $4;$76 = $5;
       label = 14;
       break L4;
      } else {
       $$03035$us$ph$pn = $10;
      }
     }
     (_SDL_memset(213280,0,120)|0);
     $12 = HEAP32[$6>>2]|0;
     HEAP32[53320] = $12;
     $13 = ((($6)) + 4|0);
     $14 = HEAP32[$13>>2]|0;
     HEAP32[(213284)>>2] = $14;
     $15 = ((($6)) + 8|0);
     $16 = HEAP32[$15>>2]|0;
     $17 = (FUNCTION_TABLE_ii[$16 & 8191]((213288))|0);
     $18 = (($$03035$us$ph$pn) + 1)|0;
     $19 = ($17|0)==(0);
     if ($19) {
      $$02736$us$ph = 1;$$03035$us$ph = $18;
     } else {
      break;
     }
    }
   } else {
    $$03142 = $4;
    label = 5;
   }
  } else {
   $$03142 = $0;
   label = 5;
  }
 } while(0);
 L12: do {
  if ((label|0) == 5) {
   $$02736$ph = 0;$$03035$ph = 0;
   while(1) {
    $36 = ($$03035$ph|0)==(3);
    if ($36) {
     $$027$lcssa34 = $$02736$ph;$$03141 = $$03142;$76 = 0;
     label = 14;
     break L12;
    } else {
     $$03035$ph$pn = $$03035$ph;
    }
    while(1) {
     $$in = (89724 + ($$03035$ph$pn<<2)|0);
     $21 = HEAP32[$$in>>2]|0;
     $22 = HEAP32[$21>>2]|0;
     $23 = (_SDL_strlen($$03142)|0);
     $24 = (_SDL_strncasecmp($22,$$03142,$23)|0);
     $25 = ($24|0)==(0);
     if ($25) {
      break;
     }
     $26 = (($$03035$ph$pn) + 1)|0;
     $27 = ($26|0)==(3);
     if ($27) {
      $$027$lcssa34 = $$02736$ph;$$03141 = $$03142;$76 = 0;
      label = 14;
      break L12;
     } else {
      $$03035$ph$pn = $26;
     }
    }
    (_SDL_memset(213280,0,120)|0);
    $28 = HEAP32[$21>>2]|0;
    HEAP32[53320] = $28;
    $29 = ((($21)) + 4|0);
    $30 = HEAP32[$29>>2]|0;
    HEAP32[(213284)>>2] = $30;
    $31 = ((($21)) + 8|0);
    $32 = HEAP32[$31>>2]|0;
    $33 = (FUNCTION_TABLE_ii[$32 & 8191]((213288))|0);
    $34 = (($$03035$ph$pn) + 1)|0;
    $35 = ($33|0)==(0);
    if ($35) {
     $$02736$ph = 1;$$03035$ph = $34;
    } else {
     break;
    }
   }
  }
 } while(0);
 if ((label|0) == 14) {
  $37 = ($$027$lcssa34|0)==(0);
  do {
   if ($37) {
    if ($76) {
     (_SDL_SetError(194297,$vararg_buffer1)|0);
     break;
    } else {
     HEAP32[$vararg_buffer>>2] = $$03141;
     (_SDL_SetError(194265,$vararg_buffer)|0);
     break;
    }
   }
  } while(0);
  (_SDL_memset(213280,0,120)|0);
  $$026 = -1;
  STACKTOP = sp;return ($$026|0);
 }
 $38 = (_SDL_CreateMutex()|0);
 HEAP32[(213372)>>2] = $38;
 $39 = HEAP32[(213352)>>2]|0;
 $40 = ($39|0)==(0);
 if (!($40)) {
  $41 = HEAP32[(213332)>>2]|0;
  $42 = ($41|0)==(0|0);
  if ($42) {
   HEAP32[(213332)>>2] = 4457;
  }
  $43 = HEAP32[(213336)>>2]|0;
  $44 = ($43|0)==(0|0);
  if ($44) {
   HEAP32[(213336)>>2] = 4457;
  }
 }
 $45 = HEAP32[(213288)>>2]|0;
 $46 = ($45|0)==(0|0);
 if ($46) {
  HEAP32[(213288)>>2] = 4458;
  $75 = 4458;
 } else {
  $75 = $45;
 }
 $47 = HEAP32[(213292)>>2]|0;
 $48 = ($47|0)==(0|0);
 if ($48) {
  HEAP32[(213292)>>2] = 4459;
 }
 $49 = HEAP32[(213296)>>2]|0;
 $50 = ($49|0)==(0|0);
 if ($50) {
  HEAP32[(213296)>>2] = 4460;
 }
 $51 = HEAP32[(213300)>>2]|0;
 $52 = ($51|0)==(0|0);
 if ($52) {
  HEAP32[(213300)>>2] = 4461;
 }
 $53 = HEAP32[(213304)>>2]|0;
 $54 = ($53|0)==(0|0);
 if ($54) {
  HEAP32[(213304)>>2] = 4462;
 }
 $55 = HEAP32[(213308)>>2]|0;
 $56 = ($55|0)==(0|0);
 if ($56) {
  HEAP32[(213308)>>2] = 4463;
 }
 $57 = HEAP32[(213312)>>2]|0;
 $58 = ($57|0)==(0|0);
 if ($58) {
  HEAP32[(213312)>>2] = 4464;
 }
 $59 = HEAP32[(213316)>>2]|0;
 $60 = ($59|0)==(0|0);
 if ($60) {
  HEAP32[(213316)>>2] = 4465;
 }
 $61 = HEAP32[(213320)>>2]|0;
 $62 = ($61|0)==(0|0);
 if ($62) {
  HEAP32[(213320)>>2] = 4466;
 }
 $63 = HEAP32[(213324)>>2]|0;
 $64 = ($63|0)==(0|0);
 if ($64) {
  HEAP32[(213324)>>2] = 4467;
 }
 $65 = HEAP32[(213328)>>2]|0;
 $66 = ($65|0)==(0|0);
 if ($66) {
  HEAP32[(213328)>>2] = 4468;
 }
 $67 = HEAP32[(213332)>>2]|0;
 $68 = ($67|0)==(0|0);
 if ($68) {
  HEAP32[(213332)>>2] = 4469;
 }
 $69 = HEAP32[(213336)>>2]|0;
 $70 = ($69|0)==(0|0);
 if ($70) {
  HEAP32[(213336)>>2] = 4470;
 }
 $71 = HEAP32[(213340)>>2]|0;
 $72 = ($71|0)==(0|0);
 if ($72) {
  HEAP32[(213340)>>2] = 4471;
 }
 $73 = HEAP32[(213344)>>2]|0;
 $74 = ($73|0)==(0|0);
 if ($74) {
  HEAP32[(213344)>>2] = 4472;
 }
 FUNCTION_TABLE_v[$75 & 8191]();
 $$026 = 0;
 STACKTOP = sp;return ($$026|0);
}
function _SDL_JoystickInit() {
 var $$ = 0, $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 _SDL_AddHintCallback(194094,4473,0);
 $0 = (_SDL_InitSubSystem(16384)|0);
 $1 = ($0|0)<(0);
 if ($1) {
  $$0 = -1;
  return ($$0|0);
 }
 $2 = (_SDL_SYS_JoystickInit()|0);
 $3 = ($2|0)<(0);
 $$ = $3 ? $2 : 0;
 $$0 = $$;
 return ($$0|0);
}
function _SDL_GameControllerInit() {
 var $$026$i$lcssa = 0, $$026$i13 = 0, $$112 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $not$$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(64|0);
 $0 = sp;
 (_SDL_GameControllerAddMapping(193237)|0);
 $1 = (_SDL_GetHint(193487)|0);
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = HEAP8[$1>>0]|0;
  $4 = ($3<<24>>24)==(0);
  if (!($4)) {
   $5 = (_SDL_strlen($1)|0);
   $6 = (($5) + 1)|0;
   $7 = (_SDL_malloc($6)|0);
   (_SDL_memcpy($7,$1,$5)|0);
   $8 = (($7) + ($5)|0);
   HEAP8[$8>>0] = 0;
   $9 = ($7|0)==(0|0);
   if (!($9)) {
    $10 = (_SDL_strchr($7,10)|0);
    $11 = ($10|0)==(0|0);
    if ($11) {
     $$026$i$lcssa = $7;
    } else {
     $$026$i13 = $7;$12 = $10;
     while(1) {
      HEAP8[$12>>0] = 0;
      (_SDL_GameControllerAddMapping($$026$i13)|0);
      $13 = ((($12)) + 1|0);
      $14 = (_SDL_strchr($13,10)|0);
      $15 = ($14|0)==(0|0);
      if ($15) {
       $$026$i$lcssa = $13;
       break;
      } else {
       $$026$i13 = $13;$12 = $14;
      }
     }
    }
    (_SDL_GameControllerAddMapping($$026$i$lcssa)|0);
   }
   _SDL_free($7);
  }
 }
 _SDL_AddEventWatch(4474,0);
 $16 = (_SDL_NumJoysticks()|0);
 $17 = ($16|0)>(0);
 if (!($17)) {
  STACKTOP = sp;return 0;
 }
 $18 = ((($0)) + 8|0);
 $$112 = 0;
 while(1) {
  $19 = (_SDL_PrivateGetControllerMapping($$112)|0);
  $not$$i = ($19|0)==(0|0);
  if (!($not$$i)) {
   HEAP32[$0>>2] = 1619;
   HEAP32[$18>>2] = $$112;
   (_SDL_PushEvent($0)|0);
  }
  $20 = (($$112) + 1)|0;
  $21 = (_SDL_NumJoysticks()|0);
  $22 = ($20|0)<($21|0);
  if ($22) {
   $$112 = $20;
  } else {
   break;
  }
 }
 STACKTOP = sp;return 0;
}
function _SDL_GameControllerAddMapping($0) {
 $0 = $0|0;
 var $$0 = 0, $$0$i35$i = 0, $$0$i37$i = 0, $$010$i$i = 0, $$011$i$i = 0, $$030 = 0, $$033$i = 0, $$07$i$i = 0, $$08$i$i = 0, $$byval_copy = 0, $$sroa$0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0;
 var $vararg_buffer4 = 0, $vararg_buffer7 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(160|0);
 $$byval_copy = sp + 136|0;
 $vararg_buffer7 = sp + 96|0;
 $vararg_buffer4 = sp + 88|0;
 $vararg_buffer1 = sp + 80|0;
 $vararg_buffer = sp + 72|0;
 $1 = sp + 16|0;
 $2 = sp;
 $$sroa$0 = sp + 120|0;
 $3 = sp + 104|0;
 $4 = ($0|0)==(0|0);
 if ($4) {
  HEAP32[$vararg_buffer>>2] = 193704;
  $5 = (_SDL_SetError(194740,$vararg_buffer)|0);
  $$0 = $5;
  STACKTOP = sp;return ($$0|0);
 }
 $6 = (_SDL_strchr($0,44)|0);
 $7 = ($6|0)==(0|0);
 do {
  if (!($7)) {
   $8 = $6;
   $9 = $0;
   $10 = (($8) - ($9))|0;
   $11 = (($10) + 1)|0;
   $12 = (_SDL_malloc($11)|0);
   $13 = ($12|0)==(0|0);
   if ($13) {
    (_SDL_Error(0)|0);
    break;
   }
   (_SDL_memcpy($12,$0,$10)|0);
   $15 = (($12) + ($10)|0);
   HEAP8[$15>>0] = 0;
   $16 = (_SDL_strcasecmp($12,193746)|0);
   $17 = ($16|0)==(0);
   $18 = (_SDL_strcasecmp($12,193753)|0);
   $19 = ($18|0)==(0);
   _SDL_JoystickGetGUIDFromString($3,$12);
   dest=$$sroa$0; src=$3; stop=dest+16|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
   _SDL_free($12);
   dest=$2; src=$$sroa$0; stop=dest+16|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
   $20 = (_SDL_strchr($0,44)|0);
   $21 = ($20|0)==(0|0);
   L10: do {
    if ($21) {
     label = 11;
    } else {
     $22 = ((($20)) + 1|0);
     $23 = (_SDL_strchr($22,44)|0);
     $24 = ($23|0)==(0|0);
     if ($24) {
      label = 11;
     } else {
      $25 = $23;
      $26 = $20;
      $27 = (($25) - ($26))|0;
      $28 = (_SDL_malloc($27)|0);
      $29 = ($28|0)==(0|0);
      if ($29) {
       (_SDL_Error(0)|0);
       label = 11;
       break;
      }
      (_SDL_memcpy($28,$22,$27)|0);
      $30 = (($27) + -1)|0;
      $31 = (($28) + ($30)|0);
      HEAP8[$31>>0] = 0;
      $32 = (_SDL_strchr($0,44)|0);
      $33 = ($32|0)==(0|0);
      if (!($33)) {
       $34 = ((($32)) + 1|0);
       $35 = (_SDL_strchr($34,44)|0);
       $36 = ($35|0)==(0|0);
       if (!($36)) {
        $37 = ((($35)) + 1|0);
        $38 = (_SDL_strdup($37)|0);
        $39 = ($38|0)==(0|0);
        if (!($39)) {
         $$07$i$i = HEAP32[53350]|0;
         $40 = ($$07$i$i|0)==(0|0);
         L20: do {
          if ($40) {
           label = 25;
          } else {
           $$08$i$i = $$07$i$i;
           while(1) {
            $41 = (_SDL_memcmp($2,$$08$i$i,16)|0);
            $42 = ($41|0)==(0);
            if ($42) {
             break;
            }
            $43 = ((($$08$i$i)) + 24|0);
            $$0$i35$i = HEAP32[$43>>2]|0;
            $44 = ($$0$i35$i|0)==(0|0);
            if ($44) {
             label = 25;
             break L20;
            } else {
             $$08$i$i = $$0$i35$i;
            }
           }
           $45 = ((($$08$i$i)) + 16|0);
           $46 = HEAP32[$45>>2]|0;
           _SDL_free($46);
           HEAP32[$45>>2] = $28;
           $47 = ((($$08$i$i)) + 20|0);
           $48 = HEAP32[$47>>2]|0;
           _SDL_free($48);
           HEAP32[$47>>2] = $38;
           $$010$i$i = HEAP32[53355]|0;
           $49 = ($$010$i$i|0)==(0|0);
           if ($49) {
            $$0 = 0;
            STACKTOP = sp;return ($$0|0);
           }
           $50 = ((($1)) + 8|0);
           $$011$i$i = $$010$i$i;
           while(1) {
            $51 = ((($$011$i$i)) + 12|0);
            $52 = (_SDL_memcmp($51,$$08$i$i,16)|0);
            $53 = ($52|0)==(0);
            if ($53) {
             HEAP32[$1>>2] = 1621;
             $54 = HEAP32[$$011$i$i>>2]|0;
             $55 = HEAP32[$54>>2]|0;
             HEAP32[$50>>2] = $55;
             (_SDL_PushEvent($1)|0);
             $56 = HEAP32[$45>>2]|0;
             $57 = HEAP32[$47>>2]|0;
             dest=$$byval_copy; src=$$08$i$i; stop=dest+16|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
             _SDL_PrivateLoadButtonMapping($51,$$byval_copy,$56,$57);
            }
            $58 = ((($$011$i$i)) + 1344|0);
            $$0$i37$i = HEAP32[$58>>2]|0;
            $59 = ($$0$i37$i|0)==(0|0);
            if ($59) {
             $$030 = 1;$$033$i = $$08$i$i;
             break;
            } else {
             $$011$i$i = $$0$i37$i;
            }
           }
          }
         } while(0);
         do {
          if ((label|0) == 25) {
           $60 = (_SDL_malloc(28)|0);
           $61 = ($60|0)==(0|0);
           if ($61) {
            _SDL_free($28);
            _SDL_free($38);
            (_SDL_Error(0)|0);
            break L10;
           } else {
            dest=$60; src=$2; stop=dest+16|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
            $62 = ((($60)) + 16|0);
            HEAP32[$62>>2] = $28;
            $63 = ((($60)) + 20|0);
            HEAP32[$63>>2] = $38;
            $64 = HEAP32[53350]|0;
            $65 = ((($60)) + 24|0);
            HEAP32[$65>>2] = $64;
            HEAP32[53350] = $60;
            $$030 = 0;$$033$i = $60;
            break;
           }
          }
         } while(0);
         $66 = ($$033$i|0)==(0|0);
         if ($66) {
          $$0 = -1;
          STACKTOP = sp;return ($$0|0);
         }
         $67 = ($$030|0)==(0);
         if (!($67)) {
          $$0 = 0;
          STACKTOP = sp;return ($$0|0);
         }
         if ($17) {
          HEAP32[53352] = $$033$i;
         }
         if (!($19)) {
          $$0 = 1;
          STACKTOP = sp;return ($$0|0);
         }
         HEAP32[53351] = $$033$i;
         $$0 = 1;
         STACKTOP = sp;return ($$0|0);
        }
       }
      }
      _SDL_free($28);
      HEAP32[$vararg_buffer7>>2] = $0;
      (_SDL_SetError(193792,$vararg_buffer7)|0);
     }
    }
   } while(0);
   if ((label|0) == 11) {
    HEAP32[$vararg_buffer4>>2] = $0;
    (_SDL_SetError(193764,$vararg_buffer4)|0);
   }
   $$0 = -1;
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 HEAP32[$vararg_buffer1>>2] = $0;
 $14 = (_SDL_SetError(193718,$vararg_buffer1)|0);
 $$0 = $14;
 STACKTOP = sp;return ($$0|0);
}
function _SDL_strchr($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_strchr($0,$1)|0);
 return ($2|0);
}
function _SDL_GameControllerEventWatcher($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$ = 0, $$0 = 0, $$0110 = 0, $$0110157 = 0, $$0110158 = 0, $$0111 = 0, $$0111162 = 0, $$0111163 = 0, $$0112 = 0, $$0112159 = 0, $$0112160 = 0, $$0113 = 0, $$0165 = 0, $$0166 = 0, $$sink$i114 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0;
 var $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0;
 var $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0;
 var $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0;
 var $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0;
 var $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0;
 var $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0;
 var $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0;
 var $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0;
 var $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $not$$i = 0, $switch = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 800|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(800|0);
 $vararg_buffer1 = sp + 792|0;
 $vararg_buffer = sp + 784|0;
 $2 = sp + 728|0;
 $3 = sp + 672|0;
 $4 = sp + 616|0;
 $5 = sp + 560|0;
 $6 = sp + 504|0;
 $7 = sp + 448|0;
 $8 = sp + 392|0;
 $9 = sp + 336|0;
 $10 = sp + 280|0;
 $11 = sp + 224|0;
 $12 = sp + 168|0;
 $13 = sp + 112|0;
 $14 = sp + 56|0;
 $15 = sp;
 $16 = HEAP32[$1>>2]|0;
 switch ($16|0) {
 case 1536:  {
  $20 = ((($1)) + 12|0);
  $21 = HEAP8[$20>>0]|0;
  $22 = ($21&255)>(47);
  if ($22) {
   $26 = $21&255;
   HEAP32[$vararg_buffer>>2] = $26;
   (_SDL_SetError(193556,$vararg_buffer)|0);
   STACKTOP = sp;return 1;
  }
  $$0110157 = HEAP32[53355]|0;
  $23 = ($$0110157|0)==(0|0);
  if ($23) {
   STACKTOP = sp;return 1;
  }
  $24 = ((($1)) + 8|0);
  $25 = HEAP32[$24>>2]|0;
  $$0110158 = $$0110157;
  while(1) {
   $27 = HEAP32[$$0110158>>2]|0;
   $28 = HEAP32[$27>>2]|0;
   $29 = ($28|0)==($25|0);
   if ($29) {
    break;
   }
   $68 = ((($$0110158)) + 1344|0);
   $$0110 = HEAP32[$68>>2]|0;
   $69 = ($$0110|0)==(0|0);
   if ($69) {
    label = 19;
    break;
   } else {
    $$0110158 = $$0110;
   }
  }
  if ((label|0) == 19) {
   STACKTOP = sp;return 1;
  }
  $30 = $21&255;
  $31 = (((($$0110158)) + 320|0) + ($30<<2)|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = ($32|0)>(-1);
  if ($33) {
   $34 = ((($1)) + 16|0);
   $35 = HEAP16[$34>>1]|0;
   $36 = $32 & -2;
   $switch = ($36|0)==(4);
   if ($switch) {
    $37 = (($35<<16>>16) / 2)&-1;
    $38 = $37&65535;
    $39 = (($38) + 16384)|0;
    $40 = $39&65535;
    $$0113 = $40;
   } else {
    $$0113 = $35;
   }
   $41 = (_SDL_EventState(1616,-1)|0);
   $42 = ($41<<24>>24)==(1);
   if (!($42)) {
    STACKTOP = sp;return 1;
   }
   HEAP32[$13>>2] = 1616;
   $43 = HEAP32[$$0110158>>2]|0;
   $44 = HEAP32[$43>>2]|0;
   $45 = ((($13)) + 8|0);
   HEAP32[$45>>2] = $44;
   $46 = $32&255;
   $47 = ((($13)) + 12|0);
   HEAP8[$47>>0] = $46;
   $48 = ((($13)) + 16|0);
   HEAP16[$48>>1] = $$0113;
   (_SDL_PushEvent($13)|0);
   STACKTOP = sp;return 1;
  } else {
   $49 = (((($$0110158)) + 896|0) + ($30<<2)|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = ($50|0)>(-1);
   if (!($51)) {
    STACKTOP = sp;return 1;
   }
   $52 = ((($1)) + 16|0);
   $53 = HEAP16[$52>>1]|0;
   $54 = $53 << 16 >> 16;
   $55 = ($53<<16>>16)<(0);
   $56 = (0 - ($54))|0;
   $57 = $55 ? $56 : $54;
   $58 = ($57|0)>(16384);
   $$ = $58 ? 1617 : 1618;
   HEAP32[$12>>2] = $$;
   $59 = (_SDL_EventState($$,-1)|0);
   $60 = ($59<<24>>24)==(1);
   if ($60) {
    $61 = $58&1;
    $62 = HEAP32[$$0110158>>2]|0;
    $63 = HEAP32[$62>>2]|0;
    $64 = ((($12)) + 8|0);
    HEAP32[$64>>2] = $63;
    $65 = $50&255;
    $66 = ((($12)) + 12|0);
    HEAP8[$66>>0] = $65;
    $67 = ((($12)) + 13|0);
    HEAP8[$67>>0] = $61;
    (_SDL_PushEvent($12)|0);
   }
   STACKTOP = sp;return 1;
  }
  break;
 }
 case 1540: case 1539:  {
  $70 = ((($1)) + 12|0);
  $71 = HEAP8[$70>>0]|0;
  $72 = ($71&255)>(47);
  if ($72) {
   $76 = $71&255;
   HEAP32[$vararg_buffer1>>2] = $76;
   (_SDL_SetError(193629,$vararg_buffer1)|0);
   STACKTOP = sp;return 1;
  }
  $$0112159 = HEAP32[53355]|0;
  $73 = ($$0112159|0)==(0|0);
  if ($73) {
   STACKTOP = sp;return 1;
  }
  $74 = ((($1)) + 8|0);
  $75 = HEAP32[$74>>2]|0;
  $$0112160 = $$0112159;
  while(1) {
   $77 = HEAP32[$$0112160>>2]|0;
   $78 = HEAP32[$77>>2]|0;
   $79 = ($78|0)==($75|0);
   if ($79) {
    break;
   }
   $109 = ((($$0112160)) + 1344|0);
   $$0112 = HEAP32[$109>>2]|0;
   $110 = ($$0112|0)==(0|0);
   if ($110) {
    label = 19;
    break;
   } else {
    $$0112160 = $$0112;
   }
  }
  if ((label|0) == 19) {
   STACKTOP = sp;return 1;
  }
  $80 = $71&255;
  $81 = (((($$0112160)) + 704|0) + ($80<<2)|0);
  $82 = HEAP32[$81>>2]|0;
  $83 = ($82|0)>(-1);
  if ($83) {
   $84 = ((($1)) + 13|0);
   $85 = HEAP8[$84>>0]|0;
   switch ($85<<24>>24) {
   case 1:  {
    $$sink$i114 = 1617;
    label = 28;
    break;
   }
   case 0:  {
    $$sink$i114 = 1618;
    label = 28;
    break;
   }
   default: {
   }
   }
   if ((label|0) == 28) {
    HEAP32[$11>>2] = $$sink$i114;
    $86 = (_SDL_EventState($$sink$i114,-1)|0);
    $87 = ($86<<24>>24)==(1);
    if ($87) {
     $88 = HEAP32[$$0112160>>2]|0;
     $89 = HEAP32[$88>>2]|0;
     $90 = ((($11)) + 8|0);
     HEAP32[$90>>2] = $89;
     $91 = $82&255;
     $92 = ((($11)) + 12|0);
     HEAP8[$92>>0] = $91;
     $93 = ((($11)) + 13|0);
     HEAP8[$93>>0] = $85;
     (_SDL_PushEvent($11)|0);
    }
   }
   STACKTOP = sp;return 1;
  } else {
   $94 = (((($$0112160)) + 512|0) + ($80<<2)|0);
   $95 = HEAP32[$94>>2]|0;
   $96 = ($95|0)>(-1);
   if (!($96)) {
    STACKTOP = sp;return 1;
   }
   $97 = ((($1)) + 13|0);
   $98 = HEAP8[$97>>0]|0;
   $99 = (_SDL_EventState(1616,-1)|0);
   $100 = ($99<<24>>24)==(1);
   if (!($100)) {
    STACKTOP = sp;return 1;
   }
   $101 = ($98<<24>>24)!=(0);
   $102 = $101 ? 32767 : 0;
   HEAP32[$10>>2] = 1616;
   $103 = HEAP32[$$0112160>>2]|0;
   $104 = HEAP32[$103>>2]|0;
   $105 = ((($10)) + 8|0);
   HEAP32[$105>>2] = $104;
   $106 = $95&255;
   $107 = ((($10)) + 12|0);
   HEAP8[$107>>0] = $106;
   $108 = ((($10)) + 16|0);
   HEAP16[$108>>1] = $102;
   (_SDL_PushEvent($10)|0);
   STACKTOP = sp;return 1;
  }
  break;
 }
 case 1538:  {
  $111 = ((($1)) + 12|0);
  $112 = HEAP8[$111>>0]|0;
  $113 = ($112&255)>(3);
  if ($113) {
   STACKTOP = sp;return 1;
  }
  $$0111162 = HEAP32[53355]|0;
  $114 = ($$0111162|0)==(0|0);
  if ($114) {
   STACKTOP = sp;return 1;
  }
  $115 = ((($1)) + 8|0);
  $116 = HEAP32[$115>>2]|0;
  $$0111163 = $$0111162;
  while(1) {
   $117 = HEAP32[$$0111163>>2]|0;
   $118 = HEAP32[$117>>2]|0;
   $119 = ($118|0)==($116|0);
   if ($119) {
    break;
   }
   $248 = ((($$0111163)) + 1344|0);
   $$0111 = HEAP32[$248>>2]|0;
   $249 = ($$0111|0)==(0|0);
   if ($249) {
    label = 19;
    break;
   } else {
    $$0111163 = $$0111;
   }
  }
  if ((label|0) == 19) {
   STACKTOP = sp;return 1;
  }
  $120 = $112&255;
  $121 = (((($$0111163)) + 8|0) + ($120)|0);
  $122 = HEAP8[$121>>0]|0;
  $123 = ((($1)) + 13|0);
  $124 = HEAP8[$123>>0]|0;
  $125 = $124 & $122;
  $126 = $125 ^ $122;
  $127 = $120 << 4;
  $128 = $126&255;
  $129 = $128 & 4;
  $130 = ($129|0)==(0);
  if (!($130)) {
   $131 = $127 | 4;
   $132 = (((($$0111163)) + 1088|0) + ($131<<2)|0);
   $133 = HEAP32[$132>>2]|0;
   $134 = ($133|0)==(-1);
   if (!($134)) {
    HEAP32[$9>>2] = 1618;
    $135 = (_SDL_EventState(1618,-1)|0);
    $136 = ($135<<24>>24)==(1);
    if ($136) {
     $137 = HEAP32[$$0111163>>2]|0;
     $138 = HEAP32[$137>>2]|0;
     $139 = ((($9)) + 8|0);
     HEAP32[$139>>2] = $138;
     $140 = $133&255;
     $141 = ((($9)) + 12|0);
     HEAP8[$141>>0] = $140;
     $142 = ((($9)) + 13|0);
     HEAP8[$142>>0] = 0;
     (_SDL_PushEvent($9)|0);
    }
   }
  }
  $143 = $128 & 1;
  $144 = ($143|0)==(0);
  if (!($144)) {
   $145 = $127 | 1;
   $146 = (((($$0111163)) + 1088|0) + ($145<<2)|0);
   $147 = HEAP32[$146>>2]|0;
   $148 = ($147|0)==(-1);
   if (!($148)) {
    HEAP32[$8>>2] = 1618;
    $149 = (_SDL_EventState(1618,-1)|0);
    $150 = ($149<<24>>24)==(1);
    if ($150) {
     $151 = HEAP32[$$0111163>>2]|0;
     $152 = HEAP32[$151>>2]|0;
     $153 = ((($8)) + 8|0);
     HEAP32[$153>>2] = $152;
     $154 = $147&255;
     $155 = ((($8)) + 12|0);
     HEAP8[$155>>0] = $154;
     $156 = ((($8)) + 13|0);
     HEAP8[$156>>0] = 0;
     (_SDL_PushEvent($8)|0);
    }
   }
  }
  $157 = $128 & 8;
  $158 = ($157|0)==(0);
  if (!($158)) {
   $159 = $127 | 8;
   $160 = (((($$0111163)) + 1088|0) + ($159<<2)|0);
   $161 = HEAP32[$160>>2]|0;
   $162 = ($161|0)==(-1);
   if (!($162)) {
    HEAP32[$7>>2] = 1618;
    $163 = (_SDL_EventState(1618,-1)|0);
    $164 = ($163<<24>>24)==(1);
    if ($164) {
     $165 = HEAP32[$$0111163>>2]|0;
     $166 = HEAP32[$165>>2]|0;
     $167 = ((($7)) + 8|0);
     HEAP32[$167>>2] = $166;
     $168 = $161&255;
     $169 = ((($7)) + 12|0);
     HEAP8[$169>>0] = $168;
     $170 = ((($7)) + 13|0);
     HEAP8[$170>>0] = 0;
     (_SDL_PushEvent($7)|0);
    }
   }
  }
  $171 = $128 & 2;
  $172 = ($171|0)==(0);
  if (!($172)) {
   $173 = $127 | 2;
   $174 = (((($$0111163)) + 1088|0) + ($173<<2)|0);
   $175 = HEAP32[$174>>2]|0;
   $176 = ($175|0)==(-1);
   if (!($176)) {
    HEAP32[$6>>2] = 1618;
    $177 = (_SDL_EventState(1618,-1)|0);
    $178 = ($177<<24>>24)==(1);
    if ($178) {
     $179 = HEAP32[$$0111163>>2]|0;
     $180 = HEAP32[$179>>2]|0;
     $181 = ((($6)) + 8|0);
     HEAP32[$181>>2] = $180;
     $182 = $175&255;
     $183 = ((($6)) + 12|0);
     HEAP8[$183>>0] = $182;
     $184 = ((($6)) + 13|0);
     HEAP8[$184>>0] = 0;
     (_SDL_PushEvent($6)|0);
    }
   }
  }
  $185 = HEAP8[$123>>0]|0;
  $186 = $185 ^ $125;
  $187 = $186&255;
  $188 = $187 & 4;
  $189 = ($188|0)==(0);
  if (!($189)) {
   $190 = $127 | 4;
   $191 = (((($$0111163)) + 1088|0) + ($190<<2)|0);
   $192 = HEAP32[$191>>2]|0;
   $193 = ($192|0)==(-1);
   if (!($193)) {
    HEAP32[$5>>2] = 1617;
    $194 = (_SDL_EventState(1617,-1)|0);
    $195 = ($194<<24>>24)==(1);
    if ($195) {
     $196 = HEAP32[$$0111163>>2]|0;
     $197 = HEAP32[$196>>2]|0;
     $198 = ((($5)) + 8|0);
     HEAP32[$198>>2] = $197;
     $199 = $192&255;
     $200 = ((($5)) + 12|0);
     HEAP8[$200>>0] = $199;
     $201 = ((($5)) + 13|0);
     HEAP8[$201>>0] = 1;
     (_SDL_PushEvent($5)|0);
    }
   }
  }
  $202 = $187 & 1;
  $203 = ($202|0)==(0);
  if (!($203)) {
   $204 = $127 | 1;
   $205 = (((($$0111163)) + 1088|0) + ($204<<2)|0);
   $206 = HEAP32[$205>>2]|0;
   $207 = ($206|0)==(-1);
   if (!($207)) {
    HEAP32[$4>>2] = 1617;
    $208 = (_SDL_EventState(1617,-1)|0);
    $209 = ($208<<24>>24)==(1);
    if ($209) {
     $210 = HEAP32[$$0111163>>2]|0;
     $211 = HEAP32[$210>>2]|0;
     $212 = ((($4)) + 8|0);
     HEAP32[$212>>2] = $211;
     $213 = $206&255;
     $214 = ((($4)) + 12|0);
     HEAP8[$214>>0] = $213;
     $215 = ((($4)) + 13|0);
     HEAP8[$215>>0] = 1;
     (_SDL_PushEvent($4)|0);
    }
   }
  }
  $216 = $187 & 8;
  $217 = ($216|0)==(0);
  if (!($217)) {
   $218 = $127 | 8;
   $219 = (((($$0111163)) + 1088|0) + ($218<<2)|0);
   $220 = HEAP32[$219>>2]|0;
   $221 = ($220|0)==(-1);
   if (!($221)) {
    HEAP32[$3>>2] = 1617;
    $222 = (_SDL_EventState(1617,-1)|0);
    $223 = ($222<<24>>24)==(1);
    if ($223) {
     $224 = HEAP32[$$0111163>>2]|0;
     $225 = HEAP32[$224>>2]|0;
     $226 = ((($3)) + 8|0);
     HEAP32[$226>>2] = $225;
     $227 = $220&255;
     $228 = ((($3)) + 12|0);
     HEAP8[$228>>0] = $227;
     $229 = ((($3)) + 13|0);
     HEAP8[$229>>0] = 1;
     (_SDL_PushEvent($3)|0);
    }
   }
  }
  $230 = $187 & 2;
  $231 = ($230|0)==(0);
  if (!($231)) {
   $232 = $127 | 2;
   $233 = (((($$0111163)) + 1088|0) + ($232<<2)|0);
   $234 = HEAP32[$233>>2]|0;
   $235 = ($234|0)==(-1);
   if (!($235)) {
    HEAP32[$2>>2] = 1617;
    $236 = (_SDL_EventState(1617,-1)|0);
    $237 = ($236<<24>>24)==(1);
    if ($237) {
     $238 = HEAP32[$$0111163>>2]|0;
     $239 = HEAP32[$238>>2]|0;
     $240 = ((($2)) + 8|0);
     HEAP32[$240>>2] = $239;
     $241 = $234&255;
     $242 = ((($2)) + 12|0);
     HEAP8[$242>>0] = $241;
     $243 = ((($2)) + 13|0);
     HEAP8[$243>>0] = 1;
     (_SDL_PushEvent($2)|0);
    }
   }
  }
  $244 = HEAP8[$123>>0]|0;
  $245 = HEAP8[$111>>0]|0;
  $246 = $245&255;
  $247 = (((($$0111163)) + 8|0) + ($246)|0);
  HEAP8[$247>>0] = $244;
  STACKTOP = sp;return 1;
  break;
 }
 case 1541:  {
  $250 = ((($1)) + 8|0);
  $251 = HEAP32[$250>>2]|0;
  $252 = (_SDL_PrivateGetControllerMapping($251)|0);
  $not$$i = ($252|0)==(0|0);
  if ($not$$i) {
   STACKTOP = sp;return 1;
  }
  HEAP32[$14>>2] = 1619;
  $253 = HEAP32[$250>>2]|0;
  $254 = ((($14)) + 8|0);
  HEAP32[$254>>2] = $253;
  (_SDL_PushEvent($14)|0);
  STACKTOP = sp;return 1;
  break;
 }
 case 1542:  {
  $$0165 = HEAP32[53355]|0;
  $17 = ($$0165|0)==(0|0);
  if ($17) {
   STACKTOP = sp;return 1;
  }
  $18 = ((($1)) + 8|0);
  $19 = HEAP32[$18>>2]|0;
  $$0166 = $$0165;
  while(1) {
   $257 = HEAP32[$$0166>>2]|0;
   $258 = HEAP32[$257>>2]|0;
   $259 = ($258|0)==($19|0);
   if ($259) {
    break;
   }
   $255 = ((($$0166)) + 1344|0);
   $$0 = HEAP32[$255>>2]|0;
   $256 = ($$0|0)==(0|0);
   if ($256) {
    label = 19;
    break;
   } else {
    $$0166 = $$0;
   }
  }
  if ((label|0) == 19) {
   STACKTOP = sp;return 1;
  }
  HEAP32[$15>>2] = 1620;
  $260 = ((($15)) + 8|0);
  HEAP32[$260>>2] = $19;
  (_SDL_PushEvent($15)|0);
  _UpdateEventsForDeviceRemoval();
  STACKTOP = sp;return 1;
  break;
 }
 default: {
  STACKTOP = sp;return 1;
 }
 }
 return (0)|0;
}
function _SDL_AddEventWatch($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$sink = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_SDL_malloc(12)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  return;
 }
 HEAP32[$2>>2] = $0;
 $4 = ((($2)) + 4|0);
 HEAP32[$4>>2] = $1;
 $5 = ((($2)) + 8|0);
 HEAP32[$5>>2] = 0;
 $6 = HEAP32[52666]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $$sink = 210664;
 } else {
  $$0 = $6;
  while(1) {
   $8 = ((($$0)) + 8|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = ($9|0)==(0|0);
   if ($10) {
    break;
   } else {
    $$0 = $9;
   }
  }
  $$sink = $8;
 }
 HEAP32[$$sink>>2] = $2;
 return;
}
function _SDL_NumJoysticks() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_SDL_SYS_NumJoysticks()|0);
 return ($0|0);
}
function _SDL_PrivateGetControllerMapping($0) {
 $0 = $0|0;
 var $$ = 0, $$0$i = 0, $$06$i = 0, $$07$i = 0, $$08$i = 0, $$2 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 _SDL_JoystickGetDeviceGUID($1,$0);
 $$07$i = HEAP32[53350]|0;
 $2 = ($$07$i|0)==(0|0);
 L1: do {
  if ($2) {
   $$06$i = 0;
  } else {
   $$08$i = $$07$i;
   while(1) {
    $3 = (_SDL_memcmp($1,$$08$i,16)|0);
    $4 = ($3|0)==(0);
    if ($4) {
     $$06$i = $$08$i;
     break L1;
    }
    $5 = ((($$08$i)) + 24|0);
    $$0$i = HEAP32[$5>>2]|0;
    $6 = ($$0$i|0)==(0|0);
    if ($6) {
     $$06$i = 0;
     break;
    } else {
     $$08$i = $$0$i;
    }
   }
  }
 } while(0);
 $7 = ($$06$i|0)==(0|0);
 $8 = HEAP32[53351]|0;
 $9 = ($8|0)!=(0|0);
 $or$cond = $7 & $9;
 $$ = $or$cond ? $8 : $$06$i;
 $10 = ($$|0)==(0|0);
 if (!($10)) {
  $$2 = $$;
  STACKTOP = sp;return ($$2|0);
 }
 $11 = (_SDL_JoystickNameForIndex($0)|0);
 $12 = ($11|0)==(0|0);
 if ($12) {
  $$2 = 0;
  STACKTOP = sp;return ($$2|0);
 }
 $13 = (_SDL_strstr($11,193512)|0);
 $14 = ($13|0)==(0|0);
 if ($14) {
  $15 = (_SDL_strstr($11,193517)|0);
  $16 = ($15|0)==(0|0);
  if ($16) {
   $$2 = 0;
   STACKTOP = sp;return ($$2|0);
  }
 }
 $17 = HEAP32[53352]|0;
 $$2 = $17;
 STACKTOP = sp;return ($$2|0);
}
function _SDL_JoystickGetDeviceGUID($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $vararg_buffer = sp;
 $2 = sp + 8|0;
 $3 = ($1|0)<(0);
 if (!($3)) {
  $4 = (_SDL_SYS_NumJoysticks()|0);
  $5 = ($4|0)>($1|0);
  if ($5) {
   _SDL_SYS_JoystickGetDeviceGUID($0,$1);
   STACKTOP = sp;return;
  }
 }
 $6 = (_SDL_SYS_NumJoysticks()|0);
 HEAP32[$vararg_buffer>>2] = $6;
 (_SDL_SetError(193523,$vararg_buffer)|0);
 (_SDL_memset($2,0,16)|0);
 dest=$0; src=$2; stop=dest+16|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 STACKTOP = sp;return;
}
function _SDL_JoystickNameForIndex($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $1 = ($0|0)<(0);
 if (!($1)) {
  $2 = (_SDL_SYS_NumJoysticks()|0);
  $3 = ($2|0)>($0|0);
  if ($3) {
   $5 = (_SDL_SYS_JoystickNameForDeviceIndex($0)|0);
   $$0 = $5;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $4 = (_SDL_SYS_NumJoysticks()|0);
 HEAP32[$vararg_buffer>>2] = $4;
 (_SDL_SetError(193523,$vararg_buffer)|0);
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _SDL_strstr($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_strstr($0,$1)|0);
 return ($2|0);
}
function _SDL_SYS_NumJoysticks() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[53354]|0;
 return ($0|0);
}
function _SDL_SYS_JoystickNameForDeviceIndex($0) {
 $0 = $0|0;
 var $$0$i = 0, $$0$lcssa$i = 0, $$046$i = 0, $$05$i = 0, $$07$i = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$05$i = HEAP32[53353]|0;
 $1 = ($0|0)>(0);
 if ($1) {
  $$046$i = $0;$$07$i = $$05$i;
  while(1) {
   $2 = (($$046$i) + -1)|0;
   $3 = ((($$07$i)) + 1320|0);
   $$0$i = HEAP32[$3>>2]|0;
   $4 = ($$046$i|0)>(1);
   if ($4) {
    $$046$i = $2;$$07$i = $$0$i;
   } else {
    $$0$lcssa$i = $$0$i;
    break;
   }
  }
 } else {
  $$0$lcssa$i = $$05$i;
 }
 $5 = ((($$0$lcssa$i)) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 return ($6|0);
}
function _SDL_SYS_JoystickGetDeviceGUID($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i = 0, $$0$lcssa$i$i = 0, $$046$i$i = 0, $$05$i$i = 0, $$07$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0;
 var stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $$05$i$i = HEAP32[53353]|0;
 $3 = ($1|0)>(0);
 if ($3) {
  $$046$i$i = $1;$$07$i$i = $$05$i$i;
  while(1) {
   $4 = (($$046$i$i) + -1)|0;
   $5 = ((($$07$i$i)) + 1320|0);
   $$0$i$i = HEAP32[$5>>2]|0;
   $6 = ($$046$i$i|0)>(1);
   if ($6) {
    $$046$i$i = $4;$$07$i$i = $$0$i$i;
   } else {
    $$0$lcssa$i$i = $$0$i$i;
    break;
   }
  }
 } else {
  $$0$lcssa$i$i = $$05$i$i;
 }
 $7 = ((($$0$lcssa$i$i)) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 (_SDL_memset($2,0,16)|0);
 $9 = (_SDL_strlen($8)|0);
 $10 = ($9>>>0)>(16);
 if ($10) {
  $12 = 16;
 } else {
  $11 = (_SDL_strlen($8)|0);
  $12 = $11;
 }
 (_SDL_memcpy($2,$8,$12)|0);
 dest=$0; src=$2; stop=dest+16|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 STACKTOP = sp;return;
}
function _UpdateEventsForDeviceRemoval() {
 var $$015 = 0, $$alloca_mul = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_SDL_PeepEvents(0,0,1,1619,1619)|0);
 $1 = ($0|0)<(1);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = ($0*56)|0;
 $$alloca_mul = $2;
 $3 = STACKTOP; STACKTOP = STACKTOP + ((((1*$$alloca_mul)|0)+15)&-16)|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(((((1*$$alloca_mul)|0)+15)&-16)|0);;
 $4 = (_SDL_PeepEvents($3,$0,2,1619,1619)|0);
 $5 = ($4|0)>(0);
 if ($5) {
  $$015 = 0;
  while(1) {
   $6 = (((($3) + (($$015*56)|0)|0)) + 8|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = (($7) + -1)|0;
   HEAP32[$6>>2] = $8;
   $9 = (($$015) + 1)|0;
   $exitcond = ($9|0)==($4|0);
   if ($exitcond) {
    break;
   } else {
    $$015 = $9;
   }
  }
 }
 (_SDL_PeepEvents($3,$4,0,0,0)|0);
 STACKTOP = sp;return;
}
function _SDL_JoystickGetGUIDFromString($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$ = 0, $$0$i = 0, $$0$i23 = 0, $$01926 = 0, $$027 = 0, $$25 = 0, $$off$i = 0, $$off$i20 = 0, $$off12$i = 0, $$off12$i21 = 0, $$off13$i = 0, $$off13$i22 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = (_SDL_strlen($1)|0);
 $4 = $3 & -2;
 (_SDL_memset($2,0,16)|0);
 $5 = ($4|0)==(0);
 L1: do {
  if (!($5)) {
   $6 = $2;
   $$01926 = $2;$$027 = 0;
   while(1) {
    $7 = $$01926;
    $8 = (($7) - ($6))|0;
    $9 = ($8|0)<(16);
    if (!($9)) {
     break L1;
    }
    $10 = (($1) + ($$027)|0);
    $11 = HEAP8[$10>>0]|0;
    $12 = $11 << 24 >> 24;
    $$off$i = (($11) + -48)<<24>>24;
    $13 = ($$off$i&255)<(10);
    do {
     if ($13) {
      $14 = (($12) + 208)|0;
      $$0$i = $14;
     } else {
      $$off12$i = (($11) + -65)<<24>>24;
      $15 = ($$off12$i&255)<(6);
      if ($15) {
       $16 = (($12) + 201)|0;
       $$0$i = $16;
       break;
      } else {
       $$off13$i = (($11) + -97)<<24>>24;
       $17 = ($$off13$i&255)<(6);
       $18 = (($12) + 169)|0;
       $$ = $17 ? $18 : 0;
       $$0$i = $$;
       break;
      }
     }
    } while(0);
    $19 = $$0$i << 4;
    $20 = $$027 | 1;
    $21 = (($1) + ($20)|0);
    $22 = HEAP8[$21>>0]|0;
    $23 = $22 << 24 >> 24;
    $$off$i20 = (($22) + -48)<<24>>24;
    $24 = ($$off$i20&255)<(10);
    do {
     if ($24) {
      $25 = (($23) + 208)|0;
      $$0$i23 = $25;
     } else {
      $$off12$i21 = (($22) + -65)<<24>>24;
      $26 = ($$off12$i21&255)<(6);
      if ($26) {
       $27 = (($23) + 201)|0;
       $$0$i23 = $27;
       break;
      } else {
       $$off13$i22 = (($22) + -97)<<24>>24;
       $28 = ($$off13$i22&255)<(6);
       $29 = (($23) + 169)|0;
       $$25 = $28 ? $29 : 0;
       $$0$i23 = $$25;
       break;
      }
     }
    } while(0);
    $30 = $$0$i23 | $19;
    $31 = $30&255;
    HEAP8[$$01926>>0] = $31;
    $32 = (($$027) + 2)|0;
    $33 = ((($$01926)) + 1|0);
    $34 = ($32>>>0)<($4>>>0);
    if ($34) {
     $$01926 = $33;$$027 = $32;
    } else {
     break;
    }
   }
  }
 } while(0);
 dest=$0; src=$2; stop=dest+16|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 STACKTOP = sp;return;
}
function _SDL_PrivateLoadButtonMapping($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$02125$i = 0, $$02224$i = 0, $$026$i = 0, $$1$i = 0, $$123$i = 0, $$235 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $scevgep = 0;
 var $vararg_buffer = 0, $vararg_buffer1 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(64|0);
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $4 = sp + 32|0;
 $5 = sp + 12|0;
 dest=$0; src=$1; stop=dest+16|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $6 = ((($0)) + 16|0);
 HEAP32[$6>>2] = $2;
 $7 = ((($0)) + 20|0);
 $8 = ((($0)) + 196|0);
 HEAP32[$8>>2] = -1;
 $9 = ((($0)) + 204|0);
 HEAP32[$9>>2] = -1;
 $10 = ((($0)) + 212|0);
 HEAP32[$10>>2] = -1;
 $11 = ((($0)) + 220|0);
 HEAP32[$11>>2] = -1;
 $12 = ((($0)) + 228|0);
 HEAP32[$12>>2] = -1;
 $13 = ((($0)) + 236|0);
 HEAP32[$13>>2] = -1;
 $14 = ((($0)) + 244|0);
 HEAP32[$14>>2] = -1;
 $15 = ((($0)) + 252|0);
 HEAP32[$15>>2] = -1;
 $16 = ((($0)) + 260|0);
 HEAP32[$16>>2] = -1;
 $17 = ((($0)) + 268|0);
 HEAP32[$17>>2] = -1;
 $18 = ((($0)) + 276|0);
 HEAP32[$18>>2] = -1;
 $19 = ((($0)) + 284|0);
 HEAP32[$19>>2] = -1;
 $20 = ((($0)) + 292|0);
 HEAP32[$20>>2] = -1;
 $21 = ((($0)) + 300|0);
 HEAP32[$21>>2] = -1;
 _memset(($7|0),-1,172)|0;
 $$235 = 0;
 while(1) {
  $22 = (((($0)) + 308|0) + ($$235<<2)|0);
  HEAP32[$22>>2] = -1;
  $23 = (((($0)) + 500|0) + ($$235<<2)|0);
  HEAP32[$23>>2] = -1;
  $24 = (((($0)) + 692|0) + ($$235<<2)|0);
  HEAP32[$24>>2] = -1;
  $25 = (((($0)) + 884|0) + ($$235<<2)|0);
  HEAP32[$25>>2] = -1;
  $26 = (($$235) + 1)|0;
  $exitcond = ($26|0)==(48);
  if ($exitcond) {
   break;
  } else {
   $$235 = $26;
  }
 }
 $scevgep = ((($0)) + 1076|0);
 _memset(($scevgep|0),-1,256)|0;
 (_SDL_memset($4,0,20)|0);
 (_SDL_memset($5,0,20)|0);
 $27 = ($3|0)==(0|0);
 L4: do {
  if (!($27)) {
   $$02125$i = 0;$$02224$i = 1;$$026$i = $3;
   L5: while(1) {
    $28 = HEAP8[$$026$i>>0]|0;
    L7: do {
     switch ($28<<24>>24) {
     case 0:  {
      break L4;
      break;
     }
     case 58:  {
      $$1$i = 0;$$123$i = 0;
      break;
     }
     case 32:  {
      $$1$i = $$02125$i;$$123$i = $$02224$i;
      break;
     }
     case 44:  {
      _SDL_PrivateGameControllerParseButton($4,$5,$0);
      (_SDL_memset($4,0,20)|0);
      (_SDL_memset($5,0,20)|0);
      $$1$i = 0;$$123$i = 1;
      break;
     }
     default: {
      $29 = ($$02224$i|0)==(0);
      $30 = ($$02125$i>>>0)>(19);
      if ($29) {
       if ($30) {
        label = 11;
        break L5;
       }
       $33 = (($5) + ($$02125$i)|0);
       HEAP8[$33>>0] = $28;
       $34 = (($$02125$i) + 1)|0;
       $$1$i = $34;$$123$i = 0;
       break L7;
      } else {
       if ($30) {
        label = 8;
        break L5;
       }
       $31 = (($4) + ($$02125$i)|0);
       HEAP8[$31>>0] = $28;
       $32 = (($$02125$i) + 1)|0;
       $$1$i = $32;$$123$i = $$02224$i;
       break L7;
      }
     }
     }
    } while(0);
    $35 = ((($$026$i)) + 1|0);
    $$02125$i = $$1$i;$$02224$i = $$123$i;$$026$i = $35;
   }
   if ((label|0) == 8) {
    HEAP32[$vararg_buffer>>2] = $4;
    (_SDL_SetError(193810,$vararg_buffer)|0);
    STACKTOP = sp;return;
   }
   else if ((label|0) == 11) {
    HEAP32[$vararg_buffer1>>2] = $5;
    (_SDL_SetError(193836,$vararg_buffer1)|0);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 _SDL_PrivateGameControllerParseButton($4,$5,$0);
 STACKTOP = sp;return;
}
function _SDL_PrivateGameControllerParseButton($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $vararg_buffer4 = sp + 16|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $3 = (_SDL_GameControllerGetButtonFromString($0)|0);
 $4 = (_SDL_GameControllerGetAxisFromString($0)|0);
 $5 = ((($1)) + 1|0);
 $6 = (_SDL_atoi($5)|0);
 $7 = HEAP8[$1>>0]|0;
 switch ($7<<24>>24) {
 case 97:  {
  $8 = ($6|0)>(47);
  if ($8) {
   HEAP32[$vararg_buffer>>2] = $6;
   (_SDL_SetError(193871,$vararg_buffer)|0);
   STACKTOP = sp;return;
  }
  $9 = ($4|0)==(-1);
  if (!($9)) {
   $10 = (((($2)) + 20|0) + ($4<<2)|0);
   HEAP32[$10>>2] = $6;
   $11 = (((($2)) + 308|0) + ($6<<2)|0);
   HEAP32[$11>>2] = $4;
   STACKTOP = sp;return;
  }
  $12 = ($3|0)==(-1);
  if ($12) {
   STACKTOP = sp;return;
  }
  $13 = (((($2)) + 884|0) + ($6<<2)|0);
  $14 = (((($2)) + 128|0) + ($3<<2)|0);
  HEAP32[$14>>2] = $6;
  HEAP32[$13>>2] = $3;
  STACKTOP = sp;return;
  break;
 }
 case 98:  {
  $15 = ($6|0)>(47);
  if ($15) {
   HEAP32[$vararg_buffer1>>2] = $6;
   (_SDL_SetError(193896,$vararg_buffer1)|0);
   STACKTOP = sp;return;
  }
  $16 = ($3|0)==(-1);
  if (!($16)) {
   $17 = (((($2)) + 68|0) + ($3<<2)|0);
   HEAP32[$17>>2] = $6;
   $18 = (((($2)) + 692|0) + ($6<<2)|0);
   HEAP32[$18>>2] = $3;
   STACKTOP = sp;return;
  }
  $19 = ($4|0)==(-1);
  if ($19) {
   STACKTOP = sp;return;
  }
  $20 = (((($2)) + 500|0) + ($6<<2)|0);
  $21 = (((($2)) + 44|0) + ($4<<2)|0);
  HEAP32[$21>>2] = $6;
  HEAP32[$20>>2] = $4;
  STACKTOP = sp;return;
  break;
 }
 case 104:  {
  $22 = (_SDL_atoi($5)|0);
  $23 = ((($1)) + 3|0);
  $24 = (_SDL_atoi($23)|0);
  $25 = ($22|0)>(3);
  if ($25) {
   HEAP32[$vararg_buffer4>>2] = $6;
   (_SDL_SetError(193923,$vararg_buffer4)|0);
  }
  $26 = ($3|0)==(-1);
  if ($26) {
   STACKTOP = sp;return;
  }
  $27 = $22 << 4;
  $28 = $27 | $24;
  $29 = (((($2)) + 1076|0) + ($28<<2)|0);
  $30 = (((((($2)) + 188|0) + ($3<<3)|0)) + 4|0);
  $31 = (((($2)) + 188|0) + ($3<<3)|0);
  HEAP32[$31>>2] = $22;
  $32 = $24&255;
  HEAP8[$30>>0] = $32;
  HEAP32[$29>>2] = $3;
  STACKTOP = sp;return;
  break;
 }
 default: {
  STACKTOP = sp;return;
 }
 }
}
function _SDL_GameControllerGetButtonFromString($0) {
 $0 = $0|0;
 var $$ = 0, $$07 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ($0|0)==(0|0);
 if ($1) {
  $$07 = -1;
 } else {
  $2 = HEAP8[$0>>0]|0;
  $3 = ($2<<24>>24)==(0);
  if ($3) {
   $$07 = -1;
  } else {
   $4 = (_SDL_strcasecmp($0,195906)|0);
   $5 = ($4|0)==(0);
   if ($5) {
    $$07 = 0;
   } else {
    $6 = (_SDL_strcasecmp($0,195908)|0);
    $7 = ($6|0)==(0);
    if ($7) {
     $$07 = 1;
    } else {
     $8 = (_SDL_strcasecmp($0,193998)|0);
     $9 = ($8|0)==(0);
     if ($9) {
      $$07 = 2;
     } else {
      $10 = (_SDL_strcasecmp($0,194000)|0);
      $11 = ($10|0)==(0);
      if ($11) {
       $$07 = 3;
      } else {
       $12 = (_SDL_strcasecmp($0,194002)|0);
       $13 = ($12|0)==(0);
       if ($13) {
        $$07 = 4;
       } else {
        $14 = (_SDL_strcasecmp($0,194007)|0);
        $15 = ($14|0)==(0);
        if ($15) {
         $$07 = 5;
        } else {
         $16 = (_SDL_strcasecmp($0,194013)|0);
         $17 = ($16|0)==(0);
         if ($17) {
          $$07 = 6;
         } else {
          $18 = (_SDL_strcasecmp($0,194019)|0);
          $19 = ($18|0)==(0);
          if ($19) {
           $$07 = 7;
          } else {
           $20 = (_SDL_strcasecmp($0,194029)|0);
           $21 = ($20|0)==(0);
           if ($21) {
            $$07 = 8;
           } else {
            $22 = (_SDL_strcasecmp($0,194040)|0);
            $23 = ($22|0)==(0);
            if ($23) {
             $$07 = 9;
            } else {
             $24 = (_SDL_strcasecmp($0,194053)|0);
             $25 = ($24|0)==(0);
             if ($25) {
              $$07 = 10;
             } else {
              $26 = (_SDL_strcasecmp($0,194067)|0);
              $27 = ($26|0)==(0);
              if ($27) {
               $$07 = 11;
              } else {
               $28 = (_SDL_strcasecmp($0,194072)|0);
               $29 = ($28|0)==(0);
               if ($29) {
                $$07 = 12;
               } else {
                $30 = (_SDL_strcasecmp($0,194079)|0);
                $31 = ($30|0)==(0);
                if ($31) {
                 $$07 = 13;
                } else {
                 $32 = (_SDL_strcasecmp($0,194086)|0);
                 $33 = ($32|0)==(0);
                 $$ = $33 ? 14 : -1;
                 return ($$|0);
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 }
 return ($$07|0);
}
function _SDL_GameControllerGetAxisFromString($0) {
 $0 = $0|0;
 var $$ = 0, $$07 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ($0|0)==(0|0);
 if ($1) {
  $$07 = -1;
 } else {
  $2 = HEAP8[$0>>0]|0;
  $3 = ($2<<24>>24)==(0);
  if ($3) {
   $$07 = -1;
  } else {
   $4 = (_SDL_strcasecmp($0,193947)|0);
   $5 = ($4|0)==(0);
   if ($5) {
    $$07 = 0;
   } else {
    $6 = (_SDL_strcasecmp($0,193953)|0);
    $7 = ($6|0)==(0);
    if ($7) {
     $$07 = 1;
    } else {
     $8 = (_SDL_strcasecmp($0,193959)|0);
     $9 = ($8|0)==(0);
     if ($9) {
      $$07 = 2;
     } else {
      $10 = (_SDL_strcasecmp($0,193966)|0);
      $11 = ($10|0)==(0);
      if ($11) {
       $$07 = 3;
      } else {
       $12 = (_SDL_strcasecmp($0,193973)|0);
       $13 = ($12|0)==(0);
       if ($13) {
        $$07 = 4;
       } else {
        $14 = (_SDL_strcasecmp($0,193985)|0);
        $15 = ($14|0)==(0);
        $$ = $15 ? 5 : -1;
        return ($$|0);
       }
      }
     }
    }
   }
  }
 }
 return ($$07|0);
}
function _SDL_JoystickAllowBackgroundEventsChanged($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$ = 0, $$sink = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $$sink = 0;
 } else {
  $5 = HEAP8[$3>>0]|0;
  $6 = ($5<<24>>24)==(49);
  $$ = $6&1;
  $$sink = $$;
 }
 HEAP32[53358] = $$sink;
 return;
}
function _SDL_AddHintCallback($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$0$i = 0, $$013$i = 0, $$015$i = 0, $$016$i = 0, $$02228$i = 0, $$023$i = 0, $$02330$i = 0, $$02331$i = 0, $$029$i = 0, $$029$i$phi = 0, $$048 = 0, $$049 = 0, $$1 = 0, $$sink$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $3 = ($0|0)==(0|0);
 if (!($3)) {
  $4 = HEAP8[$0>>0]|0;
  $5 = ($4<<24>>24)==(0);
  if (!($5)) {
   $6 = ($1|0)==(0|0);
   if ($6) {
    HEAP32[$vararg_buffer1>>2] = 194240;
    (_SDL_SetError(194740,$vararg_buffer1)|0);
    STACKTOP = sp;return;
   }
   $$02330$i = HEAP32[52378]|0;
   $7 = ($$02330$i|0)==(0|0);
   L8: do {
    if (!($7)) {
     $$02331$i = $$02330$i;
     while(1) {
      $8 = HEAP32[$$02331$i>>2]|0;
      $9 = (_SDL_strcmp($0,$8)|0);
      $10 = ($9|0)==(0);
      if ($10) {
       break;
      }
      $24 = ((($$02331$i)) + 16|0);
      $$023$i = HEAP32[$24>>2]|0;
      $25 = ($$023$i|0)==(0|0);
      if ($25) {
       break L8;
      } else {
       $$02331$i = $$023$i;
      }
     }
     $11 = ((($$02331$i)) + 12|0);
     $12 = HEAP32[$11>>2]|0;
     $13 = ($12|0)==(0|0);
     if (!($13)) {
      $$02228$i = $12;$$029$i = 0;
      while(1) {
       $14 = HEAP32[$$02228$i>>2]|0;
       $15 = ($14|0)==($1|0);
       $16 = ((($$02228$i)) + 8|0);
       $17 = HEAP32[$16>>2]|0;
       if ($15) {
        $18 = ((($$02228$i)) + 4|0);
        $19 = HEAP32[$18>>2]|0;
        $20 = ($19|0)==($2|0);
        if ($20) {
         break;
        }
       }
       $21 = ($17|0)==(0|0);
       if ($21) {
        break L8;
       } else {
        $$029$i$phi = $$02228$i;$$02228$i = $17;$$029$i = $$029$i$phi;
       }
      }
      $22 = ($$029$i|0)!=(0|0);
      $23 = ((($$029$i)) + 8|0);
      $$sink$i = $22 ? $23 : $11;
      HEAP32[$$sink$i>>2] = $17;
      _SDL_free($$02228$i);
     }
    }
   } while(0);
   $26 = (_SDL_malloc(12)|0);
   $27 = ($26|0)==(0|0);
   if ($27) {
    (_SDL_Error(0)|0);
    STACKTOP = sp;return;
   }
   HEAP32[$26>>2] = $1;
   $28 = ((($26)) + 4|0);
   HEAP32[$28>>2] = $2;
   $$048 = HEAP32[52378]|0;
   $29 = ($$048|0)==(0|0);
   L24: do {
    if ($29) {
     label = 19;
    } else {
     $$049 = $$048;
     while(1) {
      $30 = HEAP32[$$049>>2]|0;
      $31 = (_SDL_strcmp($0,$30)|0);
      $32 = ($31|0)==(0);
      if ($32) {
       $$1 = $$049;
       break L24;
      }
      $33 = ((($$049)) + 16|0);
      $$0 = HEAP32[$33>>2]|0;
      $34 = ($$0|0)==(0|0);
      if ($34) {
       label = 19;
       break;
      } else {
       $$049 = $$0;
      }
     }
    }
   } while(0);
   do {
    if ((label|0) == 19) {
     $35 = (_SDL_malloc(20)|0);
     $36 = ($35|0)==(0|0);
     if (!($36)) {
      $37 = (_SDL_strdup($0)|0);
      HEAP32[$35>>2] = $37;
      $38 = ((($35)) + 4|0);
      HEAP32[$38>>2] = 0;
      $39 = ((($35)) + 8|0);
      HEAP32[$39>>2] = 0;
      $40 = ((($35)) + 12|0);
      HEAP32[$40>>2] = 0;
      $41 = HEAP32[52378]|0;
      $42 = ((($35)) + 16|0);
      HEAP32[$42>>2] = $41;
      HEAP32[52378] = $35;
      $$1 = $35;
      break;
     }
     (_SDL_Error(0)|0);
     _SDL_free($26);
     STACKTOP = sp;return;
    }
   } while(0);
   $43 = ((($$1)) + 12|0);
   $44 = HEAP32[$43>>2]|0;
   $45 = ((($26)) + 8|0);
   HEAP32[$45>>2] = $44;
   HEAP32[$43>>2] = $26;
   $46 = (_SDL_getenv($0)|0);
   $$015$i = HEAP32[52378]|0;
   $47 = ($$015$i|0)==(0|0);
   L35: do {
    if ($47) {
     $$013$i = $46;
    } else {
     $$016$i = $$015$i;
     while(1) {
      $48 = HEAP32[$$016$i>>2]|0;
      $49 = (_SDL_strcmp($0,$48)|0);
      $50 = ($49|0)==(0);
      if ($50) {
       break;
      }
      $57 = ((($$016$i)) + 16|0);
      $$0$i = HEAP32[$57>>2]|0;
      $58 = ($$0$i|0)==(0|0);
      if ($58) {
       $$013$i = $46;
       break L35;
      } else {
       $$016$i = $$0$i;
      }
     }
     $51 = ($46|0)==(0|0);
     if (!($51)) {
      $52 = ((($$016$i)) + 8|0);
      $53 = HEAP32[$52>>2]|0;
      $54 = ($53|0)==(2);
      if (!($54)) {
       $$013$i = $46;
       break;
      }
     }
     $55 = ((($$016$i)) + 4|0);
     $56 = HEAP32[$55>>2]|0;
     $$013$i = $56;
    }
   } while(0);
   FUNCTION_TABLE_viiii[$1 & 8191]($2,$0,$$013$i,$$013$i);
   STACKTOP = sp;return;
  }
 }
 HEAP32[$vararg_buffer>>2] = 194235;
 (_SDL_SetError(194740,$vararg_buffer)|0);
 STACKTOP = sp;return;
}
function _SDL_SYS_JoystickInit() {
 var $$0 = 0, $$01519 = 0, $$in910$i = 0, $$in910$i16 = 0, $$sink = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1440|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(1440|0);
 $vararg_buffer = sp + 1432|0;
 $0 = sp;
 HEAP32[53354] = 0;
 $1 = (_emscripten_get_num_gamepads()|0);
 $2 = ($1|0)==(-1);
 do {
  if ($2) {
   $$sink = 194212;
  } else {
   $3 = ($1|0)>(0);
   if ($3) {
    $$01519 = 0;
    while(1) {
     $4 = (_emscripten_get_gamepad_status(($$01519|0),($0|0))|0);
     $5 = ($4|0)==(0);
     if ($5) {
      (_Emscripten_JoyStickConnected(0,$0,0)|0);
     }
     $6 = (($$01519) + 1)|0;
     $exitcond = ($6|0)==($1|0);
     if ($exitcond) {
      break;
     } else {
      $$01519 = $6;
     }
    }
   }
   $7 = (_emscripten_set_gamepadconnected_callback((0|0),0,(4475|0))|0);
   $8 = ($7|0)==(0);
   if (!($8)) {
    $9 = HEAP32[53353]|0;
    $10 = ($9|0)==(0|0);
    if (!($10)) {
     $$in910$i = $9;
     while(1) {
      $11 = ((($$in910$i)) + 1320|0);
      $12 = HEAP32[$11>>2]|0;
      $13 = ((($$in910$i)) + 8|0);
      $14 = HEAP32[$13>>2]|0;
      _SDL_free($14);
      $15 = ((($$in910$i)) + 4|0);
      $16 = HEAP32[$15>>2]|0;
      _SDL_free($16);
      _SDL_free($$in910$i);
      $17 = ($12|0)==(0|0);
      if ($17) {
       break;
      } else {
       $$in910$i = $12;
      }
     }
    }
    HEAP32[53356] = 0;
    HEAP32[53353] = 0;
    HEAP32[53354] = 0;
    HEAP32[53357] = 0;
    (_emscripten_set_gamepadconnected_callback((0|0),0,(0|0))|0);
    (_emscripten_set_gamepaddisconnected_callback((0|0),0,(0|0))|0);
    $$sink = 194173;
    break;
   }
   $18 = (_emscripten_set_gamepaddisconnected_callback((0|0),0,(4476|0))|0);
   $19 = ($18|0)==(0);
   if ($19) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $20 = HEAP32[53353]|0;
   $21 = ($20|0)==(0|0);
   if (!($21)) {
    $$in910$i16 = $20;
    while(1) {
     $22 = ((($$in910$i16)) + 1320|0);
     $23 = HEAP32[$22>>2]|0;
     $24 = ((($$in910$i16)) + 8|0);
     $25 = HEAP32[$24>>2]|0;
     _SDL_free($25);
     $26 = ((($$in910$i16)) + 4|0);
     $27 = HEAP32[$26>>2]|0;
     _SDL_free($27);
     _SDL_free($$in910$i16);
     $28 = ($23|0)==(0|0);
     if ($28) {
      break;
     } else {
      $$in910$i16 = $23;
     }
    }
   }
   HEAP32[53356] = 0;
   HEAP32[53353] = 0;
   HEAP32[53354] = 0;
   HEAP32[53357] = 0;
   (_emscripten_set_gamepadconnected_callback((0|0),0,(0|0))|0);
   (_emscripten_set_gamepaddisconnected_callback((0|0),0,(0|0))|0);
   $$sink = 194131;
  }
 } while(0);
 $29 = (_SDL_SetError($$sink,$vararg_buffer)|0);
 $$0 = $29;
 STACKTOP = sp;return ($$0|0);
}
function _Emscripten_JoyStickConnected($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$i = 0, $$04446 = 0, $$08$i = 0, $$09$i = 0, $$145 = 0, $$pre = 0, $$sink = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0.0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0.0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0.0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($1)) + 1300|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)<(0);
 L1: do {
  if (!($5)) {
   $$08$i = HEAP32[53353]|0;
   $6 = ($$08$i|0)==(0|0);
   if (!($6)) {
    $$09$i = $$08$i;
    while(1) {
     $7 = HEAP32[$$09$i>>2]|0;
     $8 = ($7|0)==($4|0);
     if ($8) {
      break;
     }
     $9 = ((($$09$i)) + 1320|0);
     $$0$i = HEAP32[$9>>2]|0;
     $10 = ($$0$i|0)==(0|0);
     if ($10) {
      break L1;
     } else {
      $$09$i = $$0$i;
     }
    }
    return 1;
   }
  }
 } while(0);
 $11 = (_SDL_malloc(1328)|0);
 $12 = ($11|0)==(0|0);
 if ($12) {
  return 1;
 }
 (_SDL_memset($11,0,1328)|0);
 $13 = HEAP32[$3>>2]|0;
 HEAP32[$11>>2] = $13;
 $14 = ((($1)) + 1304|0);
 $15 = (_SDL_strdup($14)|0);
 $16 = ((($11)) + 4|0);
 HEAP32[$16>>2] = $15;
 $17 = ($15|0)==(0|0);
 if ($17) {
  _SDL_free($11);
  return 1;
 }
 $18 = ((($1)) + 1368|0);
 $19 = (_SDL_strdup($18)|0);
 $20 = ((($11)) + 8|0);
 HEAP32[$20>>2] = $19;
 $21 = ($19|0)==(0|0);
 if ($21) {
  $22 = HEAP32[$16>>2]|0;
  _SDL_free($22);
  _SDL_free($11);
  return 1;
 }
 $23 = ((($1)) + 8|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ((($11)) + 24|0);
 HEAP32[$25>>2] = $24;
 $26 = ((($1)) + 12|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ((($11)) + 20|0);
 HEAP32[$28>>2] = $27;
 $29 = HEAP32[53357]|0;
 $30 = (($29) + 1)|0;
 HEAP32[53357] = $30;
 $31 = ((($11)) + 12|0);
 HEAP32[$31>>2] = $29;
 $32 = +HEAPF64[$1>>3];
 $33 = ((($11)) + 32|0);
 HEAPF64[$33>>3] = $32;
 $34 = ($24|0)>(0);
 if ($34) {
  $35 = ((($11)) + 40|0);
  $$04446 = 0;
  while(1) {
   $40 = (((($1)) + 16|0) + ($$04446<<3)|0);
   $41 = +HEAPF64[$40>>3];
   $42 = (($35) + ($$04446<<3)|0);
   HEAPF64[$42>>3] = $41;
   $43 = (($$04446) + 1)|0;
   $44 = HEAP32[$25>>2]|0;
   $45 = ($43|0)<($44|0);
   if ($45) {
    $$04446 = $43;
   } else {
    break;
   }
  }
  $$pre = HEAP32[$28>>2]|0;
  $36 = $$pre;
 } else {
  $36 = $27;
 }
 $37 = ($36|0)>(0);
 if ($37) {
  $38 = ((($11)) + 552|0);
  $39 = ((($11)) + 1064|0);
  $$145 = 0;
  while(1) {
   $46 = (((($1)) + 528|0) + ($$145<<3)|0);
   $47 = +HEAPF64[$46>>3];
   $48 = (($38) + ($$145<<3)|0);
   HEAPF64[$48>>3] = $47;
   $49 = (((($1)) + 1040|0) + ($$145<<2)|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = (($39) + ($$145<<2)|0);
   HEAP32[$51>>2] = $50;
   $52 = (($$145) + 1)|0;
   $53 = HEAP32[$28>>2]|0;
   $54 = ($52|0)<($53|0);
   if ($54) {
    $$145 = $52;
   } else {
    break;
   }
  }
 }
 $55 = HEAP32[53356]|0;
 $56 = ($55|0)==(0|0);
 if ($56) {
  HEAP32[53356] = $11;
  $$sink = 213412;
 } else {
  $57 = ((($55)) + 1320|0);
  HEAP32[$57>>2] = $11;
  $$sink = 213424;
 }
 HEAP32[$$sink>>2] = $11;
 $58 = HEAP32[53354]|0;
 $59 = (($58) + 1)|0;
 HEAP32[53354] = $59;
 _SDL_PrivateJoystickAdded($58);
 return 1;
}
function _Emscripten_JoyStickDisconnected($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$020 = 0, $$02024 = 0, $$02027 = 0, $$026 = 0, $$026$phi = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $cond = 0, $cond25 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$02024 = HEAP32[53353]|0;
 $cond25 = ($$02024|0)==(0|0);
 if ($cond25) {
  return 1;
 }
 $3 = ((($1)) + 1300|0);
 $4 = HEAP32[$3>>2]|0;
 $$02027 = $$02024;$$026 = 0;
 while(1) {
  $5 = HEAP32[$$02027>>2]|0;
  $6 = ($5|0)==($4|0);
  if ($6) {
   break;
  }
  $7 = ((($$02027)) + 1320|0);
  $$020 = HEAP32[$7>>2]|0;
  $cond = ($$020|0)==(0|0);
  if ($cond) {
   label = 13;
   break;
  } else {
   $$026$phi = $$02027;$$02027 = $$020;$$026 = $$026$phi;
  }
 }
 if ((label|0) == 13) {
  return 1;
 }
 $8 = ((($$02027)) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if (!($10)) {
  $11 = ((($9)) + 44|0);
  HEAP32[$11>>2] = 0;
 }
 $12 = ($$026|0)==(0|0);
 $13 = ((($$02027)) + 1320|0);
 $14 = HEAP32[$13>>2]|0;
 if ($12) {
  HEAP32[53353] = $14;
 } else {
  $15 = ((($$026)) + 1320|0);
  HEAP32[$15>>2] = $14;
 }
 $16 = HEAP32[53356]|0;
 $17 = ($$02027|0)==($16|0);
 if ($17) {
  HEAP32[53356] = $$026;
 }
 $18 = HEAP32[53354]|0;
 $19 = (($18) + -1)|0;
 HEAP32[53354] = $19;
 $20 = ((($$02027)) + 12|0);
 $21 = HEAP32[$20>>2]|0;
 _SDL_PrivateJoystickRemoved($21);
 $22 = ((($$02027)) + 4|0);
 $23 = HEAP32[$22>>2]|0;
 _SDL_free($23);
 $24 = ((($$02027)) + 8|0);
 $25 = HEAP32[$24>>2]|0;
 _SDL_free($25);
 _SDL_free($$02027);
 return 1;
}
function _SDL_PrivateJoystickRemoved($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(64|0);
 $1 = sp;
 HEAP32[$1>>2] = 1542;
 $2 = (_SDL_EventState(1542,-1)|0);
 $3 = ($2<<24>>24)==(1);
 do {
  if ($3) {
   $4 = ((($1)) + 8|0);
   HEAP32[$4>>2] = $0;
   $5 = HEAP32[52369]|0;
   $6 = ($5|0)==(0|0);
   if (!($6)) {
    $7 = HEAP32[52370]|0;
    $8 = (FUNCTION_TABLE_iii[$5 & 8191]($7,$1)|0);
    $9 = ($8|0)==(0);
    if ($9) {
     break;
    }
   }
   (_SDL_PushEvent($1)|0);
  }
 } while(0);
 _UpdateEventsForDeviceRemoval_352();
 STACKTOP = sp;return;
}
function _UpdateEventsForDeviceRemoval_352() {
 var $$015 = 0, $$alloca_mul = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_SDL_PeepEvents(0,0,1,1541,1541)|0);
 $1 = ($0|0)<(1);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = ($0*56)|0;
 $$alloca_mul = $2;
 $3 = STACKTOP; STACKTOP = STACKTOP + ((((1*$$alloca_mul)|0)+15)&-16)|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(((((1*$$alloca_mul)|0)+15)&-16)|0);;
 $4 = (_SDL_PeepEvents($3,$0,2,1541,1541)|0);
 $5 = ($4|0)>(0);
 if ($5) {
  $$015 = 0;
  while(1) {
   $6 = (((($3) + (($$015*56)|0)|0)) + 8|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = (($7) + -1)|0;
   HEAP32[$6>>2] = $8;
   $9 = (($$015) + 1)|0;
   $exitcond = ($9|0)==($4|0);
   if ($exitcond) {
    break;
   } else {
    $$015 = $9;
   }
  }
 }
 (_SDL_PeepEvents($3,$4,0,0,0)|0);
 STACKTOP = sp;return;
}
function _SDL_PrivateJoystickAdded($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(64|0);
 $1 = sp;
 HEAP32[$1>>2] = 1541;
 $2 = (_SDL_EventState(1541,-1)|0);
 $3 = ($2<<24>>24)==(1);
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $4 = ((($1)) + 8|0);
 HEAP32[$4>>2] = $0;
 $5 = HEAP32[52369]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = HEAP32[52370]|0;
  $8 = (FUNCTION_TABLE_iii[$5 & 8191]($7,$1)|0);
  $9 = ($8|0)==(0);
  if ($9) {
   STACKTOP = sp;return;
  }
 }
 (_SDL_PushEvent($1)|0);
 STACKTOP = sp;return;
}
function _SDL_WasInit($0) {
 $0 = $0|0;
 var $$ = 0, $$0$ = 0, $$0$lcssa = 0, $$01924 = 0, $$025 = 0, $$1 = 0, $$12123 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $exitcond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ($0|0)==(0);
 $$ = $1 ? 29233 : $0;
 $2 = (Math_clz32(($$|0))|0);
 $3 = ($2>>>0)>(31);
 if ($3) {
  $$0$lcssa = 0;
  return ($$0$lcssa|0);
 }
 $4 = (32 - ($2))|0;
 $$01924 = 0;$$025 = 0;$$12123 = $$;
 while(1) {
  $5 = $$12123 & 1;
  $6 = ($5|0)==(0);
  if ($6) {
   $$1 = $$025;
  } else {
   $7 = (219426 + ($$01924)|0);
   $8 = HEAP8[$7>>0]|0;
   $9 = ($8<<24>>24)==(0);
   $10 = 1 << $$01924;
   $11 = $9 ? 0 : $10;
   $$0$ = $11 | $$025;
   $$1 = $$0$;
  }
  $12 = $$12123 >>> 1;
  $13 = (($$01924) + 1)|0;
  $exitcond = ($13|0)==($4|0);
  if ($exitcond) {
   $$0$lcssa = $$1;
   break;
  } else {
   $$01924 = $13;$$025 = $$1;$$12123 = $12;
  }
 }
 return ($$0$lcssa|0);
}
function _SDL_AudioQuit() {
 var $$in$i = 0, $$in$i4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[53320]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  return;
 }
 $2 = HEAP32[53359]|0;
 _close_audio_device($2);
 $3 = HEAP32[(213440)>>2]|0;
 _close_audio_device($3);
 $4 = HEAP32[(213444)>>2]|0;
 _close_audio_device($4);
 $5 = HEAP32[(213448)>>2]|0;
 _close_audio_device($5);
 $6 = HEAP32[(213452)>>2]|0;
 _close_audio_device($6);
 $7 = HEAP32[(213456)>>2]|0;
 _close_audio_device($7);
 $8 = HEAP32[(213460)>>2]|0;
 _close_audio_device($8);
 $9 = HEAP32[(213464)>>2]|0;
 _close_audio_device($9);
 $10 = HEAP32[(213468)>>2]|0;
 _close_audio_device($10);
 $11 = HEAP32[(213472)>>2]|0;
 _close_audio_device($11);
 $12 = HEAP32[(213476)>>2]|0;
 _close_audio_device($12);
 $13 = HEAP32[(213480)>>2]|0;
 _close_audio_device($13);
 $14 = HEAP32[(213484)>>2]|0;
 _close_audio_device($14);
 $15 = HEAP32[(213488)>>2]|0;
 _close_audio_device($15);
 $16 = HEAP32[(213492)>>2]|0;
 _close_audio_device($16);
 $17 = HEAP32[(213496)>>2]|0;
 _close_audio_device($17);
 $18 = HEAP32[(213392)>>2]|0;
 $19 = ($18|0)==(0|0);
 if (!($19)) {
  $$in$i = $18;
  while(1) {
   $20 = ((($$in$i)) + 4|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = HEAP32[$$in$i>>2]|0;
   $23 = ($22|0)==(0|0);
   if (!($23)) {
    $24 = HEAP32[(213340)>>2]|0;
    FUNCTION_TABLE_vi[$24 & 8191]($22);
   }
   _SDL_free($$in$i);
   $25 = ($21|0)==(0|0);
   if ($25) {
    break;
   } else {
    $$in$i = $21;
   }
  }
 }
 HEAP32[(213392)>>2] = 0;
 HEAP32[(213384)>>2] = 0;
 $26 = HEAP32[(213396)>>2]|0;
 $27 = ($26|0)==(0|0);
 if (!($27)) {
  $$in$i4 = $26;
  while(1) {
   $28 = ((($$in$i4)) + 4|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = HEAP32[$$in$i4>>2]|0;
   $31 = ($30|0)==(0|0);
   if (!($31)) {
    $32 = HEAP32[(213340)>>2]|0;
    FUNCTION_TABLE_vi[$32 & 8191]($30);
   }
   _SDL_free($$in$i4);
   $33 = ($29|0)==(0|0);
   if ($33) {
    break;
   } else {
    $$in$i4 = $29;
   }
  }
 }
 HEAP32[(213396)>>2] = 0;
 HEAP32[(213388)>>2] = 0;
 $34 = HEAP32[(213344)>>2]|0;
 FUNCTION_TABLE_v[$34 & 8191]();
 $35 = HEAP32[(213372)>>2]|0;
 _SDL_DestroyMutex($35);
 (_SDL_memset(213280,0,120)|0);
 (_SDL_memset(213436,0,64)|0);
 return;
}
function _SDL_strncasecmp($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (_strncasecmp($0,$1,$2)|0);
 return ($3|0);
}
function _SDL_CreateMutex() {
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_SDL_malloc(12)|0);
 $1 = ($0|0)==(0|0);
 if ($1) {
  (_SDL_Error(0)|0);
  $$0 = $0;
  return ($$0|0);
 }
 $2 = (_SDL_CreateSemaphore(1)|0);
 $3 = ((($0)) + 8|0);
 HEAP32[$3>>2] = $2;
 HEAP32[$0>>2] = 0;
 $4 = ((($0)) + 4|0);
 HEAP32[$4>>2] = 0;
 $5 = ($2|0)==(0|0);
 if (!($5)) {
  $$0 = $0;
  return ($$0|0);
 }
 _SDL_free($0);
 $$0 = 0;
 return ($$0|0);
}
function _SDL_AudioLockOrUnlockDeviceWithNoMixerLock($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function _SDL_AudioDetectDevices_Default() {
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 _SDL_AddAudioDevice(0,194323,(1));
 $0 = HEAP32[(213356)>>2]|0;
 $1 = ($0|0)==(0);
 if ($1) {
  return;
 }
 _SDL_AddAudioDevice(1,194350,(2));
 return;
}
function _SDL_AudioOpenDevice_Default($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = (_SDL_Error(4)|0);
 return ($4|0);
}
function _SDL_AudioThreadInit_Default($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function _SDL_AudioWaitDevice_Default($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function _SDL_AudioPlayDevice_Default($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function _SDL_AudioGetPendingBytes_Default($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function _SDL_AudioGetDeviceBuf_Default($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function _SDL_AudioCaptureFromDevice_Default($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return -1;
}
function _SDL_AudioFlushCapture_Default($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function _SDL_AudioPrepareToClose_Default($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function _SDL_AudioCloseDevice_Default($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function _SDL_AudioLockDevice_Default($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 156|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = (_SDL_ThreadID()|0);
  $5 = ((($0)) + 160|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($4|0)==($6|0);
  if ($7) {
   return;
  }
 }
 return;
}
function _SDL_AudioUnlockDevice_Default($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 156|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = (_SDL_ThreadID()|0);
  $5 = ((($0)) + 160|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($4|0)==($6|0);
  if ($7) {
   return;
  }
 }
 return;
}
function _SDL_AudioFreeDeviceHandle_Default($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function _SDL_AudioDeinitialize_Default() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function _SDL_CreateSemaphore($0) {
 $0 = $0|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 (_SDL_SetError(194378,$vararg_buffer)|0);
 STACKTOP = sp;return (0|0);
}
function _close_audio_device($0) {
 $0 = $0|0;
 var $$05$i = 0, $$05$i21 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ($0|0)==(0|0);
 if ($1) {
  return;
 }
 $2 = HEAP32[$0>>2]|0;
 $3 = ($2|0)==(0);
 if (!($3)) {
  $4 = (($2) + -1)|0;
  $5 = (213436 + ($4<<2)|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==($0|0);
  if ($7) {
   HEAP32[$5>>2] = 0;
  }
 }
 $8 = ((($0)) + 132|0);
 (_SDL_AtomicSet($8,1)|0);
 $9 = ((($0)) + 136|0);
 (_SDL_AtomicSet($9,0)|0);
 $10 = ((($0)) + 156|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0|0);
 if (!($12)) {
  _SDL_WaitThread($11,0);
 }
 $13 = ((($0)) + 152|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(0|0);
 if (!($15)) {
  _SDL_DestroyMutex($14);
 }
 $16 = ((($0)) + 148|0);
 $17 = HEAP32[$16>>2]|0;
 _SDL_free($17);
 $18 = ((($0)) + 28|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)==(0);
 if (!($20)) {
  $21 = ((($0)) + 44|0);
  $22 = HEAP32[$21>>2]|0;
  _SDL_free($22);
 }
 $23 = ((($0)) + 180|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)==(0|0);
 if (!($25)) {
  $26 = HEAP32[(213328)>>2]|0;
  FUNCTION_TABLE_vi[$26 & 8191]($0);
 }
 $27 = ((($0)) + 164|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = ($28|0)==(0|0);
 if (!($29)) {
  $$05$i = $28;
  while(1) {
   $30 = ((($$05$i)) + 8200|0);
   $31 = HEAP32[$30>>2]|0;
   _SDL_free($$05$i);
   $32 = ($31|0)==(0|0);
   if ($32) {
    break;
   } else {
    $$05$i = $31;
   }
  }
 }
 $33 = ((($0)) + 172|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)==(0|0);
 if (!($35)) {
  $$05$i21 = $34;
  while(1) {
   $36 = ((($$05$i21)) + 8200|0);
   $37 = HEAP32[$36>>2]|0;
   _SDL_free($$05$i21);
   $38 = ($37|0)==(0|0);
   if ($38) {
    break;
   } else {
    $$05$i21 = $37;
   }
  }
 }
 _SDL_free($0);
 return;
}
function _SDL_DestroyMutex($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ($0|0)==(0|0);
 if ($1) {
  return;
 }
 $2 = ((($0)) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
 }
 _SDL_free($0);
 return;
}
function _SDL_DestroySemaphore($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function _SDL_WaitThread($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($0|0)==(0|0);
 if ($2) {
  return;
 }
 $3 = ($1|0)==(0|0);
 if (!($3)) {
  $4 = ((($0)) + 8|0);
  $5 = HEAP32[$4>>2]|0;
  HEAP32[$1>>2] = $5;
 }
 $6 = ((($0)) + 792|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  _SDL_free($7);
 }
 _SDL_free($0);
 return;
}
function _SDL_SYS_WaitThread($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function _SDL_VideoQuit() {
 var $$032 = 0, $$126 = 0, $$in = 0, $$lcssa = 0, $$lcssa22 = 0, $$lcssa25 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[52375]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  return;
 }
 _SDL_TouchQuit();
 _SDL_MouseQuit();
 _SDL_QuitSubSystem(16384);
 $2 = HEAP32[52375]|0;
 $3 = ((($2)) + 260|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 if ($5) {
  $10 = $2;
 } else {
  HEAP32[$3>>2] = 0;
  $6 = ((($2)) + 208|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)==(0|0);
  if ($8) {
   $10 = $2;
  } else {
   FUNCTION_TABLE_vi[$7 & 8191]($2);
   $$pre = HEAP32[52375]|0;
   $10 = $$pre;
  }
 }
 $9 = ((($10)) + 272|0);
 $11 = HEAP32[$9>>2]|0;
 $12 = ($11|0)==(0|0);
 if ($12) {
  $$lcssa25 = $10;
 } else {
  $13 = $11;
  while(1) {
   _SDL_DestroyWindow($13);
   $14 = HEAP32[52375]|0;
   $15 = ((($14)) + 272|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ($16|0)==(0|0);
   if ($17) {
    $$lcssa25 = $14;
    break;
   } else {
    $13 = $16;
   }
  }
 }
 $18 = ((($$lcssa25)) + 8|0);
 $19 = HEAP32[$18>>2]|0;
 FUNCTION_TABLE_vi[$19 & 8191]($$lcssa25);
 $20 = HEAP32[52375]|0;
 $21 = ((($20)) + 264|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)>(0);
 $24 = ((($20)) + 268|0);
 $25 = HEAP32[$24>>2]|0;
 if ($23) {
  $$032 = 0;$27 = $25;
  while(1) {
   $26 = (((($27) + (($$032*68)|0)|0)) + 8|0);
   $28 = HEAP32[$26>>2]|0;
   $29 = ($28|0)==(0);
   $30 = (((($27) + (($$032*68)|0)|0)) + 12|0);
   $31 = HEAP32[$30>>2]|0;
   if ($29) {
    $$lcssa22 = $31;
   } else {
    $$in = $28;$34 = $31;
    while(1) {
     $32 = (($$in) + -1)|0;
     $33 = (((($34) + (($32*20)|0)|0)) + 16|0);
     $35 = HEAP32[$33>>2]|0;
     _SDL_free($35);
     $36 = HEAP32[$30>>2]|0;
     $37 = (((($36) + (($32*20)|0)|0)) + 16|0);
     HEAP32[$37>>2] = 0;
     $38 = ($32|0)==(0);
     if ($38) {
      $$lcssa22 = $36;
      break;
     } else {
      $$in = $32;$34 = $36;
     }
    }
   }
   _SDL_free($$lcssa22);
   HEAP32[$30>>2] = 0;
   $39 = (((($27) + (($$032*68)|0)|0)) + 32|0);
   $40 = HEAP32[$39>>2]|0;
   _SDL_free($40);
   HEAP32[$39>>2] = 0;
   $41 = (((($27) + (($$032*68)|0)|0)) + 64|0);
   $42 = HEAP32[$41>>2]|0;
   _SDL_free($42);
   HEAP32[$41>>2] = 0;
   $43 = (($$032) + 1)|0;
   $44 = HEAP32[52375]|0;
   $45 = ((($44)) + 264|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = ($43|0)<($46|0);
   $48 = ((($44)) + 268|0);
   $49 = HEAP32[$48>>2]|0;
   if ($47) {
    $$032 = $43;$27 = $49;
   } else {
    $50 = $49;$52 = $46;$74 = $44;
    break;
   }
  }
 } else {
  $50 = $25;$52 = $22;$74 = $20;
 }
 $51 = ($50|0)==(0|0);
 if ($51) {
  $68 = $74;
 } else {
  $53 = ($52|0)>(0);
  if ($53) {
   $$126 = 0;$55 = $50;
   while(1) {
    $54 = (($55) + (($$126*68)|0)|0);
    $56 = HEAP32[$54>>2]|0;
    _SDL_free($56);
    $57 = (($$126) + 1)|0;
    $58 = HEAP32[52375]|0;
    $59 = ((($58)) + 264|0);
    $60 = HEAP32[$59>>2]|0;
    $61 = ($57|0)<($60|0);
    $62 = ((($58)) + 268|0);
    $63 = HEAP32[$62>>2]|0;
    if ($61) {
     $$126 = $57;$55 = $63;
    } else {
     $$lcssa = $63;
     break;
    }
   }
  } else {
   $$lcssa = $50;
  }
  _SDL_free($$lcssa);
  $64 = HEAP32[52375]|0;
  $65 = ((($64)) + 268|0);
  HEAP32[$65>>2] = 0;
  $66 = ((($64)) + 264|0);
  HEAP32[$66>>2] = 0;
  $68 = $64;
 }
 $67 = ((($68)) + 288|0);
 $69 = HEAP32[$67>>2]|0;
 _SDL_free($69);
 $70 = HEAP32[52375]|0;
 $71 = ((($70)) + 288|0);
 HEAP32[$71>>2] = 0;
 $72 = ((($70)) + 684|0);
 $73 = HEAP32[$72>>2]|0;
 FUNCTION_TABLE_vi[$73 & 8191]($70);
 HEAP32[52375] = 0;
 return;
}
function _SDL_KeyboardInit() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 (_SDL_memcpy((211212),89760,2048)|0);
 return 0;
}
function _SDL_MouseInit() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[(209628)>>2] = 1;
 return 0;
}
function _SDL_TouchInit() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function _SDL_TLSCreate() {
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_SDL_AtomicAdd(213500,1)|0);
 $1 = (($0) + 1)|0;
 return ($1|0);
}
function _SDL_CreateWindowTexture($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0$i = 0, $$0106148 = 0, $$0145 = 0, $$015$i = 0, $$016$i = 0, $$1107146 = 0, $$1113$in = 0, $$3105 = 0, $$6134 = 0, $$mask = 0, $$mask116 = 0, $$not = 0, $$off125 = 0, $$off127 = 0, $$phi$trans$insert = 0, $$pre = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $or$cond124 = 0;
 var $phitmp = 0, $switch = 0, $switch$split2D = 0, $switch126 = 0, $switch128 = 0, $trunc = 0, $trunc$clear = 0, $trunc139 = 0, $trunc139$clear = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 272|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(272|0);
 $vararg_buffer3 = sp + 16|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $5 = sp + 188|0;
 $6 = sp + 104|0;
 $7 = sp + 20|0;
 $8 = HEAP32[52375]|0;
 $9 = ($8|0)==(0|0);
 L1: do {
  if ($9) {
   (_SDL_SetError(175439,$vararg_buffer)|0);
   label = 11;
  } else {
   $10 = ($1|0)==(0|0);
   if (!($10)) {
    $11 = HEAP32[$1>>2]|0;
    $12 = ((($8)) + 280|0);
    $13 = ($11|0)==($12|0);
    if ($13) {
     $14 = ((($1)) + 140|0);
     $$015$i = HEAP32[$14>>2]|0;
     $15 = ($$015$i|0)==(0|0);
     if ($15) {
      label = 11;
      break;
     } else {
      $$016$i = $$015$i;
     }
     while(1) {
      $16 = HEAP32[$$016$i>>2]|0;
      $17 = ($16|0)==(0|0);
      if (!($17)) {
       $18 = (_SDL_strcmp($16,194579)|0);
       $19 = ($18|0)==(0);
       if ($19) {
        break;
       }
      }
      $20 = ((($$016$i)) + 8|0);
      $$0$i = HEAP32[$20>>2]|0;
      $21 = ($$0$i|0)==(0|0);
      if ($21) {
       label = 11;
       break L1;
      } else {
       $$016$i = $$0$i;
      }
     }
     $22 = ((($$016$i)) + 4|0);
     $23 = HEAP32[$22>>2]|0;
     $24 = ($23|0)==(0|0);
     if ($24) {
      label = 11;
      break;
     } else {
      $$1113$in = $23;
      break;
     }
    }
   }
   (_SDL_SetError(195204,$vararg_buffer1)|0);
   label = 11;
  }
 } while(0);
 do {
  if ((label|0) == 11) {
   $25 = (_SDL_GetHint(194522)|0);
   $26 = ($25|0)==(0|0);
   L16: do {
    if ($26) {
     label = 21;
    } else {
     $27 = HEAP8[$25>>0]|0;
     $28 = $27 & -2;
     $switch = ($28<<24>>24)==(48);
     if ($switch) {
      label = 21;
     } else {
      $29 = (_SDL_strcasecmp($25,204748)|0);
      $30 = ($29|0)==(0);
      if ($30) {
       label = 21;
      } else {
       $31 = (_SDL_strcasecmp($25,204742)|0);
       $32 = ($31|0)==(0);
       if ($32) {
        label = 21;
       } else {
        $33 = (_SDL_strcasecmp($25,194513)|0);
        $34 = ($33|0)==(0);
        if ($34) {
         label = 21;
        } else {
         $35 = (_SDL_GetNumRenderDrivers()|0);
         $36 = ($35|0)>(0);
         if ($36) {
          $$0106148 = 0;
          while(1) {
           (_SDL_GetRenderDriverInfo($$0106148,$5)|0);
           $37 = HEAP32[$5>>2]|0;
           $38 = (_SDL_strcasecmp($37,$25)|0);
           $39 = ($38|0)==(0);
           if ($39) {
            break;
           }
           $40 = (($$0106148) + 1)|0;
           $41 = (_SDL_GetNumRenderDrivers()|0);
           $42 = ($40|0)<($41|0);
           if ($42) {
            $$0106148 = $40;
           } else {
            label = 21;
            break L16;
           }
          }
          $43 = (_SDL_CreateRenderer($1,$$0106148,0)|0);
          $44 = ($43|0)==(0|0);
          if ($44) {
           label = 21;
          } else {
           $$6134 = $43;
          }
         } else {
          label = 21;
         }
        }
       }
      }
     }
    }
   } while(0);
   L27: do {
    if ((label|0) == 21) {
     $45 = (_SDL_GetNumRenderDrivers()|0);
     $46 = ($45|0)>(0);
     L29: do {
      if ($46) {
       $$1107146 = 0;
       while(1) {
        (_SDL_GetRenderDriverInfo($$1107146,$6)|0);
        $47 = HEAP32[$6>>2]|0;
        $48 = (_SDL_strcmp($47,194513)|0);
        $49 = ($48|0)==(0);
        if (!($49)) {
         $50 = (_SDL_CreateRenderer($1,$$1107146,0)|0);
         $51 = ($50|0)==(0|0);
         if (!($51)) {
          break;
         }
        }
        $52 = (($$1107146) + 1)|0;
        $53 = (_SDL_GetNumRenderDrivers()|0);
        $54 = ($52|0)<($53|0);
        if ($54) {
         $$1107146 = $52;
        } else {
         break L29;
        }
       }
       $$6134 = $50;
       break L27;
      }
     } while(0);
     $55 = (_SDL_SetError(195006,$vararg_buffer3)|0);
     $$3105 = $55;
     STACKTOP = sp;return ($$3105|0);
    }
   } while(0);
   $56 = (_SDL_calloc(1,20)|0);
   $57 = ($56|0)==(0|0);
   if (!($57)) {
    (_SDL_SetWindowData($1,194579,$56)|0);
    HEAP32[$56>>2] = $$6134;
    $$1113$in = $56;
    break;
   }
   _SDL_DestroyRenderer($$6134);
   $58 = (_SDL_Error(0)|0);
   $$3105 = $58;
   STACKTOP = sp;return ($$3105|0);
  }
 } while(0);
 $59 = ((($$1113$in)) + 4|0);
 $60 = HEAP32[$59>>2]|0;
 $61 = ($60|0)==(0|0);
 if (!($61)) {
  _SDL_DestroyTexture($60);
  HEAP32[$59>>2] = 0;
 }
 $62 = ((($$1113$in)) + 8|0);
 $63 = HEAP32[$62>>2]|0;
 _SDL_free($63);
 HEAP32[$62>>2] = 0;
 $64 = HEAP32[$$1113$in>>2]|0;
 $65 = (_SDL_GetRendererInfo($64,$7)|0);
 $66 = ($65|0)<(0);
 if ($66) {
  $$3105 = -1;
  STACKTOP = sp;return ($$3105|0);
 }
 $67 = ((($7)) + 12|0);
 $68 = HEAP32[$67>>2]|0;
 HEAP32[$2>>2] = $68;
 $69 = ((($7)) + 8|0);
 $70 = HEAP32[$69>>2]|0;
 $71 = ($70|0)==(0);
 L52: do {
  if ($71) {
   $85 = $68;
  } else {
   $$0145 = 0;$72 = $68;
   L53: while(1) {
    $$not = ($72|0)==(0);
    $$mask116 = $72 & -268435456;
    $73 = ($$mask116|0)==(268435456);
    $or$cond = $$not | $73;
    L55: do {
     if ($or$cond) {
      $74 = $72 >>> 24;
      $75 = $74 & 15;
      $$off125 = (($75) + -4)|0;
      $switch126 = ($$off125>>>0)<(3);
      if ($switch126) {
       $76 = $72 >>> 20;
       $trunc139 = $76&255;
       $trunc139$clear = $trunc139 & 15;
       switch ($trunc139$clear<<24>>24) {
       case 8: case 7: case 4: case 3:  {
        break L55;
        break;
       }
       default: {
       }
       }
      }
      $$off127 = (($75) + -7)|0;
      $switch128 = ($$off127>>>0)<(5);
      if (!($switch128)) {
       break L53;
      }
      $77 = $72 >>> 20;
      $trunc = $77&255;
      $trunc$clear = $trunc & 15;
      switch ($trunc$clear<<24>>24) {
      case 5: case 6: case 2: case 3:  {
       break;
      }
      default: {
       break L53;
      }
      }
     }
    } while(0);
    $78 = (($$0145) + 1)|0;
    $79 = ($78>>>0)<($70>>>0);
    if (!($79)) {
     $85 = $68;
     break L52;
    }
    $$phi$trans$insert = (((($7)) + 12|0) + ($78<<2)|0);
    $$pre = HEAP32[$$phi$trans$insert>>2]|0;
    $$0145 = $78;$72 = $$pre;
   }
   HEAP32[$2>>2] = $72;
   $85 = $72;
  }
 } while(0);
 $80 = HEAP32[$$1113$in>>2]|0;
 $81 = ((($1)) + 24|0);
 $82 = HEAP32[$81>>2]|0;
 $83 = ((($1)) + 28|0);
 $84 = HEAP32[$83>>2]|0;
 $86 = (_SDL_CreateTexture($80,$85,1,$82,$84)|0);
 HEAP32[$59>>2] = $86;
 $87 = ($86|0)==(0|0);
 if ($87) {
  $$3105 = -1;
  STACKTOP = sp;return ($$3105|0);
 }
 $88 = HEAP32[$2>>2]|0;
 $89 = ($88|0)==(0);
 $$mask = $88 & -268435456;
 $90 = ($$mask|0)==(268435456);
 $or$cond124 = $89 | $90;
 L68: do {
  if ($or$cond124) {
   $92 = $88 & 255;
   $94 = $92;
  } else {
   $switch$split2D = ($88|0)<(1498831189);
   if ($switch$split2D) {
    switch ($88|0) {
    case 844715353:  {
     $94 = 2;
     break L68;
     break;
    }
    default: {
    }
    }
   } else {
    switch ($88|0) {
    case 1498831189:  {
     $94 = 2;
     break L68;
     break;
    }
    default: {
    }
    }
   }
   $91 = ($88|0)==(1431918169);
   $phitmp = $91 ? 2 : 1;
   $94 = $phitmp;
  }
 } while(0);
 $93 = ((($$1113$in)) + 16|0);
 HEAP32[$93>>2] = $94;
 $95 = HEAP32[$81>>2]|0;
 $96 = Math_imul($95, $94)|0;
 $97 = (($96) + 3)|0;
 $98 = $97 & -4;
 $99 = ((($$1113$in)) + 12|0);
 HEAP32[$99>>2] = $98;
 $100 = HEAP32[$83>>2]|0;
 $101 = Math_imul($98, $100)|0;
 $102 = (_SDL_malloc($101)|0);
 HEAP32[$62>>2] = $102;
 $103 = ($102|0)==(0|0);
 if ($103) {
  $104 = (_SDL_Error(0)|0);
  $$3105 = $104;
  STACKTOP = sp;return ($$3105|0);
 } else {
  HEAP32[$3>>2] = $102;
  $105 = HEAP32[$99>>2]|0;
  HEAP32[$4>>2] = $105;
  $106 = HEAP32[$$1113$in>>2]|0;
  (_SDL_RenderSetViewport($106,0)|0);
  $$3105 = 0;
  STACKTOP = sp;return ($$3105|0);
 }
 return (0)|0;
}
function _SDL_UpdateWindowTexture($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $$0$i = 0, $$015$i = 0, $$016$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $vararg_buffer3 = sp + 16|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $4 = sp + 24|0;
 $5 = HEAP32[52375]|0;
 $6 = ($5|0)==(0|0);
 L1: do {
  if ($6) {
   (_SDL_SetError(175439,$vararg_buffer)|0);
  } else {
   $7 = ($1|0)==(0|0);
   if (!($7)) {
    $8 = HEAP32[$1>>2]|0;
    $9 = ((($5)) + 280|0);
    $10 = ($8|0)==($9|0);
    if ($10) {
     $11 = ((($1)) + 140|0);
     $$015$i = HEAP32[$11>>2]|0;
     $12 = ($$015$i|0)==(0|0);
     if ($12) {
      break;
     } else {
      $$016$i = $$015$i;
     }
     while(1) {
      $13 = HEAP32[$$016$i>>2]|0;
      $14 = ($13|0)==(0|0);
      if (!($14)) {
       $15 = (_SDL_strcmp($13,194579)|0);
       $16 = ($15|0)==(0);
       if ($16) {
        break;
       }
      }
      $17 = ((($$016$i)) + 8|0);
      $$0$i = HEAP32[$17>>2]|0;
      $18 = ($$0$i|0)==(0|0);
      if ($18) {
       break L1;
      } else {
       $$016$i = $$0$i;
      }
     }
     $19 = ((($$016$i)) + 4|0);
     $20 = HEAP32[$19>>2]|0;
     $21 = ($20|0)==(0|0);
     if ($21) {
      break;
     }
     $22 = ((($20)) + 4|0);
     $23 = HEAP32[$22>>2]|0;
     $24 = ($23|0)==(0|0);
     if ($24) {
      break;
     }
     $26 = ((($1)) + 24|0);
     $27 = HEAP32[$26>>2]|0;
     $28 = ((($1)) + 28|0);
     $29 = HEAP32[$28>>2]|0;
     $30 = (_SDL_GetSpanEnclosingRect($27,$29,$3,$2,$4)|0);
     $31 = ($30|0)==(0);
     if ($31) {
      $$0 = 0;
      STACKTOP = sp;return ($$0|0);
     }
     $32 = ((($20)) + 8|0);
     $33 = HEAP32[$32>>2]|0;
     $34 = ((($4)) + 4|0);
     $35 = HEAP32[$34>>2]|0;
     $36 = ((($20)) + 12|0);
     $37 = HEAP32[$36>>2]|0;
     $38 = Math_imul($37, $35)|0;
     $39 = (($33) + ($38)|0);
     $40 = HEAP32[$4>>2]|0;
     $41 = ((($20)) + 16|0);
     $42 = HEAP32[$41>>2]|0;
     $43 = Math_imul($42, $40)|0;
     $44 = (($39) + ($43)|0);
     $45 = HEAP32[$22>>2]|0;
     $46 = (_SDL_UpdateTexture($45,$4,$44,$37)|0);
     $47 = ($46|0)<(0);
     if ($47) {
      $$0 = -1;
      STACKTOP = sp;return ($$0|0);
     }
     $48 = HEAP32[$20>>2]|0;
     $49 = HEAP32[$22>>2]|0;
     $50 = (_SDL_RenderCopy($48,$49,0,0)|0);
     $51 = ($50|0)<(0);
     if ($51) {
      $$0 = -1;
      STACKTOP = sp;return ($$0|0);
     }
     $52 = HEAP32[$20>>2]|0;
     _SDL_RenderPresent($52);
     $$0 = 0;
     STACKTOP = sp;return ($$0|0);
    }
   }
   (_SDL_SetError(195204,$vararg_buffer1)|0);
  }
 } while(0);
 $25 = (_SDL_SetError(194717,$vararg_buffer3)|0);
 $$0 = $25;
 STACKTOP = sp;return ($$0|0);
}
function _SDL_DestroyWindowTexture($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_SDL_SetWindowData($1,194579,0)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  return;
 }
 $4 = ((($2)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  _SDL_DestroyTexture($5);
 }
 $7 = HEAP32[$2>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  _SDL_DestroyRenderer($7);
 }
 $9 = ((($2)) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 _SDL_free($10);
 _SDL_free($2);
 return;
}
function _SDL_DestroyTexture($0) {
 $0 = $0|0;
 var $$pre = 0, $$sink = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = HEAP32[$0>>2]|0;
  $3 = ($2|0)==(217377|0);
  if ($3) {
   $4 = ((($0)) + 32|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = ((($5)) + 308|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($7|0)==($0|0);
   if ($8) {
    (_SDL_SetRenderTarget($5,0)|0);
   }
   HEAP32[$0>>2] = 0;
   $9 = ((($0)) + 76|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($10|0)==(0|0);
   $$pre = ((($0)) + 72|0);
   if (!($11)) {
    $12 = HEAP32[$$pre>>2]|0;
    $13 = ((($10)) + 72|0);
    HEAP32[$13>>2] = $12;
   }
   $14 = HEAP32[$$pre>>2]|0;
   $15 = ($14|0)==(0|0);
   $16 = ((($5)) + 304|0);
   $17 = ((($14)) + 76|0);
   $$sink = $15 ? $16 : $17;
   HEAP32[$$sink>>2] = $10;
   $18 = ((($0)) + 36|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ($19|0)==(0|0);
   if (!($20)) {
    _SDL_DestroyTexture($19);
   }
   $21 = ((($0)) + 40|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = ($22|0)==(0|0);
   if (!($23)) {
    _SDL_SW_DestroyYUVTexture($22);
   }
   $24 = ((($0)) + 44|0);
   $25 = HEAP32[$24>>2]|0;
   _SDL_free($25);
   $26 = ((($5)) + 88|0);
   $27 = HEAP32[$26>>2]|0;
   FUNCTION_TABLE_vii[$27 & 8191]($5,$0);
   _SDL_free($0);
   STACKTOP = sp;return;
  }
 }
 (_SDL_SetError(176589,$vararg_buffer)|0);
 STACKTOP = sp;return;
}
function _SDL_DestroyRenderer($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = HEAP32[$0>>2]|0;
  $3 = ($2|0)==(217376|0);
  if ($3) {
   _SDL_DelEventWatch(4477,$0);
   $4 = ((($0)) + 304|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = ($5|0)==(0|0);
   if (!($6)) {
    $7 = $5;
    while(1) {
     _SDL_DestroyTexture($7);
     $8 = HEAP32[$4>>2]|0;
     $9 = ($8|0)==(0|0);
     if ($9) {
      break;
     } else {
      $7 = $8;
     }
    }
   }
   $10 = ((($0)) + 188|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = ($11|0)==(0|0);
   if (!($12)) {
    (_SDL_SetWindowData($11,194602,0)|0);
   }
   HEAP32[$0>>2] = 0;
   $13 = ((($0)) + 92|0);
   $14 = HEAP32[$13>>2]|0;
   FUNCTION_TABLE_vi[$14 & 8191]($0);
   STACKTOP = sp;return;
  }
 }
 (_SDL_SetError(176572,$vararg_buffer)|0);
 STACKTOP = sp;return;
}
function _SDL_RendererEventWatch($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$ = 0, $$107 = 0, $$108 = 0, $$109 = 0, $$sink = 0, $10 = 0, $100 = 0.0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0.0, $123 = 0, $124 = 0.0, $125 = 0.0, $126 = 0, $127 = 0.0, $128 = 0, $129 = 0.0, $13 = 0, $130 = 0.0;
 var $131 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0.0, $7 = 0, $70 = 0, $71 = 0.0, $72 = 0.0, $73 = 0, $74 = 0.0, $75 = 0, $76 = 0.0, $77 = 0.0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0.0, $83 = 0.0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0.0, $88 = 0.0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0.0, $95 = 0.0, $96 = 0, $97 = 0, $98 = 0, $99 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp + 4|0;
 $3 = sp;
 $4 = HEAP32[$1>>2]|0;
 switch ($4|0) {
 case 512:  {
  $5 = ((($1)) + 8|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (_SDL_GetWindowFromID($6)|0);
  $8 = ((($0)) + 188|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($7|0)==($9|0);
  if (!($10)) {
   STACKTOP = sp;return 0;
  }
  $11 = ((($0)) + 4|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($12|0)==(0|0);
  if (!($13)) {
   FUNCTION_TABLE_vii[$12 & 8191]($0,$1);
  }
  $14 = ((($1)) + 12|0);
  $15 = HEAP8[$14>>0]|0;
  switch ($15<<24>>24) {
  case 6:  {
   $16 = ((($0)) + 308|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = ($17|0)!=(0|0);
   if ($18) {
    (_SDL_SetRenderTarget($0,0)|0);
   }
   $19 = ((($0)) + 196|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = ($20|0)==(0);
   if ($21) {
    $22 = ((($0)) + 8|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = ($23|0)==(0|0);
    if ($24) {
     $25 = HEAP32[$8>>2]|0;
     _SDL_GetWindowSize($25,$2,$3);
    } else {
     (FUNCTION_TABLE_iiii[$23 & 8191]($0,$2,$3)|0);
    }
    $26 = HEAP32[$16>>2]|0;
    $27 = ($26|0)==(0|0);
    $28 = HEAP32[$2>>2]|0;
    $29 = HEAP32[$3>>2]|0;
    if ($27) {
     $34 = ((($0)) + 216|0);
     HEAP32[$34>>2] = 0;
     $35 = ((($0)) + 220|0);
     HEAP32[$35>>2] = 0;
     $36 = ((($0)) + 224|0);
     HEAP32[$36>>2] = $28;
     $37 = ((($0)) + 228|0);
     HEAP32[$37>>2] = $29;
     $38 = ((($0)) + 48|0);
     $39 = HEAP32[$38>>2]|0;
     (FUNCTION_TABLE_ii[$39 & 8191]($0)|0);
    } else {
     $30 = ((($0)) + 232|0);
     HEAP32[$30>>2] = 0;
     $31 = ((($0)) + 236|0);
     HEAP32[$31>>2] = 0;
     $32 = ((($0)) + 240|0);
     HEAP32[$32>>2] = $28;
     $33 = ((($0)) + 244|0);
     HEAP32[$33>>2] = $29;
    }
   } else {
    (_UpdateLogicalSize($0)|0);
   }
   if (!($18)) {
    STACKTOP = sp;return 0;
   }
   (_SDL_SetRenderTarget($0,$17)|0);
   STACKTOP = sp;return 0;
   break;
  }
  case 2:  {
   $40 = ((($0)) + 192|0);
   HEAP32[$40>>2] = 1;
   STACKTOP = sp;return 0;
   break;
  }
  case 1:  {
   $41 = (_SDL_GetWindowFlags($7)|0);
   $42 = $41 & 64;
   $43 = ($42|0)==(0);
   if (!($43)) {
    STACKTOP = sp;return 0;
   }
   $44 = ((($0)) + 192|0);
   HEAP32[$44>>2] = 0;
   STACKTOP = sp;return 0;
   break;
  }
  case 7:  {
   $45 = ((($0)) + 192|0);
   HEAP32[$45>>2] = 1;
   STACKTOP = sp;return 0;
   break;
  }
  case 8: case 9:  {
   $46 = (_SDL_GetWindowFlags($7)|0);
   $47 = $46 & 8;
   $48 = ($47|0)==(0);
   if (!($48)) {
    STACKTOP = sp;return 0;
   }
   $49 = ((($0)) + 192|0);
   HEAP32[$49>>2] = 0;
   STACKTOP = sp;return 0;
   break;
  }
  default: {
   STACKTOP = sp;return 0;
  }
  }
  break;
 }
 case 1024:  {
  $50 = ((($1)) + 8|0);
  $51 = HEAP32[$50>>2]|0;
  $52 = (_SDL_GetWindowFromID($51)|0);
  $53 = ((($0)) + 196|0);
  $54 = HEAP32[$53>>2]|0;
  $55 = ($54|0)==(0);
  if ($55) {
   STACKTOP = sp;return 0;
  }
  $56 = ((($0)) + 188|0);
  $57 = HEAP32[$56>>2]|0;
  $58 = ($52|0)==($57|0);
  if (!($58)) {
   STACKTOP = sp;return 0;
  }
  $59 = ((($0)) + 216|0);
  $60 = HEAP32[$59>>2]|0;
  $61 = ((($1)) + 20|0);
  $62 = HEAP32[$61>>2]|0;
  $63 = (($62) - ($60))|0;
  $64 = ((($0)) + 220|0);
  $65 = HEAP32[$64>>2]|0;
  $66 = ((($1)) + 24|0);
  $67 = HEAP32[$66>>2]|0;
  $68 = (($67) - ($65))|0;
  $69 = (+($63|0));
  $70 = ((($0)) + 288|0);
  $71 = +HEAPF32[$70>>2];
  $72 = $69 / $71;
  $73 = (~~(($72)));
  HEAP32[$61>>2] = $73;
  $74 = (+($68|0));
  $75 = ((($0)) + 292|0);
  $76 = +HEAPF32[$75>>2];
  $77 = $74 / $76;
  $78 = (~~(($77)));
  HEAP32[$66>>2] = $78;
  $79 = ((($1)) + 28|0);
  $80 = HEAP32[$79>>2]|0;
  $81 = ($80|0)>(0);
  if ($81) {
   $82 = (+($80|0));
   $83 = $82 / $71;
   $84 = (~~(($83)));
   $85 = ($84|0)>(1);
   $$ = $85 ? $84 : 1;
   $$sink = $$;
   label = 31;
  } else {
   $86 = ($80|0)<(0);
   if ($86) {
    $87 = (+($80|0));
    $88 = $87 / $71;
    $89 = (~~(($88)));
    $90 = ($89|0)<(-1);
    $$107 = $90 ? $89 : -1;
    $$sink = $$107;
    label = 31;
   }
  }
  if ((label|0) == 31) {
   HEAP32[$79>>2] = $$sink;
  }
  $91 = ((($1)) + 32|0);
  $92 = HEAP32[$91>>2]|0;
  $93 = ($92|0)>(0);
  if ($93) {
   $94 = (+($92|0));
   $95 = $94 / $76;
   $96 = (~~(($95)));
   $97 = ($96|0)>(1);
   $$108 = $97 ? $96 : 1;
   HEAP32[$91>>2] = $$108;
   STACKTOP = sp;return 0;
  }
  $98 = ($92|0)<(0);
  if (!($98)) {
   STACKTOP = sp;return 0;
  }
  $99 = (+($92|0));
  $100 = $99 / $76;
  $101 = (~~(($100)));
  $102 = ($101|0)<(-1);
  $$109 = $102 ? $101 : -1;
  HEAP32[$91>>2] = $$109;
  STACKTOP = sp;return 0;
  break;
 }
 case 1026: case 1025:  {
  $103 = ((($1)) + 8|0);
  $104 = HEAP32[$103>>2]|0;
  $105 = (_SDL_GetWindowFromID($104)|0);
  $106 = ((($0)) + 196|0);
  $107 = HEAP32[$106>>2]|0;
  $108 = ($107|0)==(0);
  if ($108) {
   STACKTOP = sp;return 0;
  }
  $109 = ((($0)) + 188|0);
  $110 = HEAP32[$109>>2]|0;
  $111 = ($105|0)==($110|0);
  if (!($111)) {
   STACKTOP = sp;return 0;
  }
  $112 = ((($0)) + 216|0);
  $113 = HEAP32[$112>>2]|0;
  $114 = ((($1)) + 20|0);
  $115 = HEAP32[$114>>2]|0;
  $116 = (($115) - ($113))|0;
  $117 = ((($0)) + 220|0);
  $118 = HEAP32[$117>>2]|0;
  $119 = ((($1)) + 24|0);
  $120 = HEAP32[$119>>2]|0;
  $121 = (($120) - ($118))|0;
  $122 = (+($116|0));
  $123 = ((($0)) + 288|0);
  $124 = +HEAPF32[$123>>2];
  $125 = $122 / $124;
  $126 = (~~(($125)));
  HEAP32[$114>>2] = $126;
  $127 = (+($121|0));
  $128 = ((($0)) + 292|0);
  $129 = +HEAPF32[$128>>2];
  $130 = $127 / $129;
  $131 = (~~(($130)));
  HEAP32[$119>>2] = $131;
  STACKTOP = sp;return 0;
  break;
 }
 default: {
  STACKTOP = sp;return 0;
 }
 }
 return (0)|0;
}
function _SDL_DelEventWatch($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$01417 = 0, $$01417$phi = 0, $$018 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $SDL_event_watchers$sink = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[52666]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  return;
 } else {
  $$01417 = 0;$$018 = $2;
 }
 while(1) {
  $4 = HEAP32[$$018>>2]|0;
  $5 = ($4|0)==($0|0);
  $6 = ((($$018)) + 8|0);
  $7 = HEAP32[$6>>2]|0;
  if ($5) {
   $9 = ((($$018)) + 4|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($10|0)==($1|0);
   if ($11) {
    break;
   }
  }
  $8 = ($7|0)==(0|0);
  if ($8) {
   label = 6;
   break;
  } else {
   $$01417$phi = $$018;$$018 = $7;$$01417 = $$01417$phi;
  }
 }
 if ((label|0) == 6) {
  return;
 }
 $12 = ($$01417|0)!=(0|0);
 $13 = ((($$01417)) + 8|0);
 $SDL_event_watchers$sink = $12 ? $13 : 210664;
 HEAP32[$SDL_event_watchers$sink>>2] = $7;
 _SDL_free($$018);
 return;
}
function _SDL_GetWindowFromID($0) {
 $0 = $0|0;
 var $$0 = 0, $$05 = 0, $$06 = 0, $$07 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[52375]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$05 = 0;
  return ($$05|0);
 }
 $3 = ((($1)) + 272|0);
 $$06 = HEAP32[$3>>2]|0;
 $4 = ($$06|0)==(0|0);
 if ($4) {
  $$05 = 0;
  return ($$05|0);
 } else {
  $$07 = $$06;
 }
 while(1) {
  $5 = ((($$07)) + 4|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==($0|0);
  if ($7) {
   $$05 = $$07;
   label = 5;
   break;
  }
  $8 = ((($$07)) + 152|0);
  $$0 = HEAP32[$8>>2]|0;
  $9 = ($$0|0)==(0|0);
  if ($9) {
   $$05 = 0;
   label = 5;
   break;
  } else {
   $$07 = $$0;
  }
 }
 if ((label|0) == 5) {
  return ($$05|0);
 }
 return (0)|0;
}
function _SDL_SetRenderTarget($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$ = 0, $$062 = 0, $$064 = 0, $$lobit = 0, $$lobit$i = 0, $$sink = 0, $$sink$in = 0, $$sink66 = 0, $$sink66$in = 0, $$sink67 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $vararg_buffer3 = sp + 16|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $2 = ($0|0)==(0|0);
 if (!($2)) {
  $3 = ((($0)) + 44|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==(0|0);
  if (!($5)) {
   $6 = ((($0)) + 108|0);
   $7 = HEAP32[$6>>2]|0;
   $$lobit$i = $7 & 8;
   $8 = ($$lobit$i|0)==(0);
   if (!($8)) {
    $10 = ((($0)) + 308|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)==($1|0);
    if ($12) {
     $$062 = 0;
     STACKTOP = sp;return ($$062|0);
    }
    $13 = ($1|0)==(0|0);
    do {
     if ($13) {
      $$064 = 0;$96 = 0;
     } else {
      $14 = HEAP32[$1>>2]|0;
      $15 = ($14|0)==(217377|0);
      if (!($15)) {
       (_SDL_SetError(176589,$vararg_buffer)|0);
       $$062 = -1;
       STACKTOP = sp;return ($$062|0);
      }
      $16 = ((($1)) + 32|0);
      $17 = HEAP32[$16>>2]|0;
      $18 = ($17|0)==($0|0);
      if (!($18)) {
       $19 = (_SDL_SetError(194624,$vararg_buffer1)|0);
       $$062 = $19;
       STACKTOP = sp;return ($$062|0);
      }
      $20 = ((($1)) + 8|0);
      $21 = HEAP32[$20>>2]|0;
      $22 = ($21|0)==(2);
      if ($22) {
       $24 = ((($1)) + 36|0);
       $25 = HEAP32[$24>>2]|0;
       $26 = ($25|0)==(0|0);
       $$ = $26 ? $1 : $25;
       $27 = ($$|0)!=(0|0);
       $28 = ($11|0)==(0|0);
       if (!($28)) {
        $$064 = $$;$96 = $27;
        break;
       }
       $29 = ((($0)) + 232|0);
       $30 = ((($0)) + 216|0);
       ;HEAP32[$29>>2]=HEAP32[$30>>2]|0;HEAP32[$29+4>>2]=HEAP32[$30+4>>2]|0;HEAP32[$29+8>>2]=HEAP32[$30+8>>2]|0;HEAP32[$29+12>>2]=HEAP32[$30+12>>2]|0;
       $31 = ((($0)) + 264|0);
       $32 = ((($0)) + 248|0);
       ;HEAP32[$31>>2]=HEAP32[$32>>2]|0;HEAP32[$31+4>>2]=HEAP32[$32+4>>2]|0;HEAP32[$31+8>>2]=HEAP32[$32+8>>2]|0;HEAP32[$31+12>>2]=HEAP32[$32+12>>2]|0;
       $33 = ((($0)) + 280|0);
       $34 = HEAP32[$33>>2]|0;
       $35 = ((($0)) + 284|0);
       HEAP32[$35>>2] = $34;
       $36 = ((($0)) + 296|0);
       $37 = ((($0)) + 288|0);
       $38 = $37;
       $39 = $38;
       $40 = HEAP32[$39>>2]|0;
       $41 = (($38) + 4)|0;
       $42 = $41;
       $43 = HEAP32[$42>>2]|0;
       $44 = $36;
       $45 = $44;
       HEAP32[$45>>2] = $40;
       $46 = (($44) + 4)|0;
       $47 = $46;
       HEAP32[$47>>2] = $43;
       $48 = ((($0)) + 196|0);
       $49 = HEAP32[$48>>2]|0;
       $50 = ((($0)) + 204|0);
       HEAP32[$50>>2] = $49;
       $51 = ((($0)) + 200|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = ((($0)) + 208|0);
       HEAP32[$53>>2] = $52;
       $$064 = $$;$96 = $27;
       break;
      } else {
       $23 = (_SDL_SetError(194667,$vararg_buffer3)|0);
       $$062 = $23;
       STACKTOP = sp;return ($$062|0);
      }
     }
    } while(0);
    HEAP32[$10>>2] = $$064;
    $54 = (FUNCTION_TABLE_iii[$4 & 8191]($0,$$064)|0);
    $55 = ($54|0)<(0);
    if ($55) {
     $$062 = -1;
     STACKTOP = sp;return ($$062|0);
    }
    $56 = ((($0)) + 216|0);
    if ($96) {
     HEAP32[$56>>2] = 0;
     $57 = ((($0)) + 220|0);
     HEAP32[$57>>2] = 0;
     $58 = ((($$064)) + 12|0);
     $59 = HEAP32[$58>>2]|0;
     $60 = ((($0)) + 224|0);
     HEAP32[$60>>2] = $59;
     $61 = ((($$064)) + 16|0);
     $62 = HEAP32[$61>>2]|0;
     $63 = ((($0)) + 228|0);
     HEAP32[$63>>2] = $62;
     $64 = ((($0)) + 248|0);
     (_SDL_memset($64,0,16)|0);
     $65 = ((($0)) + 288|0);
     HEAPF32[$65>>2] = 1.0;
     $66 = ((($0)) + 292|0);
     HEAPF32[$66>>2] = 1.0;
     $$sink$in = $61;$$sink66$in = $58;$$sink67 = 0;
    } else {
     $67 = ((($0)) + 232|0);
     ;HEAP32[$56>>2]=HEAP32[$67>>2]|0;HEAP32[$56+4>>2]=HEAP32[$67+4>>2]|0;HEAP32[$56+8>>2]=HEAP32[$67+8>>2]|0;HEAP32[$56+12>>2]=HEAP32[$67+12>>2]|0;
     $68 = ((($0)) + 248|0);
     $69 = ((($0)) + 264|0);
     ;HEAP32[$68>>2]=HEAP32[$69>>2]|0;HEAP32[$68+4>>2]=HEAP32[$69+4>>2]|0;HEAP32[$68+8>>2]=HEAP32[$69+8>>2]|0;HEAP32[$68+12>>2]=HEAP32[$69+12>>2]|0;
     $70 = ((($0)) + 284|0);
     $71 = HEAP32[$70>>2]|0;
     $72 = ((($0)) + 288|0);
     $73 = ((($0)) + 296|0);
     $74 = $73;
     $75 = $74;
     $76 = HEAP32[$75>>2]|0;
     $77 = (($74) + 4)|0;
     $78 = $77;
     $79 = HEAP32[$78>>2]|0;
     $80 = $72;
     $81 = $80;
     HEAP32[$81>>2] = $76;
     $82 = (($80) + 4)|0;
     $83 = $82;
     HEAP32[$83>>2] = $79;
     $84 = ((($0)) + 204|0);
     $85 = ((($0)) + 208|0);
     $$sink$in = $85;$$sink66$in = $84;$$sink67 = $71;
    }
    $$sink66 = HEAP32[$$sink66$in>>2]|0;
    $86 = ((($0)) + 280|0);
    HEAP32[$86>>2] = $$sink67;
    $87 = ((($0)) + 196|0);
    HEAP32[$87>>2] = $$sink66;
    $$sink = HEAP32[$$sink$in>>2]|0;
    $88 = ((($0)) + 200|0);
    HEAP32[$88>>2] = $$sink;
    $89 = ((($0)) + 48|0);
    $90 = HEAP32[$89>>2]|0;
    $91 = (FUNCTION_TABLE_ii[$90 & 8191]($0)|0);
    $92 = ($91|0)<(0);
    if ($92) {
     $$062 = -1;
     STACKTOP = sp;return ($$062|0);
    }
    $93 = ((($0)) + 52|0);
    $94 = HEAP32[$93>>2]|0;
    $95 = (FUNCTION_TABLE_ii[$94 & 8191]($0)|0);
    $$lobit = $95 >> 31;
    $$062 = $$lobit;
    STACKTOP = sp;return ($$062|0);
   }
  }
 }
 $9 = (_SDL_Error(4)|0);
 $$062 = $9;
 STACKTOP = sp;return ($$062|0);
}
function _UpdateLogicalSize($0) {
 $0 = $0|0;
 var $$0 = 0.0, $$0$i = 0, $$0$in = 0, $$036 = 0, $$1 = 0.0, $1 = 0, $10 = 0, $100 = 0.0, $101 = 0.0, $102 = 0, $103 = 0, $104 = 0.0, $105 = 0.0, $106 = 0.0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0.0, $32 = 0, $33 = 0.0, $34 = 0.0, $35 = 0, $36 = 0.0, $37 = 0, $38 = 0.0, $39 = 0.0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0.0, $55 = 0.0, $56 = 0.0, $57 = 0.0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0.0, $65 = 0.0, $66 = 0.0, $67 = 0.0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0.0, $75 = 0.0, $76 = 0.0, $77 = 0, $78 = 0, $79 = 0.0, $8 = 0, $80 = 0;
 var $81 = 0.0, $82 = 0.0, $83 = 0, $84 = 0, $85 = 0.0, $86 = 0, $87 = 0.0, $88 = 0.0, $89 = 0, $9 = 0, $90 = 0.0, $91 = 0.0, $92 = 0.0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer3 = 0, $vararg_buffer5 = 0, $vararg_buffer7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(64|0);
 $vararg_buffer7 = sp + 32|0;
 $vararg_buffer5 = sp + 24|0;
 $vararg_buffer3 = sp + 16|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $1 = sp + 60|0;
 $2 = sp + 56|0;
 $3 = sp + 40|0;
 HEAP32[$1>>2] = 1;
 HEAP32[$2>>2] = 1;
 $4 = ((($0)) + 196|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  $$036 = 0;
  STACKTOP = sp;return ($$036|0);
 }
 $7 = ((($0)) + 200|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0);
 if ($9) {
  $$036 = 0;
  STACKTOP = sp;return ($$036|0);
 }
 $10 = HEAP32[$0>>2]|0;
 $11 = ($10|0)==(217376|0);
 if (!($11)) {
  (_SDL_SetError(176572,$vararg_buffer)|0);
  $$036 = -1;
  STACKTOP = sp;return ($$036|0);
 }
 $12 = ((($0)) + 308|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0|0);
 L11: do {
  if ($14) {
   $21 = ((($0)) + 8|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = ($22|0)==(0|0);
   do {
    if ($23) {
     $25 = ((($0)) + 188|0);
     $26 = HEAP32[$25>>2]|0;
     $27 = ($26|0)==(0|0);
     if ($27) {
      $28 = (_SDL_SetError(176605,$vararg_buffer3)|0);
      $$0$i = $28;
      break;
     } else {
      _SDL_GetWindowSize($26,$1,$2);
      break L11;
     }
    } else {
     $24 = (FUNCTION_TABLE_iiii[$22 & 8191]($0,$1,$2)|0);
     $$0$i = $24;
    }
   } while(0);
   $29 = ($$0$i|0)<(0);
   if ($29) {
    $$036 = -1;
    STACKTOP = sp;return ($$036|0);
   }
  } else {
   $15 = HEAP32[$13>>2]|0;
   $16 = ($15|0)==(217377|0);
   if ($16) {
    $17 = ((($13)) + 12|0);
    $18 = HEAP32[$17>>2]|0;
    HEAP32[$1>>2] = $18;
    $19 = ((($13)) + 16|0);
    $20 = HEAP32[$19>>2]|0;
    HEAP32[$2>>2] = $20;
    break;
   }
   (_SDL_SetError(176589,$vararg_buffer1)|0);
   $$036 = -1;
   STACKTOP = sp;return ($$036|0);
  }
 } while(0);
 $30 = HEAP32[$4>>2]|0;
 $31 = (+($30|0));
 $32 = HEAP32[$7>>2]|0;
 $33 = (+($32|0));
 $34 = $31 / $33;
 $35 = HEAP32[$1>>2]|0;
 $36 = (+($35|0));
 $37 = HEAP32[$2>>2]|0;
 $38 = (+($37|0));
 $39 = $36 / $38;
 $40 = HEAP32[$0>>2]|0;
 $41 = ($40|0)==(217376|0);
 if ($41) {
  $42 = ((($0)) + 288|0);
  HEAPF32[$42>>2] = 1.0;
  $43 = ((($0)) + 292|0);
  HEAPF32[$43>>2] = 1.0;
 } else {
  (_SDL_SetError(176572,$vararg_buffer5)|0);
 }
 $44 = ((($0)) + 212|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = ($45|0)==(0);
 do {
  if ($46) {
   $74 = $34 - $39;
   $75 = $74;
   $76 = (+_SDL_fabs($75));
   $77 = $76 < 1.0E-4;
   $78 = HEAP32[$4>>2]|0;
   $79 = (+($78|0));
   if ($77) {
    $80 = HEAP32[$1>>2]|0;
    $81 = (+($80|0));
    $82 = $81 / $79;
    (_SDL_RenderSetViewport($0,0)|0);
    $$1 = $82;
    break;
   }
   $83 = $34 > $39;
   $84 = HEAP32[$7>>2]|0;
   $85 = (+($84|0));
   if ($83) {
    $86 = HEAP32[$1>>2]|0;
    $87 = (+($86|0));
    $88 = $87 / $79;
    HEAP32[$3>>2] = 0;
    $89 = ((($3)) + 8|0);
    HEAP32[$89>>2] = $86;
    $90 = $85 * $88;
    $91 = $90;
    $92 = (+_SDL_ceil($91));
    $93 = (~~(($92)));
    $94 = ((($3)) + 12|0);
    HEAP32[$94>>2] = $93;
    $95 = HEAP32[$2>>2]|0;
    $96 = (($95) - ($93))|0;
    $97 = (($96|0) / 2)&-1;
    $98 = ((($3)) + 4|0);
    HEAP32[$98>>2] = $97;
    (_SDL_RenderSetViewport($0,$3)|0);
    $$1 = $88;
    break;
   } else {
    $99 = HEAP32[$2>>2]|0;
    $100 = (+($99|0));
    $101 = $100 / $85;
    $102 = ((($3)) + 4|0);
    HEAP32[$102>>2] = 0;
    $103 = ((($3)) + 12|0);
    HEAP32[$103>>2] = $99;
    $104 = $79 * $101;
    $105 = $104;
    $106 = (+_SDL_ceil($105));
    $107 = (~~(($106)));
    $108 = ((($3)) + 8|0);
    HEAP32[$108>>2] = $107;
    $109 = HEAP32[$1>>2]|0;
    $110 = (($109) - ($107))|0;
    $111 = (($110|0) / 2)&-1;
    HEAP32[$3>>2] = $111;
    (_SDL_RenderSetViewport($0,$3)|0);
    $$1 = $101;
    break;
   }
  } else {
   $47 = $34 > $39;
   $48 = HEAP32[$4>>2]|0;
   if ($47) {
    $49 = HEAP32[$1>>2]|0;
    $50 = (($49|0) / ($48|0))&-1;
    $$0$in = $50;
   } else {
    $51 = HEAP32[$2>>2]|0;
    $52 = HEAP32[$7>>2]|0;
    $53 = (($51|0) / ($52|0))&-1;
    $$0$in = $53;
   }
   $$0 = (+($$0$in|0));
   $54 = (+($48|0));
   $55 = $54 * $$0;
   $56 = $55;
   $57 = (+_SDL_ceil($56));
   $58 = (~~(($57)));
   $59 = ((($3)) + 8|0);
   HEAP32[$59>>2] = $58;
   $60 = HEAP32[$1>>2]|0;
   $61 = (($60) - ($58))|0;
   $62 = (($61|0) / 2)&-1;
   HEAP32[$3>>2] = $62;
   $63 = HEAP32[$7>>2]|0;
   $64 = (+($63|0));
   $65 = $$0 * $64;
   $66 = $65;
   $67 = (+_SDL_ceil($66));
   $68 = (~~(($67)));
   $69 = ((($3)) + 12|0);
   HEAP32[$69>>2] = $68;
   $70 = HEAP32[$2>>2]|0;
   $71 = (($70) - ($68))|0;
   $72 = (($71|0) / 2)&-1;
   $73 = ((($3)) + 4|0);
   HEAP32[$73>>2] = $72;
   (_SDL_RenderSetViewport($0,$3)|0);
   $$1 = $$0;
  }
 } while(0);
 $112 = HEAP32[$0>>2]|0;
 $113 = ($112|0)==(217376|0);
 if ($113) {
  $114 = ((($0)) + 288|0);
  HEAPF32[$114>>2] = $$1;
  $115 = ((($0)) + 292|0);
  HEAPF32[$115>>2] = $$1;
  $$036 = 0;
  STACKTOP = sp;return ($$036|0);
 } else {
  (_SDL_SetError(176572,$vararg_buffer7)|0);
  $$036 = 0;
  STACKTOP = sp;return ($$036|0);
 }
 return (0)|0;
}
function _SDL_RenderSetViewport($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$0$i = 0, $10 = 0.0, $11 = 0.0, $12 = 0.0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0.0, $18 = 0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0.0, $28 = 0.0, $29 = 0.0, $3 = 0, $30 = 0.0, $31 = 0.0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0.0, $37 = 0.0, $38 = 0.0, $39 = 0.0, $4 = 0, $40 = 0.0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0.0, $8 = 0, $9 = 0.0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $vararg_buffer3 = sp + 16|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $2 = ($0|0)==(0|0);
 if (!($2)) {
  $3 = HEAP32[$0>>2]|0;
  $4 = ($3|0)==(217376|0);
  if ($4) {
   $5 = ($1|0)==(0|0);
   L4: do {
    if ($5) {
     $43 = ((($0)) + 216|0);
     HEAP32[$43>>2] = 0;
     $44 = ((($0)) + 220|0);
     HEAP32[$44>>2] = 0;
     $45 = ((($0)) + 224|0);
     $46 = ((($0)) + 228|0);
     $47 = ((($0)) + 308|0);
     $48 = HEAP32[$47>>2]|0;
     $49 = ($48|0)==(0|0);
     if (!($49)) {
      $50 = HEAP32[$48>>2]|0;
      $51 = ($50|0)==(217377|0);
      if ($51) {
       $52 = ((($48)) + 12|0);
       $53 = HEAP32[$52>>2]|0;
       HEAP32[$45>>2] = $53;
       $54 = ((($48)) + 16|0);
       $55 = HEAP32[$54>>2]|0;
       HEAP32[$46>>2] = $55;
       break;
      }
      (_SDL_SetError(176589,$vararg_buffer1)|0);
      $$0 = -1;
      STACKTOP = sp;return ($$0|0);
     }
     $56 = ((($0)) + 8|0);
     $57 = HEAP32[$56>>2]|0;
     $58 = ($57|0)==(0|0);
     do {
      if ($58) {
       $60 = ((($0)) + 188|0);
       $61 = HEAP32[$60>>2]|0;
       $62 = ($61|0)==(0|0);
       if ($62) {
        $63 = (_SDL_SetError(176605,$vararg_buffer3)|0);
        $$0$i = $63;
        break;
       } else {
        _SDL_GetWindowSize($61,$45,$46);
        break L4;
       }
      } else {
       $59 = (FUNCTION_TABLE_iiii[$57 & 8191]($0,$45,$46)|0);
       $$0$i = $59;
      }
     } while(0);
     $64 = ($$0$i|0)<(0);
     if ($64) {
      $$0 = -1;
      STACKTOP = sp;return ($$0|0);
     }
    } else {
     $6 = HEAP32[$1>>2]|0;
     $7 = (+($6|0));
     $8 = ((($0)) + 288|0);
     $9 = +HEAPF32[$8>>2];
     $10 = $7 * $9;
     $11 = $10;
     $12 = (+_SDL_floor($11));
     $13 = (~~(($12)));
     $14 = ((($0)) + 216|0);
     HEAP32[$14>>2] = $13;
     $15 = ((($1)) + 4|0);
     $16 = HEAP32[$15>>2]|0;
     $17 = (+($16|0));
     $18 = ((($0)) + 292|0);
     $19 = +HEAPF32[$18>>2];
     $20 = $17 * $19;
     $21 = $20;
     $22 = (+_SDL_floor($21));
     $23 = (~~(($22)));
     $24 = ((($0)) + 220|0);
     HEAP32[$24>>2] = $23;
     $25 = ((($1)) + 8|0);
     $26 = HEAP32[$25>>2]|0;
     $27 = (+($26|0));
     $28 = +HEAPF32[$8>>2];
     $29 = $27 * $28;
     $30 = $29;
     $31 = (+_SDL_ceil($30));
     $32 = (~~(($31)));
     $33 = ((($0)) + 224|0);
     HEAP32[$33>>2] = $32;
     $34 = ((($1)) + 12|0);
     $35 = HEAP32[$34>>2]|0;
     $36 = (+($35|0));
     $37 = +HEAPF32[$18>>2];
     $38 = $36 * $37;
     $39 = $38;
     $40 = (+_SDL_ceil($39));
     $41 = (~~(($40)));
     $42 = ((($0)) + 228|0);
     HEAP32[$42>>2] = $41;
    }
   } while(0);
   $65 = ((($0)) + 48|0);
   $66 = HEAP32[$65>>2]|0;
   $67 = (FUNCTION_TABLE_ii[$66 & 8191]($0)|0);
   $$0 = $67;
   STACKTOP = sp;return ($$0|0);
  }
 }
 (_SDL_SetError(176572,$vararg_buffer)|0);
 $$0 = -1;
 STACKTOP = sp;return ($$0|0);
}
function _SDL_SW_DestroyYUVTexture($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ($0|0)==(0|0);
 if ($1) {
  return;
 }
 $2 = ((($0)) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 _SDL_free($3);
 $4 = ((($0)) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 _SDL_free($5);
 $6 = ((($0)) + 24|0);
 $7 = HEAP32[$6>>2]|0;
 _SDL_free($7);
 $8 = ((($0)) + 56|0);
 $9 = HEAP32[$8>>2]|0;
 _SDL_FreeSurface($9);
 $10 = ((($0)) + 60|0);
 $11 = HEAP32[$10>>2]|0;
 _SDL_FreeSurface($11);
 _SDL_free($0);
 return;
}
function _SDL_GetSpanEnclosingRect($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$$044 = 0, $$$045 = 0, $$0 = 0, $$04349 = 0, $$04448 = 0, $$04547 = 0, $$1 = 0, $$146 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer10 = 0, $vararg_buffer4 = 0, $vararg_buffer7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $vararg_buffer10 = sp + 32|0;
 $vararg_buffer7 = sp + 24|0;
 $vararg_buffer4 = sp + 16|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $5 = ($0|0)<(1);
 if ($5) {
  HEAP32[$vararg_buffer>>2] = 194973;
  (_SDL_SetError(194740,$vararg_buffer)|0);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $6 = ($1|0)<(1);
 if ($6) {
  HEAP32[$vararg_buffer1>>2] = 194979;
  (_SDL_SetError(194740,$vararg_buffer1)|0);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $7 = ($3|0)==(0|0);
 if ($7) {
  HEAP32[$vararg_buffer4>>2] = 194986;
  (_SDL_SetError(194740,$vararg_buffer4)|0);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $8 = ($4|0)==(0|0);
 if ($8) {
  HEAP32[$vararg_buffer7>>2] = 194992;
  (_SDL_SetError(194740,$vararg_buffer7)|0);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $9 = ($2|0)<(1);
 if ($9) {
  HEAP32[$vararg_buffer10>>2] = 194997;
  (_SDL_SetError(194740,$vararg_buffer10)|0);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  $$04349 = 0;$$04448 = 0;$$04547 = $1;
 }
 while(1) {
  $10 = (((($3) + ($$04349<<4)|0)) + 4|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (((($3) + ($$04349<<4)|0)) + 12|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($13) + ($11))|0;
  $15 = ($11|0)<(0);
  $16 = ($11|0)<($$04547|0);
  $$$045 = $16 ? $11 : $$04547;
  $$146 = $15 ? 0 : $$$045;
  $17 = ($14|0)>($1|0);
  $18 = ($14|0)>($$04448|0);
  $$$044 = $18 ? $14 : $$04448;
  $$1 = $17 ? $1 : $$$044;
  $19 = (($$04349) + 1)|0;
  $exitcond = ($19|0)==($2|0);
  if ($exitcond) {
   break;
  } else {
   $$04349 = $19;$$04448 = $$1;$$04547 = $$146;
  }
 }
 $20 = ($$1|0)>($$146|0);
 if (!($20)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $21 = ((($4)) + 12|0);
 $22 = (($$1) - ($$146))|0;
 $23 = ((($4)) + 8|0);
 $24 = ((($4)) + 4|0);
 HEAP32[$4>>2] = 0;
 HEAP32[$24>>2] = $$146;
 HEAP32[$23>>2] = $0;
 HEAP32[$21>>2] = $22;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function _SDL_UpdateTexture($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $$025 = 0, $$2$i = 0, $$mask$i = 0, $$mask$i27 = 0, $$phi$trans$insert = 0, $$pre = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond$i = 0, $or$cond$i28 = 0, $phitmp$i = 0, $phitmp$i29 = 0;
 var $switch$split112D = 0, $switch$split2D = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(80|0);
 $vararg_buffer3 = sp + 16|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $4 = sp + 68|0;
 $5 = sp + 64|0;
 $6 = sp + 48|0;
 $7 = sp + 44|0;
 $8 = sp + 40|0;
 $9 = sp + 24|0;
 $10 = ($0|0)==(0|0);
 if (!($10)) {
  $11 = HEAP32[$0>>2]|0;
  $12 = ($11|0)==(217377|0);
  if ($12) {
   $13 = ($2|0)==(0|0);
   if ($13) {
    HEAP32[$vararg_buffer1>>2] = 194766;
    $14 = (_SDL_SetError(194740,$vararg_buffer1)|0);
    $$0 = $14;
    STACKTOP = sp;return ($$0|0);
   }
   $15 = ($3|0)==(0);
   if ($15) {
    HEAP32[$vararg_buffer3>>2] = 194773;
    $16 = (_SDL_SetError(194740,$vararg_buffer3)|0);
    $$0 = $16;
    STACKTOP = sp;return ($$0|0);
   }
   $17 = ($1|0)==(0|0);
   if ($17) {
    HEAP32[$9>>2] = 0;
    $18 = ((($9)) + 4|0);
    HEAP32[$18>>2] = 0;
    $19 = ((($0)) + 12|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = ((($9)) + 8|0);
    HEAP32[$21>>2] = $20;
    $22 = ((($0)) + 16|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = ((($9)) + 12|0);
    HEAP32[$24>>2] = $23;
    $$025 = $9;$26 = $20;
   } else {
    $$phi$trans$insert = ((($1)) + 8|0);
    $$pre = HEAP32[$$phi$trans$insert>>2]|0;
    $$025 = $1;$26 = $$pre;
   }
   $25 = ((($$025)) + 8|0);
   $27 = ($26|0)==(0);
   if ($27) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $28 = ((($$025)) + 12|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = ($29|0)==(0);
   if ($30) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $31 = ((($0)) + 40|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ($32|0)==(0|0);
   $34 = ((($0)) + 36|0);
   $35 = HEAP32[$34>>2]|0;
   if (!($33)) {
    $36 = (_SDL_SW_UpdateYUVTexture($32,$$025,$2,$3)|0);
    $37 = ($36|0)<(0);
    do {
     if ($37) {
      $$2$i = -1;
     } else {
      HEAP32[$6>>2] = 0;
      $38 = ((($6)) + 4|0);
      HEAP32[$38>>2] = 0;
      $39 = ((($0)) + 12|0);
      $40 = HEAP32[$39>>2]|0;
      $41 = ((($6)) + 8|0);
      HEAP32[$41>>2] = $40;
      $42 = ((($0)) + 16|0);
      $43 = HEAP32[$42>>2]|0;
      $44 = ((($6)) + 12|0);
      HEAP32[$44>>2] = $43;
      $45 = ((($0)) + 8|0);
      $46 = HEAP32[$45>>2]|0;
      $47 = ($46|0)==(1);
      if ($47) {
       $48 = (_SDL_LockTexture($35,$6,$7,$8)|0);
       $49 = ($48|0)<(0);
       if ($49) {
        $$2$i = -1;
        break;
       } else {
        $50 = HEAP32[$31>>2]|0;
        $51 = ((($35)) + 4|0);
        $52 = HEAP32[$51>>2]|0;
        $53 = HEAP32[$41>>2]|0;
        $54 = HEAP32[$44>>2]|0;
        $55 = HEAP32[$7>>2]|0;
        $56 = HEAP32[$8>>2]|0;
        (_SDL_SW_CopyYUVToRGB($50,$6,$52,$53,$54,$55,$56)|0);
        _SDL_UnlockTexture($35);
        $$2$i = 0;
        break;
       }
      }
      $57 = ((($35)) + 4|0);
      $58 = HEAP32[$57>>2]|0;
      $59 = ($58|0)==(0);
      $$mask$i = $58 & -268435456;
      $60 = ($$mask$i|0)==(268435456);
      $or$cond$i = $59 | $60;
      L32: do {
       if ($or$cond$i) {
        $62 = $58 & 255;
        $64 = $62;
       } else {
        $switch$split2D = ($58|0)<(1498831189);
        if ($switch$split2D) {
         switch ($58|0) {
         case 844715353:  {
          $64 = 2;
          break L32;
          break;
         }
         default: {
         }
         }
        } else {
         switch ($58|0) {
         case 1498831189:  {
          $64 = 2;
          break L32;
          break;
         }
         default: {
         }
         }
        }
        $61 = ($58|0)==(1431918169);
        $phitmp$i = $61 ? 2 : 1;
        $64 = $phitmp$i;
       }
      } while(0);
      $63 = Math_imul($64, $40)|0;
      $65 = (($63) + 3)|0;
      $66 = $65 & -4;
      $67 = Math_imul($66, $43)|0;
      $68 = (_SDL_malloc($67)|0);
      $69 = ($68|0)==(0|0);
      if ($69) {
       $74 = (_SDL_Error(0)|0);
       $$2$i = $74;
       break;
      } else {
       $70 = HEAP32[$31>>2]|0;
       $71 = HEAP32[$57>>2]|0;
       $72 = HEAP32[$41>>2]|0;
       $73 = HEAP32[$44>>2]|0;
       (_SDL_SW_CopyYUVToRGB($70,$6,$71,$72,$73,$68,$66)|0);
       (_SDL_UpdateTexture($35,$6,$68,$66)|0);
       _SDL_free($68);
       $$2$i = 0;
       break;
      }
     }
    } while(0);
    $$0 = $$2$i;
    STACKTOP = sp;return ($$0|0);
   }
   $75 = ($35|0)==(0|0);
   if ($75) {
    $108 = ((($0)) + 32|0);
    $109 = HEAP32[$108>>2]|0;
    $110 = ((($109)) + 28|0);
    $111 = HEAP32[$110>>2]|0;
    $112 = (FUNCTION_TABLE_iiiiii[$111 & 8191]($109,$0,$$025,$2,$3)|0);
    $$0 = $112;
    STACKTOP = sp;return ($$0|0);
   }
   $76 = ((($0)) + 8|0);
   $77 = HEAP32[$76>>2]|0;
   $78 = ($77|0)==(1);
   if ($78) {
    $79 = (_SDL_LockTexture($35,$$025,$4,$5)|0);
    $80 = ($79|0)<(0);
    if ($80) {
     $$0 = -1;
     STACKTOP = sp;return ($$0|0);
    } else {
     $81 = HEAP32[$25>>2]|0;
     $82 = HEAP32[$28>>2]|0;
     $83 = ((($0)) + 4|0);
     $84 = HEAP32[$83>>2]|0;
     $85 = ((($35)) + 4|0);
     $86 = HEAP32[$85>>2]|0;
     $87 = HEAP32[$4>>2]|0;
     $88 = HEAP32[$5>>2]|0;
     (_SDL_ConvertPixels($81,$82,$84,$2,$3,$86,$87,$88)|0);
     _SDL_UnlockTexture($35);
     $$0 = 0;
     STACKTOP = sp;return ($$0|0);
    }
   }
   $89 = ((($35)) + 4|0);
   $90 = HEAP32[$89>>2]|0;
   $91 = ($90|0)==(0);
   $$mask$i27 = $90 & -268435456;
   $92 = ($$mask$i27|0)==(268435456);
   $or$cond$i28 = $91 | $92;
   L58: do {
    if ($or$cond$i28) {
     $94 = $90 & 255;
     $96 = $94;
    } else {
     $switch$split112D = ($90|0)<(1498831189);
     if ($switch$split112D) {
      switch ($90|0) {
      case 844715353:  {
       $96 = 2;
       break L58;
       break;
      }
      default: {
      }
      }
     } else {
      switch ($90|0) {
      case 1498831189:  {
       $96 = 2;
       break L58;
       break;
      }
      default: {
      }
      }
     }
     $93 = ($90|0)==(1431918169);
     $phitmp$i29 = $93 ? 2 : 1;
     $96 = $phitmp$i29;
    }
   } while(0);
   $95 = Math_imul($96, $26)|0;
   $97 = (($95) + 3)|0;
   $98 = $97 & -4;
   $99 = Math_imul($98, $29)|0;
   $100 = (_SDL_malloc($99)|0);
   $101 = ($100|0)==(0|0);
   if ($101) {
    $107 = (_SDL_Error(0)|0);
    $$0 = $107;
    STACKTOP = sp;return ($$0|0);
   } else {
    $102 = HEAP32[$25>>2]|0;
    $103 = HEAP32[$28>>2]|0;
    $104 = ((($0)) + 4|0);
    $105 = HEAP32[$104>>2]|0;
    $106 = HEAP32[$89>>2]|0;
    (_SDL_ConvertPixels($102,$103,$105,$2,$3,$106,$100,$98)|0);
    (_SDL_UpdateTexture($35,$$025,$100,$98)|0);
    _SDL_free($100);
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 (_SDL_SetError(176589,$vararg_buffer)|0);
 $$0 = -1;
 STACKTOP = sp;return ($$0|0);
}
function _SDL_RenderCopy($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$ = 0, $$0 = 0, $$pre = 0, $$pre$phi29Z2D = 0, $$pre$phiZ2D = 0, $$pre25 = 0, $$pre26 = 0, $$pre28 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0.0, $33 = 0, $34 = 0.0, $35 = 0.0, $36 = 0, $37 = 0, $38 = 0, $39 = 0.0, $4 = 0, $40 = 0;
 var $41 = 0.0, $42 = 0.0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0.0, $48 = 0.0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0.0, $54 = 0.0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0.0, $65 = 0.0, $66 = 0.0, $67 = 0, $68 = 0.0, $69 = 0.0, $7 = 0, $70 = 0.0, $71 = 0, $72 = 0, $73 = 0, $74 = 0.0, $75 = 0.0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0.0, $8 = 0, $80 = 0.0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $9 = 0, $phitmp = 0, $phitmp30 = 0.0, $phitmp31 = 0.0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer3 = 0, $vararg_buffer5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(80|0);
 $vararg_buffer5 = sp + 24|0;
 $vararg_buffer3 = sp + 16|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $4 = sp + 64|0;
 $5 = sp + 48|0;
 $6 = sp + 32|0;
 ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;HEAP32[$4+12>>2]=0|0;
 ;HEAP32[$5>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;HEAP32[$5+12>>2]=0|0;
 $7 = ($0|0)==(0|0);
 if (!($7)) {
  $8 = HEAP32[$0>>2]|0;
  $9 = ($8|0)==(217376|0);
  if ($9) {
   $10 = ($1|0)==(0|0);
   if (!($10)) {
    $11 = HEAP32[$1>>2]|0;
    $12 = ($11|0)==(217377|0);
    if ($12) {
     $13 = ((($1)) + 32|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = ($14|0)==($0|0);
     if (!($15)) {
      $16 = (_SDL_SetError(194624,$vararg_buffer3)|0);
      $$0 = $16;
      STACKTOP = sp;return ($$0|0);
     }
     $17 = ((($0)) + 192|0);
     $18 = HEAP32[$17>>2]|0;
     $19 = ($18|0)==(0);
     if (!($19)) {
      $$0 = 0;
      STACKTOP = sp;return ($$0|0);
     }
     HEAP32[$4>>2] = 0;
     $20 = ((($4)) + 4|0);
     HEAP32[$20>>2] = 0;
     $21 = ((($1)) + 12|0);
     $22 = HEAP32[$21>>2]|0;
     $23 = ((($4)) + 8|0);
     HEAP32[$23>>2] = $22;
     $24 = ((($1)) + 16|0);
     $25 = HEAP32[$24>>2]|0;
     $26 = ((($4)) + 12|0);
     HEAP32[$26>>2] = $25;
     $27 = ($2|0)==(0|0);
     if ($27) {
      label = 14;
     } else {
      $28 = (_SDL_IntersectRect($2,$4,$4)|0);
      $29 = ($28|0)==(0);
      if ($29) {
       $$0 = 0;
       STACKTOP = sp;return ($$0|0);
      }
      $$pre = HEAP32[$0>>2]|0;
      $phitmp = ($$pre|0)==(217376|0);
      if ($phitmp) {
       label = 14;
      } else {
       (_SDL_SetError(176572,$vararg_buffer5)|0);
       $$pre28 = ((($5)) + 4|0);
       $$pre$phi29Z2D = $$pre28;$$pre$phiZ2D = $5;
      }
     }
     if ((label|0) == 14) {
      $30 = ((($0)) + 216|0);
      $31 = HEAP32[$30>>2]|0;
      $32 = (+($31|0));
      $33 = ((($0)) + 288|0);
      $34 = +HEAPF32[$33>>2];
      $35 = $32 / $34;
      $36 = (~~(($35)));
      HEAP32[$5>>2] = $36;
      $37 = ((($0)) + 220|0);
      $38 = HEAP32[$37>>2]|0;
      $39 = (+($38|0));
      $40 = ((($0)) + 292|0);
      $41 = +HEAPF32[$40>>2];
      $42 = $39 / $41;
      $43 = (~~(($42)));
      $44 = ((($5)) + 4|0);
      HEAP32[$44>>2] = $43;
      $45 = ((($0)) + 224|0);
      $46 = HEAP32[$45>>2]|0;
      $47 = (+($46|0));
      $48 = $47 / $34;
      $49 = (~~(($48)));
      $50 = ((($5)) + 8|0);
      HEAP32[$50>>2] = $49;
      $51 = ((($0)) + 228|0);
      $52 = HEAP32[$51>>2]|0;
      $53 = (+($52|0));
      $54 = $53 / $41;
      $55 = (~~(($54)));
      $56 = ((($5)) + 12|0);
      HEAP32[$56>>2] = $55;
      $$pre$phi29Z2D = $44;$$pre$phiZ2D = $5;
     }
     HEAP32[$$pre$phiZ2D>>2] = 0;
     HEAP32[$$pre$phi29Z2D>>2] = 0;
     $57 = ($3|0)==(0|0);
     do {
      if ($57) {
       $66 = 0.0;$70 = 0.0;
      } else {
       $58 = (_SDL_HasIntersection($3,$5)|0);
       $59 = ($58|0)==(0);
       if ($59) {
        $$0 = 0;
        STACKTOP = sp;return ($$0|0);
       } else {
        ;HEAP32[$5>>2]=HEAP32[$3>>2]|0;HEAP32[$5+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$3+12>>2]|0;
        $$pre25 = HEAP32[$$pre$phiZ2D>>2]|0;
        $$pre26 = HEAP32[$$pre$phi29Z2D>>2]|0;
        $phitmp30 = (+($$pre25|0));
        $phitmp31 = (+($$pre26|0));
        $66 = $phitmp30;$70 = $phitmp31;
        break;
       }
      }
     } while(0);
     $60 = ((($1)) + 36|0);
     $61 = HEAP32[$60>>2]|0;
     $62 = ($61|0)==(0|0);
     $$ = $62 ? $1 : $61;
     $63 = ((($0)) + 288|0);
     $64 = +HEAPF32[$63>>2];
     $65 = $66 * $64;
     HEAPF32[$6>>2] = $65;
     $67 = ((($0)) + 292|0);
     $68 = +HEAPF32[$67>>2];
     $69 = $70 * $68;
     $71 = ((($6)) + 4|0);
     HEAPF32[$71>>2] = $69;
     $72 = ((($5)) + 8|0);
     $73 = HEAP32[$72>>2]|0;
     $74 = (+($73|0));
     $75 = $64 * $74;
     $76 = ((($6)) + 8|0);
     HEAPF32[$76>>2] = $75;
     $77 = ((($5)) + 12|0);
     $78 = HEAP32[$77>>2]|0;
     $79 = (+($78|0));
     $80 = $68 * $79;
     $81 = ((($6)) + 12|0);
     HEAPF32[$81>>2] = $80;
     $82 = ((($0)) + 72|0);
     $83 = HEAP32[$82>>2]|0;
     $84 = (FUNCTION_TABLE_iiiii[$83 & 8191]($0,$$,$4,$6)|0);
     $$0 = $84;
     STACKTOP = sp;return ($$0|0);
    }
   }
   (_SDL_SetError(176589,$vararg_buffer1)|0);
   $$0 = -1;
   STACKTOP = sp;return ($$0|0);
  }
 }
 (_SDL_SetError(176572,$vararg_buffer)|0);
 $$0 = -1;
 STACKTOP = sp;return ($$0|0);
}
function _SDL_RenderPresent($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = HEAP32[$0>>2]|0;
  $3 = ($2|0)==(217376|0);
  if ($3) {
   $4 = ((($0)) + 192|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = ($5|0)==(0);
   if (!($6)) {
    STACKTOP = sp;return;
   }
   $7 = ((($0)) + 84|0);
   $8 = HEAP32[$7>>2]|0;
   FUNCTION_TABLE_vi[$8 & 8191]($0);
   STACKTOP = sp;return;
  }
 }
 (_SDL_SetError(176572,$vararg_buffer)|0);
 STACKTOP = sp;return;
}
function _SDL_HasIntersection($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$ = 0, $$0 = 0, $$041 = 0, $$1 = 0, $$42 = 0, $$43 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $2 = ($0|0)==(0|0);
 do {
  if ($2) {
   HEAP32[$vararg_buffer>>2] = 195914;
   (_SDL_SetError(194740,$vararg_buffer)|0);
   $$041 = 0;
  } else {
   $3 = ($1|0)==(0|0);
   if ($3) {
    HEAP32[$vararg_buffer1>>2] = 176524;
    (_SDL_SetError(194740,$vararg_buffer1)|0);
    $$041 = 0;
    break;
   }
   $4 = ((($0)) + 8|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = ($5|0)<(1);
   if ($6) {
    $$041 = 0;
   } else {
    $7 = ((($0)) + 12|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = ($8|0)<(1);
    if ($9) {
     $$041 = 0;
    } else {
     $10 = ((($1)) + 8|0);
     $11 = HEAP32[$10>>2]|0;
     $12 = ($11|0)<(1);
     if ($12) {
      $$041 = 0;
     } else {
      $13 = ((($1)) + 12|0);
      $14 = HEAP32[$13>>2]|0;
      $15 = ($14|0)<(1);
      if ($15) {
       $$041 = 0;
      } else {
       $16 = HEAP32[$0>>2]|0;
       $17 = (($5) + ($16))|0;
       $18 = HEAP32[$1>>2]|0;
       $19 = (($11) + ($18))|0;
       $20 = ($18|0)>($16|0);
       $$ = $20 ? $18 : $16;
       $21 = ($19|0)<($17|0);
       $$0 = $21 ? $19 : $17;
       $22 = ($$0|0)>($$|0);
       if ($22) {
        $23 = ((($0)) + 4|0);
        $24 = HEAP32[$23>>2]|0;
        $25 = (($8) + ($24))|0;
        $26 = ((($1)) + 4|0);
        $27 = HEAP32[$26>>2]|0;
        $28 = (($14) + ($27))|0;
        $29 = ($27|0)>($24|0);
        $$42 = $29 ? $27 : $24;
        $30 = ($28|0)<($25|0);
        $$1 = $30 ? $28 : $25;
        $31 = ($$1|0)>($$42|0);
        $$43 = $31&1;
        $$041 = $$43;
       } else {
        $$041 = 0;
       }
      }
     }
    }
   }
  }
 } while(0);
 STACKTOP = sp;return ($$041|0);
}
function _SDL_SW_UpdateYUVTexture($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0105134 = 0, $$0106133 = 0, $$0107132 = 0, $$0108125 = 0, $$0111124 = 0, $$0126 = 0, $$1109121 = 0, $$1112120 = 0, $$1122 = 0, $$2110118 = 0, $$2113117 = 0, $$2119 = 0, $$pre141 = 0, $$pre142 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0;
 var $123 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $switch$split12D = 0, $switch$split2D = 0, $switch$split42D = 0, $switch$split72D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = HEAP32[$0>>2]|0;
 $switch$split2D = ($4|0)<(1431918169);
 L1: do {
  if ($switch$split2D) {
   $switch$split12D = ($4|0)<(844715353);
   if ($switch$split12D) {
    switch ($4|0) {
    case 842094169:  {
     break L1;
     break;
    }
    default: {
    }
    }
    return 0;
   } else {
    switch ($4|0) {
    case 844715353:  {
     label = 15;
     break L1;
     break;
    }
    default: {
    }
    }
    return 0;
   }
  } else {
   $switch$split42D = ($4|0)<(1448433993);
   if ($switch$split42D) {
    switch ($4|0) {
    case 1431918169:  {
     label = 15;
     break L1;
     break;
    }
    default: {
    }
    }
    return 0;
   }
   $switch$split72D = ($4|0)<(1498831189);
   if ($switch$split72D) {
    switch ($4|0) {
    case 1448433993:  {
     break L1;
     break;
    }
    default: {
    }
    }
    return 0;
   } else {
    switch ($4|0) {
    case 1498831189:  {
     label = 15;
     break L1;
     break;
    }
    default: {
    }
    }
    return 0;
   }
  }
 } while(0);
 if ((label|0) == 15) {
  $99 = ((($0)) + 36|0);
  $100 = ((($1)) + 8|0);
  $101 = HEAP32[$100>>2]|0;
  $102 = $101 << 1;
  $103 = ((($1)) + 12|0);
  $104 = HEAP32[$103>>2]|0;
  $105 = ($104|0)>(0);
  if (!($105)) {
   return 0;
  }
  $106 = ((($0)) + 44|0);
  $107 = HEAP32[$106>>2]|0;
  $108 = HEAP16[$99>>1]|0;
  $109 = $108&65535;
  $110 = ((($1)) + 4|0);
  $111 = HEAP32[$110>>2]|0;
  $112 = Math_imul($109, $111)|0;
  $113 = (($107) + ($112)|0);
  $114 = HEAP32[$1>>2]|0;
  $115 = $114 << 1;
  $116 = (($113) + ($115)|0);
  $$0105134 = 0;$$0106133 = $116;$$0107132 = $2;
  while(1) {
   (_SDL_memcpy($$0106133,$$0107132,$102)|0);
   $117 = (($$0107132) + ($3)|0);
   $118 = HEAP16[$99>>1]|0;
   $119 = $118&65535;
   $120 = (($$0106133) + ($119)|0);
   $121 = (($$0105134) + 1)|0;
   $122 = HEAP32[$103>>2]|0;
   $123 = ($121|0)<($122|0);
   if ($123) {
    $$0105134 = $121;$$0106133 = $120;$$0107132 = $117;
   } else {
    break;
   }
  }
  return 0;
 }
 $5 = HEAP32[$1>>2]|0;
 $6 = ((($1)) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $5 | $7;
 $9 = ($8|0)==(0);
 if ($9) {
  $10 = ((($1)) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ((($0)) + 8|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($11|0)==($13|0);
  if ($14) {
   $15 = ((($1)) + 12|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ((($0)) + 12|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = ($16|0)==($18|0);
   if ($19) {
    $20 = ((($0)) + 16|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = Math_imul($16, $11)|0;
    $23 = (($22|0) / 2)&-1;
    $24 = (($23) + ($22))|0;
    (_SDL_memcpy($21,$2,$24)|0);
    return 0;
   } else {
    $35 = 0;
   }
  } else {
   $35 = 0;
  }
 } else {
  $35 = $7;
 }
 $25 = ((($0)) + 16|0);
 $26 = ((($0)) + 8|0);
 $27 = ((($1)) + 8|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = ((($1)) + 12|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ($30|0)>(0);
 if (!($31)) {
  return 0;
 }
 $32 = HEAP32[$26>>2]|0;
 $33 = HEAP32[$25>>2]|0;
 $34 = Math_imul($32, $35)|0;
 $36 = (($33) + ($34)|0);
 $37 = (($36) + ($5)|0);
 $$0108125 = 0;$$0111124 = $37;$$0126 = $2;
 while(1) {
  (_SDL_memcpy($$0111124,$$0126,$28)|0);
  $38 = (($$0126) + ($3)|0);
  $39 = HEAP32[$26>>2]|0;
  $40 = (($$0111124) + ($39)|0);
  $41 = (($$0108125) + 1)|0;
  $42 = HEAP32[$29>>2]|0;
  $43 = ($41|0)<($42|0);
  if ($43) {
   $$0108125 = $41;$$0111124 = $40;$$0126 = $38;
  } else {
   break;
  }
 }
 $$pre141 = HEAP32[$27>>2]|0;
 $44 = ((($0)) + 12|0);
 $45 = (($$pre141|0) / 2)&-1;
 $46 = ($42|0)>(1);
 if (!($46)) {
  return 0;
 }
 $47 = HEAP32[$25>>2]|0;
 $48 = HEAP32[$44>>2]|0;
 $49 = Math_imul($39, $48)|0;
 $50 = (($47) + ($49)|0);
 $51 = HEAP32[$6>>2]|0;
 $52 = (($51|0) / 2)&-1;
 $53 = Math_imul($52, $39)|0;
 $54 = (($53|0) / 2)&-1;
 $55 = HEAP32[$1>>2]|0;
 $56 = (($55|0) / 2)&-1;
 $57 = (($54) + ($56))|0;
 $58 = (($50) + ($57)|0);
 $59 = Math_imul($42, $3)|0;
 $60 = (($2) + ($59)|0);
 $61 = (($3|0) / 2)&-1;
 $$1109121 = 0;$$1112120 = $58;$$1122 = $60;
 while(1) {
  (_SDL_memcpy($$1112120,$$1122,$45)|0);
  $62 = (($$1122) + ($61)|0);
  $63 = HEAP32[$26>>2]|0;
  $64 = (($63|0) / 2)&-1;
  $65 = (($$1112120) + ($64)|0);
  $66 = (($$1109121) + 1)|0;
  $67 = HEAP32[$29>>2]|0;
  $68 = (($67|0) / 2)&-1;
  $69 = ($66|0)<($68|0);
  if ($69) {
   $$1109121 = $66;$$1112120 = $65;$$1122 = $62;
  } else {
   break;
  }
 }
 $$pre142 = HEAP32[$27>>2]|0;
 $70 = Math_imul($67, $3)|0;
 $71 = HEAP32[$44>>2]|0;
 $72 = Math_imul($63, $71)|0;
 $73 = (($$pre142|0) / 2)&-1;
 $74 = ($67|0)>(1);
 if (!($74)) {
  return 0;
 }
 $75 = HEAP32[$25>>2]|0;
 $76 = (($75) + ($72)|0);
 $77 = (($72|0) / 4)&-1;
 $78 = (($76) + ($77)|0);
 $79 = HEAP32[$6>>2]|0;
 $80 = (($79|0) / 2)&-1;
 $81 = Math_imul($80, $63)|0;
 $82 = (($81|0) / 2)&-1;
 $83 = HEAP32[$1>>2]|0;
 $84 = (($83|0) / 2)&-1;
 $85 = (($82) + ($84))|0;
 $86 = (($78) + ($85)|0);
 $87 = (($2) + ($70)|0);
 $88 = (($70|0) / 4)&-1;
 $89 = (($87) + ($88)|0);
 $90 = (($3|0) / 2)&-1;
 $$2110118 = 0;$$2113117 = $86;$$2119 = $89;
 while(1) {
  (_SDL_memcpy($$2113117,$$2119,$73)|0);
  $91 = (($$2119) + ($90)|0);
  $92 = HEAP32[$26>>2]|0;
  $93 = (($92|0) / 2)&-1;
  $94 = (($$2113117) + ($93)|0);
  $95 = (($$2110118) + 1)|0;
  $96 = HEAP32[$29>>2]|0;
  $97 = (($96|0) / 2)&-1;
  $98 = ($95|0)<($97|0);
  if ($98) {
   $$2110118 = $95;$$2113117 = $94;$$2119 = $91;
  } else {
   break;
  }
 }
 return 0;
}
function _SDL_LockTexture($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $$022 = 0, $$mask$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i = 0, $phitmp$i = 0, $switch$split2D = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $4 = sp + 16|0;
 $5 = ($0|0)==(0|0);
 if (!($5)) {
  $6 = HEAP32[$0>>2]|0;
  $7 = ($6|0)==(217377|0);
  if ($7) {
   $8 = ((($0)) + 8|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = ($9|0)==(1);
   if (!($10)) {
    $11 = (_SDL_SetError(194873,$vararg_buffer1)|0);
    $$0 = $11;
    STACKTOP = sp;return ($$0|0);
   }
   $12 = ($1|0)==(0|0);
   if ($12) {
    HEAP32[$4>>2] = 0;
    $13 = ((($4)) + 4|0);
    HEAP32[$13>>2] = 0;
    $14 = ((($0)) + 12|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = ((($4)) + 8|0);
    HEAP32[$16>>2] = $15;
    $17 = ((($0)) + 16|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = ((($4)) + 12|0);
    HEAP32[$19>>2] = $18;
    $$022 = $4;
   } else {
    $$022 = $1;
   }
   $20 = ((($0)) + 40|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = ($21|0)==(0|0);
   if (!($22)) {
    $23 = (_SDL_SW_LockYUVTexture($21,$$022,$2,$3)|0);
    $$0 = $23;
    STACKTOP = sp;return ($$0|0);
   }
   $24 = ((($0)) + 36|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = ($25|0)==(0|0);
   if ($26) {
    $46 = ((($0)) + 32|0);
    $47 = HEAP32[$46>>2]|0;
    $48 = ((($47)) + 36|0);
    $49 = HEAP32[$48>>2]|0;
    $50 = (FUNCTION_TABLE_iiiiii[$49 & 8191]($47,$0,$$022,$2,$3)|0);
    $$0 = $50;
    STACKTOP = sp;return ($$0|0);
   }
   $27 = ((($0)) + 52|0);
   ;HEAP32[$27>>2]=HEAP32[$$022>>2]|0;HEAP32[$27+4>>2]=HEAP32[$$022+4>>2]|0;HEAP32[$27+8>>2]=HEAP32[$$022+8>>2]|0;HEAP32[$27+12>>2]=HEAP32[$$022+12>>2]|0;
   $28 = ((($0)) + 44|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = ((($$022)) + 4|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = ((($0)) + 48|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = Math_imul($33, $31)|0;
   $35 = (($29) + ($34)|0);
   $36 = HEAP32[$$022>>2]|0;
   $37 = ((($0)) + 4|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = ($38|0)==(0);
   $$mask$i = $38 & -268435456;
   $40 = ($$mask$i|0)==(268435456);
   $or$cond$i = $39 | $40;
   L19: do {
    if ($or$cond$i) {
     $42 = $38 & 255;
     $44 = $42;
    } else {
     $switch$split2D = ($38|0)<(1498831189);
     if ($switch$split2D) {
      switch ($38|0) {
      case 844715353:  {
       $44 = 2;
       break L19;
       break;
      }
      default: {
      }
      }
     } else {
      switch ($38|0) {
      case 1498831189:  {
       $44 = 2;
       break L19;
       break;
      }
      default: {
      }
      }
     }
     $41 = ($38|0)==(1431918169);
     $phitmp$i = $41 ? 2 : 1;
     $44 = $phitmp$i;
    }
   } while(0);
   $43 = Math_imul($44, $36)|0;
   $45 = (($35) + ($43)|0);
   HEAP32[$2>>2] = $45;
   HEAP32[$3>>2] = $33;
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 (_SDL_SetError(176589,$vararg_buffer)|0);
 $$0 = -1;
 STACKTOP = sp;return ($$0|0);
}
function _SDL_SW_CopyYUVToRGB($0,$1,$2,$3,$4,$5,$6) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 var $$$i$i = 0, $$$i176$i = 0, $$$i182$i = 0, $$0 = 0, $$0111 = 0, $$0112 = 0, $$0113 = 0, $$0114128 = 0, $$0114129 = 0, $$0115126 = 0, $$0117 = 0, $$0119 = 0, $$0218$i = 0, $$1 = 0, $$1118 = 0, $$1120 = 0, $$1217$i = 0, $$125 = 0, $$2216$i = 0, $$mask = 0;
 var $$tr5$i$i = 0, $$tr5$i174$i = 0, $$tr5$i180$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0;
 var $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $accumulator$tr$lcssa$i$i = 0, $accumulator$tr$lcssa$i178$i = 0, $accumulator$tr$lcssa$i184$i = 0, $accumulator$tr4$i$i = 0, $accumulator$tr4$i175$i = 0, $accumulator$tr4$i181$i = 0, $exitcond$i = 0, $exitcond219$i = 0, $exitcond220$i = 0, $or$cond = 0, $or$cond$i = 0;
 var $or$cond122 = 0, $or$cond124 = 0, $phitmp = 0, $switch$split152D = 0, $switch$split182D = 0, $switch$split212D = 0, $switch$split242D = 0, $switch$split272D = 0, $switch$split2D = 0, $switch$split302D = 0, $switch$split332D = 0, $switch$split362D = 0, $switch$split392D = 0, $switch$split422D = 0, $switch$split452D = 0, $switch$split482D = 0, $switch$split512D = 0, $switch$split542D = 0, $switch$split572D = 0, $trunc$i = 0;
 var $trunc224$i = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(80|0);
 $vararg_buffer3 = sp + 16|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $7 = sp + 76|0;
 $8 = sp + 72|0;
 $9 = sp + 68|0;
 $10 = sp + 64|0;
 $11 = sp + 60|0;
 $12 = sp + 56|0;
 $13 = sp + 52|0;
 $14 = sp + 48|0;
 $15 = sp + 44|0;
 $16 = sp + 40|0;
 $17 = sp + 24|0;
 $18 = ($2|0)==(0);
 $$mask = $2 & -268435456;
 $19 = ($$mask|0)==(268435456);
 $or$cond122 = $18 | $19;
 L1: do {
  if ($or$cond122) {
   $20 = $2 & 255;
   $21 = ($20|0)==(0);
   if ($21) {
    $22 = (_SDL_SetError(194779,$vararg_buffer)|0);
    $$1 = $22;
    STACKTOP = sp;return ($$1|0);
   } else {
    $212 = $20;
   }
  } else {
   $switch$split2D = ($2|0)<(1431918169);
   L6: do {
    if ($switch$split2D) {
     switch ($2|0) {
     case 844715353:  {
      break;
     }
     default: {
      $212 = 1;
      break L1;
     }
     }
    } else {
     $switch$split302D = ($2|0)<(1498831189);
     if ($switch$split302D) {
      switch ($2|0) {
      case 1431918169:  {
       break L6;
       break;
      }
      default: {
       $212 = 1;
       break L1;
      }
      }
     } else {
      switch ($2|0) {
      case 1498831189:  {
       break L6;
       break;
      }
      default: {
       $212 = 1;
       break L1;
      }
      }
     }
    }
   } while(0);
   $212 = 2;
  }
 } while(0);
 $23 = ((($0)) + 4|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)==($2|0);
 do {
  if (!($25)) {
   $26 = (_SDL_PixelFormatEnumToMasks($2,$7,$8,$9,$10,$11)|0);
   $27 = ($26|0)==(0);
   $28 = HEAP32[$7>>2]|0;
   $29 = ($28|0)<(15);
   $or$cond$i = $27 | $29;
   if ($or$cond$i) {
    $30 = (_SDL_SetError(194807,$vararg_buffer1)|0);
    $phitmp = ($30|0)<(0);
    if ($phitmp) {
     $$1 = -1;
    } else {
     break;
    }
    STACKTOP = sp;return ($$1|0);
   }
   HEAP32[$23>>2] = $2;
   $31 = ((($0)) + 24|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ((($32)) + 3072|0);
   $34 = ((($32)) + 6144|0);
   $$0218$i = 0;
   while(1) {
    $35 = HEAP32[$8>>2]|0;
    $36 = ($35|0)==(0);
    if ($36) {
     $accumulator$tr$lcssa$i$i = 0;
    } else {
     $$tr5$i$i = $35;$accumulator$tr4$i$i = 0;
     while(1) {
      $37 = $$tr5$i$i & 1;
      $38 = $$tr5$i$i >>> 1;
      $$$i$i = (($37) + ($accumulator$tr4$i$i))|0;
      $39 = ($38|0)==(0);
      if ($39) {
       $accumulator$tr$lcssa$i$i = $$$i$i;
       break;
      } else {
       $$tr5$i$i = $38;$accumulator$tr4$i$i = $$$i$i;
      }
     }
    }
    $40 = (8 - ($accumulator$tr$lcssa$i$i))|0;
    $41 = $$0218$i >> $40;
    $42 = (($$0218$i) + 256)|0;
    $43 = (($32) + ($42<<2)|0);
    HEAP32[$43>>2] = $41;
    $44 = HEAP32[$8>>2]|0;
    $45 = (_free_bits_at_bottom($44)|0);
    $46 = $41 << $45;
    HEAP32[$43>>2] = $46;
    $47 = HEAP32[$11>>2]|0;
    $48 = $47 | $46;
    HEAP32[$43>>2] = $48;
    $49 = HEAP32[$9>>2]|0;
    $50 = ($49|0)==(0);
    if ($50) {
     $accumulator$tr$lcssa$i178$i = 0;
    } else {
     $$tr5$i174$i = $49;$accumulator$tr4$i175$i = 0;
     while(1) {
      $51 = $$tr5$i174$i & 1;
      $52 = $$tr5$i174$i >>> 1;
      $$$i176$i = (($51) + ($accumulator$tr4$i175$i))|0;
      $53 = ($52|0)==(0);
      if ($53) {
       $accumulator$tr$lcssa$i178$i = $$$i176$i;
       break;
      } else {
       $$tr5$i174$i = $52;$accumulator$tr4$i175$i = $$$i176$i;
      }
     }
    }
    $54 = (8 - ($accumulator$tr$lcssa$i178$i))|0;
    $55 = $$0218$i >> $54;
    $56 = (($33) + ($42<<2)|0);
    HEAP32[$56>>2] = $55;
    $57 = HEAP32[$9>>2]|0;
    $58 = (_free_bits_at_bottom($57)|0);
    $59 = $55 << $58;
    HEAP32[$56>>2] = $59;
    $60 = HEAP32[$11>>2]|0;
    $61 = $60 | $59;
    HEAP32[$56>>2] = $61;
    $62 = HEAP32[$10>>2]|0;
    $63 = ($62|0)==(0);
    if ($63) {
     $accumulator$tr$lcssa$i184$i = 0;
    } else {
     $$tr5$i180$i = $62;$accumulator$tr4$i181$i = 0;
     while(1) {
      $64 = $$tr5$i180$i & 1;
      $65 = $$tr5$i180$i >>> 1;
      $$$i182$i = (($64) + ($accumulator$tr4$i181$i))|0;
      $66 = ($65|0)==(0);
      if ($66) {
       $accumulator$tr$lcssa$i184$i = $$$i182$i;
       break;
      } else {
       $$tr5$i180$i = $65;$accumulator$tr4$i181$i = $$$i182$i;
      }
     }
    }
    $67 = (8 - ($accumulator$tr$lcssa$i184$i))|0;
    $68 = $$0218$i >> $67;
    $69 = (($34) + ($42<<2)|0);
    HEAP32[$69>>2] = $68;
    $70 = HEAP32[$10>>2]|0;
    $71 = (_free_bits_at_bottom($70)|0);
    $72 = $68 << $71;
    HEAP32[$69>>2] = $72;
    $73 = HEAP32[$11>>2]|0;
    $74 = $73 | $72;
    HEAP32[$69>>2] = $74;
    $75 = (($$0218$i) + 1)|0;
    $exitcond220$i = ($75|0)==(256);
    if ($exitcond220$i) {
     break;
    } else {
     $$0218$i = $75;
    }
   }
   L35: do {
    if ($or$cond122) {
     $82 = $2 & 255;
     $83 = ($82|0)==(2);
     if ($83) {
      $$1217$i = 0;
      label = 21;
     }
    } else {
     $switch$split152D = ($2|0)<(1431918169);
     if ($switch$split152D) {
      switch ($2|0) {
      case 844715353:  {
       $$1217$i = 0;
       label = 21;
       break L35;
       break;
      }
      default: {
       break L35;
      }
      }
     }
     $switch$split332D = ($2|0)<(1498831189);
     if ($switch$split332D) {
      switch ($2|0) {
      case 1431918169:  {
       $$1217$i = 0;
       label = 21;
       break L35;
       break;
      }
      default: {
       break L35;
      }
      }
     } else {
      switch ($2|0) {
      case 1498831189:  {
       $$1217$i = 0;
       label = 21;
       break L35;
       break;
      }
      default: {
       break L35;
      }
      }
     }
    }
   } while(0);
   if ((label|0) == 21) {
    while(1) {
     label = 0;
     $84 = (($$1217$i) + 256)|0;
     $85 = (($32) + ($84<<2)|0);
     $86 = HEAP32[$85>>2]|0;
     $87 = $86 << 16;
     $88 = $87 | $86;
     HEAP32[$85>>2] = $88;
     $89 = (($33) + ($84<<2)|0);
     $90 = HEAP32[$89>>2]|0;
     $91 = $90 << 16;
     $92 = $91 | $90;
     HEAP32[$89>>2] = $92;
     $93 = (($34) + ($84<<2)|0);
     $94 = HEAP32[$93>>2]|0;
     $95 = $94 << 16;
     $96 = $95 | $94;
     HEAP32[$93>>2] = $96;
     $97 = (($$1217$i) + 1)|0;
     $exitcond219$i = ($97|0)==(256);
     if ($exitcond219$i) {
      break;
     } else {
      $$1217$i = $97;
      label = 21;
     }
    }
   }
   $76 = ((($32)) + 1024|0);
   $77 = ((($32)) + 2044|0);
   $78 = ((($32)) + 4096|0);
   $79 = ((($32)) + 5116|0);
   $80 = ((($32)) + 7168|0);
   $81 = ((($32)) + 8188|0);
   $$2216$i = 0;
   while(1) {
    $98 = HEAP32[$76>>2]|0;
    $99 = (($32) + ($$2216$i<<2)|0);
    HEAP32[$99>>2] = $98;
    $100 = HEAP32[$77>>2]|0;
    $101 = (($$2216$i) + 512)|0;
    $102 = (($32) + ($101<<2)|0);
    HEAP32[$102>>2] = $100;
    $103 = HEAP32[$78>>2]|0;
    $104 = (($33) + ($$2216$i<<2)|0);
    HEAP32[$104>>2] = $103;
    $105 = HEAP32[$79>>2]|0;
    $106 = (($33) + ($101<<2)|0);
    HEAP32[$106>>2] = $105;
    $107 = HEAP32[$80>>2]|0;
    $108 = (($34) + ($$2216$i<<2)|0);
    HEAP32[$108>>2] = $107;
    $109 = HEAP32[$81>>2]|0;
    $110 = (($34) + ($101<<2)|0);
    HEAP32[$110>>2] = $109;
    $111 = (($$2216$i) + 1)|0;
    $exitcond$i = ($111|0)==(256);
    if ($exitcond$i) {
     break;
    } else {
     $$2216$i = $111;
    }
   }
   $112 = HEAP32[$0>>2]|0;
   $switch$split182D = ($112|0)<(1431918169);
   L51: do {
    if ($switch$split182D) {
     $switch$split362D = ($112|0)<(844715353);
     if ($switch$split362D) {
      switch ($112|0) {
      case 842094169:  {
       label = 24;
       break L51;
       break;
      }
      default: {
       break L51;
      }
      }
     } else {
      switch ($112|0) {
      case 844715353:  {
       label = 31;
       break L51;
       break;
      }
      default: {
       break L51;
      }
      }
     }
    } else {
     $switch$split392D = ($112|0)<(1448433993);
     if ($switch$split392D) {
      switch ($112|0) {
      case 1431918169:  {
       label = 31;
       break L51;
       break;
      }
      default: {
       break L51;
      }
      }
     }
     $switch$split542D = ($112|0)<(1498831189);
     if ($switch$split542D) {
      switch ($112|0) {
      case 1448433993:  {
       label = 24;
       break L51;
       break;
      }
      default: {
       break L51;
      }
      }
     } else {
      switch ($112|0) {
      case 1498831189:  {
       label = 31;
       break L51;
       break;
      }
      default: {
       break L51;
      }
      }
     }
    }
   } while(0);
   L63: do {
    if ((label|0) == 24) {
     if ($or$cond122) {
      $trunc224$i = $2&255;
      switch ($trunc224$i<<24>>24) {
      case 2:  {
       $113 = ((($0)) + 28|0);
       HEAP32[$113>>2] = 4478;
       $114 = ((($0)) + 32|0);
       HEAP32[$114>>2] = 4479;
       break L63;
       break;
      }
      case 3:  {
       $117 = ((($0)) + 28|0);
       HEAP32[$117>>2] = 4480;
       $118 = ((($0)) + 32|0);
       HEAP32[$118>>2] = 4481;
       break L63;
       break;
      }
      case 4:  {
       $119 = ((($0)) + 28|0);
       HEAP32[$119>>2] = 4482;
       $120 = ((($0)) + 32|0);
       HEAP32[$120>>2] = 4483;
       break L63;
       break;
      }
      default: {
       break L63;
      }
      }
     }
     $switch$split212D = ($2|0)<(1431918169);
     L72: do {
      if ($switch$split212D) {
       switch ($2|0) {
       case 844715353:  {
        break;
       }
       default: {
        break L63;
       }
       }
      } else {
       $switch$split422D = ($2|0)<(1498831189);
       if ($switch$split422D) {
        switch ($2|0) {
        case 1431918169:  {
         break L72;
         break;
        }
        default: {
         break L63;
        }
        }
       } else {
        switch ($2|0) {
        case 1498831189:  {
         break L72;
         break;
        }
        default: {
         break L63;
        }
        }
       }
      }
     } while(0);
     $115 = ((($0)) + 28|0);
     HEAP32[$115>>2] = 4478;
     $116 = ((($0)) + 32|0);
     HEAP32[$116>>2] = 4479;
    }
    else if ((label|0) == 31) {
     if ($or$cond122) {
      $trunc$i = $2&255;
      switch ($trunc$i<<24>>24) {
      case 2:  {
       $121 = ((($0)) + 28|0);
       HEAP32[$121>>2] = 4484;
       $122 = ((($0)) + 32|0);
       HEAP32[$122>>2] = 4485;
       break L63;
       break;
      }
      case 3:  {
       $125 = ((($0)) + 28|0);
       HEAP32[$125>>2] = 4486;
       $126 = ((($0)) + 32|0);
       HEAP32[$126>>2] = 4487;
       break L63;
       break;
      }
      case 4:  {
       $127 = ((($0)) + 28|0);
       HEAP32[$127>>2] = 4488;
       $128 = ((($0)) + 32|0);
       HEAP32[$128>>2] = 4489;
       break L63;
       break;
      }
      default: {
       break L63;
      }
      }
     }
     $switch$split242D = ($2|0)<(1431918169);
     L87: do {
      if ($switch$split242D) {
       switch ($2|0) {
       case 844715353:  {
        break;
       }
       default: {
        break L63;
       }
       }
      } else {
       $switch$split452D = ($2|0)<(1498831189);
       if ($switch$split452D) {
        switch ($2|0) {
        case 1431918169:  {
         break L87;
         break;
        }
        default: {
         break L63;
        }
        }
       } else {
        switch ($2|0) {
        case 1498831189:  {
         break L87;
         break;
        }
        default: {
         break L63;
        }
        }
       }
      }
     } while(0);
     $123 = ((($0)) + 28|0);
     HEAP32[$123>>2] = 4484;
     $124 = ((($0)) + 32|0);
     HEAP32[$124>>2] = 4485;
    }
   } while(0);
   $129 = ((($0)) + 60|0);
   $130 = HEAP32[$129>>2]|0;
   _SDL_FreeSurface($130);
   HEAP32[$129>>2] = 0;
  }
 } while(0);
 $131 = HEAP32[$1>>2]|0;
 $132 = ($131|0)==(0);
 if ($132) {
  $133 = ((($1)) + 4|0);
  $134 = HEAP32[$133>>2]|0;
  $135 = ($134|0)==(0);
  if ($135) {
   $136 = ((($1)) + 8|0);
   $137 = HEAP32[$136>>2]|0;
   $138 = ((($0)) + 8|0);
   $139 = HEAP32[$138>>2]|0;
   $140 = ($137|0)<($139|0);
   if ($140) {
    $$0114129 = 0;
    label = 45;
   } else {
    $141 = ((($1)) + 12|0);
    $142 = HEAP32[$141>>2]|0;
    $143 = ((($0)) + 12|0);
    $144 = HEAP32[$143>>2]|0;
    $145 = ($142|0)<($144|0);
    if ($145) {
     $$0114129 = 0;
     label = 45;
    } else {
     $146 = ($137|0)==($3|0);
     $147 = ($142|0)==($4|0);
     $or$cond = $146 & $147;
     $148 = $137 << 1;
     $149 = ($148|0)==($3|0);
     $150 = $142 << 1;
     $151 = ($150|0)==($4|0);
     $or$cond124 = $149 & $151;
     $$125 = $or$cond124&1;
     if ($or$cond) {
      $$0114128 = 0;$$0115126 = 0;$$1118 = $6;$$1120 = $5;
     } else {
      if ($or$cond124) {
       $$0114128 = $$125;$$0115126 = 0;$$1118 = $6;$$1120 = $5;
      } else {
       $$0114129 = $$125;
       label = 45;
      }
     }
    }
   }
  } else {
   $$0114129 = 0;
   label = 45;
  }
 } else {
  $$0114129 = 0;
  label = 45;
 }
 if ((label|0) == 45) {
  $152 = ((($0)) + 60|0);
  $153 = HEAP32[$152>>2]|0;
  $154 = ($153|0)==(0|0);
  if ($154) {
   (_SDL_PixelFormatEnumToMasks($2,$12,$13,$14,$15,$16)|0);
   $159 = HEAP32[$12>>2]|0;
   $160 = HEAP32[$13>>2]|0;
   $161 = HEAP32[$14>>2]|0;
   $162 = HEAP32[$15>>2]|0;
   $163 = HEAP32[$16>>2]|0;
   $164 = (_SDL_CreateRGBSurfaceFrom($5,$3,$4,$159,$6,$160,$161,$162,$163)|0);
   HEAP32[$152>>2] = $164;
   $165 = ($164|0)==(0|0);
   if ($165) {
    $$0 = 0;$$0117 = $6;$$0119 = $5;
   } else {
    label = 48;
   }
  } else {
   $155 = ((($153)) + 8|0);
   HEAP32[$155>>2] = $3;
   $156 = ((($153)) + 12|0);
   HEAP32[$156>>2] = $4;
   $157 = ((($153)) + 20|0);
   HEAP32[$157>>2] = $5;
   $158 = ((($153)) + 16|0);
   HEAP32[$158>>2] = $6;
   label = 48;
  }
  do {
   if ((label|0) == 48) {
    $166 = ((($0)) + 56|0);
    $167 = HEAP32[$166>>2]|0;
    $168 = ($167|0)==(0|0);
    if ($168) {
     (_SDL_PixelFormatEnumToMasks($2,$12,$13,$14,$15,$16)|0);
     $169 = ((($0)) + 8|0);
     $170 = HEAP32[$169>>2]|0;
     $171 = ((($0)) + 12|0);
     $172 = HEAP32[$171>>2]|0;
     $173 = HEAP32[$12>>2]|0;
     $174 = HEAP32[$13>>2]|0;
     $175 = HEAP32[$14>>2]|0;
     $176 = HEAP32[$15>>2]|0;
     $177 = HEAP32[$16>>2]|0;
     $178 = (_SDL_CreateRGBSurface(0,$170,$172,$173,$174,$175,$176,$177)|0);
     HEAP32[$166>>2] = $178;
     $179 = ($178|0)==(0|0);
     if ($179) {
      $$0 = 0;$$0117 = $6;$$0119 = $5;
      break;
     } else {
      $181 = $178;
     }
    } else {
     $181 = $167;
    }
    $180 = ((($181)) + 20|0);
    $182 = HEAP32[$180>>2]|0;
    $183 = ((($181)) + 16|0);
    $184 = HEAP32[$183>>2]|0;
    $$0 = 1;$$0117 = $184;$$0119 = $182;
   }
  } while(0);
  if ($$0) {
   $$0114128 = $$0114129;$$0115126 = 1;$$1118 = $$0117;$$1120 = $$0119;
  } else {
   $$1 = -1;
   STACKTOP = sp;return ($$1|0);
  }
 }
 $185 = HEAP32[$0>>2]|0;
 $switch$split272D = ($185|0)<(1431918169);
 L115: do {
  if ($switch$split272D) {
   $switch$split482D = ($185|0)<(844715353);
   if ($switch$split482D) {
    switch ($185|0) {
    case 842094169:  {
     break;
    }
    default: {
     label = 58;
     break L115;
    }
    }
    $186 = ((($0)) + 44|0);
    $187 = HEAP32[$186>>2]|0;
    $188 = ((($0)) + 48|0);
    $189 = HEAP32[$188>>2]|0;
    $190 = ((($0)) + 52|0);
    $191 = HEAP32[$190>>2]|0;
    $$0111 = $191;$$0112 = $189;$$0113 = $187;
    break;
   } else {
    switch ($185|0) {
    case 844715353:  {
     break;
    }
    default: {
     label = 58;
     break L115;
    }
    }
    $198 = ((($0)) + 44|0);
    $199 = HEAP32[$198>>2]|0;
    $200 = ((($199)) + 3|0);
    $201 = ((($199)) + 1|0);
    $$0111 = $201;$$0112 = $200;$$0113 = $199;
    break;
   }
  } else {
   $switch$split512D = ($185|0)<(1448433993);
   if ($switch$split512D) {
    switch ($185|0) {
    case 1431918169:  {
     break;
    }
    default: {
     label = 58;
     break L115;
    }
    }
    $206 = ((($0)) + 44|0);
    $207 = HEAP32[$206>>2]|0;
    $208 = ((($207)) + 1|0);
    $209 = ((($207)) + 3|0);
    $$0111 = $209;$$0112 = $208;$$0113 = $207;
    break;
   }
   $switch$split572D = ($185|0)<(1498831189);
   if ($switch$split572D) {
    switch ($185|0) {
    case 1448433993:  {
     break;
    }
    default: {
     label = 58;
     break L115;
    }
    }
    $192 = ((($0)) + 44|0);
    $193 = HEAP32[$192>>2]|0;
    $194 = ((($0)) + 52|0);
    $195 = HEAP32[$194>>2]|0;
    $196 = ((($0)) + 48|0);
    $197 = HEAP32[$196>>2]|0;
    $$0111 = $197;$$0112 = $195;$$0113 = $193;
    break;
   } else {
    switch ($185|0) {
    case 1498831189:  {
     break;
    }
    default: {
     label = 58;
     break L115;
    }
    }
    $202 = ((($0)) + 44|0);
    $203 = HEAP32[$202>>2]|0;
    $204 = ((($203)) + 1|0);
    $205 = ((($203)) + 2|0);
    $$0111 = $203;$$0112 = $205;$$0113 = $204;
    break;
   }
  }
 } while(0);
 if ((label|0) == 58) {
  $210 = (_SDL_SetError(194842,$vararg_buffer3)|0);
  $$1 = $210;
  STACKTOP = sp;return ($$1|0);
 }
 $211 = (($$1118|0) / ($212|0))&-1;
 $213 = ($$0114128|0)==(0);
 $214 = ((($0)) + 8|0);
 $215 = HEAP32[$214>>2]|0;
 $216 = ((($0)) + 12|0);
 $217 = HEAP32[$216>>2]|0;
 $218 = ((($0)) + 20|0);
 $219 = HEAP32[$218>>2]|0;
 $220 = ((($0)) + 24|0);
 $221 = HEAP32[$220>>2]|0;
 if ($213) {
  $226 = (($211) - ($215))|0;
  $227 = ((($0)) + 28|0);
  $228 = HEAP32[$227>>2]|0;
  FUNCTION_TABLE_viiiiiiiii[$228 & 8191]($219,$221,$$0113,$$0112,$$0111,$$1120,$217,$215,$226);
 } else {
  $222 = $215 << 1;
  $223 = (($211) - ($222))|0;
  $224 = ((($0)) + 32|0);
  $225 = HEAP32[$224>>2]|0;
  FUNCTION_TABLE_viiiiiiiii[$225 & 8191]($219,$221,$$0113,$$0112,$$0111,$$1120,$217,$215,$223);
 }
 if (!($$0115126)) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 ;HEAP32[$17>>2]=HEAP32[$1>>2]|0;HEAP32[$17+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$17+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$17+12>>2]=HEAP32[$1+12>>2]|0;
 $229 = ((($0)) + 56|0);
 $230 = HEAP32[$229>>2]|0;
 $231 = ((($0)) + 60|0);
 $232 = HEAP32[$231>>2]|0;
 (_SDL_SoftStretch($230,$17,$232,0)|0);
 $$1 = 0;
 STACKTOP = sp;return ($$1|0);
}
function _SDL_UnlockTexture($0) {
 $0 = $0|0;
 var $$mask$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i = 0, $phitmp$i = 0, $switch$split2D = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $vararg_buffer = sp;
 $1 = sp + 36|0;
 $2 = sp + 32|0;
 $3 = sp + 28|0;
 $4 = sp + 24|0;
 $5 = sp + 8|0;
 $6 = ($0|0)==(0|0);
 if (!($6)) {
  $7 = HEAP32[$0>>2]|0;
  $8 = ($7|0)==(217377|0);
  if ($8) {
   $9 = ((($0)) + 8|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($10|0)==(1);
   if (!($11)) {
    STACKTOP = sp;return;
   }
   $12 = ((($0)) + 40|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = ($13|0)==(0|0);
   $15 = ((($0)) + 36|0);
   $16 = HEAP32[$15>>2]|0;
   if (!($14)) {
    HEAP32[$3>>2] = 0;
    HEAP32[$4>>2] = 0;
    HEAP32[$5>>2] = 0;
    $17 = ((($5)) + 4|0);
    HEAP32[$17>>2] = 0;
    $18 = ((($0)) + 12|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = ((($5)) + 8|0);
    HEAP32[$20>>2] = $19;
    $21 = ((($0)) + 16|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = ((($5)) + 12|0);
    HEAP32[$23>>2] = $22;
    $24 = (_SDL_LockTexture($16,$5,$3,$4)|0);
    $25 = ($24|0)<(0);
    if (!($25)) {
     $26 = HEAP32[$12>>2]|0;
     $27 = ((($16)) + 4|0);
     $28 = HEAP32[$27>>2]|0;
     $29 = HEAP32[$20>>2]|0;
     $30 = HEAP32[$23>>2]|0;
     $31 = HEAP32[$3>>2]|0;
     $32 = HEAP32[$4>>2]|0;
     (_SDL_SW_CopyYUVToRGB($26,$5,$28,$29,$30,$31,$32)|0);
     _SDL_UnlockTexture($16);
    }
    STACKTOP = sp;return;
   }
   $33 = ($16|0)==(0|0);
   if ($33) {
    $64 = ((($0)) + 32|0);
    $65 = HEAP32[$64>>2]|0;
    $66 = ((($65)) + 40|0);
    $67 = HEAP32[$66>>2]|0;
    FUNCTION_TABLE_vii[$67 & 8191]($65,$0);
    STACKTOP = sp;return;
   }
   HEAP32[$1>>2] = 0;
   HEAP32[$2>>2] = 0;
   $34 = ((($0)) + 52|0);
   $35 = ((($0)) + 44|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = ((($0)) + 56|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = ((($0)) + 48|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = Math_imul($40, $38)|0;
   $42 = (($36) + ($41)|0);
   $43 = HEAP32[$34>>2]|0;
   $44 = ((($0)) + 4|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = ($45|0)==(0);
   $$mask$i = $45 & -268435456;
   $47 = ($$mask$i|0)==(268435456);
   $or$cond$i = $46 | $47;
   L18: do {
    if ($or$cond$i) {
     $49 = $45 & 255;
     $53 = $49;
    } else {
     $switch$split2D = ($45|0)<(1498831189);
     if ($switch$split2D) {
      switch ($45|0) {
      case 844715353:  {
       $53 = 2;
       break L18;
       break;
      }
      default: {
      }
      }
     } else {
      switch ($45|0) {
      case 1498831189:  {
       $53 = 2;
       break L18;
       break;
      }
      default: {
      }
      }
     }
     $48 = ($45|0)==(1431918169);
     $phitmp$i = $48 ? 2 : 1;
     $53 = $phitmp$i;
    }
   } while(0);
   $50 = (_SDL_LockTexture($16,$34,$1,$2)|0);
   $51 = ($50|0)<(0);
   if (!($51)) {
    $52 = Math_imul($53, $43)|0;
    $54 = (($42) + ($52)|0);
    $55 = ((($0)) + 60|0);
    $56 = HEAP32[$55>>2]|0;
    $57 = ((($0)) + 64|0);
    $58 = HEAP32[$57>>2]|0;
    $59 = HEAP32[$44>>2]|0;
    $60 = ((($16)) + 4|0);
    $61 = HEAP32[$60>>2]|0;
    $62 = HEAP32[$1>>2]|0;
    $63 = HEAP32[$2>>2]|0;
    (_SDL_ConvertPixels($56,$58,$59,$54,$40,$61,$62,$63)|0);
    _SDL_UnlockTexture($16);
   }
   STACKTOP = sp;return;
  }
 }
 (_SDL_SetError(176589,$vararg_buffer)|0);
 STACKTOP = sp;return;
}
function _free_bits_at_bottom($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ($0|0)==(0);
 if ($1) {
  $$0 = 32;
  return ($$0|0);
 }
 $2 = $0 & 1;
 $3 = ($2|0)==(0);
 if ($3) {
  $4 = $0 >>> 1;
  $5 = (_free_bits_at_bottom($4)|0);
  $6 = (($5) + 1)|0;
  return ($6|0);
 } else {
  $$0 = 0;
  return ($$0|0);
 }
 return (0)|0;
}
function _Color16DitherYV12Mod1X($0,$1,$2,$3,$4,$5,$6,$7,$8) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 $8 = $8|0;
 var $$0101108 = 0, $$0102 = 0, $$0104118 = 0, $$0123 = 0, $$094122 = 0, $$096121 = 0, $$098120 = 0, $$1103107 = 0, $$1105106 = 0, $$1112 = 0, $$195111 = 0, $$197110 = 0, $$199109 = 0, $$in = 0, $$off = 0, $$off127 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $factor = 0, $or$cond = 0, $scevgep = 0, $scevgep134 = 0;
 var $scevgep135 = 0, $scevgep136 = 0, $scevgep138 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $9 = (($7|0) / 2)&-1;
 $factor = $8 << 1;
 $10 = (($factor) + ($7))|0;
 $$off = (($6) + 1)|0;
 $11 = ($$off>>>0)<(3);
 $$off127 = (($7) + 1)|0;
 $12 = ($$off127>>>0)<(3);
 $or$cond = $11 | $12;
 if ($or$cond) {
  return;
 }
 $13 = (($6|0) / 2)&-1;
 $14 = (($5) + ($7<<1)|0);
 $15 = (($14) + ($8<<1)|0);
 $16 = $9 << 1;
 $$0104118 = $15;$$0123 = $2;$$094122 = $3;$$096121 = $4;$$098120 = $5;$$in = $13;
 while(1) {
  $17 = (($$in) + -1)|0;
  $$0102 = (($$0123) + ($7)|0);
  $scevgep = (($$094122) + ($9)|0);
  $scevgep135 = (($$0123) + ($16)|0);
  $18 = (($scevgep135) + ($7)|0);
  $$0101108 = $9;$$1103107 = $$0102;$$1105106 = $$0104118;$$1112 = $$0123;$$195111 = $$094122;$$197110 = $$096121;$$199109 = $$098120;
  while(1) {
   $19 = (($$0101108) + -1)|0;
   $20 = HEAP8[$$195111>>0]|0;
   $21 = $20&255;
   $22 = (($0) + ($21<<2)|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = (($23) + 256)|0;
   $25 = $21 | 256;
   $26 = (($0) + ($25<<2)|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = (($27) + 1024)|0;
   $29 = HEAP8[$$197110>>0]|0;
   $30 = $29&255;
   $31 = $30 | 512;
   $32 = (($0) + ($31<<2)|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = (($28) + ($33))|0;
   $35 = $30 | 768;
   $36 = (($0) + ($35<<2)|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = (($37) + 1792)|0;
   $39 = ((($$195111)) + 1|0);
   $40 = ((($$197110)) + 1|0);
   $41 = ((($$1112)) + 1|0);
   $42 = HEAP8[$$1112>>0]|0;
   $43 = $42&255;
   $44 = (($43) + ($24))|0;
   $45 = (($1) + ($44<<2)|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = (($43) + ($34))|0;
   $48 = (($1) + ($47<<2)|0);
   $49 = HEAP32[$48>>2]|0;
   $50 = $49 | $46;
   $51 = (($43) + ($38))|0;
   $52 = (($1) + ($51<<2)|0);
   $53 = HEAP32[$52>>2]|0;
   $54 = $50 | $53;
   $55 = $54&65535;
   $56 = ((($$199109)) + 2|0);
   HEAP16[$$199109>>1] = $55;
   $57 = ((($$1112)) + 2|0);
   $58 = HEAP8[$41>>0]|0;
   $59 = $58&255;
   $60 = (($59) + ($24))|0;
   $61 = (($1) + ($60<<2)|0);
   $62 = HEAP32[$61>>2]|0;
   $63 = (($59) + ($34))|0;
   $64 = (($1) + ($63<<2)|0);
   $65 = HEAP32[$64>>2]|0;
   $66 = $65 | $62;
   $67 = (($59) + ($38))|0;
   $68 = (($1) + ($67<<2)|0);
   $69 = HEAP32[$68>>2]|0;
   $70 = $66 | $69;
   $71 = $70&65535;
   $72 = ((($$199109)) + 4|0);
   HEAP16[$56>>1] = $71;
   $73 = ((($$1103107)) + 1|0);
   $74 = HEAP8[$$1103107>>0]|0;
   $75 = $74&255;
   $76 = (($75) + ($24))|0;
   $77 = (($1) + ($76<<2)|0);
   $78 = HEAP32[$77>>2]|0;
   $79 = (($75) + ($34))|0;
   $80 = (($1) + ($79<<2)|0);
   $81 = HEAP32[$80>>2]|0;
   $82 = $81 | $78;
   $83 = (($75) + ($38))|0;
   $84 = (($1) + ($83<<2)|0);
   $85 = HEAP32[$84>>2]|0;
   $86 = $82 | $85;
   $87 = $86&65535;
   $88 = ((($$1105106)) + 2|0);
   HEAP16[$$1105106>>1] = $87;
   $89 = ((($$1103107)) + 2|0);
   $90 = HEAP8[$73>>0]|0;
   $91 = $90&255;
   $92 = (($91) + ($24))|0;
   $93 = (($1) + ($92<<2)|0);
   $94 = HEAP32[$93>>2]|0;
   $95 = (($91) + ($34))|0;
   $96 = (($1) + ($95<<2)|0);
   $97 = HEAP32[$96>>2]|0;
   $98 = $97 | $94;
   $99 = (($91) + ($38))|0;
   $100 = (($1) + ($99<<2)|0);
   $101 = HEAP32[$100>>2]|0;
   $102 = $98 | $101;
   $103 = $102&65535;
   $104 = ((($$1105106)) + 4|0);
   HEAP16[$88>>1] = $103;
   $105 = ($19|0)==(0);
   if ($105) {
    break;
   } else {
    $$0101108 = $19;$$1103107 = $89;$$1105106 = $104;$$1112 = $57;$$195111 = $39;$$197110 = $40;$$199109 = $72;
   }
  }
  $scevgep134 = (($$096121) + ($9)|0);
  $scevgep136 = (($$098120) + ($16<<1)|0);
  $scevgep138 = (($$0104118) + ($16<<1)|0);
  $106 = (($scevgep136) + ($10<<1)|0);
  $107 = (($scevgep138) + ($10<<1)|0);
  $108 = ($17|0)==(0);
  if ($108) {
   break;
  } else {
   $$0104118 = $107;$$0123 = $18;$$094122 = $scevgep;$$096121 = $scevgep134;$$098120 = $106;$$in = $17;
  }
 }
 return;
}
function _Color16DitherYV12Mod2X($0,$1,$2,$3,$4,$5,$6,$7,$8) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 $8 = $8|0;
 var $$0108136 = 0, $$0110135 = 0, $$0112134 = 0, $$0115122 = 0, $$0116 = 0, $$0118132 = 0, $$0137 = 0, $$1109125 = 0, $$1111124 = 0, $$1113123 = 0, $$1117121 = 0, $$1119120 = 0, $$1126 = 0, $$in = 0, $$off = 0, $$off141 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0;
 var $scevgep = 0, $scevgep148 = 0, $scevgep149 = 0, $scevgep150 = 0, $scevgep152 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $9 = (($8|0) / 2)&-1;
 $10 = (($9) + ($7))|0;
 $11 = (($7|0) / 2)&-1;
 $12 = ($10*3)|0;
 $13 = (($12) + ($9))|0;
 $$off = (($6) + 1)|0;
 $14 = ($$off>>>0)<(3);
 $$off141 = (($7) + 1)|0;
 $15 = ($$off141>>>0)<(3);
 $or$cond = $14 | $15;
 if ($or$cond) {
  return;
 }
 $16 = (($6|0) / 2)&-1;
 $17 = $10 << 1;
 $18 = (($5) + ($17<<2)|0);
 $19 = $11 << 1;
 $$0108136 = $3;$$0110135 = $4;$$0112134 = $5;$$0118132 = $18;$$0137 = $2;$$in = $16;
 while(1) {
  $20 = (($$in) + -1)|0;
  $$0116 = (($$0137) + ($7)|0);
  $scevgep = (($$0108136) + ($11)|0);
  $scevgep149 = (($$0137) + ($19)|0);
  $21 = (($scevgep149) + ($7)|0);
  $$0115122 = $11;$$1109125 = $$0108136;$$1111124 = $$0110135;$$1113123 = $$0112134;$$1117121 = $$0116;$$1119120 = $$0118132;$$1126 = $$0137;
  while(1) {
   $22 = (($$0115122) + -1)|0;
   $23 = HEAP8[$$1109125>>0]|0;
   $24 = $23&255;
   $25 = (($0) + ($24<<2)|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = (($26) + 256)|0;
   $28 = $24 | 256;
   $29 = (($0) + ($28<<2)|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = (($30) + 1024)|0;
   $32 = HEAP8[$$1111124>>0]|0;
   $33 = $32&255;
   $34 = $33 | 512;
   $35 = (($0) + ($34<<2)|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($31) + ($36))|0;
   $38 = $33 | 768;
   $39 = (($0) + ($38<<2)|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = (($40) + 1792)|0;
   $42 = ((($$1109125)) + 1|0);
   $43 = ((($$1111124)) + 1|0);
   $44 = ((($$1126)) + 1|0);
   $45 = HEAP8[$$1126>>0]|0;
   $46 = $45&255;
   $47 = (($46) + ($27))|0;
   $48 = (($1) + ($47<<2)|0);
   $49 = HEAP32[$48>>2]|0;
   $50 = (($46) + ($37))|0;
   $51 = (($1) + ($50<<2)|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = $52 | $49;
   $54 = (($46) + ($41))|0;
   $55 = (($1) + ($54<<2)|0);
   $56 = HEAP32[$55>>2]|0;
   $57 = $53 | $56;
   $58 = (($$1113123) + ($10<<2)|0);
   HEAP32[$58>>2] = $57;
   HEAP32[$$1113123>>2] = $57;
   $59 = ((($$1113123)) + 4|0);
   $60 = ((($$1126)) + 2|0);
   $61 = HEAP8[$44>>0]|0;
   $62 = $61&255;
   $63 = (($62) + ($27))|0;
   $64 = (($1) + ($63<<2)|0);
   $65 = HEAP32[$64>>2]|0;
   $66 = (($62) + ($37))|0;
   $67 = (($1) + ($66<<2)|0);
   $68 = HEAP32[$67>>2]|0;
   $69 = $68 | $65;
   $70 = (($62) + ($41))|0;
   $71 = (($1) + ($70<<2)|0);
   $72 = HEAP32[$71>>2]|0;
   $73 = $69 | $72;
   $74 = (($59) + ($10<<2)|0);
   HEAP32[$74>>2] = $73;
   HEAP32[$59>>2] = $73;
   $75 = ((($$1113123)) + 8|0);
   $76 = ((($$1117121)) + 1|0);
   $77 = HEAP8[$$1117121>>0]|0;
   $78 = $77&255;
   $79 = (($78) + ($27))|0;
   $80 = (($1) + ($79<<2)|0);
   $81 = HEAP32[$80>>2]|0;
   $82 = (($78) + ($37))|0;
   $83 = (($1) + ($82<<2)|0);
   $84 = HEAP32[$83>>2]|0;
   $85 = $84 | $81;
   $86 = (($78) + ($41))|0;
   $87 = (($1) + ($86<<2)|0);
   $88 = HEAP32[$87>>2]|0;
   $89 = $85 | $88;
   $90 = (($$1119120) + ($10<<2)|0);
   HEAP32[$90>>2] = $89;
   HEAP32[$$1119120>>2] = $89;
   $91 = ((($$1119120)) + 4|0);
   $92 = ((($$1117121)) + 2|0);
   $93 = HEAP8[$76>>0]|0;
   $94 = $93&255;
   $95 = (($94) + ($27))|0;
   $96 = (($1) + ($95<<2)|0);
   $97 = HEAP32[$96>>2]|0;
   $98 = (($94) + ($37))|0;
   $99 = (($1) + ($98<<2)|0);
   $100 = HEAP32[$99>>2]|0;
   $101 = $100 | $97;
   $102 = (($94) + ($41))|0;
   $103 = (($1) + ($102<<2)|0);
   $104 = HEAP32[$103>>2]|0;
   $105 = $101 | $104;
   $106 = (($91) + ($10<<2)|0);
   HEAP32[$106>>2] = $105;
   HEAP32[$91>>2] = $105;
   $107 = ((($$1119120)) + 8|0);
   $108 = ($22|0)==(0);
   if ($108) {
    break;
   } else {
    $$0115122 = $22;$$1109125 = $42;$$1111124 = $43;$$1113123 = $75;$$1117121 = $92;$$1119120 = $107;$$1126 = $60;
   }
  }
  $scevgep148 = (($$0110135) + ($11)|0);
  $scevgep150 = (($$0112134) + ($19<<2)|0);
  $scevgep152 = (($$0118132) + ($19<<2)|0);
  $109 = (($scevgep150) + ($13<<2)|0);
  $110 = (($scevgep152) + ($13<<2)|0);
  $111 = ($20|0)==(0);
  if ($111) {
   break;
  } else {
   $$0108136 = $scevgep;$$0110135 = $scevgep148;$$0112134 = $109;$$0118132 = $110;$$0137 = $21;$$in = $20;
  }
 }
 return;
}
function _Color24DitherYV12Mod1X($0,$1,$2,$3,$4,$5,$6,$7,$8) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 $8 = $8|0;
 var $$0117145 = 0, $$0119144 = 0, $$0121143 = 0, $$0124131 = 0, $$0125 = 0, $$0127141 = 0, $$0146 = 0, $$1$lcssa = 0, $$1118$lcssa = 0, $$1118134 = 0, $$1120$lcssa = 0, $$1120133 = 0, $$1122$lcssa = 0, $$1122132 = 0, $$1126$lcssa = 0, $$1126130 = 0, $$1128$lcssa = 0, $$1128129 = 0, $$1135 = 0, $$in = 0;
 var $$off = 0, $$off150 = 0, $$pn142 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $factor = 0, $scevgep = 0, $scevgep156 = 0, $scevgep157 = 0, $scevgep158 = 0, $scevgep159 = 0, $scevgep160 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $9 = (($7|0) / 2)&-1;
 $factor = $8 << 1;
 $10 = (($factor) + ($7))|0;
 $11 = ($10*3)|0;
 $$off = (($6) + 1)|0;
 $12 = ($$off>>>0)<(3);
 if ($12) {
  return;
 }
 $13 = (($6|0) / 2)&-1;
 $14 = ($7*3)|0;
 $15 = (($5) + ($14)|0);
 $16 = ($8*3)|0;
 $17 = (($15) + ($16)|0);
 $$off150 = (($7) + 1)|0;
 $18 = ($$off150>>>0)<(3);
 $19 = $9 << 1;
 $20 = ($9*6)|0;
 $21 = (($19) + ($7))|0;
 $$0117145 = $3;$$0119144 = $4;$$0121143 = $5;$$0127141 = $17;$$0146 = $2;$$in = $13;$$pn142 = $2;
 while(1) {
  $22 = (($$in) + -1)|0;
  $$0125 = (($$pn142) + ($7)|0);
  if ($18) {
   $$1$lcssa = $$0146;$$1118$lcssa = $$0117145;$$1120$lcssa = $$0119144;$$1122$lcssa = $$0121143;$$1126$lcssa = $$0125;$$1128$lcssa = $$0127141;
  } else {
   $scevgep = (($$0117145) + ($9)|0);
   $scevgep157 = (($$0146) + ($19)|0);
   $scevgep159 = (($$pn142) + ($21)|0);
   $$0124131 = $9;$$1118134 = $$0117145;$$1120133 = $$0119144;$$1122132 = $$0121143;$$1126130 = $$0125;$$1128129 = $$0127141;$$1135 = $$0146;
   while(1) {
    $23 = (($$0124131) + -1)|0;
    $24 = HEAP8[$$1118134>>0]|0;
    $25 = $24&255;
    $26 = (($0) + ($25<<2)|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = (($27) + 256)|0;
    $29 = $25 | 256;
    $30 = (($0) + ($29<<2)|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = (($31) + 1024)|0;
    $33 = HEAP8[$$1120133>>0]|0;
    $34 = $33&255;
    $35 = $34 | 512;
    $36 = (($0) + ($35<<2)|0);
    $37 = HEAP32[$36>>2]|0;
    $38 = (($32) + ($37))|0;
    $39 = $34 | 768;
    $40 = (($0) + ($39<<2)|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = (($41) + 1792)|0;
    $43 = ((($$1118134)) + 1|0);
    $44 = ((($$1120133)) + 1|0);
    $45 = ((($$1135)) + 1|0);
    $46 = HEAP8[$$1135>>0]|0;
    $47 = $46&255;
    $48 = (($47) + ($28))|0;
    $49 = (($1) + ($48<<2)|0);
    $50 = HEAP32[$49>>2]|0;
    $51 = (($47) + ($38))|0;
    $52 = (($1) + ($51<<2)|0);
    $53 = HEAP32[$52>>2]|0;
    $54 = $53 | $50;
    $55 = (($47) + ($42))|0;
    $56 = (($1) + ($55<<2)|0);
    $57 = HEAP32[$56>>2]|0;
    $58 = $54 | $57;
    $59 = $58&255;
    $60 = ((($$1122132)) + 1|0);
    HEAP8[$$1122132>>0] = $59;
    $61 = $58 >>> 8;
    $62 = $61&255;
    $63 = ((($$1122132)) + 2|0);
    HEAP8[$60>>0] = $62;
    $64 = $58 >>> 16;
    $65 = $64&255;
    $66 = ((($$1122132)) + 3|0);
    HEAP8[$63>>0] = $65;
    $67 = ((($$1135)) + 2|0);
    $68 = HEAP8[$45>>0]|0;
    $69 = $68&255;
    $70 = (($69) + ($28))|0;
    $71 = (($1) + ($70<<2)|0);
    $72 = HEAP32[$71>>2]|0;
    $73 = (($69) + ($38))|0;
    $74 = (($1) + ($73<<2)|0);
    $75 = HEAP32[$74>>2]|0;
    $76 = $75 | $72;
    $77 = (($69) + ($42))|0;
    $78 = (($1) + ($77<<2)|0);
    $79 = HEAP32[$78>>2]|0;
    $80 = $76 | $79;
    $81 = $80&255;
    $82 = ((($$1122132)) + 4|0);
    HEAP8[$66>>0] = $81;
    $83 = $80 >>> 8;
    $84 = $83&255;
    $85 = ((($$1122132)) + 5|0);
    HEAP8[$82>>0] = $84;
    $86 = $80 >>> 16;
    $87 = $86&255;
    $88 = ((($$1122132)) + 6|0);
    HEAP8[$85>>0] = $87;
    $89 = ((($$1126130)) + 1|0);
    $90 = HEAP8[$$1126130>>0]|0;
    $91 = $90&255;
    $92 = (($91) + ($28))|0;
    $93 = (($1) + ($92<<2)|0);
    $94 = HEAP32[$93>>2]|0;
    $95 = (($91) + ($38))|0;
    $96 = (($1) + ($95<<2)|0);
    $97 = HEAP32[$96>>2]|0;
    $98 = $97 | $94;
    $99 = (($91) + ($42))|0;
    $100 = (($1) + ($99<<2)|0);
    $101 = HEAP32[$100>>2]|0;
    $102 = $98 | $101;
    $103 = $102&255;
    $104 = ((($$1128129)) + 1|0);
    HEAP8[$$1128129>>0] = $103;
    $105 = $102 >>> 8;
    $106 = $105&255;
    $107 = ((($$1128129)) + 2|0);
    HEAP8[$104>>0] = $106;
    $108 = $102 >>> 16;
    $109 = $108&255;
    $110 = ((($$1128129)) + 3|0);
    HEAP8[$107>>0] = $109;
    $111 = ((($$1126130)) + 2|0);
    $112 = HEAP8[$89>>0]|0;
    $113 = $112&255;
    $114 = (($113) + ($28))|0;
    $115 = (($1) + ($114<<2)|0);
    $116 = HEAP32[$115>>2]|0;
    $117 = (($113) + ($38))|0;
    $118 = (($1) + ($117<<2)|0);
    $119 = HEAP32[$118>>2]|0;
    $120 = $119 | $116;
    $121 = (($113) + ($42))|0;
    $122 = (($1) + ($121<<2)|0);
    $123 = HEAP32[$122>>2]|0;
    $124 = $120 | $123;
    $125 = $124&255;
    $126 = ((($$1128129)) + 4|0);
    HEAP8[$110>>0] = $125;
    $127 = $124 >>> 8;
    $128 = $127&255;
    $129 = ((($$1128129)) + 5|0);
    HEAP8[$126>>0] = $128;
    $130 = $124 >>> 16;
    $131 = $130&255;
    $132 = ((($$1128129)) + 6|0);
    HEAP8[$129>>0] = $131;
    $133 = ($23|0)==(0);
    if ($133) {
     break;
    } else {
     $$0124131 = $23;$$1118134 = $43;$$1120133 = $44;$$1122132 = $88;$$1126130 = $111;$$1128129 = $132;$$1135 = $67;
    }
   }
   $scevgep156 = (($$0119144) + ($9)|0);
   $scevgep158 = (($$0121143) + ($20)|0);
   $scevgep160 = (($$0127141) + ($20)|0);
   $$1$lcssa = $scevgep157;$$1118$lcssa = $scevgep;$$1120$lcssa = $scevgep156;$$1122$lcssa = $scevgep158;$$1126$lcssa = $scevgep159;$$1128$lcssa = $scevgep160;
  }
  $134 = (($$1$lcssa) + ($7)|0);
  $135 = (($$1122$lcssa) + ($11)|0);
  $136 = (($$1128$lcssa) + ($11)|0);
  $137 = ($22|0)==(0);
  if ($137) {
   break;
  } else {
   $$0117145 = $$1118$lcssa;$$0119144 = $$1120$lcssa;$$0121143 = $135;$$0127141 = $136;$$0146 = $134;$$in = $22;$$pn142 = $$1126$lcssa;
  }
 }
 return;
}
function _Color24DitherYV12Mod2X($0,$1,$2,$3,$4,$5,$6,$7,$8) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 $8 = $8|0;
 var $$0182210 = 0, $$0184209 = 0, $$0186208 = 0, $$0189196 = 0, $$0190 = 0, $$0192206 = 0, $$0211 = 0, $$1$lcssa = 0, $$1183$lcssa = 0, $$1183199 = 0, $$1185$lcssa = 0, $$1185198 = 0, $$1187$lcssa = 0, $$1187197 = 0, $$1191$lcssa = 0, $$1191195 = 0, $$1193$lcssa = 0, $$1193194 = 0, $$1200 = 0, $$in = 0;
 var $$off = 0, $$off215 = 0, $$pn207 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $scevgep = 0, $scevgep221 = 0, $scevgep222 = 0, $scevgep223 = 0, $scevgep224 = 0;
 var $scevgep225 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $9 = $7 << 1;
 $10 = (($9) + ($8))|0;
 $11 = ($10*3)|0;
 $12 = (($7|0) / 2)&-1;
 $13 = ($10*9)|0;
 $14 = ($8*3)|0;
 $15 = (($13) + ($14))|0;
 $$off = (($6) + 1)|0;
 $16 = ($$off>>>0)<(3);
 if ($16) {
  return;
 }
 $17 = (($6|0) / 2)&-1;
 $18 = ($10*6)|0;
 $19 = (($5) + ($18)|0);
 $$off215 = (($7) + 1)|0;
 $20 = ($$off215>>>0)<(3);
 $21 = (($11) + 3)|0;
 $22 = (($11) + 4)|0;
 $23 = (($11) + 1)|0;
 $24 = (($11) + 5)|0;
 $25 = (($11) + 2)|0;
 $26 = $12 << 1;
 $27 = ($12*12)|0;
 $28 = (($26) + ($7))|0;
 $$0182210 = $3;$$0184209 = $4;$$0186208 = $5;$$0192206 = $19;$$0211 = $2;$$in = $17;$$pn207 = $2;
 while(1) {
  $29 = (($$in) + -1)|0;
  $$0190 = (($$pn207) + ($7)|0);
  if ($20) {
   $$1$lcssa = $$0211;$$1183$lcssa = $$0182210;$$1185$lcssa = $$0184209;$$1187$lcssa = $$0186208;$$1191$lcssa = $$0190;$$1193$lcssa = $$0192206;
  } else {
   $scevgep = (($$0182210) + ($12)|0);
   $scevgep222 = (($$0211) + ($26)|0);
   $scevgep224 = (($$pn207) + ($28)|0);
   $$0189196 = $12;$$1183199 = $$0182210;$$1185198 = $$0184209;$$1187197 = $$0186208;$$1191195 = $$0190;$$1193194 = $$0192206;$$1200 = $$0211;
   while(1) {
    $30 = (($$0189196) + -1)|0;
    $31 = HEAP8[$$1183199>>0]|0;
    $32 = $31&255;
    $33 = (($0) + ($32<<2)|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = (($34) + 256)|0;
    $36 = $32 | 256;
    $37 = (($0) + ($36<<2)|0);
    $38 = HEAP32[$37>>2]|0;
    $39 = (($38) + 1024)|0;
    $40 = HEAP8[$$1185198>>0]|0;
    $41 = $40&255;
    $42 = $41 | 512;
    $43 = (($0) + ($42<<2)|0);
    $44 = HEAP32[$43>>2]|0;
    $45 = (($39) + ($44))|0;
    $46 = $41 | 768;
    $47 = (($0) + ($46<<2)|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = (($48) + 1792)|0;
    $50 = ((($$1183199)) + 1|0);
    $51 = ((($$1185198)) + 1|0);
    $52 = ((($$1200)) + 1|0);
    $53 = HEAP8[$$1200>>0]|0;
    $54 = $53&255;
    $55 = (($54) + ($35))|0;
    $56 = (($1) + ($55<<2)|0);
    $57 = HEAP32[$56>>2]|0;
    $58 = (($54) + ($45))|0;
    $59 = (($1) + ($58<<2)|0);
    $60 = HEAP32[$59>>2]|0;
    $61 = $60 | $57;
    $62 = (($54) + ($49))|0;
    $63 = (($1) + ($62<<2)|0);
    $64 = HEAP32[$63>>2]|0;
    $65 = $61 | $64;
    $66 = $65&255;
    $67 = (($$1187197) + ($21)|0);
    HEAP8[$67>>0] = $66;
    $68 = (($$1187197) + ($11)|0);
    HEAP8[$68>>0] = $66;
    $69 = ((($$1187197)) + 3|0);
    HEAP8[$69>>0] = $66;
    HEAP8[$$1187197>>0] = $66;
    $70 = $65 >>> 8;
    $71 = $70&255;
    $72 = (($$1187197) + ($22)|0);
    HEAP8[$72>>0] = $71;
    $73 = (($$1187197) + ($23)|0);
    HEAP8[$73>>0] = $71;
    $74 = ((($$1187197)) + 4|0);
    HEAP8[$74>>0] = $71;
    $75 = ((($$1187197)) + 1|0);
    HEAP8[$75>>0] = $71;
    $76 = $65 >>> 16;
    $77 = $76&255;
    $78 = (($$1187197) + ($24)|0);
    HEAP8[$78>>0] = $77;
    $79 = (($$1187197) + ($25)|0);
    HEAP8[$79>>0] = $77;
    $80 = ((($$1187197)) + 5|0);
    HEAP8[$80>>0] = $77;
    $81 = ((($$1187197)) + 2|0);
    HEAP8[$81>>0] = $77;
    $82 = ((($$1187197)) + 6|0);
    $83 = ((($$1200)) + 2|0);
    $84 = HEAP8[$52>>0]|0;
    $85 = $84&255;
    $86 = (($85) + ($35))|0;
    $87 = (($1) + ($86<<2)|0);
    $88 = HEAP32[$87>>2]|0;
    $89 = (($85) + ($45))|0;
    $90 = (($1) + ($89<<2)|0);
    $91 = HEAP32[$90>>2]|0;
    $92 = $91 | $88;
    $93 = (($85) + ($49))|0;
    $94 = (($1) + ($93<<2)|0);
    $95 = HEAP32[$94>>2]|0;
    $96 = $92 | $95;
    $97 = $96&255;
    $98 = (($82) + ($21)|0);
    HEAP8[$98>>0] = $97;
    $99 = (($82) + ($11)|0);
    HEAP8[$99>>0] = $97;
    $100 = ((($$1187197)) + 9|0);
    HEAP8[$100>>0] = $97;
    HEAP8[$82>>0] = $97;
    $101 = $96 >>> 8;
    $102 = $101&255;
    $103 = (($82) + ($22)|0);
    HEAP8[$103>>0] = $102;
    $104 = (($82) + ($23)|0);
    HEAP8[$104>>0] = $102;
    $105 = ((($$1187197)) + 10|0);
    HEAP8[$105>>0] = $102;
    $106 = ((($$1187197)) + 7|0);
    HEAP8[$106>>0] = $102;
    $107 = $96 >>> 16;
    $108 = $107&255;
    $109 = (($82) + ($24)|0);
    HEAP8[$109>>0] = $108;
    $110 = (($82) + ($25)|0);
    HEAP8[$110>>0] = $108;
    $111 = ((($$1187197)) + 11|0);
    HEAP8[$111>>0] = $108;
    $112 = ((($$1187197)) + 8|0);
    HEAP8[$112>>0] = $108;
    $113 = ((($$1187197)) + 12|0);
    $114 = ((($$1191195)) + 1|0);
    $115 = HEAP8[$$1191195>>0]|0;
    $116 = $115&255;
    $117 = (($116) + ($35))|0;
    $118 = (($1) + ($117<<2)|0);
    $119 = HEAP32[$118>>2]|0;
    $120 = (($116) + ($45))|0;
    $121 = (($1) + ($120<<2)|0);
    $122 = HEAP32[$121>>2]|0;
    $123 = $122 | $119;
    $124 = (($116) + ($49))|0;
    $125 = (($1) + ($124<<2)|0);
    $126 = HEAP32[$125>>2]|0;
    $127 = $123 | $126;
    $128 = $127&255;
    $129 = (($$1193194) + ($21)|0);
    HEAP8[$129>>0] = $128;
    $130 = (($$1193194) + ($11)|0);
    HEAP8[$130>>0] = $128;
    $131 = ((($$1193194)) + 3|0);
    HEAP8[$131>>0] = $128;
    HEAP8[$$1193194>>0] = $128;
    $132 = $127 >>> 8;
    $133 = $132&255;
    $134 = (($$1193194) + ($22)|0);
    HEAP8[$134>>0] = $133;
    $135 = (($$1193194) + ($23)|0);
    HEAP8[$135>>0] = $133;
    $136 = ((($$1193194)) + 4|0);
    HEAP8[$136>>0] = $133;
    $137 = ((($$1193194)) + 1|0);
    HEAP8[$137>>0] = $133;
    $138 = $127 >>> 16;
    $139 = $138&255;
    $140 = (($$1193194) + ($24)|0);
    HEAP8[$140>>0] = $139;
    $141 = (($$1193194) + ($25)|0);
    HEAP8[$141>>0] = $139;
    $142 = ((($$1193194)) + 5|0);
    HEAP8[$142>>0] = $139;
    $143 = ((($$1193194)) + 2|0);
    HEAP8[$143>>0] = $139;
    $144 = ((($$1193194)) + 6|0);
    $145 = ((($$1191195)) + 2|0);
    $146 = HEAP8[$114>>0]|0;
    $147 = $146&255;
    $148 = (($147) + ($35))|0;
    $149 = (($1) + ($148<<2)|0);
    $150 = HEAP32[$149>>2]|0;
    $151 = (($147) + ($45))|0;
    $152 = (($1) + ($151<<2)|0);
    $153 = HEAP32[$152>>2]|0;
    $154 = $153 | $150;
    $155 = (($147) + ($49))|0;
    $156 = (($1) + ($155<<2)|0);
    $157 = HEAP32[$156>>2]|0;
    $158 = $154 | $157;
    $159 = $158&255;
    $160 = (($144) + ($21)|0);
    HEAP8[$160>>0] = $159;
    $161 = (($144) + ($11)|0);
    HEAP8[$161>>0] = $159;
    $162 = ((($$1193194)) + 9|0);
    HEAP8[$162>>0] = $159;
    HEAP8[$144>>0] = $159;
    $163 = $158 >>> 8;
    $164 = $163&255;
    $165 = (($144) + ($22)|0);
    HEAP8[$165>>0] = $164;
    $166 = (($144) + ($23)|0);
    HEAP8[$166>>0] = $164;
    $167 = ((($$1193194)) + 10|0);
    HEAP8[$167>>0] = $164;
    $168 = ((($$1193194)) + 7|0);
    HEAP8[$168>>0] = $164;
    $169 = $158 >>> 16;
    $170 = $169&255;
    $171 = (($144) + ($24)|0);
    HEAP8[$171>>0] = $170;
    $172 = (($144) + ($25)|0);
    HEAP8[$172>>0] = $170;
    $173 = ((($$1193194)) + 11|0);
    HEAP8[$173>>0] = $170;
    $174 = ((($$1193194)) + 8|0);
    HEAP8[$174>>0] = $170;
    $175 = ((($$1193194)) + 12|0);
    $176 = ($30|0)==(0);
    if ($176) {
     break;
    } else {
     $$0189196 = $30;$$1183199 = $50;$$1185198 = $51;$$1187197 = $113;$$1191195 = $145;$$1193194 = $175;$$1200 = $83;
    }
   }
   $scevgep221 = (($$0184209) + ($12)|0);
   $scevgep223 = (($$0186208) + ($27)|0);
   $scevgep225 = (($$0192206) + ($27)|0);
   $$1$lcssa = $scevgep222;$$1183$lcssa = $scevgep;$$1185$lcssa = $scevgep221;$$1187$lcssa = $scevgep223;$$1191$lcssa = $scevgep224;$$1193$lcssa = $scevgep225;
  }
  $177 = (($$1$lcssa) + ($7)|0);
  $178 = (($$1187$lcssa) + ($15)|0);
  $179 = (($$1193$lcssa) + ($15)|0);
  $180 = ($29|0)==(0);
  if ($180) {
   break;
  } else {
   $$0182210 = $$1183$lcssa;$$0184209 = $$1185$lcssa;$$0186208 = $178;$$0192206 = $179;$$0211 = $177;$$in = $29;$$pn207 = $$1191$lcssa;
  }
 }
 return;
}
function _Color32DitherYV12Mod1X($0,$1,$2,$3,$4,$5,$6,$7,$8) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 $8 = $8|0;
 var $$0101108 = 0, $$0102 = 0, $$0104118 = 0, $$0123 = 0, $$094122 = 0, $$096121 = 0, $$098120 = 0, $$1103107 = 0, $$1105106 = 0, $$1112 = 0, $$195111 = 0, $$197110 = 0, $$199109 = 0, $$in = 0, $$off = 0, $$off127 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $factor = 0, $or$cond = 0, $scevgep = 0, $scevgep134 = 0, $scevgep135 = 0, $scevgep136 = 0, $scevgep138 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $9 = (($7|0) / 2)&-1;
 $factor = $8 << 1;
 $10 = (($factor) + ($7))|0;
 $$off = (($6) + 1)|0;
 $11 = ($$off>>>0)<(3);
 $$off127 = (($7) + 1)|0;
 $12 = ($$off127>>>0)<(3);
 $or$cond = $11 | $12;
 if ($or$cond) {
  return;
 }
 $13 = (($6|0) / 2)&-1;
 $14 = (($5) + ($7<<2)|0);
 $15 = (($14) + ($8<<2)|0);
 $16 = $9 << 1;
 $$0104118 = $15;$$0123 = $2;$$094122 = $3;$$096121 = $4;$$098120 = $5;$$in = $13;
 while(1) {
  $17 = (($$in) + -1)|0;
  $$0102 = (($$0123) + ($7)|0);
  $scevgep = (($$094122) + ($9)|0);
  $scevgep135 = (($$0123) + ($16)|0);
  $18 = (($scevgep135) + ($7)|0);
  $$0101108 = $9;$$1103107 = $$0102;$$1105106 = $$0104118;$$1112 = $$0123;$$195111 = $$094122;$$197110 = $$096121;$$199109 = $$098120;
  while(1) {
   $19 = (($$0101108) + -1)|0;
   $20 = HEAP8[$$195111>>0]|0;
   $21 = $20&255;
   $22 = (($0) + ($21<<2)|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = (($23) + 256)|0;
   $25 = $21 | 256;
   $26 = (($0) + ($25<<2)|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = (($27) + 1024)|0;
   $29 = HEAP8[$$197110>>0]|0;
   $30 = $29&255;
   $31 = $30 | 512;
   $32 = (($0) + ($31<<2)|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = (($28) + ($33))|0;
   $35 = $30 | 768;
   $36 = (($0) + ($35<<2)|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = (($37) + 1792)|0;
   $39 = ((($$195111)) + 1|0);
   $40 = ((($$197110)) + 1|0);
   $41 = ((($$1112)) + 1|0);
   $42 = HEAP8[$$1112>>0]|0;
   $43 = $42&255;
   $44 = (($43) + ($24))|0;
   $45 = (($1) + ($44<<2)|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = (($43) + ($34))|0;
   $48 = (($1) + ($47<<2)|0);
   $49 = HEAP32[$48>>2]|0;
   $50 = $49 | $46;
   $51 = (($43) + ($38))|0;
   $52 = (($1) + ($51<<2)|0);
   $53 = HEAP32[$52>>2]|0;
   $54 = $50 | $53;
   $55 = ((($$199109)) + 4|0);
   HEAP32[$$199109>>2] = $54;
   $56 = ((($$1112)) + 2|0);
   $57 = HEAP8[$41>>0]|0;
   $58 = $57&255;
   $59 = (($58) + ($24))|0;
   $60 = (($1) + ($59<<2)|0);
   $61 = HEAP32[$60>>2]|0;
   $62 = (($58) + ($34))|0;
   $63 = (($1) + ($62<<2)|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = $64 | $61;
   $66 = (($58) + ($38))|0;
   $67 = (($1) + ($66<<2)|0);
   $68 = HEAP32[$67>>2]|0;
   $69 = $65 | $68;
   $70 = ((($$199109)) + 8|0);
   HEAP32[$55>>2] = $69;
   $71 = ((($$1103107)) + 1|0);
   $72 = HEAP8[$$1103107>>0]|0;
   $73 = $72&255;
   $74 = (($73) + ($24))|0;
   $75 = (($1) + ($74<<2)|0);
   $76 = HEAP32[$75>>2]|0;
   $77 = (($73) + ($34))|0;
   $78 = (($1) + ($77<<2)|0);
   $79 = HEAP32[$78>>2]|0;
   $80 = $79 | $76;
   $81 = (($73) + ($38))|0;
   $82 = (($1) + ($81<<2)|0);
   $83 = HEAP32[$82>>2]|0;
   $84 = $80 | $83;
   $85 = ((($$1105106)) + 4|0);
   HEAP32[$$1105106>>2] = $84;
   $86 = ((($$1103107)) + 2|0);
   $87 = HEAP8[$71>>0]|0;
   $88 = $87&255;
   $89 = (($88) + ($24))|0;
   $90 = (($1) + ($89<<2)|0);
   $91 = HEAP32[$90>>2]|0;
   $92 = (($88) + ($34))|0;
   $93 = (($1) + ($92<<2)|0);
   $94 = HEAP32[$93>>2]|0;
   $95 = $94 | $91;
   $96 = (($88) + ($38))|0;
   $97 = (($1) + ($96<<2)|0);
   $98 = HEAP32[$97>>2]|0;
   $99 = $95 | $98;
   $100 = ((($$1105106)) + 8|0);
   HEAP32[$85>>2] = $99;
   $101 = ($19|0)==(0);
   if ($101) {
    break;
   } else {
    $$0101108 = $19;$$1103107 = $86;$$1105106 = $100;$$1112 = $56;$$195111 = $39;$$197110 = $40;$$199109 = $70;
   }
  }
  $scevgep134 = (($$096121) + ($9)|0);
  $scevgep136 = (($$098120) + ($16<<2)|0);
  $scevgep138 = (($$0104118) + ($16<<2)|0);
  $102 = (($scevgep136) + ($10<<2)|0);
  $103 = (($scevgep138) + ($10<<2)|0);
  $104 = ($17|0)==(0);
  if ($104) {
   break;
  } else {
   $$0104118 = $103;$$0123 = $18;$$094122 = $scevgep;$$096121 = $scevgep134;$$098120 = $102;$$in = $17;
  }
 }
 return;
}
function _Color32DitherYV12Mod2X($0,$1,$2,$3,$4,$5,$6,$7,$8) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 $8 = $8|0;
 var $$0120148 = 0, $$0122147 = 0, $$0124146 = 0, $$0127134 = 0, $$0128 = 0, $$0130144 = 0, $$0149 = 0, $$1$lcssa = 0, $$1121$lcssa = 0, $$1121137 = 0, $$1123$lcssa = 0, $$1123136 = 0, $$1125$lcssa = 0, $$1125135 = 0, $$1129$lcssa = 0, $$1129133 = 0, $$1131$lcssa = 0, $$1131132 = 0, $$1138 = 0, $$in = 0;
 var $$off = 0, $$off153 = 0, $$pn145 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $scevgep = 0, $scevgep159 = 0, $scevgep160 = 0;
 var $scevgep161 = 0, $scevgep162 = 0, $scevgep163 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $9 = $7 << 1;
 $10 = (($9) + ($8))|0;
 $11 = (($7|0) / 2)&-1;
 $12 = ($10*3)|0;
 $13 = (($12) + ($8))|0;
 $$off = (($6) + 1)|0;
 $14 = ($$off>>>0)<(3);
 if ($14) {
  return;
 }
 $15 = (($6|0) / 2)&-1;
 $16 = $10 << 1;
 $17 = (($5) + ($16<<2)|0);
 $$off153 = (($7) + 1)|0;
 $18 = ($$off153>>>0)<(3);
 $19 = (($10) + 1)|0;
 $20 = $11 << 1;
 $21 = $11 << 2;
 $22 = (($20) + ($7))|0;
 $$0120148 = $3;$$0122147 = $4;$$0124146 = $5;$$0130144 = $17;$$0149 = $2;$$in = $15;$$pn145 = $2;
 while(1) {
  $23 = (($$in) + -1)|0;
  $$0128 = (($$pn145) + ($7)|0);
  if ($18) {
   $$1$lcssa = $$0149;$$1121$lcssa = $$0120148;$$1123$lcssa = $$0122147;$$1125$lcssa = $$0124146;$$1129$lcssa = $$0128;$$1131$lcssa = $$0130144;
  } else {
   $scevgep = (($$0120148) + ($11)|0);
   $scevgep160 = (($$0149) + ($20)|0);
   $scevgep162 = (($$pn145) + ($22)|0);
   $$0127134 = $11;$$1121137 = $$0120148;$$1123136 = $$0122147;$$1125135 = $$0124146;$$1129133 = $$0128;$$1131132 = $$0130144;$$1138 = $$0149;
   while(1) {
    $24 = (($$0127134) + -1)|0;
    $25 = HEAP8[$$1121137>>0]|0;
    $26 = $25&255;
    $27 = (($0) + ($26<<2)|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = (($28) + 256)|0;
    $30 = $26 | 256;
    $31 = (($0) + ($30<<2)|0);
    $32 = HEAP32[$31>>2]|0;
    $33 = (($32) + 1024)|0;
    $34 = HEAP8[$$1123136>>0]|0;
    $35 = $34&255;
    $36 = $35 | 512;
    $37 = (($0) + ($36<<2)|0);
    $38 = HEAP32[$37>>2]|0;
    $39 = (($33) + ($38))|0;
    $40 = $35 | 768;
    $41 = (($0) + ($40<<2)|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = (($42) + 1792)|0;
    $44 = ((($$1121137)) + 1|0);
    $45 = ((($$1123136)) + 1|0);
    $46 = ((($$1138)) + 1|0);
    $47 = HEAP8[$$1138>>0]|0;
    $48 = $47&255;
    $49 = (($48) + ($29))|0;
    $50 = (($1) + ($49<<2)|0);
    $51 = HEAP32[$50>>2]|0;
    $52 = (($48) + ($39))|0;
    $53 = (($1) + ($52<<2)|0);
    $54 = HEAP32[$53>>2]|0;
    $55 = $54 | $51;
    $56 = (($48) + ($43))|0;
    $57 = (($1) + ($56<<2)|0);
    $58 = HEAP32[$57>>2]|0;
    $59 = $55 | $58;
    $60 = (($$1125135) + ($19<<2)|0);
    HEAP32[$60>>2] = $59;
    $61 = (($$1125135) + ($10<<2)|0);
    HEAP32[$61>>2] = $59;
    $62 = ((($$1125135)) + 4|0);
    HEAP32[$62>>2] = $59;
    HEAP32[$$1125135>>2] = $59;
    $63 = ((($$1125135)) + 8|0);
    $64 = ((($$1138)) + 2|0);
    $65 = HEAP8[$46>>0]|0;
    $66 = $65&255;
    $67 = (($66) + ($29))|0;
    $68 = (($1) + ($67<<2)|0);
    $69 = HEAP32[$68>>2]|0;
    $70 = (($66) + ($39))|0;
    $71 = (($1) + ($70<<2)|0);
    $72 = HEAP32[$71>>2]|0;
    $73 = $72 | $69;
    $74 = (($66) + ($43))|0;
    $75 = (($1) + ($74<<2)|0);
    $76 = HEAP32[$75>>2]|0;
    $77 = $73 | $76;
    $78 = (($63) + ($19<<2)|0);
    HEAP32[$78>>2] = $77;
    $79 = (($63) + ($10<<2)|0);
    HEAP32[$79>>2] = $77;
    $80 = ((($$1125135)) + 12|0);
    HEAP32[$80>>2] = $77;
    HEAP32[$63>>2] = $77;
    $81 = ((($$1125135)) + 16|0);
    $82 = ((($$1129133)) + 1|0);
    $83 = HEAP8[$$1129133>>0]|0;
    $84 = $83&255;
    $85 = (($84) + ($29))|0;
    $86 = (($1) + ($85<<2)|0);
    $87 = HEAP32[$86>>2]|0;
    $88 = (($84) + ($39))|0;
    $89 = (($1) + ($88<<2)|0);
    $90 = HEAP32[$89>>2]|0;
    $91 = $90 | $87;
    $92 = (($84) + ($43))|0;
    $93 = (($1) + ($92<<2)|0);
    $94 = HEAP32[$93>>2]|0;
    $95 = $91 | $94;
    $96 = (($$1131132) + ($19<<2)|0);
    HEAP32[$96>>2] = $95;
    $97 = (($$1131132) + ($10<<2)|0);
    HEAP32[$97>>2] = $95;
    $98 = ((($$1131132)) + 4|0);
    HEAP32[$98>>2] = $95;
    HEAP32[$$1131132>>2] = $95;
    $99 = ((($$1131132)) + 8|0);
    $100 = ((($$1129133)) + 2|0);
    $101 = HEAP8[$82>>0]|0;
    $102 = $101&255;
    $103 = (($102) + ($29))|0;
    $104 = (($1) + ($103<<2)|0);
    $105 = HEAP32[$104>>2]|0;
    $106 = (($102) + ($39))|0;
    $107 = (($1) + ($106<<2)|0);
    $108 = HEAP32[$107>>2]|0;
    $109 = $108 | $105;
    $110 = (($102) + ($43))|0;
    $111 = (($1) + ($110<<2)|0);
    $112 = HEAP32[$111>>2]|0;
    $113 = $109 | $112;
    $114 = (($99) + ($19<<2)|0);
    HEAP32[$114>>2] = $113;
    $115 = (($99) + ($10<<2)|0);
    HEAP32[$115>>2] = $113;
    $116 = ((($$1131132)) + 12|0);
    HEAP32[$116>>2] = $113;
    HEAP32[$99>>2] = $113;
    $117 = ((($$1131132)) + 16|0);
    $118 = ($24|0)==(0);
    if ($118) {
     break;
    } else {
     $$0127134 = $24;$$1121137 = $44;$$1123136 = $45;$$1125135 = $81;$$1129133 = $100;$$1131132 = $117;$$1138 = $64;
    }
   }
   $scevgep159 = (($$0122147) + ($11)|0);
   $scevgep161 = (($$0124146) + ($21<<2)|0);
   $scevgep163 = (($$0130144) + ($21<<2)|0);
   $$1$lcssa = $scevgep160;$$1121$lcssa = $scevgep;$$1123$lcssa = $scevgep159;$$1125$lcssa = $scevgep161;$$1129$lcssa = $scevgep162;$$1131$lcssa = $scevgep163;
  }
  $119 = (($$1$lcssa) + ($7)|0);
  $120 = (($$1125$lcssa) + ($13<<2)|0);
  $121 = (($$1131$lcssa) + ($13<<2)|0);
  $122 = ($23|0)==(0);
  if ($122) {
   break;
  } else {
   $$0120148 = $$1121$lcssa;$$0122147 = $$1123$lcssa;$$0124146 = $120;$$0130144 = $121;$$0149 = $119;$$in = $23;$$pn145 = $$1129$lcssa;
  }
 }
 return;
}
function _Color16DitherYUY2Mod1X($0,$1,$2,$3,$4,$5,$6,$7,$8) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 $8 = $8|0;
 var $$05674 = 0, $$05873 = 0, $$06072 = 0, $$06264 = 0, $$075 = 0, $$15767 = 0, $$15966 = 0, $$16165 = 0, $$168 = 0, $$in = 0, $$off = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $9 = 0, $or$cond = 0, $scevgep = 0, $scevgep81 = 0, $scevgep82 = 0, $scevgep83 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $9 = (($7|0) / 2)&-1;
 $10 = ($6|0)==(0);
 $$off = (($7) + 1)|0;
 $11 = ($$off>>>0)<(3);
 $or$cond = $10 | $11;
 if ($or$cond) {
  return;
 }
 $12 = $9 << 2;
 $13 = $9 << 1;
 $$05674 = $3;$$05873 = $4;$$06072 = $5;$$075 = $2;$$in = $6;
 while(1) {
  $14 = (($$in) + -1)|0;
  $scevgep = (($$05674) + ($12)|0);
  $scevgep82 = (($$075) + ($12)|0);
  $$06264 = $9;$$15767 = $$05674;$$15966 = $$05873;$$16165 = $$06072;$$168 = $$075;
  while(1) {
   $15 = (($$06264) + -1)|0;
   $16 = HEAP8[$$15767>>0]|0;
   $17 = $16&255;
   $18 = (($0) + ($17<<2)|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($19) + 256)|0;
   $21 = $17 | 256;
   $22 = (($0) + ($21<<2)|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = (($23) + 1024)|0;
   $25 = HEAP8[$$15966>>0]|0;
   $26 = $25&255;
   $27 = $26 | 512;
   $28 = (($0) + ($27<<2)|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = (($24) + ($29))|0;
   $31 = $26 | 768;
   $32 = (($0) + ($31<<2)|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = (($33) + 1792)|0;
   $35 = ((($$15767)) + 4|0);
   $36 = ((($$15966)) + 4|0);
   $37 = HEAP8[$$168>>0]|0;
   $38 = $37&255;
   $39 = ((($$168)) + 2|0);
   $40 = (($38) + ($20))|0;
   $41 = (($1) + ($40<<2)|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = (($38) + ($30))|0;
   $44 = (($1) + ($43<<2)|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = $45 | $42;
   $47 = (($38) + ($34))|0;
   $48 = (($1) + ($47<<2)|0);
   $49 = HEAP32[$48>>2]|0;
   $50 = $46 | $49;
   $51 = $50&65535;
   $52 = ((($$16165)) + 2|0);
   HEAP16[$$16165>>1] = $51;
   $53 = HEAP8[$39>>0]|0;
   $54 = $53&255;
   $55 = ((($$168)) + 4|0);
   $56 = (($54) + ($20))|0;
   $57 = (($1) + ($56<<2)|0);
   $58 = HEAP32[$57>>2]|0;
   $59 = (($54) + ($30))|0;
   $60 = (($1) + ($59<<2)|0);
   $61 = HEAP32[$60>>2]|0;
   $62 = $61 | $58;
   $63 = (($54) + ($34))|0;
   $64 = (($1) + ($63<<2)|0);
   $65 = HEAP32[$64>>2]|0;
   $66 = $62 | $65;
   $67 = $66&65535;
   $68 = ((($$16165)) + 4|0);
   HEAP16[$52>>1] = $67;
   $69 = ($15|0)==(0);
   if ($69) {
    break;
   } else {
    $$06264 = $15;$$15767 = $35;$$15966 = $36;$$16165 = $68;$$168 = $55;
   }
  }
  $scevgep81 = (($$05873) + ($12)|0);
  $scevgep83 = (($$06072) + ($13<<1)|0);
  $70 = (($scevgep83) + ($8<<1)|0);
  $71 = ($14|0)==(0);
  if ($71) {
   break;
  } else {
   $$05674 = $scevgep;$$05873 = $scevgep81;$$06072 = $70;$$075 = $scevgep82;$$in = $14;
  }
 }
 return;
}
function _Color16DitherYUY2Mod2X($0,$1,$2,$3,$4,$5,$6,$7,$8) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 $8 = $8|0;
 var $$06684 = 0, $$06883 = 0, $$07082 = 0, $$07274 = 0, $$085 = 0, $$16777 = 0, $$16976 = 0, $$17175 = 0, $$178 = 0, $$in = 0, $$off = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $9 = 0, $or$cond = 0, $scevgep = 0, $scevgep91 = 0, $scevgep92 = 0;
 var $scevgep93 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $9 = (($8|0) / 2)&-1;
 $10 = (($9) + ($7))|0;
 $11 = (($7|0) / 2)&-1;
 $12 = ($6|0)==(0);
 $$off = (($7) + 1)|0;
 $13 = ($$off>>>0)<(3);
 $or$cond = $12 | $13;
 if ($or$cond) {
  return;
 }
 $14 = $11 << 2;
 $15 = $11 << 1;
 $$06684 = $3;$$06883 = $4;$$07082 = $5;$$085 = $2;$$in = $6;
 while(1) {
  $16 = (($$in) + -1)|0;
  $scevgep = (($$06684) + ($14)|0);
  $scevgep92 = (($$085) + ($14)|0);
  $$07274 = $11;$$16777 = $$06684;$$16976 = $$06883;$$17175 = $$07082;$$178 = $$085;
  while(1) {
   $17 = (($$07274) + -1)|0;
   $18 = HEAP8[$$16777>>0]|0;
   $19 = $18&255;
   $20 = (($0) + ($19<<2)|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = (($21) + 256)|0;
   $23 = $19 | 256;
   $24 = (($0) + ($23<<2)|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = (($25) + 1024)|0;
   $27 = HEAP8[$$16976>>0]|0;
   $28 = $27&255;
   $29 = $28 | 512;
   $30 = (($0) + ($29<<2)|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = (($26) + ($31))|0;
   $33 = $28 | 768;
   $34 = (($0) + ($33<<2)|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = (($35) + 1792)|0;
   $37 = ((($$16777)) + 4|0);
   $38 = ((($$16976)) + 4|0);
   $39 = HEAP8[$$178>>0]|0;
   $40 = $39&255;
   $41 = ((($$178)) + 2|0);
   $42 = (($40) + ($22))|0;
   $43 = (($1) + ($42<<2)|0);
   $44 = HEAP32[$43>>2]|0;
   $45 = (($40) + ($32))|0;
   $46 = (($1) + ($45<<2)|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = $47 | $44;
   $49 = (($40) + ($36))|0;
   $50 = (($1) + ($49<<2)|0);
   $51 = HEAP32[$50>>2]|0;
   $52 = $48 | $51;
   $53 = (($$17175) + ($10<<2)|0);
   HEAP32[$53>>2] = $52;
   HEAP32[$$17175>>2] = $52;
   $54 = ((($$17175)) + 4|0);
   $55 = HEAP8[$41>>0]|0;
   $56 = $55&255;
   $57 = ((($$178)) + 4|0);
   $58 = (($56) + ($22))|0;
   $59 = (($1) + ($58<<2)|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = (($56) + ($32))|0;
   $62 = (($1) + ($61<<2)|0);
   $63 = HEAP32[$62>>2]|0;
   $64 = $63 | $60;
   $65 = (($56) + ($36))|0;
   $66 = (($1) + ($65<<2)|0);
   $67 = HEAP32[$66>>2]|0;
   $68 = $64 | $67;
   $69 = (($54) + ($10<<2)|0);
   HEAP32[$69>>2] = $68;
   HEAP32[$54>>2] = $68;
   $70 = ((($$17175)) + 8|0);
   $71 = ($17|0)==(0);
   if ($71) {
    break;
   } else {
    $$07274 = $17;$$16777 = $37;$$16976 = $38;$$17175 = $70;$$178 = $57;
   }
  }
  $scevgep91 = (($$06883) + ($14)|0);
  $scevgep93 = (($$07082) + ($15<<2)|0);
  $72 = (($scevgep93) + ($10<<2)|0);
  $73 = ($16|0)==(0);
  if ($73) {
   break;
  } else {
   $$06684 = $scevgep;$$06883 = $scevgep91;$$07082 = $72;$$085 = $scevgep92;$$in = $16;
  }
 }
 return;
}
function _Color24DitherYUY2Mod1X($0,$1,$2,$3,$4,$5,$6,$7,$8) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 $8 = $8|0;
 var $$06987 = 0, $$07186 = 0, $$07385 = 0, $$07677 = 0, $$088 = 0, $$17080 = 0, $$17279 = 0, $$17478 = 0, $$181 = 0, $$in = 0, $$off = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $9 = 0, $or$cond = 0, $scevgep = 0, $scevgep94 = 0, $scevgep95 = 0, $scevgep96 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $9 = (($7|0) / 2)&-1;
 $10 = ($8*3)|0;
 $11 = ($6|0)==(0);
 $$off = (($7) + 1)|0;
 $12 = ($$off>>>0)<(3);
 $or$cond = $11 | $12;
 if ($or$cond) {
  return;
 }
 $13 = $9 << 2;
 $14 = ($9*6)|0;
 $$06987 = $3;$$07186 = $4;$$07385 = $5;$$088 = $2;$$in = $6;
 while(1) {
  $15 = (($$in) + -1)|0;
  $scevgep = (($$06987) + ($13)|0);
  $scevgep95 = (($$088) + ($13)|0);
  $$07677 = $9;$$17080 = $$06987;$$17279 = $$07186;$$17478 = $$07385;$$181 = $$088;
  while(1) {
   $16 = (($$07677) + -1)|0;
   $17 = HEAP8[$$17080>>0]|0;
   $18 = $17&255;
   $19 = (($0) + ($18<<2)|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($20) + 256)|0;
   $22 = $18 | 256;
   $23 = (($0) + ($22<<2)|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = (($24) + 1024)|0;
   $26 = HEAP8[$$17279>>0]|0;
   $27 = $26&255;
   $28 = $27 | 512;
   $29 = (($0) + ($28<<2)|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = (($25) + ($30))|0;
   $32 = $27 | 768;
   $33 = (($0) + ($32<<2)|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = (($34) + 1792)|0;
   $36 = ((($$17080)) + 4|0);
   $37 = ((($$17279)) + 4|0);
   $38 = HEAP8[$$181>>0]|0;
   $39 = $38&255;
   $40 = ((($$181)) + 2|0);
   $41 = (($39) + ($21))|0;
   $42 = (($1) + ($41<<2)|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = (($39) + ($31))|0;
   $45 = (($1) + ($44<<2)|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = $46 | $43;
   $48 = (($39) + ($35))|0;
   $49 = (($1) + ($48<<2)|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = $47 | $50;
   $52 = $51&255;
   $53 = ((($$17478)) + 1|0);
   HEAP8[$$17478>>0] = $52;
   $54 = $51 >>> 8;
   $55 = $54&255;
   $56 = ((($$17478)) + 2|0);
   HEAP8[$53>>0] = $55;
   $57 = $51 >>> 16;
   $58 = $57&255;
   $59 = ((($$17478)) + 3|0);
   HEAP8[$56>>0] = $58;
   $60 = HEAP8[$40>>0]|0;
   $61 = $60&255;
   $62 = ((($$181)) + 4|0);
   $63 = (($61) + ($21))|0;
   $64 = (($1) + ($63<<2)|0);
   $65 = HEAP32[$64>>2]|0;
   $66 = (($61) + ($31))|0;
   $67 = (($1) + ($66<<2)|0);
   $68 = HEAP32[$67>>2]|0;
   $69 = $68 | $65;
   $70 = (($61) + ($35))|0;
   $71 = (($1) + ($70<<2)|0);
   $72 = HEAP32[$71>>2]|0;
   $73 = $69 | $72;
   $74 = $73&255;
   $75 = ((($$17478)) + 4|0);
   HEAP8[$59>>0] = $74;
   $76 = $73 >>> 8;
   $77 = $76&255;
   $78 = ((($$17478)) + 5|0);
   HEAP8[$75>>0] = $77;
   $79 = $73 >>> 16;
   $80 = $79&255;
   $81 = ((($$17478)) + 6|0);
   HEAP8[$78>>0] = $80;
   $82 = ($16|0)==(0);
   if ($82) {
    break;
   } else {
    $$07677 = $16;$$17080 = $36;$$17279 = $37;$$17478 = $81;$$181 = $62;
   }
  }
  $scevgep94 = (($$07186) + ($13)|0);
  $scevgep96 = (($$07385) + ($14)|0);
  $83 = (($scevgep96) + ($10)|0);
  $84 = ($15|0)==(0);
  if ($84) {
   break;
  } else {
   $$06987 = $scevgep;$$07186 = $scevgep94;$$07385 = $83;$$088 = $scevgep95;$$in = $15;
  }
 }
 return;
}
function _Color24DitherYUY2Mod2X($0,$1,$2,$3,$4,$5,$6,$7,$8) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 $8 = $8|0;
 var $$0104122 = 0, $$0106121 = 0, $$0108120 = 0, $$0110112 = 0, $$0123 = 0, $$1105115 = 0, $$1107114 = 0, $$1109113 = 0, $$1116 = 0, $$in = 0, $$off = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $scevgep = 0, $scevgep129 = 0, $scevgep130 = 0, $scevgep131 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $9 = $7 << 1;
 $10 = (($9) + ($8))|0;
 $11 = ($10*3)|0;
 $12 = (($7|0) / 2)&-1;
 $13 = ($6|0)==(0);
 if ($13) {
  return;
 }
 $$off = (($7) + 1)|0;
 $14 = ($$off>>>0)<(3);
 $15 = (($11) + 3)|0;
 $16 = (($11) + 4)|0;
 $17 = (($11) + 1)|0;
 $18 = (($11) + 5)|0;
 $19 = (($11) + 2)|0;
 if ($14) {
  return;
 }
 $20 = $12 << 2;
 $21 = ($12*12)|0;
 $$0104122 = $3;$$0106121 = $4;$$0108120 = $5;$$0123 = $2;$$in = $6;
 while(1) {
  $22 = (($$in) + -1)|0;
  $scevgep = (($$0104122) + ($20)|0);
  $scevgep130 = (($$0123) + ($20)|0);
  $$0110112 = $12;$$1105115 = $$0104122;$$1107114 = $$0106121;$$1109113 = $$0108120;$$1116 = $$0123;
  while(1) {
   $23 = (($$0110112) + -1)|0;
   $24 = HEAP8[$$1105115>>0]|0;
   $25 = $24&255;
   $26 = (($0) + ($25<<2)|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = (($27) + 256)|0;
   $29 = $25 | 256;
   $30 = (($0) + ($29<<2)|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = (($31) + 1024)|0;
   $33 = HEAP8[$$1107114>>0]|0;
   $34 = $33&255;
   $35 = $34 | 512;
   $36 = (($0) + ($35<<2)|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = (($32) + ($37))|0;
   $39 = $34 | 768;
   $40 = (($0) + ($39<<2)|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = (($41) + 1792)|0;
   $43 = ((($$1105115)) + 4|0);
   $44 = ((($$1107114)) + 4|0);
   $45 = HEAP8[$$1116>>0]|0;
   $46 = $45&255;
   $47 = ((($$1116)) + 2|0);
   $48 = (($46) + ($28))|0;
   $49 = (($1) + ($48<<2)|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = (($46) + ($38))|0;
   $52 = (($1) + ($51<<2)|0);
   $53 = HEAP32[$52>>2]|0;
   $54 = $53 | $50;
   $55 = (($46) + ($42))|0;
   $56 = (($1) + ($55<<2)|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = $54 | $57;
   $59 = $58&255;
   $60 = (($$1109113) + ($15)|0);
   HEAP8[$60>>0] = $59;
   $61 = (($$1109113) + ($11)|0);
   HEAP8[$61>>0] = $59;
   $62 = ((($$1109113)) + 3|0);
   HEAP8[$62>>0] = $59;
   HEAP8[$$1109113>>0] = $59;
   $63 = $58 >>> 8;
   $64 = $63&255;
   $65 = (($$1109113) + ($16)|0);
   HEAP8[$65>>0] = $64;
   $66 = (($$1109113) + ($17)|0);
   HEAP8[$66>>0] = $64;
   $67 = ((($$1109113)) + 4|0);
   HEAP8[$67>>0] = $64;
   $68 = ((($$1109113)) + 1|0);
   HEAP8[$68>>0] = $64;
   $69 = $58 >>> 16;
   $70 = $69&255;
   $71 = (($$1109113) + ($18)|0);
   HEAP8[$71>>0] = $70;
   $72 = (($$1109113) + ($19)|0);
   HEAP8[$72>>0] = $70;
   $73 = ((($$1109113)) + 5|0);
   HEAP8[$73>>0] = $70;
   $74 = ((($$1109113)) + 2|0);
   HEAP8[$74>>0] = $70;
   $75 = ((($$1109113)) + 6|0);
   $76 = HEAP8[$47>>0]|0;
   $77 = $76&255;
   $78 = ((($$1116)) + 4|0);
   $79 = (($77) + ($28))|0;
   $80 = (($1) + ($79<<2)|0);
   $81 = HEAP32[$80>>2]|0;
   $82 = (($77) + ($38))|0;
   $83 = (($1) + ($82<<2)|0);
   $84 = HEAP32[$83>>2]|0;
   $85 = $84 | $81;
   $86 = (($77) + ($42))|0;
   $87 = (($1) + ($86<<2)|0);
   $88 = HEAP32[$87>>2]|0;
   $89 = $85 | $88;
   $90 = $89&255;
   $91 = (($75) + ($15)|0);
   HEAP8[$91>>0] = $90;
   $92 = (($75) + ($11)|0);
   HEAP8[$92>>0] = $90;
   $93 = ((($$1109113)) + 9|0);
   HEAP8[$93>>0] = $90;
   HEAP8[$75>>0] = $90;
   $94 = $89 >>> 8;
   $95 = $94&255;
   $96 = (($75) + ($16)|0);
   HEAP8[$96>>0] = $95;
   $97 = (($75) + ($17)|0);
   HEAP8[$97>>0] = $95;
   $98 = ((($$1109113)) + 10|0);
   HEAP8[$98>>0] = $95;
   $99 = ((($$1109113)) + 7|0);
   HEAP8[$99>>0] = $95;
   $100 = $89 >>> 16;
   $101 = $100&255;
   $102 = (($75) + ($18)|0);
   HEAP8[$102>>0] = $101;
   $103 = (($75) + ($19)|0);
   HEAP8[$103>>0] = $101;
   $104 = ((($$1109113)) + 11|0);
   HEAP8[$104>>0] = $101;
   $105 = ((($$1109113)) + 8|0);
   HEAP8[$105>>0] = $101;
   $106 = ((($$1109113)) + 12|0);
   $107 = ($23|0)==(0);
   if ($107) {
    break;
   } else {
    $$0110112 = $23;$$1105115 = $43;$$1107114 = $44;$$1109113 = $106;$$1116 = $78;
   }
  }
  $scevgep129 = (($$0106121) + ($20)|0);
  $scevgep131 = (($$0108120) + ($21)|0);
  $108 = (($scevgep131) + ($11)|0);
  $109 = ($22|0)==(0);
  if ($109) {
   break;
  } else {
   $$0104122 = $scevgep;$$0106121 = $scevgep129;$$0108120 = $108;$$0123 = $scevgep130;$$in = $22;
  }
 }
 return;
}
function _Color32DitherYUY2Mod1X($0,$1,$2,$3,$4,$5,$6,$7,$8) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 $8 = $8|0;
 var $$05674 = 0, $$05873 = 0, $$06072 = 0, $$06264 = 0, $$075 = 0, $$15767 = 0, $$15966 = 0, $$16165 = 0, $$168 = 0, $$in = 0, $$off = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $9 = 0, $or$cond = 0, $scevgep = 0, $scevgep81 = 0, $scevgep82 = 0, $scevgep83 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $9 = (($7|0) / 2)&-1;
 $10 = ($6|0)==(0);
 $$off = (($7) + 1)|0;
 $11 = ($$off>>>0)<(3);
 $or$cond = $10 | $11;
 if ($or$cond) {
  return;
 }
 $12 = $9 << 2;
 $13 = $9 << 1;
 $$05674 = $3;$$05873 = $4;$$06072 = $5;$$075 = $2;$$in = $6;
 while(1) {
  $14 = (($$in) + -1)|0;
  $scevgep = (($$05674) + ($12)|0);
  $scevgep82 = (($$075) + ($12)|0);
  $$06264 = $9;$$15767 = $$05674;$$15966 = $$05873;$$16165 = $$06072;$$168 = $$075;
  while(1) {
   $15 = (($$06264) + -1)|0;
   $16 = HEAP8[$$15767>>0]|0;
   $17 = $16&255;
   $18 = (($0) + ($17<<2)|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($19) + 256)|0;
   $21 = $17 | 256;
   $22 = (($0) + ($21<<2)|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = (($23) + 1024)|0;
   $25 = HEAP8[$$15966>>0]|0;
   $26 = $25&255;
   $27 = $26 | 512;
   $28 = (($0) + ($27<<2)|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = (($24) + ($29))|0;
   $31 = $26 | 768;
   $32 = (($0) + ($31<<2)|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = (($33) + 1792)|0;
   $35 = ((($$15767)) + 4|0);
   $36 = ((($$15966)) + 4|0);
   $37 = HEAP8[$$168>>0]|0;
   $38 = $37&255;
   $39 = ((($$168)) + 2|0);
   $40 = (($38) + ($20))|0;
   $41 = (($1) + ($40<<2)|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = (($38) + ($30))|0;
   $44 = (($1) + ($43<<2)|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = $45 | $42;
   $47 = (($38) + ($34))|0;
   $48 = (($1) + ($47<<2)|0);
   $49 = HEAP32[$48>>2]|0;
   $50 = $46 | $49;
   $51 = ((($$16165)) + 4|0);
   HEAP32[$$16165>>2] = $50;
   $52 = HEAP8[$39>>0]|0;
   $53 = $52&255;
   $54 = ((($$168)) + 4|0);
   $55 = (($53) + ($20))|0;
   $56 = (($1) + ($55<<2)|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = (($53) + ($30))|0;
   $59 = (($1) + ($58<<2)|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = $60 | $57;
   $62 = (($53) + ($34))|0;
   $63 = (($1) + ($62<<2)|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = $61 | $64;
   $66 = ((($$16165)) + 8|0);
   HEAP32[$51>>2] = $65;
   $67 = ($15|0)==(0);
   if ($67) {
    break;
   } else {
    $$06264 = $15;$$15767 = $35;$$15966 = $36;$$16165 = $66;$$168 = $54;
   }
  }
  $scevgep81 = (($$05873) + ($12)|0);
  $scevgep83 = (($$06072) + ($13<<2)|0);
  $68 = (($scevgep83) + ($8<<2)|0);
  $69 = ($14|0)==(0);
  if ($69) {
   break;
  } else {
   $$05674 = $scevgep;$$05873 = $scevgep81;$$06072 = $68;$$075 = $scevgep82;$$in = $14;
  }
 }
 return;
}
function _Color32DitherYUY2Mod2X($0,$1,$2,$3,$4,$5,$6,$7,$8) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 $8 = $8|0;
 var $$07492 = 0, $$07691 = 0, $$07890 = 0, $$08082 = 0, $$093 = 0, $$17585 = 0, $$17784 = 0, $$17983 = 0, $$186 = 0, $$in = 0, $$off = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $9 = 0;
 var $scevgep = 0, $scevgep100 = 0, $scevgep101 = 0, $scevgep99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $9 = $7 << 1;
 $10 = (($9) + ($8))|0;
 $11 = (($7|0) / 2)&-1;
 $12 = ($6|0)==(0);
 if ($12) {
  return;
 }
 $$off = (($7) + 1)|0;
 $13 = ($$off>>>0)<(3);
 $14 = (($10) + 1)|0;
 if ($13) {
  return;
 }
 $15 = $11 << 2;
 $$07492 = $3;$$07691 = $4;$$07890 = $5;$$093 = $2;$$in = $6;
 while(1) {
  $16 = (($$in) + -1)|0;
  $scevgep = (($$07492) + ($15)|0);
  $scevgep100 = (($$093) + ($15)|0);
  $$08082 = $11;$$17585 = $$07492;$$17784 = $$07691;$$17983 = $$07890;$$186 = $$093;
  while(1) {
   $17 = (($$08082) + -1)|0;
   $18 = HEAP8[$$17585>>0]|0;
   $19 = $18&255;
   $20 = (($0) + ($19<<2)|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = (($21) + 256)|0;
   $23 = $19 | 256;
   $24 = (($0) + ($23<<2)|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = (($25) + 1024)|0;
   $27 = HEAP8[$$17784>>0]|0;
   $28 = $27&255;
   $29 = $28 | 512;
   $30 = (($0) + ($29<<2)|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = (($26) + ($31))|0;
   $33 = $28 | 768;
   $34 = (($0) + ($33<<2)|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = (($35) + 1792)|0;
   $37 = ((($$17585)) + 4|0);
   $38 = ((($$17784)) + 4|0);
   $39 = HEAP8[$$186>>0]|0;
   $40 = $39&255;
   $41 = ((($$186)) + 2|0);
   $42 = (($40) + ($22))|0;
   $43 = (($1) + ($42<<2)|0);
   $44 = HEAP32[$43>>2]|0;
   $45 = (($40) + ($32))|0;
   $46 = (($1) + ($45<<2)|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = $47 | $44;
   $49 = (($40) + ($36))|0;
   $50 = (($1) + ($49<<2)|0);
   $51 = HEAP32[$50>>2]|0;
   $52 = $48 | $51;
   $53 = (($$17983) + ($14<<2)|0);
   HEAP32[$53>>2] = $52;
   $54 = (($$17983) + ($10<<2)|0);
   HEAP32[$54>>2] = $52;
   $55 = ((($$17983)) + 4|0);
   HEAP32[$55>>2] = $52;
   HEAP32[$$17983>>2] = $52;
   $56 = ((($$17983)) + 8|0);
   $57 = HEAP8[$41>>0]|0;
   $58 = $57&255;
   $59 = ((($$186)) + 4|0);
   $60 = (($58) + ($22))|0;
   $61 = (($1) + ($60<<2)|0);
   $62 = HEAP32[$61>>2]|0;
   $63 = (($58) + ($32))|0;
   $64 = (($1) + ($63<<2)|0);
   $65 = HEAP32[$64>>2]|0;
   $66 = $65 | $62;
   $67 = (($58) + ($36))|0;
   $68 = (($1) + ($67<<2)|0);
   $69 = HEAP32[$68>>2]|0;
   $70 = $66 | $69;
   $71 = (($56) + ($14<<2)|0);
   HEAP32[$71>>2] = $70;
   $72 = (($56) + ($10<<2)|0);
   HEAP32[$72>>2] = $70;
   $73 = ((($$17983)) + 12|0);
   HEAP32[$73>>2] = $70;
   HEAP32[$56>>2] = $70;
   $74 = ((($$17983)) + 16|0);
   $75 = ($17|0)==(0);
   if ($75) {
    break;
   } else {
    $$08082 = $17;$$17585 = $37;$$17784 = $38;$$17983 = $74;$$186 = $59;
   }
  }
  $scevgep99 = (($$07691) + ($15)|0);
  $scevgep101 = (($$07890) + ($15<<2)|0);
  $76 = (($scevgep101) + ($10<<2)|0);
  $77 = ($16|0)==(0);
  if ($77) {
   break;
  } else {
   $$07492 = $scevgep;$$07691 = $scevgep99;$$07890 = $76;$$093 = $scevgep100;$$in = $16;
  }
 }
 return;
}
function _SDL_SW_LockYUVTexture($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre19 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp = 0, $storemerge = 0, $switch$split2D = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $4 = HEAP32[$0>>2]|0;
 $switch$split2D = ($4|0)<(1448433993);
 if ($switch$split2D) {
  switch ($4|0) {
  case 842094169:  {
   label = 2;
   break;
  }
  default: {
   label = 10;
  }
  }
 } else {
  switch ($4|0) {
  case 1448433993:  {
   label = 2;
   break;
  }
  default: {
   label = 10;
  }
  }
 }
 do {
  if ((label|0) == 2) {
   $5 = ($1|0)==(0|0);
   if ($5) {
    $6 = ((($0)) + 44|0);
    $7 = HEAP32[$6>>2]|0;
    $8 = ((($0)) + 36|0);
    $9 = HEAP16[$8>>1]|0;
    $10 = $9&65535;
    $45 = $10;$storemerge = $7;
    break;
   }
   $11 = HEAP32[$1>>2]|0;
   $12 = ($11|0)==(0);
   if ($12) {
    $13 = ((($1)) + 4|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ($14|0)==(0);
    if ($15) {
     $16 = ((($1)) + 8|0);
     $17 = HEAP32[$16>>2]|0;
     $18 = ((($0)) + 8|0);
     $19 = HEAP32[$18>>2]|0;
     $20 = ($17|0)==($19|0);
     if ($20) {
      $21 = ((($1)) + 12|0);
      $22 = HEAP32[$21>>2]|0;
      $23 = ((($0)) + 12|0);
      $24 = HEAP32[$23>>2]|0;
      $25 = ($22|0)==($24|0);
      if ($25) {
       $26 = ((($0)) + 44|0);
       $27 = HEAP32[$26>>2]|0;
       $28 = ((($0)) + 36|0);
       $29 = HEAP16[$28>>1]|0;
       $30 = $29&65535;
       $39 = $30;$40 = 0;$42 = $27;$44 = 0;
       label = 12;
       break;
      }
     }
    }
   }
   $31 = (_SDL_SetError(194918,$vararg_buffer)|0);
   $$0 = $31;
   STACKTOP = sp;return ($$0|0);
  }
  else if ((label|0) == 10) {
   $32 = ($1|0)==(0|0);
   $33 = ((($0)) + 44|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = ((($0)) + 36|0);
   $36 = HEAP16[$35>>1]|0;
   $37 = $36&65535;
   if ($32) {
    $45 = $37;$storemerge = $34;
   } else {
    $$phi$trans$insert = ((($1)) + 4|0);
    $$pre = HEAP32[$$phi$trans$insert>>2]|0;
    $$pre19 = HEAP32[$1>>2]|0;
    $phitmp = $$pre19 << 1;
    $39 = $37;$40 = $$pre;$42 = $34;$44 = $phitmp;
    label = 12;
   }
  }
 } while(0);
 if ((label|0) == 12) {
  $38 = Math_imul($40, $39)|0;
  $41 = (($42) + ($38)|0);
  $43 = (($41) + ($44)|0);
  $45 = $39;$storemerge = $43;
 }
 HEAP32[$2>>2] = $storemerge;
 HEAP32[$3>>2] = $45;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _SDL_GetNumRenderDrivers() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 2;
}
function _SDL_GetRenderDriverInfo($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $2 = ($0>>>0)>(1);
 if ($2) {
  HEAP32[$vararg_buffer>>2] = 1;
  $3 = (_SDL_SetError(195395,$vararg_buffer)|0);
  $$0 = $3;
  STACKTOP = sp;return ($$0|0);
 } else {
  $4 = (89752 + ($0<<2)|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ((($5)) + 4|0);
  dest=$1; src=$6; stop=dest+84|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 return (0)|0;
}
function _SDL_CreateRenderer($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$061 = 0, $$772 = 0, $$lcssa78 = 0, $$sink = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer3 = 0, $vararg_buffer5 = 0, $vararg_buffer7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $vararg_buffer7 = sp + 32|0;
 $vararg_buffer5 = sp + 24|0;
 $vararg_buffer3 = sp + 16|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $3 = ($0|0)==(0|0);
 if ($3) {
  (_SDL_SetError(195204,$vararg_buffer)|0);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = (_SDL_GetWindowData($0,194602)|0);
 $5 = ($4|0)==(0|0);
 if (!($5)) {
  (_SDL_SetError(195219,$vararg_buffer1)|0);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $6 = (_SDL_GetHint(195259)|0);
 $7 = ($6|0)==(0|0);
 do {
  if ($7) {
   $$061 = $2;
  } else {
   $8 = (_SDL_GetHintBoolean(195259,1)|0);
   $9 = ($8|0)==(0);
   if ($9) {
    $11 = $2 & -5;
    $$061 = $11;
    break;
   } else {
    $10 = $2 | 4;
    $$061 = $10;
    break;
   }
  }
 } while(0);
 $12 = ($1|0)<(0);
 L15: do {
  if ($12) {
   $13 = (_SDL_GetHint(195276)|0);
   $14 = ($13|0)==(0|0);
   do {
    if (!($14)) {
     $15 = HEAP32[(76584)>>2]|0;
     $16 = (_SDL_strcasecmp($13,$15)|0);
     $17 = ($16|0)==(0);
     if ($17) {
      $$lcssa78 = 76580;
     } else {
      $18 = HEAP32[(88664)>>2]|0;
      $19 = (_SDL_strcasecmp($13,$18)|0);
      $20 = ($19|0)==(0);
      if ($20) {
       $$lcssa78 = 88660;
      } else {
       break;
      }
     }
     $21 = HEAP32[$$lcssa78>>2]|0;
     $22 = (FUNCTION_TABLE_iii[$21 & 8191]($0,$$061)|0);
     $23 = ($22|0)==(0|0);
     if (!($23)) {
      $$772 = $22;
      break L15;
     }
    }
   } while(0);
   $24 = HEAP32[(76588)>>2]|0;
   $25 = $24 & $$061;
   $26 = ($25|0)==($$061|0);
   if ($26) {
    $27 = HEAP32[19145]|0;
    $28 = (FUNCTION_TABLE_iii[$27 & 8191]($0,$$061)|0);
    $29 = ($28|0)==(0|0);
    if (!($29)) {
     $$772 = $28;
     break;
    }
   }
   $30 = HEAP32[(88668)>>2]|0;
   $31 = $30 & $$061;
   $32 = ($31|0)==($$061|0);
   if ($32) {
    $48 = HEAP32[22165]|0;
    $49 = (FUNCTION_TABLE_iii[$48 & 8191]($0,$$061)|0);
    $50 = ($49|0)==(0|0);
    if (!($50)) {
     $$772 = $49;
     break;
    }
   }
   (_SDL_SetError(195294,$vararg_buffer3)|0);
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  } else {
   $33 = ($1|0)>(1);
   if ($33) {
    HEAP32[$vararg_buffer5>>2] = 1;
    (_SDL_SetError(195331,$vararg_buffer5)|0);
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   } else {
    $34 = (89752 + ($1<<2)|0);
    $35 = HEAP32[$34>>2]|0;
    $36 = HEAP32[$35>>2]|0;
    $37 = (FUNCTION_TABLE_iii[$36 & 8191]($0,$$061)|0);
    $38 = ($37|0)==(0|0);
    if ($38) {
     $$0 = 0;
    } else {
     $$772 = $37;
     break;
    }
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 HEAP32[$$772>>2] = 217376;
 $39 = ((($$772)) + 188|0);
 HEAP32[$39>>2] = $0;
 $40 = ((($$772)) + 288|0);
 HEAPF32[$40>>2] = 1.0;
 $41 = ((($$772)) + 292|0);
 HEAPF32[$41>>2] = 1.0;
 $42 = (_SDL_GetWindowFlags($0)|0);
 $43 = $42 & 72;
 $44 = ($43|0)!=(0);
 $45 = ((($$772)) + 192|0);
 $$sink = $44&1;
 HEAP32[$45>>2] = $$sink;
 (_SDL_SetWindowData($0,194602,$$772)|0);
 (_SDL_RenderSetViewport($$772,0)|0);
 _SDL_AddEventWatch(4477,$$772);
 $46 = ((($$772)) + 104|0);
 $47 = HEAP32[$46>>2]|0;
 HEAP32[$vararg_buffer7>>2] = $47;
 _SDL_LogInfo(6,195374,$vararg_buffer7);
 $$0 = $$772;
 STACKTOP = sp;return ($$0|0);
}
function _SDL_GetRendererInfo($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $2 = ($0|0)==(0|0);
 if (!($2)) {
  $3 = HEAP32[$0>>2]|0;
  $4 = ($3|0)==(217376|0);
  if ($4) {
   $5 = ((($0)) + 104|0);
   dest=$1; src=$5; stop=dest+84|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 (_SDL_SetError(176572,$vararg_buffer)|0);
 $$0 = -1;
 STACKTOP = sp;return ($$0|0);
}
function _SDL_CreateTexture($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0 = 0, $$0106 = 0, $$08$i = 0, $$086134$i = 0, $$1$i = 0, $$187133$i = 0, $$187133$us$i = 0, $$clear = 0, $$clear10 = 0, $$clear11 = 0, $$mask107 = 0, $$mask109 = 0, $$mask89$i = 0, $$mask89$us$i = 0, $$not = 0, $$not100$i = 0, $$not100$us$i = 0, $$off = 0, $$off$i = 0, $$off109$i = 0;
 var $$off113$i = 0, $$off113$us$i = 0, $$off122$i = 0, $$off122$us$i = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond102$i = 0, $or$cond102$us$i = 0, $or$cond111 = 0, $or$cond114 = 0, $or$cond115 = 0, $or$cond117 = 0, $or$cond3 = 0, $phitmp = 0, $switch = 0, $switch$cast$i = 0, $switch$cast$i$clear = 0;
 var $switch$cast126$i = 0, $switch$cast126$i$clear = 0, $switch$cast126$us$i = 0, $switch$cast126$us$i$clear = 0, $switch$downshift$i = 0, $switch$downshift128$i = 0, $switch$downshift128$us$i = 0, $switch$i = 0, $switch$lobit$i = 0, $switch$lobit121$i = 0, $switch$lobit121$us$i = 0, $switch$masked$i = 0, $switch$masked129$i = 0, $switch$maskindex$i = 0, $switch$maskindex119$i = 0, $switch$maskindex119$us$i = 0, $switch$shifted$i = 0, $switch$shifted120$i = 0, $switch$shifted120$us$i = 0, $switch$split2D = 0;
 var $switch$tableidx$i = 0, $switch$tableidx112$i = 0, $switch$tableidx116$i = 0, $switch$tableidx116$us$i = 0, $switch$tableidx125$i = 0, $switch$tableidx125$us$i = 0, $switch110$i = 0, $switch114$i = 0, $switch114$us$i = 0, $switch123$i = 0, $switch123$us$i = 0, $tmp$us$i = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer3 = 0, $vararg_buffer5 = 0, $vararg_buffer7 = 0, $vararg_ptr9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $vararg_buffer7 = sp + 32|0;
 $vararg_buffer5 = sp + 24|0;
 $vararg_buffer3 = sp + 16|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $5 = ($0|0)==(0|0);
 if (!($5)) {
  $6 = HEAP32[$0>>2]|0;
  $7 = ($6|0)==(217376|0);
  if ($7) {
   $8 = ($1|0)==(0);
   if ($8) {
    $9 = ((($0)) + 116|0);
    $10 = HEAP32[$9>>2]|0;
    $$0106 = $10;
   } else {
    $$0106 = $1;
   }
   $$not = ($$0106|0)==(0);
   $$mask109 = $$0106 & -268435456;
   $11 = ($$mask109|0)==(268435456);
   $or$cond111 = $$not | $11;
   $12 = $$0106 & 255;
   $13 = ($12|0)==(0);
   $14 = $13 & $or$cond111;
   if ($14) {
    (_SDL_SetError(195050,$vararg_buffer1)|0);
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   if ($or$cond111) {
    $15 = $$0106 >>> 24;
    $16 = $15 & 15;
    $$off = (($16) + -1)|0;
    $switch = ($$off>>>0)<(3);
    if ($switch) {
     (_SDL_SetError(195073,$vararg_buffer3)|0);
     $$0 = 0;
     STACKTOP = sp;return ($$0|0);
    }
   }
   $17 = ($3|0)<(1);
   $18 = ($4|0)<(1);
   $or$cond3 = $17 | $18;
   if ($or$cond3) {
    (_SDL_SetError(195111,$vararg_buffer5)|0);
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $19 = ((($0)) + 180|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = ($20|0)!=(0);
   $22 = ($20|0)<($3|0);
   $or$cond114 = $21 & $22;
   $$phi$trans$insert = ((($0)) + 184|0);
   $$pre = HEAP32[$$phi$trans$insert>>2]|0;
   if (!($or$cond114)) {
    $23 = ($$pre|0)!=(0);
    $24 = ($$pre|0)<($4|0);
    $or$cond115 = $23 & $24;
    if (!($or$cond115)) {
     $25 = (_SDL_calloc(1,80)|0);
     $26 = ($25|0)==(0|0);
     if ($26) {
      (_SDL_Error(0)|0);
      $$0 = 0;
      STACKTOP = sp;return ($$0|0);
     }
     HEAP32[$25>>2] = 217377;
     $27 = ((($25)) + 4|0);
     HEAP32[$27>>2] = $$0106;
     $28 = ((($25)) + 8|0);
     HEAP32[$28>>2] = $2;
     $29 = ((($25)) + 12|0);
     HEAP32[$29>>2] = $3;
     $30 = ((($25)) + 16|0);
     HEAP32[$30>>2] = $4;
     $31 = ((($25)) + 28|0);
     $32 = ((($25)) + 32|0);
     HEAP32[$31>>2] = -1;
     HEAP32[$32>>2] = $0;
     $33 = ((($0)) + 304|0);
     $34 = HEAP32[$33>>2]|0;
     $35 = ((($25)) + 76|0);
     HEAP32[$35>>2] = $34;
     $36 = ($34|0)==(0|0);
     if (!($36)) {
      $37 = ((($34)) + 72|0);
      HEAP32[$37>>2] = $25;
     }
     HEAP32[$33>>2] = $25;
     $38 = ((($0)) + 112|0);
     $39 = HEAP32[$38>>2]|0;
     $40 = ($39|0)==(0);
     L30: do {
      if (!($40)) {
       $$08$i = 0;
       while(1) {
        $43 = (((($0)) + 116|0) + ($$08$i<<2)|0);
        $44 = HEAP32[$43>>2]|0;
        $45 = ($44|0)==($$0106|0);
        $41 = (($$08$i) + 1)|0;
        if ($45) {
         break;
        }
        $42 = ($41>>>0)<($39>>>0);
        if ($42) {
         $$08$i = $41;
        } else {
         break L30;
        }
       }
       $46 = ((($0)) + 12|0);
       $47 = HEAP32[$46>>2]|0;
       $48 = (FUNCTION_TABLE_iii[$47 & 8191]($0,$25)|0);
       $49 = ($48|0)<(0);
       if (!($49)) {
        $$0 = $25;
        STACKTOP = sp;return ($$0|0);
       }
       _SDL_DestroyTexture($25);
       $$0 = 0;
       STACKTOP = sp;return ($$0|0);
      }
     } while(0);
     L40: do {
      if ($or$cond111) {
       $55 = $$0106 >>> 24;
       $56 = $55 & 15;
       $$off$i = (($56) + -4)|0;
       $switch$i = ($$off$i>>>0)<(3);
       if ($switch$i) {
        $57 = $$0106 >>> 20;
        $58 = $57 & 15;
        $switch$tableidx$i = (($58) + -3)|0;
        $59 = ($switch$tableidx$i>>>0)<(6);
        if ($59) {
         $switch$maskindex$i = $switch$tableidx$i&255;
         $switch$shifted$i = (51&255) >>> $switch$maskindex$i;
         $63 = $switch$shifted$i & 1;
         $switch$lobit$i = ($63<<24>>24)==(0);
         if ($switch$lobit$i) {
          label = 31;
         } else {
          $126 = 1;
         }
        } else {
         label = 31;
        }
       } else {
        label = 31;
       }
       if ((label|0) == 31) {
        $$off109$i = (($56) + -7)|0;
        $switch110$i = ($$off109$i>>>0)<(5);
        if ($switch110$i) {
         $60 = $$0106 >>> 20;
         $61 = $60 & 15;
         $switch$tableidx112$i = (($61) + -2)|0;
         $62 = ($switch$tableidx112$i>>>0)<(5);
         if ($62) {
          $switch$cast$i = $switch$tableidx112$i&255;
          $switch$cast$i$clear = $switch$cast$i & 31;
          $switch$downshift$i = (27&255) >>> $switch$cast$i$clear;
          $64 = $switch$downshift$i & 1;
          $$clear = $64 & 31;
          $switch$masked$i = ($$clear<<24>>24)!=(0);
          $126 = $switch$masked$i;
         } else {
          $126 = 0;
         }
        } else {
         $126 = 0;
        }
       }
       if ($40) {
        label = 53;
       } else {
        if ($126) {
         $$187133$us$i = 0;
         while(1) {
          $65 = (((($0)) + 116|0) + ($$187133$us$i<<2)|0);
          $66 = HEAP32[$65>>2]|0;
          $$not100$us$i = ($66|0)==(0);
          $$mask89$us$i = $66 & -268435456;
          $67 = ($$mask89$us$i|0)==(268435456);
          $or$cond102$us$i = $$not100$us$i | $67;
          do {
           if ($or$cond102$us$i) {
            $68 = $66 >>> 24;
            $69 = $68 & 15;
            $$off113$us$i = (($69) + -4)|0;
            $switch114$us$i = ($$off113$us$i>>>0)<(3);
            do {
             if ($switch114$us$i) {
              $70 = $66 >>> 20;
              $71 = $70 & 15;
              $switch$tableidx116$us$i = (($71) + -3)|0;
              $72 = ($switch$tableidx116$us$i>>>0)<(6);
              if (!($72)) {
               break;
              }
              $switch$maskindex119$us$i = $switch$tableidx116$us$i&255;
              $switch$shifted120$us$i = (51&255) >>> $switch$maskindex119$us$i;
              $73 = $switch$shifted120$us$i & 1;
              $switch$lobit121$us$i = ($73<<24>>24)==(0);
              if (!($switch$lobit121$us$i)) {
               $$1$i = $66;
               break L40;
              }
             }
            } while(0);
            $$off122$us$i = (($69) + -7)|0;
            $switch123$us$i = ($$off122$us$i>>>0)<(5);
            if (!($switch123$us$i)) {
             break;
            }
            $74 = $66 >>> 20;
            $75 = $74 & 15;
            $switch$tableidx125$us$i = (($75) + -2)|0;
            $76 = ($switch$tableidx125$us$i>>>0)<(5);
            if (!($76)) {
             break;
            }
            $switch$cast126$us$i = $switch$tableidx125$us$i&255;
            $switch$cast126$us$i$clear = $switch$cast126$us$i & 31;
            $switch$downshift128$us$i = (27&255) >>> $switch$cast126$us$i$clear;
            $77 = $switch$downshift128$us$i & 1;
            $$clear10 = $77 & 31;
            $tmp$us$i = ($$clear10<<24>>24)==(0);
            if (!($tmp$us$i)) {
             $$1$i = $66;
             break L40;
            }
           }
          } while(0);
          $78 = (($$187133$us$i) + 1)|0;
          $79 = ($78>>>0)<($39>>>0);
          if ($79) {
           $$187133$us$i = $78;
          } else {
           label = 53;
           break;
          }
         }
        } else {
         $$187133$i = 0;
         while(1) {
          $80 = (((($0)) + 116|0) + ($$187133$i<<2)|0);
          $81 = HEAP32[$80>>2]|0;
          $$not100$i = ($81|0)==(0);
          $$mask89$i = $81 & -268435456;
          $82 = ($$mask89$i|0)==(268435456);
          $or$cond102$i = $$not100$i | $82;
          L65: do {
           if ($or$cond102$i) {
            $83 = $81 >>> 24;
            $84 = $83 & 15;
            $$off113$i = (($84) + -4)|0;
            $switch114$i = ($$off113$i>>>0)<(3);
            do {
             if ($switch114$i) {
              $85 = $81 >>> 20;
              $86 = $85 & 15;
              $switch$tableidx116$i = (($86) + -3)|0;
              $87 = ($switch$tableidx116$i>>>0)<(6);
              if (!($87)) {
               break;
              }
              $switch$maskindex119$i = $switch$tableidx116$i&255;
              $switch$shifted120$i = (51&255) >>> $switch$maskindex119$i;
              $91 = $switch$shifted120$i & 1;
              $switch$lobit121$i = ($91<<24>>24)==(0);
              if (!($switch$lobit121$i)) {
               break L65;
              }
             }
            } while(0);
            $$off122$i = (($84) + -7)|0;
            $switch123$i = ($$off122$i>>>0)<(5);
            if (!($switch123$i)) {
             $$1$i = $81;
             break L40;
            }
            $88 = $81 >>> 20;
            $89 = $88 & 15;
            $switch$tableidx125$i = (($89) + -2)|0;
            $90 = ($switch$tableidx125$i>>>0)<(5);
            if (!($90)) {
             $$1$i = $81;
             break L40;
            }
            $switch$cast126$i = $switch$tableidx125$i&255;
            $switch$cast126$i$clear = $switch$cast126$i & 31;
            $switch$downshift128$i = (27&255) >>> $switch$cast126$i$clear;
            $92 = $switch$downshift128$i & 1;
            $$clear11 = $92 & 31;
            $switch$masked129$i = ($$clear11<<24>>24)==(0);
            if ($switch$masked129$i) {
             $$1$i = $81;
             break L40;
            }
           }
          } while(0);
          $93 = (($$187133$i) + 1)|0;
          $94 = ($93>>>0)<($39>>>0);
          if ($94) {
           $$187133$i = $93;
          } else {
           label = 53;
           break;
          }
         }
        }
       }
      } else {
       if ($40) {
        label = 53;
       } else {
        $$086134$i = 0;
        while(1) {
         $52 = (((($0)) + 116|0) + ($$086134$i<<2)|0);
         $53 = HEAP32[$52>>2]|0;
         $54 = ($53|0)==($$0106|0);
         $50 = (($$086134$i) + 1)|0;
         if ($54) {
          $$1$i = $$0106;
          break L40;
         }
         $51 = ($50>>>0)<($39>>>0);
         if ($51) {
          $$086134$i = $50;
         } else {
          label = 53;
          break;
         }
        }
       }
      }
     } while(0);
     if ((label|0) == 53) {
      $95 = ((($0)) + 116|0);
      $$pre$i = HEAP32[$95>>2]|0;
      $$1$i = $$pre$i;
     }
     $96 = (_SDL_CreateTexture($0,$$1$i,$2,$3,$4)|0);
     $97 = ((($25)) + 36|0);
     HEAP32[$97>>2] = $96;
     $98 = ($96|0)==(0|0);
     if ($98) {
      _SDL_DestroyTexture($25);
      $$0 = 0;
      STACKTOP = sp;return ($$0|0);
     }
     $99 = HEAP32[$35>>2]|0;
     $100 = ((($96)) + 76|0);
     HEAP32[$100>>2] = $99;
     $101 = ($99|0)==(0);
     if (!($101)) {
      $102 = $99;
      $103 = ((($102)) + 72|0);
      HEAP32[$103>>2] = $96;
     }
     $104 = ((($96)) + 72|0);
     $105 = HEAP32[$104>>2]|0;
     $106 = ((($25)) + 72|0);
     HEAP32[$106>>2] = $105;
     $107 = ($105|0)==(0|0);
     if (!($107)) {
      $108 = ((($105)) + 76|0);
      HEAP32[$108>>2] = $25;
     }
     HEAP32[$104>>2] = $25;
     HEAP32[$35>>2] = $96;
     HEAP32[$33>>2] = $25;
     $109 = HEAP32[$27>>2]|0;
     $110 = ($109|0)==(0);
     $$mask107 = $109 & -268435456;
     $111 = ($$mask107|0)==(268435456);
     $or$cond117 = $110 | $111;
     if (!($or$cond117)) {
      $112 = (_SDL_SW_CreateYUVTexture($$0106,$3,$4)|0);
      $113 = ((($25)) + 40|0);
      HEAP32[$113>>2] = $112;
      $114 = ($112|0)==(0|0);
      if (!($114)) {
       $$0 = $25;
       STACKTOP = sp;return ($$0|0);
      }
      _SDL_DestroyTexture($25);
      $$0 = 0;
      STACKTOP = sp;return ($$0|0);
     }
     $115 = ($2|0)==(1);
     if (!($115)) {
      $$0 = $25;
      STACKTOP = sp;return ($$0|0);
     }
     L101: do {
      if ($or$cond111) {
       $118 = $12;
      } else {
       $switch$split2D = ($$0106|0)<(1498831189);
       if ($switch$split2D) {
        switch ($$0106|0) {
        case 844715353:  {
         $118 = 2;
         break L101;
         break;
        }
        default: {
        }
        }
       } else {
        switch ($$0106|0) {
        case 1498831189:  {
         $118 = 2;
         break L101;
         break;
        }
        default: {
        }
        }
       }
       $116 = ($$0106|0)==(1431918169);
       $phitmp = $116 ? 2 : 1;
       $118 = $phitmp;
      }
     } while(0);
     $117 = Math_imul($118, $3)|0;
     $119 = (($117) + 3)|0;
     $120 = $119 & -4;
     $121 = ((($25)) + 48|0);
     HEAP32[$121>>2] = $120;
     $122 = Math_imul($120, $4)|0;
     $123 = (_SDL_calloc(1,$122)|0);
     $124 = ((($25)) + 44|0);
     HEAP32[$124>>2] = $123;
     $125 = ($123|0)==(0|0);
     if (!($125)) {
      $$0 = $25;
      STACKTOP = sp;return ($$0|0);
     }
     _SDL_DestroyTexture($25);
     $$0 = 0;
     STACKTOP = sp;return ($$0|0);
    }
   }
   HEAP32[$vararg_buffer7>>2] = $20;
   $vararg_ptr9 = ((($vararg_buffer7)) + 4|0);
   HEAP32[$vararg_ptr9>>2] = $$pre;
   (_SDL_SetError(195141,$vararg_buffer7)|0);
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 (_SDL_SetError(176572,$vararg_buffer)|0);
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _SDL_SW_CreateYUVTexture($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$07879 = 0, $$pre = 0, $$pre$phiZ2D = 0, $$sink = 0, $$sink3 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0.0, $32 = 0.0, $33 = 0, $34 = 0, $35 = 0.0, $36 = 0, $37 = 0, $38 = 0.0, $39 = 0, $4 = 0, $40 = 0, $41 = 0.0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $7 = 0, $8 = 0, $9 = 0, $div = 0, $exitcond = 0, $or$cond = 0, $switch$split102D = 0, $switch$split12D = 0, $switch$split132D = 0, $switch$split162D = 0, $switch$split192D = 0, $switch$split2D = 0, $switch$split42D = 0, $switch$split72D = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $switch$split2D = ($0|0)<(1431918169);
 L1: do {
  if ($switch$split2D) {
   $switch$split42D = ($0|0)<(844715353);
   if ($switch$split42D) {
    switch ($0|0) {
    case 842094169:  {
     break L1;
     break;
    }
    default: {
     label = 2;
     break L1;
    }
    }
   } else {
    switch ($0|0) {
    case 844715353:  {
     break L1;
     break;
    }
    default: {
     label = 2;
     break L1;
    }
    }
   }
  } else {
   $switch$split72D = ($0|0)<(1448433993);
   if ($switch$split72D) {
    switch ($0|0) {
    case 1431918169:  {
     break L1;
     break;
    }
    default: {
     label = 2;
     break L1;
    }
    }
   }
   $switch$split162D = ($0|0)<(1498831189);
   if ($switch$split162D) {
    switch ($0|0) {
    case 1448433993:  {
     break L1;
     break;
    }
    default: {
     label = 2;
     break L1;
    }
    }
   } else {
    switch ($0|0) {
    case 1498831189:  {
     break L1;
     break;
    }
    default: {
     label = 2;
     break L1;
    }
    }
   }
  }
 } while(0);
 if ((label|0) == 2) {
  (_SDL_SetError(195181,$vararg_buffer)|0);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (_SDL_calloc(1,64)|0);
 $4 = ($3|0)==(0|0);
 if ($4) {
  (_SDL_Error(0)|0);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$3>>2] = $0;
 $5 = ((($3)) + 4|0);
 HEAP32[$5>>2] = 0;
 $6 = ((($3)) + 8|0);
 HEAP32[$6>>2] = $1;
 $7 = ((($3)) + 12|0);
 HEAP32[$7>>2] = $2;
 $8 = $1 << 1;
 $9 = Math_imul($8, $2)|0;
 $10 = (_SDL_malloc($9)|0);
 $11 = ((($3)) + 16|0);
 HEAP32[$11>>2] = $10;
 $12 = (_SDL_malloc(4096)|0);
 $13 = ((($3)) + 20|0);
 HEAP32[$13>>2] = $12;
 $14 = (_SDL_malloc(9216)|0);
 $15 = ((($3)) + 24|0);
 HEAP32[$15>>2] = $14;
 $16 = HEAP32[$11>>2]|0;
 $17 = ($16|0)==(0|0);
 if (!($17)) {
  $18 = HEAP32[$13>>2]|0;
  $19 = ($18|0)==(0|0);
  $20 = ($14|0)==(0|0);
  $or$cond = $20 | $19;
  if (!($or$cond)) {
   $27 = ((($18)) + 1024|0);
   $28 = ((($18)) + 2048|0);
   $29 = ((($18)) + 3072|0);
   $$07879 = 0;
   while(1) {
    $30 = (($$07879) + -128)|0;
    $31 = (+($30|0));
    $32 = $31 * 1.4013377926421404;
    $33 = (~~(($32)));
    $34 = (($18) + ($$07879<<2)|0);
    HEAP32[$34>>2] = $33;
    $35 = $31 * -0.71360381861575184;
    $36 = (~~(($35)));
    $37 = (($27) + ($$07879<<2)|0);
    HEAP32[$37>>2] = $36;
    $38 = $31 * -0.34441087613293053;
    $39 = (~~(($38)));
    $40 = (($28) + ($$07879<<2)|0);
    HEAP32[$40>>2] = $39;
    $41 = $31 * 1.7734138972809665;
    $42 = (~~(($41)));
    $43 = (($29) + ($$07879<<2)|0);
    HEAP32[$43>>2] = $42;
    $44 = (($$07879) + 1)|0;
    $exitcond = ($44|0)==(256);
    if ($exitcond) {
     break;
    } else {
     $$07879 = $44;
    }
   }
   $switch$split12D = ($0|0)<(1431918169);
   L27: do {
    if ($switch$split12D) {
     $switch$split102D = ($0|0)<(844715353);
     if ($switch$split102D) {
      switch ($0|0) {
      case 842094169:  {
       label = 11;
       break L27;
       break;
      }
      default: {
       $$0 = $3;
      }
      }
      STACKTOP = sp;return ($$0|0);
     } else {
      switch ($0|0) {
      case 844715353:  {
       label = 12;
       break L27;
       break;
      }
      default: {
       $$0 = $3;
      }
      }
      STACKTOP = sp;return ($$0|0);
     }
    } else {
     $switch$split132D = ($0|0)<(1448433993);
     if ($switch$split132D) {
      switch ($0|0) {
      case 1431918169:  {
       label = 12;
       break L27;
       break;
      }
      default: {
       $$0 = $3;
      }
      }
      STACKTOP = sp;return ($$0|0);
     }
     $switch$split192D = ($0|0)<(1498831189);
     if ($switch$split192D) {
      switch ($0|0) {
      case 1448433993:  {
       label = 11;
       break L27;
       break;
      }
      default: {
       $$0 = $3;
      }
      }
      STACKTOP = sp;return ($$0|0);
     } else {
      switch ($0|0) {
      case 1498831189:  {
       label = 12;
       break L27;
       break;
      }
      default: {
       $$0 = $3;
      }
      }
      STACKTOP = sp;return ($$0|0);
     }
    }
   } while(0);
   if ((label|0) == 11) {
    $45 = $1&65535;
    $46 = ((($3)) + 36|0);
    HEAP16[$46>>1] = $45;
    $47 = $1 >>> 1;
    $48 = $47 & 32767;
    $49 = $48&65535;
    $50 = ((($3)) + 38|0);
    HEAP16[$50>>1] = $49;
    $51 = $1 & 65535;
    $div = ($45&65535) >>> 1;
    $52 = ((($3)) + 40|0);
    HEAP16[$52>>1] = $div;
    $53 = ((($3)) + 44|0);
    HEAP32[$53>>2] = $16;
    $54 = Math_imul($51, $2)|0;
    $55 = (($16) + ($54)|0);
    $56 = ((($3)) + 48|0);
    HEAP32[$56>>2] = $55;
    $57 = Math_imul($48, $2)|0;
    $58 = (($57|0) / 2)&-1;
    $59 = (($55) + ($58)|0);
    $$pre$phiZ2D = $53;$$sink = $59;$$sink3 = 2;
   }
   else if ((label|0) == 12) {
    $60 = $8&65535;
    $61 = ((($3)) + 36|0);
    HEAP16[$61>>1] = $60;
    $$pre = ((($3)) + 44|0);
    $$pre$phiZ2D = $$pre;$$sink = $16;$$sink3 = 0;
   }
   $62 = (($$pre$phiZ2D) + ($$sink3<<2)|0);
   HEAP32[$62>>2] = $$sink;
   $$0 = $3;
   STACKTOP = sp;return ($$0|0);
  }
 }
 _SDL_free($16);
 $21 = HEAP32[$13>>2]|0;
 _SDL_free($21);
 $22 = HEAP32[$15>>2]|0;
 _SDL_free($22);
 $23 = ((($3)) + 56|0);
 $24 = HEAP32[$23>>2]|0;
 _SDL_FreeSurface($24);
 $25 = ((($3)) + 60|0);
 $26 = HEAP32[$25>>2]|0;
 _SDL_FreeSurface($26);
 _SDL_free($3);
 (_SDL_Error(0)|0);
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _SDL_LogInfo($0,$1,$varargs) {
 $0 = $0|0;
 $1 = $1|0;
 $varargs = $varargs|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 HEAP32[$2>>2] = $varargs;
 _SDL_LogMessageV($0,3,$1,$2);
 STACKTOP = sp;return;
}
function _SDL_TouchQuit() {
 var $$in = 0, $$lcssa = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[53315]|0;
 $1 = ($0|0)==(0);
 $2 = HEAP32[53316]|0;
 if ($1) {
  $$lcssa = $2;
  _SDL_free($$lcssa);
  HEAP32[53316] = 0;
  return;
 } else {
  $$in = $0;$5 = $2;
 }
 while(1) {
  $3 = (($$in) + -1)|0;
  $4 = (($5) + ($3<<2)|0);
  $6 = HEAP32[$4>>2]|0;
  $7 = $6;
  $8 = $7;
  $9 = HEAP32[$8>>2]|0;
  $10 = (($7) + 4)|0;
  $11 = $10;
  $12 = HEAP32[$11>>2]|0;
  _SDL_DelTouch($9,$12);
  $13 = ($3|0)==(0);
  $14 = HEAP32[53316]|0;
  if ($13) {
   $$lcssa = $14;
   break;
  } else {
   $$in = $3;$5 = $14;
  }
 }
 _SDL_free($$lcssa);
 HEAP32[53316] = 0;
 return;
}
function _SDL_MouseQuit() {
 var $$$i = 0, $$0$i20 = 0, $$0$i20$phi = 0, $$022 = 0, $$024$i = 0, $$025$i$i = 0, $$lobit = 0, $$sink$i = 0, $$val$i = 0, $$val12$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $notlhs$i$i = 0, $notlhs$i$i18 = 0, $notrhs$i$i = 0, $or$cond27$not$i$i = 0, $or$cond29$i$i = 0, $or$cond29$i$i19 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[(209556)>>2]|0;
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (_SDL_GetKeyboardFocus()|0);
  $3 = ($2|0)==(0|0);
  if (!($3)) {
   $4 = ((($2)) + 48|0);
   $5 = HEAP32[$4>>2]|0;
   $$lobit = $5 & 16384;
   $6 = ($$lobit|0)==(0);
   if (!($6)) {
    $7 = HEAP32[(209556)>>2]|0;
    $8 = (FUNCTION_TABLE_ii[$7 & 8191](0)|0);
    $9 = ($8|0)==(-1);
    if (!($9)) {
     $10 = HEAP32[$4>>2]|0;
     $11 = $10 & -16385;
     HEAP32[$4>>2] = $11;
    }
   }
  }
 }
 (_SDL_SetRelativeMouseMode(0)|0);
 $12 = HEAP32[(209628)>>2]|0;
 HEAP32[(209628)>>2] = 1;
 $13 = ($12|0)==(1);
 do {
  if (!($13)) {
   $14 = HEAP32[(209568)>>2]|0;
   $15 = ($14|0)==(0|0);
   $$val$i = HEAP32[(209620)>>2]|0;
   $$val12$i = HEAP32[(209624)>>2]|0;
   $16 = $15 ? $$val$i : $$val12$i;
   $notlhs$i$i = ($16|0)!=(0|0);
   $17 = HEAP32[(209600)>>2]|0;
   $18 = ($17|0)==(0);
   $or$cond29$i$i = $notlhs$i$i & $18;
   $19 = HEAP32[(209532)>>2]|0;
   $20 = ($19|0)==(0|0);
   if ($or$cond29$i$i) {
    if ($20) {
     break;
    }
    (FUNCTION_TABLE_ii[$19 & 8191]($16)|0);
    break;
   } else {
    if ($20) {
     break;
    }
    (FUNCTION_TABLE_ii[$19 & 8191](0)|0);
    break;
   }
  }
 } while(0);
 $21 = HEAP32[(209616)>>2]|0;
 $22 = ($21|0)==(0|0);
 if (!($22)) {
  $$022 = $21;
  while(1) {
   $23 = HEAP32[$$022>>2]|0;
   $24 = HEAP32[(209620)>>2]|0;
   $25 = ($24|0)==($$022|0);
   L18: do {
    if (!($25)) {
     $27 = HEAP32[(209624)>>2]|0;
     $28 = ($27|0)==($$022|0);
     do {
      if ($28) {
       $29 = ($24|0)==(0|0);
       if ($29) {
        $30 = HEAP32[(209568)>>2]|0;
        $31 = ($30|0)==(0|0);
        $$$i = $31 ? 0 : $$022;
        $$025$i$i = $$$i;
       } else {
        HEAP32[(209624)>>2] = $24;
        $$025$i$i = $24;
       }
       $32 = HEAP32[(209628)>>2]|0;
       $notlhs$i$i18 = ($$025$i$i|0)!=(0|0);
       $notrhs$i$i = ($32|0)!=(0);
       $or$cond27$not$i$i = $notlhs$i$i18 & $notrhs$i$i;
       $33 = HEAP32[(209600)>>2]|0;
       $34 = ($33|0)==(0);
       $or$cond29$i$i19 = $or$cond27$not$i$i & $34;
       $35 = HEAP32[(209532)>>2]|0;
       $36 = ($35|0)==(0|0);
       if ($or$cond29$i$i19) {
        if ($36) {
         break;
        }
        (FUNCTION_TABLE_ii[$35 & 8191]($$025$i$i)|0);
        break;
       } else {
        if ($36) {
         break;
        }
        (FUNCTION_TABLE_ii[$35 & 8191](0)|0);
        break;
       }
      }
     } while(0);
     $37 = HEAP32[(209616)>>2]|0;
     $$0$i20 = 0;$$024$i = $37;
     while(1) {
      $38 = ($$024$i|0)==(0|0);
      if ($38) {
       break L18;
      }
      $39 = ($$024$i|0)==($$022|0);
      $40 = HEAP32[$$024$i>>2]|0;
      if ($39) {
       break;
      } else {
       $$0$i20$phi = $$024$i;$$024$i = $40;$$0$i20 = $$0$i20$phi;
      }
     }
     $41 = ($$0$i20|0)!=(0|0);
     $$sink$i = $41 ? $$0$i20 : (209616);
     HEAP32[$$sink$i>>2] = $40;
     $42 = HEAP32[(209540)>>2]|0;
     $43 = ($42|0)==(0|0);
     if (!($43)) {
      FUNCTION_TABLE_vi[$42 & 8191]($$022);
     }
    }
   } while(0);
   $26 = ($23|0)==(0|0);
   if ($26) {
    break;
   } else {
    $$022 = $23;
   }
  }
 }
 $44 = HEAP32[(209620)>>2]|0;
 $45 = ($44|0)==(0|0);
 if (!($45)) {
  $46 = HEAP32[(209540)>>2]|0;
  $47 = ($46|0)==(0|0);
  if (!($47)) {
   FUNCTION_TABLE_vi[$46 & 8191]($44);
  }
 }
 $48 = HEAP32[(209612)>>2]|0;
 $49 = ($48|0)==(0|0);
 if ($49) {
  (_SDL_memset(209524,0,112)|0);
  return;
 }
 _SDL_free($48);
 (_SDL_memset(209524,0,112)|0);
 return;
}
function _SDL_KeyboardQuit() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function _SDL_QuitSubSystem($0) {
 $0 = $0|0;
 var $$0 = 0, $$1 = 0, $$2 = 0, $$pre = 0, $$pre19 = 0, $$pre20 = 0, $$pre21 = 0, $$pre22 = 0, $$pre23 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = $0 & 8192;
 $2 = ($1|0)==(0);
 if ($2) {
  $$0 = $0;
 } else {
  $3 = $0 | 512;
  $4 = HEAP8[(219439)>>0]|0;
  $5 = ($4<<24>>24)==(0);
  $6 = ($4<<24>>24)==(1);
  $7 = $6&1;
  $8 = HEAP32[53376]|0;
  $9 = $7 | $8;
  $10 = ($9|0)==(0);
  $11 = $5 | $10;
  if ($11) {
   $12 = $4;
  } else {
   _SDL_GameControllerQuit();
   $$pre = HEAP8[(219439)>>0]|0;
   $12 = $$pre;
  }
  $13 = ($12<<24>>24)==(0);
  if ($13) {
   $$0 = $3;
  } else {
   $14 = (($12) + -1)<<24>>24;
   HEAP8[(219439)>>0] = $14;
   $$0 = $3;
  }
 }
 $15 = $$0 & 512;
 $16 = ($15|0)==(0);
 if ($16) {
  $$1 = $$0;
 } else {
  $17 = $$0 | 16384;
  $18 = HEAP8[(219435)>>0]|0;
  $19 = ($18<<24>>24)==(0);
  $20 = ($18<<24>>24)==(1);
  $21 = $20&1;
  $22 = HEAP32[53376]|0;
  $23 = $21 | $22;
  $24 = ($23|0)==(0);
  $25 = $19 | $24;
  if ($25) {
   $26 = $18;
  } else {
   _SDL_JoystickQuit();
   $$pre19 = HEAP8[(219435)>>0]|0;
   $26 = $$pre19;
  }
  $27 = ($26<<24>>24)==(0);
  if ($27) {
   $$1 = $17;
  } else {
   $28 = (($26) + -1)<<24>>24;
   HEAP8[(219435)>>0] = $28;
   $$1 = $17;
  }
 }
 $29 = $$1 & 16;
 $30 = ($29|0)==(0);
 if (!($30)) {
  $31 = HEAP8[(219430)>>0]|0;
  $32 = ($31<<24>>24)==(0);
  $33 = ($31<<24>>24)==(1);
  $34 = $33&1;
  $35 = HEAP32[53376]|0;
  $36 = $34 | $35;
  $37 = ($36|0)==(0);
  $38 = $32 | $37;
  if ($38) {
   $39 = $31;
  } else {
   _SDL_AudioQuit();
   $$pre20 = HEAP8[(219430)>>0]|0;
   $39 = $$pre20;
  }
  $40 = ($39<<24>>24)==(0);
  if (!($40)) {
   $41 = (($39) + -1)<<24>>24;
   HEAP8[(219430)>>0] = $41;
  }
 }
 $42 = $$1 & 32;
 $43 = ($42|0)==(0);
 if ($43) {
  $$2 = $$1;
 } else {
  $44 = $$1 | 16384;
  $45 = HEAP8[(219431)>>0]|0;
  $46 = ($45<<24>>24)==(0);
  $47 = ($45<<24>>24)==(1);
  $48 = $47&1;
  $49 = HEAP32[53376]|0;
  $50 = $48 | $49;
  $51 = ($50|0)==(0);
  $52 = $46 | $51;
  if ($52) {
   $53 = $45;
  } else {
   _SDL_VideoQuit();
   $$pre21 = HEAP8[(219431)>>0]|0;
   $53 = $$pre21;
  }
  $54 = ($53<<24>>24)==(0);
  if ($54) {
   $$2 = $44;
  } else {
   $55 = (($53) + -1)<<24>>24;
   HEAP8[(219431)>>0] = $55;
   $$2 = $44;
  }
 }
 $56 = $$2 & 1;
 $57 = ($56|0)==(0);
 if (!($57)) {
  $58 = HEAP8[219426]|0;
  $59 = ($58<<24>>24)==(0);
  $60 = ($58<<24>>24)==(1);
  $61 = $60&1;
  $62 = HEAP32[53376]|0;
  $63 = $61 | $62;
  $64 = ($63|0)==(0);
  $65 = $59 | $64;
  if ($65) {
   $66 = $58;
  } else {
   $$pre22 = HEAP8[219426]|0;
   $66 = $$pre22;
  }
  $67 = ($66<<24>>24)==(0);
  if (!($67)) {
   $68 = (($66) + -1)<<24>>24;
   HEAP8[219426] = $68;
  }
 }
 $69 = $$2 & 16384;
 $70 = ($69|0)==(0);
 if ($70) {
  return;
 }
 $71 = HEAP8[(219440)>>0]|0;
 $72 = ($71<<24>>24)==(0);
 $73 = ($71<<24>>24)==(1);
 $74 = $73&1;
 $75 = HEAP32[53376]|0;
 $76 = $74 | $75;
 $77 = ($76|0)==(0);
 $78 = $72 | $77;
 if ($78) {
  $79 = $71;
 } else {
  _SDL_QuitQuit();
  _SDL_StopEventLoop();
  $$pre23 = HEAP8[(219440)>>0]|0;
  $79 = $$pre23;
 }
 $80 = ($79<<24>>24)==(0);
 if ($80) {
  return;
 }
 $81 = (($79) + -1)<<24>>24;
 HEAP8[(219440)>>0] = $81;
 return;
}
function _SDL_DestroyWindow($0) {
 $0 = $0|0;
 var $$0$i = 0, $$pre = 0, $$pre39 = 0, $$sink = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $vararg_buffer3 = sp + 16|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $1 = HEAP32[52375]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  (_SDL_SetError(175439,$vararg_buffer)|0);
  STACKTOP = sp;return;
 }
 $3 = ($0|0)==(0|0);
 if (!($3)) {
  $4 = HEAP32[$0>>2]|0;
  $5 = ((($1)) + 280|0);
  $6 = ($4|0)==($5|0);
  if ($6) {
   $7 = ((($0)) + 120|0);
   HEAP32[$7>>2] = 1;
   $8 = ((($0)) + 48|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = $9 & 4;
   $11 = ($10|0)==(0);
   if (!($11)) {
    $12 = ((($0)) + 116|0);
    HEAP32[$12>>2] = 1;
    (_SDL_UpdateFullscreenMode($0,0)|0);
    $13 = HEAP32[52375]|0;
    $14 = ((($13)) + 84|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = ($15|0)==(0|0);
    if (!($16)) {
     FUNCTION_TABLE_vii[$15 & 8191]($13,$0);
    }
    HEAP32[$12>>2] = 0;
    (_SDL_SendWindowEvent($0,2,0,0)|0);
   }
   $17 = (_SDL_GetKeyboardFocus()|0);
   $18 = ($17|0)==($0|0);
   if ($18) {
    _SDL_SetKeyboardFocus(0);
   }
   $19 = (_SDL_GetMouseFocus()|0);
   $20 = ($19|0)==($0|0);
   if ($20) {
    _SDL_SetMouseFocus(0);
   }
   $21 = ((($0)) + 48|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = $22 & 2;
   $24 = ($23|0)==(0);
   if (!($24)) {
    $25 = HEAP32[52375]|0;
    $26 = ((($25)) + 652|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = ($27|0)==($0|0);
    if ($28) {
     (_SDL_GL_MakeCurrent($0,0)|0);
    }
   }
   $29 = ((($0)) + 108|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = ($30|0)==(0|0);
   if (!($31)) {
    $32 = HEAP32[$30>>2]|0;
    $33 = $32 & -5;
    HEAP32[$30>>2] = $33;
    _SDL_FreeSurface($30);
   }
   $34 = HEAP32[52375]|0;
   $35 = ((($34)) + 140|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = ($36|0)==(0|0);
   if ($37) {
    $39 = $34;
   } else {
    FUNCTION_TABLE_vii[$36 & 8191]($34,$0);
    $$pre = HEAP32[52375]|0;
    $39 = $$pre;
   }
   $38 = ((($39)) + 128|0);
   $40 = HEAP32[$38>>2]|0;
   $41 = ($40|0)==(0|0);
   if (!($41)) {
    FUNCTION_TABLE_vii[$40 & 8191]($39,$0);
   }
   $42 = HEAP32[$21>>2]|0;
   $43 = $42 & 2;
   $44 = ($43|0)==(0);
   do {
    if (!($44)) {
     $45 = HEAP32[52375]|0;
     $46 = ($45|0)==(0|0);
     if ($46) {
      (_SDL_SetError(175439,$vararg_buffer3)|0);
      break;
     }
     $47 = ((($45)) + 388|0);
     $48 = HEAP32[$47>>2]|0;
     $49 = ($48|0)>(0);
     if ($49) {
      $50 = (($48) + -1)|0;
      HEAP32[$47>>2] = $50;
      $51 = ($48|0)==(1);
      if ($51) {
       $52 = ((($45)) + 172|0);
       $53 = HEAP32[$52>>2]|0;
       $54 = ($53|0)==(0|0);
       if (!($54)) {
        FUNCTION_TABLE_vi[$53 & 8191]($45);
       }
      }
     }
    }
   } while(0);
   $55 = (_SDL_GetWindowDisplayIndex($0)|0);
   $56 = ($55|0)>(-1);
   if ($56) {
    $57 = HEAP32[52375]|0;
    $58 = ((($57)) + 268|0);
    $59 = HEAP32[$58>>2]|0;
    $60 = (($59) + (($55*68)|0)|0);
    $$0$i = $60;
   } else {
    $$0$i = 0;
   }
   $61 = ((($$0$i)) + 56|0);
   $62 = HEAP32[$61>>2]|0;
   $63 = ($62|0)==($0|0);
   if ($63) {
    HEAP32[$61>>2] = 0;
   }
   HEAP32[$0>>2] = 0;
   $64 = ((($0)) + 8|0);
   $65 = HEAP32[$64>>2]|0;
   _SDL_free($65);
   $66 = ((($0)) + 12|0);
   $67 = HEAP32[$66>>2]|0;
   _SDL_FreeSurface($67);
   $68 = ((($0)) + 100|0);
   $69 = HEAP32[$68>>2]|0;
   _SDL_free($69);
   $70 = ((($0)) + 140|0);
   $71 = HEAP32[$70>>2]|0;
   $72 = ($71|0)==(0|0);
   if (!($72)) {
    $74 = $71;
    while(1) {
     $73 = ((($74)) + 8|0);
     $75 = HEAP32[$73>>2]|0;
     HEAP32[$70>>2] = $75;
     $76 = HEAP32[$74>>2]|0;
     _SDL_free($76);
     _SDL_free($74);
     $77 = HEAP32[$70>>2]|0;
     $78 = ($77|0)==(0|0);
     if ($78) {
      break;
     } else {
      $74 = $77;
     }
    }
   }
   $79 = ((($0)) + 152|0);
   $80 = HEAP32[$79>>2]|0;
   $81 = ($80|0)==(0|0);
   $$pre39 = ((($0)) + 148|0);
   if (!($81)) {
    $82 = HEAP32[$$pre39>>2]|0;
    $83 = ((($80)) + 148|0);
    HEAP32[$83>>2] = $82;
   }
   $84 = HEAP32[$$pre39>>2]|0;
   $85 = ($84|0)==(0|0);
   $86 = HEAP32[52375]|0;
   $87 = ((($86)) + 272|0);
   $88 = ((($84)) + 152|0);
   $$sink = $85 ? $87 : $88;
   HEAP32[$$sink>>2] = $80;
   _SDL_free($0);
   STACKTOP = sp;return;
  }
 }
 (_SDL_SetError(195204,$vararg_buffer1)|0);
 STACKTOP = sp;return;
}
function _SDL_GameControllerQuit() {
 var $$016$i = 0, $$01619$i = 0, $$01621$i = 0, $$020$i = 0, $$020$i$phi = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[53355]|0;
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $5 = $0;
  while(1) {
   $4 = ((($5)) + 4|0);
   HEAP32[$4>>2] = 0;
   $6 = HEAP32[$5>>2]|0;
   _SDL_JoystickClose($6);
   $$01619$i = HEAP32[53355]|0;
   $7 = ($$01619$i|0)==(0|0);
   L4: do {
    if (!($7)) {
     $$01621$i = $$01619$i;$$020$i = 0;
     while(1) {
      $8 = ($$01621$i|0)==($5|0);
      if ($8) {
       break;
      }
      $13 = ((($$01621$i)) + 1344|0);
      $$016$i = HEAP32[$13>>2]|0;
      $14 = ($$016$i|0)==(0|0);
      if ($14) {
       break L4;
      } else {
       $$020$i$phi = $$01621$i;$$01621$i = $$016$i;$$020$i = $$020$i$phi;
      }
     }
     $9 = ($$020$i|0)==(0|0);
     $10 = ((($5)) + 1344|0);
     $11 = HEAP32[$10>>2]|0;
     if ($9) {
      HEAP32[53355] = $11;
      break;
     } else {
      $12 = ((($$020$i)) + 1344|0);
      HEAP32[$12>>2] = $11;
      break;
     }
    }
   } while(0);
   _SDL_free($5);
   $15 = HEAP32[53355]|0;
   $16 = ($15|0)==(0|0);
   if ($16) {
    break;
   } else {
    $5 = $15;
   }
  }
 }
 $2 = HEAP32[53350]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  _SDL_DelEventWatch(4474,0);
  return;
 } else {
  $18 = $2;
 }
 while(1) {
  $17 = ((($18)) + 24|0);
  $19 = HEAP32[$17>>2]|0;
  HEAP32[53350] = $19;
  $20 = ((($18)) + 16|0);
  $21 = HEAP32[$20>>2]|0;
  _SDL_free($21);
  $22 = ((($18)) + 20|0);
  $23 = HEAP32[$22>>2]|0;
  _SDL_free($23);
  _SDL_free($18);
  $24 = HEAP32[53350]|0;
  $25 = ($24|0)==(0|0);
  if ($25) {
   break;
  } else {
   $18 = $24;
  }
 }
 _SDL_DelEventWatch(4474,0);
 return;
}
function _SDL_JoystickQuit() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[53377]|0;
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $3 = $0;
  while(1) {
   $2 = ((($3)) + 48|0);
   HEAP32[$2>>2] = 1;
   _SDL_JoystickClose($3);
   $4 = HEAP32[53377]|0;
   $5 = ($4|0)==(0|0);
   if ($5) {
    break;
   } else {
    $3 = $4;
   }
  }
 }
 _SDL_SYS_JoystickQuit();
 _SDL_QuitSubSystem(16384);
 return;
}
function _SDL_TimerQuit() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function _SDL_QuitQuit() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(144|0);
 $0 = sp;
 (_sigaction(2,(0|0),($0|0))|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(4453|0);
 if ($2) {
  HEAP32[$0>>2] = 0;
  (_sigaction(2,($0|0),(0|0))|0);
 }
 (_sigaction(15,(0|0),($0|0))|0);
 $3 = HEAP32[$0>>2]|0;
 $4 = ($3|0)==(4453|0);
 if (!($4)) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 0;
 (_sigaction(15,($0|0),(0|0))|0);
 STACKTOP = sp;return;
}
function _SDL_StopEventLoop() {
 var $$04151 = 0, $$046 = 0, $$14247 = 0, $$in4459 = 0, $$in4555 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $0 = (_SDL_GetHint(195432)|0);
 $1 = HEAP32[22156]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
 }
 (_SDL_AtomicSet((88628),0)|0);
 $3 = ($0|0)==(0|0);
 if (!($3)) {
  $4 = (_SDL_atoi($0)|0);
  $5 = ($4|0)==(0);
  if (!($5)) {
   $6 = HEAP32[(88636)>>2]|0;
   HEAP32[$vararg_buffer>>2] = $6;
   _SDL_Log(195459,$vararg_buffer);
  }
 }
 $7 = HEAP32[(88640)>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $$in4459 = $7;
  while(1) {
   $9 = ((($$in4459)) + 72|0);
   $10 = HEAP32[$9>>2]|0;
   _SDL_free($$in4459);
   $11 = ($10|0)==(0|0);
   if ($11) {
    break;
   } else {
    $$in4459 = $10;
   }
  }
 }
 $12 = HEAP32[(88648)>>2]|0;
 $13 = ($12|0)==(0|0);
 if (!($13)) {
  $$in4555 = $12;
  while(1) {
   $14 = ((($$in4555)) + 72|0);
   $15 = HEAP32[$14>>2]|0;
   _SDL_free($$in4555);
   $16 = ($15|0)==(0|0);
   if ($16) {
    break;
   } else {
    $$in4555 = $15;
   }
  }
 }
 $17 = HEAP32[(88652)>>2]|0;
 $18 = ($17|0)==(0|0);
 if (!($18)) {
  $$04151 = $17;
  while(1) {
   $19 = ((($$04151)) + 12|0);
   $20 = HEAP32[$19>>2]|0;
   _SDL_free($$04151);
   $21 = ($20|0)==(0|0);
   if ($21) {
    break;
   } else {
    $$04151 = $20;
   }
  }
 }
 $22 = HEAP32[(88656)>>2]|0;
 $23 = ($22|0)==(0|0);
 if (!($23)) {
  $$14247 = $22;
  while(1) {
   $24 = ((($$14247)) + 12|0);
   $25 = HEAP32[$24>>2]|0;
   _SDL_free($$14247);
   $26 = ($25|0)==(0|0);
   if ($26) {
    break;
   } else {
    $$14247 = $25;
   }
  }
 }
 (_SDL_AtomicSet((88632),0)|0);
 ;HEAP32[(88636)>>2]=0|0;HEAP32[(88636)+4>>2]=0|0;HEAP32[(88636)+8>>2]=0|0;HEAP32[(88636)+12>>2]=0|0;HEAP32[(88636)+16>>2]=0|0;HEAP32[(88636)+20>>2]=0|0;
 $$046 = 0;
 while(1) {
  $29 = (209640 + ($$046<<2)|0);
  $30 = HEAP32[$29>>2]|0;
  _SDL_free($30);
  HEAP32[$29>>2] = 0;
  $31 = (($$046) + 1)|0;
  $exitcond = ($31|0)==(256);
  if ($exitcond) {
   break;
  } else {
   $$046 = $31;
  }
 }
 $27 = HEAP32[52666]|0;
 $28 = ($27|0)==(0|0);
 if (!($28)) {
  $33 = $27;
  while(1) {
   $32 = ((($33)) + 8|0);
   $34 = HEAP32[$32>>2]|0;
   HEAP32[52666] = $34;
   _SDL_free($33);
   $35 = HEAP32[52666]|0;
   $36 = ($35|0)==(0|0);
   if ($36) {
    break;
   } else {
    $33 = $35;
   }
  }
 }
 HEAP32[52369] = 0;
 $37 = HEAP32[22156]|0;
 $38 = ($37|0)==(0|0);
 if ($38) {
  STACKTOP = sp;return;
 }
 $39 = HEAP32[22156]|0;
 _SDL_DestroyMutex($39);
 HEAP32[22156] = 0;
 STACKTOP = sp;return;
}
function _SDL_Log($0,$varargs) {
 $0 = $0|0;
 $varargs = $varargs|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 HEAP32[$1>>2] = $varargs;
 _SDL_LogMessageV(0,3,$0,$1);
 STACKTOP = sp;return;
}
function _SDL_HandleSIG($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (_signal(($0|0),(4453|0))|0);
 HEAP32[52409] = 1;
 return;
}
function _SDL_JoystickClose($0) {
 $0 = $0|0;
 var $$023 = 0, $$02327 = 0, $$02329 = 0, $$028 = 0, $$028$phi = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ($0|0)==(0|0);
 if ($1) {
  return;
 }
 $2 = ((($0)) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + -1)|0;
 HEAP32[$2>>2] = $4;
 $5 = ($3|0)>(1);
 $6 = HEAP32[53378]|0;
 $7 = ($6|0)==($0|0);
 $or$cond = $5 | $7;
 if ($or$cond) {
  return;
 }
 _SDL_SYS_JoystickClose($0);
 $8 = ((($0)) + 44|0);
 HEAP32[$8>>2] = 0;
 $$02327 = HEAP32[53377]|0;
 $9 = ($$02327|0)==(0|0);
 L7: do {
  if (!($9)) {
   $$02329 = $$02327;$$028 = 0;
   while(1) {
    $10 = ($$02329|0)==($0|0);
    if ($10) {
     break;
    }
    $15 = ((($$02329)) + 60|0);
    $$023 = HEAP32[$15>>2]|0;
    $16 = ($$023|0)==(0|0);
    if ($16) {
     break L7;
    } else {
     $$028$phi = $$02329;$$02329 = $$023;$$028 = $$028$phi;
    }
   }
   $11 = ($$028|0)==(0|0);
   $12 = ((($0)) + 60|0);
   $13 = HEAP32[$12>>2]|0;
   if ($11) {
    HEAP32[53377] = $13;
    break;
   } else {
    $14 = ((($$028)) + 60|0);
    HEAP32[$14>>2] = $13;
    break;
   }
  }
 } while(0);
 $17 = ((($0)) + 4|0);
 $18 = HEAP32[$17>>2]|0;
 _SDL_free($18);
 $19 = ((($0)) + 12|0);
 $20 = HEAP32[$19>>2]|0;
 _SDL_free($20);
 $21 = ((($0)) + 24|0);
 $22 = HEAP32[$21>>2]|0;
 _SDL_free($22);
 $23 = ((($0)) + 32|0);
 $24 = HEAP32[$23>>2]|0;
 _SDL_free($24);
 $25 = ((($0)) + 40|0);
 $26 = HEAP32[$25>>2]|0;
 _SDL_free($26);
 _SDL_free($0);
 return;
}
function _SDL_SYS_JoystickQuit() {
 var $$in910 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[53353]|0;
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $$in910 = $0;
  while(1) {
   $2 = ((($$in910)) + 1320|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = ((($$in910)) + 8|0);
   $5 = HEAP32[$4>>2]|0;
   _SDL_free($5);
   $6 = ((($$in910)) + 4|0);
   $7 = HEAP32[$6>>2]|0;
   _SDL_free($7);
   _SDL_free($$in910);
   $8 = ($3|0)==(0|0);
   if ($8) {
    break;
   } else {
    $$in910 = $3;
   }
  }
 }
 HEAP32[53356] = 0;
 HEAP32[53353] = 0;
 HEAP32[53354] = 0;
 HEAP32[53357] = 0;
 (_emscripten_set_gamepadconnected_callback((0|0),0,(0|0))|0);
 (_emscripten_set_gamepaddisconnected_callback((0|0),0,(0|0))|0);
 return;
}
function _SDL_SYS_JoystickClose($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 44|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  return;
 }
 $4 = ((($2)) + 16|0);
 HEAP32[$4>>2] = 0;
 return;
}
function _SDL_SetRelativeMouseMode($0) {
 $0 = $0|0;
 var $$pr$i = 0, $$sink = 0, $$val = 0, $$val41 = 0, $$val42 = 0, $$val43 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $not$$i = 0, $not$$i38 = 0;
 var $notlhs$i = 0, $notlhs$i$i = 0, $notrhs$i = 0, $notrhs$i$i = 0, $or$cond = 0, $or$cond27$not$i = 0, $or$cond27$not$i$i = 0, $or$cond29$i = 0, $or$cond29$i$i = 0, $or$cond3 = 0, $or$cond35 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (_SDL_GetKeyboardFocus()|0);
 $2 = HEAP32[(209600)>>2]|0;
 $3 = ($2|0)==($0|0);
 if ($3) {
  return 0;
 }
 $4 = ($0|0)!=(0);
 $5 = ($1|0)!=(0|0);
 $or$cond = $4 & $5;
 do {
  if ($or$cond) {
   $6 = HEAP32[(209568)>>2]|0;
   $7 = ($6|0)==($1|0);
   do {
    if (!($7)) {
     $8 = ($6|0)==(0|0);
     if (!($8)) {
      (_SDL_SendWindowEvent($6,11,0,0)|0);
     }
     HEAP32[(209568)>>2] = $1;
     (_SDL_SendWindowEvent($1,10,0,0)|0);
     $$pr$i = HEAP32[(209568)>>2]|0;
     $9 = ($$pr$i|0)==(0|0);
     $$val42 = HEAP32[(209620)>>2]|0;
     $$val43 = HEAP32[(209624)>>2]|0;
     $10 = $9 ? $$val42 : $$val43;
     $11 = HEAP32[(209628)>>2]|0;
     $notlhs$i$i = ($10|0)!=(0|0);
     $notrhs$i$i = ($11|0)!=(0);
     $or$cond27$not$i$i = $notlhs$i$i & $notrhs$i$i;
     $12 = HEAP32[(209600)>>2]|0;
     $13 = ($12|0)==(0);
     $or$cond29$i$i = $or$cond27$not$i$i & $13;
     $14 = HEAP32[(209532)>>2]|0;
     $15 = ($14|0)==(0|0);
     if ($or$cond29$i$i) {
      if ($15) {
       break;
      }
      (FUNCTION_TABLE_ii[$14 & 8191]($10)|0);
      break;
     } else {
      if ($15) {
       break;
      }
      (FUNCTION_TABLE_ii[$14 & 8191](0)|0);
      break;
     }
    }
   } while(0);
   $16 = ((($1)) + 24|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (($17|0) / 2)&-1;
   $19 = ((($1)) + 28|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($20|0) / 2)&-1;
   $22 = HEAP32[(209544)>>2]|0;
   $23 = ($22|0)==(0|0);
   if (!($23)) {
    FUNCTION_TABLE_viii[$22 & 8191]($1,$18,$21);
    break;
   }
   $24 = HEAP32[(209564)>>2]|0;
   $25 = (_SDL_UpdateMouseFocus($1,$18,$21)|0);
   $not$$i = ($25|0)==(0);
   if (!($not$$i)) {
    (_SDL_PrivateSendMouseMotion($1,$24,0,$18,$21)|0);
   }
  }
 } while(0);
 $26 = HEAP32[(209604)>>2]|0;
 $27 = ($26|0)==(0);
 $or$cond35 = $4 | $27;
 do {
  if ($or$cond35) {
   if ($4) {
    $28 = HEAP32[(209552)>>2]|0;
    $29 = ($28|0)==(0|0);
    if ($29) {
     $$sink = 1;
     label = 20;
     break;
    }
    $30 = (_SDL_GetHintBoolean(195506,0)|0);
    $31 = ($30|0)==(0);
    if (!($31)) {
     $$sink = 1;
     label = 20;
     break;
    }
   }
   $32 = HEAP32[(209552)>>2]|0;
   $33 = (FUNCTION_TABLE_ii[$32 & 8191]($0)|0);
   $34 = ($33|0)<(0);
   $or$cond3 = $4 & $34;
   if ($or$cond3) {
    $$sink = 1;
    label = 20;
   }
  } else {
   $$sink = 0;
   label = 20;
  }
 } while(0);
 if ((label|0) == 20) {
  HEAP32[(209604)>>2] = $$sink;
 }
 HEAP32[(209600)>>2] = $0;
 $35 = HEAP32[(209568)>>2]|0;
 $36 = ($35|0)==(0|0);
 do {
  if (!($36)) {
   _SDL_UpdateWindowGrab($35);
   if (!($4)) {
    $37 = HEAP32[(209568)>>2]|0;
    $38 = HEAP32[(209572)>>2]|0;
    $39 = HEAP32[(209576)>>2]|0;
    $40 = ($37|0)==(0|0);
    if (!($40)) {
     $41 = HEAP32[(209544)>>2]|0;
     $42 = ($41|0)==(0|0);
     if (!($42)) {
      FUNCTION_TABLE_viii[$41 & 8191]($37,$38,$39);
      break;
     }
     $43 = HEAP32[(209564)>>2]|0;
     $44 = (_SDL_UpdateMouseFocus($37,$38,$39)|0);
     $not$$i38 = ($44|0)==(0);
     if (!($not$$i38)) {
      (_SDL_PrivateSendMouseMotion($37,$43,0,$38,$39)|0);
     }
    }
   }
  }
 } while(0);
 _SDL_FlushEvent(1024);
 $45 = HEAP32[(209568)>>2]|0;
 $46 = ($45|0)==(0|0);
 $$val = HEAP32[(209620)>>2]|0;
 $$val41 = HEAP32[(209624)>>2]|0;
 $47 = $46 ? $$val : $$val41;
 $48 = HEAP32[(209628)>>2]|0;
 $notlhs$i = ($47|0)!=(0|0);
 $notrhs$i = ($48|0)!=(0);
 $or$cond27$not$i = $notlhs$i & $notrhs$i;
 $49 = HEAP32[(209600)>>2]|0;
 $50 = ($49|0)==(0);
 $or$cond29$i = $or$cond27$not$i & $50;
 $51 = HEAP32[(209532)>>2]|0;
 $52 = ($51|0)==(0|0);
 if ($or$cond29$i) {
  if ($52) {
   return 0;
  }
  (FUNCTION_TABLE_ii[$51 & 8191]($47)|0);
  return 0;
 } else {
  if ($52) {
   return 0;
  }
  (FUNCTION_TABLE_ii[$51 & 8191](0)|0);
  return 0;
 }
 return (0)|0;
}
function _SDL_UpdateWindowGrab($0) {
 $0 = $0|0;
 var $$0 = 0, $$pre = 0, $$sink = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $not$or$cond18 = 0, $not$or$cond18$demorgan = 0, $or$cond18 = 0, $or$cond19 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (_SDL_GetMouse()|0);
 $2 = ((($1)) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 48|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5 & 256;
 $7 = $6 | $3;
 $8 = ($7|0)==(0);
 $9 = $5 & 512;
 $10 = ($9|0)==(0);
 $or$cond18 = $10 | $8;
 $not$or$cond18$demorgan = $10 | $8;
 $not$or$cond18 = $not$or$cond18$demorgan ^ 1;
 $$0 = $not$or$cond18&1;
 $11 = HEAP32[52375]|0;
 $12 = ((($11)) + 276|0);
 $13 = HEAP32[$12>>2]|0;
 if ($or$cond18) {
  $22 = ($13|0)==($0|0);
  if ($22) {
   $$sink = 0;$24 = $11;
   label = 6;
  } else {
   $26 = $11;
  }
 } else {
  $14 = ($13|0)==(0|0);
  $15 = ($13|0)==($0|0);
  $or$cond19 = $14 | $15;
  if ($or$cond19) {
   $$sink = $0;$24 = $11;
   label = 6;
  } else {
   $16 = ((($13)) + 48|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = $17 & -257;
   HEAP32[$16>>2] = $18;
   $19 = ((($11)) + 124|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = ($20|0)==(0|0);
   if ($21) {
    $$sink = $0;$24 = $11;
    label = 6;
   } else {
    FUNCTION_TABLE_viii[$20 & 8191]($11,$13,0);
    $$pre = HEAP32[52375]|0;
    $$sink = $0;$24 = $$pre;
    label = 6;
   }
  }
 }
 if ((label|0) == 6) {
  $23 = ((($24)) + 276|0);
  HEAP32[$23>>2] = $$sink;
  $26 = $24;
 }
 $25 = ((($26)) + 124|0);
 $27 = HEAP32[$25>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  return;
 }
 FUNCTION_TABLE_viii[$27 & 8191]($26,$0,$$0);
 return;
}
function _SDL_FlushEvent($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 _SDL_FlushEvents($0,$0);
 return;
}
function _SDL_DelTouch($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$ph = 0, $$020 = 0, $$089$i = 0, $$089$i$i = 0, $$lcssa = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $2 = HEAP32[53315]|0;
 $3 = ($2|0)>(0);
 L1: do {
  if ($3) {
   $4 = HEAP32[53316]|0;
   $$089$i = 0;
   while(1) {
    $5 = (($4) + ($$089$i<<2)|0);
    $6 = HEAP32[$5>>2]|0;
    $7 = $6;
    $8 = $7;
    $9 = HEAP32[$8>>2]|0;
    $10 = (($7) + 4)|0;
    $11 = $10;
    $12 = HEAP32[$11>>2]|0;
    $13 = ($9|0)==($0|0);
    $14 = ($12|0)==($1|0);
    $15 = $13 & $14;
    if ($15) {
     $$0$i$ph = $$089$i;
     break;
    }
    $16 = (($$089$i) + 1)|0;
    $17 = ($16|0)<($2|0);
    if ($17) {
     $$089$i = $16;
    } else {
     $$0$i$ph = -1;
     break;
    }
   }
   $$089$i$i = 0;
   while(1) {
    $18 = (($4) + ($$089$i$i<<2)|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = $19;
    $21 = $20;
    $22 = HEAP32[$21>>2]|0;
    $23 = (($20) + 4)|0;
    $24 = $23;
    $25 = HEAP32[$24>>2]|0;
    $26 = ($22|0)==($0|0);
    $27 = ($25|0)==($1|0);
    $28 = $26 & $27;
    if ($28) {
     break;
    }
    $29 = (($$089$i$i) + 1)|0;
    $30 = ($29|0)<($2|0);
    if ($30) {
     $$089$i$i = $29;
    } else {
     break L1;
    }
   }
   $31 = ($$089$i$i|0)>(-1);
   $32 = ($$089$i$i|0)<($2|0);
   $or$cond$i = $31 & $32;
   if ($or$cond$i) {
    $33 = ($19|0)==(0|0);
    if ($33) {
     STACKTOP = sp;return;
    }
    $34 = ((($19)) + 12|0);
    $35 = HEAP32[$34>>2]|0;
    $36 = ($35|0)>(0);
    $37 = ((($19)) + 16|0);
    $38 = HEAP32[$37>>2]|0;
    if ($36) {
     $$020 = 0;$40 = $38;
     while(1) {
      $39 = (($40) + ($$020<<2)|0);
      $41 = HEAP32[$39>>2]|0;
      _SDL_free($41);
      $42 = (($$020) + 1)|0;
      $43 = HEAP32[$34>>2]|0;
      $44 = ($42|0)<($43|0);
      $45 = HEAP32[$37>>2]|0;
      if ($44) {
       $$020 = $42;$40 = $45;
      } else {
       $$lcssa = $45;
       break;
      }
     }
    } else {
     $$lcssa = $38;
    }
    _SDL_free($$lcssa);
    _SDL_free($19);
    $46 = HEAP32[53315]|0;
    $47 = (($46) + -1)|0;
    HEAP32[53315] = $47;
    $48 = HEAP32[53316]|0;
    $49 = (($48) + ($47<<2)|0);
    $50 = HEAP32[$49>>2]|0;
    $51 = (($48) + ($$0$i$ph<<2)|0);
    HEAP32[$51>>2] = $50;
    STACKTOP = sp;return;
   }
  }
 } while(0);
 (_SDL_SetError(185893,$vararg_buffer)|0);
 STACKTOP = sp;return;
}
function _SDL_Init($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (_SDL_InitSubSystem($0)|0);
 return ($1|0);
}
function _SDL_Quit() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[53376] = 1;
 _SDL_QuitSubSystem(29233);
 _SDL_TicksQuit();
 _SDL_ClearHints();
 _SDL_AssertionsQuit();
 _SDL_LogResetPriorities();
 (_SDL_memset(219426,0,32)|0);
 HEAP32[53376] = 0;
 return;
}
function _SDL_TicksQuit() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[52667] = 0;
 return;
}
function _SDL_ClearHints() {
 var $$in1415 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[52378]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  return;
 } else {
  $3 = $0;
 }
 while(1) {
  $2 = ((($3)) + 16|0);
  $4 = HEAP32[$2>>2]|0;
  HEAP32[52378] = $4;
  $5 = HEAP32[$3>>2]|0;
  _SDL_free($5);
  $6 = ((($3)) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  _SDL_free($7);
  $8 = ((($3)) + 12|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($9|0)==(0|0);
  if (!($10)) {
   $$in1415 = $9;
   while(1) {
    $11 = ((($$in1415)) + 8|0);
    $12 = HEAP32[$11>>2]|0;
    _SDL_free($$in1415);
    $13 = ($12|0)==(0|0);
    if ($13) {
     break;
    } else {
     $$in1415 = $12;
    }
   }
  }
  _SDL_free($3);
  $14 = HEAP32[52378]|0;
  $15 = ($14|0)==(0|0);
  if ($15) {
   break;
  } else {
   $3 = $14;
  }
 }
 return;
}
function _SDL_AssertionsQuit() {
 var $$012$i = 0, $$09$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer11 = 0, $vararg_buffer3 = 0, $vararg_ptr10 = 0, $vararg_ptr5 = 0, $vararg_ptr6 = 0;
 var $vararg_ptr7 = 0, $vararg_ptr8 = 0, $vararg_ptr9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(64|0);
 $vararg_buffer11 = sp + 48|0;
 $vararg_buffer3 = sp + 16|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $0 = HEAP32[53379]|0;
 $1 = ($0|0)!=(0|0);
 $2 = HEAP32[22952]|0;
 $3 = ($2|0)!=(2900|0);
 $or$cond$i = $1 & $3;
 if ($or$cond$i) {
  _debug_print(195558,$vararg_buffer);
  _debug_print(195583,$vararg_buffer1);
  $$012$i = $0;
  while(1) {
   $4 = ((($$012$i)) + 8|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = ((($$012$i)) + 20|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ((($$012$i)) + 12|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = ((($$012$i)) + 16|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = ((($$012$i)) + 4|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = ($13|0)==(1);
   $15 = $14 ? 221531 : 195628;
   $16 = HEAP32[$$012$i>>2]|0;
   $17 = ($16|0)!=(0);
   $18 = $17 ? 195630 : 195634;
   HEAP32[$vararg_buffer3>>2] = $5;
   $vararg_ptr5 = ((($vararg_buffer3)) + 4|0);
   HEAP32[$vararg_ptr5>>2] = $7;
   $vararg_ptr6 = ((($vararg_buffer3)) + 8|0);
   HEAP32[$vararg_ptr6>>2] = $9;
   $vararg_ptr7 = ((($vararg_buffer3)) + 12|0);
   HEAP32[$vararg_ptr7>>2] = $11;
   $vararg_ptr8 = ((($vararg_buffer3)) + 16|0);
   HEAP32[$vararg_ptr8>>2] = $13;
   $vararg_ptr9 = ((($vararg_buffer3)) + 20|0);
   HEAP32[$vararg_ptr9>>2] = $15;
   $vararg_ptr10 = ((($vararg_buffer3)) + 24|0);
   HEAP32[$vararg_ptr10>>2] = $18;
   _debug_print(195637,$vararg_buffer3);
   $19 = ((($$012$i)) + 24|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = ($20|0)==(0|0);
   if ($21) {
    break;
   } else {
    $$012$i = $20;
   }
  }
  _debug_print(195712,$vararg_buffer11);
  $22 = HEAP32[53379]|0;
  $23 = ($22|0)==(0|0);
  if (!($23)) {
   $$09$i$i = $22;
   while(1) {
    $24 = ((($$09$i$i)) + 24|0);
    $25 = HEAP32[$24>>2]|0;
    HEAP32[$$09$i$i>>2] = 0;
    $26 = ((($$09$i$i)) + 4|0);
    HEAP32[$26>>2] = 0;
    HEAP32[$24>>2] = 0;
    $27 = ($25|0)==(0|0);
    if ($27) {
     break;
    } else {
     $$09$i$i = $25;
    }
   }
  }
  HEAP32[53379] = 0;
 }
 $28 = HEAP32[53380]|0;
 $29 = ($28|0)==(0|0);
 if ($29) {
  STACKTOP = sp;return;
 }
 _SDL_DestroyMutex($28);
 HEAP32[53380] = 0;
 STACKTOP = sp;return;
}
function _SDL_LogResetPriorities() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[52379]|0;
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $3 = $0;
  while(1) {
   $2 = ((($3)) + 8|0);
   $4 = HEAP32[$2>>2]|0;
   HEAP32[52379] = $4;
   _SDL_free($3);
   $5 = HEAP32[52379]|0;
   $6 = ($5|0)==(0|0);
   if ($6) {
    break;
   } else {
    $3 = $5;
   }
  }
 }
 HEAP32[22147] = 6;
 HEAP32[22146] = 4;
 HEAP32[22148] = 3;
 return;
}
function _SDL_PromptAssertion($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$ = 0, $$032 = 0, $$033 = 0, $$1$ph = 0, $$2 = 0, $$35 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer6 = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, $vararg_ptr3 = 0, $vararg_ptr4 = 0, $vararg_ptr5 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 4256|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(4256|0);
 $vararg_buffer6 = sp + 4120|0;
 $vararg_buffer = sp + 4096|0;
 $2 = sp + 4188|0;
 $3 = sp + 4128|0;
 $4 = sp + 4124|0;
 $5 = sp + 4216|0;
 dest=$3; src=91812; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $6 = sp;
 $7 = ((($0)) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($0)) + 12|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ((($0)) + 16|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ((($0)) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(1);
 $16 = $15 ? 195714 : 195719;
 $17 = ((($0)) + 8|0);
 $18 = HEAP32[$17>>2]|0;
 HEAP32[$vararg_buffer>>2] = $8;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $10;
 $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $12;
 $vararg_ptr3 = ((($vararg_buffer)) + 12|0);
 HEAP32[$vararg_ptr3>>2] = $14;
 $vararg_ptr4 = ((($vararg_buffer)) + 16|0);
 HEAP32[$vararg_ptr4>>2] = $16;
 $vararg_ptr5 = ((($vararg_buffer)) + 20|0);
 HEAP32[$vararg_ptr5>>2] = $18;
 (_SDL_snprintf($6,4096,195725,$vararg_buffer)|0);
 HEAP32[$vararg_buffer6>>2] = $6;
 _debug_print(195782,$vararg_buffer6);
 $19 = (_SDL_getenv(195789)|0);
 $20 = ($19|0)==(0|0);
 if (!($20)) {
  $21 = (_SDL_strcmp($19,195800)|0);
  $22 = ($21|0)==(0);
  if ($22) {
   $$032 = 2;
   STACKTOP = sp;return ($$032|0);
  }
  $23 = (_SDL_strcmp($19,195806)|0);
  $24 = ($23|0)==(0);
  if ($24) {
   $$032 = 1;
   STACKTOP = sp;return ($$032|0);
  }
  $25 = (_SDL_strcmp($19,195812)|0);
  $26 = ($25|0)==(0);
  if ($26) {
   $$032 = 0;
   STACKTOP = sp;return ($$032|0);
  }
  $27 = (_SDL_strcmp($19,195818)|0);
  $28 = ($27|0)==(0);
  if ($28) {
   $$032 = 3;
   STACKTOP = sp;return ($$032|0);
  }
  $29 = (_SDL_strcmp($19,195825)|0);
  $30 = ($29|0)==(0);
  $$ = $30 ? 4 : 2;
  $$032 = $$;
  STACKTOP = sp;return ($$032|0);
 }
 $31 = (_SDL_GetFocusWindow()|0);
 $32 = ($31|0)==(0|0);
 if ($32) {
  $$033 = 0;
 } else {
  $33 = (_SDL_GetWindowFlags($31)|0);
  $34 = $33 & 1;
  $35 = ($34|0)==(0);
  if ($35) {
   $$033 = 0;
  } else {
   _SDL_MinimizeWindow($31);
   $$033 = $31;
  }
 }
 (_SDL_memset($2,0,28)|0);
 HEAP32[$2>>2] = 32;
 $36 = ((($2)) + 4|0);
 HEAP32[$36>>2] = $$033;
 $37 = ((($2)) + 8|0);
 HEAP32[$37>>2] = 195839;
 $38 = ((($2)) + 12|0);
 HEAP32[$38>>2] = $6;
 $39 = ((($2)) + 16|0);
 HEAP32[$39>>2] = 5;
 $40 = ((($2)) + 20|0);
 HEAP32[$40>>2] = $3;
 $41 = (_SDL_ShowMessageBox($2,$4)|0);
 $42 = ($41|0)==(0);
 L21: do {
  if ($42) {
   $45 = HEAP32[$4>>2]|0;
   $46 = ($45|0)==(-1);
   $$35 = $46 ? 3 : $45;
   $$2 = $$35;
  } else {
   $43 = HEAP32[23152]|0;
   $44 = HEAP32[23120]|0;
   while(1) {
    (_fwrite(195856,49,1,$43)|0);
    (_fflush($43)|0);
    $47 = (_fgets($5,32,$44)|0);
    $48 = ($47|0)==(0|0);
    if ($48) {
     $$1$ph = 2;
     break;
    }
    $49 = (_SDL_strcmp($5,195906)|0);
    $50 = ($49|0)==(0);
    if ($50) {
     $$1$ph = 2;
     break;
    }
    $51 = (_SDL_strcmp($5,195908)|0);
    $52 = ($51|0)==(0);
    if ($52) {
     $$1$ph = 1;
     break;
    }
    $53 = (_SDL_strcmp($5,195910)|0);
    $54 = ($53|0)==(0);
    if ($54) {
     $$1$ph = 0;
     break;
    }
    $55 = (_SDL_strcmp($5,195912)|0);
    $56 = ($55|0)==(0);
    if ($56) {
     $$1$ph = 3;
     break;
    }
    $57 = (_SDL_strcmp($5,195914)|0);
    $58 = ($57|0)==(0);
    if ($58) {
     $$2 = 4;
     break L21;
    }
   }
   $$2 = $$1$ph;
  }
 } while(0);
 $59 = ($$033|0)==(0|0);
 if ($59) {
  $$032 = $$2;
  STACKTOP = sp;return ($$032|0);
 }
 _SDL_RestoreWindow($$033);
 $$032 = $$2;
 STACKTOP = sp;return ($$032|0);
}
function _debug_print($0,$varargs) {
 $0 = $0|0;
 $varargs = $varargs|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 HEAP32[$1>>2] = $varargs;
 _SDL_LogMessageV(2,4,$0,$1);
 STACKTOP = sp;return;
}
function _SDL_GetFocusWindow() {
 var $$0 = 0, $$05 = 0, $$06 = 0, $$07 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[52375]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  $$05 = 0;
  return ($$05|0);
 }
 $2 = ((($0)) + 272|0);
 $$06 = HEAP32[$2>>2]|0;
 $3 = ($$06|0)==(0|0);
 if ($3) {
  $$05 = 0;
  return ($$05|0);
 } else {
  $$07 = $$06;
 }
 while(1) {
  $4 = ((($$07)) + 48|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = $5 & 512;
  $7 = ($6|0)==(0);
  if (!($7)) {
   $$05 = $$07;
   label = 5;
   break;
  }
  $8 = ((($$07)) + 152|0);
  $$0 = HEAP32[$8>>2]|0;
  $9 = ($$0|0)==(0|0);
  if ($9) {
   $$05 = 0;
   label = 5;
   break;
  } else {
   $$07 = $$0;
  }
 }
 if ((label|0) == 5) {
  return ($$05|0);
 }
 return (0)|0;
}
function _SDL_MinimizeWindow($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $1 = HEAP32[52375]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  (_SDL_SetError(175439,$vararg_buffer)|0);
  STACKTOP = sp;return;
 }
 $3 = ($0|0)==(0|0);
 if (!($3)) {
  $4 = HEAP32[$0>>2]|0;
  $5 = ((($1)) + 280|0);
  $6 = ($4|0)==($5|0);
  if ($6) {
   $7 = ((($0)) + 48|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = $8 & 64;
   $10 = ($9|0)==(0);
   if (!($10)) {
    STACKTOP = sp;return;
   }
   (_SDL_UpdateFullscreenMode($0,0)|0);
   $11 = HEAP32[52375]|0;
   $12 = ((($11)) + 96|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = ($13|0)==(0|0);
   if ($14) {
    STACKTOP = sp;return;
   }
   FUNCTION_TABLE_vii[$13 & 8191]($11,$0);
   STACKTOP = sp;return;
  }
 }
 (_SDL_SetError(195204,$vararg_buffer1)|0);
 STACKTOP = sp;return;
}
function _SDL_ShowMessageBox($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$ = 0, $$0 = 0, $$02324 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp = 0, $phitmp26 = 0;
 var $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer3 = 0, $vararg_buffer5 = 0, $vararg_buffer7 = 0, $vararg_buffer9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $vararg_buffer9 = sp + 40|0;
 $vararg_buffer7 = sp + 32|0;
 $vararg_buffer5 = sp + 24|0;
 $vararg_buffer3 = sp + 16|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $2 = sp + 44|0;
 $3 = ($0|0)==(0|0);
 if ($3) {
  HEAP32[$vararg_buffer>>2] = 195916;
  $4 = (_SDL_SetError(194740,$vararg_buffer)|0);
  $$0 = $4;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = (_SDL_GetKeyboardFocus()|0);
 $6 = ($5|0)!=(0|0);
 do {
  if ($6) {
   $7 = HEAP32[52375]|0;
   $8 = ($7|0)==(0|0);
   if ($8) {
    (_SDL_SetError(175439,$vararg_buffer1)|0);
    $36 = 0;
    break;
   }
   $9 = HEAP32[$5>>2]|0;
   $10 = ((($7)) + 280|0);
   $11 = ($9|0)==($10|0);
   if ($11) {
    $12 = ((($5)) + 48|0);
    $13 = HEAP32[$12>>2]|0;
    $phitmp = $13 & 16384;
    $phitmp26 = ($phitmp|0)!=(0);
    $36 = $phitmp26;
    break;
   } else {
    (_SDL_SetError(195204,$vararg_buffer3)|0);
    $36 = 0;
    break;
   }
  } else {
   $36 = 0;
  }
 } while(0);
 $14 = (_SDL_GetRelativeMouseMode()|0);
 (_SDL_CaptureMouse(0)|0);
 (_SDL_SetRelativeMouseMode(0)|0);
 $15 = (_SDL_ShowCursor(1)|0);
 _SDL_ResetKeyboard();
 $16 = ($1|0)==(0|0);
 $$ = $16 ? $2 : $1;
 $17 = HEAP32[52375]|0;
 $18 = ($17|0)==(0|0);
 if ($18) {
  label = 12;
 } else {
  $19 = ((($17)) + 252|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = ($20|0)==(0|0);
  if ($21) {
   label = 12;
  } else {
   $22 = (FUNCTION_TABLE_iiii[$20 & 8191]($17,$0,$$)|0);
   $23 = ($22|0)==(-1);
   if ($23) {
    label = 12;
   } else {
    $$02324 = $22;
   }
  }
 }
 if ((label|0) == 12) {
  (_SDL_SetError(195931,$vararg_buffer5)|0);
  $$02324 = -1;
 }
 if ($6) {
  $24 = HEAP32[52375]|0;
  $25 = ($24|0)==(0|0);
  do {
   if ($25) {
    (_SDL_SetError(175439,$vararg_buffer7)|0);
   } else {
    $26 = HEAP32[$5>>2]|0;
    $27 = ((($24)) + 280|0);
    $28 = ($26|0)==($27|0);
    if (!($28)) {
     (_SDL_SetError(195204,$vararg_buffer9)|0);
     break;
    }
    $29 = ((($5)) + 48|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = $30 & 4;
    $32 = ($31|0)==(0);
    if (!($32)) {
     $33 = ((($24)) + 88|0);
     $34 = HEAP32[$33>>2]|0;
     $35 = ($34|0)==(0|0);
     if (!($35)) {
      FUNCTION_TABLE_vii[$34 & 8191]($24,$5);
     }
    }
   }
  } while(0);
  if ($36) {
   (_SDL_CaptureMouse(1)|0);
  }
 }
 (_SDL_ShowCursor($15)|0);
 (_SDL_SetRelativeMouseMode($14)|0);
 $$0 = $$02324;
 STACKTOP = sp;return ($$0|0);
}
function _SDL_RestoreWindow($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $1 = HEAP32[52375]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  (_SDL_SetError(175439,$vararg_buffer)|0);
  STACKTOP = sp;return;
 }
 $3 = ($0|0)==(0|0);
 if (!($3)) {
  $4 = HEAP32[$0>>2]|0;
  $5 = ((($1)) + 280|0);
  $6 = ($4|0)==($5|0);
  if ($6) {
   $7 = ((($0)) + 48|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = $8 & 192;
   $10 = ($9|0)==(0);
   if ($10) {
    STACKTOP = sp;return;
   }
   $11 = ((($1)) + 100|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = ($12|0)==(0|0);
   if ($13) {
    STACKTOP = sp;return;
   }
   FUNCTION_TABLE_vii[$12 & 8191]($1,$0);
   STACKTOP = sp;return;
  }
 }
 (_SDL_SetError(195204,$vararg_buffer1)|0);
 STACKTOP = sp;return;
}
function _SDL_GetRelativeMouseMode() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[(209600)>>2]|0;
 return ($0|0);
}
function _SDL_ShowCursor($0) {
 $0 = $0|0;
 var $$sink = 0, $$val = 0, $$val12 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $notlhs$i = 0, $or$cond27$not$i = 0, $or$cond29$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[(209628)>>2]|0;
 $2 = ($0|0)>(-1);
 if (!($2)) {
  return ($1|0);
 }
 $3 = ($0|0)!=(0);
 $$sink = $3&1;
 HEAP32[(209628)>>2] = $$sink;
 $4 = ($$sink|0)==($1|0);
 if ($4) {
  return ($1|0);
 }
 $5 = HEAP32[(209568)>>2]|0;
 $6 = ($5|0)==(0|0);
 $$val = HEAP32[(209620)>>2]|0;
 $$val12 = HEAP32[(209624)>>2]|0;
 $7 = $6 ? $$val : $$val12;
 $notlhs$i = ($7|0)!=(0|0);
 $or$cond27$not$i = $notlhs$i & $3;
 $8 = HEAP32[(209600)>>2]|0;
 $9 = ($8|0)==(0);
 $or$cond29$i = $or$cond27$not$i & $9;
 $10 = HEAP32[(209532)>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($or$cond29$i) {
  if ($11) {
   return ($1|0);
  }
  (FUNCTION_TABLE_ii[$10 & 8191]($7)|0);
  return ($1|0);
 } else {
  if ($11) {
   return ($1|0);
  }
  (FUNCTION_TABLE_ii[$10 & 8191](0)|0);
  return ($1|0);
 }
 return (0)|0;
}
function _SDL_JoystickEventState($0) {
 $0 = $0|0;
 var $$015 = 0, $$112 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $cond = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $cond = ($0|0)==(-1);
 if ($cond) {
  $$015 = 0;
 } else {
  (_SDL_EventState(1536,$0)|0);
  (_SDL_EventState(1537,$0)|0);
  (_SDL_EventState(1538,$0)|0);
  (_SDL_EventState(1539,$0)|0);
  (_SDL_EventState(1540,$0)|0);
  (_SDL_EventState(1541,$0)|0);
  (_SDL_EventState(1542,$0)|0);
  $$112 = $0;
  return ($$112|0);
 }
 while(1) {
  $1 = (91872 + ($$015<<2)|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = (_SDL_EventState($2,-1)|0);
  $4 = ($3<<24>>24)!=(1);
  $5 = (($$015) + 1)|0;
  $6 = ($5>>>0)<(7);
  $or$cond = $4 & $6;
  if ($or$cond) {
   $$015 = $5;
  } else {
   break;
  }
 }
 $7 = $3&255;
 $$112 = $7;
 return ($$112|0);
}
function _SDL_JoystickUpdate() {
 var $$02939 = 0, $$034 = 0, $$135 = 0, $$237 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(112|0);
 $0 = sp + 56|0;
 $1 = sp;
 $2 = HEAP32[53377]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = ((($0)) + 8|0);
 $5 = ((($0)) + 12|0);
 $6 = ((($0)) + 13|0);
 $7 = ((($1)) + 8|0);
 $8 = ((($1)) + 12|0);
 $9 = ((($1)) + 13|0);
 $$02939 = $2;
 while(1) {
  $10 = ((($$02939)) + 60|0);
  $11 = HEAP32[$10>>2]|0;
  HEAP32[53378] = $$02939;
  _SDL_SYS_JoystickUpdate($$02939);
  $12 = ((($$02939)) + 52|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($13|0)==(0);
  if (!($14)) {
   $15 = ((($$02939)) + 8|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ($16|0)>(0);
   if ($17) {
    $18 = ((($$02939)) + 16|0);
    $$034 = 0;
    while(1) {
     $23 = $$034&255;
     $24 = HEAP32[$18>>2]|0;
     $25 = (($24) + ($$034<<1)|0);
     $26 = HEAP16[$25>>1]|0;
     (_SDL_PrivateJoystickAxis($$02939,$23,$26)|0);
     $27 = (($$034) + 1)|0;
     $28 = HEAP32[$15>>2]|0;
     $29 = ($27|0)<($28|0);
     if ($29) {
      $$034 = $27;
     } else {
      break;
     }
    }
   }
   $19 = ((($$02939)) + 36|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = ($20|0)>(0);
   if ($21) {
    $22 = ((($$02939)) + 40|0);
    $$135 = 0;$37 = $20;
    while(1) {
     $34 = $$135&255;
     HEAP32[$1>>2] = 1540;
     $35 = $$135 & 255;
     $36 = ($35|0)<($37|0);
     if ($36) {
      $38 = HEAP32[$22>>2]|0;
      $39 = (($38) + ($35)|0);
      $40 = HEAP8[$39>>0]|0;
      $41 = ($40<<24>>24)==(0);
      if (!($41)) {
       $42 = HEAP32[53358]|0;
       $43 = ($42|0)==(0);
       if ($43) {
        $44 = (_SDL_WasInit(32)|0);
        $45 = ($44|0)==(0);
        if (!($45)) {
        }
       }
       $46 = HEAP32[$22>>2]|0;
       $47 = (($46) + ($35)|0);
       HEAP8[$47>>0] = 0;
       $48 = HEAP32[$1>>2]|0;
       $49 = (_SDL_EventState($48,-1)|0);
       $50 = ($49<<24>>24)==(1);
       if ($50) {
        $51 = HEAP32[$$02939>>2]|0;
        HEAP32[$7>>2] = $51;
        HEAP8[$8>>0] = $34;
        HEAP8[$9>>0] = 0;
        (_SDL_PushEvent($1)|0);
       }
      }
     }
     $52 = (($$135) + 1)|0;
     $53 = HEAP32[$19>>2]|0;
     $54 = ($52|0)<($53|0);
     if ($54) {
      $$135 = $52;$37 = $53;
     } else {
      break;
     }
    }
   }
   $30 = ((($$02939)) + 20|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = ($31|0)>(0);
   if ($32) {
    $33 = ((($$02939)) + 24|0);
    $$237 = 0;$58 = $31;
    while(1) {
     $55 = $$237&255;
     $56 = $$237 & 255;
     $57 = ($56|0)<($58|0);
     if ($57) {
      $59 = HEAP32[$33>>2]|0;
      $60 = (($59) + ($56)|0);
      $61 = HEAP8[$60>>0]|0;
      $62 = ($61<<24>>24)==(0);
      if (!($62)) {
       $63 = HEAP32[53358]|0;
       $64 = ($63|0)==(0);
       if ($64) {
        $65 = (_SDL_WasInit(32)|0);
        $66 = ($65|0)==(0);
        if (!($66)) {
        }
       }
       $67 = HEAP32[$33>>2]|0;
       $68 = (($67) + ($56)|0);
       HEAP8[$68>>0] = 0;
       $69 = (_SDL_EventState(1538,-1)|0);
       $70 = ($69<<24>>24)==(1);
       if ($70) {
        HEAP32[$0>>2] = 1538;
        $71 = HEAP32[$$02939>>2]|0;
        HEAP32[$4>>2] = $71;
        HEAP8[$5>>0] = $55;
        HEAP8[$6>>0] = 0;
        (_SDL_PushEvent($0)|0);
       }
      }
     }
     $72 = (($$237) + 1)|0;
     $73 = HEAP32[$30>>2]|0;
     $74 = ($72|0)<($73|0);
     if ($74) {
      $$237 = $72;$58 = $73;
     } else {
      break;
     }
    }
   }
   HEAP32[$12>>2] = 0;
  }
  HEAP32[53378] = 0;
  $75 = ((($$02939)) + 48|0);
  $76 = HEAP32[$75>>2]|0;
  $77 = ($76|0)<(1);
  if ($77) {
   _SDL_JoystickClose($$02939);
  }
  $78 = ($11|0)==(0|0);
  if ($78) {
   break;
  } else {
   $$02939 = $11;
  }
 }
 STACKTOP = sp;return;
}
function _SDL_SendPendingQuit() {
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[52409]|0;
 $1 = ($0|0)==(0);
 if ($1) {
  return;
 }
 HEAP32[52409] = 0;
 (_SDL_SendAppEvent(256)|0);
 return;
}
function _SDL_SYS_JoystickUpdate($0) {
 $0 = $0|0;
 var $$042 = 0, $$141 = 0, $$pre = 0, $$pre44 = 0.0, $1 = 0, $10 = 0, $11 = 0.0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0.0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0.0, $39 = 0, $4 = 0, $40 = 0.0, $41 = 0;
 var $42 = 0.0, $43 = 0, $44 = 0, $45 = 0, $46 = 0.0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0.0, $51 = 0, $6 = 0, $7 = 0, $8 = 0.0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1440|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(1440|0);
 $1 = sp;
 $2 = ((($0)) + 44|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = HEAP32[$3>>2]|0;
 $6 = (_emscripten_get_gamepad_status(($5|0),($1|0))|0);
 $7 = ($6|0)==(0);
 if (!($7)) {
  STACKTOP = sp;return;
 }
 $8 = +HEAPF64[$1>>3];
 $9 = $8 == 0.0;
 if (!($9)) {
  $10 = ((($3)) + 32|0);
  $11 = +HEAPF64[$10>>3];
  $12 = $8 != $11;
  if (!($12)) {
   STACKTOP = sp;return;
  }
 }
 $13 = ((($3)) + 20|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)>(0);
 if ($15) {
  $16 = ((($3)) + 16|0);
  $$042 = 0;
  while(1) {
   $21 = (((($3)) + 1064|0) + ($$042<<2)|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = (((($1)) + 1040|0) + ($$042<<2)|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = ($22|0)==($24|0);
   if ($25) {
    $33 = $22;
   } else {
    $26 = ($24|0)!=(0);
    $27 = $26&1;
    $28 = HEAP32[$16>>2]|0;
    $29 = $$042&255;
    (_SDL_PrivateJoystickButton($28,$29,$27)|0);
    $$pre = HEAP32[$23>>2]|0;
    $33 = $$pre;
   }
   $30 = (((($1)) + 528|0) + ($$042<<3)|0);
   $31 = +HEAPF64[$30>>3];
   $32 = (((($3)) + 552|0) + ($$042<<3)|0);
   HEAPF64[$32>>3] = $31;
   HEAP32[$21>>2] = $33;
   $34 = (($$042) + 1)|0;
   $35 = HEAP32[$13>>2]|0;
   $36 = ($34|0)<($35|0);
   if ($36) {
    $$042 = $34;
   } else {
    break;
   }
  }
 }
 $17 = ((($3)) + 24|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ($18|0)>(0);
 if ($19) {
  $20 = ((($3)) + 16|0);
  $$141 = 0;
  while(1) {
   $37 = (((($3)) + 40|0) + ($$141<<3)|0);
   $38 = +HEAPF64[$37>>3];
   $39 = (((($1)) + 16|0) + ($$141<<3)|0);
   $40 = +HEAPF64[$39>>3];
   $41 = $38 != $40;
   if ($41) {
    $42 = $40 * 32767.0;
    $43 = (~~(($42)));
    $44 = HEAP32[$20>>2]|0;
    $45 = $$141&255;
    (_SDL_PrivateJoystickAxis($44,$45,$43)|0);
    $$pre44 = +HEAPF64[$39>>3];
    $46 = $$pre44;
   } else {
    $46 = $40;
   }
   HEAPF64[$37>>3] = $46;
   $47 = (($$141) + 1)|0;
   $48 = HEAP32[$17>>2]|0;
   $49 = ($47|0)<($48|0);
   if ($49) {
    $$141 = $47;
   } else {
    break;
   }
  }
 }
 $50 = +HEAPF64[$1>>3];
 $51 = ((($3)) + 32|0);
 HEAPF64[$51>>3] = $50;
 STACKTOP = sp;return;
}
function _SDL_PrivateJoystickAxis($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$025 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(64|0);
 $3 = sp;
 $4 = $1&255;
 $5 = ((($0)) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4|0)<($6|0);
 if (!($7)) {
  $$025 = 0;
  STACKTOP = sp;return ($$025|0);
 }
 $8 = ((($0)) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + ($4<<1)|0);
 $11 = HEAP16[$10>>1]|0;
 $12 = ($11<<16>>16)==($2<<16>>16);
 if ($12) {
  $$025 = 0;
  STACKTOP = sp;return ($$025|0);
 }
 $13 = HEAP32[53358]|0;
 $14 = ($13|0)==(0);
 if ($14) {
  $15 = (_SDL_WasInit(32)|0);
  $16 = ($15|0)==(0);
  if (!($16)) {
   $17 = (_SDL_GetKeyboardFocus()|0);
   $18 = ($17|0)==(0|0);
   if ($18) {
    $19 = ((($0)) + 16|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = (($20) + ($4<<1)|0);
    $22 = HEAP16[$21>>1]|0;
    $23 = ($22<<16>>16)<($2<<16>>16);
    if ($23) {
     $24 = HEAP32[$8>>2]|0;
     $25 = (($24) + ($4<<1)|0);
     $26 = HEAP16[$25>>1]|0;
     $27 = ($26<<16>>16)>($2<<16>>16);
     if (!($27)) {
      $$025 = 0;
      STACKTOP = sp;return ($$025|0);
     }
    }
    $28 = ($22<<16>>16)>($2<<16>>16);
    if ($28) {
     $29 = HEAP32[$8>>2]|0;
     $30 = (($29) + ($4<<1)|0);
     $31 = HEAP16[$30>>1]|0;
     $32 = ($31<<16>>16)<($2<<16>>16);
     if (!($32)) {
      $$025 = 0;
      STACKTOP = sp;return ($$025|0);
     }
    }
   }
  }
 }
 $33 = HEAP32[$8>>2]|0;
 $34 = (($33) + ($4<<1)|0);
 HEAP16[$34>>1] = $2;
 $35 = (_SDL_EventState(1536,-1)|0);
 $36 = ($35<<24>>24)==(1);
 if (!($36)) {
  $$025 = 0;
  STACKTOP = sp;return ($$025|0);
 }
 HEAP32[$3>>2] = 1536;
 $37 = HEAP32[$0>>2]|0;
 $38 = ((($3)) + 8|0);
 HEAP32[$38>>2] = $37;
 $39 = ((($3)) + 12|0);
 HEAP8[$39>>0] = $1;
 $40 = ((($3)) + 16|0);
 HEAP16[$40>>1] = $2;
 $41 = (_SDL_PushEvent($3)|0);
 $42 = ($41|0)==(1);
 $43 = $42&1;
 $$025 = $43;
 STACKTOP = sp;return ($$025|0);
}
function _SDL_SYS_JoystickDetect() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function _SDL_PrivateJoystickButton($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$016 = 0, $$sink = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(64|0);
 $3 = sp;
 switch ($2<<24>>24) {
 case 1:  {
  $$sink = 1539;
  break;
 }
 case 0:  {
  $$sink = 1540;
  break;
 }
 default: {
  $$016 = 0;
  STACKTOP = sp;return ($$016|0);
 }
 }
 HEAP32[$3>>2] = $$sink;
 $4 = $1&255;
 $5 = ((($0)) + 36|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4|0)<($6|0);
 if (!($7)) {
  $$016 = 0;
  STACKTOP = sp;return ($$016|0);
 }
 $8 = ((($0)) + 40|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + ($4)|0);
 $11 = HEAP8[$10>>0]|0;
 $12 = ($11<<24>>24)==($2<<24>>24);
 if ($12) {
  $$016 = 0;
  STACKTOP = sp;return ($$016|0);
 }
 $13 = HEAP32[53358]|0;
 $14 = ($13|0)==(0);
 if ($14) {
  $15 = (_SDL_WasInit(32)|0);
  $16 = ($15|0)==(0);
  if (!($16)) {
   $17 = (_SDL_GetKeyboardFocus()|0);
   $18 = ($17|0)==(0|0);
   $19 = ($2<<24>>24)==(1);
   $or$cond = $19 & $18;
   if ($or$cond) {
    $$016 = 0;
    STACKTOP = sp;return ($$016|0);
   }
  }
 }
 $20 = HEAP32[$8>>2]|0;
 $21 = (($20) + ($4)|0);
 HEAP8[$21>>0] = $2;
 $22 = HEAP32[$3>>2]|0;
 $23 = (_SDL_EventState($22,-1)|0);
 $24 = ($23<<24>>24)==(1);
 if (!($24)) {
  $$016 = 0;
  STACKTOP = sp;return ($$016|0);
 }
 $25 = HEAP32[$0>>2]|0;
 $26 = ((($3)) + 8|0);
 HEAP32[$26>>2] = $25;
 $27 = ((($3)) + 12|0);
 HEAP8[$27>>0] = $1;
 $28 = ((($3)) + 13|0);
 HEAP8[$28>>0] = $2;
 $29 = (_SDL_PushEvent($3)|0);
 $30 = ($29|0)==(1);
 $31 = $30&1;
 $$016 = $31;
 STACKTOP = sp;return ($$016|0);
}
function _SDL_PollEvent($0) {
 $0 = $0|0;
 var $$07$i = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (_SDL_GetVideoDevice()|0);
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = ((($1)) + 204|0);
  $4 = HEAP32[$3>>2]|0;
  FUNCTION_TABLE_vi[$4 & 8191]($1);
 }
 $5 = HEAP32[(209664)>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  label = 5;
 } else {
  $7 = (_SDL_JoystickEventState(-1)|0);
  $8 = ($7|0)==(0);
  if (!($8)) {
   label = 5;
  }
 }
 if ((label|0) == 5) {
  _SDL_JoystickUpdate();
 }
 _SDL_SendPendingQuit();
 $9 = (_SDL_PeepEvents($0,1,2,0,65535)|0);
 switch ($9|0) {
 case 0: case -1:  {
  break;
 }
 default: {
  $$07$i = 1;
  return ($$07$i|0);
 }
 }
 $$07$i = 0;
 return ($$07$i|0);
}
function _SDL_CreateWindow($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$ = 0, $$0 = 0, $$0$i = 0, $$0$i96 = 0, $$05$i = 0, $$05$i102 = 0, $$06$i = 0, $$06$i101 = 0, $$06$i95 = 0, $$085 = 0, $$086 = 0, $$89 = 0, $$lobit = 0, $$lobit87 = 0, $$lobit88 = 0, $$phi$trans$insert = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert$i98 = 0, $$pre = 0, $$pre$i = 0;
 var $$pre$i99 = 0, $$pre107 = 0, $$pre108 = 0, $$pre108$pre = 0, $$pre109 = 0, $$pre110 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0;
 var $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $or$cond = 0, $switch$split2D = 0, $switch$split302D = 0, $switch$split332D = 0, $switch$split362D = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer11 = 0, $vararg_buffer13 = 0, $vararg_buffer15 = 0, $vararg_buffer17 = 0, $vararg_buffer19 = 0, $vararg_buffer21 = 0, $vararg_buffer23 = 0, $vararg_buffer25 = 0, $vararg_buffer27 = 0, $vararg_buffer3 = 0, $vararg_buffer5 = 0, $vararg_buffer7 = 0;
 var $vararg_buffer9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(160|0);
 $vararg_buffer27 = sp + 112|0;
 $vararg_buffer25 = sp + 104|0;
 $vararg_buffer23 = sp + 96|0;
 $vararg_buffer21 = sp + 88|0;
 $vararg_buffer19 = sp + 80|0;
 $vararg_buffer17 = sp + 72|0;
 $vararg_buffer15 = sp + 64|0;
 $vararg_buffer13 = sp + 56|0;
 $vararg_buffer11 = sp + 48|0;
 $vararg_buffer9 = sp + 40|0;
 $vararg_buffer7 = sp + 32|0;
 $vararg_buffer5 = sp + 24|0;
 $vararg_buffer3 = sp + 16|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $6 = sp + 136|0;
 $7 = sp + 120|0;
 $8 = HEAP32[52375]|0;
 $9 = ($8|0)==(0|0);
 if ($9) {
  $10 = (_SDL_VideoInit(0)|0);
  $11 = ($10|0)<(0);
  if ($11) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $12 = $5 >>> 17;
 $$lobit = $12 & 1;
 $13 = $5 >>> 18;
 $$lobit87 = $13 & 1;
 $14 = (($$lobit) + ($$lobit87))|0;
 $15 = $5 >>> 19;
 $$lobit88 = $15 & 1;
 $16 = (($14) + ($$lobit88))|0;
 $17 = ($16>>>0)>(1);
 if ($17) {
  (_SDL_SetError(195998,$vararg_buffer)|0);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $18 = ($3|0)>(1);
 $$ = $18 ? $3 : 1;
 $19 = ($4|0)>(1);
 $$085 = $19 ? $4 : 1;
 $20 = ($$|0)>(16384);
 $21 = ($$085|0)>(16384);
 $or$cond = $20 | $21;
 if ($or$cond) {
  (_SDL_SetError(196033,$vararg_buffer1)|0);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $22 = $5 & 2;
 $23 = ($22|0)==(0);
 L13: do {
  if (!($23)) {
   $24 = HEAP32[52375]|0;
   $25 = ((($24)) + 176|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = ($26|0)==(0|0);
   if ($27) {
    (_SDL_SetError(181953,$vararg_buffer3)|0);
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $28 = ($24|0)==(0|0);
   L19: do {
    if ($28) {
     $29 = (_SDL_SetError(175439,$vararg_buffer5)|0);
     $$06$i = $29;
    } else {
     $30 = ((($24)) + 388|0);
     $31 = HEAP32[$30>>2]|0;
     $32 = ($31|0)==(0);
     do {
      if ($32) {
       $33 = ((($24)) + 164|0);
       $34 = HEAP32[$33>>2]|0;
       $35 = ($34|0)==(0|0);
       if ($35) {
        $36 = (_SDL_SetError(181719,$vararg_buffer7)|0);
        $$06$i = $36;
        break L19;
       }
       $37 = (FUNCTION_TABLE_iii[$34 & 8191]($24,0)|0);
       $38 = ($37|0)==(0);
       $39 = HEAP32[52375]|0;
       if ($38) {
        $$phi$trans$insert = ((($39)) + 388|0);
        $$pre = HEAP32[$$phi$trans$insert>>2]|0;
        $41 = $39;$43 = $$pre;
        break;
       }
       $44 = ((($39)) + 172|0);
       $45 = HEAP32[$44>>2]|0;
       $46 = ($45|0)==(0|0);
       if ($46) {
        $$06$i = $37;
        break L19;
       }
       FUNCTION_TABLE_vi[$45 & 8191]($39);
       $$06$i = $37;
       break L19;
      } else {
       $41 = $24;$43 = $31;
      }
     } while(0);
     $40 = ((($41)) + 388|0);
     $42 = (($43) + 1)|0;
     HEAP32[$40>>2] = $42;
     break L13;
    }
   } while(0);
   $47 = ($$06$i|0)<(0);
   if ($47) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $48 = $5 & 8192;
 $49 = ($48|0)==(0);
 if ($49) {
  $$086 = $5;
 } else {
  $50 = $5 & -8193;
  $51 = (_SDL_GetHintBoolean(196054,0)|0);
  $52 = ($51|0)==(0);
  $$89 = $52 ? $5 : $50;
  $$086 = $$89;
 }
 $53 = (_SDL_calloc(1,156)|0);
 $54 = ($53|0)==(0|0);
 if ($54) {
  (_SDL_Error(0)|0);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $55 = HEAP32[52375]|0;
 $56 = ((($55)) + 280|0);
 HEAP32[$53>>2] = $56;
 $57 = ((($55)) + 284|0);
 $58 = HEAP32[$57>>2]|0;
 $59 = (($58) + 1)|0;
 HEAP32[$57>>2] = $59;
 $60 = ((($53)) + 4|0);
 HEAP32[$60>>2] = $58;
 $61 = ((($53)) + 16|0);
 HEAP32[$61>>2] = $1;
 $62 = ((($53)) + 20|0);
 HEAP32[$62>>2] = $2;
 $63 = ((($53)) + 24|0);
 HEAP32[$63>>2] = $$;
 $64 = ((($53)) + 28|0);
 HEAP32[$64>>2] = $$085;
 $65 = $1 & -65536;
 $switch$split2D = ($65|0)<(805240832);
 if ($switch$split2D) {
  switch ($65|0) {
  case 536805376:  {
   label = 27;
   break;
  }
  default: {
   label = 26;
  }
  }
 } else {
  switch ($65|0) {
  case 805240832:  {
   label = 27;
   break;
  }
  default: {
   label = 26;
  }
  }
 }
 L45: do {
  if ((label|0) == 26) {
   $66 = $2 & -65536;
   $switch$split302D = ($66|0)<(805240832);
   if ($switch$split302D) {
    switch ($66|0) {
    case 536805376:  {
     label = 27;
     break L45;
     break;
    }
    default: {
     $101 = $$085;$95 = $1;$97 = $2;$99 = $$;
     break L45;
    }
    }
   } else {
    switch ($66|0) {
    case 805240832:  {
     label = 27;
     break L45;
     break;
    }
    default: {
     $101 = $$085;$95 = $1;$97 = $2;$99 = $$;
     break L45;
    }
    }
   }
  }
 } while(0);
 if ((label|0) == 27) {
  $67 = (_SDL_GetWindowDisplayIndex($53)|0);
  $68 = ($67|0)>(-1);
  $69 = HEAP32[52375]|0;
  if ($68) {
   $70 = ((($69)) + 268|0);
   $71 = HEAP32[$70>>2]|0;
   $72 = (($71) + (($67*68)|0)|0);
   $$0$i = $72;
  } else {
   $$0$i = 0;
  }
  $73 = ((($69)) + 264|0);
  $74 = HEAP32[$73>>2]|0;
  $75 = ($74|0)>(0);
  L55: do {
   if ($75) {
    $$phi$trans$insert$i = ((($69)) + 268|0);
    $$pre$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $$06$i95 = 0;
    while(1) {
     $76 = (($$pre$i) + (($$06$i95*68)|0)|0);
     $77 = ($76|0)==($$0$i|0);
     if ($77) {
      $$05$i = $$06$i95;
      break L55;
     }
     $78 = (($$06$i95) + 1)|0;
     $79 = ($78|0)<($74|0);
     if ($79) {
      $$06$i95 = $78;
     } else {
      $$05$i = 0;
      break;
     }
    }
   } else {
    $$05$i = 0;
   }
  } while(0);
  (_SDL_GetDisplayBounds($$05$i,$6)|0);
  $switch$split332D = ($65|0)<(805240832);
  if ($switch$split332D) {
   switch ($65|0) {
   case 536805376:  {
    label = 34;
    break;
   }
   default: {
   }
   }
  } else {
   switch ($65|0) {
   case 805240832:  {
    label = 34;
    break;
   }
   default: {
   }
   }
  }
  if ((label|0) == 34) {
   $80 = HEAP32[$6>>2]|0;
   $81 = ((($6)) + 8|0);
   $82 = HEAP32[$81>>2]|0;
   $83 = (($82) - ($$))|0;
   $84 = (($83|0) / 2)&-1;
   $85 = (($84) + ($80))|0;
   HEAP32[$61>>2] = $85;
  }
  $86 = $2 & -65536;
  $switch$split362D = ($86|0)<(805240832);
  if ($switch$split362D) {
   switch ($86|0) {
   case 536805376:  {
    label = 37;
    break;
   }
   default: {
    label = 36;
   }
   }
  } else {
   switch ($86|0) {
   case 805240832:  {
    label = 37;
    break;
   }
   default: {
    label = 36;
   }
   }
  }
  if ((label|0) == 36) {
   $$pre108$pre = HEAP32[$62>>2]|0;
   $$pre108 = $$pre108$pre;
  }
  else if ((label|0) == 37) {
   $87 = ((($6)) + 4|0);
   $88 = HEAP32[$87>>2]|0;
   $89 = ((($6)) + 12|0);
   $90 = HEAP32[$89>>2]|0;
   $91 = (($90) - ($$085))|0;
   $92 = (($91|0) / 2)&-1;
   $93 = (($92) + ($88))|0;
   HEAP32[$62>>2] = $93;
   $$pre108 = $93;
  }
  $$pre107 = HEAP32[$61>>2]|0;
  $$pre109 = HEAP32[$63>>2]|0;
  $$pre110 = HEAP32[$64>>2]|0;
  $101 = $$pre110;$95 = $$pre107;$97 = $$pre108;$99 = $$pre109;
 }
 $94 = ((($53)) + 56|0);
 HEAP32[$94>>2] = $95;
 $96 = ((($53)) + 60|0);
 HEAP32[$96>>2] = $97;
 $98 = ((($53)) + 64|0);
 HEAP32[$98>>2] = $99;
 $100 = ((($53)) + 68|0);
 HEAP32[$100>>2] = $101;
 $102 = $$086 & 1;
 $103 = ($102|0)==(0);
 if (!($103)) {
  $104 = (_SDL_GetWindowDisplayIndex($53)|0);
  $105 = ($104|0)>(-1);
  $106 = HEAP32[52375]|0;
  if ($105) {
   $107 = ((($106)) + 268|0);
   $108 = HEAP32[$107>>2]|0;
   $109 = (($108) + (($104*68)|0)|0);
   $$0$i96 = $109;
  } else {
   $$0$i96 = 0;
  }
  $110 = ((($106)) + 264|0);
  $111 = HEAP32[$110>>2]|0;
  $112 = ($111|0)>(0);
  L80: do {
   if ($112) {
    $$phi$trans$insert$i98 = ((($106)) + 268|0);
    $$pre$i99 = HEAP32[$$phi$trans$insert$i98>>2]|0;
    $$06$i101 = 0;
    while(1) {
     $113 = (($$pre$i99) + (($$06$i101*68)|0)|0);
     $114 = ($113|0)==($$0$i96|0);
     if ($114) {
      $$05$i102 = $$06$i101;
      break L80;
     }
     $115 = (($$06$i101) + 1)|0;
     $116 = ($115|0)<($111|0);
     if ($116) {
      $$06$i101 = $115;
     } else {
      $$05$i102 = 0;
      break;
     }
    }
   } else {
    $$05$i102 = 0;
   }
  } while(0);
  (_SDL_GetDisplayBounds($$05$i102,$7)|0);
  $117 = HEAP32[$7>>2]|0;
  HEAP32[$61>>2] = $117;
  $118 = ((($7)) + 4|0);
  $119 = HEAP32[$118>>2]|0;
  HEAP32[$62>>2] = $119;
  $120 = ((($7)) + 8|0);
  $121 = HEAP32[$120>>2]|0;
  HEAP32[$63>>2] = $121;
  $122 = ((($7)) + 12|0);
  $123 = HEAP32[$122>>2]|0;
  HEAP32[$64>>2] = $123;
 }
 $124 = $$086 & 1024050;
 $125 = $124 | 8;
 $126 = ((($53)) + 48|0);
 HEAP32[$126>>2] = $125;
 $127 = ((($53)) + 52|0);
 HEAP32[$127>>2] = $125;
 $128 = ((($53)) + 92|0);
 HEAPF32[$128>>2] = 1.0;
 $129 = ((($53)) + 96|0);
 HEAPF32[$129>>2] = 1.0;
 $130 = HEAP32[52375]|0;
 $131 = ((($130)) + 272|0);
 $132 = HEAP32[$131>>2]|0;
 $133 = ((($53)) + 152|0);
 HEAP32[$133>>2] = $132;
 $134 = ((($53)) + 120|0);
 HEAP32[$134>>2] = 0;
 $135 = ($132|0)==(0|0);
 if (!($135)) {
  $136 = ((($132)) + 148|0);
  HEAP32[$136>>2] = $53;
 }
 HEAP32[$131>>2] = $53;
 $137 = ((($130)) + 32|0);
 $138 = HEAP32[$137>>2]|0;
 $139 = ($138|0)==(0|0);
 if (!($139)) {
  $140 = (FUNCTION_TABLE_iii[$138 & 8191]($130,$53)|0);
  $141 = ($140|0)<(0);
  if ($141) {
   _SDL_DestroyWindow($53);
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $142 = ($0|0)==(0|0);
 do {
  if (!($142)) {
   $143 = HEAP32[52375]|0;
   $144 = ($143|0)==(0|0);
   if ($144) {
    (_SDL_SetError(175439,$vararg_buffer9)|0);
    break;
   }
   $145 = HEAP32[$53>>2]|0;
   $146 = ((($143)) + 280|0);
   $147 = ($145|0)==($146|0);
   if (!($147)) {
    (_SDL_SetError(195204,$vararg_buffer11)|0);
    break;
   }
   $148 = ((($53)) + 8|0);
   $149 = HEAP32[$148>>2]|0;
   $150 = ($149|0)==($0|0);
   if (!($150)) {
    _SDL_free($149);
    $151 = (_SDL_strdup($0)|0);
    HEAP32[$148>>2] = $151;
    $152 = HEAP32[52375]|0;
    $153 = ((($152)) + 40|0);
    $154 = HEAP32[$153>>2]|0;
    $155 = ($154|0)==(0|0);
    if (!($155)) {
     FUNCTION_TABLE_vii[$154 & 8191]($152,$53);
    }
   }
  }
 } while(0);
 $156 = $$086 & 128;
 $157 = ($156|0)==(0);
 do {
  if (!($157)) {
   $158 = HEAP32[52375]|0;
   $159 = ($158|0)==(0|0);
   if ($159) {
    (_SDL_SetError(175439,$vararg_buffer13)|0);
    break;
   }
   $160 = HEAP32[$53>>2]|0;
   $161 = ((($158)) + 280|0);
   $162 = ($160|0)==($161|0);
   if (!($162)) {
    (_SDL_SetError(195204,$vararg_buffer15)|0);
    break;
   }
   $163 = HEAP32[$126>>2]|0;
   $164 = $163 & 128;
   $165 = ($164|0)==(0);
   if ($165) {
    $166 = ((($158)) + 92|0);
    $167 = HEAP32[$166>>2]|0;
    $168 = ($167|0)==(0|0);
    if (!($168)) {
     FUNCTION_TABLE_vii[$167 & 8191]($158,$53);
    }
   }
  }
 } while(0);
 $169 = $$086 & 64;
 $170 = ($169|0)==(0);
 do {
  if (!($170)) {
   $171 = HEAP32[52375]|0;
   $172 = ($171|0)==(0|0);
   if ($172) {
    (_SDL_SetError(175439,$vararg_buffer17)|0);
    break;
   }
   $173 = HEAP32[$53>>2]|0;
   $174 = ((($171)) + 280|0);
   $175 = ($173|0)==($174|0);
   if (!($175)) {
    (_SDL_SetError(195204,$vararg_buffer19)|0);
    break;
   }
   $176 = HEAP32[$126>>2]|0;
   $177 = $176 & 64;
   $178 = ($177|0)==(0);
   if ($178) {
    (_SDL_UpdateFullscreenMode($53,0)|0);
    $179 = HEAP32[52375]|0;
    $180 = ((($179)) + 96|0);
    $181 = HEAP32[$180>>2]|0;
    $182 = ($181|0)==(0|0);
    if (!($182)) {
     FUNCTION_TABLE_vii[$181 & 8191]($179,$53);
    }
   }
  }
 } while(0);
 do {
  if (!($103)) {
   $183 = HEAP32[52375]|0;
   $184 = ($183|0)==(0|0);
   if ($184) {
    (_SDL_SetError(175439,$vararg_buffer21)|0);
    break;
   }
   $185 = HEAP32[$53>>2]|0;
   $186 = ((($183)) + 280|0);
   $187 = ($185|0)==($186|0);
   if (!($187)) {
    (_SDL_SetError(195204,$vararg_buffer23)|0);
    break;
   }
   $188 = $$086 & 4097;
   $189 = HEAP32[$126>>2]|0;
   $190 = $189 & 4097;
   $191 = ($188|0)==($190|0);
   if (!($191)) {
    $192 = $189 & -4098;
    $193 = $192 | $188;
    HEAP32[$126>>2] = $193;
    $194 = $189 & 68;
    $195 = ($194|0)==(4);
    $196 = $195&1;
    $197 = (_SDL_UpdateFullscreenMode($53,$196)|0);
    $198 = ($197|0)==(0);
    if (!($198)) {
     $199 = HEAP32[$126>>2]|0;
     $200 = $199 & -4098;
     $201 = $200 | $190;
     HEAP32[$126>>2] = $201;
    }
   }
  }
 } while(0);
 $202 = $$086 & 256;
 $203 = ($202|0)==(0);
 if (!($203)) {
  _SDL_SetWindowGrab($53,1);
 }
 $204 = $$086 & 8;
 $205 = ($204|0)==(0);
 do {
  if ($205) {
   $206 = HEAP32[52375]|0;
   $207 = ($206|0)==(0|0);
   if ($207) {
    (_SDL_SetError(175439,$vararg_buffer25)|0);
    break;
   }
   $208 = HEAP32[$53>>2]|0;
   $209 = ((($206)) + 280|0);
   $210 = ($208|0)==($209|0);
   if (!($210)) {
    (_SDL_SetError(195204,$vararg_buffer27)|0);
    break;
   }
   $211 = HEAP32[$126>>2]|0;
   $212 = $211 & 4;
   $213 = ($212|0)==(0);
   if ($213) {
    $214 = ((($206)) + 80|0);
    $215 = HEAP32[$214>>2]|0;
    $216 = ($215|0)==(0|0);
    if (!($216)) {
     FUNCTION_TABLE_vii[$215 & 8191]($206,$53);
    }
    (_SDL_SendWindowEvent($53,1,0,0)|0);
   }
  }
 } while(0);
 $217 = HEAP32[$126>>2]|0;
 $218 = $217 & 69;
 $219 = ($218|0)==(5);
 $220 = $219&1;
 (_SDL_UpdateFullscreenMode($53,$220)|0);
 $$0 = $53;
 STACKTOP = sp;return ($$0|0);
}
function _emscripten_GetProcAddress($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0;
 var $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0;
 var $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0;
 var $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0;
 var $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0;
 var $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0;
 var $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0;
 var $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0;
 var $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0;
 var $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0;
 var $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0;
 var $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0;
 var $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0;
 var $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0;
 var $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0;
 var $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0;
 var $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0;
 var $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0;
 var $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0;
 var $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0;
 var $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0;
 var $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0;
 var $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0;
 var $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0;
 var $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0;
 var $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = $0;
 $5 = $2;
 $6 = (_strlen($5)|0);
 $7 = (($6) + 1)|0;
 $8 = (_malloc($7)|0);
 $3 = $8;
 $9 = $3;
 $10 = $2;
 (_strcpy($9,$10)|0);
 $11 = $3;
 $12 = (_strstr($11,196081)|0);
 $4 = $12;
 $13 = $4;
 $14 = ($13|0)!=(0|0);
 if ($14) {
  $15 = $4;
  HEAP8[$15>>0] = 0;
 }
 $16 = $3;
 $17 = (_strstr($16,196085)|0);
 $4 = $17;
 $18 = $4;
 $19 = ($18|0)!=(0|0);
 if ($19) {
  $20 = $4;
  HEAP8[$20>>0] = 0;
 }
 $21 = $3;
 $22 = (_strstr($21,196089)|0);
 $4 = $22;
 $23 = $4;
 $24 = ($23|0)!=(0|0);
 if ($24) {
  $25 = $4;
  HEAP8[$25>>0] = 0;
 }
 $26 = $3;
 $27 = (_strstr($26,196093)|0);
 $4 = $27;
 $28 = $4;
 $29 = ($28|0)!=(0|0);
 if ($29) {
  $30 = $4;
  HEAP8[$30>>0] = 0;
 }
 $31 = $3;
 $32 = (_strcmp($31,196099)|0);
 $33 = ($32|0)!=(0);
 do {
  if ($33) {
   $34 = $3;
   $35 = (_strcmp($34,196137)|0);
   $36 = ($35|0)!=(0);
   if (!($36)) {
    $3 = 196156;
    break;
   }
   $37 = $3;
   $38 = (_strcmp($37,196169)|0);
   $39 = ($38|0)!=(0);
   if (!($39)) {
    $3 = 196190;
    break;
   }
   $40 = $3;
   $41 = (_strcmp($40,196205)|0);
   $42 = ($41|0)!=(0);
   if (!($42)) {
    $3 = 196220;
    break;
   }
   $43 = $3;
   $44 = (_strcmp($43,196235)|0);
   $45 = ($44|0)!=(0);
   if (!($45)) {
    $3 = 196250;
   }
  } else {
   $3 = 196121;
  }
 } while(0);
 $46 = $3;
 $47 = (_strcmp($46,196265)|0);
 $48 = ($47|0)!=(0);
 do {
  if ($48) {
   $49 = $3;
   $50 = (_strcmp($49,196279)|0);
   $51 = ($50|0)!=(0);
   if (!($51)) {
    $1 = 4491;
    break;
   }
   $52 = $3;
   $53 = (_strcmp($52,196291)|0);
   $54 = ($53|0)!=(0);
   if (!($54)) {
    $1 = 4492;
    break;
   }
   $55 = $3;
   $56 = (_strcmp($55,196305)|0);
   $57 = ($56|0)!=(0);
   if (!($57)) {
    $1 = 4493;
    break;
   }
   $58 = $3;
   $59 = (_strcmp($58,196317)|0);
   $60 = ($59|0)!=(0);
   if (!($60)) {
    $1 = 4494;
    break;
   }
   $61 = $3;
   $62 = (_strcmp($61,196331)|0);
   $63 = ($62|0)!=(0);
   if (!($63)) {
    $1 = 4495;
    break;
   }
   $64 = $3;
   $65 = (_strcmp($64,196345)|0);
   $66 = ($65|0)!=(0);
   if (!($66)) {
    $1 = 4496;
    break;
   }
   $67 = $3;
   $68 = (_strcmp($67,196362)|0);
   $69 = ($68|0)!=(0);
   if (!($69)) {
    $1 = 4497;
    break;
   }
   $70 = $3;
   $71 = (_strcmp($70,196385)|0);
   $72 = ($71|0)!=(0);
   if (!($72)) {
    $1 = 4498;
    break;
   }
   $73 = $3;
   $74 = (_strcmp($73,196411)|0);
   $75 = ($74|0)!=(0);
   if (!($75)) {
    $1 = 4499;
    break;
   }
   $76 = $3;
   $77 = (_strcmp($76,196424)|0);
   $78 = ($77|0)!=(0);
   if (!($78)) {
    $1 = 4500;
    break;
   }
   $79 = $3;
   $80 = (_strcmp($79,196440)|0);
   $81 = ($80|0)!=(0);
   if (!($81)) {
    $1 = 4501;
    break;
   }
   $82 = $3;
   $83 = (_strcmp($82,196453)|0);
   $84 = ($83|0)!=(0);
   if (!($84)) {
    $1 = 4502;
    break;
   }
   $85 = $3;
   $86 = (_strcmp($85,196467)|0);
   $87 = ($86|0)!=(0);
   if (!($87)) {
    $1 = 4503;
    break;
   }
   $88 = $3;
   $89 = (_strcmp($88,196487)|0);
   $90 = ($89|0)!=(0);
   if (!($90)) {
    $1 = 4504;
    break;
   }
   $91 = $3;
   $92 = (_strcmp($91,196507)|0);
   $93 = ($92|0)!=(0);
   if (!($93)) {
    $1 = 4505;
    break;
   }
   $94 = $3;
   $95 = (_strcmp($94,196524)|0);
   $96 = ($95|0)!=(0);
   if (!($96)) {
    $1 = 4506;
    break;
   }
   $97 = $3;
   $98 = (_strcmp($97,196541)|0);
   $99 = ($98|0)!=(0);
   if (!($99)) {
    $1 = 4507;
    break;
   }
   $100 = $3;
   $101 = (_strcmp($100,196553)|0);
   $102 = ($101|0)!=(0);
   if (!($102)) {
    $1 = 4508;
    break;
   }
   $103 = $3;
   $104 = (_strcmp($103,196566)|0);
   $105 = ($104|0)!=(0);
   if (!($105)) {
    $1 = 4509;
    break;
   }
   $106 = $3;
   $107 = (_strcmp($106,196582)|0);
   $108 = ($107|0)!=(0);
   if (!($108)) {
    $1 = 4510;
    break;
   }
   $109 = $3;
   $110 = (_strcmp($109,196605)|0);
   $111 = ($110|0)!=(0);
   if (!($111)) {
    $1 = 4511;
    break;
   }
   $112 = $3;
   $113 = (_strcmp($112,196618)|0);
   $114 = ($113|0)!=(0);
   if (!($114)) {
    $1 = 4512;
    break;
   }
   $115 = $3;
   $116 = (_strcmp($115,196634)|0);
   $117 = ($116|0)!=(0);
   if (!($117)) {
    $1 = 4513;
    break;
   }
   $118 = $3;
   $119 = (_strcmp($118,196645)|0);
   $120 = ($119|0)!=(0);
   if (!($120)) {
    $1 = 4514;
    break;
   }
   $121 = $3;
   $122 = (_strcmp($121,196664)|0);
   $123 = ($122|0)!=(0);
   if (!($123)) {
    $1 = 4515;
    break;
   }
   $124 = $3;
   $125 = (_strcmp($124,196686)|0);
   $126 = ($125|0)!=(0);
   if (!($126)) {
    $1 = 4516;
    break;
   }
   $127 = $3;
   $128 = (_strcmp($127,196705)|0);
   $129 = ($128|0)!=(0);
   if (!($129)) {
    $1 = 4517;
    break;
   }
   $130 = $3;
   $131 = (_strcmp($130,196734)|0);
   $132 = ($131|0)!=(0);
   if (!($132)) {
    $1 = 4518;
    break;
   }
   $133 = $3;
   $134 = (_strcmp($133,196751)|0);
   $135 = ($134|0)!=(0);
   if (!($135)) {
    $1 = 4519;
    break;
   }
   $136 = $3;
   $137 = (_strcmp($136,196766)|0);
   $138 = ($137|0)!=(0);
   if (!($138)) {
    $1 = 4520;
    break;
   }
   $139 = $3;
   $140 = (_strcmp($139,196781)|0);
   $141 = ($140|0)!=(0);
   if (!($141)) {
    $1 = 4521;
    break;
   }
   $142 = $3;
   $143 = (_strcmp($142,196802)|0);
   $144 = ($143|0)!=(0);
   if (!($144)) {
    $1 = 4522;
    break;
   }
   $145 = $3;
   $146 = (_strcmp($145,196822)|0);
   $147 = ($146|0)!=(0);
   if (!($147)) {
    $1 = 4523;
    break;
   }
   $148 = $3;
   $149 = (_strcmp($148,196842)|0);
   $150 = ($149|0)!=(0);
   if (!($150)) {
    $1 = 4524;
    break;
   }
   $151 = $3;
   $152 = (_strcmp($151,196868)|0);
   $153 = ($152|0)!=(0);
   if (!($153)) {
    $1 = 4525;
    break;
   }
   $154 = $3;
   $155 = (_strcmp($154,196887)|0);
   $156 = ($155|0)!=(0);
   if (!($156)) {
    $1 = 4526;
    break;
   }
   $157 = $3;
   $158 = (_strcmp($157,196899)|0);
   $159 = ($158|0)!=(0);
   if (!($159)) {
    $1 = 4527;
    break;
   }
   $160 = $3;
   $161 = (_strcmp($160,196911)|0);
   $162 = ($161|0)!=(0);
   if (!($162)) {
    $1 = 4528;
    break;
   }
   $163 = $3;
   $164 = (_strcmp($163,196923)|0);
   $165 = ($164|0)!=(0);
   if (!($165)) {
    $1 = 4529;
    break;
   }
   $166 = $3;
   $167 = (_strcmp($166,196935)|0);
   $168 = ($167|0)!=(0);
   if (!($168)) {
    $1 = 4530;
    break;
   }
   $169 = $3;
   $170 = (_strcmp($169,196947)|0);
   $171 = ($170|0)!=(0);
   if (!($171)) {
    $1 = 4531;
    break;
   }
   $172 = $3;
   $173 = (_strcmp($172,196959)|0);
   $174 = ($173|0)!=(0);
   if (!($174)) {
    $1 = 4532;
    break;
   }
   $175 = $3;
   $176 = (_strcmp($175,196971)|0);
   $177 = ($176|0)!=(0);
   if (!($177)) {
    $1 = 4533;
    break;
   }
   $178 = $3;
   $179 = (_strcmp($178,196983)|0);
   $180 = ($179|0)!=(0);
   if (!($180)) {
    $1 = 4534;
    break;
   }
   $181 = $3;
   $182 = (_strcmp($181,196996)|0);
   $183 = ($182|0)!=(0);
   if (!($183)) {
    $1 = 4535;
    break;
   }
   $184 = $3;
   $185 = (_strcmp($184,197009)|0);
   $186 = ($185|0)!=(0);
   if (!($186)) {
    $1 = 4536;
    break;
   }
   $187 = $3;
   $188 = (_strcmp($187,197022)|0);
   $189 = ($188|0)!=(0);
   if (!($189)) {
    $1 = 4537;
    break;
   }
   $190 = $3;
   $191 = (_strcmp($190,197035)|0);
   $192 = ($191|0)!=(0);
   if (!($192)) {
    $1 = 4538;
    break;
   }
   $193 = $3;
   $194 = (_strcmp($193,197048)|0);
   $195 = ($194|0)!=(0);
   if (!($195)) {
    $1 = 4539;
    break;
   }
   $196 = $3;
   $197 = (_strcmp($196,197061)|0);
   $198 = ($197|0)!=(0);
   if (!($198)) {
    $1 = 4540;
    break;
   }
   $199 = $3;
   $200 = (_strcmp($199,197074)|0);
   $201 = ($200|0)!=(0);
   if (!($201)) {
    $1 = 4541;
    break;
   }
   $202 = $3;
   $203 = (_strcmp($202,197087)|0);
   $204 = ($203|0)!=(0);
   if (!($204)) {
    $1 = 4542;
    break;
   }
   $205 = $3;
   $206 = (_strcmp($205,197106)|0);
   $207 = ($206|0)!=(0);
   if (!($207)) {
    $1 = 4543;
    break;
   }
   $208 = $3;
   $209 = (_strcmp($208,197125)|0);
   $210 = ($209|0)!=(0);
   if (!($210)) {
    $1 = 4544;
    break;
   }
   $211 = $3;
   $212 = (_strcmp($211,197144)|0);
   $213 = ($212|0)!=(0);
   if (!($213)) {
    $1 = 4545;
    break;
   }
   $214 = $3;
   $215 = (_strcmp($214,197157)|0);
   $216 = ($215|0)!=(0);
   if (!($216)) {
    $1 = 4546;
    break;
   }
   $217 = $3;
   $218 = (_strcmp($217,197175)|0);
   $219 = ($218|0)!=(0);
   if (!($219)) {
    $1 = 4547;
    break;
   }
   $220 = $3;
   $221 = (_strcmp($220,197193)|0);
   $222 = ($221|0)!=(0);
   if (!($222)) {
    $1 = 4548;
    break;
   }
   $223 = $3;
   $224 = (_strcmp($223,197211)|0);
   $225 = ($224|0)!=(0);
   if (!($225)) {
    $1 = 4549;
    break;
   }
   $226 = $3;
   $227 = (_strcmp($226,197229)|0);
   $228 = ($227|0)!=(0);
   if (!($228)) {
    $1 = 4550;
    break;
   }
   $229 = $3;
   $230 = (_strcmp($229,197249)|0);
   $231 = ($230|0)!=(0);
   if (!($231)) {
    $1 = 4551;
    break;
   }
   $232 = $3;
   $233 = (_strcmp($232,196190)|0);
   $234 = ($233|0)!=(0);
   if (!($234)) {
    $1 = 4552;
    break;
   }
   $235 = $3;
   $236 = (_strcmp($235,197267)|0);
   $237 = ($236|0)!=(0);
   if (!($237)) {
    $1 = 4553;
    break;
   }
   $238 = $3;
   $239 = (_strcmp($238,197282)|0);
   $240 = ($239|0)!=(0);
   if (!($240)) {
    $1 = 4554;
    break;
   }
   $241 = $3;
   $242 = (_strcmp($241,197303)|0);
   $243 = ($242|0)!=(0);
   if (!($243)) {
    $1 = 4555;
    break;
   }
   $244 = $3;
   $245 = (_strcmp($244,197318)|0);
   $246 = ($245|0)!=(0);
   if (!($246)) {
    $1 = 4556;
    break;
   }
   $247 = $3;
   $248 = (_strcmp($247,197336)|0);
   $249 = ($248|0)!=(0);
   if (!($249)) {
    $1 = 4557;
    break;
   }
   $250 = $3;
   $251 = (_strcmp($250,197352)|0);
   $252 = ($251|0)!=(0);
   if (!($252)) {
    $1 = 4558;
    break;
   }
   $253 = $3;
   $254 = (_strcmp($253,197371)|0);
   $255 = ($254|0)!=(0);
   if (!($255)) {
    $1 = 4559;
    break;
   }
   $256 = $3;
   $257 = (_strcmp($256,197385)|0);
   $258 = ($257|0)!=(0);
   if (!($258)) {
    $1 = 4560;
    break;
   }
   $259 = $3;
   $260 = (_strcmp($259,197400)|0);
   $261 = ($260|0)!=(0);
   if (!($261)) {
    $1 = 4561;
    break;
   }
   $262 = $3;
   $263 = (_strcmp($262,196121)|0);
   $264 = ($263|0)!=(0);
   if (!($264)) {
    $1 = 4562;
    break;
   }
   $265 = $3;
   $266 = (_strcmp($265,197411)|0);
   $267 = ($266|0)!=(0);
   if (!($267)) {
    $1 = 4563;
    break;
   }
   $268 = $3;
   $269 = (_strcmp($268,196220)|0);
   $270 = ($269|0)!=(0);
   if (!($270)) {
    $1 = 4564;
    break;
   }
   $271 = $3;
   $272 = (_strcmp($271,196250)|0);
   $273 = ($272|0)!=(0);
   if (!($273)) {
    $1 = 4565;
    break;
   }
   $274 = $3;
   $275 = (_strcmp($274,197427)|0);
   $276 = ($275|0)!=(0);
   if (!($276)) {
    $1 = 4566;
    break;
   }
   $277 = $3;
   $278 = (_strcmp($277,197454)|0);
   $279 = ($278|0)!=(0);
   if (!($279)) {
    $1 = 4567;
    break;
   }
   $280 = $3;
   $281 = (_strcmp($280,197468)|0);
   $282 = ($281|0)!=(0);
   if (!($282)) {
    $1 = 4568;
    break;
   }
   $283 = $3;
   $284 = (_strcmp($283,196156)|0);
   $285 = ($284|0)!=(0);
   if (!($285)) {
    $1 = 4569;
    break;
   }
   $286 = $3;
   $287 = (_strcmp($286,197488)|0);
   $288 = ($287|0)!=(0);
   if (!($288)) {
    $1 = 4570;
    break;
   }
   $289 = $3;
   $290 = (_strcmp($289,197506)|0);
   $291 = ($290|0)!=(0);
   if (!($291)) {
    $1 = 4571;
    break;
   }
   $292 = $3;
   $293 = (_strcmp($292,197518)|0);
   $294 = ($293|0)!=(0);
   if (!($294)) {
    $1 = 4572;
    break;
   }
   $295 = $3;
   $296 = (_strcmp($295,197539)|0);
   $297 = ($296|0)!=(0);
   if (!($297)) {
    $1 = 4573;
    break;
   }
   $298 = $3;
   $299 = (_strcmp($298,197557)|0);
   $300 = ($299|0)!=(0);
   if (!($300)) {
    $1 = 4574;
    break;
   }
   $301 = $3;
   $302 = (_strcmp($301,197575)|0);
   $303 = ($302|0)!=(0);
   if (!($303)) {
    $1 = 4575;
    break;
   }
   $304 = $3;
   $305 = (_strcmp($304,197596)|0);
   $306 = ($305|0)!=(0);
   if (!($306)) {
    $1 = 4576;
    break;
   }
   $307 = $3;
   $308 = (_strcmp($307,197622)|0);
   $309 = ($308|0)!=(0);
   if (!($309)) {
    $1 = 4577;
    break;
   }
   $310 = $3;
   $311 = (_strcmp($310,197645)|0);
   $312 = ($311|0)!=(0);
   if (!($312)) {
    $1 = 4578;
    break;
   }
   $313 = $3;
   $314 = (_strcmp($313,197683)|0);
   $315 = ($314|0)!=(0);
   if (!($315)) {
    $1 = 4579;
    break;
   }
   $316 = $3;
   $317 = (_strcmp($316,197699)|0);
   $318 = ($317|0)!=(0);
   if (!($318)) {
    $1 = 4580;
    break;
   }
   $319 = $3;
   $320 = (_strcmp($319,197714)|0);
   $321 = ($320|0)!=(0);
   if (!($321)) {
    $1 = 4581;
    break;
   }
   $322 = $3;
   $323 = (_strcmp($322,197737)|0);
   $324 = ($323|0)!=(0);
   if (!($324)) {
    $1 = 4582;
    break;
   }
   $325 = $3;
   $326 = (_strcmp($325,197750)|0);
   $327 = ($326|0)!=(0);
   if (!($327)) {
    $1 = 4583;
    break;
   }
   $328 = $3;
   $329 = (_strcmp($328,197764)|0);
   $330 = ($329|0)!=(0);
   if (!($330)) {
    $1 = 4584;
    break;
   }
   $331 = $3;
   $332 = (_strcmp($331,197778)|0);
   $333 = ($332|0)!=(0);
   if (!($333)) {
    $1 = 4585;
    break;
   }
   $334 = $3;
   $335 = (_strcmp($334,197798)|0);
   $336 = ($335|0)!=(0);
   if (!($336)) {
    $1 = 4586;
    break;
   }
   $337 = $3;
   $338 = (_strcmp($337,197818)|0);
   $339 = ($338|0)!=(0);
   if (!($339)) {
    $1 = 4587;
    break;
   }
   $340 = $3;
   $341 = (_strcmp($340,197834)|0);
   $342 = ($341|0)!=(0);
   if (!($342)) {
    $1 = 4588;
    break;
   }
   $343 = $3;
   $344 = (_strcmp($343,197852)|0);
   $345 = ($344|0)!=(0);
   if (!($345)) {
    $1 = 4589;
    break;
   }
   $346 = $3;
   $347 = (_strcmp($346,197868)|0);
   $348 = ($347|0)!=(0);
   if (!($348)) {
    $1 = 4590;
    break;
   }
   $349 = $3;
   $350 = (_strcmp($349,197883)|0);
   $351 = ($350|0)!=(0);
   if (!($351)) {
    $1 = 4591;
    break;
   }
   $352 = $3;
   $353 = (_strcmp($352,197905)|0);
   $354 = ($353|0)!=(0);
   if (!($354)) {
    $1 = 4592;
    break;
   }
   $355 = $3;
   $356 = (_strcmp($355,197923)|0);
   $357 = ($356|0)!=(0);
   if (!($357)) {
    $1 = 4593;
    break;
   }
   $358 = $3;
   $359 = (_strcmp($358,197944)|0);
   $360 = ($359|0)!=(0);
   if (!($360)) {
    $1 = 4594;
    break;
   }
   $361 = $3;
   $362 = (_strcmp($361,197962)|0);
   $363 = ($362|0)!=(0);
   if (!($363)) {
    $1 = 4595;
    break;
   }
   $364 = $3;
   $365 = (_strcmp($364,197975)|0);
   $366 = ($365|0)!=(0);
   if (!($366)) {
    $1 = 4596;
    break;
   }
   $367 = $3;
   $368 = (_strcmp($367,197990)|0);
   $369 = ($368|0)!=(0);
   if (!($369)) {
    $1 = 4597;
    break;
   }
   $370 = $3;
   $371 = (_strcmp($370,198004)|0);
   $372 = ($371|0)!=(0);
   if (!($372)) {
    $1 = 4598;
    break;
   }
   $373 = $3;
   $374 = (_strcmp($373,198014)|0);
   $375 = ($374|0)!=(0);
   if (!($375)) {
    $1 = 4599;
    break;
   }
   $376 = $3;
   $377 = (_strcmp($376,198024)|0);
   $378 = ($377|0)!=(0);
   if (!($378)) {
    $1 = 4600;
    break;
   }
   $379 = $3;
   $380 = (_strcmp($379,198046)|0);
   $381 = ($380|0)!=(0);
   if (!($381)) {
    $1 = 4601;
    break;
   }
   $382 = $3;
   $383 = (_strcmp($382,198072)|0);
   $384 = ($383|0)!=(0);
   if (!($384)) {
    $1 = 4602;
    break;
   }
   $385 = $3;
   $386 = (_strcmp($385,198099)|0);
   $387 = ($386|0)!=(0);
   if (!($387)) {
    $1 = 4603;
    break;
   }
   $388 = $3;
   $389 = (_strcmp($388,198112)|0);
   $390 = ($389|0)!=(0);
   if (!($390)) {
    $1 = 4604;
    break;
   }
   $391 = $3;
   $392 = (_strcmp($391,198127)|0);
   $393 = ($392|0)!=(0);
   if (!($393)) {
    $1 = 4605;
    break;
   }
   $394 = $3;
   $395 = (_strcmp($394,198142)|0);
   $396 = ($395|0)!=(0);
   if (!($396)) {
    $1 = 4606;
    break;
   }
   $397 = $3;
   $398 = (_strcmp($397,198166)|0);
   $399 = ($398|0)!=(0);
   if (!($399)) {
    $1 = 4607;
    break;
   }
   $400 = $3;
   $401 = (_strcmp($400,198177)|0);
   $402 = ($401|0)!=(0);
   if (!($402)) {
    $1 = 4608;
    break;
   }
   $403 = $3;
   $404 = (_strcmp($403,198199)|0);
   $405 = ($404|0)!=(0);
   if (!($405)) {
    $1 = 4609;
    break;
   }
   $406 = $3;
   $407 = (_strcmp($406,198221)|0);
   $408 = ($407|0)!=(0);
   if (!($408)) {
    $1 = 4610;
    break;
   }
   $409 = $3;
   $410 = (_strcmp($409,198245)|0);
   $411 = ($410|0)!=(0);
   if (!($411)) {
    $1 = 4611;
    break;
   }
   $412 = $3;
   $413 = (_strcmp($412,198254)|0);
   $414 = ($413|0)!=(0);
   if (!($414)) {
    $1 = 4612;
    break;
   }
   $415 = $3;
   $416 = (_strcmp($415,198262)|0);
   $417 = ($416|0)!=(0);
   if (!($417)) {
    $1 = 4613;
    break;
   }
   $418 = $3;
   $419 = (_strcmp($418,198275)|0);
   $420 = ($419|0)!=(0);
   if (!($420)) {
    $1 = 4614;
    break;
   }
   $421 = $3;
   $422 = (_strcmp($421,198289)|0);
   $423 = ($422|0)!=(0);
   if (!($423)) {
    $1 = 4615;
    break;
   }
   $424 = $3;
   $425 = (_strcmp($424,198301)|0);
   $426 = ($425|0)!=(0);
   if (!($426)) {
    $1 = 4616;
    break;
   }
   $427 = $3;
   $428 = (_strcmp($427,198310)|0);
   $429 = ($428|0)!=(0);
   if (!($429)) {
    $1 = 4617;
    break;
   }
   $430 = $3;
   $431 = (_strcmp($430,198320)|0);
   $432 = ($431|0)!=(0);
   if (!($432)) {
    $1 = 4618;
    break;
   }
   $433 = $3;
   $434 = (_strcmp($433,198332)|0);
   $435 = ($434|0)!=(0);
   if (!($435)) {
    $1 = 4619;
    break;
   }
   $436 = $3;
   $437 = (_strcmp($436,198343)|0);
   $438 = ($437|0)!=(0);
   if (!($438)) {
    $1 = 4620;
    break;
   }
   $439 = $3;
   $440 = (_strcmp($439,198351)|0);
   $441 = ($440|0)!=(0);
   if (!($441)) {
    $1 = 4621;
    break;
   }
   $442 = $3;
   $443 = (_strcmp($442,198363)|0);
   $444 = ($443|0)!=(0);
   if (!($444)) {
    $1 = 4622;
    break;
   }
   $445 = $3;
   $446 = (_strcmp($445,198378)|0);
   $447 = ($446|0)!=(0);
   if (!($447)) {
    $1 = 4623;
    break;
   }
   $448 = $3;
   $449 = (_strcmp($448,198390)|0);
   $450 = ($449|0)!=(0);
   if (!($450)) {
    $1 = 4624;
    break;
   }
   $451 = $3;
   $452 = (_strcmp($451,198404)|0);
   $453 = ($452|0)!=(0);
   if (!($453)) {
    $1 = 4625;
    break;
   }
   $454 = $3;
   $455 = (_strcmp($454,198429)|0);
   $456 = ($455|0)!=(0);
   if (!($456)) {
    $1 = 4626;
    break;
   }
   $457 = $3;
   $458 = (_strcmp($457,198446)|0);
   $459 = ($458|0)!=(0);
   if (!($459)) {
    $1 = 4627;
    break;
   }
   $460 = $3;
   $461 = (_strcmp($460,198462)|0);
   $462 = ($461|0)!=(0);
   if (!($462)) {
    $1 = 4628;
    break;
   }
   $463 = $3;
   $464 = (_strcmp($463,198478)|0);
   $465 = ($464|0)!=(0);
   if (!($465)) {
    $1 = 4629;
    break;
   }
   $466 = $3;
   $467 = (_strcmp($466,198490)|0);
   $468 = ($467|0)!=(0);
   if (!($468)) {
    $1 = 4630;
    break;
   }
   $469 = $3;
   $470 = (_strcmp($469,198502)|0);
   $471 = ($470|0)!=(0);
   if (!($471)) {
    $1 = 4631;
    break;
   }
   $472 = $3;
   $473 = (_strcmp($472,198526)|0);
   $474 = ($473|0)!=(0);
   if (!($474)) {
    $1 = 4632;
    break;
   }
   $475 = $3;
   $476 = (_strcmp($475,198539)|0);
   $477 = ($476|0)!=(0);
   if (!($477)) {
    $1 = 4633;
    break;
   }
   $478 = $3;
   $479 = (_strcmp($478,198553)|0);
   $480 = ($479|0)!=(0);
   if (!($480)) {
    $1 = 4634;
    break;
   }
   $481 = $3;
   $482 = (_strcmp($481,198575)|0);
   $483 = ($482|0)!=(0);
   if (!($483)) {
    $1 = 4635;
    break;
   }
   $484 = $3;
   $485 = (_strcmp($484,198582)|0);
   $486 = ($485|0)!=(0);
   if (!($486)) {
    $1 = 4636;
    break;
   }
   $487 = $3;
   $488 = (_strcmp($487,198598)|0);
   $489 = ($488|0)!=(0);
   if (!($489)) {
    $1 = 4637;
    break;
   }
   $490 = $3;
   $491 = (_strcmp($490,198615)|0);
   $492 = ($491|0)!=(0);
   if (!($492)) {
    $1 = 4638;
    break;
   }
   $493 = $3;
   $494 = (_strcmp($493,198632)|0);
   $495 = ($494|0)!=(0);
   if (!($495)) {
    $1 = 4639;
    break;
   }
   $496 = $3;
   $497 = (_strcmp($496,198648)|0);
   $498 = ($497|0)!=(0);
   if (!($498)) {
    $1 = 4640;
    break;
   }
   $499 = $3;
   $500 = (_strcmp($499,198664)|0);
   $501 = ($500|0)!=(0);
   if (!($501)) {
    $1 = 4641;
    break;
   }
   $502 = $3;
   $503 = (_strcmp($502,198681)|0);
   $504 = ($503|0)!=(0);
   if (!($504)) {
    $1 = 4642;
    break;
   }
   $505 = $3;
   $506 = (_strcmp($505,198695)|0);
   $507 = ($506|0)!=(0);
   if (!($507)) {
    $1 = 4643;
    break;
   }
   $508 = $3;
   $509 = (_strcmp($508,198707)|0);
   $510 = ($509|0)!=(0);
   if (!($510)) {
    $1 = 4644;
    break;
   }
   $511 = $3;
   $512 = (_strcmp($511,198718)|0);
   $513 = ($512|0)!=(0);
   if (!($513)) {
    $1 = 4645;
    break;
   }
   $514 = $3;
   $515 = (_strcmp($514,198731)|0);
   $516 = ($515|0)!=(0);
   if (!($516)) {
    $1 = 4646;
    break;
   }
   $517 = $3;
   $518 = (_strcmp($517,198741)|0);
   $519 = ($518|0)!=(0);
   if (!($519)) {
    $1 = 4647;
    break;
   }
   $520 = $3;
   $521 = (_strcmp($520,198758)|0);
   $522 = ($521|0)!=(0);
   if (!($522)) {
    $1 = 4648;
    break;
   }
   $523 = $3;
   $524 = (_strcmp($523,198770)|0);
   $525 = ($524|0)!=(0);
   if (!($525)) {
    $1 = 4649;
    break;
   }
   $526 = $3;
   $527 = (_strcmp($526,198792)|0);
   $528 = ($527|0)!=(0);
   if (!($528)) {
    $1 = 4650;
    break;
   }
   $529 = $3;
   $530 = (_strcmp($529,198812)|0);
   $531 = ($530|0)!=(0);
   if (!($531)) {
    $1 = 4651;
    break;
   }
   $532 = $3;
   $533 = (_strcmp($532,198825)|0);
   $534 = ($533|0)!=(0);
   if (!($534)) {
    $1 = 4652;
    break;
   }
   $535 = $3;
   $536 = (_strcmp($535,198847)|0);
   $537 = ($536|0)!=(0);
   if (!($537)) {
    $1 = 4653;
    break;
   }
   $538 = $3;
   $539 = (_strcmp($538,198867)|0);
   $540 = ($539|0)!=(0);
   if (!($540)) {
    $1 = 4654;
    break;
   }
   $541 = $3;
   $542 = (_strcmp($541,198884)|0);
   $543 = ($542|0)!=(0);
   if (!($543)) {
    $1 = 4655;
    break;
   }
   $544 = $3;
   $545 = (_strcmp($544,198901)|0);
   $546 = ($545|0)!=(0);
   if (!($546)) {
    $1 = 4656;
    break;
   }
   $547 = $3;
   $548 = (_strcmp($547,198921)|0);
   $549 = ($548|0)!=(0);
   if ($549) {
    $550 = $2;
    $551 = $3;
    $552 = _emscripten_asm_const_iii(16, ($550|0), ($551|0))|0;
    $1 = 0;
    break;
   } else {
    $1 = 4657;
    break;
   }
  } else {
   $1 = 4490;
  }
 } while(0);
 $553 = $1;
 STACKTOP = sp;return ($553|0);
}
function _malloc($0) {
 $0 = $0|0;
 var $$$0172$i = 0, $$$0173$i = 0, $$$4236$i = 0, $$$4329$i = 0, $$$i = 0, $$0 = 0, $$0$i = 0, $$0$i$i = 0, $$0$i$i$i = 0, $$0$i20$i = 0, $$01$i$i = 0, $$0172$lcssa$i = 0, $$01726$i = 0, $$0173$lcssa$i = 0, $$01735$i = 0, $$0192 = 0, $$0194 = 0, $$0201$i$i = 0, $$0202$i$i = 0, $$0206$i$i = 0;
 var $$0207$i$i = 0, $$024370$i = 0, $$0260$i$i = 0, $$0261$i$i = 0, $$0262$i$i = 0, $$0268$i$i = 0, $$0269$i$i = 0, $$0320$i = 0, $$0322$i = 0, $$0323$i = 0, $$0325$i = 0, $$0331$i = 0, $$0336$i = 0, $$0337$$i = 0, $$0337$i = 0, $$0339$i = 0, $$0340$i = 0, $$0345$i = 0, $$1176$i = 0, $$1178$i = 0;
 var $$124469$i = 0, $$1264$i$i = 0, $$1266$i$i = 0, $$1321$i = 0, $$1326$i = 0, $$1341$i = 0, $$1347$i = 0, $$1351$i = 0, $$2234243136$i = 0, $$2247$ph$i = 0, $$2253$ph$i = 0, $$2333$i = 0, $$3$i = 0, $$3$i$i = 0, $$3$i200 = 0, $$3328$i = 0, $$3349$i = 0, $$4$lcssa$i = 0, $$4$ph$i = 0, $$411$i = 0;
 var $$4236$i = 0, $$4329$lcssa$i = 0, $$432910$i = 0, $$4335$$4$i = 0, $$4335$ph$i = 0, $$43359$i = 0, $$723947$i = 0, $$748$i = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i17$i = 0, $$pre$i195 = 0, $$pre$i210 = 0, $$pre$phi$i$iZ2D = 0, $$pre$phi$i18$iZ2D = 0, $$pre$phi$i211Z2D = 0, $$pre$phi$iZ2D = 0, $$pre$phiZ2D = 0, $$sink1$i = 0;
 var $$sink1$i$i = 0, $$sink14$i = 0, $$sink2$i = 0, $$sink2$i204 = 0, $$sink3$i = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0;
 var $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0;
 var $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0;
 var $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0;
 var $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0;
 var $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0;
 var $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0;
 var $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0;
 var $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0;
 var $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0;
 var $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0;
 var $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0;
 var $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0;
 var $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0;
 var $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0;
 var $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0;
 var $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0;
 var $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0;
 var $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0;
 var $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0;
 var $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0;
 var $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0;
 var $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0;
 var $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0;
 var $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0;
 var $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0;
 var $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0;
 var $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0;
 var $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0;
 var $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0;
 var $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0;
 var $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0;
 var $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0;
 var $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0;
 var $798 = 0, $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0;
 var $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0;
 var $833 = 0, $834 = 0, $835 = 0, $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0, $850 = 0;
 var $851 = 0, $852 = 0, $853 = 0, $854 = 0, $855 = 0, $856 = 0, $857 = 0, $858 = 0, $859 = 0, $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0, $869 = 0;
 var $87 = 0, $870 = 0, $871 = 0, $872 = 0, $873 = 0, $874 = 0, $875 = 0, $876 = 0, $877 = 0, $878 = 0, $879 = 0, $88 = 0, $880 = 0, $881 = 0, $882 = 0, $883 = 0, $884 = 0, $885 = 0, $886 = 0, $887 = 0;
 var $888 = 0, $889 = 0, $89 = 0, $890 = 0, $891 = 0, $892 = 0, $893 = 0, $894 = 0, $895 = 0, $896 = 0, $897 = 0, $898 = 0, $899 = 0, $9 = 0, $90 = 0, $900 = 0, $901 = 0, $902 = 0, $903 = 0, $904 = 0;
 var $905 = 0, $906 = 0, $907 = 0, $908 = 0, $909 = 0, $91 = 0, $910 = 0, $911 = 0, $912 = 0, $913 = 0, $914 = 0, $915 = 0, $916 = 0, $917 = 0, $918 = 0, $919 = 0, $92 = 0, $920 = 0, $921 = 0, $922 = 0;
 var $923 = 0, $924 = 0, $925 = 0, $926 = 0, $927 = 0, $928 = 0, $929 = 0, $93 = 0, $930 = 0, $931 = 0, $932 = 0, $933 = 0, $934 = 0, $935 = 0, $936 = 0, $937 = 0, $938 = 0, $939 = 0, $94 = 0, $940 = 0;
 var $941 = 0, $942 = 0, $943 = 0, $944 = 0, $945 = 0, $946 = 0, $947 = 0, $948 = 0, $949 = 0, $95 = 0, $950 = 0, $951 = 0, $952 = 0, $953 = 0, $954 = 0, $955 = 0, $956 = 0, $957 = 0, $958 = 0, $959 = 0;
 var $96 = 0, $960 = 0, $961 = 0, $962 = 0, $963 = 0, $964 = 0, $965 = 0, $966 = 0, $967 = 0, $968 = 0, $969 = 0, $97 = 0, $970 = 0, $98 = 0, $99 = 0, $cond$i = 0, $cond$i$i = 0, $cond$i208 = 0, $exitcond$i$i = 0, $not$$i = 0;
 var $not$$i$i = 0, $not$$i197 = 0, $not$$i209 = 0, $not$1$i = 0, $not$1$i203 = 0, $not$3$i = 0, $not$5$i = 0, $or$cond$i = 0, $or$cond$i201 = 0, $or$cond1$i = 0, $or$cond10$i = 0, $or$cond11$i = 0, $or$cond11$not$i = 0, $or$cond12$i = 0, $or$cond2$i = 0, $or$cond2$i199 = 0, $or$cond49$i = 0, $or$cond5$i = 0, $or$cond50$i = 0, $or$cond7$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $2 = ($0>>>0)<(245);
 do {
  if ($2) {
   $3 = ($0>>>0)<(11);
   $4 = (($0) + 11)|0;
   $5 = $4 & -8;
   $6 = $3 ? 16 : $5;
   $7 = $6 >>> 3;
   $8 = HEAP32[53381]|0;
   $9 = $8 >>> $7;
   $10 = $9 & 3;
   $11 = ($10|0)==(0);
   if (!($11)) {
    $12 = $9 & 1;
    $13 = $12 ^ 1;
    $14 = (($13) + ($7))|0;
    $15 = $14 << 1;
    $16 = (213564 + ($15<<2)|0);
    $17 = ((($16)) + 8|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = ((($18)) + 8|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = ($16|0)==($20|0);
    if ($21) {
     $22 = 1 << $14;
     $23 = $22 ^ -1;
     $24 = $8 & $23;
     HEAP32[53381] = $24;
    } else {
     $25 = ((($20)) + 12|0);
     HEAP32[$25>>2] = $16;
     HEAP32[$17>>2] = $20;
    }
    $26 = $14 << 3;
    $27 = $26 | 3;
    $28 = ((($18)) + 4|0);
    HEAP32[$28>>2] = $27;
    $29 = (($18) + ($26)|0);
    $30 = ((($29)) + 4|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = $31 | 1;
    HEAP32[$30>>2] = $32;
    $$0 = $19;
    STACKTOP = sp;return ($$0|0);
   }
   $33 = HEAP32[(213532)>>2]|0;
   $34 = ($6>>>0)>($33>>>0);
   if ($34) {
    $35 = ($9|0)==(0);
    if (!($35)) {
     $36 = $9 << $7;
     $37 = 2 << $7;
     $38 = (0 - ($37))|0;
     $39 = $37 | $38;
     $40 = $36 & $39;
     $41 = (0 - ($40))|0;
     $42 = $40 & $41;
     $43 = (($42) + -1)|0;
     $44 = $43 >>> 12;
     $45 = $44 & 16;
     $46 = $43 >>> $45;
     $47 = $46 >>> 5;
     $48 = $47 & 8;
     $49 = $48 | $45;
     $50 = $46 >>> $48;
     $51 = $50 >>> 2;
     $52 = $51 & 4;
     $53 = $49 | $52;
     $54 = $50 >>> $52;
     $55 = $54 >>> 1;
     $56 = $55 & 2;
     $57 = $53 | $56;
     $58 = $54 >>> $56;
     $59 = $58 >>> 1;
     $60 = $59 & 1;
     $61 = $57 | $60;
     $62 = $58 >>> $60;
     $63 = (($61) + ($62))|0;
     $64 = $63 << 1;
     $65 = (213564 + ($64<<2)|0);
     $66 = ((($65)) + 8|0);
     $67 = HEAP32[$66>>2]|0;
     $68 = ((($67)) + 8|0);
     $69 = HEAP32[$68>>2]|0;
     $70 = ($65|0)==($69|0);
     if ($70) {
      $71 = 1 << $63;
      $72 = $71 ^ -1;
      $73 = $8 & $72;
      HEAP32[53381] = $73;
      $90 = $73;
     } else {
      $74 = ((($69)) + 12|0);
      HEAP32[$74>>2] = $65;
      HEAP32[$66>>2] = $69;
      $90 = $8;
     }
     $75 = $63 << 3;
     $76 = (($75) - ($6))|0;
     $77 = $6 | 3;
     $78 = ((($67)) + 4|0);
     HEAP32[$78>>2] = $77;
     $79 = (($67) + ($6)|0);
     $80 = $76 | 1;
     $81 = ((($79)) + 4|0);
     HEAP32[$81>>2] = $80;
     $82 = (($79) + ($76)|0);
     HEAP32[$82>>2] = $76;
     $83 = ($33|0)==(0);
     if (!($83)) {
      $84 = HEAP32[(213544)>>2]|0;
      $85 = $33 >>> 3;
      $86 = $85 << 1;
      $87 = (213564 + ($86<<2)|0);
      $88 = 1 << $85;
      $89 = $90 & $88;
      $91 = ($89|0)==(0);
      if ($91) {
       $92 = $90 | $88;
       HEAP32[53381] = $92;
       $$pre = ((($87)) + 8|0);
       $$0194 = $87;$$pre$phiZ2D = $$pre;
      } else {
       $93 = ((($87)) + 8|0);
       $94 = HEAP32[$93>>2]|0;
       $$0194 = $94;$$pre$phiZ2D = $93;
      }
      HEAP32[$$pre$phiZ2D>>2] = $84;
      $95 = ((($$0194)) + 12|0);
      HEAP32[$95>>2] = $84;
      $96 = ((($84)) + 8|0);
      HEAP32[$96>>2] = $$0194;
      $97 = ((($84)) + 12|0);
      HEAP32[$97>>2] = $87;
     }
     HEAP32[(213532)>>2] = $76;
     HEAP32[(213544)>>2] = $79;
     $$0 = $68;
     STACKTOP = sp;return ($$0|0);
    }
    $98 = HEAP32[(213528)>>2]|0;
    $99 = ($98|0)==(0);
    if ($99) {
     $$0192 = $6;
    } else {
     $100 = (0 - ($98))|0;
     $101 = $98 & $100;
     $102 = (($101) + -1)|0;
     $103 = $102 >>> 12;
     $104 = $103 & 16;
     $105 = $102 >>> $104;
     $106 = $105 >>> 5;
     $107 = $106 & 8;
     $108 = $107 | $104;
     $109 = $105 >>> $107;
     $110 = $109 >>> 2;
     $111 = $110 & 4;
     $112 = $108 | $111;
     $113 = $109 >>> $111;
     $114 = $113 >>> 1;
     $115 = $114 & 2;
     $116 = $112 | $115;
     $117 = $113 >>> $115;
     $118 = $117 >>> 1;
     $119 = $118 & 1;
     $120 = $116 | $119;
     $121 = $117 >>> $119;
     $122 = (($120) + ($121))|0;
     $123 = (213828 + ($122<<2)|0);
     $124 = HEAP32[$123>>2]|0;
     $125 = ((($124)) + 4|0);
     $126 = HEAP32[$125>>2]|0;
     $127 = $126 & -8;
     $128 = (($127) - ($6))|0;
     $129 = ((($124)) + 16|0);
     $130 = HEAP32[$129>>2]|0;
     $not$3$i = ($130|0)==(0|0);
     $$sink14$i = $not$3$i&1;
     $131 = (((($124)) + 16|0) + ($$sink14$i<<2)|0);
     $132 = HEAP32[$131>>2]|0;
     $133 = ($132|0)==(0|0);
     if ($133) {
      $$0172$lcssa$i = $124;$$0173$lcssa$i = $128;
     } else {
      $$01726$i = $124;$$01735$i = $128;$135 = $132;
      while(1) {
       $134 = ((($135)) + 4|0);
       $136 = HEAP32[$134>>2]|0;
       $137 = $136 & -8;
       $138 = (($137) - ($6))|0;
       $139 = ($138>>>0)<($$01735$i>>>0);
       $$$0173$i = $139 ? $138 : $$01735$i;
       $$$0172$i = $139 ? $135 : $$01726$i;
       $140 = ((($135)) + 16|0);
       $141 = HEAP32[$140>>2]|0;
       $not$$i = ($141|0)==(0|0);
       $$sink1$i = $not$$i&1;
       $142 = (((($135)) + 16|0) + ($$sink1$i<<2)|0);
       $143 = HEAP32[$142>>2]|0;
       $144 = ($143|0)==(0|0);
       if ($144) {
        $$0172$lcssa$i = $$$0172$i;$$0173$lcssa$i = $$$0173$i;
        break;
       } else {
        $$01726$i = $$$0172$i;$$01735$i = $$$0173$i;$135 = $143;
       }
      }
     }
     $145 = (($$0172$lcssa$i) + ($6)|0);
     $146 = ($$0172$lcssa$i>>>0)<($145>>>0);
     if ($146) {
      $147 = ((($$0172$lcssa$i)) + 24|0);
      $148 = HEAP32[$147>>2]|0;
      $149 = ((($$0172$lcssa$i)) + 12|0);
      $150 = HEAP32[$149>>2]|0;
      $151 = ($150|0)==($$0172$lcssa$i|0);
      do {
       if ($151) {
        $156 = ((($$0172$lcssa$i)) + 20|0);
        $157 = HEAP32[$156>>2]|0;
        $158 = ($157|0)==(0|0);
        if ($158) {
         $159 = ((($$0172$lcssa$i)) + 16|0);
         $160 = HEAP32[$159>>2]|0;
         $161 = ($160|0)==(0|0);
         if ($161) {
          $$3$i = 0;
          break;
         } else {
          $$1176$i = $160;$$1178$i = $159;
         }
        } else {
         $$1176$i = $157;$$1178$i = $156;
        }
        while(1) {
         $162 = ((($$1176$i)) + 20|0);
         $163 = HEAP32[$162>>2]|0;
         $164 = ($163|0)==(0|0);
         if (!($164)) {
          $$1176$i = $163;$$1178$i = $162;
          continue;
         }
         $165 = ((($$1176$i)) + 16|0);
         $166 = HEAP32[$165>>2]|0;
         $167 = ($166|0)==(0|0);
         if ($167) {
          break;
         } else {
          $$1176$i = $166;$$1178$i = $165;
         }
        }
        HEAP32[$$1178$i>>2] = 0;
        $$3$i = $$1176$i;
       } else {
        $152 = ((($$0172$lcssa$i)) + 8|0);
        $153 = HEAP32[$152>>2]|0;
        $154 = ((($153)) + 12|0);
        HEAP32[$154>>2] = $150;
        $155 = ((($150)) + 8|0);
        HEAP32[$155>>2] = $153;
        $$3$i = $150;
       }
      } while(0);
      $168 = ($148|0)==(0|0);
      do {
       if (!($168)) {
        $169 = ((($$0172$lcssa$i)) + 28|0);
        $170 = HEAP32[$169>>2]|0;
        $171 = (213828 + ($170<<2)|0);
        $172 = HEAP32[$171>>2]|0;
        $173 = ($$0172$lcssa$i|0)==($172|0);
        if ($173) {
         HEAP32[$171>>2] = $$3$i;
         $cond$i = ($$3$i|0)==(0|0);
         if ($cond$i) {
          $174 = 1 << $170;
          $175 = $174 ^ -1;
          $176 = $98 & $175;
          HEAP32[(213528)>>2] = $176;
          break;
         }
        } else {
         $177 = ((($148)) + 16|0);
         $178 = HEAP32[$177>>2]|0;
         $not$1$i = ($178|0)!=($$0172$lcssa$i|0);
         $$sink2$i = $not$1$i&1;
         $179 = (((($148)) + 16|0) + ($$sink2$i<<2)|0);
         HEAP32[$179>>2] = $$3$i;
         $180 = ($$3$i|0)==(0|0);
         if ($180) {
          break;
         }
        }
        $181 = ((($$3$i)) + 24|0);
        HEAP32[$181>>2] = $148;
        $182 = ((($$0172$lcssa$i)) + 16|0);
        $183 = HEAP32[$182>>2]|0;
        $184 = ($183|0)==(0|0);
        if (!($184)) {
         $185 = ((($$3$i)) + 16|0);
         HEAP32[$185>>2] = $183;
         $186 = ((($183)) + 24|0);
         HEAP32[$186>>2] = $$3$i;
        }
        $187 = ((($$0172$lcssa$i)) + 20|0);
        $188 = HEAP32[$187>>2]|0;
        $189 = ($188|0)==(0|0);
        if (!($189)) {
         $190 = ((($$3$i)) + 20|0);
         HEAP32[$190>>2] = $188;
         $191 = ((($188)) + 24|0);
         HEAP32[$191>>2] = $$3$i;
        }
       }
      } while(0);
      $192 = ($$0173$lcssa$i>>>0)<(16);
      if ($192) {
       $193 = (($$0173$lcssa$i) + ($6))|0;
       $194 = $193 | 3;
       $195 = ((($$0172$lcssa$i)) + 4|0);
       HEAP32[$195>>2] = $194;
       $196 = (($$0172$lcssa$i) + ($193)|0);
       $197 = ((($196)) + 4|0);
       $198 = HEAP32[$197>>2]|0;
       $199 = $198 | 1;
       HEAP32[$197>>2] = $199;
      } else {
       $200 = $6 | 3;
       $201 = ((($$0172$lcssa$i)) + 4|0);
       HEAP32[$201>>2] = $200;
       $202 = $$0173$lcssa$i | 1;
       $203 = ((($145)) + 4|0);
       HEAP32[$203>>2] = $202;
       $204 = (($145) + ($$0173$lcssa$i)|0);
       HEAP32[$204>>2] = $$0173$lcssa$i;
       $205 = ($33|0)==(0);
       if (!($205)) {
        $206 = HEAP32[(213544)>>2]|0;
        $207 = $33 >>> 3;
        $208 = $207 << 1;
        $209 = (213564 + ($208<<2)|0);
        $210 = 1 << $207;
        $211 = $8 & $210;
        $212 = ($211|0)==(0);
        if ($212) {
         $213 = $8 | $210;
         HEAP32[53381] = $213;
         $$pre$i = ((($209)) + 8|0);
         $$0$i = $209;$$pre$phi$iZ2D = $$pre$i;
        } else {
         $214 = ((($209)) + 8|0);
         $215 = HEAP32[$214>>2]|0;
         $$0$i = $215;$$pre$phi$iZ2D = $214;
        }
        HEAP32[$$pre$phi$iZ2D>>2] = $206;
        $216 = ((($$0$i)) + 12|0);
        HEAP32[$216>>2] = $206;
        $217 = ((($206)) + 8|0);
        HEAP32[$217>>2] = $$0$i;
        $218 = ((($206)) + 12|0);
        HEAP32[$218>>2] = $209;
       }
       HEAP32[(213532)>>2] = $$0173$lcssa$i;
       HEAP32[(213544)>>2] = $145;
      }
      $219 = ((($$0172$lcssa$i)) + 8|0);
      $$0 = $219;
      STACKTOP = sp;return ($$0|0);
     } else {
      $$0192 = $6;
     }
    }
   } else {
    $$0192 = $6;
   }
  } else {
   $220 = ($0>>>0)>(4294967231);
   if ($220) {
    $$0192 = -1;
   } else {
    $221 = (($0) + 11)|0;
    $222 = $221 & -8;
    $223 = HEAP32[(213528)>>2]|0;
    $224 = ($223|0)==(0);
    if ($224) {
     $$0192 = $222;
    } else {
     $225 = (0 - ($222))|0;
     $226 = $221 >>> 8;
     $227 = ($226|0)==(0);
     if ($227) {
      $$0336$i = 0;
     } else {
      $228 = ($222>>>0)>(16777215);
      if ($228) {
       $$0336$i = 31;
      } else {
       $229 = (($226) + 1048320)|0;
       $230 = $229 >>> 16;
       $231 = $230 & 8;
       $232 = $226 << $231;
       $233 = (($232) + 520192)|0;
       $234 = $233 >>> 16;
       $235 = $234 & 4;
       $236 = $235 | $231;
       $237 = $232 << $235;
       $238 = (($237) + 245760)|0;
       $239 = $238 >>> 16;
       $240 = $239 & 2;
       $241 = $236 | $240;
       $242 = (14 - ($241))|0;
       $243 = $237 << $240;
       $244 = $243 >>> 15;
       $245 = (($242) + ($244))|0;
       $246 = $245 << 1;
       $247 = (($245) + 7)|0;
       $248 = $222 >>> $247;
       $249 = $248 & 1;
       $250 = $249 | $246;
       $$0336$i = $250;
      }
     }
     $251 = (213828 + ($$0336$i<<2)|0);
     $252 = HEAP32[$251>>2]|0;
     $253 = ($252|0)==(0|0);
     L74: do {
      if ($253) {
       $$2333$i = 0;$$3$i200 = 0;$$3328$i = $225;
       label = 57;
      } else {
       $254 = ($$0336$i|0)==(31);
       $255 = $$0336$i >>> 1;
       $256 = (25 - ($255))|0;
       $257 = $254 ? 0 : $256;
       $258 = $222 << $257;
       $$0320$i = 0;$$0325$i = $225;$$0331$i = $252;$$0337$i = $258;$$0340$i = 0;
       while(1) {
        $259 = ((($$0331$i)) + 4|0);
        $260 = HEAP32[$259>>2]|0;
        $261 = $260 & -8;
        $262 = (($261) - ($222))|0;
        $263 = ($262>>>0)<($$0325$i>>>0);
        if ($263) {
         $264 = ($262|0)==(0);
         if ($264) {
          $$411$i = $$0331$i;$$432910$i = 0;$$43359$i = $$0331$i;
          label = 61;
          break L74;
         } else {
          $$1321$i = $$0331$i;$$1326$i = $262;
         }
        } else {
         $$1321$i = $$0320$i;$$1326$i = $$0325$i;
        }
        $265 = ((($$0331$i)) + 20|0);
        $266 = HEAP32[$265>>2]|0;
        $267 = $$0337$i >>> 31;
        $268 = (((($$0331$i)) + 16|0) + ($267<<2)|0);
        $269 = HEAP32[$268>>2]|0;
        $270 = ($266|0)==(0|0);
        $271 = ($266|0)==($269|0);
        $or$cond2$i199 = $270 | $271;
        $$1341$i = $or$cond2$i199 ? $$0340$i : $266;
        $272 = ($269|0)==(0|0);
        $not$5$i = $272 ^ 1;
        $273 = $not$5$i&1;
        $$0337$$i = $$0337$i << $273;
        if ($272) {
         $$2333$i = $$1341$i;$$3$i200 = $$1321$i;$$3328$i = $$1326$i;
         label = 57;
         break;
        } else {
         $$0320$i = $$1321$i;$$0325$i = $$1326$i;$$0331$i = $269;$$0337$i = $$0337$$i;$$0340$i = $$1341$i;
        }
       }
      }
     } while(0);
     if ((label|0) == 57) {
      $274 = ($$2333$i|0)==(0|0);
      $275 = ($$3$i200|0)==(0|0);
      $or$cond$i201 = $274 & $275;
      if ($or$cond$i201) {
       $276 = 2 << $$0336$i;
       $277 = (0 - ($276))|0;
       $278 = $276 | $277;
       $279 = $223 & $278;
       $280 = ($279|0)==(0);
       if ($280) {
        $$0192 = $222;
        break;
       }
       $281 = (0 - ($279))|0;
       $282 = $279 & $281;
       $283 = (($282) + -1)|0;
       $284 = $283 >>> 12;
       $285 = $284 & 16;
       $286 = $283 >>> $285;
       $287 = $286 >>> 5;
       $288 = $287 & 8;
       $289 = $288 | $285;
       $290 = $286 >>> $288;
       $291 = $290 >>> 2;
       $292 = $291 & 4;
       $293 = $289 | $292;
       $294 = $290 >>> $292;
       $295 = $294 >>> 1;
       $296 = $295 & 2;
       $297 = $293 | $296;
       $298 = $294 >>> $296;
       $299 = $298 >>> 1;
       $300 = $299 & 1;
       $301 = $297 | $300;
       $302 = $298 >>> $300;
       $303 = (($301) + ($302))|0;
       $304 = (213828 + ($303<<2)|0);
       $305 = HEAP32[$304>>2]|0;
       $$4$ph$i = 0;$$4335$ph$i = $305;
      } else {
       $$4$ph$i = $$3$i200;$$4335$ph$i = $$2333$i;
      }
      $306 = ($$4335$ph$i|0)==(0|0);
      if ($306) {
       $$4$lcssa$i = $$4$ph$i;$$4329$lcssa$i = $$3328$i;
      } else {
       $$411$i = $$4$ph$i;$$432910$i = $$3328$i;$$43359$i = $$4335$ph$i;
       label = 61;
      }
     }
     if ((label|0) == 61) {
      while(1) {
       label = 0;
       $307 = ((($$43359$i)) + 4|0);
       $308 = HEAP32[$307>>2]|0;
       $309 = $308 & -8;
       $310 = (($309) - ($222))|0;
       $311 = ($310>>>0)<($$432910$i>>>0);
       $$$4329$i = $311 ? $310 : $$432910$i;
       $$4335$$4$i = $311 ? $$43359$i : $$411$i;
       $312 = ((($$43359$i)) + 16|0);
       $313 = HEAP32[$312>>2]|0;
       $not$1$i203 = ($313|0)==(0|0);
       $$sink2$i204 = $not$1$i203&1;
       $314 = (((($$43359$i)) + 16|0) + ($$sink2$i204<<2)|0);
       $315 = HEAP32[$314>>2]|0;
       $316 = ($315|0)==(0|0);
       if ($316) {
        $$4$lcssa$i = $$4335$$4$i;$$4329$lcssa$i = $$$4329$i;
        break;
       } else {
        $$411$i = $$4335$$4$i;$$432910$i = $$$4329$i;$$43359$i = $315;
        label = 61;
       }
      }
     }
     $317 = ($$4$lcssa$i|0)==(0|0);
     if ($317) {
      $$0192 = $222;
     } else {
      $318 = HEAP32[(213532)>>2]|0;
      $319 = (($318) - ($222))|0;
      $320 = ($$4329$lcssa$i>>>0)<($319>>>0);
      if ($320) {
       $321 = (($$4$lcssa$i) + ($222)|0);
       $322 = ($$4$lcssa$i>>>0)<($321>>>0);
       if (!($322)) {
        $$0 = 0;
        STACKTOP = sp;return ($$0|0);
       }
       $323 = ((($$4$lcssa$i)) + 24|0);
       $324 = HEAP32[$323>>2]|0;
       $325 = ((($$4$lcssa$i)) + 12|0);
       $326 = HEAP32[$325>>2]|0;
       $327 = ($326|0)==($$4$lcssa$i|0);
       do {
        if ($327) {
         $332 = ((($$4$lcssa$i)) + 20|0);
         $333 = HEAP32[$332>>2]|0;
         $334 = ($333|0)==(0|0);
         if ($334) {
          $335 = ((($$4$lcssa$i)) + 16|0);
          $336 = HEAP32[$335>>2]|0;
          $337 = ($336|0)==(0|0);
          if ($337) {
           $$3349$i = 0;
           break;
          } else {
           $$1347$i = $336;$$1351$i = $335;
          }
         } else {
          $$1347$i = $333;$$1351$i = $332;
         }
         while(1) {
          $338 = ((($$1347$i)) + 20|0);
          $339 = HEAP32[$338>>2]|0;
          $340 = ($339|0)==(0|0);
          if (!($340)) {
           $$1347$i = $339;$$1351$i = $338;
           continue;
          }
          $341 = ((($$1347$i)) + 16|0);
          $342 = HEAP32[$341>>2]|0;
          $343 = ($342|0)==(0|0);
          if ($343) {
           break;
          } else {
           $$1347$i = $342;$$1351$i = $341;
          }
         }
         HEAP32[$$1351$i>>2] = 0;
         $$3349$i = $$1347$i;
        } else {
         $328 = ((($$4$lcssa$i)) + 8|0);
         $329 = HEAP32[$328>>2]|0;
         $330 = ((($329)) + 12|0);
         HEAP32[$330>>2] = $326;
         $331 = ((($326)) + 8|0);
         HEAP32[$331>>2] = $329;
         $$3349$i = $326;
        }
       } while(0);
       $344 = ($324|0)==(0|0);
       do {
        if ($344) {
         $426 = $223;
        } else {
         $345 = ((($$4$lcssa$i)) + 28|0);
         $346 = HEAP32[$345>>2]|0;
         $347 = (213828 + ($346<<2)|0);
         $348 = HEAP32[$347>>2]|0;
         $349 = ($$4$lcssa$i|0)==($348|0);
         if ($349) {
          HEAP32[$347>>2] = $$3349$i;
          $cond$i208 = ($$3349$i|0)==(0|0);
          if ($cond$i208) {
           $350 = 1 << $346;
           $351 = $350 ^ -1;
           $352 = $223 & $351;
           HEAP32[(213528)>>2] = $352;
           $426 = $352;
           break;
          }
         } else {
          $353 = ((($324)) + 16|0);
          $354 = HEAP32[$353>>2]|0;
          $not$$i209 = ($354|0)!=($$4$lcssa$i|0);
          $$sink3$i = $not$$i209&1;
          $355 = (((($324)) + 16|0) + ($$sink3$i<<2)|0);
          HEAP32[$355>>2] = $$3349$i;
          $356 = ($$3349$i|0)==(0|0);
          if ($356) {
           $426 = $223;
           break;
          }
         }
         $357 = ((($$3349$i)) + 24|0);
         HEAP32[$357>>2] = $324;
         $358 = ((($$4$lcssa$i)) + 16|0);
         $359 = HEAP32[$358>>2]|0;
         $360 = ($359|0)==(0|0);
         if (!($360)) {
          $361 = ((($$3349$i)) + 16|0);
          HEAP32[$361>>2] = $359;
          $362 = ((($359)) + 24|0);
          HEAP32[$362>>2] = $$3349$i;
         }
         $363 = ((($$4$lcssa$i)) + 20|0);
         $364 = HEAP32[$363>>2]|0;
         $365 = ($364|0)==(0|0);
         if ($365) {
          $426 = $223;
         } else {
          $366 = ((($$3349$i)) + 20|0);
          HEAP32[$366>>2] = $364;
          $367 = ((($364)) + 24|0);
          HEAP32[$367>>2] = $$3349$i;
          $426 = $223;
         }
        }
       } while(0);
       $368 = ($$4329$lcssa$i>>>0)<(16);
       do {
        if ($368) {
         $369 = (($$4329$lcssa$i) + ($222))|0;
         $370 = $369 | 3;
         $371 = ((($$4$lcssa$i)) + 4|0);
         HEAP32[$371>>2] = $370;
         $372 = (($$4$lcssa$i) + ($369)|0);
         $373 = ((($372)) + 4|0);
         $374 = HEAP32[$373>>2]|0;
         $375 = $374 | 1;
         HEAP32[$373>>2] = $375;
        } else {
         $376 = $222 | 3;
         $377 = ((($$4$lcssa$i)) + 4|0);
         HEAP32[$377>>2] = $376;
         $378 = $$4329$lcssa$i | 1;
         $379 = ((($321)) + 4|0);
         HEAP32[$379>>2] = $378;
         $380 = (($321) + ($$4329$lcssa$i)|0);
         HEAP32[$380>>2] = $$4329$lcssa$i;
         $381 = $$4329$lcssa$i >>> 3;
         $382 = ($$4329$lcssa$i>>>0)<(256);
         if ($382) {
          $383 = $381 << 1;
          $384 = (213564 + ($383<<2)|0);
          $385 = HEAP32[53381]|0;
          $386 = 1 << $381;
          $387 = $385 & $386;
          $388 = ($387|0)==(0);
          if ($388) {
           $389 = $385 | $386;
           HEAP32[53381] = $389;
           $$pre$i210 = ((($384)) + 8|0);
           $$0345$i = $384;$$pre$phi$i211Z2D = $$pre$i210;
          } else {
           $390 = ((($384)) + 8|0);
           $391 = HEAP32[$390>>2]|0;
           $$0345$i = $391;$$pre$phi$i211Z2D = $390;
          }
          HEAP32[$$pre$phi$i211Z2D>>2] = $321;
          $392 = ((($$0345$i)) + 12|0);
          HEAP32[$392>>2] = $321;
          $393 = ((($321)) + 8|0);
          HEAP32[$393>>2] = $$0345$i;
          $394 = ((($321)) + 12|0);
          HEAP32[$394>>2] = $384;
          break;
         }
         $395 = $$4329$lcssa$i >>> 8;
         $396 = ($395|0)==(0);
         if ($396) {
          $$0339$i = 0;
         } else {
          $397 = ($$4329$lcssa$i>>>0)>(16777215);
          if ($397) {
           $$0339$i = 31;
          } else {
           $398 = (($395) + 1048320)|0;
           $399 = $398 >>> 16;
           $400 = $399 & 8;
           $401 = $395 << $400;
           $402 = (($401) + 520192)|0;
           $403 = $402 >>> 16;
           $404 = $403 & 4;
           $405 = $404 | $400;
           $406 = $401 << $404;
           $407 = (($406) + 245760)|0;
           $408 = $407 >>> 16;
           $409 = $408 & 2;
           $410 = $405 | $409;
           $411 = (14 - ($410))|0;
           $412 = $406 << $409;
           $413 = $412 >>> 15;
           $414 = (($411) + ($413))|0;
           $415 = $414 << 1;
           $416 = (($414) + 7)|0;
           $417 = $$4329$lcssa$i >>> $416;
           $418 = $417 & 1;
           $419 = $418 | $415;
           $$0339$i = $419;
          }
         }
         $420 = (213828 + ($$0339$i<<2)|0);
         $421 = ((($321)) + 28|0);
         HEAP32[$421>>2] = $$0339$i;
         $422 = ((($321)) + 16|0);
         $423 = ((($422)) + 4|0);
         HEAP32[$423>>2] = 0;
         HEAP32[$422>>2] = 0;
         $424 = 1 << $$0339$i;
         $425 = $426 & $424;
         $427 = ($425|0)==(0);
         if ($427) {
          $428 = $426 | $424;
          HEAP32[(213528)>>2] = $428;
          HEAP32[$420>>2] = $321;
          $429 = ((($321)) + 24|0);
          HEAP32[$429>>2] = $420;
          $430 = ((($321)) + 12|0);
          HEAP32[$430>>2] = $321;
          $431 = ((($321)) + 8|0);
          HEAP32[$431>>2] = $321;
          break;
         }
         $432 = HEAP32[$420>>2]|0;
         $433 = ($$0339$i|0)==(31);
         $434 = $$0339$i >>> 1;
         $435 = (25 - ($434))|0;
         $436 = $433 ? 0 : $435;
         $437 = $$4329$lcssa$i << $436;
         $$0322$i = $437;$$0323$i = $432;
         while(1) {
          $438 = ((($$0323$i)) + 4|0);
          $439 = HEAP32[$438>>2]|0;
          $440 = $439 & -8;
          $441 = ($440|0)==($$4329$lcssa$i|0);
          if ($441) {
           label = 97;
           break;
          }
          $442 = $$0322$i >>> 31;
          $443 = (((($$0323$i)) + 16|0) + ($442<<2)|0);
          $444 = $$0322$i << 1;
          $445 = HEAP32[$443>>2]|0;
          $446 = ($445|0)==(0|0);
          if ($446) {
           label = 96;
           break;
          } else {
           $$0322$i = $444;$$0323$i = $445;
          }
         }
         if ((label|0) == 96) {
          HEAP32[$443>>2] = $321;
          $447 = ((($321)) + 24|0);
          HEAP32[$447>>2] = $$0323$i;
          $448 = ((($321)) + 12|0);
          HEAP32[$448>>2] = $321;
          $449 = ((($321)) + 8|0);
          HEAP32[$449>>2] = $321;
          break;
         }
         else if ((label|0) == 97) {
          $450 = ((($$0323$i)) + 8|0);
          $451 = HEAP32[$450>>2]|0;
          $452 = ((($451)) + 12|0);
          HEAP32[$452>>2] = $321;
          HEAP32[$450>>2] = $321;
          $453 = ((($321)) + 8|0);
          HEAP32[$453>>2] = $451;
          $454 = ((($321)) + 12|0);
          HEAP32[$454>>2] = $$0323$i;
          $455 = ((($321)) + 24|0);
          HEAP32[$455>>2] = 0;
          break;
         }
        }
       } while(0);
       $456 = ((($$4$lcssa$i)) + 8|0);
       $$0 = $456;
       STACKTOP = sp;return ($$0|0);
      } else {
       $$0192 = $222;
      }
     }
    }
   }
  }
 } while(0);
 $457 = HEAP32[(213532)>>2]|0;
 $458 = ($457>>>0)<($$0192>>>0);
 if (!($458)) {
  $459 = (($457) - ($$0192))|0;
  $460 = HEAP32[(213544)>>2]|0;
  $461 = ($459>>>0)>(15);
  if ($461) {
   $462 = (($460) + ($$0192)|0);
   HEAP32[(213544)>>2] = $462;
   HEAP32[(213532)>>2] = $459;
   $463 = $459 | 1;
   $464 = ((($462)) + 4|0);
   HEAP32[$464>>2] = $463;
   $465 = (($462) + ($459)|0);
   HEAP32[$465>>2] = $459;
   $466 = $$0192 | 3;
   $467 = ((($460)) + 4|0);
   HEAP32[$467>>2] = $466;
  } else {
   HEAP32[(213532)>>2] = 0;
   HEAP32[(213544)>>2] = 0;
   $468 = $457 | 3;
   $469 = ((($460)) + 4|0);
   HEAP32[$469>>2] = $468;
   $470 = (($460) + ($457)|0);
   $471 = ((($470)) + 4|0);
   $472 = HEAP32[$471>>2]|0;
   $473 = $472 | 1;
   HEAP32[$471>>2] = $473;
  }
  $474 = ((($460)) + 8|0);
  $$0 = $474;
  STACKTOP = sp;return ($$0|0);
 }
 $475 = HEAP32[(213536)>>2]|0;
 $476 = ($475>>>0)>($$0192>>>0);
 if ($476) {
  $477 = (($475) - ($$0192))|0;
  HEAP32[(213536)>>2] = $477;
  $478 = HEAP32[(213548)>>2]|0;
  $479 = (($478) + ($$0192)|0);
  HEAP32[(213548)>>2] = $479;
  $480 = $477 | 1;
  $481 = ((($479)) + 4|0);
  HEAP32[$481>>2] = $480;
  $482 = $$0192 | 3;
  $483 = ((($478)) + 4|0);
  HEAP32[$483>>2] = $482;
  $484 = ((($478)) + 8|0);
  $$0 = $484;
  STACKTOP = sp;return ($$0|0);
 }
 $485 = HEAP32[53499]|0;
 $486 = ($485|0)==(0);
 if ($486) {
  HEAP32[(214004)>>2] = 4096;
  HEAP32[(214000)>>2] = 4096;
  HEAP32[(214008)>>2] = -1;
  HEAP32[(214012)>>2] = -1;
  HEAP32[(214016)>>2] = 0;
  HEAP32[(213968)>>2] = 0;
  $487 = $1;
  $488 = $487 & -16;
  $489 = $488 ^ 1431655768;
  HEAP32[$1>>2] = $489;
  HEAP32[53499] = $489;
  $493 = 4096;
 } else {
  $$pre$i195 = HEAP32[(214004)>>2]|0;
  $493 = $$pre$i195;
 }
 $490 = (($$0192) + 48)|0;
 $491 = (($$0192) + 47)|0;
 $492 = (($493) + ($491))|0;
 $494 = (0 - ($493))|0;
 $495 = $492 & $494;
 $496 = ($495>>>0)>($$0192>>>0);
 if (!($496)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $497 = HEAP32[(213964)>>2]|0;
 $498 = ($497|0)==(0);
 if (!($498)) {
  $499 = HEAP32[(213956)>>2]|0;
  $500 = (($499) + ($495))|0;
  $501 = ($500>>>0)<=($499>>>0);
  $502 = ($500>>>0)>($497>>>0);
  $or$cond1$i = $501 | $502;
  if ($or$cond1$i) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $503 = HEAP32[(213968)>>2]|0;
 $504 = $503 & 4;
 $505 = ($504|0)==(0);
 L167: do {
  if ($505) {
   $506 = HEAP32[(213548)>>2]|0;
   $507 = ($506|0)==(0|0);
   L169: do {
    if ($507) {
     label = 118;
    } else {
     $$0$i20$i = (213972);
     while(1) {
      $508 = HEAP32[$$0$i20$i>>2]|0;
      $509 = ($508>>>0)>($506>>>0);
      if (!($509)) {
       $510 = ((($$0$i20$i)) + 4|0);
       $511 = HEAP32[$510>>2]|0;
       $512 = (($508) + ($511)|0);
       $513 = ($512>>>0)>($506>>>0);
       if ($513) {
        break;
       }
      }
      $514 = ((($$0$i20$i)) + 8|0);
      $515 = HEAP32[$514>>2]|0;
      $516 = ($515|0)==(0|0);
      if ($516) {
       label = 118;
       break L169;
      } else {
       $$0$i20$i = $515;
      }
     }
     $539 = (($492) - ($475))|0;
     $540 = $539 & $494;
     $541 = ($540>>>0)<(2147483647);
     if ($541) {
      $542 = (_sbrk(($540|0))|0);
      $543 = HEAP32[$$0$i20$i>>2]|0;
      $544 = HEAP32[$510>>2]|0;
      $545 = (($543) + ($544)|0);
      $546 = ($542|0)==($545|0);
      if ($546) {
       $547 = ($542|0)==((-1)|0);
       if ($547) {
        $$2234243136$i = $540;
       } else {
        $$723947$i = $540;$$748$i = $542;
        label = 135;
        break L167;
       }
      } else {
       $$2247$ph$i = $542;$$2253$ph$i = $540;
       label = 126;
      }
     } else {
      $$2234243136$i = 0;
     }
    }
   } while(0);
   do {
    if ((label|0) == 118) {
     $517 = (_sbrk(0)|0);
     $518 = ($517|0)==((-1)|0);
     if ($518) {
      $$2234243136$i = 0;
     } else {
      $519 = $517;
      $520 = HEAP32[(214000)>>2]|0;
      $521 = (($520) + -1)|0;
      $522 = $521 & $519;
      $523 = ($522|0)==(0);
      $524 = (($521) + ($519))|0;
      $525 = (0 - ($520))|0;
      $526 = $524 & $525;
      $527 = (($526) - ($519))|0;
      $528 = $523 ? 0 : $527;
      $$$i = (($528) + ($495))|0;
      $529 = HEAP32[(213956)>>2]|0;
      $530 = (($$$i) + ($529))|0;
      $531 = ($$$i>>>0)>($$0192>>>0);
      $532 = ($$$i>>>0)<(2147483647);
      $or$cond$i = $531 & $532;
      if ($or$cond$i) {
       $533 = HEAP32[(213964)>>2]|0;
       $534 = ($533|0)==(0);
       if (!($534)) {
        $535 = ($530>>>0)<=($529>>>0);
        $536 = ($530>>>0)>($533>>>0);
        $or$cond2$i = $535 | $536;
        if ($or$cond2$i) {
         $$2234243136$i = 0;
         break;
        }
       }
       $537 = (_sbrk(($$$i|0))|0);
       $538 = ($537|0)==($517|0);
       if ($538) {
        $$723947$i = $$$i;$$748$i = $517;
        label = 135;
        break L167;
       } else {
        $$2247$ph$i = $537;$$2253$ph$i = $$$i;
        label = 126;
       }
      } else {
       $$2234243136$i = 0;
      }
     }
    }
   } while(0);
   do {
    if ((label|0) == 126) {
     $548 = (0 - ($$2253$ph$i))|0;
     $549 = ($$2247$ph$i|0)!=((-1)|0);
     $550 = ($$2253$ph$i>>>0)<(2147483647);
     $or$cond7$i = $550 & $549;
     $551 = ($490>>>0)>($$2253$ph$i>>>0);
     $or$cond10$i = $551 & $or$cond7$i;
     if (!($or$cond10$i)) {
      $561 = ($$2247$ph$i|0)==((-1)|0);
      if ($561) {
       $$2234243136$i = 0;
       break;
      } else {
       $$723947$i = $$2253$ph$i;$$748$i = $$2247$ph$i;
       label = 135;
       break L167;
      }
     }
     $552 = HEAP32[(214004)>>2]|0;
     $553 = (($491) - ($$2253$ph$i))|0;
     $554 = (($553) + ($552))|0;
     $555 = (0 - ($552))|0;
     $556 = $554 & $555;
     $557 = ($556>>>0)<(2147483647);
     if (!($557)) {
      $$723947$i = $$2253$ph$i;$$748$i = $$2247$ph$i;
      label = 135;
      break L167;
     }
     $558 = (_sbrk(($556|0))|0);
     $559 = ($558|0)==((-1)|0);
     if ($559) {
      (_sbrk(($548|0))|0);
      $$2234243136$i = 0;
      break;
     } else {
      $560 = (($556) + ($$2253$ph$i))|0;
      $$723947$i = $560;$$748$i = $$2247$ph$i;
      label = 135;
      break L167;
     }
    }
   } while(0);
   $562 = HEAP32[(213968)>>2]|0;
   $563 = $562 | 4;
   HEAP32[(213968)>>2] = $563;
   $$4236$i = $$2234243136$i;
   label = 133;
  } else {
   $$4236$i = 0;
   label = 133;
  }
 } while(0);
 if ((label|0) == 133) {
  $564 = ($495>>>0)<(2147483647);
  if ($564) {
   $565 = (_sbrk(($495|0))|0);
   $566 = (_sbrk(0)|0);
   $567 = ($565|0)!=((-1)|0);
   $568 = ($566|0)!=((-1)|0);
   $or$cond5$i = $567 & $568;
   $569 = ($565>>>0)<($566>>>0);
   $or$cond11$i = $569 & $or$cond5$i;
   $570 = $566;
   $571 = $565;
   $572 = (($570) - ($571))|0;
   $573 = (($$0192) + 40)|0;
   $574 = ($572>>>0)>($573>>>0);
   $$$4236$i = $574 ? $572 : $$4236$i;
   $or$cond11$not$i = $or$cond11$i ^ 1;
   $575 = ($565|0)==((-1)|0);
   $not$$i197 = $574 ^ 1;
   $576 = $575 | $not$$i197;
   $or$cond49$i = $576 | $or$cond11$not$i;
   if (!($or$cond49$i)) {
    $$723947$i = $$$4236$i;$$748$i = $565;
    label = 135;
   }
  }
 }
 if ((label|0) == 135) {
  $577 = HEAP32[(213956)>>2]|0;
  $578 = (($577) + ($$723947$i))|0;
  HEAP32[(213956)>>2] = $578;
  $579 = HEAP32[(213960)>>2]|0;
  $580 = ($578>>>0)>($579>>>0);
  if ($580) {
   HEAP32[(213960)>>2] = $578;
  }
  $581 = HEAP32[(213548)>>2]|0;
  $582 = ($581|0)==(0|0);
  do {
   if ($582) {
    $583 = HEAP32[(213540)>>2]|0;
    $584 = ($583|0)==(0|0);
    $585 = ($$748$i>>>0)<($583>>>0);
    $or$cond12$i = $584 | $585;
    if ($or$cond12$i) {
     HEAP32[(213540)>>2] = $$748$i;
    }
    HEAP32[(213972)>>2] = $$748$i;
    HEAP32[(213976)>>2] = $$723947$i;
    HEAP32[(213984)>>2] = 0;
    $586 = HEAP32[53499]|0;
    HEAP32[(213560)>>2] = $586;
    HEAP32[(213556)>>2] = -1;
    $$01$i$i = 0;
    while(1) {
     $587 = $$01$i$i << 1;
     $588 = (213564 + ($587<<2)|0);
     $589 = ((($588)) + 12|0);
     HEAP32[$589>>2] = $588;
     $590 = ((($588)) + 8|0);
     HEAP32[$590>>2] = $588;
     $591 = (($$01$i$i) + 1)|0;
     $exitcond$i$i = ($591|0)==(32);
     if ($exitcond$i$i) {
      break;
     } else {
      $$01$i$i = $591;
     }
    }
    $592 = (($$723947$i) + -40)|0;
    $593 = ((($$748$i)) + 8|0);
    $594 = $593;
    $595 = $594 & 7;
    $596 = ($595|0)==(0);
    $597 = (0 - ($594))|0;
    $598 = $597 & 7;
    $599 = $596 ? 0 : $598;
    $600 = (($$748$i) + ($599)|0);
    $601 = (($592) - ($599))|0;
    HEAP32[(213548)>>2] = $600;
    HEAP32[(213536)>>2] = $601;
    $602 = $601 | 1;
    $603 = ((($600)) + 4|0);
    HEAP32[$603>>2] = $602;
    $604 = (($600) + ($601)|0);
    $605 = ((($604)) + 4|0);
    HEAP32[$605>>2] = 40;
    $606 = HEAP32[(214012)>>2]|0;
    HEAP32[(213552)>>2] = $606;
   } else {
    $$024370$i = (213972);
    while(1) {
     $607 = HEAP32[$$024370$i>>2]|0;
     $608 = ((($$024370$i)) + 4|0);
     $609 = HEAP32[$608>>2]|0;
     $610 = (($607) + ($609)|0);
     $611 = ($$748$i|0)==($610|0);
     if ($611) {
      label = 145;
      break;
     }
     $612 = ((($$024370$i)) + 8|0);
     $613 = HEAP32[$612>>2]|0;
     $614 = ($613|0)==(0|0);
     if ($614) {
      break;
     } else {
      $$024370$i = $613;
     }
    }
    if ((label|0) == 145) {
     $615 = ((($$024370$i)) + 12|0);
     $616 = HEAP32[$615>>2]|0;
     $617 = $616 & 8;
     $618 = ($617|0)==(0);
     if ($618) {
      $619 = ($581>>>0)>=($607>>>0);
      $620 = ($581>>>0)<($$748$i>>>0);
      $or$cond50$i = $620 & $619;
      if ($or$cond50$i) {
       $621 = (($609) + ($$723947$i))|0;
       HEAP32[$608>>2] = $621;
       $622 = HEAP32[(213536)>>2]|0;
       $623 = ((($581)) + 8|0);
       $624 = $623;
       $625 = $624 & 7;
       $626 = ($625|0)==(0);
       $627 = (0 - ($624))|0;
       $628 = $627 & 7;
       $629 = $626 ? 0 : $628;
       $630 = (($581) + ($629)|0);
       $631 = (($$723947$i) - ($629))|0;
       $632 = (($622) + ($631))|0;
       HEAP32[(213548)>>2] = $630;
       HEAP32[(213536)>>2] = $632;
       $633 = $632 | 1;
       $634 = ((($630)) + 4|0);
       HEAP32[$634>>2] = $633;
       $635 = (($630) + ($632)|0);
       $636 = ((($635)) + 4|0);
       HEAP32[$636>>2] = 40;
       $637 = HEAP32[(214012)>>2]|0;
       HEAP32[(213552)>>2] = $637;
       break;
      }
     }
    }
    $638 = HEAP32[(213540)>>2]|0;
    $639 = ($$748$i>>>0)<($638>>>0);
    if ($639) {
     HEAP32[(213540)>>2] = $$748$i;
    }
    $640 = (($$748$i) + ($$723947$i)|0);
    $$124469$i = (213972);
    while(1) {
     $641 = HEAP32[$$124469$i>>2]|0;
     $642 = ($641|0)==($640|0);
     if ($642) {
      label = 153;
      break;
     }
     $643 = ((($$124469$i)) + 8|0);
     $644 = HEAP32[$643>>2]|0;
     $645 = ($644|0)==(0|0);
     if ($645) {
      break;
     } else {
      $$124469$i = $644;
     }
    }
    if ((label|0) == 153) {
     $646 = ((($$124469$i)) + 12|0);
     $647 = HEAP32[$646>>2]|0;
     $648 = $647 & 8;
     $649 = ($648|0)==(0);
     if ($649) {
      HEAP32[$$124469$i>>2] = $$748$i;
      $650 = ((($$124469$i)) + 4|0);
      $651 = HEAP32[$650>>2]|0;
      $652 = (($651) + ($$723947$i))|0;
      HEAP32[$650>>2] = $652;
      $653 = ((($$748$i)) + 8|0);
      $654 = $653;
      $655 = $654 & 7;
      $656 = ($655|0)==(0);
      $657 = (0 - ($654))|0;
      $658 = $657 & 7;
      $659 = $656 ? 0 : $658;
      $660 = (($$748$i) + ($659)|0);
      $661 = ((($640)) + 8|0);
      $662 = $661;
      $663 = $662 & 7;
      $664 = ($663|0)==(0);
      $665 = (0 - ($662))|0;
      $666 = $665 & 7;
      $667 = $664 ? 0 : $666;
      $668 = (($640) + ($667)|0);
      $669 = $668;
      $670 = $660;
      $671 = (($669) - ($670))|0;
      $672 = (($660) + ($$0192)|0);
      $673 = (($671) - ($$0192))|0;
      $674 = $$0192 | 3;
      $675 = ((($660)) + 4|0);
      HEAP32[$675>>2] = $674;
      $676 = ($668|0)==($581|0);
      do {
       if ($676) {
        $677 = HEAP32[(213536)>>2]|0;
        $678 = (($677) + ($673))|0;
        HEAP32[(213536)>>2] = $678;
        HEAP32[(213548)>>2] = $672;
        $679 = $678 | 1;
        $680 = ((($672)) + 4|0);
        HEAP32[$680>>2] = $679;
       } else {
        $681 = HEAP32[(213544)>>2]|0;
        $682 = ($668|0)==($681|0);
        if ($682) {
         $683 = HEAP32[(213532)>>2]|0;
         $684 = (($683) + ($673))|0;
         HEAP32[(213532)>>2] = $684;
         HEAP32[(213544)>>2] = $672;
         $685 = $684 | 1;
         $686 = ((($672)) + 4|0);
         HEAP32[$686>>2] = $685;
         $687 = (($672) + ($684)|0);
         HEAP32[$687>>2] = $684;
         break;
        }
        $688 = ((($668)) + 4|0);
        $689 = HEAP32[$688>>2]|0;
        $690 = $689 & 3;
        $691 = ($690|0)==(1);
        if ($691) {
         $692 = $689 & -8;
         $693 = $689 >>> 3;
         $694 = ($689>>>0)<(256);
         L237: do {
          if ($694) {
           $695 = ((($668)) + 8|0);
           $696 = HEAP32[$695>>2]|0;
           $697 = ((($668)) + 12|0);
           $698 = HEAP32[$697>>2]|0;
           $699 = ($698|0)==($696|0);
           if ($699) {
            $700 = 1 << $693;
            $701 = $700 ^ -1;
            $702 = HEAP32[53381]|0;
            $703 = $702 & $701;
            HEAP32[53381] = $703;
            break;
           } else {
            $704 = ((($696)) + 12|0);
            HEAP32[$704>>2] = $698;
            $705 = ((($698)) + 8|0);
            HEAP32[$705>>2] = $696;
            break;
           }
          } else {
           $706 = ((($668)) + 24|0);
           $707 = HEAP32[$706>>2]|0;
           $708 = ((($668)) + 12|0);
           $709 = HEAP32[$708>>2]|0;
           $710 = ($709|0)==($668|0);
           do {
            if ($710) {
             $715 = ((($668)) + 16|0);
             $716 = ((($715)) + 4|0);
             $717 = HEAP32[$716>>2]|0;
             $718 = ($717|0)==(0|0);
             if ($718) {
              $719 = HEAP32[$715>>2]|0;
              $720 = ($719|0)==(0|0);
              if ($720) {
               $$3$i$i = 0;
               break;
              } else {
               $$1264$i$i = $719;$$1266$i$i = $715;
              }
             } else {
              $$1264$i$i = $717;$$1266$i$i = $716;
             }
             while(1) {
              $721 = ((($$1264$i$i)) + 20|0);
              $722 = HEAP32[$721>>2]|0;
              $723 = ($722|0)==(0|0);
              if (!($723)) {
               $$1264$i$i = $722;$$1266$i$i = $721;
               continue;
              }
              $724 = ((($$1264$i$i)) + 16|0);
              $725 = HEAP32[$724>>2]|0;
              $726 = ($725|0)==(0|0);
              if ($726) {
               break;
              } else {
               $$1264$i$i = $725;$$1266$i$i = $724;
              }
             }
             HEAP32[$$1266$i$i>>2] = 0;
             $$3$i$i = $$1264$i$i;
            } else {
             $711 = ((($668)) + 8|0);
             $712 = HEAP32[$711>>2]|0;
             $713 = ((($712)) + 12|0);
             HEAP32[$713>>2] = $709;
             $714 = ((($709)) + 8|0);
             HEAP32[$714>>2] = $712;
             $$3$i$i = $709;
            }
           } while(0);
           $727 = ($707|0)==(0|0);
           if ($727) {
            break;
           }
           $728 = ((($668)) + 28|0);
           $729 = HEAP32[$728>>2]|0;
           $730 = (213828 + ($729<<2)|0);
           $731 = HEAP32[$730>>2]|0;
           $732 = ($668|0)==($731|0);
           do {
            if ($732) {
             HEAP32[$730>>2] = $$3$i$i;
             $cond$i$i = ($$3$i$i|0)==(0|0);
             if (!($cond$i$i)) {
              break;
             }
             $733 = 1 << $729;
             $734 = $733 ^ -1;
             $735 = HEAP32[(213528)>>2]|0;
             $736 = $735 & $734;
             HEAP32[(213528)>>2] = $736;
             break L237;
            } else {
             $737 = ((($707)) + 16|0);
             $738 = HEAP32[$737>>2]|0;
             $not$$i$i = ($738|0)!=($668|0);
             $$sink1$i$i = $not$$i$i&1;
             $739 = (((($707)) + 16|0) + ($$sink1$i$i<<2)|0);
             HEAP32[$739>>2] = $$3$i$i;
             $740 = ($$3$i$i|0)==(0|0);
             if ($740) {
              break L237;
             }
            }
           } while(0);
           $741 = ((($$3$i$i)) + 24|0);
           HEAP32[$741>>2] = $707;
           $742 = ((($668)) + 16|0);
           $743 = HEAP32[$742>>2]|0;
           $744 = ($743|0)==(0|0);
           if (!($744)) {
            $745 = ((($$3$i$i)) + 16|0);
            HEAP32[$745>>2] = $743;
            $746 = ((($743)) + 24|0);
            HEAP32[$746>>2] = $$3$i$i;
           }
           $747 = ((($742)) + 4|0);
           $748 = HEAP32[$747>>2]|0;
           $749 = ($748|0)==(0|0);
           if ($749) {
            break;
           }
           $750 = ((($$3$i$i)) + 20|0);
           HEAP32[$750>>2] = $748;
           $751 = ((($748)) + 24|0);
           HEAP32[$751>>2] = $$3$i$i;
          }
         } while(0);
         $752 = (($668) + ($692)|0);
         $753 = (($692) + ($673))|0;
         $$0$i$i = $752;$$0260$i$i = $753;
        } else {
         $$0$i$i = $668;$$0260$i$i = $673;
        }
        $754 = ((($$0$i$i)) + 4|0);
        $755 = HEAP32[$754>>2]|0;
        $756 = $755 & -2;
        HEAP32[$754>>2] = $756;
        $757 = $$0260$i$i | 1;
        $758 = ((($672)) + 4|0);
        HEAP32[$758>>2] = $757;
        $759 = (($672) + ($$0260$i$i)|0);
        HEAP32[$759>>2] = $$0260$i$i;
        $760 = $$0260$i$i >>> 3;
        $761 = ($$0260$i$i>>>0)<(256);
        if ($761) {
         $762 = $760 << 1;
         $763 = (213564 + ($762<<2)|0);
         $764 = HEAP32[53381]|0;
         $765 = 1 << $760;
         $766 = $764 & $765;
         $767 = ($766|0)==(0);
         if ($767) {
          $768 = $764 | $765;
          HEAP32[53381] = $768;
          $$pre$i17$i = ((($763)) + 8|0);
          $$0268$i$i = $763;$$pre$phi$i18$iZ2D = $$pre$i17$i;
         } else {
          $769 = ((($763)) + 8|0);
          $770 = HEAP32[$769>>2]|0;
          $$0268$i$i = $770;$$pre$phi$i18$iZ2D = $769;
         }
         HEAP32[$$pre$phi$i18$iZ2D>>2] = $672;
         $771 = ((($$0268$i$i)) + 12|0);
         HEAP32[$771>>2] = $672;
         $772 = ((($672)) + 8|0);
         HEAP32[$772>>2] = $$0268$i$i;
         $773 = ((($672)) + 12|0);
         HEAP32[$773>>2] = $763;
         break;
        }
        $774 = $$0260$i$i >>> 8;
        $775 = ($774|0)==(0);
        do {
         if ($775) {
          $$0269$i$i = 0;
         } else {
          $776 = ($$0260$i$i>>>0)>(16777215);
          if ($776) {
           $$0269$i$i = 31;
           break;
          }
          $777 = (($774) + 1048320)|0;
          $778 = $777 >>> 16;
          $779 = $778 & 8;
          $780 = $774 << $779;
          $781 = (($780) + 520192)|0;
          $782 = $781 >>> 16;
          $783 = $782 & 4;
          $784 = $783 | $779;
          $785 = $780 << $783;
          $786 = (($785) + 245760)|0;
          $787 = $786 >>> 16;
          $788 = $787 & 2;
          $789 = $784 | $788;
          $790 = (14 - ($789))|0;
          $791 = $785 << $788;
          $792 = $791 >>> 15;
          $793 = (($790) + ($792))|0;
          $794 = $793 << 1;
          $795 = (($793) + 7)|0;
          $796 = $$0260$i$i >>> $795;
          $797 = $796 & 1;
          $798 = $797 | $794;
          $$0269$i$i = $798;
         }
        } while(0);
        $799 = (213828 + ($$0269$i$i<<2)|0);
        $800 = ((($672)) + 28|0);
        HEAP32[$800>>2] = $$0269$i$i;
        $801 = ((($672)) + 16|0);
        $802 = ((($801)) + 4|0);
        HEAP32[$802>>2] = 0;
        HEAP32[$801>>2] = 0;
        $803 = HEAP32[(213528)>>2]|0;
        $804 = 1 << $$0269$i$i;
        $805 = $803 & $804;
        $806 = ($805|0)==(0);
        if ($806) {
         $807 = $803 | $804;
         HEAP32[(213528)>>2] = $807;
         HEAP32[$799>>2] = $672;
         $808 = ((($672)) + 24|0);
         HEAP32[$808>>2] = $799;
         $809 = ((($672)) + 12|0);
         HEAP32[$809>>2] = $672;
         $810 = ((($672)) + 8|0);
         HEAP32[$810>>2] = $672;
         break;
        }
        $811 = HEAP32[$799>>2]|0;
        $812 = ($$0269$i$i|0)==(31);
        $813 = $$0269$i$i >>> 1;
        $814 = (25 - ($813))|0;
        $815 = $812 ? 0 : $814;
        $816 = $$0260$i$i << $815;
        $$0261$i$i = $816;$$0262$i$i = $811;
        while(1) {
         $817 = ((($$0262$i$i)) + 4|0);
         $818 = HEAP32[$817>>2]|0;
         $819 = $818 & -8;
         $820 = ($819|0)==($$0260$i$i|0);
         if ($820) {
          label = 194;
          break;
         }
         $821 = $$0261$i$i >>> 31;
         $822 = (((($$0262$i$i)) + 16|0) + ($821<<2)|0);
         $823 = $$0261$i$i << 1;
         $824 = HEAP32[$822>>2]|0;
         $825 = ($824|0)==(0|0);
         if ($825) {
          label = 193;
          break;
         } else {
          $$0261$i$i = $823;$$0262$i$i = $824;
         }
        }
        if ((label|0) == 193) {
         HEAP32[$822>>2] = $672;
         $826 = ((($672)) + 24|0);
         HEAP32[$826>>2] = $$0262$i$i;
         $827 = ((($672)) + 12|0);
         HEAP32[$827>>2] = $672;
         $828 = ((($672)) + 8|0);
         HEAP32[$828>>2] = $672;
         break;
        }
        else if ((label|0) == 194) {
         $829 = ((($$0262$i$i)) + 8|0);
         $830 = HEAP32[$829>>2]|0;
         $831 = ((($830)) + 12|0);
         HEAP32[$831>>2] = $672;
         HEAP32[$829>>2] = $672;
         $832 = ((($672)) + 8|0);
         HEAP32[$832>>2] = $830;
         $833 = ((($672)) + 12|0);
         HEAP32[$833>>2] = $$0262$i$i;
         $834 = ((($672)) + 24|0);
         HEAP32[$834>>2] = 0;
         break;
        }
       }
      } while(0);
      $959 = ((($660)) + 8|0);
      $$0 = $959;
      STACKTOP = sp;return ($$0|0);
     }
    }
    $$0$i$i$i = (213972);
    while(1) {
     $835 = HEAP32[$$0$i$i$i>>2]|0;
     $836 = ($835>>>0)>($581>>>0);
     if (!($836)) {
      $837 = ((($$0$i$i$i)) + 4|0);
      $838 = HEAP32[$837>>2]|0;
      $839 = (($835) + ($838)|0);
      $840 = ($839>>>0)>($581>>>0);
      if ($840) {
       break;
      }
     }
     $841 = ((($$0$i$i$i)) + 8|0);
     $842 = HEAP32[$841>>2]|0;
     $$0$i$i$i = $842;
    }
    $843 = ((($839)) + -47|0);
    $844 = ((($843)) + 8|0);
    $845 = $844;
    $846 = $845 & 7;
    $847 = ($846|0)==(0);
    $848 = (0 - ($845))|0;
    $849 = $848 & 7;
    $850 = $847 ? 0 : $849;
    $851 = (($843) + ($850)|0);
    $852 = ((($581)) + 16|0);
    $853 = ($851>>>0)<($852>>>0);
    $854 = $853 ? $581 : $851;
    $855 = ((($854)) + 8|0);
    $856 = ((($854)) + 24|0);
    $857 = (($$723947$i) + -40)|0;
    $858 = ((($$748$i)) + 8|0);
    $859 = $858;
    $860 = $859 & 7;
    $861 = ($860|0)==(0);
    $862 = (0 - ($859))|0;
    $863 = $862 & 7;
    $864 = $861 ? 0 : $863;
    $865 = (($$748$i) + ($864)|0);
    $866 = (($857) - ($864))|0;
    HEAP32[(213548)>>2] = $865;
    HEAP32[(213536)>>2] = $866;
    $867 = $866 | 1;
    $868 = ((($865)) + 4|0);
    HEAP32[$868>>2] = $867;
    $869 = (($865) + ($866)|0);
    $870 = ((($869)) + 4|0);
    HEAP32[$870>>2] = 40;
    $871 = HEAP32[(214012)>>2]|0;
    HEAP32[(213552)>>2] = $871;
    $872 = ((($854)) + 4|0);
    HEAP32[$872>>2] = 27;
    ;HEAP32[$855>>2]=HEAP32[(213972)>>2]|0;HEAP32[$855+4>>2]=HEAP32[(213972)+4>>2]|0;HEAP32[$855+8>>2]=HEAP32[(213972)+8>>2]|0;HEAP32[$855+12>>2]=HEAP32[(213972)+12>>2]|0;
    HEAP32[(213972)>>2] = $$748$i;
    HEAP32[(213976)>>2] = $$723947$i;
    HEAP32[(213984)>>2] = 0;
    HEAP32[(213980)>>2] = $855;
    $874 = $856;
    while(1) {
     $873 = ((($874)) + 4|0);
     HEAP32[$873>>2] = 7;
     $875 = ((($874)) + 8|0);
     $876 = ($875>>>0)<($839>>>0);
     if ($876) {
      $874 = $873;
     } else {
      break;
     }
    }
    $877 = ($854|0)==($581|0);
    if (!($877)) {
     $878 = $854;
     $879 = $581;
     $880 = (($878) - ($879))|0;
     $881 = HEAP32[$872>>2]|0;
     $882 = $881 & -2;
     HEAP32[$872>>2] = $882;
     $883 = $880 | 1;
     $884 = ((($581)) + 4|0);
     HEAP32[$884>>2] = $883;
     HEAP32[$854>>2] = $880;
     $885 = $880 >>> 3;
     $886 = ($880>>>0)<(256);
     if ($886) {
      $887 = $885 << 1;
      $888 = (213564 + ($887<<2)|0);
      $889 = HEAP32[53381]|0;
      $890 = 1 << $885;
      $891 = $889 & $890;
      $892 = ($891|0)==(0);
      if ($892) {
       $893 = $889 | $890;
       HEAP32[53381] = $893;
       $$pre$i$i = ((($888)) + 8|0);
       $$0206$i$i = $888;$$pre$phi$i$iZ2D = $$pre$i$i;
      } else {
       $894 = ((($888)) + 8|0);
       $895 = HEAP32[$894>>2]|0;
       $$0206$i$i = $895;$$pre$phi$i$iZ2D = $894;
      }
      HEAP32[$$pre$phi$i$iZ2D>>2] = $581;
      $896 = ((($$0206$i$i)) + 12|0);
      HEAP32[$896>>2] = $581;
      $897 = ((($581)) + 8|0);
      HEAP32[$897>>2] = $$0206$i$i;
      $898 = ((($581)) + 12|0);
      HEAP32[$898>>2] = $888;
      break;
     }
     $899 = $880 >>> 8;
     $900 = ($899|0)==(0);
     if ($900) {
      $$0207$i$i = 0;
     } else {
      $901 = ($880>>>0)>(16777215);
      if ($901) {
       $$0207$i$i = 31;
      } else {
       $902 = (($899) + 1048320)|0;
       $903 = $902 >>> 16;
       $904 = $903 & 8;
       $905 = $899 << $904;
       $906 = (($905) + 520192)|0;
       $907 = $906 >>> 16;
       $908 = $907 & 4;
       $909 = $908 | $904;
       $910 = $905 << $908;
       $911 = (($910) + 245760)|0;
       $912 = $911 >>> 16;
       $913 = $912 & 2;
       $914 = $909 | $913;
       $915 = (14 - ($914))|0;
       $916 = $910 << $913;
       $917 = $916 >>> 15;
       $918 = (($915) + ($917))|0;
       $919 = $918 << 1;
       $920 = (($918) + 7)|0;
       $921 = $880 >>> $920;
       $922 = $921 & 1;
       $923 = $922 | $919;
       $$0207$i$i = $923;
      }
     }
     $924 = (213828 + ($$0207$i$i<<2)|0);
     $925 = ((($581)) + 28|0);
     HEAP32[$925>>2] = $$0207$i$i;
     $926 = ((($581)) + 20|0);
     HEAP32[$926>>2] = 0;
     HEAP32[$852>>2] = 0;
     $927 = HEAP32[(213528)>>2]|0;
     $928 = 1 << $$0207$i$i;
     $929 = $927 & $928;
     $930 = ($929|0)==(0);
     if ($930) {
      $931 = $927 | $928;
      HEAP32[(213528)>>2] = $931;
      HEAP32[$924>>2] = $581;
      $932 = ((($581)) + 24|0);
      HEAP32[$932>>2] = $924;
      $933 = ((($581)) + 12|0);
      HEAP32[$933>>2] = $581;
      $934 = ((($581)) + 8|0);
      HEAP32[$934>>2] = $581;
      break;
     }
     $935 = HEAP32[$924>>2]|0;
     $936 = ($$0207$i$i|0)==(31);
     $937 = $$0207$i$i >>> 1;
     $938 = (25 - ($937))|0;
     $939 = $936 ? 0 : $938;
     $940 = $880 << $939;
     $$0201$i$i = $940;$$0202$i$i = $935;
     while(1) {
      $941 = ((($$0202$i$i)) + 4|0);
      $942 = HEAP32[$941>>2]|0;
      $943 = $942 & -8;
      $944 = ($943|0)==($880|0);
      if ($944) {
       label = 216;
       break;
      }
      $945 = $$0201$i$i >>> 31;
      $946 = (((($$0202$i$i)) + 16|0) + ($945<<2)|0);
      $947 = $$0201$i$i << 1;
      $948 = HEAP32[$946>>2]|0;
      $949 = ($948|0)==(0|0);
      if ($949) {
       label = 215;
       break;
      } else {
       $$0201$i$i = $947;$$0202$i$i = $948;
      }
     }
     if ((label|0) == 215) {
      HEAP32[$946>>2] = $581;
      $950 = ((($581)) + 24|0);
      HEAP32[$950>>2] = $$0202$i$i;
      $951 = ((($581)) + 12|0);
      HEAP32[$951>>2] = $581;
      $952 = ((($581)) + 8|0);
      HEAP32[$952>>2] = $581;
      break;
     }
     else if ((label|0) == 216) {
      $953 = ((($$0202$i$i)) + 8|0);
      $954 = HEAP32[$953>>2]|0;
      $955 = ((($954)) + 12|0);
      HEAP32[$955>>2] = $581;
      HEAP32[$953>>2] = $581;
      $956 = ((($581)) + 8|0);
      HEAP32[$956>>2] = $954;
      $957 = ((($581)) + 12|0);
      HEAP32[$957>>2] = $$0202$i$i;
      $958 = ((($581)) + 24|0);
      HEAP32[$958>>2] = 0;
      break;
     }
    }
   }
  } while(0);
  $960 = HEAP32[(213536)>>2]|0;
  $961 = ($960>>>0)>($$0192>>>0);
  if ($961) {
   $962 = (($960) - ($$0192))|0;
   HEAP32[(213536)>>2] = $962;
   $963 = HEAP32[(213548)>>2]|0;
   $964 = (($963) + ($$0192)|0);
   HEAP32[(213548)>>2] = $964;
   $965 = $962 | 1;
   $966 = ((($964)) + 4|0);
   HEAP32[$966>>2] = $965;
   $967 = $$0192 | 3;
   $968 = ((($963)) + 4|0);
   HEAP32[$968>>2] = $967;
   $969 = ((($963)) + 8|0);
   $$0 = $969;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $970 = (___errno_location()|0);
 HEAP32[$970>>2] = 12;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _free($0) {
 $0 = $0|0;
 var $$0195$i = 0, $$0195$in$i = 0, $$0348 = 0, $$0349 = 0, $$0361 = 0, $$0368 = 0, $$1 = 0, $$1347 = 0, $$1352 = 0, $$1355 = 0, $$1363 = 0, $$1367 = 0, $$2 = 0, $$3 = 0, $$3365 = 0, $$pre = 0, $$pre$phiZ2D = 0, $$sink3 = 0, $$sink5 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0;
 var $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0;
 var $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0;
 var $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0;
 var $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0;
 var $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0;
 var $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0;
 var $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $cond374 = 0, $cond375 = 0, $not$ = 0, $not$370 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ($0|0)==(0|0);
 if ($1) {
  return;
 }
 $2 = ((($0)) + -8|0);
 $3 = HEAP32[(213540)>>2]|0;
 $4 = ((($0)) + -4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5 & -8;
 $7 = (($2) + ($6)|0);
 $8 = $5 & 1;
 $9 = ($8|0)==(0);
 do {
  if ($9) {
   $10 = HEAP32[$2>>2]|0;
   $11 = $5 & 3;
   $12 = ($11|0)==(0);
   if ($12) {
    return;
   }
   $13 = (0 - ($10))|0;
   $14 = (($2) + ($13)|0);
   $15 = (($10) + ($6))|0;
   $16 = ($14>>>0)<($3>>>0);
   if ($16) {
    return;
   }
   $17 = HEAP32[(213544)>>2]|0;
   $18 = ($14|0)==($17|0);
   if ($18) {
    $78 = ((($7)) + 4|0);
    $79 = HEAP32[$78>>2]|0;
    $80 = $79 & 3;
    $81 = ($80|0)==(3);
    if (!($81)) {
     $$1 = $14;$$1347 = $15;$86 = $14;
     break;
    }
    $82 = (($14) + ($15)|0);
    $83 = ((($14)) + 4|0);
    $84 = $15 | 1;
    $85 = $79 & -2;
    HEAP32[(213532)>>2] = $15;
    HEAP32[$78>>2] = $85;
    HEAP32[$83>>2] = $84;
    HEAP32[$82>>2] = $15;
    return;
   }
   $19 = $10 >>> 3;
   $20 = ($10>>>0)<(256);
   if ($20) {
    $21 = ((($14)) + 8|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = ((($14)) + 12|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = ($24|0)==($22|0);
    if ($25) {
     $26 = 1 << $19;
     $27 = $26 ^ -1;
     $28 = HEAP32[53381]|0;
     $29 = $28 & $27;
     HEAP32[53381] = $29;
     $$1 = $14;$$1347 = $15;$86 = $14;
     break;
    } else {
     $30 = ((($22)) + 12|0);
     HEAP32[$30>>2] = $24;
     $31 = ((($24)) + 8|0);
     HEAP32[$31>>2] = $22;
     $$1 = $14;$$1347 = $15;$86 = $14;
     break;
    }
   }
   $32 = ((($14)) + 24|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = ((($14)) + 12|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ($35|0)==($14|0);
   do {
    if ($36) {
     $41 = ((($14)) + 16|0);
     $42 = ((($41)) + 4|0);
     $43 = HEAP32[$42>>2]|0;
     $44 = ($43|0)==(0|0);
     if ($44) {
      $45 = HEAP32[$41>>2]|0;
      $46 = ($45|0)==(0|0);
      if ($46) {
       $$3 = 0;
       break;
      } else {
       $$1352 = $45;$$1355 = $41;
      }
     } else {
      $$1352 = $43;$$1355 = $42;
     }
     while(1) {
      $47 = ((($$1352)) + 20|0);
      $48 = HEAP32[$47>>2]|0;
      $49 = ($48|0)==(0|0);
      if (!($49)) {
       $$1352 = $48;$$1355 = $47;
       continue;
      }
      $50 = ((($$1352)) + 16|0);
      $51 = HEAP32[$50>>2]|0;
      $52 = ($51|0)==(0|0);
      if ($52) {
       break;
      } else {
       $$1352 = $51;$$1355 = $50;
      }
     }
     HEAP32[$$1355>>2] = 0;
     $$3 = $$1352;
    } else {
     $37 = ((($14)) + 8|0);
     $38 = HEAP32[$37>>2]|0;
     $39 = ((($38)) + 12|0);
     HEAP32[$39>>2] = $35;
     $40 = ((($35)) + 8|0);
     HEAP32[$40>>2] = $38;
     $$3 = $35;
    }
   } while(0);
   $53 = ($33|0)==(0|0);
   if ($53) {
    $$1 = $14;$$1347 = $15;$86 = $14;
   } else {
    $54 = ((($14)) + 28|0);
    $55 = HEAP32[$54>>2]|0;
    $56 = (213828 + ($55<<2)|0);
    $57 = HEAP32[$56>>2]|0;
    $58 = ($14|0)==($57|0);
    if ($58) {
     HEAP32[$56>>2] = $$3;
     $cond374 = ($$3|0)==(0|0);
     if ($cond374) {
      $59 = 1 << $55;
      $60 = $59 ^ -1;
      $61 = HEAP32[(213528)>>2]|0;
      $62 = $61 & $60;
      HEAP32[(213528)>>2] = $62;
      $$1 = $14;$$1347 = $15;$86 = $14;
      break;
     }
    } else {
     $63 = ((($33)) + 16|0);
     $64 = HEAP32[$63>>2]|0;
     $not$370 = ($64|0)!=($14|0);
     $$sink3 = $not$370&1;
     $65 = (((($33)) + 16|0) + ($$sink3<<2)|0);
     HEAP32[$65>>2] = $$3;
     $66 = ($$3|0)==(0|0);
     if ($66) {
      $$1 = $14;$$1347 = $15;$86 = $14;
      break;
     }
    }
    $67 = ((($$3)) + 24|0);
    HEAP32[$67>>2] = $33;
    $68 = ((($14)) + 16|0);
    $69 = HEAP32[$68>>2]|0;
    $70 = ($69|0)==(0|0);
    if (!($70)) {
     $71 = ((($$3)) + 16|0);
     HEAP32[$71>>2] = $69;
     $72 = ((($69)) + 24|0);
     HEAP32[$72>>2] = $$3;
    }
    $73 = ((($68)) + 4|0);
    $74 = HEAP32[$73>>2]|0;
    $75 = ($74|0)==(0|0);
    if ($75) {
     $$1 = $14;$$1347 = $15;$86 = $14;
    } else {
     $76 = ((($$3)) + 20|0);
     HEAP32[$76>>2] = $74;
     $77 = ((($74)) + 24|0);
     HEAP32[$77>>2] = $$3;
     $$1 = $14;$$1347 = $15;$86 = $14;
    }
   }
  } else {
   $$1 = $2;$$1347 = $6;$86 = $2;
  }
 } while(0);
 $87 = ($86>>>0)<($7>>>0);
 if (!($87)) {
  return;
 }
 $88 = ((($7)) + 4|0);
 $89 = HEAP32[$88>>2]|0;
 $90 = $89 & 1;
 $91 = ($90|0)==(0);
 if ($91) {
  return;
 }
 $92 = $89 & 2;
 $93 = ($92|0)==(0);
 if ($93) {
  $94 = HEAP32[(213548)>>2]|0;
  $95 = ($7|0)==($94|0);
  $96 = HEAP32[(213544)>>2]|0;
  if ($95) {
   $97 = HEAP32[(213536)>>2]|0;
   $98 = (($97) + ($$1347))|0;
   HEAP32[(213536)>>2] = $98;
   HEAP32[(213548)>>2] = $$1;
   $99 = $98 | 1;
   $100 = ((($$1)) + 4|0);
   HEAP32[$100>>2] = $99;
   $101 = ($$1|0)==($96|0);
   if (!($101)) {
    return;
   }
   HEAP32[(213544)>>2] = 0;
   HEAP32[(213532)>>2] = 0;
   return;
  }
  $102 = ($7|0)==($96|0);
  if ($102) {
   $103 = HEAP32[(213532)>>2]|0;
   $104 = (($103) + ($$1347))|0;
   HEAP32[(213532)>>2] = $104;
   HEAP32[(213544)>>2] = $86;
   $105 = $104 | 1;
   $106 = ((($$1)) + 4|0);
   HEAP32[$106>>2] = $105;
   $107 = (($86) + ($104)|0);
   HEAP32[$107>>2] = $104;
   return;
  }
  $108 = $89 & -8;
  $109 = (($108) + ($$1347))|0;
  $110 = $89 >>> 3;
  $111 = ($89>>>0)<(256);
  do {
   if ($111) {
    $112 = ((($7)) + 8|0);
    $113 = HEAP32[$112>>2]|0;
    $114 = ((($7)) + 12|0);
    $115 = HEAP32[$114>>2]|0;
    $116 = ($115|0)==($113|0);
    if ($116) {
     $117 = 1 << $110;
     $118 = $117 ^ -1;
     $119 = HEAP32[53381]|0;
     $120 = $119 & $118;
     HEAP32[53381] = $120;
     break;
    } else {
     $121 = ((($113)) + 12|0);
     HEAP32[$121>>2] = $115;
     $122 = ((($115)) + 8|0);
     HEAP32[$122>>2] = $113;
     break;
    }
   } else {
    $123 = ((($7)) + 24|0);
    $124 = HEAP32[$123>>2]|0;
    $125 = ((($7)) + 12|0);
    $126 = HEAP32[$125>>2]|0;
    $127 = ($126|0)==($7|0);
    do {
     if ($127) {
      $132 = ((($7)) + 16|0);
      $133 = ((($132)) + 4|0);
      $134 = HEAP32[$133>>2]|0;
      $135 = ($134|0)==(0|0);
      if ($135) {
       $136 = HEAP32[$132>>2]|0;
       $137 = ($136|0)==(0|0);
       if ($137) {
        $$3365 = 0;
        break;
       } else {
        $$1363 = $136;$$1367 = $132;
       }
      } else {
       $$1363 = $134;$$1367 = $133;
      }
      while(1) {
       $138 = ((($$1363)) + 20|0);
       $139 = HEAP32[$138>>2]|0;
       $140 = ($139|0)==(0|0);
       if (!($140)) {
        $$1363 = $139;$$1367 = $138;
        continue;
       }
       $141 = ((($$1363)) + 16|0);
       $142 = HEAP32[$141>>2]|0;
       $143 = ($142|0)==(0|0);
       if ($143) {
        break;
       } else {
        $$1363 = $142;$$1367 = $141;
       }
      }
      HEAP32[$$1367>>2] = 0;
      $$3365 = $$1363;
     } else {
      $128 = ((($7)) + 8|0);
      $129 = HEAP32[$128>>2]|0;
      $130 = ((($129)) + 12|0);
      HEAP32[$130>>2] = $126;
      $131 = ((($126)) + 8|0);
      HEAP32[$131>>2] = $129;
      $$3365 = $126;
     }
    } while(0);
    $144 = ($124|0)==(0|0);
    if (!($144)) {
     $145 = ((($7)) + 28|0);
     $146 = HEAP32[$145>>2]|0;
     $147 = (213828 + ($146<<2)|0);
     $148 = HEAP32[$147>>2]|0;
     $149 = ($7|0)==($148|0);
     if ($149) {
      HEAP32[$147>>2] = $$3365;
      $cond375 = ($$3365|0)==(0|0);
      if ($cond375) {
       $150 = 1 << $146;
       $151 = $150 ^ -1;
       $152 = HEAP32[(213528)>>2]|0;
       $153 = $152 & $151;
       HEAP32[(213528)>>2] = $153;
       break;
      }
     } else {
      $154 = ((($124)) + 16|0);
      $155 = HEAP32[$154>>2]|0;
      $not$ = ($155|0)!=($7|0);
      $$sink5 = $not$&1;
      $156 = (((($124)) + 16|0) + ($$sink5<<2)|0);
      HEAP32[$156>>2] = $$3365;
      $157 = ($$3365|0)==(0|0);
      if ($157) {
       break;
      }
     }
     $158 = ((($$3365)) + 24|0);
     HEAP32[$158>>2] = $124;
     $159 = ((($7)) + 16|0);
     $160 = HEAP32[$159>>2]|0;
     $161 = ($160|0)==(0|0);
     if (!($161)) {
      $162 = ((($$3365)) + 16|0);
      HEAP32[$162>>2] = $160;
      $163 = ((($160)) + 24|0);
      HEAP32[$163>>2] = $$3365;
     }
     $164 = ((($159)) + 4|0);
     $165 = HEAP32[$164>>2]|0;
     $166 = ($165|0)==(0|0);
     if (!($166)) {
      $167 = ((($$3365)) + 20|0);
      HEAP32[$167>>2] = $165;
      $168 = ((($165)) + 24|0);
      HEAP32[$168>>2] = $$3365;
     }
    }
   }
  } while(0);
  $169 = $109 | 1;
  $170 = ((($$1)) + 4|0);
  HEAP32[$170>>2] = $169;
  $171 = (($86) + ($109)|0);
  HEAP32[$171>>2] = $109;
  $172 = HEAP32[(213544)>>2]|0;
  $173 = ($$1|0)==($172|0);
  if ($173) {
   HEAP32[(213532)>>2] = $109;
   return;
  } else {
   $$2 = $109;
  }
 } else {
  $174 = $89 & -2;
  HEAP32[$88>>2] = $174;
  $175 = $$1347 | 1;
  $176 = ((($$1)) + 4|0);
  HEAP32[$176>>2] = $175;
  $177 = (($86) + ($$1347)|0);
  HEAP32[$177>>2] = $$1347;
  $$2 = $$1347;
 }
 $178 = $$2 >>> 3;
 $179 = ($$2>>>0)<(256);
 if ($179) {
  $180 = $178 << 1;
  $181 = (213564 + ($180<<2)|0);
  $182 = HEAP32[53381]|0;
  $183 = 1 << $178;
  $184 = $182 & $183;
  $185 = ($184|0)==(0);
  if ($185) {
   $186 = $182 | $183;
   HEAP32[53381] = $186;
   $$pre = ((($181)) + 8|0);
   $$0368 = $181;$$pre$phiZ2D = $$pre;
  } else {
   $187 = ((($181)) + 8|0);
   $188 = HEAP32[$187>>2]|0;
   $$0368 = $188;$$pre$phiZ2D = $187;
  }
  HEAP32[$$pre$phiZ2D>>2] = $$1;
  $189 = ((($$0368)) + 12|0);
  HEAP32[$189>>2] = $$1;
  $190 = ((($$1)) + 8|0);
  HEAP32[$190>>2] = $$0368;
  $191 = ((($$1)) + 12|0);
  HEAP32[$191>>2] = $181;
  return;
 }
 $192 = $$2 >>> 8;
 $193 = ($192|0)==(0);
 if ($193) {
  $$0361 = 0;
 } else {
  $194 = ($$2>>>0)>(16777215);
  if ($194) {
   $$0361 = 31;
  } else {
   $195 = (($192) + 1048320)|0;
   $196 = $195 >>> 16;
   $197 = $196 & 8;
   $198 = $192 << $197;
   $199 = (($198) + 520192)|0;
   $200 = $199 >>> 16;
   $201 = $200 & 4;
   $202 = $201 | $197;
   $203 = $198 << $201;
   $204 = (($203) + 245760)|0;
   $205 = $204 >>> 16;
   $206 = $205 & 2;
   $207 = $202 | $206;
   $208 = (14 - ($207))|0;
   $209 = $203 << $206;
   $210 = $209 >>> 15;
   $211 = (($208) + ($210))|0;
   $212 = $211 << 1;
   $213 = (($211) + 7)|0;
   $214 = $$2 >>> $213;
   $215 = $214 & 1;
   $216 = $215 | $212;
   $$0361 = $216;
  }
 }
 $217 = (213828 + ($$0361<<2)|0);
 $218 = ((($$1)) + 28|0);
 HEAP32[$218>>2] = $$0361;
 $219 = ((($$1)) + 16|0);
 $220 = ((($$1)) + 20|0);
 HEAP32[$220>>2] = 0;
 HEAP32[$219>>2] = 0;
 $221 = HEAP32[(213528)>>2]|0;
 $222 = 1 << $$0361;
 $223 = $221 & $222;
 $224 = ($223|0)==(0);
 do {
  if ($224) {
   $225 = $221 | $222;
   HEAP32[(213528)>>2] = $225;
   HEAP32[$217>>2] = $$1;
   $226 = ((($$1)) + 24|0);
   HEAP32[$226>>2] = $217;
   $227 = ((($$1)) + 12|0);
   HEAP32[$227>>2] = $$1;
   $228 = ((($$1)) + 8|0);
   HEAP32[$228>>2] = $$1;
  } else {
   $229 = HEAP32[$217>>2]|0;
   $230 = ($$0361|0)==(31);
   $231 = $$0361 >>> 1;
   $232 = (25 - ($231))|0;
   $233 = $230 ? 0 : $232;
   $234 = $$2 << $233;
   $$0348 = $234;$$0349 = $229;
   while(1) {
    $235 = ((($$0349)) + 4|0);
    $236 = HEAP32[$235>>2]|0;
    $237 = $236 & -8;
    $238 = ($237|0)==($$2|0);
    if ($238) {
     label = 73;
     break;
    }
    $239 = $$0348 >>> 31;
    $240 = (((($$0349)) + 16|0) + ($239<<2)|0);
    $241 = $$0348 << 1;
    $242 = HEAP32[$240>>2]|0;
    $243 = ($242|0)==(0|0);
    if ($243) {
     label = 72;
     break;
    } else {
     $$0348 = $241;$$0349 = $242;
    }
   }
   if ((label|0) == 72) {
    HEAP32[$240>>2] = $$1;
    $244 = ((($$1)) + 24|0);
    HEAP32[$244>>2] = $$0349;
    $245 = ((($$1)) + 12|0);
    HEAP32[$245>>2] = $$1;
    $246 = ((($$1)) + 8|0);
    HEAP32[$246>>2] = $$1;
    break;
   }
   else if ((label|0) == 73) {
    $247 = ((($$0349)) + 8|0);
    $248 = HEAP32[$247>>2]|0;
    $249 = ((($248)) + 12|0);
    HEAP32[$249>>2] = $$1;
    HEAP32[$247>>2] = $$1;
    $250 = ((($$1)) + 8|0);
    HEAP32[$250>>2] = $248;
    $251 = ((($$1)) + 12|0);
    HEAP32[$251>>2] = $$0349;
    $252 = ((($$1)) + 24|0);
    HEAP32[$252>>2] = 0;
    break;
   }
  }
 } while(0);
 $253 = HEAP32[(213556)>>2]|0;
 $254 = (($253) + -1)|0;
 HEAP32[(213556)>>2] = $254;
 $255 = ($254|0)==(0);
 if ($255) {
  $$0195$in$i = (213980);
 } else {
  return;
 }
 while(1) {
  $$0195$i = HEAP32[$$0195$in$i>>2]|0;
  $256 = ($$0195$i|0)==(0|0);
  $257 = ((($$0195$i)) + 8|0);
  if ($256) {
   break;
  } else {
   $$0195$in$i = $257;
  }
 }
 HEAP32[(213556)>>2] = -1;
 return;
}
function _calloc($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$ = 0, $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($0|0)==(0);
 if ($2) {
  $$0 = 0;
 } else {
  $3 = Math_imul($1, $0)|0;
  $4 = $1 | $0;
  $5 = ($4>>>0)>(65535);
  if ($5) {
   $6 = (($3>>>0) / ($0>>>0))&-1;
   $7 = ($6|0)==($1|0);
   $$ = $7 ? $3 : -1;
   $$0 = $$;
  } else {
   $$0 = $3;
  }
 }
 $8 = (_malloc($$0)|0);
 $9 = ($8|0)==(0|0);
 if ($9) {
  return ($8|0);
 }
 $10 = ((($8)) + -4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11 & 3;
 $13 = ($12|0)==(0);
 if ($13) {
  return ($8|0);
 }
 _memset(($8|0),0,($$0|0))|0;
 return ($8|0);
}
function _realloc($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($0|0)==(0|0);
 if ($2) {
  $3 = (_malloc($1)|0);
  $$1 = $3;
  return ($$1|0);
 }
 $4 = ($1>>>0)>(4294967231);
 if ($4) {
  $5 = (___errno_location()|0);
  HEAP32[$5>>2] = 12;
  $$1 = 0;
  return ($$1|0);
 }
 $6 = ($1>>>0)<(11);
 $7 = (($1) + 11)|0;
 $8 = $7 & -8;
 $9 = $6 ? 16 : $8;
 $10 = ((($0)) + -8|0);
 $11 = (_try_realloc_chunk($10,$9)|0);
 $12 = ($11|0)==(0|0);
 if (!($12)) {
  $13 = ((($11)) + 8|0);
  $$1 = $13;
  return ($$1|0);
 }
 $14 = (_malloc($1)|0);
 $15 = ($14|0)==(0|0);
 if ($15) {
  $$1 = 0;
  return ($$1|0);
 }
 $16 = ((($0)) + -4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = $17 & -8;
 $19 = $17 & 3;
 $20 = ($19|0)==(0);
 $21 = $20 ? 8 : 4;
 $22 = (($18) - ($21))|0;
 $23 = ($22>>>0)<($1>>>0);
 $24 = $23 ? $22 : $1;
 _memcpy(($14|0),($0|0),($24|0))|0;
 _free($0);
 $$1 = $14;
 return ($$1|0);
}
function _try_realloc_chunk($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$1246 = 0, $$1249 = 0, $$2 = 0, $$3 = 0, $$sink1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $cond = 0, $not$ = 0, $storemerge = 0, $storemerge1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 & -8;
 $5 = (($0) + ($4)|0);
 $6 = $3 & 3;
 $7 = ($6|0)==(0);
 if ($7) {
  $8 = ($1>>>0)<(256);
  if ($8) {
   $$2 = 0;
   return ($$2|0);
  }
  $9 = (($1) + 4)|0;
  $10 = ($4>>>0)<($9>>>0);
  if (!($10)) {
   $11 = (($4) - ($1))|0;
   $12 = HEAP32[(214004)>>2]|0;
   $13 = $12 << 1;
   $14 = ($11>>>0)>($13>>>0);
   if (!($14)) {
    $$2 = $0;
    return ($$2|0);
   }
  }
  $$2 = 0;
  return ($$2|0);
 }
 $15 = ($4>>>0)<($1>>>0);
 if (!($15)) {
  $16 = (($4) - ($1))|0;
  $17 = ($16>>>0)>(15);
  if (!($17)) {
   $$2 = $0;
   return ($$2|0);
  }
  $18 = (($0) + ($1)|0);
  $19 = $3 & 1;
  $20 = $19 | $1;
  $21 = $20 | 2;
  HEAP32[$2>>2] = $21;
  $22 = ((($18)) + 4|0);
  $23 = $16 | 3;
  HEAP32[$22>>2] = $23;
  $24 = (($18) + ($16)|0);
  $25 = ((($24)) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = $26 | 1;
  HEAP32[$25>>2] = $27;
  _dispose_chunk($18,$16);
  $$2 = $0;
  return ($$2|0);
 }
 $28 = HEAP32[(213548)>>2]|0;
 $29 = ($5|0)==($28|0);
 if ($29) {
  $30 = HEAP32[(213536)>>2]|0;
  $31 = (($30) + ($4))|0;
  $32 = ($31>>>0)>($1>>>0);
  $33 = (($31) - ($1))|0;
  $34 = (($0) + ($1)|0);
  if (!($32)) {
   $$2 = 0;
   return ($$2|0);
  }
  $35 = $33 | 1;
  $36 = ((($34)) + 4|0);
  $37 = $3 & 1;
  $38 = $37 | $1;
  $39 = $38 | 2;
  HEAP32[$2>>2] = $39;
  HEAP32[$36>>2] = $35;
  HEAP32[(213548)>>2] = $34;
  HEAP32[(213536)>>2] = $33;
  $$2 = $0;
  return ($$2|0);
 }
 $40 = HEAP32[(213544)>>2]|0;
 $41 = ($5|0)==($40|0);
 if ($41) {
  $42 = HEAP32[(213532)>>2]|0;
  $43 = (($42) + ($4))|0;
  $44 = ($43>>>0)<($1>>>0);
  if ($44) {
   $$2 = 0;
   return ($$2|0);
  }
  $45 = (($43) - ($1))|0;
  $46 = ($45>>>0)>(15);
  $47 = $3 & 1;
  if ($46) {
   $48 = (($0) + ($1)|0);
   $49 = (($48) + ($45)|0);
   $50 = $47 | $1;
   $51 = $50 | 2;
   HEAP32[$2>>2] = $51;
   $52 = ((($48)) + 4|0);
   $53 = $45 | 1;
   HEAP32[$52>>2] = $53;
   HEAP32[$49>>2] = $45;
   $54 = ((($49)) + 4|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = $55 & -2;
   HEAP32[$54>>2] = $56;
   $storemerge = $48;$storemerge1 = $45;
  } else {
   $57 = $47 | $43;
   $58 = $57 | 2;
   HEAP32[$2>>2] = $58;
   $59 = (($0) + ($43)|0);
   $60 = ((($59)) + 4|0);
   $61 = HEAP32[$60>>2]|0;
   $62 = $61 | 1;
   HEAP32[$60>>2] = $62;
   $storemerge = 0;$storemerge1 = 0;
  }
  HEAP32[(213532)>>2] = $storemerge1;
  HEAP32[(213544)>>2] = $storemerge;
  $$2 = $0;
  return ($$2|0);
 }
 $63 = ((($5)) + 4|0);
 $64 = HEAP32[$63>>2]|0;
 $65 = $64 & 2;
 $66 = ($65|0)==(0);
 if (!($66)) {
  $$2 = 0;
  return ($$2|0);
 }
 $67 = $64 & -8;
 $68 = (($67) + ($4))|0;
 $69 = ($68>>>0)<($1>>>0);
 if ($69) {
  $$2 = 0;
  return ($$2|0);
 }
 $70 = (($68) - ($1))|0;
 $71 = $64 >>> 3;
 $72 = ($64>>>0)<(256);
 do {
  if ($72) {
   $73 = ((($5)) + 8|0);
   $74 = HEAP32[$73>>2]|0;
   $75 = ((($5)) + 12|0);
   $76 = HEAP32[$75>>2]|0;
   $77 = ($76|0)==($74|0);
   if ($77) {
    $78 = 1 << $71;
    $79 = $78 ^ -1;
    $80 = HEAP32[53381]|0;
    $81 = $80 & $79;
    HEAP32[53381] = $81;
    break;
   } else {
    $82 = ((($74)) + 12|0);
    HEAP32[$82>>2] = $76;
    $83 = ((($76)) + 8|0);
    HEAP32[$83>>2] = $74;
    break;
   }
  } else {
   $84 = ((($5)) + 24|0);
   $85 = HEAP32[$84>>2]|0;
   $86 = ((($5)) + 12|0);
   $87 = HEAP32[$86>>2]|0;
   $88 = ($87|0)==($5|0);
   do {
    if ($88) {
     $93 = ((($5)) + 16|0);
     $94 = ((($93)) + 4|0);
     $95 = HEAP32[$94>>2]|0;
     $96 = ($95|0)==(0|0);
     if ($96) {
      $97 = HEAP32[$93>>2]|0;
      $98 = ($97|0)==(0|0);
      if ($98) {
       $$3 = 0;
       break;
      } else {
       $$1246 = $97;$$1249 = $93;
      }
     } else {
      $$1246 = $95;$$1249 = $94;
     }
     while(1) {
      $99 = ((($$1246)) + 20|0);
      $100 = HEAP32[$99>>2]|0;
      $101 = ($100|0)==(0|0);
      if (!($101)) {
       $$1246 = $100;$$1249 = $99;
       continue;
      }
      $102 = ((($$1246)) + 16|0);
      $103 = HEAP32[$102>>2]|0;
      $104 = ($103|0)==(0|0);
      if ($104) {
       break;
      } else {
       $$1246 = $103;$$1249 = $102;
      }
     }
     HEAP32[$$1249>>2] = 0;
     $$3 = $$1246;
    } else {
     $89 = ((($5)) + 8|0);
     $90 = HEAP32[$89>>2]|0;
     $91 = ((($90)) + 12|0);
     HEAP32[$91>>2] = $87;
     $92 = ((($87)) + 8|0);
     HEAP32[$92>>2] = $90;
     $$3 = $87;
    }
   } while(0);
   $105 = ($85|0)==(0|0);
   if (!($105)) {
    $106 = ((($5)) + 28|0);
    $107 = HEAP32[$106>>2]|0;
    $108 = (213828 + ($107<<2)|0);
    $109 = HEAP32[$108>>2]|0;
    $110 = ($5|0)==($109|0);
    if ($110) {
     HEAP32[$108>>2] = $$3;
     $cond = ($$3|0)==(0|0);
     if ($cond) {
      $111 = 1 << $107;
      $112 = $111 ^ -1;
      $113 = HEAP32[(213528)>>2]|0;
      $114 = $113 & $112;
      HEAP32[(213528)>>2] = $114;
      break;
     }
    } else {
     $115 = ((($85)) + 16|0);
     $116 = HEAP32[$115>>2]|0;
     $not$ = ($116|0)!=($5|0);
     $$sink1 = $not$&1;
     $117 = (((($85)) + 16|0) + ($$sink1<<2)|0);
     HEAP32[$117>>2] = $$3;
     $118 = ($$3|0)==(0|0);
     if ($118) {
      break;
     }
    }
    $119 = ((($$3)) + 24|0);
    HEAP32[$119>>2] = $85;
    $120 = ((($5)) + 16|0);
    $121 = HEAP32[$120>>2]|0;
    $122 = ($121|0)==(0|0);
    if (!($122)) {
     $123 = ((($$3)) + 16|0);
     HEAP32[$123>>2] = $121;
     $124 = ((($121)) + 24|0);
     HEAP32[$124>>2] = $$3;
    }
    $125 = ((($120)) + 4|0);
    $126 = HEAP32[$125>>2]|0;
    $127 = ($126|0)==(0|0);
    if (!($127)) {
     $128 = ((($$3)) + 20|0);
     HEAP32[$128>>2] = $126;
     $129 = ((($126)) + 24|0);
     HEAP32[$129>>2] = $$3;
    }
   }
  }
 } while(0);
 $130 = ($70>>>0)<(16);
 $131 = $3 & 1;
 if ($130) {
  $132 = $68 | $131;
  $133 = $132 | 2;
  HEAP32[$2>>2] = $133;
  $134 = (($0) + ($68)|0);
  $135 = ((($134)) + 4|0);
  $136 = HEAP32[$135>>2]|0;
  $137 = $136 | 1;
  HEAP32[$135>>2] = $137;
  $$2 = $0;
  return ($$2|0);
 } else {
  $138 = (($0) + ($1)|0);
  $139 = $131 | $1;
  $140 = $139 | 2;
  HEAP32[$2>>2] = $140;
  $141 = ((($138)) + 4|0);
  $142 = $70 | 3;
  HEAP32[$141>>2] = $142;
  $143 = (($138) + ($70)|0);
  $144 = ((($143)) + 4|0);
  $145 = HEAP32[$144>>2]|0;
  $146 = $145 | 1;
  HEAP32[$144>>2] = $146;
  _dispose_chunk($138,$70);
  $$2 = $0;
  return ($$2|0);
 }
 return (0)|0;
}
function _dispose_chunk($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0366 = 0, $$0367 = 0, $$0378 = 0, $$0385 = 0, $$1 = 0, $$1365 = 0, $$1373 = 0, $$1376 = 0, $$1380 = 0, $$1384 = 0, $$2 = 0, $$3 = 0, $$3382 = 0, $$pre = 0, $$pre$phiZ2D = 0, $$sink2 = 0, $$sink4 = 0, $10 = 0, $100 = 0, $101 = 0;
 var $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0;
 var $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0;
 var $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0;
 var $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0;
 var $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0;
 var $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0;
 var $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0;
 var $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $cond = 0, $cond5 = 0, $not$ = 0, $not$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (($0) + ($1)|0);
 $3 = ((($0)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 & 1;
 $6 = ($5|0)==(0);
 do {
  if ($6) {
   $7 = HEAP32[$0>>2]|0;
   $8 = $4 & 3;
   $9 = ($8|0)==(0);
   if ($9) {
    return;
   }
   $10 = (0 - ($7))|0;
   $11 = (($0) + ($10)|0);
   $12 = (($7) + ($1))|0;
   $13 = HEAP32[(213544)>>2]|0;
   $14 = ($11|0)==($13|0);
   if ($14) {
    $74 = ((($2)) + 4|0);
    $75 = HEAP32[$74>>2]|0;
    $76 = $75 & 3;
    $77 = ($76|0)==(3);
    if (!($77)) {
     $$1 = $11;$$1365 = $12;
     break;
    }
    $78 = (($11) + ($12)|0);
    $79 = ((($11)) + 4|0);
    $80 = $12 | 1;
    $81 = $75 & -2;
    HEAP32[(213532)>>2] = $12;
    HEAP32[$74>>2] = $81;
    HEAP32[$79>>2] = $80;
    HEAP32[$78>>2] = $12;
    return;
   }
   $15 = $7 >>> 3;
   $16 = ($7>>>0)<(256);
   if ($16) {
    $17 = ((($11)) + 8|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = ((($11)) + 12|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = ($20|0)==($18|0);
    if ($21) {
     $22 = 1 << $15;
     $23 = $22 ^ -1;
     $24 = HEAP32[53381]|0;
     $25 = $24 & $23;
     HEAP32[53381] = $25;
     $$1 = $11;$$1365 = $12;
     break;
    } else {
     $26 = ((($18)) + 12|0);
     HEAP32[$26>>2] = $20;
     $27 = ((($20)) + 8|0);
     HEAP32[$27>>2] = $18;
     $$1 = $11;$$1365 = $12;
     break;
    }
   }
   $28 = ((($11)) + 24|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = ((($11)) + 12|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = ($31|0)==($11|0);
   do {
    if ($32) {
     $37 = ((($11)) + 16|0);
     $38 = ((($37)) + 4|0);
     $39 = HEAP32[$38>>2]|0;
     $40 = ($39|0)==(0|0);
     if ($40) {
      $41 = HEAP32[$37>>2]|0;
      $42 = ($41|0)==(0|0);
      if ($42) {
       $$3 = 0;
       break;
      } else {
       $$1373 = $41;$$1376 = $37;
      }
     } else {
      $$1373 = $39;$$1376 = $38;
     }
     while(1) {
      $43 = ((($$1373)) + 20|0);
      $44 = HEAP32[$43>>2]|0;
      $45 = ($44|0)==(0|0);
      if (!($45)) {
       $$1373 = $44;$$1376 = $43;
       continue;
      }
      $46 = ((($$1373)) + 16|0);
      $47 = HEAP32[$46>>2]|0;
      $48 = ($47|0)==(0|0);
      if ($48) {
       break;
      } else {
       $$1373 = $47;$$1376 = $46;
      }
     }
     HEAP32[$$1376>>2] = 0;
     $$3 = $$1373;
    } else {
     $33 = ((($11)) + 8|0);
     $34 = HEAP32[$33>>2]|0;
     $35 = ((($34)) + 12|0);
     HEAP32[$35>>2] = $31;
     $36 = ((($31)) + 8|0);
     HEAP32[$36>>2] = $34;
     $$3 = $31;
    }
   } while(0);
   $49 = ($29|0)==(0|0);
   if ($49) {
    $$1 = $11;$$1365 = $12;
   } else {
    $50 = ((($11)) + 28|0);
    $51 = HEAP32[$50>>2]|0;
    $52 = (213828 + ($51<<2)|0);
    $53 = HEAP32[$52>>2]|0;
    $54 = ($11|0)==($53|0);
    if ($54) {
     HEAP32[$52>>2] = $$3;
     $cond = ($$3|0)==(0|0);
     if ($cond) {
      $55 = 1 << $51;
      $56 = $55 ^ -1;
      $57 = HEAP32[(213528)>>2]|0;
      $58 = $57 & $56;
      HEAP32[(213528)>>2] = $58;
      $$1 = $11;$$1365 = $12;
      break;
     }
    } else {
     $59 = ((($29)) + 16|0);
     $60 = HEAP32[$59>>2]|0;
     $not$1 = ($60|0)!=($11|0);
     $$sink2 = $not$1&1;
     $61 = (((($29)) + 16|0) + ($$sink2<<2)|0);
     HEAP32[$61>>2] = $$3;
     $62 = ($$3|0)==(0|0);
     if ($62) {
      $$1 = $11;$$1365 = $12;
      break;
     }
    }
    $63 = ((($$3)) + 24|0);
    HEAP32[$63>>2] = $29;
    $64 = ((($11)) + 16|0);
    $65 = HEAP32[$64>>2]|0;
    $66 = ($65|0)==(0|0);
    if (!($66)) {
     $67 = ((($$3)) + 16|0);
     HEAP32[$67>>2] = $65;
     $68 = ((($65)) + 24|0);
     HEAP32[$68>>2] = $$3;
    }
    $69 = ((($64)) + 4|0);
    $70 = HEAP32[$69>>2]|0;
    $71 = ($70|0)==(0|0);
    if ($71) {
     $$1 = $11;$$1365 = $12;
    } else {
     $72 = ((($$3)) + 20|0);
     HEAP32[$72>>2] = $70;
     $73 = ((($70)) + 24|0);
     HEAP32[$73>>2] = $$3;
     $$1 = $11;$$1365 = $12;
    }
   }
  } else {
   $$1 = $0;$$1365 = $1;
  }
 } while(0);
 $82 = ((($2)) + 4|0);
 $83 = HEAP32[$82>>2]|0;
 $84 = $83 & 2;
 $85 = ($84|0)==(0);
 if ($85) {
  $86 = HEAP32[(213548)>>2]|0;
  $87 = ($2|0)==($86|0);
  $88 = HEAP32[(213544)>>2]|0;
  if ($87) {
   $89 = HEAP32[(213536)>>2]|0;
   $90 = (($89) + ($$1365))|0;
   HEAP32[(213536)>>2] = $90;
   HEAP32[(213548)>>2] = $$1;
   $91 = $90 | 1;
   $92 = ((($$1)) + 4|0);
   HEAP32[$92>>2] = $91;
   $93 = ($$1|0)==($88|0);
   if (!($93)) {
    return;
   }
   HEAP32[(213544)>>2] = 0;
   HEAP32[(213532)>>2] = 0;
   return;
  }
  $94 = ($2|0)==($88|0);
  if ($94) {
   $95 = HEAP32[(213532)>>2]|0;
   $96 = (($95) + ($$1365))|0;
   HEAP32[(213532)>>2] = $96;
   HEAP32[(213544)>>2] = $$1;
   $97 = $96 | 1;
   $98 = ((($$1)) + 4|0);
   HEAP32[$98>>2] = $97;
   $99 = (($$1) + ($96)|0);
   HEAP32[$99>>2] = $96;
   return;
  }
  $100 = $83 & -8;
  $101 = (($100) + ($$1365))|0;
  $102 = $83 >>> 3;
  $103 = ($83>>>0)<(256);
  do {
   if ($103) {
    $104 = ((($2)) + 8|0);
    $105 = HEAP32[$104>>2]|0;
    $106 = ((($2)) + 12|0);
    $107 = HEAP32[$106>>2]|0;
    $108 = ($107|0)==($105|0);
    if ($108) {
     $109 = 1 << $102;
     $110 = $109 ^ -1;
     $111 = HEAP32[53381]|0;
     $112 = $111 & $110;
     HEAP32[53381] = $112;
     break;
    } else {
     $113 = ((($105)) + 12|0);
     HEAP32[$113>>2] = $107;
     $114 = ((($107)) + 8|0);
     HEAP32[$114>>2] = $105;
     break;
    }
   } else {
    $115 = ((($2)) + 24|0);
    $116 = HEAP32[$115>>2]|0;
    $117 = ((($2)) + 12|0);
    $118 = HEAP32[$117>>2]|0;
    $119 = ($118|0)==($2|0);
    do {
     if ($119) {
      $124 = ((($2)) + 16|0);
      $125 = ((($124)) + 4|0);
      $126 = HEAP32[$125>>2]|0;
      $127 = ($126|0)==(0|0);
      if ($127) {
       $128 = HEAP32[$124>>2]|0;
       $129 = ($128|0)==(0|0);
       if ($129) {
        $$3382 = 0;
        break;
       } else {
        $$1380 = $128;$$1384 = $124;
       }
      } else {
       $$1380 = $126;$$1384 = $125;
      }
      while(1) {
       $130 = ((($$1380)) + 20|0);
       $131 = HEAP32[$130>>2]|0;
       $132 = ($131|0)==(0|0);
       if (!($132)) {
        $$1380 = $131;$$1384 = $130;
        continue;
       }
       $133 = ((($$1380)) + 16|0);
       $134 = HEAP32[$133>>2]|0;
       $135 = ($134|0)==(0|0);
       if ($135) {
        break;
       } else {
        $$1380 = $134;$$1384 = $133;
       }
      }
      HEAP32[$$1384>>2] = 0;
      $$3382 = $$1380;
     } else {
      $120 = ((($2)) + 8|0);
      $121 = HEAP32[$120>>2]|0;
      $122 = ((($121)) + 12|0);
      HEAP32[$122>>2] = $118;
      $123 = ((($118)) + 8|0);
      HEAP32[$123>>2] = $121;
      $$3382 = $118;
     }
    } while(0);
    $136 = ($116|0)==(0|0);
    if (!($136)) {
     $137 = ((($2)) + 28|0);
     $138 = HEAP32[$137>>2]|0;
     $139 = (213828 + ($138<<2)|0);
     $140 = HEAP32[$139>>2]|0;
     $141 = ($2|0)==($140|0);
     if ($141) {
      HEAP32[$139>>2] = $$3382;
      $cond5 = ($$3382|0)==(0|0);
      if ($cond5) {
       $142 = 1 << $138;
       $143 = $142 ^ -1;
       $144 = HEAP32[(213528)>>2]|0;
       $145 = $144 & $143;
       HEAP32[(213528)>>2] = $145;
       break;
      }
     } else {
      $146 = ((($116)) + 16|0);
      $147 = HEAP32[$146>>2]|0;
      $not$ = ($147|0)!=($2|0);
      $$sink4 = $not$&1;
      $148 = (((($116)) + 16|0) + ($$sink4<<2)|0);
      HEAP32[$148>>2] = $$3382;
      $149 = ($$3382|0)==(0|0);
      if ($149) {
       break;
      }
     }
     $150 = ((($$3382)) + 24|0);
     HEAP32[$150>>2] = $116;
     $151 = ((($2)) + 16|0);
     $152 = HEAP32[$151>>2]|0;
     $153 = ($152|0)==(0|0);
     if (!($153)) {
      $154 = ((($$3382)) + 16|0);
      HEAP32[$154>>2] = $152;
      $155 = ((($152)) + 24|0);
      HEAP32[$155>>2] = $$3382;
     }
     $156 = ((($151)) + 4|0);
     $157 = HEAP32[$156>>2]|0;
     $158 = ($157|0)==(0|0);
     if (!($158)) {
      $159 = ((($$3382)) + 20|0);
      HEAP32[$159>>2] = $157;
      $160 = ((($157)) + 24|0);
      HEAP32[$160>>2] = $$3382;
     }
    }
   }
  } while(0);
  $161 = $101 | 1;
  $162 = ((($$1)) + 4|0);
  HEAP32[$162>>2] = $161;
  $163 = (($$1) + ($101)|0);
  HEAP32[$163>>2] = $101;
  $164 = HEAP32[(213544)>>2]|0;
  $165 = ($$1|0)==($164|0);
  if ($165) {
   HEAP32[(213532)>>2] = $101;
   return;
  } else {
   $$2 = $101;
  }
 } else {
  $166 = $83 & -2;
  HEAP32[$82>>2] = $166;
  $167 = $$1365 | 1;
  $168 = ((($$1)) + 4|0);
  HEAP32[$168>>2] = $167;
  $169 = (($$1) + ($$1365)|0);
  HEAP32[$169>>2] = $$1365;
  $$2 = $$1365;
 }
 $170 = $$2 >>> 3;
 $171 = ($$2>>>0)<(256);
 if ($171) {
  $172 = $170 << 1;
  $173 = (213564 + ($172<<2)|0);
  $174 = HEAP32[53381]|0;
  $175 = 1 << $170;
  $176 = $174 & $175;
  $177 = ($176|0)==(0);
  if ($177) {
   $178 = $174 | $175;
   HEAP32[53381] = $178;
   $$pre = ((($173)) + 8|0);
   $$0385 = $173;$$pre$phiZ2D = $$pre;
  } else {
   $179 = ((($173)) + 8|0);
   $180 = HEAP32[$179>>2]|0;
   $$0385 = $180;$$pre$phiZ2D = $179;
  }
  HEAP32[$$pre$phiZ2D>>2] = $$1;
  $181 = ((($$0385)) + 12|0);
  HEAP32[$181>>2] = $$1;
  $182 = ((($$1)) + 8|0);
  HEAP32[$182>>2] = $$0385;
  $183 = ((($$1)) + 12|0);
  HEAP32[$183>>2] = $173;
  return;
 }
 $184 = $$2 >>> 8;
 $185 = ($184|0)==(0);
 if ($185) {
  $$0378 = 0;
 } else {
  $186 = ($$2>>>0)>(16777215);
  if ($186) {
   $$0378 = 31;
  } else {
   $187 = (($184) + 1048320)|0;
   $188 = $187 >>> 16;
   $189 = $188 & 8;
   $190 = $184 << $189;
   $191 = (($190) + 520192)|0;
   $192 = $191 >>> 16;
   $193 = $192 & 4;
   $194 = $193 | $189;
   $195 = $190 << $193;
   $196 = (($195) + 245760)|0;
   $197 = $196 >>> 16;
   $198 = $197 & 2;
   $199 = $194 | $198;
   $200 = (14 - ($199))|0;
   $201 = $195 << $198;
   $202 = $201 >>> 15;
   $203 = (($200) + ($202))|0;
   $204 = $203 << 1;
   $205 = (($203) + 7)|0;
   $206 = $$2 >>> $205;
   $207 = $206 & 1;
   $208 = $207 | $204;
   $$0378 = $208;
  }
 }
 $209 = (213828 + ($$0378<<2)|0);
 $210 = ((($$1)) + 28|0);
 HEAP32[$210>>2] = $$0378;
 $211 = ((($$1)) + 16|0);
 $212 = ((($$1)) + 20|0);
 HEAP32[$212>>2] = 0;
 HEAP32[$211>>2] = 0;
 $213 = HEAP32[(213528)>>2]|0;
 $214 = 1 << $$0378;
 $215 = $213 & $214;
 $216 = ($215|0)==(0);
 if ($216) {
  $217 = $213 | $214;
  HEAP32[(213528)>>2] = $217;
  HEAP32[$209>>2] = $$1;
  $218 = ((($$1)) + 24|0);
  HEAP32[$218>>2] = $209;
  $219 = ((($$1)) + 12|0);
  HEAP32[$219>>2] = $$1;
  $220 = ((($$1)) + 8|0);
  HEAP32[$220>>2] = $$1;
  return;
 }
 $221 = HEAP32[$209>>2]|0;
 $222 = ($$0378|0)==(31);
 $223 = $$0378 >>> 1;
 $224 = (25 - ($223))|0;
 $225 = $222 ? 0 : $224;
 $226 = $$2 << $225;
 $$0366 = $226;$$0367 = $221;
 while(1) {
  $227 = ((($$0367)) + 4|0);
  $228 = HEAP32[$227>>2]|0;
  $229 = $228 & -8;
  $230 = ($229|0)==($$2|0);
  if ($230) {
   label = 69;
   break;
  }
  $231 = $$0366 >>> 31;
  $232 = (((($$0367)) + 16|0) + ($231<<2)|0);
  $233 = $$0366 << 1;
  $234 = HEAP32[$232>>2]|0;
  $235 = ($234|0)==(0|0);
  if ($235) {
   label = 68;
   break;
  } else {
   $$0366 = $233;$$0367 = $234;
  }
 }
 if ((label|0) == 68) {
  HEAP32[$232>>2] = $$1;
  $236 = ((($$1)) + 24|0);
  HEAP32[$236>>2] = $$0367;
  $237 = ((($$1)) + 12|0);
  HEAP32[$237>>2] = $$1;
  $238 = ((($$1)) + 8|0);
  HEAP32[$238>>2] = $$1;
  return;
 }
 else if ((label|0) == 69) {
  $239 = ((($$0367)) + 8|0);
  $240 = HEAP32[$239>>2]|0;
  $241 = ((($240)) + 12|0);
  HEAP32[$241>>2] = $$1;
  HEAP32[$239>>2] = $$1;
  $242 = ((($$1)) + 8|0);
  HEAP32[$242>>2] = $240;
  $243 = ((($$1)) + 12|0);
  HEAP32[$243>>2] = $$0367;
  $244 = ((($$1)) + 24|0);
  HEAP32[$244>>2] = 0;
  return;
 }
}
function ___stdio_close($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $1 = ((($0)) + 60|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (_dummy($2)|0);
 HEAP32[$vararg_buffer>>2] = $3;
 $4 = (___syscall6(6,($vararg_buffer|0))|0);
 $5 = (___syscall_ret($4)|0);
 STACKTOP = sp;return ($5|0);
}
function ___stdout_write($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $vararg_buffer = sp;
 $3 = sp + 16|0;
 $4 = ((($0)) + 36|0);
 HEAP32[$4>>2] = 2905;
 $5 = HEAP32[$0>>2]|0;
 $6 = $5 & 64;
 $7 = ($6|0)==(0);
 if ($7) {
  $8 = ((($0)) + 60|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = $3;
  HEAP32[$vararg_buffer>>2] = $9;
  $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
  HEAP32[$vararg_ptr1>>2] = 21523;
  $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
  HEAP32[$vararg_ptr2>>2] = $10;
  $11 = (___syscall54(54,($vararg_buffer|0))|0);
  $12 = ($11|0)==(0);
  if (!($12)) {
   $13 = ((($0)) + 75|0);
   HEAP8[$13>>0] = -1;
  }
 }
 $14 = (___stdio_write($0,$1,$2)|0);
 STACKTOP = sp;return ($14|0);
}
function ___stdio_seek($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$pre = 0, $10 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, $vararg_ptr3 = 0, $vararg_ptr4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $vararg_buffer = sp;
 $3 = sp + 20|0;
 $4 = ((($0)) + 60|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $3;
 HEAP32[$vararg_buffer>>2] = $5;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 0;
 $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $1;
 $vararg_ptr3 = ((($vararg_buffer)) + 12|0);
 HEAP32[$vararg_ptr3>>2] = $6;
 $vararg_ptr4 = ((($vararg_buffer)) + 16|0);
 HEAP32[$vararg_ptr4>>2] = $2;
 $7 = (___syscall140(140,($vararg_buffer|0))|0);
 $8 = (___syscall_ret($7)|0);
 $9 = ($8|0)<(0);
 if ($9) {
  HEAP32[$3>>2] = -1;
  $10 = -1;
 } else {
  $$pre = HEAP32[$3>>2]|0;
  $10 = $$pre;
 }
 STACKTOP = sp;return ($10|0);
}
function ___syscall_ret($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ($0>>>0)>(4294963200);
 if ($1) {
  $2 = (0 - ($0))|0;
  $3 = (___errno_location()|0);
  HEAP32[$3>>2] = $2;
  $$0 = -1;
 } else {
  $$0 = $0;
 }
 return ($$0|0);
}
function ___errno_location() {
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (___pthread_self_882()|0);
 $1 = ((($0)) + 64|0);
 return ($1|0);
}
function ___pthread_self_882() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_pthread_self()|0);
 return ($0|0);
}
function _pthread_self() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (92232|0);
}
function ___stdio_write($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$04756 = 0, $$04855 = 0, $$04954 = 0, $$051 = 0, $$1 = 0, $$150 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer3 = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, $vararg_ptr6 = 0;
 var $vararg_ptr7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $vararg_buffer3 = sp + 16|0;
 $vararg_buffer = sp;
 $3 = sp + 32|0;
 $4 = ((($0)) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 HEAP32[$3>>2] = $5;
 $6 = ((($3)) + 4|0);
 $7 = ((($0)) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) - ($5))|0;
 HEAP32[$6>>2] = $9;
 $10 = ((($3)) + 8|0);
 HEAP32[$10>>2] = $1;
 $11 = ((($3)) + 12|0);
 HEAP32[$11>>2] = $2;
 $12 = (($9) + ($2))|0;
 $13 = ((($0)) + 60|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $3;
 HEAP32[$vararg_buffer>>2] = $14;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $15;
 $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
 HEAP32[$vararg_ptr2>>2] = 2;
 $16 = (___syscall146(146,($vararg_buffer|0))|0);
 $17 = (___syscall_ret($16)|0);
 $18 = ($12|0)==($17|0);
 L1: do {
  if ($18) {
   label = 3;
  } else {
   $$04756 = 2;$$04855 = $12;$$04954 = $3;$25 = $17;
   while(1) {
    $26 = ($25|0)<(0);
    if ($26) {
     break;
    }
    $34 = (($$04855) - ($25))|0;
    $35 = ((($$04954)) + 4|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = ($25>>>0)>($36>>>0);
    $38 = ((($$04954)) + 8|0);
    $$150 = $37 ? $38 : $$04954;
    $39 = $37 << 31 >> 31;
    $$1 = (($39) + ($$04756))|0;
    $40 = $37 ? $36 : 0;
    $$0 = (($25) - ($40))|0;
    $41 = HEAP32[$$150>>2]|0;
    $42 = (($41) + ($$0)|0);
    HEAP32[$$150>>2] = $42;
    $43 = ((($$150)) + 4|0);
    $44 = HEAP32[$43>>2]|0;
    $45 = (($44) - ($$0))|0;
    HEAP32[$43>>2] = $45;
    $46 = HEAP32[$13>>2]|0;
    $47 = $$150;
    HEAP32[$vararg_buffer3>>2] = $46;
    $vararg_ptr6 = ((($vararg_buffer3)) + 4|0);
    HEAP32[$vararg_ptr6>>2] = $47;
    $vararg_ptr7 = ((($vararg_buffer3)) + 8|0);
    HEAP32[$vararg_ptr7>>2] = $$1;
    $48 = (___syscall146(146,($vararg_buffer3|0))|0);
    $49 = (___syscall_ret($48)|0);
    $50 = ($34|0)==($49|0);
    if ($50) {
     label = 3;
     break L1;
    } else {
     $$04756 = $$1;$$04855 = $34;$$04954 = $$150;$25 = $49;
    }
   }
   $27 = ((($0)) + 16|0);
   HEAP32[$27>>2] = 0;
   HEAP32[$4>>2] = 0;
   HEAP32[$7>>2] = 0;
   $28 = HEAP32[$0>>2]|0;
   $29 = $28 | 32;
   HEAP32[$0>>2] = $29;
   $30 = ($$04756|0)==(2);
   if ($30) {
    $$051 = 0;
   } else {
    $31 = ((($$04954)) + 4|0);
    $32 = HEAP32[$31>>2]|0;
    $33 = (($2) - ($32))|0;
    $$051 = $33;
   }
  }
 } while(0);
 if ((label|0) == 3) {
  $19 = ((($0)) + 44|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = ((($0)) + 48|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = (($20) + ($22)|0);
  $24 = ((($0)) + 16|0);
  HEAP32[$24>>2] = $23;
  HEAP32[$4>>2] = $20;
  HEAP32[$7>>2] = $20;
  $$051 = $2;
 }
 STACKTOP = sp;return ($$051|0);
}
function _dummy($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ($0|0);
}
function ___stdio_read($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $vararg_buffer = sp;
 $3 = sp + 16|0;
 HEAP32[$3>>2] = $1;
 $4 = ((($3)) + 4|0);
 $5 = ((($0)) + 48|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)!=(0);
 $8 = $7&1;
 $9 = (($2) - ($8))|0;
 HEAP32[$4>>2] = $9;
 $10 = ((($3)) + 8|0);
 $11 = ((($0)) + 44|0);
 $12 = HEAP32[$11>>2]|0;
 HEAP32[$10>>2] = $12;
 $13 = ((($3)) + 12|0);
 HEAP32[$13>>2] = $6;
 $14 = ((($0)) + 60|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = $3;
 HEAP32[$vararg_buffer>>2] = $15;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $16;
 $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
 HEAP32[$vararg_ptr2>>2] = 2;
 $17 = (___syscall145(145,($vararg_buffer|0))|0);
 $18 = (___syscall_ret($17)|0);
 $19 = ($18|0)<(1);
 if ($19) {
  $20 = $18 & 48;
  $21 = $20 ^ 16;
  $22 = HEAP32[$0>>2]|0;
  $23 = $22 | $21;
  HEAP32[$0>>2] = $23;
  $$0 = $18;
 } else {
  $24 = HEAP32[$4>>2]|0;
  $25 = ($18>>>0)>($24>>>0);
  if ($25) {
   $26 = (($18) - ($24))|0;
   $27 = HEAP32[$11>>2]|0;
   $28 = ((($0)) + 4|0);
   HEAP32[$28>>2] = $27;
   $29 = (($27) + ($26)|0);
   $30 = ((($0)) + 8|0);
   HEAP32[$30>>2] = $29;
   $31 = HEAP32[$5>>2]|0;
   $32 = ($31|0)==(0);
   if ($32) {
    $$0 = $2;
   } else {
    $33 = ((($27)) + 1|0);
    HEAP32[$28>>2] = $33;
    $34 = HEAP8[$27>>0]|0;
    $35 = (($2) + -1)|0;
    $36 = (($1) + ($35)|0);
    HEAP8[$36>>0] = $34;
    $$0 = $2;
   }
  } else {
   $$0 = $18;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function _emscripten_get_global_libc() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (214020|0);
}
function _strtoull($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (_strtox($0,$1,$2,-1,-1)|0);
 $4 = tempRet0;
 tempRet0 = ($4);
 return ($3|0);
}
function _strtox($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$sink = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(128|0);
 $5 = sp;
 HEAP32[$5>>2] = 0;
 $6 = ((($5)) + 4|0);
 HEAP32[$6>>2] = $0;
 $7 = ((($5)) + 44|0);
 HEAP32[$7>>2] = $0;
 $8 = ($0|0)<(0|0);
 $9 = ((($0)) + 2147483647|0);
 $$sink = $8 ? (-1) : $9;
 $10 = ((($5)) + 8|0);
 HEAP32[$10>>2] = $$sink;
 $11 = ((($5)) + 76|0);
 HEAP32[$11>>2] = -1;
 ___shlim($5,0);
 $12 = (___intscan($5,$2,1,$3,$4)|0);
 $13 = tempRet0;
 $14 = ($1|0)==(0|0);
 if (!($14)) {
  $15 = ((($5)) + 108|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = HEAP32[$6>>2]|0;
  $18 = HEAP32[$10>>2]|0;
  $19 = (($17) + ($16))|0;
  $20 = (($19) - ($18))|0;
  $21 = (($0) + ($20)|0);
  HEAP32[$1>>2] = $21;
 }
 tempRet0 = ($13);
 STACKTOP = sp;return ($12|0);
}
function ___shlim($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$sink = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 104|0);
 HEAP32[$2>>2] = $1;
 $3 = ((($0)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $4;
 $8 = $6;
 $9 = (($7) - ($8))|0;
 $10 = ((($0)) + 108|0);
 HEAP32[$10>>2] = $9;
 $11 = ($1|0)!=(0);
 $12 = ($9|0)>($1|0);
 $or$cond = $11 & $12;
 $13 = (($6) + ($1)|0);
 $$sink = $or$cond ? $13 : $4;
 $14 = ((($0)) + 100|0);
 HEAP32[$14>>2] = $$sink;
 return;
}
function ___intscan($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0154222 = 0, $$0157 = 0, $$0157$ = 0, $$0159 = 0, $$1155192 = 0, $$1158 = 0, $$1160 = 0, $$1160169 = 0, $$1165 = 0, $$1165167 = 0, $$1165168 = 0, $$166 = 0, $$2156210 = 0, $$2161$be = 0, $$2161$lcssa = 0, $$3162$be = 0, $$3162215 = 0, $$4163$be = 0, $$4163$lcssa = 0, $$5$be = 0;
 var $$6$be = 0, $$6$lcssa = 0, $$7$be = 0, $$7198 = 0, $$8 = 0, $$9$be = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0;
 var $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0;
 var $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0;
 var $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0;
 var $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0;
 var $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0;
 var $294 = 0, $295 = 0, $296 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $or$cond12 = 0;
 var $or$cond187 = 0, $or$cond5 = 0, $or$cond7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = ($1>>>0)>(36);
 L1: do {
  if ($5) {
   $8 = (___errno_location()|0);
   HEAP32[$8>>2] = 22;
   $289 = 0;$290 = 0;
  } else {
   $6 = ((($0)) + 4|0);
   $7 = ((($0)) + 100|0);
   while(1) {
    $9 = HEAP32[$6>>2]|0;
    $10 = HEAP32[$7>>2]|0;
    $11 = ($9>>>0)<($10>>>0);
    if ($11) {
     $12 = ((($9)) + 1|0);
     HEAP32[$6>>2] = $12;
     $13 = HEAP8[$9>>0]|0;
     $14 = $13&255;
     $16 = $14;
    } else {
     $15 = (___shgetc($0)|0);
     $16 = $15;
    }
    $17 = (_isspace($16)|0);
    $18 = ($17|0)==(0);
    if ($18) {
     break;
    }
   }
   L11: do {
    switch ($16|0) {
    case 43: case 45:  {
     $19 = ($16|0)==(45);
     $20 = $19 << 31 >> 31;
     $21 = HEAP32[$6>>2]|0;
     $22 = HEAP32[$7>>2]|0;
     $23 = ($21>>>0)<($22>>>0);
     if ($23) {
      $24 = ((($21)) + 1|0);
      HEAP32[$6>>2] = $24;
      $25 = HEAP8[$21>>0]|0;
      $26 = $25&255;
      $$0157 = $20;$$0159 = $26;
      break L11;
     } else {
      $27 = (___shgetc($0)|0);
      $$0157 = $20;$$0159 = $27;
      break L11;
     }
     break;
    }
    default: {
     $$0157 = 0;$$0159 = $16;
    }
    }
   } while(0);
   $28 = ($1|0)==(0);
   $29 = $1 | 16;
   $30 = ($29|0)==(16);
   $31 = ($$0159|0)==(48);
   $or$cond5 = $30 & $31;
   do {
    if ($or$cond5) {
     $32 = HEAP32[$6>>2]|0;
     $33 = HEAP32[$7>>2]|0;
     $34 = ($32>>>0)<($33>>>0);
     if ($34) {
      $35 = ((($32)) + 1|0);
      HEAP32[$6>>2] = $35;
      $36 = HEAP8[$32>>0]|0;
      $37 = $36&255;
      $40 = $37;
     } else {
      $38 = (___shgetc($0)|0);
      $40 = $38;
     }
     $39 = $40 | 32;
     $41 = ($39|0)==(120);
     if (!($41)) {
      if ($28) {
       $$1160169 = $40;$$1165168 = 8;
       label = 46;
       break;
      } else {
       $$1160 = $40;$$1165 = $1;
       label = 32;
       break;
      }
     }
     $42 = HEAP32[$6>>2]|0;
     $43 = HEAP32[$7>>2]|0;
     $44 = ($42>>>0)<($43>>>0);
     if ($44) {
      $45 = ((($42)) + 1|0);
      HEAP32[$6>>2] = $45;
      $46 = HEAP8[$42>>0]|0;
      $47 = $46&255;
      $50 = $47;
     } else {
      $48 = (___shgetc($0)|0);
      $50 = $48;
     }
     $49 = ((199033) + ($50)|0);
     $51 = HEAP8[$49>>0]|0;
     $52 = ($51&255)>(15);
     if ($52) {
      $53 = HEAP32[$7>>2]|0;
      $54 = ($53|0)!=(0|0);
      if ($54) {
       $55 = HEAP32[$6>>2]|0;
       $56 = ((($55)) + -1|0);
       HEAP32[$6>>2] = $56;
      }
      $57 = ($2|0)==(0);
      if ($57) {
       ___shlim($0,0);
       $289 = 0;$290 = 0;
       break L1;
      }
      if (!($54)) {
       $289 = 0;$290 = 0;
       break L1;
      }
      $58 = HEAP32[$6>>2]|0;
      $59 = ((($58)) + -1|0);
      HEAP32[$6>>2] = $59;
      $289 = 0;$290 = 0;
      break L1;
     } else {
      $$1160169 = $50;$$1165168 = 16;
      label = 46;
     }
    } else {
     $$166 = $28 ? 10 : $1;
     $60 = ((199033) + ($$0159)|0);
     $61 = HEAP8[$60>>0]|0;
     $62 = $61&255;
     $63 = ($62>>>0)<($$166>>>0);
     if ($63) {
      $$1160 = $$0159;$$1165 = $$166;
      label = 32;
     } else {
      $64 = HEAP32[$7>>2]|0;
      $65 = ($64|0)==(0|0);
      if (!($65)) {
       $66 = HEAP32[$6>>2]|0;
       $67 = ((($66)) + -1|0);
       HEAP32[$6>>2] = $67;
      }
      ___shlim($0,0);
      $68 = (___errno_location()|0);
      HEAP32[$68>>2] = 22;
      $289 = 0;$290 = 0;
      break L1;
     }
    }
   } while(0);
   L43: do {
    if ((label|0) == 32) {
     $69 = ($$1165|0)==(10);
     if ($69) {
      $70 = (($$1160) + -48)|0;
      $71 = ($70>>>0)<(10);
      if ($71) {
       $$0154222 = 0;$74 = $70;
       while(1) {
        $72 = ($$0154222*10)|0;
        $73 = (($72) + ($74))|0;
        $75 = HEAP32[$6>>2]|0;
        $76 = HEAP32[$7>>2]|0;
        $77 = ($75>>>0)<($76>>>0);
        if ($77) {
         $78 = ((($75)) + 1|0);
         HEAP32[$6>>2] = $78;
         $79 = HEAP8[$75>>0]|0;
         $80 = $79&255;
         $$2161$be = $80;
        } else {
         $81 = (___shgetc($0)|0);
         $$2161$be = $81;
        }
        $82 = (($$2161$be) + -48)|0;
        $83 = ($82>>>0)<(10);
        $84 = ($73>>>0)<(429496729);
        $85 = $83 & $84;
        if ($85) {
         $$0154222 = $73;$74 = $82;
        } else {
         break;
        }
       }
       $$2161$lcssa = $$2161$be;$291 = $73;$292 = 0;
      } else {
       $$2161$lcssa = $$1160;$291 = 0;$292 = 0;
      }
      $86 = (($$2161$lcssa) + -48)|0;
      $87 = ($86>>>0)<(10);
      if ($87) {
       $$3162215 = $$2161$lcssa;$88 = $291;$89 = $292;$92 = $86;
       while(1) {
        $90 = (___muldi3(($88|0),($89|0),10,0)|0);
        $91 = tempRet0;
        $93 = ($92|0)<(0);
        $94 = $93 << 31 >> 31;
        $95 = $92 ^ -1;
        $96 = $94 ^ -1;
        $97 = ($91>>>0)>($96>>>0);
        $98 = ($90>>>0)>($95>>>0);
        $99 = ($91|0)==($96|0);
        $100 = $99 & $98;
        $101 = $97 | $100;
        if ($101) {
         $$1165167 = 10;$$8 = $$3162215;$293 = $88;$294 = $89;
         label = 72;
         break L43;
        }
        $102 = (_i64Add(($90|0),($91|0),($92|0),($94|0))|0);
        $103 = tempRet0;
        $104 = HEAP32[$6>>2]|0;
        $105 = HEAP32[$7>>2]|0;
        $106 = ($104>>>0)<($105>>>0);
        if ($106) {
         $107 = ((($104)) + 1|0);
         HEAP32[$6>>2] = $107;
         $108 = HEAP8[$104>>0]|0;
         $109 = $108&255;
         $$3162$be = $109;
        } else {
         $110 = (___shgetc($0)|0);
         $$3162$be = $110;
        }
        $111 = (($$3162$be) + -48)|0;
        $112 = ($111>>>0)<(10);
        $113 = ($103>>>0)<(429496729);
        $114 = ($102>>>0)<(2576980378);
        $115 = ($103|0)==(429496729);
        $116 = $115 & $114;
        $117 = $113 | $116;
        $or$cond7 = $112 & $117;
        if ($or$cond7) {
         $$3162215 = $$3162$be;$88 = $102;$89 = $103;$92 = $111;
        } else {
         break;
        }
       }
       $118 = ($111>>>0)>(9);
       if ($118) {
        $$1158 = $$0157;$262 = $103;$264 = $102;
       } else {
        $$1165167 = 10;$$8 = $$3162$be;$293 = $102;$294 = $103;
        label = 72;
       }
      } else {
       $$1158 = $$0157;$262 = $292;$264 = $291;
      }
     } else {
      $$1160169 = $$1160;$$1165168 = $$1165;
      label = 46;
     }
    }
   } while(0);
   L63: do {
    if ((label|0) == 46) {
     $119 = (($$1165168) + -1)|0;
     $120 = $119 & $$1165168;
     $121 = ($120|0)==(0);
     if ($121) {
      $126 = ($$1165168*23)|0;
      $127 = $126 >>> 5;
      $128 = $127 & 7;
      $129 = (199289 + ($128)|0);
      $130 = HEAP8[$129>>0]|0;
      $131 = $130 << 24 >> 24;
      $132 = ((199033) + ($$1160169)|0);
      $133 = HEAP8[$132>>0]|0;
      $134 = $133&255;
      $135 = ($134>>>0)<($$1165168>>>0);
      if ($135) {
       $$1155192 = 0;$138 = $134;
       while(1) {
        $136 = $$1155192 << $131;
        $137 = $138 | $136;
        $139 = HEAP32[$6>>2]|0;
        $140 = HEAP32[$7>>2]|0;
        $141 = ($139>>>0)<($140>>>0);
        if ($141) {
         $142 = ((($139)) + 1|0);
         HEAP32[$6>>2] = $142;
         $143 = HEAP8[$139>>0]|0;
         $144 = $143&255;
         $$4163$be = $144;
        } else {
         $145 = (___shgetc($0)|0);
         $$4163$be = $145;
        }
        $146 = ((199033) + ($$4163$be)|0);
        $147 = HEAP8[$146>>0]|0;
        $148 = $147&255;
        $149 = ($148>>>0)<($$1165168>>>0);
        $150 = ($137>>>0)<(134217728);
        $151 = $150 & $149;
        if ($151) {
         $$1155192 = $137;$138 = $148;
        } else {
         break;
        }
       }
       $$4163$lcssa = $$4163$be;$155 = $147;$157 = 0;$159 = $137;
      } else {
       $$4163$lcssa = $$1160169;$155 = $133;$157 = 0;$159 = 0;
      }
      $152 = (_bitshift64Lshr(-1,-1,($131|0))|0);
      $153 = tempRet0;
      $154 = $155&255;
      $156 = ($154>>>0)>=($$1165168>>>0);
      $158 = ($157>>>0)>($153>>>0);
      $160 = ($159>>>0)>($152>>>0);
      $161 = ($157|0)==($153|0);
      $162 = $161 & $160;
      $163 = $158 | $162;
      $or$cond187 = $156 | $163;
      if ($or$cond187) {
       $$1165167 = $$1165168;$$8 = $$4163$lcssa;$293 = $159;$294 = $157;
       label = 72;
       break;
      } else {
       $164 = $159;$165 = $157;$169 = $155;
      }
      while(1) {
       $166 = (_bitshift64Shl(($164|0),($165|0),($131|0))|0);
       $167 = tempRet0;
       $168 = $169&255;
       $170 = $168 | $166;
       $171 = HEAP32[$6>>2]|0;
       $172 = HEAP32[$7>>2]|0;
       $173 = ($171>>>0)<($172>>>0);
       if ($173) {
        $174 = ((($171)) + 1|0);
        HEAP32[$6>>2] = $174;
        $175 = HEAP8[$171>>0]|0;
        $176 = $175&255;
        $$5$be = $176;
       } else {
        $177 = (___shgetc($0)|0);
        $$5$be = $177;
       }
       $178 = ((199033) + ($$5$be)|0);
       $179 = HEAP8[$178>>0]|0;
       $180 = $179&255;
       $181 = ($180>>>0)>=($$1165168>>>0);
       $182 = ($167>>>0)>($153>>>0);
       $183 = ($170>>>0)>($152>>>0);
       $184 = ($167|0)==($153|0);
       $185 = $184 & $183;
       $186 = $182 | $185;
       $or$cond = $181 | $186;
       if ($or$cond) {
        $$1165167 = $$1165168;$$8 = $$5$be;$293 = $170;$294 = $167;
        label = 72;
        break L63;
       } else {
        $164 = $170;$165 = $167;$169 = $179;
       }
      }
     }
     $122 = ((199033) + ($$1160169)|0);
     $123 = HEAP8[$122>>0]|0;
     $124 = $123&255;
     $125 = ($124>>>0)<($$1165168>>>0);
     if ($125) {
      $$2156210 = 0;$189 = $124;
      while(1) {
       $187 = Math_imul($$2156210, $$1165168)|0;
       $188 = (($189) + ($187))|0;
       $190 = HEAP32[$6>>2]|0;
       $191 = HEAP32[$7>>2]|0;
       $192 = ($190>>>0)<($191>>>0);
       if ($192) {
        $193 = ((($190)) + 1|0);
        HEAP32[$6>>2] = $193;
        $194 = HEAP8[$190>>0]|0;
        $195 = $194&255;
        $$6$be = $195;
       } else {
        $196 = (___shgetc($0)|0);
        $$6$be = $196;
       }
       $197 = ((199033) + ($$6$be)|0);
       $198 = HEAP8[$197>>0]|0;
       $199 = $198&255;
       $200 = ($199>>>0)<($$1165168>>>0);
       $201 = ($188>>>0)<(119304647);
       $202 = $201 & $200;
       if ($202) {
        $$2156210 = $188;$189 = $199;
       } else {
        break;
       }
      }
      $$6$lcssa = $$6$be;$204 = $198;$295 = $188;$296 = 0;
     } else {
      $$6$lcssa = $$1160169;$204 = $123;$295 = 0;$296 = 0;
     }
     $203 = $204&255;
     $205 = ($203>>>0)<($$1165168>>>0);
     if ($205) {
      $206 = (___udivdi3(-1,-1,($$1165168|0),0)|0);
      $207 = tempRet0;
      $$7198 = $$6$lcssa;$208 = $296;$210 = $295;$218 = $204;
      while(1) {
       $209 = ($208>>>0)>($207>>>0);
       $211 = ($210>>>0)>($206>>>0);
       $212 = ($208|0)==($207|0);
       $213 = $212 & $211;
       $214 = $209 | $213;
       if ($214) {
        $$1165167 = $$1165168;$$8 = $$7198;$293 = $210;$294 = $208;
        label = 72;
        break L63;
       }
       $215 = (___muldi3(($210|0),($208|0),($$1165168|0),0)|0);
       $216 = tempRet0;
       $217 = $218&255;
       $219 = $217 ^ -1;
       $220 = ($216>>>0)>(4294967295);
       $221 = ($215>>>0)>($219>>>0);
       $222 = ($216|0)==(-1);
       $223 = $222 & $221;
       $224 = $220 | $223;
       if ($224) {
        $$1165167 = $$1165168;$$8 = $$7198;$293 = $210;$294 = $208;
        label = 72;
        break L63;
       }
       $225 = (_i64Add(($217|0),0,($215|0),($216|0))|0);
       $226 = tempRet0;
       $227 = HEAP32[$6>>2]|0;
       $228 = HEAP32[$7>>2]|0;
       $229 = ($227>>>0)<($228>>>0);
       if ($229) {
        $230 = ((($227)) + 1|0);
        HEAP32[$6>>2] = $230;
        $231 = HEAP8[$227>>0]|0;
        $232 = $231&255;
        $$7$be = $232;
       } else {
        $233 = (___shgetc($0)|0);
        $$7$be = $233;
       }
       $234 = ((199033) + ($$7$be)|0);
       $235 = HEAP8[$234>>0]|0;
       $236 = $235&255;
       $237 = ($236>>>0)<($$1165168>>>0);
       if ($237) {
        $$7198 = $$7$be;$208 = $226;$210 = $225;$218 = $235;
       } else {
        $$1165167 = $$1165168;$$8 = $$7$be;$293 = $225;$294 = $226;
        label = 72;
        break;
       }
      }
     } else {
      $$1165167 = $$1165168;$$8 = $$6$lcssa;$293 = $295;$294 = $296;
      label = 72;
     }
    }
   } while(0);
   if ((label|0) == 72) {
    $238 = ((199033) + ($$8)|0);
    $239 = HEAP8[$238>>0]|0;
    $240 = $239&255;
    $241 = ($240>>>0)<($$1165167>>>0);
    if ($241) {
     while(1) {
      $242 = HEAP32[$6>>2]|0;
      $243 = HEAP32[$7>>2]|0;
      $244 = ($242>>>0)<($243>>>0);
      if ($244) {
       $245 = ((($242)) + 1|0);
       HEAP32[$6>>2] = $245;
       $246 = HEAP8[$242>>0]|0;
       $247 = $246&255;
       $$9$be = $247;
      } else {
       $248 = (___shgetc($0)|0);
       $$9$be = $248;
      }
      $249 = ((199033) + ($$9$be)|0);
      $250 = HEAP8[$249>>0]|0;
      $251 = $250&255;
      $252 = ($251>>>0)<($$1165167>>>0);
      if (!($252)) {
       break;
      }
     }
     $253 = (___errno_location()|0);
     HEAP32[$253>>2] = 34;
     $254 = $3 & 1;
     $255 = ($254|0)==(0);
     $256 = (0)==(0);
     $257 = $255 & $256;
     $$0157$ = $257 ? $$0157 : 0;
     $$1158 = $$0157$;$262 = $4;$264 = $3;
    } else {
     $$1158 = $$0157;$262 = $294;$264 = $293;
    }
   }
   $258 = HEAP32[$7>>2]|0;
   $259 = ($258|0)==(0|0);
   if (!($259)) {
    $260 = HEAP32[$6>>2]|0;
    $261 = ((($260)) + -1|0);
    HEAP32[$6>>2] = $261;
   }
   $263 = ($262>>>0)<($4>>>0);
   $265 = ($264>>>0)<($3>>>0);
   $266 = ($262|0)==($4|0);
   $267 = $266 & $265;
   $268 = $263 | $267;
   if (!($268)) {
    $269 = $3 & 1;
    $270 = ($269|0)!=(0);
    $271 = (0)!=(0);
    $272 = $270 | $271;
    $273 = ($$1158|0)!=(0);
    $or$cond12 = $272 | $273;
    if (!($or$cond12)) {
     $274 = (___errno_location()|0);
     HEAP32[$274>>2] = 34;
     $275 = (_i64Add(($3|0),($4|0),-1,-1)|0);
     $276 = tempRet0;
     $289 = $276;$290 = $275;
     break;
    }
    $277 = ($262>>>0)>($4>>>0);
    $278 = ($264>>>0)>($3>>>0);
    $279 = ($262|0)==($4|0);
    $280 = $279 & $278;
    $281 = $277 | $280;
    if ($281) {
     $282 = (___errno_location()|0);
     HEAP32[$282>>2] = 34;
     $289 = $4;$290 = $3;
     break;
    }
   }
   $283 = ($$1158|0)<(0);
   $284 = $283 << 31 >> 31;
   $285 = $264 ^ $$1158;
   $286 = $262 ^ $284;
   $287 = (_i64Subtract(($285|0),($286|0),($$1158|0),($284|0))|0);
   $288 = tempRet0;
   $289 = $288;$290 = $287;
  }
 } while(0);
 tempRet0 = ($289);
 return ($290|0);
}
function ___shgetc($0) {
 $0 = $0|0;
 var $$0 = 0, $$phi$trans$insert = 0, $$phi$trans$insert28$phi$trans$insert = 0, $$pre = 0, $$pre$phi34Z2D = 0, $$pre29$pre = 0, $$pre35 = 0, $$sink = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 104|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  label = 3;
 } else {
  $4 = ((($0)) + 108|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)<($2|0);
  if ($6) {
   label = 3;
  } else {
   label = 4;
  }
 }
 if ((label|0) == 3) {
  $7 = (___uflow($0)|0);
  $8 = ($7|0)<(0);
  if ($8) {
   label = 4;
  } else {
   $10 = HEAP32[$1>>2]|0;
   $11 = ($10|0)==(0);
   $$phi$trans$insert = ((($0)) + 8|0);
   if ($11) {
    $$pre = HEAP32[$$phi$trans$insert>>2]|0;
    $$phi$trans$insert28$phi$trans$insert = ((($0)) + 4|0);
    $$pre29$pre = HEAP32[$$phi$trans$insert28$phi$trans$insert>>2]|0;
    $$pre35 = ((($0)) + 108|0);
    $$pre$phi34Z2D = $$pre35;$$sink = $$pre;$25 = $$pre;$28 = $$pre29$pre;
   } else {
    $12 = HEAP32[$$phi$trans$insert>>2]|0;
    $13 = ((($0)) + 4|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = $14;
    $16 = (($12) - ($15))|0;
    $17 = ((($0)) + 108|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = (($10) - ($18))|0;
    $20 = ($16|0)<($19|0);
    $21 = $12;
    if ($20) {
     $$pre$phi34Z2D = $17;$$sink = $21;$25 = $21;$28 = $14;
    } else {
     $22 = (($19) + -1)|0;
     $23 = (($14) + ($22)|0);
     $$pre$phi34Z2D = $17;$$sink = $23;$25 = $21;$28 = $14;
    }
   }
   $24 = ((($0)) + 100|0);
   HEAP32[$24>>2] = $$sink;
   $26 = ($25|0)==(0|0);
   if (!($26)) {
    $27 = $25;
    $29 = $28;
    $30 = HEAP32[$$pre$phi34Z2D>>2]|0;
    $31 = (($27) + 1)|0;
    $32 = (($31) - ($29))|0;
    $33 = (($32) + ($30))|0;
    HEAP32[$$pre$phi34Z2D>>2] = $33;
   }
   $34 = ((($28)) + -1|0);
   $35 = HEAP8[$34>>0]|0;
   $36 = $35&255;
   $37 = ($36|0)==($7|0);
   if ($37) {
    $$0 = $7;
   } else {
    $38 = $7&255;
    HEAP8[$34>>0] = $38;
    $$0 = $7;
   }
  }
 }
 if ((label|0) == 4) {
  $9 = ((($0)) + 100|0);
  HEAP32[$9>>2] = 0;
  $$0 = -1;
 }
 return ($$0|0);
}
function _isspace($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ($0|0)==(32);
 $2 = (($0) + -9)|0;
 $3 = ($2>>>0)<(5);
 $4 = $1 | $3;
 $5 = $4&1;
 return ($5|0);
}
function ___uflow($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $2 = (___toread($0)|0);
 $3 = ($2|0)==(0);
 if ($3) {
  $4 = ((($0)) + 32|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (FUNCTION_TABLE_iiii[$5 & 8191]($0,$1,1)|0);
  $7 = ($6|0)==(1);
  if ($7) {
   $8 = HEAP8[$1>>0]|0;
   $9 = $8&255;
   $$0 = $9;
  } else {
   $$0 = -1;
  }
 } else {
  $$0 = -1;
 }
 STACKTOP = sp;return ($$0|0);
}
function ___toread($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $sext = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 74|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = $2 << 24 >> 24;
 $4 = (($3) + 255)|0;
 $5 = $4 | $3;
 $6 = $5&255;
 HEAP8[$1>>0] = $6;
 $7 = ((($0)) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($0)) + 28|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8>>>0)>($10>>>0);
 if ($11) {
  $12 = ((($0)) + 36|0);
  $13 = HEAP32[$12>>2]|0;
  (FUNCTION_TABLE_iiii[$13 & 8191]($0,0,0)|0);
 }
 $14 = ((($0)) + 16|0);
 HEAP32[$14>>2] = 0;
 HEAP32[$9>>2] = 0;
 HEAP32[$7>>2] = 0;
 $15 = HEAP32[$0>>2]|0;
 $16 = $15 & 4;
 $17 = ($16|0)==(0);
 if ($17) {
  $19 = ((($0)) + 44|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = ((($0)) + 48|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = (($20) + ($22)|0);
  $24 = ((($0)) + 8|0);
  HEAP32[$24>>2] = $23;
  $25 = ((($0)) + 4|0);
  HEAP32[$25>>2] = $23;
  $26 = $15 << 27;
  $sext = $26 >> 31;
  $$0 = $sext;
 } else {
  $18 = $15 | 32;
  HEAP32[$0>>2] = $18;
  $$0 = -1;
 }
 return ($$0|0);
}
function _strtoll($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (_strtox($0,$1,$2,0,-2147483648)|0);
 $4 = tempRet0;
 tempRet0 = ($4);
 return ($3|0);
}
function _strtol($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (_strtox($0,$1,$2,-2147483648,0)|0);
 $4 = tempRet0;
 return ($3|0);
}
function _qsort($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $$067$lcssa = 0, $$06772 = 0, $$068$lcssa = 0, $$06871 = 0, $$1 = 0, $$169 = 0, $$2 = 0, $$pre$pre = 0, $$pre76 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $15$phi = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 208|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(208|0);
 $4 = sp + 8|0;
 $5 = sp;
 $6 = Math_imul($2, $1)|0;
 $7 = $5;
 $8 = $7;
 HEAP32[$8>>2] = 1;
 $9 = (($7) + 4)|0;
 $10 = $9;
 HEAP32[$10>>2] = 0;
 $11 = ($6|0)==(0);
 L1: do {
  if (!($11)) {
   $12 = (0 - ($2))|0;
   $13 = ((($4)) + 4|0);
   HEAP32[$13>>2] = $2;
   HEAP32[$4>>2] = $2;
   $$0 = 2;$15 = $2;$17 = $2;
   while(1) {
    $14 = (($15) + ($2))|0;
    $16 = (($14) + ($17))|0;
    $18 = (($4) + ($$0<<2)|0);
    HEAP32[$18>>2] = $16;
    $19 = ($16>>>0)<($6>>>0);
    $20 = (($$0) + 1)|0;
    if ($19) {
     $15$phi = $17;$$0 = $20;$17 = $16;$15 = $15$phi;
    } else {
     break;
    }
   }
   $21 = (($0) + ($6)|0);
   $22 = (($21) + ($12)|0);
   $23 = ($22>>>0)>($0>>>0);
   if ($23) {
    $24 = $22;
    $$06772 = 1;$$06871 = $0;$26 = 1;
    while(1) {
     $25 = $26 & 3;
     $27 = ($25|0)==(3);
     do {
      if ($27) {
       _sift($$06871,$2,$3,$$06772,$4);
       _shr($5,2);
       $28 = (($$06772) + 2)|0;
       $$1 = $28;
      } else {
       $29 = (($$06772) + -1)|0;
       $30 = (($4) + ($29<<2)|0);
       $31 = HEAP32[$30>>2]|0;
       $32 = $$06871;
       $33 = (($24) - ($32))|0;
       $34 = ($31>>>0)<($33>>>0);
       if ($34) {
        _sift($$06871,$2,$3,$$06772,$4);
       } else {
        _trinkle($$06871,$2,$3,$5,$$06772,0,$4);
       }
       $35 = ($$06772|0)==(1);
       if ($35) {
        _shl($5,1);
        $$1 = 0;
        break;
       } else {
        _shl($5,$29);
        $$1 = 1;
        break;
       }
      }
     } while(0);
     $36 = HEAP32[$5>>2]|0;
     $37 = $36 | 1;
     HEAP32[$5>>2] = $37;
     $38 = (($$06871) + ($2)|0);
     $39 = ($38>>>0)<($22>>>0);
     if ($39) {
      $$06772 = $$1;$$06871 = $38;$26 = $37;
     } else {
      $$067$lcssa = $$1;$$068$lcssa = $38;$61 = $37;
      break;
     }
    }
   } else {
    $$067$lcssa = 1;$$068$lcssa = $0;$61 = 1;
   }
   _trinkle($$068$lcssa,$2,$3,$5,$$067$lcssa,0,$4);
   $40 = ((($5)) + 4|0);
   $$169 = $$068$lcssa;$$2 = $$067$lcssa;$42 = $61;
   while(1) {
    $41 = ($$2|0)==(1);
    $43 = ($42|0)==(1);
    $or$cond = $41 & $43;
    if ($or$cond) {
     $44 = HEAP32[$40>>2]|0;
     $45 = ($44|0)==(0);
     if ($45) {
      break L1;
     }
    } else {
     $46 = ($$2|0)<(2);
     if (!($46)) {
      _shl($5,2);
      $49 = (($$2) + -2)|0;
      $50 = HEAP32[$5>>2]|0;
      $51 = $50 ^ 7;
      HEAP32[$5>>2] = $51;
      _shr($5,1);
      $52 = (($4) + ($49<<2)|0);
      $53 = HEAP32[$52>>2]|0;
      $54 = (0 - ($53))|0;
      $55 = (($$169) + ($54)|0);
      $56 = (($55) + ($12)|0);
      $57 = (($$2) + -1)|0;
      _trinkle($56,$2,$3,$5,$57,1,$4);
      _shl($5,1);
      $58 = HEAP32[$5>>2]|0;
      $59 = $58 | 1;
      HEAP32[$5>>2] = $59;
      $60 = (($$169) + ($12)|0);
      _trinkle($60,$2,$3,$5,$49,1,$4);
      $$169 = $60;$$2 = $49;$42 = $59;
      continue;
     }
    }
    $47 = (_pntz($5)|0);
    _shr($5,$47);
    $48 = (($47) + ($$2))|0;
    $$pre$pre = HEAP32[$5>>2]|0;
    $$pre76 = (($$169) + ($12)|0);
    $$169 = $$pre76;$$2 = $48;$42 = $$pre$pre;
   }
  }
 } while(0);
 STACKTOP = sp;return;
}
function _sift($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0$lcssa = 0, $$029$be = 0, $$02932 = 0, $$030$be = 0, $$03031 = 0, $$033 = 0, $$pre = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 240|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(240|0);
 $5 = sp;
 HEAP32[$5>>2] = $0;
 $6 = ($3|0)>(1);
 L1: do {
  if ($6) {
   $7 = (0 - ($1))|0;
   $$02932 = $0;$$03031 = $3;$$033 = 1;$14 = $0;
   while(1) {
    $8 = (($$02932) + ($7)|0);
    $9 = (($$03031) + -2)|0;
    $10 = (($4) + ($9<<2)|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = (0 - ($11))|0;
    $13 = (($8) + ($12)|0);
    $15 = (FUNCTION_TABLE_iii[$2 & 8191]($14,$13)|0);
    $16 = ($15|0)>(-1);
    if ($16) {
     $17 = (FUNCTION_TABLE_iii[$2 & 8191]($14,$8)|0);
     $18 = ($17|0)>(-1);
     if ($18) {
      $$0$lcssa = $$033;
      break L1;
     }
    }
    $19 = (FUNCTION_TABLE_iii[$2 & 8191]($13,$8)|0);
    $20 = ($19|0)>(-1);
    $21 = (($$033) + 1)|0;
    $22 = (($5) + ($$033<<2)|0);
    if ($20) {
     HEAP32[$22>>2] = $13;
     $23 = (($$03031) + -1)|0;
     $$029$be = $13;$$030$be = $23;
    } else {
     HEAP32[$22>>2] = $8;
     $$029$be = $8;$$030$be = $9;
    }
    $24 = ($$030$be|0)>(1);
    if (!($24)) {
     $$0$lcssa = $21;
     break L1;
    }
    $$pre = HEAP32[$5>>2]|0;
    $$02932 = $$029$be;$$03031 = $$030$be;$$033 = $21;$14 = $$pre;
   }
  } else {
   $$0$lcssa = 1;
  }
 } while(0);
 _cycle($1,$5,$$0$lcssa);
 STACKTOP = sp;return;
}
function _shr($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$pre = 0, $$pre11 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1>>>0)>(31);
 $3 = ((($0)) + 4|0);
 if ($2) {
  $4 = (($1) + -32)|0;
  $5 = HEAP32[$3>>2]|0;
  HEAP32[$0>>2] = $5;
  HEAP32[$3>>2] = 0;
  $$0 = $4;$10 = 0;$7 = $5;
 } else {
  $$pre = HEAP32[$0>>2]|0;
  $$pre11 = HEAP32[$3>>2]|0;
  $$0 = $1;$10 = $$pre11;$7 = $$pre;
 }
 $6 = $7 >>> $$0;
 $8 = (32 - ($$0))|0;
 $9 = $10 << $8;
 $11 = $9 | $6;
 HEAP32[$0>>2] = $11;
 $12 = $10 >>> $$0;
 HEAP32[$3>>2] = $12;
 return;
}
function _trinkle($0,$1,$2,$3,$4,$5,$6) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 var $$0$lcssa = 0, $$045$lcssa = 0, $$04551 = 0, $$0455780 = 0, $$046$lcssa = 0, $$04653 = 0, $$0465681 = 0, $$047$lcssa = 0, $$0475582 = 0, $$049 = 0, $$05879 = 0, $$05879$phi = 0, $$pre = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $phitmp = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 240|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(240|0);
 $7 = sp + 232|0;
 $8 = sp;
 $9 = HEAP32[$3>>2]|0;
 HEAP32[$7>>2] = $9;
 $10 = ((($3)) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($7)) + 4|0);
 HEAP32[$12>>2] = $11;
 HEAP32[$8>>2] = $0;
 $13 = ($9|0)!=(1);
 $14 = ($11|0)!=(0);
 $15 = $13 | $14;
 L1: do {
  if ($15) {
   $16 = (0 - ($1))|0;
   $17 = (($6) + ($4<<2)|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = (0 - ($18))|0;
   $20 = (($0) + ($19)|0);
   $21 = (FUNCTION_TABLE_iii[$2 & 8191]($20,$0)|0);
   $22 = ($21|0)<(1);
   if ($22) {
    $$0$lcssa = $0;$$045$lcssa = 1;$$046$lcssa = $4;$$047$lcssa = $5;
    label = 9;
   } else {
    $phitmp = ($5|0)==(0);
    $$0455780 = 1;$$0465681 = $4;$$0475582 = $phitmp;$$05879 = $0;$28 = $20;
    while(1) {
     $23 = ($$0465681|0)>(1);
     $or$cond = $$0475582 & $23;
     if ($or$cond) {
      $24 = (($$05879) + ($16)|0);
      $25 = (($$0465681) + -2)|0;
      $26 = (($6) + ($25<<2)|0);
      $27 = HEAP32[$26>>2]|0;
      $29 = (FUNCTION_TABLE_iii[$2 & 8191]($24,$28)|0);
      $30 = ($29|0)>(-1);
      if ($30) {
       $$04551 = $$0455780;$$04653 = $$0465681;$$049 = $$05879;
       label = 10;
       break L1;
      }
      $31 = (0 - ($27))|0;
      $32 = (($24) + ($31)|0);
      $33 = (FUNCTION_TABLE_iii[$2 & 8191]($32,$28)|0);
      $34 = ($33|0)>(-1);
      if ($34) {
       $$04551 = $$0455780;$$04653 = $$0465681;$$049 = $$05879;
       label = 10;
       break L1;
      }
     }
     $35 = (($$0455780) + 1)|0;
     $36 = (($8) + ($$0455780<<2)|0);
     HEAP32[$36>>2] = $28;
     $37 = (_pntz($7)|0);
     _shr($7,$37);
     $38 = (($37) + ($$0465681))|0;
     $39 = HEAP32[$7>>2]|0;
     $40 = ($39|0)!=(1);
     $41 = HEAP32[$12>>2]|0;
     $42 = ($41|0)!=(0);
     $43 = $40 | $42;
     if (!($43)) {
      $$04551 = $35;$$04653 = $38;$$049 = $28;
      label = 10;
      break L1;
     }
     $$pre = HEAP32[$8>>2]|0;
     $44 = (($6) + ($38<<2)|0);
     $45 = HEAP32[$44>>2]|0;
     $46 = (0 - ($45))|0;
     $47 = (($28) + ($46)|0);
     $48 = (FUNCTION_TABLE_iii[$2 & 8191]($47,$$pre)|0);
     $49 = ($48|0)<(1);
     if ($49) {
      $$0$lcssa = $28;$$045$lcssa = $35;$$046$lcssa = $38;$$047$lcssa = 0;
      label = 9;
      break;
     } else {
      $$05879$phi = $28;$$0455780 = $35;$$0465681 = $38;$$0475582 = 1;$28 = $47;$$05879 = $$05879$phi;
     }
    }
   }
  } else {
   $$0$lcssa = $0;$$045$lcssa = 1;$$046$lcssa = $4;$$047$lcssa = $5;
   label = 9;
  }
 } while(0);
 if ((label|0) == 9) {
  $50 = ($$047$lcssa|0)==(0);
  if ($50) {
   $$04551 = $$045$lcssa;$$04653 = $$046$lcssa;$$049 = $$0$lcssa;
   label = 10;
  }
 }
 if ((label|0) == 10) {
  _cycle($1,$8,$$04551);
  _sift($$049,$1,$2,$$04653,$6);
 }
 STACKTOP = sp;return;
}
function _shl($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$pre = 0, $$pre11 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1>>>0)>(31);
 $3 = ((($0)) + 4|0);
 if ($2) {
  $4 = (($1) + -32)|0;
  $5 = HEAP32[$0>>2]|0;
  HEAP32[$3>>2] = $5;
  HEAP32[$0>>2] = 0;
  $$0 = $4;$10 = 0;$7 = $5;
 } else {
  $$pre = HEAP32[$3>>2]|0;
  $$pre11 = HEAP32[$0>>2]|0;
  $$0 = $1;$10 = $$pre11;$7 = $$pre;
 }
 $6 = $7 << $$0;
 $8 = (32 - ($$0))|0;
 $9 = $10 >>> $8;
 $11 = $9 | $6;
 HEAP32[$3>>2] = $11;
 $12 = $10 << $$0;
 HEAP32[$0>>2] = $12;
 return;
}
function _pntz($0) {
 $0 = $0|0;
 var $$ = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + -1)|0;
 $3 = (_a_ctz_l($2)|0);
 $4 = ($3|0)==(0);
 if ($4) {
  $5 = ((($0)) + 4|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (_a_ctz_l($6)|0);
  $8 = (($7) + 32)|0;
  $9 = ($7|0)==(0);
  $$ = $9 ? 0 : $8;
  return ($$|0);
 } else {
  return ($3|0);
 }
 return (0)|0;
}
function _a_ctz_l($0) {
 $0 = $0|0;
 var $$068 = 0, $$07 = 0, $$09 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ($0|0)==(0);
 if ($1) {
  $$07 = 32;
 } else {
  $2 = $0 & 1;
  $3 = ($2|0)==(0);
  if ($3) {
   $$068 = $0;$$09 = 0;
   while(1) {
    $4 = (($$09) + 1)|0;
    $5 = $$068 >>> 1;
    $6 = $5 & 1;
    $7 = ($6|0)==(0);
    if ($7) {
     $$068 = $5;$$09 = $4;
    } else {
     $$07 = $4;
     break;
    }
   }
  } else {
   $$07 = 0;
  }
 }
 return ($$07|0);
}
function _cycle($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$02527 = 0, $$026 = 0, $$pre = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $exitcond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 256|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(256|0);
 $3 = sp;
 $4 = ($2|0)<(2);
 L1: do {
  if (!($4)) {
   $5 = (($1) + ($2<<2)|0);
   HEAP32[$5>>2] = $3;
   $6 = ($0|0)==(0);
   if (!($6)) {
    $$02527 = $0;$10 = $3;
    while(1) {
     $7 = ($$02527>>>0)<(256);
     $8 = $7 ? $$02527 : 256;
     $9 = HEAP32[$1>>2]|0;
     _memcpy(($10|0),($9|0),($8|0))|0;
     $$026 = 0;
     while(1) {
      $11 = (($1) + ($$026<<2)|0);
      $12 = HEAP32[$11>>2]|0;
      $13 = (($$026) + 1)|0;
      $14 = (($1) + ($13<<2)|0);
      $15 = HEAP32[$14>>2]|0;
      _memcpy(($12|0),($15|0),($8|0))|0;
      $16 = HEAP32[$11>>2]|0;
      $17 = (($16) + ($8)|0);
      HEAP32[$11>>2] = $17;
      $exitcond = ($13|0)==($2|0);
      if ($exitcond) {
       break;
      } else {
       $$026 = $13;
      }
     }
     $18 = (($$02527) - ($8))|0;
     $19 = ($18|0)==(0);
     if ($19) {
      break L1;
     }
     $$pre = HEAP32[$5>>2]|0;
     $$02527 = $18;$10 = $$pre;
    }
   }
  }
 } while(0);
 STACKTOP = sp;return;
}
function _strtod($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (+_strtox_13($0,$1,1));
 return (+$2);
}
function _strtox_13($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0.0, $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(128|0);
 $3 = sp;
 dest=$3; stop=dest+124|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $4 = ((($3)) + 4|0);
 HEAP32[$4>>2] = $0;
 $5 = ((($3)) + 8|0);
 HEAP32[$5>>2] = (-1);
 $6 = ((($3)) + 44|0);
 HEAP32[$6>>2] = $0;
 $7 = ((($3)) + 76|0);
 HEAP32[$7>>2] = -1;
 ___shlim($3,0);
 $8 = (+___floatscan($3,$2,1));
 $9 = ((($3)) + 108|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$4>>2]|0;
 $12 = HEAP32[$5>>2]|0;
 $13 = (($11) - ($12))|0;
 $14 = (($13) + ($10))|0;
 $15 = ($1|0)==(0|0);
 if (!($15)) {
  $16 = ($14|0)!=(0);
  $17 = (($0) + ($14)|0);
  $18 = $16 ? $17 : $0;
  HEAP32[$1>>2] = $18;
 }
 STACKTOP = sp;return (+$8);
}
function ___floatscan($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$0105$ph = 0, $$0106$ph = 0, $$0107$lcssa = 0, $$0107127 = 0, $$0113 = 0, $$0114 = 0.0, $$1$lcssa = 0, $$1108 = 0, $$1128 = 0, $$2 = 0, $$2109125 = 0, $$3110 = 0, $$3126 = 0, $$4 = 0, $$4111 = 0, $$5 = 0, $$6 = 0, $$in = 0, $$old8 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0.0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0.0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0.0, $54 = 0.0, $55 = 0.0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $or$cond5 = 0, $or$cond7 = 0, $or$cond9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 switch ($1|0) {
 case 0:  {
  $$0105$ph = -149;$$0106$ph = 24;
  label = 4;
  break;
 }
 case 1:  {
  $$0105$ph = -1074;$$0106$ph = 53;
  label = 4;
  break;
 }
 case 2:  {
  $$0105$ph = -1074;$$0106$ph = 53;
  label = 4;
  break;
 }
 default: {
  $$0114 = 0.0;
 }
 }
 L4: do {
  if ((label|0) == 4) {
   $3 = ((($0)) + 4|0);
   $4 = ((($0)) + 100|0);
   while(1) {
    $5 = HEAP32[$3>>2]|0;
    $6 = HEAP32[$4>>2]|0;
    $7 = ($5>>>0)<($6>>>0);
    if ($7) {
     $8 = ((($5)) + 1|0);
     HEAP32[$3>>2] = $8;
     $9 = HEAP8[$5>>0]|0;
     $10 = $9&255;
     $12 = $10;
    } else {
     $11 = (___shgetc($0)|0);
     $12 = $11;
    }
    $13 = (_isspace($12)|0);
    $14 = ($13|0)==(0);
    if ($14) {
     break;
    }
   }
   L13: do {
    switch ($12|0) {
    case 43: case 45:  {
     $15 = ($12|0)==(45);
     $16 = $15&1;
     $17 = $16 << 1;
     $18 = (1 - ($17))|0;
     $19 = HEAP32[$3>>2]|0;
     $20 = HEAP32[$4>>2]|0;
     $21 = ($19>>>0)<($20>>>0);
     if ($21) {
      $22 = ((($19)) + 1|0);
      HEAP32[$3>>2] = $22;
      $23 = HEAP8[$19>>0]|0;
      $24 = $23&255;
      $$0 = $24;$$0113 = $18;
      break L13;
     } else {
      $25 = (___shgetc($0)|0);
      $$0 = $25;$$0113 = $18;
      break L13;
     }
     break;
    }
    default: {
     $$0 = $12;$$0113 = 1;
    }
    }
   } while(0);
   $$0107127 = 0;$$1128 = $$0;
   while(1) {
    $26 = $$1128 | 32;
    $27 = (199298 + ($$0107127)|0);
    $28 = HEAP8[$27>>0]|0;
    $29 = $28 << 24 >> 24;
    $30 = ($26|0)==($29|0);
    if (!($30)) {
     $$0107$lcssa = $$0107127;$$1$lcssa = $$1128;
     break;
    }
    $31 = ($$0107127>>>0)<(7);
    do {
     if ($31) {
      $32 = HEAP32[$3>>2]|0;
      $33 = HEAP32[$4>>2]|0;
      $34 = ($32>>>0)<($33>>>0);
      if ($34) {
       $35 = ((($32)) + 1|0);
       HEAP32[$3>>2] = $35;
       $36 = HEAP8[$32>>0]|0;
       $37 = $36&255;
       $$2 = $37;
       break;
      } else {
       $38 = (___shgetc($0)|0);
       $$2 = $38;
       break;
      }
     } else {
      $$2 = $$1128;
     }
    } while(0);
    $39 = (($$0107127) + 1)|0;
    $40 = ($39>>>0)<(8);
    if ($40) {
     $$0107127 = $39;$$1128 = $$2;
    } else {
     $$0107$lcssa = $39;$$1$lcssa = $$2;
     break;
    }
   }
   L29: do {
    switch ($$0107$lcssa|0) {
    case 8:  {
     break;
    }
    case 3:  {
     label = 23;
     break;
    }
    default: {
     $41 = ($$0107$lcssa>>>0)>(3);
     $42 = ($2|0)!=(0);
     $or$cond5 = $42 & $41;
     if ($or$cond5) {
      $43 = ($$0107$lcssa|0)==(8);
      if ($43) {
       break L29;
      } else {
       label = 23;
       break L29;
      }
     }
     $56 = ($$0107$lcssa|0)==(0);
     L34: do {
      if ($56) {
       $$2109125 = 0;$$3126 = $$1$lcssa;
       while(1) {
        $57 = $$3126 | 32;
        $58 = (199815 + ($$2109125)|0);
        $59 = HEAP8[$58>>0]|0;
        $60 = $59 << 24 >> 24;
        $61 = ($57|0)==($60|0);
        if (!($61)) {
         $$3110 = $$2109125;$$5 = $$3126;
         break L34;
        }
        $62 = ($$2109125>>>0)<(2);
        do {
         if ($62) {
          $63 = HEAP32[$3>>2]|0;
          $64 = HEAP32[$4>>2]|0;
          $65 = ($63>>>0)<($64>>>0);
          if ($65) {
           $66 = ((($63)) + 1|0);
           HEAP32[$3>>2] = $66;
           $67 = HEAP8[$63>>0]|0;
           $68 = $67&255;
           $$4 = $68;
           break;
          } else {
           $69 = (___shgetc($0)|0);
           $$4 = $69;
           break;
          }
         } else {
          $$4 = $$3126;
         }
        } while(0);
        $70 = (($$2109125) + 1)|0;
        $71 = ($70>>>0)<(3);
        if ($71) {
         $$2109125 = $70;$$3126 = $$4;
        } else {
         $$3110 = $70;$$5 = $$4;
         break;
        }
       }
      } else {
       $$3110 = $$0107$lcssa;$$5 = $$1$lcssa;
      }
     } while(0);
     switch ($$3110|0) {
     case 3:  {
      $72 = HEAP32[$3>>2]|0;
      $73 = HEAP32[$4>>2]|0;
      $74 = ($72>>>0)<($73>>>0);
      if ($74) {
       $75 = ((($72)) + 1|0);
       HEAP32[$3>>2] = $75;
       $76 = HEAP8[$72>>0]|0;
       $77 = $76&255;
       $79 = $77;
      } else {
       $78 = (___shgetc($0)|0);
       $79 = $78;
      }
      $80 = ($79|0)==(40);
      if ($80) {
       $$4111 = 1;
      } else {
       $81 = HEAP32[$4>>2]|0;
       $82 = ($81|0)==(0|0);
       if ($82) {
        $$0114 = nan;
        break L4;
       }
       $83 = HEAP32[$3>>2]|0;
       $84 = ((($83)) + -1|0);
       HEAP32[$3>>2] = $84;
       $$0114 = nan;
       break L4;
      }
      while(1) {
       $85 = HEAP32[$3>>2]|0;
       $86 = HEAP32[$4>>2]|0;
       $87 = ($85>>>0)<($86>>>0);
       if ($87) {
        $88 = ((($85)) + 1|0);
        HEAP32[$3>>2] = $88;
        $89 = HEAP8[$85>>0]|0;
        $90 = $89&255;
        $93 = $90;
       } else {
        $91 = (___shgetc($0)|0);
        $93 = $91;
       }
       $92 = (($93) + -48)|0;
       $94 = ($92>>>0)<(10);
       $95 = (($93) + -65)|0;
       $96 = ($95>>>0)<(26);
       $or$cond = $94 | $96;
       if (!($or$cond)) {
        $97 = (($93) + -97)|0;
        $98 = ($97>>>0)<(26);
        $99 = ($93|0)==(95);
        $or$cond7 = $99 | $98;
        if (!($or$cond7)) {
         break;
        }
       }
       $111 = (($$4111) + 1)|0;
       $$4111 = $111;
      }
      $100 = ($93|0)==(41);
      if ($100) {
       $$0114 = nan;
       break L4;
      }
      $101 = HEAP32[$4>>2]|0;
      $102 = ($101|0)==(0|0);
      if (!($102)) {
       $103 = HEAP32[$3>>2]|0;
       $104 = ((($103)) + -1|0);
       HEAP32[$3>>2] = $104;
      }
      if (!($42)) {
       $106 = (___errno_location()|0);
       HEAP32[$106>>2] = 22;
       ___shlim($0,0);
       $$0114 = 0.0;
       break L4;
      }
      $105 = ($$4111|0)==(0);
      if ($105) {
       $$0114 = nan;
       break L4;
      } else {
       $$in = $$4111;
      }
      while(1) {
       $107 = (($$in) + -1)|0;
       if (!($102)) {
        $108 = HEAP32[$3>>2]|0;
        $109 = ((($108)) + -1|0);
        HEAP32[$3>>2] = $109;
       }
       $110 = ($107|0)==(0);
       if ($110) {
        $$0114 = nan;
        break L4;
       } else {
        $$in = $107;
       }
      }
      break;
     }
     case 0:  {
      $117 = ($$5|0)==(48);
      if ($117) {
       $118 = HEAP32[$3>>2]|0;
       $119 = HEAP32[$4>>2]|0;
       $120 = ($118>>>0)<($119>>>0);
       if ($120) {
        $121 = ((($118)) + 1|0);
        HEAP32[$3>>2] = $121;
        $122 = HEAP8[$118>>0]|0;
        $123 = $122&255;
        $126 = $123;
       } else {
        $124 = (___shgetc($0)|0);
        $126 = $124;
       }
       $125 = $126 | 32;
       $127 = ($125|0)==(120);
       if ($127) {
        $128 = (+_hexfloat($0,$$0106$ph,$$0105$ph,$$0113,$2));
        $$0114 = $128;
        break L4;
       }
       $129 = HEAP32[$4>>2]|0;
       $130 = ($129|0)==(0|0);
       if ($130) {
        $$6 = 48;
       } else {
        $131 = HEAP32[$3>>2]|0;
        $132 = ((($131)) + -1|0);
        HEAP32[$3>>2] = $132;
        $$6 = 48;
       }
      } else {
       $$6 = $$5;
      }
      $133 = (+_decfloat($0,$$6,$$0106$ph,$$0105$ph,$$0113,$2));
      $$0114 = $133;
      break L4;
      break;
     }
     default: {
      $112 = HEAP32[$4>>2]|0;
      $113 = ($112|0)==(0|0);
      if (!($113)) {
       $114 = HEAP32[$3>>2]|0;
       $115 = ((($114)) + -1|0);
       HEAP32[$3>>2] = $115;
      }
      $116 = (___errno_location()|0);
      HEAP32[$116>>2] = 22;
      ___shlim($0,0);
      $$0114 = 0.0;
      break L4;
     }
     }
    }
    }
   } while(0);
   if ((label|0) == 23) {
    $44 = HEAP32[$4>>2]|0;
    $45 = ($44|0)==(0|0);
    if (!($45)) {
     $46 = HEAP32[$3>>2]|0;
     $47 = ((($46)) + -1|0);
     HEAP32[$3>>2] = $47;
    }
    $48 = ($2|0)!=(0);
    $49 = ($$0107$lcssa>>>0)>(3);
    $or$cond9 = $48 & $49;
    if ($or$cond9) {
     $$1108 = $$0107$lcssa;
     while(1) {
      if (!($45)) {
       $50 = HEAP32[$3>>2]|0;
       $51 = ((($50)) + -1|0);
       HEAP32[$3>>2] = $51;
      }
      $52 = (($$1108) + -1)|0;
      $$old8 = ($52>>>0)>(3);
      if ($$old8) {
       $$1108 = $52;
      } else {
       break;
      }
     }
    }
   }
   $53 = (+($$0113|0));
   $54 = $53 * inf;
   $55 = $54;
   $$0114 = $55;
  }
 } while(0);
 return (+$$0114);
}
function _hexfloat($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0 = 0, $$0133 = 0, $$0142 = 0, $$0146 = 0, $$0148 = 0, $$0148$ = 0, $$0151 = 0.0, $$0152 = 0.0, $$0155 = 0.0, $$0155$ = 0.0, $$0159 = 0, $$0165 = 0.0, $$0166 = 0, $$0166169 = 0, $$0166170 = 0, $$1$ph = 0, $$1147 = 0, $$1149 = 0, $$1153 = 0.0, $$1156 = 0.0;
 var $$1160 = 0, $$2 = 0, $$2$lcssa = 0, $$2144 = 0, $$2150 = 0, $$2154 = 0.0, $$2157 = 0.0, $$2161 = 0, $$3145 = 0, $$3158$lcssa = 0.0, $$3158179 = 0.0, $$3162$lcssa = 0, $$3162183 = 0, $$4 = 0.0, $$4163$lcssa = 0, $$4163178 = 0, $$5 = 0.0, $$5164 = 0, $$6 = 0, $$pn = 0.0;
 var $$pre = 0.0, $$pre$phiZ2D = 0.0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0.0, $143 = 0.0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0.0, $154 = 0.0, $155 = 0.0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0.0, $167 = 0.0, $168 = 0.0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0.0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0.0, $197 = 0, $198 = 0.0, $199 = 0.0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0.0, $206 = 0.0;
 var $207 = 0.0, $208 = 0.0, $209 = 0.0, $21 = 0, $210 = 0.0, $211 = 0, $212 = 0, $213 = 0.0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0.0, $67 = 0.0;
 var $68 = 0.0, $69 = 0.0, $7 = 0, $70 = 0, $71 = 0, $72 = 0.0, $73 = 0.0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0.0, $96 = 0.0, $97 = 0, $98 = 0, $99 = 0, $not$ = 0, $or$cond = 0, $or$cond168 = 0, $or$cond206 = 0, $or$cond4 = 0;
 var $or$cond6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = ((($0)) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($0)) + 100|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)<($8>>>0);
 if ($9) {
  $10 = ((($6)) + 1|0);
  HEAP32[$5>>2] = $10;
  $11 = HEAP8[$6>>0]|0;
  $12 = $11&255;
  $$0 = $12;$$0142 = 0;
 } else {
  $13 = (___shgetc($0)|0);
  $$0 = $13;$$0142 = 0;
 }
 L4: while(1) {
  switch ($$0|0) {
  case 46:  {
   label = 8;
   break L4;
   break;
  }
  case 48:  {
   break;
  }
  default: {
   $$0146 = 0;$$0148 = 0;$$0152 = 1.0;$$0155 = 0.0;$$0159 = 0;$$2 = $$0;$$2144 = $$0142;$100 = 0;$52 = 0;$54 = 0;$98 = 0;
   break L4;
  }
  }
  $14 = HEAP32[$5>>2]|0;
  $15 = HEAP32[$7>>2]|0;
  $16 = ($14>>>0)<($15>>>0);
  if ($16) {
   $17 = ((($14)) + 1|0);
   HEAP32[$5>>2] = $17;
   $18 = HEAP8[$14>>0]|0;
   $19 = $18&255;
   $$0 = $19;$$0142 = 1;
   continue;
  } else {
   $20 = (___shgetc($0)|0);
   $$0 = $20;$$0142 = 1;
   continue;
  }
 }
 if ((label|0) == 8) {
  $21 = HEAP32[$5>>2]|0;
  $22 = HEAP32[$7>>2]|0;
  $23 = ($21>>>0)<($22>>>0);
  if ($23) {
   $24 = ((($21)) + 1|0);
   HEAP32[$5>>2] = $24;
   $25 = HEAP8[$21>>0]|0;
   $26 = $25&255;
   $$1$ph = $26;
  } else {
   $27 = (___shgetc($0)|0);
   $$1$ph = $27;
  }
  $28 = ($$1$ph|0)==(48);
  if ($28) {
   $36 = 0;$37 = 0;
   while(1) {
    $29 = HEAP32[$5>>2]|0;
    $30 = HEAP32[$7>>2]|0;
    $31 = ($29>>>0)<($30>>>0);
    if ($31) {
     $32 = ((($29)) + 1|0);
     HEAP32[$5>>2] = $32;
     $33 = HEAP8[$29>>0]|0;
     $34 = $33&255;
     $40 = $34;
    } else {
     $35 = (___shgetc($0)|0);
     $40 = $35;
    }
    $38 = (_i64Add(($36|0),($37|0),-1,-1)|0);
    $39 = tempRet0;
    $41 = ($40|0)==(48);
    if ($41) {
     $36 = $38;$37 = $39;
    } else {
     $$0146 = 1;$$0148 = 0;$$0152 = 1.0;$$0155 = 0.0;$$0159 = 0;$$2 = $40;$$2144 = 1;$100 = $39;$52 = 0;$54 = 0;$98 = $38;
     break;
    }
   }
  } else {
   $$0146 = 1;$$0148 = 0;$$0152 = 1.0;$$0155 = 0.0;$$0159 = 0;$$2 = $$1$ph;$$2144 = $$0142;$100 = 0;$52 = 0;$54 = 0;$98 = 0;
  }
 }
 while(1) {
  $42 = (($$2) + -48)|0;
  $43 = ($42>>>0)<(10);
  $44 = ($$2|0)==(46);
  if (!($43)) {
   $45 = $$2 | 32;
   $46 = (($45) + -97)|0;
   $47 = ($46>>>0)<(6);
   $or$cond6 = $44 | $47;
   if (!($or$cond6)) {
    $$2$lcssa = $$2;
    break;
   }
  }
  if ($44) {
   $48 = ($$0146|0)==(0);
   if ($48) {
    $$1147 = 1;$$2150 = $$0148;$$2154 = $$0152;$$2157 = $$0155;$$2161 = $$0159;$$3145 = $$2144;$214 = $54;$215 = $52;$216 = $54;$217 = $52;
   } else {
    $$2$lcssa = 46;
    break;
   }
  } else {
   $49 = ($$2|0)>(57);
   $50 = $$2 | 32;
   $51 = (($50) + -87)|0;
   $$0133 = $49 ? $51 : $42;
   $53 = ($52|0)<(0);
   $55 = ($54>>>0)<(8);
   $56 = ($52|0)==(0);
   $57 = $56 & $55;
   $58 = $53 | $57;
   do {
    if ($58) {
     $59 = $$0159 << 4;
     $60 = (($$0133) + ($59))|0;
     $$1149 = $$0148;$$1153 = $$0152;$$1156 = $$0155;$$1160 = $60;
    } else {
     $61 = ($52|0)<(0);
     $62 = ($54>>>0)<(14);
     $63 = ($52|0)==(0);
     $64 = $63 & $62;
     $65 = $61 | $64;
     if ($65) {
      $66 = (+($$0133|0));
      $67 = $$0152 * 0.0625;
      $68 = $67 * $66;
      $69 = $$0155 + $68;
      $$1149 = $$0148;$$1153 = $67;$$1156 = $69;$$1160 = $$0159;
      break;
     } else {
      $70 = ($$0133|0)==(0);
      $71 = ($$0148|0)!=(0);
      $or$cond = $71 | $70;
      $72 = $$0152 * 0.5;
      $73 = $$0155 + $72;
      $$0155$ = $or$cond ? $$0155 : $73;
      $$0148$ = $or$cond ? $$0148 : 1;
      $$1149 = $$0148$;$$1153 = $$0152;$$1156 = $$0155$;$$1160 = $$0159;
      break;
     }
    }
   } while(0);
   $74 = (_i64Add(($54|0),($52|0),1,0)|0);
   $75 = tempRet0;
   $$1147 = $$0146;$$2150 = $$1149;$$2154 = $$1153;$$2157 = $$1156;$$2161 = $$1160;$$3145 = 1;$214 = $98;$215 = $100;$216 = $74;$217 = $75;
  }
  $76 = HEAP32[$5>>2]|0;
  $77 = HEAP32[$7>>2]|0;
  $78 = ($76>>>0)<($77>>>0);
  if ($78) {
   $79 = ((($76)) + 1|0);
   HEAP32[$5>>2] = $79;
   $80 = HEAP8[$76>>0]|0;
   $81 = $80&255;
   $$0146 = $$1147;$$0148 = $$2150;$$0152 = $$2154;$$0155 = $$2157;$$0159 = $$2161;$$2 = $81;$$2144 = $$3145;$100 = $215;$52 = $217;$54 = $216;$98 = $214;
   continue;
  } else {
   $82 = (___shgetc($0)|0);
   $$0146 = $$1147;$$0148 = $$2150;$$0152 = $$2154;$$0155 = $$2157;$$0159 = $$2161;$$2 = $82;$$2144 = $$3145;$100 = $215;$52 = $217;$54 = $216;$98 = $214;
   continue;
  }
 }
 $83 = ($$2144|0)==(0);
 do {
  if ($83) {
   $84 = HEAP32[$7>>2]|0;
   $85 = ($84|0)!=(0|0);
   if ($85) {
    $86 = HEAP32[$5>>2]|0;
    $87 = ((($86)) + -1|0);
    HEAP32[$5>>2] = $87;
   }
   $88 = ($4|0)==(0);
   if ($88) {
    ___shlim($0,0);
   } else {
    if ($85) {
     $89 = HEAP32[$5>>2]|0;
     $90 = ((($89)) + -1|0);
     HEAP32[$5>>2] = $90;
    }
    $91 = ($$0146|0)==(0);
    $92 = ($84|0)==(0|0);
    $or$cond206 = $91 | $92;
    if (!($or$cond206)) {
     $93 = HEAP32[$5>>2]|0;
     $94 = ((($93)) + -1|0);
     HEAP32[$5>>2] = $94;
    }
   }
   $95 = (+($3|0));
   $96 = $95 * 0.0;
   $$0165 = $96;
  } else {
   $97 = ($$0146|0)==(0);
   $99 = $97 ? $54 : $98;
   $101 = $97 ? $52 : $100;
   $102 = ($52|0)<(0);
   $103 = ($54>>>0)<(8);
   $104 = ($52|0)==(0);
   $105 = $104 & $103;
   $106 = $102 | $105;
   if ($106) {
    $$3162183 = $$0159;$108 = $54;$109 = $52;
    while(1) {
     $107 = $$3162183 << 4;
     $110 = (_i64Add(($108|0),($109|0),1,0)|0);
     $111 = tempRet0;
     $112 = ($111|0)<(0);
     $113 = ($110>>>0)<(8);
     $114 = ($111|0)==(0);
     $115 = $114 & $113;
     $116 = $112 | $115;
     if ($116) {
      $$3162183 = $107;$108 = $110;$109 = $111;
     } else {
      $$3162$lcssa = $107;
      break;
     }
    }
   } else {
    $$3162$lcssa = $$0159;
   }
   $117 = $$2$lcssa | 32;
   $118 = ($117|0)==(112);
   if ($118) {
    $119 = (_scanexp($0,$4)|0);
    $120 = tempRet0;
    $121 = ($119|0)==(0);
    $122 = ($120|0)==(-2147483648);
    $123 = $121 & $122;
    if ($123) {
     $124 = ($4|0)==(0);
     if ($124) {
      ___shlim($0,0);
      $$0165 = 0.0;
      break;
     }
     $125 = HEAP32[$7>>2]|0;
     $126 = ($125|0)==(0|0);
     if ($126) {
      $137 = 0;$138 = 0;
     } else {
      $127 = HEAP32[$5>>2]|0;
      $128 = ((($127)) + -1|0);
      HEAP32[$5>>2] = $128;
      $137 = 0;$138 = 0;
     }
    } else {
     $137 = $119;$138 = $120;
    }
   } else {
    $129 = HEAP32[$7>>2]|0;
    $130 = ($129|0)==(0|0);
    if ($130) {
     $137 = 0;$138 = 0;
    } else {
     $131 = HEAP32[$5>>2]|0;
     $132 = ((($131)) + -1|0);
     HEAP32[$5>>2] = $132;
     $137 = 0;$138 = 0;
    }
   }
   $133 = (_bitshift64Shl(($99|0),($101|0),2)|0);
   $134 = tempRet0;
   $135 = (_i64Add(($133|0),($134|0),-32,-1)|0);
   $136 = tempRet0;
   $139 = (_i64Add(($135|0),($136|0),($137|0),($138|0))|0);
   $140 = tempRet0;
   $141 = ($$3162$lcssa|0)==(0);
   if ($141) {
    $142 = (+($3|0));
    $143 = $142 * 0.0;
    $$0165 = $143;
    break;
   }
   $144 = (0 - ($2))|0;
   $145 = ($144|0)<(0);
   $146 = $145 << 31 >> 31;
   $147 = ($140|0)>($146|0);
   $148 = ($139>>>0)>($144>>>0);
   $149 = ($140|0)==($146|0);
   $150 = $149 & $148;
   $151 = $147 | $150;
   if ($151) {
    $152 = (___errno_location()|0);
    HEAP32[$152>>2] = 34;
    $153 = (+($3|0));
    $154 = $153 * 1.7976931348623157E+308;
    $155 = $154 * 1.7976931348623157E+308;
    $$0165 = $155;
    break;
   }
   $156 = (($2) + -106)|0;
   $157 = ($156|0)<(0);
   $158 = $157 << 31 >> 31;
   $159 = ($140|0)<($158|0);
   $160 = ($139>>>0)<($156>>>0);
   $161 = ($140|0)==($158|0);
   $162 = $161 & $160;
   $163 = $159 | $162;
   if ($163) {
    $165 = (___errno_location()|0);
    HEAP32[$165>>2] = 34;
    $166 = (+($3|0));
    $167 = $166 * 2.2250738585072014E-308;
    $168 = $167 * 2.2250738585072014E-308;
    $$0165 = $168;
    break;
   }
   $164 = ($$3162$lcssa|0)>(-1);
   if ($164) {
    $$3158179 = $$0155;$$4163178 = $$3162$lcssa;$173 = $139;$174 = $140;
    while(1) {
     $169 = !($$3158179 >= 0.5);
     $170 = $$4163178 << 1;
     $171 = $$3158179 + -1.0;
     $not$ = $169 ^ 1;
     $172 = $not$&1;
     $$5164 = $170 | $172;
     $$pn = $169 ? $$3158179 : $171;
     $$4 = $$3158179 + $$pn;
     $175 = (_i64Add(($173|0),($174|0),-1,-1)|0);
     $176 = tempRet0;
     $177 = ($$5164|0)>(-1);
     if ($177) {
      $$3158179 = $$4;$$4163178 = $$5164;$173 = $175;$174 = $176;
     } else {
      $$3158$lcssa = $$4;$$4163$lcssa = $$5164;$184 = $175;$185 = $176;
      break;
     }
    }
   } else {
    $$3158$lcssa = $$0155;$$4163$lcssa = $$3162$lcssa;$184 = $139;$185 = $140;
   }
   $178 = ($1|0)<(0);
   $179 = $178 << 31 >> 31;
   $180 = ($2|0)<(0);
   $181 = $180 << 31 >> 31;
   $182 = (_i64Subtract(32,0,($2|0),($181|0))|0);
   $183 = tempRet0;
   $186 = (_i64Add(($182|0),($183|0),($184|0),($185|0))|0);
   $187 = tempRet0;
   $188 = ($179|0)>($187|0);
   $189 = ($1>>>0)>($186>>>0);
   $190 = ($179|0)==($187|0);
   $191 = $190 & $189;
   $192 = $188 | $191;
   if ($192) {
    $193 = ($186|0)>(0);
    if ($193) {
     $$0166 = $186;
     label = 59;
    } else {
     $$0166170 = 0;$197 = 84;
     label = 61;
    }
   } else {
    $$0166 = $1;
    label = 59;
   }
   if ((label|0) == 59) {
    $194 = ($$0166|0)<(53);
    $195 = (84 - ($$0166))|0;
    if ($194) {
     $$0166170 = $$0166;$197 = $195;
     label = 61;
    } else {
     $$pre = (+($3|0));
     $$0151 = 0.0;$$0166169 = $$0166;$$pre$phiZ2D = $$pre;
    }
   }
   if ((label|0) == 61) {
    $196 = (+($3|0));
    $198 = (+_scalbn(1.0,$197));
    $199 = (+_copysignl($198,$196));
    $$0151 = $199;$$0166169 = $$0166170;$$pre$phiZ2D = $196;
   }
   $200 = ($$0166169|0)<(32);
   $201 = $$3158$lcssa != 0.0;
   $or$cond4 = $201 & $200;
   $202 = $$4163$lcssa & 1;
   $203 = ($202|0)==(0);
   $or$cond168 = $203 & $or$cond4;
   $204 = $or$cond168&1;
   $$6 = (($204) + ($$4163$lcssa))|0;
   $$5 = $or$cond168 ? 0.0 : $$3158$lcssa;
   $205 = (+($$6>>>0));
   $206 = $$pre$phiZ2D * $205;
   $207 = $$0151 + $206;
   $208 = $$pre$phiZ2D * $$5;
   $209 = $208 + $207;
   $210 = $209 - $$0151;
   $211 = $210 != 0.0;
   if (!($211)) {
    $212 = (___errno_location()|0);
    HEAP32[$212>>2] = 34;
   }
   $213 = (+_scalbnl($210,$184));
   $$0165 = $213;
  }
 } while(0);
 return (+$$0165);
}
function _decfloat($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$ = 0, $$$0345 = 0, $$$0350 = 0, $$$0385 = 0, $$$0401 = 0, $$$5355 = 0, $$$5390 = 0, $$0329 = 0, $$0332490 = 0, $$0333 = 0, $$0334 = 0, $$0336486 = 0, $$0340496 = 0, $$0341$lcssa = 0, $$0341463 = 0, $$0341464 = 0, $$0341465 = 0, $$0341513 = 0, $$0345$lcssa = 0, $$0345467 = 0;
 var $$0345468 = 0, $$0345469 = 0, $$0345512 = 0, $$0350$lcssa554 = 0, $$0350494 = 0, $$0360 = 0.0, $$0361 = 0.0, $$0365484 = 0.0, $$0372 = 0, $$0380 = 0, $$0380$ph = 0, $$0385$lcssa553 = 0, $$0385493 = 0, $$0393 = 0, $$0396 = 0, $$0401$lcssa = 0, $$0401473 = 0, $$0401474 = 0, $$0401475 = 0, $$0401509 = 0;
 var $$1 = 0.0, $$10 = 0, $$1330$be = 0, $$1330$ph = 0, $$1335 = 0, $$1337 = 0, $$1362 = 0.0, $$1366 = 0.0, $$1373 = 0, $$1373$ph448 = 0, $$1381 = 0, $$1381$ph = 0, $$1381$ph558 = 0, $$1394$lcssa = 0, $$1394511 = 0, $$2 = 0, $$2343 = 0, $$2347 = 0, $$2352$ph449 = 0, $$2367 = 0.0;
 var $$2371$v = 0, $$2374 = 0, $$2387$ph447 = 0, $$2395 = 0, $$2398 = 0, $$2403 = 0, $$3$be = 0, $$3$lcssa = 0, $$3344503 = 0, $$3348 = 0, $$3364 = 0.0, $$3368 = 0.0, $$3375 = 0, $$3383 = 0, $$3399$lcssa = 0, $$3399510 = 0, $$3514 = 0, $$413 = 0, $$425 = 0, $$4349495 = 0;
 var $$4354 = 0, $$4354$ph = 0, $$4354$ph559 = 0, $$4376 = 0, $$4384 = 0, $$4389$ph = 0, $$4389$ph445 = 0, $$4400 = 0, $$4485 = 0, $$5 = 0, $$5$in = 0, $$5355488 = 0, $$5390487 = 0, $$6378$ph = 0, $$6489 = 0, $$9483 = 0, $$neg442 = 0, $$neg443 = 0, $$pre = 0, $$promoted = 0;
 var $$sink = 0, $$sink421$off0 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0.0, $103 = 0.0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0.0, $12 = 0, $120 = 0.0, $121 = 0.0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0.0, $132 = 0.0, $133 = 0.0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0.0, $144 = 0.0, $145 = 0.0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0.0, $159 = 0.0, $16 = 0, $160 = 0.0, $161 = 0, $162 = 0.0, $163 = 0.0, $164 = 0.0, $165 = 0, $166 = 0, $167 = 0, $168 = 0.0, $169 = 0.0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0.0, $177 = 0.0, $178 = 0.0, $179 = 0, $18 = 0, $180 = 0.0, $181 = 0.0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0;
 var $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0;
 var $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0;
 var $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0;
 var $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0;
 var $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0;
 var $298 = 0, $299 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0.0, $304 = 0, $305 = 0, $306 = 0.0, $307 = 0.0, $308 = 0, $309 = 0.0, $31 = 0, $310 = 0.0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0;
 var $316 = 0, $317 = 0.0, $318 = 0.0, $319 = 0, $32 = 0, $320 = 0.0, $321 = 0.0, $322 = 0.0, $323 = 0.0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0;
 var $334 = 0.0, $335 = 0.0, $336 = 0, $337 = 0.0, $338 = 0.0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0.0, $343 = 0.0, $344 = 0.0, $345 = 0.0, $346 = 0, $347 = 0, $348 = 0.0, $349 = 0, $35 = 0, $350 = 0.0, $351 = 0.0;
 var $352 = 0.0, $353 = 0, $354 = 0, $355 = 0, $356 = 0.0, $357 = 0, $358 = 0.0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0.0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0;
 var $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $39 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $cond = 0, $exitcond = 0, $exitcond551 = 0, $narrow = 0, $not$ = 0, $or$cond = 0, $or$cond11 = 0, $or$cond14 = 0, $or$cond415 = 0, $or$cond417 = 0, $or$cond419 = 0, $or$cond420 = 0, $or$cond422 = 0, $or$cond422$not = 0, $or$cond423 = 0, $or$cond426 = 0, $or$cond5 = 0, $sum = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 512|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(512|0);
 $6 = sp;
 $sum = (($3) + ($2))|0;
 $7 = (0 - ($sum))|0;
 $8 = ((($0)) + 4|0);
 $9 = ((($0)) + 100|0);
 $$0329 = $1;$$0396 = 0;
 L1: while(1) {
  switch ($$0329|0) {
  case 46:  {
   label = 6;
   break L1;
   break;
  }
  case 48:  {
   break;
  }
  default: {
   $$0393 = 0;$$2 = $$0329;$$2398 = $$0396;$366 = 0;$367 = 0;
   break L1;
  }
  }
  $10 = HEAP32[$8>>2]|0;
  $11 = HEAP32[$9>>2]|0;
  $12 = ($10>>>0)<($11>>>0);
  if ($12) {
   $13 = ((($10)) + 1|0);
   HEAP32[$8>>2] = $13;
   $14 = HEAP8[$10>>0]|0;
   $15 = $14&255;
   $$0329 = $15;$$0396 = 1;
   continue;
  } else {
   $16 = (___shgetc($0)|0);
   $$0329 = $16;$$0396 = 1;
   continue;
  }
 }
 if ((label|0) == 6) {
  $17 = HEAP32[$8>>2]|0;
  $18 = HEAP32[$9>>2]|0;
  $19 = ($17>>>0)<($18>>>0);
  if ($19) {
   $20 = ((($17)) + 1|0);
   HEAP32[$8>>2] = $20;
   $21 = HEAP8[$17>>0]|0;
   $22 = $21&255;
   $$1330$ph = $22;
  } else {
   $23 = (___shgetc($0)|0);
   $$1330$ph = $23;
  }
  $24 = ($$1330$ph|0)==(48);
  if ($24) {
   $25 = 0;$26 = 0;
   while(1) {
    $27 = (_i64Add(($25|0),($26|0),-1,-1)|0);
    $28 = tempRet0;
    $29 = HEAP32[$8>>2]|0;
    $30 = HEAP32[$9>>2]|0;
    $31 = ($29>>>0)<($30>>>0);
    if ($31) {
     $32 = ((($29)) + 1|0);
     HEAP32[$8>>2] = $32;
     $33 = HEAP8[$29>>0]|0;
     $34 = $33&255;
     $$1330$be = $34;
    } else {
     $35 = (___shgetc($0)|0);
     $$1330$be = $35;
    }
    $36 = ($$1330$be|0)==(48);
    if ($36) {
     $25 = $27;$26 = $28;
    } else {
     $$0393 = 1;$$2 = $$1330$be;$$2398 = 1;$366 = $27;$367 = $28;
     break;
    }
   }
  } else {
   $$0393 = 1;$$2 = $$1330$ph;$$2398 = $$0396;$366 = 0;$367 = 0;
  }
 }
 HEAP32[$6>>2] = 0;
 $37 = (($$2) + -48)|0;
 $38 = ($37>>>0)<(10);
 $39 = ($$2|0)==(46);
 $40 = $39 | $38;
 L20: do {
  if ($40) {
   $41 = ((($6)) + 496|0);
   $$0341513 = 0;$$0345512 = 0;$$0401509 = 0;$$1394511 = $$0393;$$3399510 = $$2398;$$3514 = $$2;$368 = $39;$369 = $37;$370 = $366;$371 = $367;$44 = 0;$45 = 0;
   L22: while(1) {
    do {
     if ($368) {
      $cond = ($$1394511|0)==(0);
      if ($cond) {
       $$2343 = $$0341513;$$2347 = $$0345512;$$2395 = 1;$$2403 = $$0401509;$$4400 = $$3399510;$372 = $44;$373 = $45;$374 = $44;$375 = $45;
      } else {
       break L22;
      }
     } else {
      $43 = ($$0345512|0)<(125);
      $46 = (_i64Add(($44|0),($45|0),1,0)|0);
      $47 = tempRet0;
      $48 = ($$3514|0)!=(48);
      if (!($43)) {
       if (!($48)) {
        $$2343 = $$0341513;$$2347 = $$0345512;$$2395 = $$1394511;$$2403 = $$0401509;$$4400 = $$3399510;$372 = $370;$373 = $371;$374 = $46;$375 = $47;
        break;
       }
       $57 = HEAP32[$41>>2]|0;
       $58 = $57 | 1;
       HEAP32[$41>>2] = $58;
       $$2343 = $$0341513;$$2347 = $$0345512;$$2395 = $$1394511;$$2403 = $$0401509;$$4400 = $$3399510;$372 = $370;$373 = $371;$374 = $46;$375 = $47;
       break;
      }
      $$$0401 = $48 ? $46 : $$0401509;
      $49 = ($$0341513|0)==(0);
      $$pre = (($6) + ($$0345512<<2)|0);
      if ($49) {
       $$sink = $369;
      } else {
       $50 = HEAP32[$$pre>>2]|0;
       $51 = ($50*10)|0;
       $52 = (($$3514) + -48)|0;
       $53 = (($52) + ($51))|0;
       $$sink = $53;
      }
      HEAP32[$$pre>>2] = $$sink;
      $54 = (($$0341513) + 1)|0;
      $55 = ($54|0)==(9);
      $56 = $55&1;
      $$$0345 = (($56) + ($$0345512))|0;
      $$413 = $55 ? 0 : $54;
      $$2343 = $$413;$$2347 = $$$0345;$$2395 = $$1394511;$$2403 = $$$0401;$$4400 = 1;$372 = $370;$373 = $371;$374 = $46;$375 = $47;
     }
    } while(0);
    $59 = HEAP32[$8>>2]|0;
    $60 = HEAP32[$9>>2]|0;
    $61 = ($59>>>0)<($60>>>0);
    if ($61) {
     $62 = ((($59)) + 1|0);
     HEAP32[$8>>2] = $62;
     $63 = HEAP8[$59>>0]|0;
     $64 = $63&255;
     $$3$be = $64;
    } else {
     $65 = (___shgetc($0)|0);
     $$3$be = $65;
    }
    $66 = (($$3$be) + -48)|0;
    $67 = ($66>>>0)<(10);
    $68 = ($$3$be|0)==(46);
    $69 = $68 | $67;
    if ($69) {
     $$0341513 = $$2343;$$0345512 = $$2347;$$0401509 = $$2403;$$1394511 = $$2395;$$3399510 = $$4400;$$3514 = $$3$be;$368 = $68;$369 = $66;$370 = $372;$371 = $373;$44 = $374;$45 = $375;
    } else {
     $$0341$lcssa = $$2343;$$0345$lcssa = $$2347;$$0401$lcssa = $$2403;$$1394$lcssa = $$2395;$$3$lcssa = $$3$be;$$3399$lcssa = $$4400;$71 = $372;$72 = $374;$74 = $373;$75 = $375;
     label = 29;
     break L20;
    }
   }
   $42 = ($$3399510|0)!=(0);
   $$0341465 = $$0341513;$$0345469 = $$0345512;$$0401475 = $$0401509;$376 = $44;$377 = $45;$378 = $370;$379 = $371;$380 = $42;
   label = 37;
  } else {
   $$0341$lcssa = 0;$$0345$lcssa = 0;$$0401$lcssa = 0;$$1394$lcssa = $$0393;$$3$lcssa = $$2;$$3399$lcssa = $$2398;$71 = $366;$72 = 0;$74 = $367;$75 = 0;
   label = 29;
  }
 } while(0);
 do {
  if ((label|0) == 29) {
   $70 = ($$1394$lcssa|0)==(0);
   $73 = $70 ? $72 : $71;
   $76 = $70 ? $75 : $74;
   $77 = ($$3399$lcssa|0)!=(0);
   $78 = $$3$lcssa | 32;
   $79 = ($78|0)==(101);
   $or$cond415 = $77 & $79;
   if (!($or$cond415)) {
    $94 = ($$3$lcssa|0)>(-1);
    if ($94) {
     $$0341465 = $$0341$lcssa;$$0345469 = $$0345$lcssa;$$0401475 = $$0401$lcssa;$376 = $72;$377 = $75;$378 = $73;$379 = $76;$380 = $77;
     label = 37;
     break;
    } else {
     $$0341464 = $$0341$lcssa;$$0345468 = $$0345$lcssa;$$0401474 = $$0401$lcssa;$381 = $72;$382 = $75;$383 = $77;$384 = $73;$385 = $76;
     label = 39;
     break;
    }
   }
   $80 = (_scanexp($0,$5)|0);
   $81 = tempRet0;
   $82 = ($80|0)==(0);
   $83 = ($81|0)==(-2147483648);
   $84 = $82 & $83;
   if ($84) {
    $85 = ($5|0)==(0);
    if ($85) {
     ___shlim($0,0);
     $$1 = 0.0;
     break;
    }
    $86 = HEAP32[$9>>2]|0;
    $87 = ($86|0)==(0|0);
    if ($87) {
     $90 = 0;$91 = 0;
    } else {
     $88 = HEAP32[$8>>2]|0;
     $89 = ((($88)) + -1|0);
     HEAP32[$8>>2] = $89;
     $90 = 0;$91 = 0;
    }
   } else {
    $90 = $80;$91 = $81;
   }
   $92 = (_i64Add(($90|0),($91|0),($73|0),($76|0))|0);
   $93 = tempRet0;
   $$0341463 = $$0341$lcssa;$$0345467 = $$0345$lcssa;$$0401473 = $$0401$lcssa;$104 = $92;$106 = $72;$107 = $93;$109 = $75;
   label = 41;
  }
 } while(0);
 if ((label|0) == 37) {
  $95 = HEAP32[$9>>2]|0;
  $96 = ($95|0)==(0|0);
  if ($96) {
   $$0341464 = $$0341465;$$0345468 = $$0345469;$$0401474 = $$0401475;$381 = $376;$382 = $377;$383 = $380;$384 = $378;$385 = $379;
   label = 39;
  } else {
   $97 = HEAP32[$8>>2]|0;
   $98 = ((($97)) + -1|0);
   HEAP32[$8>>2] = $98;
   if ($380) {
    $$0341463 = $$0341465;$$0345467 = $$0345469;$$0401473 = $$0401475;$104 = $378;$106 = $376;$107 = $379;$109 = $377;
    label = 41;
   } else {
    label = 40;
   }
  }
 }
 if ((label|0) == 39) {
  if ($383) {
   $$0341463 = $$0341464;$$0345467 = $$0345468;$$0401473 = $$0401474;$104 = $384;$106 = $381;$107 = $385;$109 = $382;
   label = 41;
  } else {
   label = 40;
  }
 }
 do {
  if ((label|0) == 40) {
   $99 = (___errno_location()|0);
   HEAP32[$99>>2] = 22;
   ___shlim($0,0);
   $$1 = 0.0;
  }
  else if ((label|0) == 41) {
   $100 = HEAP32[$6>>2]|0;
   $101 = ($100|0)==(0);
   if ($101) {
    $102 = (+($4|0));
    $103 = $102 * 0.0;
    $$1 = $103;
    break;
   }
   $105 = ($104|0)==($106|0);
   $108 = ($107|0)==($109|0);
   $110 = $105 & $108;
   $111 = ($109|0)<(0);
   $112 = ($106>>>0)<(10);
   $113 = ($109|0)==(0);
   $114 = $113 & $112;
   $115 = $111 | $114;
   $or$cond = $115 & $110;
   if ($or$cond) {
    $116 = ($2|0)>(30);
    $117 = $100 >>> $2;
    $118 = ($117|0)==(0);
    $or$cond417 = $116 | $118;
    if ($or$cond417) {
     $119 = (+($4|0));
     $120 = (+($100>>>0));
     $121 = $119 * $120;
     $$1 = $121;
     break;
    }
   }
   $122 = (($3|0) / -2)&-1;
   $123 = ($122|0)<(0);
   $124 = $123 << 31 >> 31;
   $125 = ($107|0)>($124|0);
   $126 = ($104>>>0)>($122>>>0);
   $127 = ($107|0)==($124|0);
   $128 = $127 & $126;
   $129 = $125 | $128;
   if ($129) {
    $130 = (___errno_location()|0);
    HEAP32[$130>>2] = 34;
    $131 = (+($4|0));
    $132 = $131 * 1.7976931348623157E+308;
    $133 = $132 * 1.7976931348623157E+308;
    $$1 = $133;
    break;
   }
   $134 = (($3) + -106)|0;
   $135 = ($134|0)<(0);
   $136 = $135 << 31 >> 31;
   $137 = ($107|0)<($136|0);
   $138 = ($104>>>0)<($134>>>0);
   $139 = ($107|0)==($136|0);
   $140 = $139 & $138;
   $141 = $137 | $140;
   if ($141) {
    $142 = (___errno_location()|0);
    HEAP32[$142>>2] = 34;
    $143 = (+($4|0));
    $144 = $143 * 2.2250738585072014E-308;
    $145 = $144 * 2.2250738585072014E-308;
    $$1 = $145;
    break;
   }
   $146 = ($$0341463|0)==(0);
   if ($146) {
    $$3348 = $$0345467;
   } else {
    $147 = ($$0341463|0)<(9);
    if ($147) {
     $148 = (($6) + ($$0345467<<2)|0);
     $$promoted = HEAP32[$148>>2]|0;
     $$3344503 = $$0341463;$150 = $$promoted;
     while(1) {
      $149 = ($150*10)|0;
      $151 = (($$3344503) + 1)|0;
      $exitcond551 = ($151|0)==(9);
      if ($exitcond551) {
       break;
      } else {
       $$3344503 = $151;$150 = $149;
      }
     }
     HEAP32[$148>>2] = $149;
    }
    $152 = (($$0345467) + 1)|0;
    $$3348 = $152;
   }
   $153 = ($$0401473|0)<(9);
   if ($153) {
    $154 = ($$0401473|0)<=($104|0);
    $155 = ($104|0)<(18);
    $or$cond5 = $154 & $155;
    if ($or$cond5) {
     $156 = ($104|0)==(9);
     $157 = HEAP32[$6>>2]|0;
     if ($156) {
      $158 = (+($4|0));
      $159 = (+($157>>>0));
      $160 = $158 * $159;
      $$1 = $160;
      break;
     }
     $161 = ($104|0)<(9);
     if ($161) {
      $162 = (+($4|0));
      $163 = (+($157>>>0));
      $164 = $162 * $163;
      $165 = (8 - ($104))|0;
      $166 = (92808 + ($165<<2)|0);
      $167 = HEAP32[$166>>2]|0;
      $168 = (+($167|0));
      $169 = $164 / $168;
      $$1 = $169;
      break;
     }
     $$neg442 = Math_imul($104, -3)|0;
     $$neg443 = (($2) + 27)|0;
     $170 = (($$neg443) + ($$neg442))|0;
     $171 = ($170|0)>(30);
     $172 = $157 >>> $170;
     $173 = ($172|0)==(0);
     $or$cond419 = $171 | $173;
     if ($or$cond419) {
      $174 = (($104) + -10)|0;
      $175 = (92808 + ($174<<2)|0);
      $176 = (+($4|0));
      $177 = (+($157>>>0));
      $178 = $176 * $177;
      $179 = HEAP32[$175>>2]|0;
      $180 = (+($179|0));
      $181 = $178 * $180;
      $$1 = $181;
      break;
     }
    }
   }
   $182 = (($104|0) % 9)&-1;
   $183 = ($182|0)==(0);
   if ($183) {
    $$0380$ph = 0;$$1373$ph448 = $$3348;$$2352$ph449 = 0;$$2387$ph447 = $104;
   } else {
    $184 = ($104|0)>(-1);
    $185 = (($182) + 9)|0;
    $186 = $184 ? $182 : $185;
    $187 = (8 - ($186))|0;
    $188 = (92808 + ($187<<2)|0);
    $189 = HEAP32[$188>>2]|0;
    $190 = ($$3348|0)==(0);
    if ($190) {
     $$0350$lcssa554 = 0;$$0372 = 0;$$0385$lcssa553 = $104;
    } else {
     $191 = (1000000000 / ($189|0))&-1;
     $$0340496 = 0;$$0350494 = 0;$$0385493 = $104;$$4349495 = 0;
     while(1) {
      $192 = (($6) + ($$4349495<<2)|0);
      $193 = HEAP32[$192>>2]|0;
      $194 = (($193>>>0) % ($189>>>0))&-1;
      $195 = (($193>>>0) / ($189>>>0))&-1;
      $196 = (($195) + ($$0340496))|0;
      HEAP32[$192>>2] = $196;
      $197 = Math_imul($191, $194)|0;
      $198 = ($$4349495|0)==($$0350494|0);
      $199 = ($196|0)==(0);
      $or$cond420 = $198 & $199;
      $200 = (($$0350494) + 1)|0;
      $201 = $200 & 127;
      $202 = (($$0385493) + -9)|0;
      $$$0385 = $or$cond420 ? $202 : $$0385493;
      $$$0350 = $or$cond420 ? $201 : $$0350494;
      $203 = (($$4349495) + 1)|0;
      $204 = ($203|0)==($$3348|0);
      if ($204) {
       break;
      } else {
       $$0340496 = $197;$$0350494 = $$$0350;$$0385493 = $$$0385;$$4349495 = $203;
      }
     }
     $205 = ($197|0)==(0);
     if ($205) {
      $$0350$lcssa554 = $$$0350;$$0372 = $$3348;$$0385$lcssa553 = $$$0385;
     } else {
      $206 = (($6) + ($$3348<<2)|0);
      $207 = (($$3348) + 1)|0;
      HEAP32[$206>>2] = $197;
      $$0350$lcssa554 = $$$0350;$$0372 = $207;$$0385$lcssa553 = $$$0385;
     }
    }
    $208 = (9 - ($186))|0;
    $209 = (($208) + ($$0385$lcssa553))|0;
    $$0380$ph = 0;$$1373$ph448 = $$0372;$$2352$ph449 = $$0350$lcssa554;$$2387$ph447 = $209;
   }
   L101: while(1) {
    $210 = ($$2387$ph447|0)<(18);
    $211 = ($$2387$ph447|0)==(18);
    $212 = (($6) + ($$2352$ph449<<2)|0);
    $$0380 = $$0380$ph;$$1373 = $$1373$ph448;
    while(1) {
     if (!($210)) {
      if (!($211)) {
       $$1381$ph = $$0380;$$4354$ph = $$2352$ph449;$$4389$ph445 = $$2387$ph447;$$6378$ph = $$1373;
       break L101;
      }
      $213 = HEAP32[$212>>2]|0;
      $214 = ($213>>>0)<(9007199);
      if (!($214)) {
       $$1381$ph = $$0380;$$4354$ph = $$2352$ph449;$$4389$ph445 = 18;$$6378$ph = $$1373;
       break L101;
      }
     }
     $215 = (($$1373) + 127)|0;
     $$0334 = 0;$$2374 = $$1373;$$5$in = $215;
     while(1) {
      $$5 = $$5$in & 127;
      $216 = (($6) + ($$5<<2)|0);
      $217 = HEAP32[$216>>2]|0;
      $218 = (_bitshift64Shl(($217|0),0,29)|0);
      $219 = tempRet0;
      $220 = (_i64Add(($218|0),($219|0),($$0334|0),0)|0);
      $221 = tempRet0;
      $222 = ($221>>>0)>(0);
      $223 = ($220>>>0)>(1000000000);
      $224 = ($221|0)==(0);
      $225 = $224 & $223;
      $226 = $222 | $225;
      if ($226) {
       $227 = (___udivdi3(($220|0),($221|0),1000000000,0)|0);
       $228 = tempRet0;
       $229 = (___uremdi3(($220|0),($221|0),1000000000,0)|0);
       $230 = tempRet0;
       $$1335 = $227;$$sink421$off0 = $229;
      } else {
       $$1335 = 0;$$sink421$off0 = $220;
      }
      HEAP32[$216>>2] = $$sink421$off0;
      $231 = (($$2374) + 127)|0;
      $232 = $231 & 127;
      $233 = ($$5|0)!=($232|0);
      $234 = ($$5|0)==($$2352$ph449|0);
      $or$cond422 = $233 | $234;
      $or$cond422$not = $or$cond422 ^ 1;
      $235 = ($$sink421$off0|0)==(0);
      $or$cond423 = $235 & $or$cond422$not;
      $$3375 = $or$cond423 ? $$5 : $$2374;
      $236 = (($$5) + -1)|0;
      if ($234) {
       break;
      } else {
       $$0334 = $$1335;$$2374 = $$3375;$$5$in = $236;
      }
     }
     $237 = (($$0380) + -29)|0;
     $238 = ($$1335|0)==(0);
     if ($238) {
      $$0380 = $237;$$1373 = $$3375;
     } else {
      break;
     }
    }
    $239 = (($$2387$ph447) + 9)|0;
    $240 = (($$2352$ph449) + 127)|0;
    $241 = $240 & 127;
    $242 = ($241|0)==($$3375|0);
    $243 = (($$3375) + 127)|0;
    $244 = $243 & 127;
    $245 = (($$3375) + 126)|0;
    $246 = $245 & 127;
    $247 = (($6) + ($246<<2)|0);
    if ($242) {
     $248 = (($6) + ($244<<2)|0);
     $249 = HEAP32[$248>>2]|0;
     $250 = HEAP32[$247>>2]|0;
     $251 = $250 | $249;
     HEAP32[$247>>2] = $251;
     $$4376 = $244;
    } else {
     $$4376 = $$3375;
    }
    $252 = (($6) + ($241<<2)|0);
    HEAP32[$252>>2] = $$1335;
    $$0380$ph = $237;$$1373$ph448 = $$4376;$$2352$ph449 = $241;$$2387$ph447 = $239;
   }
   L119: while(1) {
    $289 = (($$6378$ph) + 1)|0;
    $286 = $289 & 127;
    $290 = (($$6378$ph) + 127)|0;
    $291 = $290 & 127;
    $292 = (($6) + ($291<<2)|0);
    $$1381$ph558 = $$1381$ph;$$4354$ph559 = $$4354$ph;$$4389$ph = $$4389$ph445;
    while(1) {
     $265 = ($$4389$ph|0)==(18);
     $293 = ($$4389$ph|0)>(27);
     $$425 = $293 ? 9 : 1;
     $$1381 = $$1381$ph558;$$4354 = $$4354$ph559;
     while(1) {
      $$0336486 = 0;
      while(1) {
       $253 = (($$0336486) + ($$4354))|0;
       $254 = $253 & 127;
       $255 = ($254|0)==($$6378$ph|0);
       if ($255) {
        $$1337 = 2;
        label = 88;
        break;
       }
       $256 = (($6) + ($254<<2)|0);
       $257 = HEAP32[$256>>2]|0;
       $258 = (92840 + ($$0336486<<2)|0);
       $259 = HEAP32[$258>>2]|0;
       $260 = ($257>>>0)<($259>>>0);
       if ($260) {
        $$1337 = 2;
        label = 88;
        break;
       }
       $261 = ($257>>>0)>($259>>>0);
       if ($261) {
        break;
       }
       $262 = (($$0336486) + 1)|0;
       $263 = ($262|0)<(2);
       if ($263) {
        $$0336486 = $262;
       } else {
        $$1337 = $262;
        label = 88;
        break;
       }
      }
      if ((label|0) == 88) {
       label = 0;
       $264 = ($$1337|0)==(2);
       $or$cond11 = $265 & $264;
       if ($or$cond11) {
        $$0365484 = 0.0;$$4485 = 0;$$9483 = $$6378$ph;
        break L119;
       }
      }
      $266 = (($$425) + ($$1381))|0;
      $267 = ($$4354|0)==($$6378$ph|0);
      if ($267) {
       $$1381 = $266;$$4354 = $$6378$ph;
      } else {
       break;
      }
     }
     $268 = 1 << $$425;
     $269 = (($268) + -1)|0;
     $270 = 1000000000 >>> $$425;
     $$0332490 = 0;$$5355488 = $$4354;$$5390487 = $$4389$ph;$$6489 = $$4354;
     while(1) {
      $271 = (($6) + ($$6489<<2)|0);
      $272 = HEAP32[$271>>2]|0;
      $273 = $272 & $269;
      $274 = $272 >>> $$425;
      $275 = (($274) + ($$0332490))|0;
      HEAP32[$271>>2] = $275;
      $276 = Math_imul($273, $270)|0;
      $277 = ($$6489|0)==($$5355488|0);
      $278 = ($275|0)==(0);
      $or$cond426 = $277 & $278;
      $279 = (($$5355488) + 1)|0;
      $280 = $279 & 127;
      $281 = (($$5390487) + -9)|0;
      $$$5390 = $or$cond426 ? $281 : $$5390487;
      $$$5355 = $or$cond426 ? $280 : $$5355488;
      $282 = (($$6489) + 1)|0;
      $283 = $282 & 127;
      $284 = ($283|0)==($$6378$ph|0);
      if ($284) {
       break;
      } else {
       $$0332490 = $276;$$5355488 = $$$5355;$$5390487 = $$$5390;$$6489 = $283;
      }
     }
     $285 = ($276|0)==(0);
     if ($285) {
      $$1381$ph558 = $266;$$4354$ph559 = $$$5355;$$4389$ph = $$$5390;
      continue;
     }
     $287 = ($286|0)==($$$5355|0);
     if (!($287)) {
      break;
     }
     $294 = HEAP32[$292>>2]|0;
     $295 = $294 | 1;
     HEAP32[$292>>2] = $295;
     $$1381$ph558 = $266;$$4354$ph559 = $$$5355;$$4389$ph = $$$5390;
    }
    $288 = (($6) + ($$6378$ph<<2)|0);
    HEAP32[$288>>2] = $276;
    $$1381$ph = $266;$$4354$ph = $$$5355;$$4389$ph445 = $$$5390;$$6378$ph = $286;
   }
   while(1) {
    $296 = (($$4485) + ($$4354))|0;
    $297 = $296 & 127;
    $298 = ($297|0)==($$9483|0);
    $299 = (($$9483) + 1)|0;
    $300 = $299 & 127;
    if ($298) {
     $301 = (($300) + -1)|0;
     $302 = (($6) + ($301<<2)|0);
     HEAP32[$302>>2] = 0;
     $$10 = $300;
    } else {
     $$10 = $$9483;
    }
    $303 = $$0365484 * 1.0E+9;
    $304 = (($6) + ($297<<2)|0);
    $305 = HEAP32[$304>>2]|0;
    $306 = (+($305>>>0));
    $307 = $303 + $306;
    $308 = (($$4485) + 1)|0;
    $exitcond = ($308|0)==(2);
    if ($exitcond) {
     break;
    } else {
     $$0365484 = $307;$$4485 = $308;$$9483 = $$10;
    }
   }
   $309 = (+($4|0));
   $310 = $309 * $307;
   $311 = (($$1381) + 53)|0;
   $312 = (($311) - ($3))|0;
   $313 = ($312|0)<($2|0);
   $314 = ($312|0)>(0);
   $$ = $314 ? $312 : 0;
   $$0333 = $313 ? $$ : $2;
   $315 = ($$0333|0)<(53);
   if ($315) {
    $316 = (105 - ($$0333))|0;
    $317 = (+_scalbn(1.0,$316));
    $318 = (+_copysignl($317,$310));
    $319 = (53 - ($$0333))|0;
    $320 = (+_scalbn(1.0,$319));
    $321 = (+_fmodl($310,$320));
    $322 = $310 - $321;
    $323 = $318 + $322;
    $$0360 = $318;$$0361 = $321;$$1366 = $323;
   } else {
    $$0360 = 0.0;$$0361 = 0.0;$$1366 = $310;
   }
   $324 = (($$4354) + 2)|0;
   $325 = $324 & 127;
   $326 = ($325|0)==($$10|0);
   if ($326) {
    $$3364 = $$0361;
   } else {
    $327 = (($6) + ($325<<2)|0);
    $328 = HEAP32[$327>>2]|0;
    $329 = ($328>>>0)<(500000000);
    do {
     if ($329) {
      $330 = ($328|0)==(0);
      if ($330) {
       $331 = (($$4354) + 3)|0;
       $332 = $331 & 127;
       $333 = ($332|0)==($$10|0);
       if ($333) {
        $$1362 = $$0361;
        break;
       }
      }
      $334 = $309 * 0.25;
      $335 = $334 + $$0361;
      $$1362 = $335;
     } else {
      $336 = ($328|0)==(500000000);
      if (!($336)) {
       $337 = $309 * 0.75;
       $338 = $337 + $$0361;
       $$1362 = $338;
       break;
      }
      $339 = (($$4354) + 3)|0;
      $340 = $339 & 127;
      $341 = ($340|0)==($$10|0);
      if ($341) {
       $342 = $309 * 0.5;
       $343 = $342 + $$0361;
       $$1362 = $343;
       break;
      } else {
       $344 = $309 * 0.75;
       $345 = $344 + $$0361;
       $$1362 = $345;
       break;
      }
     }
    } while(0);
    $346 = (53 - ($$0333))|0;
    $347 = ($346|0)>(1);
    if ($347) {
     $348 = (+_fmodl($$1362,1.0));
     $349 = $348 != 0.0;
     if ($349) {
      $$3364 = $$1362;
     } else {
      $350 = $$1362 + 1.0;
      $$3364 = $350;
     }
    } else {
     $$3364 = $$1362;
    }
   }
   $351 = $$1366 + $$3364;
   $352 = $351 - $$0360;
   $353 = $311 & 2147483647;
   $354 = (-2 - ($sum))|0;
   $355 = ($353|0)>($354|0);
   do {
    if ($355) {
     $356 = (+Math_abs((+$352)));
     $357 = !($356 >= 9007199254740992.0);
     $358 = $352 * 0.5;
     $not$ = $357 ^ 1;
     $359 = $not$&1;
     $$3383 = (($359) + ($$1381))|0;
     $$2367 = $357 ? $352 : $358;
     $360 = (($$3383) + 50)|0;
     $361 = ($360|0)>($7|0);
     if (!($361)) {
      $362 = ($$0333|0)!=($312|0);
      $narrow = $362 | $357;
      $$2371$v = $313 & $narrow;
      $363 = $$3364 != 0.0;
      $or$cond14 = $363 & $$2371$v;
      if (!($or$cond14)) {
       $$3368 = $$2367;$$4384 = $$3383;
       break;
      }
     }
     $364 = (___errno_location()|0);
     HEAP32[$364>>2] = 34;
     $$3368 = $$2367;$$4384 = $$3383;
    } else {
     $$3368 = $352;$$4384 = $$1381;
    }
   } while(0);
   $365 = (+_scalbnl($$3368,$$4384));
   $$1 = $365;
  }
 } while(0);
 STACKTOP = sp;return (+$$1);
}
function _scanexp($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$04861 = 0, $$049 = 0, $$1$be = 0, $$160 = 0, $$2$be = 0, $$2$lcssa = 0, $$254 = 0, $$3$be = 0, $$lcssa = 0, $$pre = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 100|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)<($5>>>0);
 if ($6) {
  $7 = ((($3)) + 1|0);
  HEAP32[$2>>2] = $7;
  $8 = HEAP8[$3>>0]|0;
  $9 = $8&255;
  $11 = $9;
 } else {
  $10 = (___shgetc($0)|0);
  $11 = $10;
 }
 switch ($11|0) {
 case 43: case 45:  {
  $12 = ($11|0)==(45);
  $13 = $12&1;
  $14 = HEAP32[$2>>2]|0;
  $15 = HEAP32[$4>>2]|0;
  $16 = ($14>>>0)<($15>>>0);
  if ($16) {
   $17 = ((($14)) + 1|0);
   HEAP32[$2>>2] = $17;
   $18 = HEAP8[$14>>0]|0;
   $19 = $18&255;
   $22 = $19;
  } else {
   $20 = (___shgetc($0)|0);
   $22 = $20;
  }
  $21 = (($22) + -48)|0;
  $23 = ($21>>>0)>(9);
  $24 = ($1|0)!=(0);
  $or$cond3 = $24 & $23;
  if ($or$cond3) {
   $25 = HEAP32[$4>>2]|0;
   $26 = ($25|0)==(0|0);
   if ($26) {
    $$0 = $13;$$049 = $22;
   } else {
    $27 = HEAP32[$2>>2]|0;
    $28 = ((($27)) + -1|0);
    HEAP32[$2>>2] = $28;
    $$0 = $13;$$049 = $22;
   }
  } else {
   $$0 = $13;$$049 = $22;
  }
  break;
 }
 default: {
  $$0 = 0;$$049 = $11;
 }
 }
 $29 = (($$049) + -48)|0;
 $30 = ($29>>>0)>(9);
 if ($30) {
  $31 = HEAP32[$4>>2]|0;
  $32 = ($31|0)==(0|0);
  if ($32) {
   $100 = -2147483648;$101 = 0;
  } else {
   $33 = HEAP32[$2>>2]|0;
   $34 = ((($33)) + -1|0);
   HEAP32[$2>>2] = $34;
   $100 = -2147483648;$101 = 0;
  }
 } else {
  $$04861 = 0;$$160 = $$049;
  while(1) {
   $35 = ($$04861*10)|0;
   $36 = (($$160) + -48)|0;
   $37 = (($36) + ($35))|0;
   $38 = HEAP32[$2>>2]|0;
   $39 = HEAP32[$4>>2]|0;
   $40 = ($38>>>0)<($39>>>0);
   if ($40) {
    $41 = ((($38)) + 1|0);
    HEAP32[$2>>2] = $41;
    $42 = HEAP8[$38>>0]|0;
    $43 = $42&255;
    $$1$be = $43;
   } else {
    $44 = (___shgetc($0)|0);
    $$1$be = $44;
   }
   $45 = (($$1$be) + -48)|0;
   $46 = ($45>>>0)<(10);
   $47 = ($37|0)<(214748364);
   $48 = $46 & $47;
   if ($48) {
    $$04861 = $37;$$160 = $$1$be;
   } else {
    break;
   }
  }
  $49 = ($37|0)<(0);
  $50 = $49 << 31 >> 31;
  $51 = (($$1$be) + -48)|0;
  $52 = ($51>>>0)<(10);
  if ($52) {
   $$254 = $$1$be;$56 = $37;$57 = $50;
   while(1) {
    $58 = (___muldi3(($56|0),($57|0),10,0)|0);
    $59 = tempRet0;
    $60 = ($$254|0)<(0);
    $61 = $60 << 31 >> 31;
    $62 = (_i64Add(($$254|0),($61|0),-48,-1)|0);
    $63 = tempRet0;
    $64 = (_i64Add(($62|0),($63|0),($58|0),($59|0))|0);
    $65 = tempRet0;
    $66 = HEAP32[$2>>2]|0;
    $67 = HEAP32[$4>>2]|0;
    $68 = ($66>>>0)<($67>>>0);
    if ($68) {
     $69 = ((($66)) + 1|0);
     HEAP32[$2>>2] = $69;
     $70 = HEAP8[$66>>0]|0;
     $71 = $70&255;
     $$2$be = $71;
    } else {
     $72 = (___shgetc($0)|0);
     $$2$be = $72;
    }
    $73 = (($$2$be) + -48)|0;
    $74 = ($73>>>0)<(10);
    $75 = ($65|0)<(21474836);
    $76 = ($64>>>0)<(2061584302);
    $77 = ($65|0)==(21474836);
    $78 = $77 & $76;
    $79 = $75 | $78;
    $80 = $74 & $79;
    if ($80) {
     $$254 = $$2$be;$56 = $64;$57 = $65;
    } else {
     $$2$lcssa = $$2$be;$94 = $64;$95 = $65;
     break;
    }
   }
  } else {
   $$2$lcssa = $$1$be;$94 = $37;$95 = $50;
  }
  $53 = (($$2$lcssa) + -48)|0;
  $54 = ($53>>>0)<(10);
  $55 = HEAP32[$4>>2]|0;
  if ($54) {
   $83 = $55;
   while(1) {
    $81 = HEAP32[$2>>2]|0;
    $82 = ($81>>>0)<($83>>>0);
    if ($82) {
     $84 = ((($81)) + 1|0);
     HEAP32[$2>>2] = $84;
     $85 = HEAP8[$81>>0]|0;
     $86 = $85&255;
     $$3$be = $86;$102 = $83;
    } else {
     $87 = (___shgetc($0)|0);
     $$pre = HEAP32[$4>>2]|0;
     $$3$be = $87;$102 = $$pre;
    }
    $88 = (($$3$be) + -48)|0;
    $89 = ($88>>>0)<(10);
    if ($89) {
     $83 = $102;
    } else {
     $$lcssa = $102;
     break;
    }
   }
  } else {
   $$lcssa = $55;
  }
  $90 = ($$lcssa|0)==(0|0);
  if (!($90)) {
   $91 = HEAP32[$2>>2]|0;
   $92 = ((($91)) + -1|0);
   HEAP32[$2>>2] = $92;
  }
  $93 = ($$0|0)!=(0);
  $96 = (_i64Subtract(0,0,($94|0),($95|0))|0);
  $97 = tempRet0;
  $98 = $93 ? $96 : $94;
  $99 = $93 ? $97 : $95;
  $100 = $99;$101 = $98;
 }
 tempRet0 = ($100);
 return ($101|0);
}
function _scalbn($0,$1) {
 $0 = +$0;
 $1 = $1|0;
 var $$ = 0, $$$ = 0, $$0 = 0.0, $$020 = 0, $$1 = 0, $$1$ = 0, $$21 = 0.0, $$22 = 0.0, $10 = 0.0, $11 = 0, $12 = 0, $13 = 0.0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0.0, $2 = 0, $20 = 0.0;
 var $3 = 0.0, $4 = 0, $5 = 0, $6 = 0.0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)>(1023);
 if ($2) {
  $3 = $0 * 8.9884656743115795E+307;
  $4 = (($1) + -1023)|0;
  $5 = ($4|0)>(1023);
  $6 = $3 * 8.9884656743115795E+307;
  $7 = (($1) + -2046)|0;
  $8 = ($7|0)<(1023);
  $$ = $8 ? $7 : 1023;
  $$$ = $5 ? $$ : $4;
  $$21 = $5 ? $6 : $3;
  $$0 = $$21;$$020 = $$$;
 } else {
  $9 = ($1|0)<(-1022);
  if ($9) {
   $10 = $0 * 2.2250738585072014E-308;
   $11 = (($1) + 1022)|0;
   $12 = ($11|0)<(-1022);
   $13 = $10 * 2.2250738585072014E-308;
   $14 = (($1) + 2044)|0;
   $15 = ($14|0)>(-1022);
   $$1 = $15 ? $14 : -1022;
   $$1$ = $12 ? $$1 : $11;
   $$22 = $12 ? $13 : $10;
   $$0 = $$22;$$020 = $$1$;
  } else {
   $$0 = $0;$$020 = $1;
  }
 }
 $16 = (($$020) + 1023)|0;
 $17 = (_bitshift64Shl(($16|0),0,52)|0);
 $18 = tempRet0;
 HEAP32[tempDoublePtr>>2] = $17;HEAP32[tempDoublePtr+4>>2] = $18;$19 = +HEAPF64[tempDoublePtr>>3];
 $20 = $$0 * $19;
 return (+$20);
}
function _copysignl($0,$1) {
 $0 = +$0;
 $1 = +$1;
 var $2 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (+_copysign($0,$1));
 return (+$2);
}
function _fmodl($0,$1) {
 $0 = +$0;
 $1 = +$1;
 var $2 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (+_fmod($0,$1));
 return (+$2);
}
function _scalbnl($0,$1) {
 $0 = +$0;
 $1 = $1|0;
 var $2 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (+_scalbn($0,$1));
 return (+$2);
}
function _fmod($0,$1) {
 $0 = +$0;
 $1 = +$1;
 var $$ = 0.0, $$070 = 0.0, $$071$lcssa = 0, $$07194 = 0, $$073$lcssa = 0, $$073100 = 0, $$172$ph = 0, $$174 = 0, $$275$lcssa = 0, $$27586 = 0, $$376$lcssa = 0, $$37683 = 0, $$lcssa = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0.0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0.0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0.0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0;
 var $160 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0.0, $28 = 0.0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0.0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF64[tempDoublePtr>>3] = $0;$2 = HEAP32[tempDoublePtr>>2]|0;
 $3 = HEAP32[tempDoublePtr+4>>2]|0;
 HEAPF64[tempDoublePtr>>3] = $1;$4 = HEAP32[tempDoublePtr>>2]|0;
 $5 = HEAP32[tempDoublePtr+4>>2]|0;
 $6 = (_bitshift64Lshr(($2|0),($3|0),52)|0);
 $7 = tempRet0;
 $8 = $6 & 2047;
 $9 = (_bitshift64Lshr(($4|0),($5|0),52)|0);
 $10 = tempRet0;
 $11 = $9 & 2047;
 $12 = $3 & -2147483648;
 $13 = (_bitshift64Shl(($4|0),($5|0),1)|0);
 $14 = tempRet0;
 $15 = ($13|0)==(0);
 $16 = ($14|0)==(0);
 $17 = $15 & $16;
 L1: do {
  if ($17) {
   label = 3;
  } else {
   $18 = (___DOUBLE_BITS_82($1)|0);
   $19 = tempRet0;
   $20 = $19 & 2147483647;
   $21 = ($20>>>0)>(2146435072);
   $22 = ($18>>>0)>(0);
   $23 = ($20|0)==(2146435072);
   $24 = $23 & $22;
   $25 = $21 | $24;
   $26 = ($8|0)==(2047);
   $or$cond = $26 | $25;
   if ($or$cond) {
    label = 3;
   } else {
    $29 = (_bitshift64Shl(($2|0),($3|0),1)|0);
    $30 = tempRet0;
    $31 = ($30>>>0)>($14>>>0);
    $32 = ($29>>>0)>($13>>>0);
    $33 = ($30|0)==($14|0);
    $34 = $33 & $32;
    $35 = $31 | $34;
    if (!($35)) {
     $36 = ($29|0)==($13|0);
     $37 = ($30|0)==($14|0);
     $38 = $36 & $37;
     $39 = $0 * 0.0;
     $$ = $38 ? $39 : $0;
     return (+$$);
    }
    $40 = ($8|0)==(0);
    if ($40) {
     $41 = (_bitshift64Shl(($2|0),($3|0),12)|0);
     $42 = tempRet0;
     $43 = ($42|0)>(-1);
     $44 = ($41>>>0)>(4294967295);
     $45 = ($42|0)==(-1);
     $46 = $45 & $44;
     $47 = $43 | $46;
     if ($47) {
      $$073100 = 0;$49 = $41;$50 = $42;
      while(1) {
       $48 = (($$073100) + -1)|0;
       $51 = (_bitshift64Shl(($49|0),($50|0),1)|0);
       $52 = tempRet0;
       $53 = ($52|0)>(-1);
       $54 = ($51>>>0)>(4294967295);
       $55 = ($52|0)==(-1);
       $56 = $55 & $54;
       $57 = $53 | $56;
       if ($57) {
        $$073100 = $48;$49 = $51;$50 = $52;
       } else {
        $$073$lcssa = $48;
        break;
       }
      }
     } else {
      $$073$lcssa = 0;
     }
     $58 = (1 - ($$073$lcssa))|0;
     $59 = (_bitshift64Shl(($2|0),($3|0),($58|0))|0);
     $60 = tempRet0;
     $$174 = $$073$lcssa;$87 = $59;$88 = $60;
    } else {
     $61 = $3 & 1048575;
     $62 = $61 | 1048576;
     $$174 = $8;$87 = $2;$88 = $62;
    }
    $63 = ($11|0)==(0);
    if ($63) {
     $64 = (_bitshift64Shl(($4|0),($5|0),12)|0);
     $65 = tempRet0;
     $66 = ($65|0)>(-1);
     $67 = ($64>>>0)>(4294967295);
     $68 = ($65|0)==(-1);
     $69 = $68 & $67;
     $70 = $66 | $69;
     if ($70) {
      $$07194 = 0;$72 = $64;$73 = $65;
      while(1) {
       $71 = (($$07194) + -1)|0;
       $74 = (_bitshift64Shl(($72|0),($73|0),1)|0);
       $75 = tempRet0;
       $76 = ($75|0)>(-1);
       $77 = ($74>>>0)>(4294967295);
       $78 = ($75|0)==(-1);
       $79 = $78 & $77;
       $80 = $76 | $79;
       if ($80) {
        $$07194 = $71;$72 = $74;$73 = $75;
       } else {
        $$071$lcssa = $71;
        break;
       }
      }
     } else {
      $$071$lcssa = 0;
     }
     $81 = (1 - ($$071$lcssa))|0;
     $82 = (_bitshift64Shl(($4|0),($5|0),($81|0))|0);
     $83 = tempRet0;
     $$172$ph = $$071$lcssa;$89 = $82;$90 = $83;
    } else {
     $84 = $5 & 1048575;
     $85 = $84 | 1048576;
     $$172$ph = $11;$89 = $4;$90 = $85;
    }
    $86 = ($$174|0)>($$172$ph|0);
    $91 = (_i64Subtract(($87|0),($88|0),($89|0),($90|0))|0);
    $92 = tempRet0;
    $93 = ($92|0)>(-1);
    $94 = ($91>>>0)>(4294967295);
    $95 = ($92|0)==(-1);
    $96 = $95 & $94;
    $97 = $93 | $96;
    L23: do {
     if ($86) {
      $$27586 = $$174;$100 = $92;$156 = $97;$157 = $87;$158 = $88;$98 = $91;
      while(1) {
       if ($156) {
        $99 = ($98|0)==(0);
        $101 = ($100|0)==(0);
        $102 = $99 & $101;
        if ($102) {
         break;
        } else {
         $104 = $98;$105 = $100;
        }
       } else {
        $104 = $157;$105 = $158;
       }
       $106 = (_bitshift64Shl(($104|0),($105|0),1)|0);
       $107 = tempRet0;
       $108 = (($$27586) + -1)|0;
       $109 = ($108|0)>($$172$ph|0);
       $110 = (_i64Subtract(($106|0),($107|0),($89|0),($90|0))|0);
       $111 = tempRet0;
       $112 = ($111|0)>(-1);
       $113 = ($110>>>0)>(4294967295);
       $114 = ($111|0)==(-1);
       $115 = $114 & $113;
       $116 = $112 | $115;
       if ($109) {
        $$27586 = $108;$100 = $111;$156 = $116;$157 = $106;$158 = $107;$98 = $110;
       } else {
        $$275$lcssa = $108;$$lcssa = $116;$117 = $110;$119 = $111;$159 = $106;$160 = $107;
        break L23;
       }
      }
      $103 = $0 * 0.0;
      $$070 = $103;
      break L1;
     } else {
      $$275$lcssa = $$174;$$lcssa = $97;$117 = $91;$119 = $92;$159 = $87;$160 = $88;
     }
    } while(0);
    if ($$lcssa) {
     $118 = ($117|0)==(0);
     $120 = ($119|0)==(0);
     $121 = $118 & $120;
     if ($121) {
      $129 = $0 * 0.0;
      $$070 = $129;
      break;
     } else {
      $122 = $119;$124 = $117;
     }
    } else {
     $122 = $160;$124 = $159;
    }
    $123 = ($122>>>0)<(1048576);
    $125 = ($124>>>0)<(0);
    $126 = ($122|0)==(1048576);
    $127 = $126 & $125;
    $128 = $123 | $127;
    if ($128) {
     $$37683 = $$275$lcssa;$130 = $124;$131 = $122;
     while(1) {
      $132 = (_bitshift64Shl(($130|0),($131|0),1)|0);
      $133 = tempRet0;
      $134 = (($$37683) + -1)|0;
      $135 = ($133>>>0)<(1048576);
      $136 = ($132>>>0)<(0);
      $137 = ($133|0)==(1048576);
      $138 = $137 & $136;
      $139 = $135 | $138;
      if ($139) {
       $$37683 = $134;$130 = $132;$131 = $133;
      } else {
       $$376$lcssa = $134;$141 = $132;$142 = $133;
       break;
      }
     }
    } else {
     $$376$lcssa = $$275$lcssa;$141 = $124;$142 = $122;
    }
    $140 = ($$376$lcssa|0)>(0);
    if ($140) {
     $143 = (_i64Add(($141|0),($142|0),0,-1048576)|0);
     $144 = tempRet0;
     $145 = (_bitshift64Shl(($$376$lcssa|0),0,52)|0);
     $146 = tempRet0;
     $147 = $143 | $145;
     $148 = $144 | $146;
     $153 = $148;$155 = $147;
    } else {
     $149 = (1 - ($$376$lcssa))|0;
     $150 = (_bitshift64Lshr(($141|0),($142|0),($149|0))|0);
     $151 = tempRet0;
     $153 = $151;$155 = $150;
    }
    $152 = $153 | $12;
    HEAP32[tempDoublePtr>>2] = $155;HEAP32[tempDoublePtr+4>>2] = $152;$154 = +HEAPF64[tempDoublePtr>>3];
    $$070 = $154;
   }
  }
 } while(0);
 if ((label|0) == 3) {
  $27 = $0 * $1;
  $28 = $27 / $27;
  $$070 = $28;
 }
 return (+$$070);
}
function ___DOUBLE_BITS_82($0) {
 $0 = +$0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF64[tempDoublePtr>>3] = $0;$1 = HEAP32[tempDoublePtr>>2]|0;
 $2 = HEAP32[tempDoublePtr+4>>2]|0;
 tempRet0 = ($2);
 return ($1|0);
}
function _copysign($0,$1) {
 $0 = +$0;
 $1 = +$1;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF64[tempDoublePtr>>3] = $0;$2 = HEAP32[tempDoublePtr>>2]|0;
 $3 = HEAP32[tempDoublePtr+4>>2]|0;
 HEAPF64[tempDoublePtr>>3] = $1;$4 = HEAP32[tempDoublePtr>>2]|0;
 $5 = HEAP32[tempDoublePtr+4>>2]|0;
 $6 = $3 & 2147483647;
 $7 = $5 & -2147483648;
 $8 = $7 | $6;
 HEAP32[tempDoublePtr>>2] = $2;HEAP32[tempDoublePtr+4>>2] = $8;$9 = +HEAPF64[tempDoublePtr>>3];
 return (+$9);
}
function _wcslen($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$0 = $0;
 while(1) {
  $1 = HEAP32[$$0>>2]|0;
  $2 = ($1|0)==(0);
  $3 = ((($$0)) + 4|0);
  if ($2) {
   break;
  } else {
   $$0 = $3;
  }
 }
 $4 = $$0;
 $5 = $0;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 2;
 return ($7|0);
}
function _sprintf($0,$1,$varargs) {
 $0 = $0|0;
 $1 = $1|0;
 $varargs = $varargs|0;
 var $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 HEAP32[$2>>2] = $varargs;
 $3 = (_vsprintf($0,$1,$2)|0);
 STACKTOP = sp;return ($3|0);
}
function _atoi($0) {
 $0 = $0|0;
 var $$0 = 0, $$010$lcssa = 0, $$01016 = 0, $$011 = 0, $$1$ph = 0, $$112$ph = 0, $$11215 = 0, $$pre = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $isdigit = 0, $isdigit14 = 0, $isdigittmp = 0, $isdigittmp13 = 0, $isdigittmp17 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$011 = $0;
 while(1) {
  $1 = HEAP8[$$011>>0]|0;
  $2 = $1 << 24 >> 24;
  $3 = (_isspace($2)|0);
  $4 = ($3|0)==(0);
  $5 = ((($$011)) + 1|0);
  if ($4) {
   break;
  } else {
   $$011 = $5;
  }
 }
 switch ($2|0) {
 case 45:  {
  $$0 = 1;
  label = 5;
  break;
 }
 case 43:  {
  $$0 = 0;
  label = 5;
  break;
 }
 default: {
  $$1$ph = 0;$$112$ph = $$011;$7 = $1;
 }
 }
 if ((label|0) == 5) {
  $$pre = HEAP8[$5>>0]|0;
  $$1$ph = $$0;$$112$ph = $5;$7 = $$pre;
 }
 $6 = $7 << 24 >> 24;
 $isdigittmp13 = (($6) + -48)|0;
 $isdigit14 = ($isdigittmp13>>>0)<(10);
 if ($isdigit14) {
  $$01016 = 0;$$11215 = $$112$ph;$isdigittmp17 = $isdigittmp13;
  while(1) {
   $8 = ($$01016*10)|0;
   $9 = ((($$11215)) + 1|0);
   $10 = (($8) - ($isdigittmp17))|0;
   $11 = HEAP8[$9>>0]|0;
   $12 = $11 << 24 >> 24;
   $isdigittmp = (($12) + -48)|0;
   $isdigit = ($isdigittmp>>>0)<(10);
   if ($isdigit) {
    $$01016 = $10;$$11215 = $9;$isdigittmp17 = $isdigittmp;
   } else {
    $$010$lcssa = $10;
    break;
   }
  }
 } else {
  $$010$lcssa = 0;
 }
 $13 = ($$1$ph|0)!=(0);
 $14 = (0 - ($$010$lcssa))|0;
 $15 = $13 ? $$010$lcssa : $14;
 return ($15|0);
}
function ___strchrnul($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$029$lcssa = 0, $$02936 = 0, $$030$lcssa = 0, $$03039 = 0, $$1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond33 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = $1 & 255;
 $3 = ($2|0)==(0);
 L1: do {
  if ($3) {
   $8 = (_strlen($0)|0);
   $9 = (($0) + ($8)|0);
   $$0 = $9;
  } else {
   $4 = $0;
   $5 = $4 & 3;
   $6 = ($5|0)==(0);
   if ($6) {
    $$030$lcssa = $0;
   } else {
    $7 = $1&255;
    $$03039 = $0;
    while(1) {
     $10 = HEAP8[$$03039>>0]|0;
     $11 = ($10<<24>>24)==(0);
     $12 = ($10<<24>>24)==($7<<24>>24);
     $or$cond = $11 | $12;
     if ($or$cond) {
      $$0 = $$03039;
      break L1;
     }
     $13 = ((($$03039)) + 1|0);
     $14 = $13;
     $15 = $14 & 3;
     $16 = ($15|0)==(0);
     if ($16) {
      $$030$lcssa = $13;
      break;
     } else {
      $$03039 = $13;
     }
    }
   }
   $17 = Math_imul($2, 16843009)|0;
   $18 = HEAP32[$$030$lcssa>>2]|0;
   $19 = (($18) + -16843009)|0;
   $20 = $18 & -2139062144;
   $21 = $20 ^ -2139062144;
   $22 = $21 & $19;
   $23 = ($22|0)==(0);
   L10: do {
    if ($23) {
     $$02936 = $$030$lcssa;$25 = $18;
     while(1) {
      $24 = $25 ^ $17;
      $26 = (($24) + -16843009)|0;
      $27 = $24 & -2139062144;
      $28 = $27 ^ -2139062144;
      $29 = $28 & $26;
      $30 = ($29|0)==(0);
      if (!($30)) {
       $$029$lcssa = $$02936;
       break L10;
      }
      $31 = ((($$02936)) + 4|0);
      $32 = HEAP32[$31>>2]|0;
      $33 = (($32) + -16843009)|0;
      $34 = $32 & -2139062144;
      $35 = $34 ^ -2139062144;
      $36 = $35 & $33;
      $37 = ($36|0)==(0);
      if ($37) {
       $$02936 = $31;$25 = $32;
      } else {
       $$029$lcssa = $31;
       break;
      }
     }
    } else {
     $$029$lcssa = $$030$lcssa;
    }
   } while(0);
   $38 = $1&255;
   $$1 = $$029$lcssa;
   while(1) {
    $39 = HEAP8[$$1>>0]|0;
    $40 = ($39<<24>>24)==(0);
    $41 = ($39<<24>>24)==($38<<24>>24);
    $or$cond33 = $40 | $41;
    $42 = ((($$1)) + 1|0);
    if ($or$cond33) {
     $$0 = $$1;
     break;
    } else {
     $$1 = $42;
    }
   }
  }
 } while(0);
 return ($$0|0);
}
function _strlen($0) {
 $0 = $0|0;
 var $$0 = 0, $$015$lcssa = 0, $$01519 = 0, $$1$lcssa = 0, $$pn = 0, $$pre = 0, $$sink = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = $0;
 $2 = $1 & 3;
 $3 = ($2|0)==(0);
 L1: do {
  if ($3) {
   $$015$lcssa = $0;
   label = 4;
  } else {
   $$01519 = $0;$23 = $1;
   while(1) {
    $4 = HEAP8[$$01519>>0]|0;
    $5 = ($4<<24>>24)==(0);
    if ($5) {
     $$sink = $23;
     break L1;
    }
    $6 = ((($$01519)) + 1|0);
    $7 = $6;
    $8 = $7 & 3;
    $9 = ($8|0)==(0);
    if ($9) {
     $$015$lcssa = $6;
     label = 4;
     break;
    } else {
     $$01519 = $6;$23 = $7;
    }
   }
  }
 } while(0);
 if ((label|0) == 4) {
  $$0 = $$015$lcssa;
  while(1) {
   $10 = HEAP32[$$0>>2]|0;
   $11 = (($10) + -16843009)|0;
   $12 = $10 & -2139062144;
   $13 = $12 ^ -2139062144;
   $14 = $13 & $11;
   $15 = ($14|0)==(0);
   $16 = ((($$0)) + 4|0);
   if ($15) {
    $$0 = $16;
   } else {
    break;
   }
  }
  $17 = $10&255;
  $18 = ($17<<24>>24)==(0);
  if ($18) {
   $$1$lcssa = $$0;
  } else {
   $$pn = $$0;
   while(1) {
    $19 = ((($$pn)) + 1|0);
    $$pre = HEAP8[$19>>0]|0;
    $20 = ($$pre<<24>>24)==(0);
    if ($20) {
     $$1$lcssa = $19;
     break;
    } else {
     $$pn = $19;
    }
   }
  }
  $21 = $$1$lcssa;
  $$sink = $21;
 }
 $22 = (($$sink) - ($1))|0;
 return ($22|0);
}
function _vsprintf($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (_vsnprintf($0,2147483647,$1,$2)|0);
 return ($3|0);
}
function _vsnprintf($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$$015 = 0, $$0 = 0, $$014 = 0, $$015 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(128|0);
 $4 = sp + 124|0;
 $5 = sp;
 dest=$5; src=92848; stop=dest+124|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $6 = (($1) + -1)|0;
 $7 = ($6>>>0)>(2147483646);
 if ($7) {
  $8 = ($1|0)==(0);
  if ($8) {
   $$014 = $4;$$015 = 1;
   label = 4;
  } else {
   $9 = (___errno_location()|0);
   HEAP32[$9>>2] = 75;
   $$0 = -1;
  }
 } else {
  $$014 = $0;$$015 = $1;
  label = 4;
 }
 if ((label|0) == 4) {
  $10 = $$014;
  $11 = (-2 - ($10))|0;
  $12 = ($$015>>>0)>($11>>>0);
  $$$015 = $12 ? $11 : $$015;
  $13 = ((($5)) + 48|0);
  HEAP32[$13>>2] = $$$015;
  $14 = ((($5)) + 20|0);
  HEAP32[$14>>2] = $$014;
  $15 = ((($5)) + 44|0);
  HEAP32[$15>>2] = $$014;
  $16 = (($$014) + ($$$015)|0);
  $17 = ((($5)) + 16|0);
  HEAP32[$17>>2] = $16;
  $18 = ((($5)) + 28|0);
  HEAP32[$18>>2] = $16;
  $19 = (_vfprintf($5,$2,$3)|0);
  $20 = ($$$015|0)==(0);
  if ($20) {
   $$0 = $19;
  } else {
   $21 = HEAP32[$14>>2]|0;
   $22 = HEAP32[$17>>2]|0;
   $23 = ($21|0)==($22|0);
   $24 = $23 << 31 >> 31;
   $25 = (($21) + ($24)|0);
   HEAP8[$25>>0] = 0;
   $$0 = $19;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function _vfprintf($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$ = 0, $$0 = 0, $$1 = 0, $$1$ = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $vacopy_currentptr = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(224|0);
 $3 = sp + 120|0;
 $4 = sp + 80|0;
 $5 = sp;
 $6 = sp + 136|0;
 dest=$4; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $vacopy_currentptr = HEAP32[$2>>2]|0;
 HEAP32[$3>>2] = $vacopy_currentptr;
 $7 = (_printf_core(0,$1,$3,$5,$4)|0);
 $8 = ($7|0)<(0);
 if ($8) {
  $$0 = -1;
 } else {
  $9 = ((($0)) + 76|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10|0)>(-1);
  if ($11) {
   $12 = (___lockfile($0)|0);
   $39 = $12;
  } else {
   $39 = 0;
  }
  $13 = HEAP32[$0>>2]|0;
  $14 = $13 & 32;
  $15 = ((($0)) + 74|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = ($16<<24>>24)<(1);
  if ($17) {
   $18 = $13 & -33;
   HEAP32[$0>>2] = $18;
  }
  $19 = ((($0)) + 48|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = ($20|0)==(0);
  if ($21) {
   $23 = ((($0)) + 44|0);
   $24 = HEAP32[$23>>2]|0;
   HEAP32[$23>>2] = $6;
   $25 = ((($0)) + 28|0);
   HEAP32[$25>>2] = $6;
   $26 = ((($0)) + 20|0);
   HEAP32[$26>>2] = $6;
   HEAP32[$19>>2] = 80;
   $27 = ((($6)) + 80|0);
   $28 = ((($0)) + 16|0);
   HEAP32[$28>>2] = $27;
   $29 = (_printf_core($0,$1,$3,$5,$4)|0);
   $30 = ($24|0)==(0|0);
   if ($30) {
    $$1 = $29;
   } else {
    $31 = ((($0)) + 36|0);
    $32 = HEAP32[$31>>2]|0;
    (FUNCTION_TABLE_iiii[$32 & 8191]($0,0,0)|0);
    $33 = HEAP32[$26>>2]|0;
    $34 = ($33|0)==(0|0);
    $$ = $34 ? -1 : $29;
    HEAP32[$23>>2] = $24;
    HEAP32[$19>>2] = 0;
    HEAP32[$28>>2] = 0;
    HEAP32[$25>>2] = 0;
    HEAP32[$26>>2] = 0;
    $$1 = $$;
   }
  } else {
   $22 = (_printf_core($0,$1,$3,$5,$4)|0);
   $$1 = $22;
  }
  $35 = HEAP32[$0>>2]|0;
  $36 = $35 & 32;
  $37 = ($36|0)==(0);
  $$1$ = $37 ? $$1 : -1;
  $38 = $35 | $14;
  HEAP32[$0>>2] = $38;
  $40 = ($39|0)==(0);
  if (!($40)) {
   ___unlockfile($0);
  }
  $$0 = $$1$;
 }
 STACKTOP = sp;return ($$0|0);
}
function _printf_core($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$ = 0, $$$ = 0, $$$0259 = 0, $$$0262 = 0, $$$0269 = 0, $$$4266 = 0, $$$5 = 0, $$0 = 0, $$0228 = 0, $$0228$ = 0, $$0229322 = 0, $$0232 = 0, $$0235 = 0, $$0237 = 0, $$0240$lcssa = 0, $$0240$lcssa357 = 0, $$0240321 = 0, $$0243 = 0, $$0247 = 0, $$0249$lcssa = 0;
 var $$0249306 = 0, $$0252 = 0, $$0253 = 0, $$0254 = 0, $$0254$$0254$ = 0, $$0259 = 0, $$0262$lcssa = 0, $$0262311 = 0, $$0269 = 0, $$0269$phi = 0, $$1 = 0, $$1230333 = 0, $$1233 = 0, $$1236 = 0, $$1238 = 0, $$1241332 = 0, $$1244320 = 0, $$1248 = 0, $$1250 = 0, $$1255 = 0;
 var $$1260 = 0, $$1263 = 0, $$1263$ = 0, $$1270 = 0, $$2 = 0, $$2234 = 0, $$2239 = 0, $$2242305 = 0, $$2245 = 0, $$2251 = 0, $$2256 = 0, $$2256$ = 0, $$2256$$$2256 = 0, $$2261 = 0, $$2271 = 0, $$284$ = 0, $$289 = 0, $$290 = 0, $$3257 = 0, $$3265 = 0;
 var $$3272 = 0, $$3303 = 0, $$377 = 0, $$4258355 = 0, $$4266 = 0, $$5 = 0, $$6268 = 0, $$lcssa295 = 0, $$pre = 0, $$pre346 = 0, $$pre347 = 0, $$pre347$pre = 0, $$pre349 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0;
 var $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0;
 var $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0;
 var $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0;
 var $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0;
 var $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0;
 var $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0;
 var $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0;
 var $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0;
 var $306 = 0.0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0;
 var $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $arglist_current = 0, $arglist_current2 = 0, $arglist_next = 0, $arglist_next3 = 0, $expanded = 0, $expanded10 = 0, $expanded11 = 0, $expanded13 = 0, $expanded14 = 0, $expanded15 = 0, $expanded4 = 0, $expanded6 = 0, $expanded7 = 0, $expanded8 = 0, $isdigit = 0, $isdigit275 = 0, $isdigit277 = 0, $isdigittmp = 0, $isdigittmp$ = 0, $isdigittmp274 = 0;
 var $isdigittmp276 = 0, $narrow = 0, $or$cond = 0, $or$cond281 = 0, $or$cond283 = 0, $or$cond286 = 0, $storemerge = 0, $storemerge273310 = 0, $storemerge278 = 0, $trunc = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(64|0);
 $5 = sp + 16|0;
 $6 = sp;
 $7 = sp + 24|0;
 $8 = sp + 8|0;
 $9 = sp + 20|0;
 HEAP32[$5>>2] = $1;
 $10 = ($0|0)!=(0|0);
 $11 = ((($7)) + 40|0);
 $12 = $11;
 $13 = ((($7)) + 39|0);
 $14 = ((($8)) + 4|0);
 $$0243 = 0;$$0247 = 0;$$0269 = 0;$21 = $1;
 L1: while(1) {
  $15 = ($$0247|0)>(-1);
  do {
   if ($15) {
    $16 = (2147483647 - ($$0247))|0;
    $17 = ($$0243|0)>($16|0);
    if ($17) {
     $18 = (___errno_location()|0);
     HEAP32[$18>>2] = 75;
     $$1248 = -1;
     break;
    } else {
     $19 = (($$0243) + ($$0247))|0;
     $$1248 = $19;
     break;
    }
   } else {
    $$1248 = $$0247;
   }
  } while(0);
  $20 = HEAP8[$21>>0]|0;
  $22 = ($20<<24>>24)==(0);
  if ($22) {
   label = 87;
   break;
  } else {
   $23 = $20;$25 = $21;
  }
  L9: while(1) {
   switch ($23<<24>>24) {
   case 37:  {
    $$0249306 = $25;$27 = $25;
    label = 9;
    break L9;
    break;
   }
   case 0:  {
    $$0249$lcssa = $25;$39 = $25;
    break L9;
    break;
   }
   default: {
   }
   }
   $24 = ((($25)) + 1|0);
   HEAP32[$5>>2] = $24;
   $$pre = HEAP8[$24>>0]|0;
   $23 = $$pre;$25 = $24;
  }
  L12: do {
   if ((label|0) == 9) {
    while(1) {
     label = 0;
     $26 = ((($27)) + 1|0);
     $28 = HEAP8[$26>>0]|0;
     $29 = ($28<<24>>24)==(37);
     if (!($29)) {
      $$0249$lcssa = $$0249306;$39 = $27;
      break L12;
     }
     $30 = ((($$0249306)) + 1|0);
     $31 = ((($27)) + 2|0);
     HEAP32[$5>>2] = $31;
     $32 = HEAP8[$31>>0]|0;
     $33 = ($32<<24>>24)==(37);
     if ($33) {
      $$0249306 = $30;$27 = $31;
      label = 9;
     } else {
      $$0249$lcssa = $30;$39 = $31;
      break;
     }
    }
   }
  } while(0);
  $34 = $$0249$lcssa;
  $35 = $21;
  $36 = (($34) - ($35))|0;
  if ($10) {
   _out($0,$21,$36);
  }
  $37 = ($36|0)==(0);
  if (!($37)) {
   $$0269$phi = $$0269;$$0243 = $36;$$0247 = $$1248;$21 = $39;$$0269 = $$0269$phi;
   continue;
  }
  $38 = ((($39)) + 1|0);
  $40 = HEAP8[$38>>0]|0;
  $41 = $40 << 24 >> 24;
  $isdigittmp = (($41) + -48)|0;
  $isdigit = ($isdigittmp>>>0)<(10);
  if ($isdigit) {
   $42 = ((($39)) + 2|0);
   $43 = HEAP8[$42>>0]|0;
   $44 = ($43<<24>>24)==(36);
   $45 = ((($39)) + 3|0);
   $$377 = $44 ? $45 : $38;
   $$$0269 = $44 ? 1 : $$0269;
   $isdigittmp$ = $44 ? $isdigittmp : -1;
   $$0253 = $isdigittmp$;$$1270 = $$$0269;$storemerge = $$377;
  } else {
   $$0253 = -1;$$1270 = $$0269;$storemerge = $38;
  }
  HEAP32[$5>>2] = $storemerge;
  $46 = HEAP8[$storemerge>>0]|0;
  $47 = $46 << 24 >> 24;
  $48 = (($47) + -32)|0;
  $49 = ($48>>>0)<(32);
  L24: do {
   if ($49) {
    $$0262311 = 0;$329 = $46;$51 = $48;$storemerge273310 = $storemerge;
    while(1) {
     $50 = 1 << $51;
     $52 = $50 & 75913;
     $53 = ($52|0)==(0);
     if ($53) {
      $$0262$lcssa = $$0262311;$$lcssa295 = $329;$62 = $storemerge273310;
      break L24;
     }
     $54 = $50 | $$0262311;
     $55 = ((($storemerge273310)) + 1|0);
     HEAP32[$5>>2] = $55;
     $56 = HEAP8[$55>>0]|0;
     $57 = $56 << 24 >> 24;
     $58 = (($57) + -32)|0;
     $59 = ($58>>>0)<(32);
     if ($59) {
      $$0262311 = $54;$329 = $56;$51 = $58;$storemerge273310 = $55;
     } else {
      $$0262$lcssa = $54;$$lcssa295 = $56;$62 = $55;
      break;
     }
    }
   } else {
    $$0262$lcssa = 0;$$lcssa295 = $46;$62 = $storemerge;
   }
  } while(0);
  $60 = ($$lcssa295<<24>>24)==(42);
  if ($60) {
   $61 = ((($62)) + 1|0);
   $63 = HEAP8[$61>>0]|0;
   $64 = $63 << 24 >> 24;
   $isdigittmp276 = (($64) + -48)|0;
   $isdigit277 = ($isdigittmp276>>>0)<(10);
   if ($isdigit277) {
    $65 = ((($62)) + 2|0);
    $66 = HEAP8[$65>>0]|0;
    $67 = ($66<<24>>24)==(36);
    if ($67) {
     $68 = (($4) + ($isdigittmp276<<2)|0);
     HEAP32[$68>>2] = 10;
     $69 = HEAP8[$61>>0]|0;
     $70 = $69 << 24 >> 24;
     $71 = (($70) + -48)|0;
     $72 = (($3) + ($71<<3)|0);
     $73 = $72;
     $74 = $73;
     $75 = HEAP32[$74>>2]|0;
     $76 = (($73) + 4)|0;
     $77 = $76;
     $78 = HEAP32[$77>>2]|0;
     $79 = ((($62)) + 3|0);
     $$0259 = $75;$$2271 = 1;$storemerge278 = $79;
    } else {
     label = 23;
    }
   } else {
    label = 23;
   }
   if ((label|0) == 23) {
    label = 0;
    $80 = ($$1270|0)==(0);
    if (!($80)) {
     $$0 = -1;
     break;
    }
    if ($10) {
     $arglist_current = HEAP32[$2>>2]|0;
     $81 = $arglist_current;
     $82 = ((0) + 4|0);
     $expanded4 = $82;
     $expanded = (($expanded4) - 1)|0;
     $83 = (($81) + ($expanded))|0;
     $84 = ((0) + 4|0);
     $expanded8 = $84;
     $expanded7 = (($expanded8) - 1)|0;
     $expanded6 = $expanded7 ^ -1;
     $85 = $83 & $expanded6;
     $86 = $85;
     $87 = HEAP32[$86>>2]|0;
     $arglist_next = ((($86)) + 4|0);
     HEAP32[$2>>2] = $arglist_next;
     $$0259 = $87;$$2271 = 0;$storemerge278 = $61;
    } else {
     $$0259 = 0;$$2271 = 0;$storemerge278 = $61;
    }
   }
   HEAP32[$5>>2] = $storemerge278;
   $88 = ($$0259|0)<(0);
   $89 = $$0262$lcssa | 8192;
   $90 = (0 - ($$0259))|0;
   $$$0262 = $88 ? $89 : $$0262$lcssa;
   $$$0259 = $88 ? $90 : $$0259;
   $$1260 = $$$0259;$$1263 = $$$0262;$$3272 = $$2271;$94 = $storemerge278;
  } else {
   $91 = (_getint($5)|0);
   $92 = ($91|0)<(0);
   if ($92) {
    $$0 = -1;
    break;
   }
   $$pre346 = HEAP32[$5>>2]|0;
   $$1260 = $91;$$1263 = $$0262$lcssa;$$3272 = $$1270;$94 = $$pre346;
  }
  $93 = HEAP8[$94>>0]|0;
  $95 = ($93<<24>>24)==(46);
  do {
   if ($95) {
    $96 = ((($94)) + 1|0);
    $97 = HEAP8[$96>>0]|0;
    $98 = ($97<<24>>24)==(42);
    if (!($98)) {
     $125 = ((($94)) + 1|0);
     HEAP32[$5>>2] = $125;
     $126 = (_getint($5)|0);
     $$pre347$pre = HEAP32[$5>>2]|0;
     $$0254 = $126;$$pre347 = $$pre347$pre;
     break;
    }
    $99 = ((($94)) + 2|0);
    $100 = HEAP8[$99>>0]|0;
    $101 = $100 << 24 >> 24;
    $isdigittmp274 = (($101) + -48)|0;
    $isdigit275 = ($isdigittmp274>>>0)<(10);
    if ($isdigit275) {
     $102 = ((($94)) + 3|0);
     $103 = HEAP8[$102>>0]|0;
     $104 = ($103<<24>>24)==(36);
     if ($104) {
      $105 = (($4) + ($isdigittmp274<<2)|0);
      HEAP32[$105>>2] = 10;
      $106 = HEAP8[$99>>0]|0;
      $107 = $106 << 24 >> 24;
      $108 = (($107) + -48)|0;
      $109 = (($3) + ($108<<3)|0);
      $110 = $109;
      $111 = $110;
      $112 = HEAP32[$111>>2]|0;
      $113 = (($110) + 4)|0;
      $114 = $113;
      $115 = HEAP32[$114>>2]|0;
      $116 = ((($94)) + 4|0);
      HEAP32[$5>>2] = $116;
      $$0254 = $112;$$pre347 = $116;
      break;
     }
    }
    $117 = ($$3272|0)==(0);
    if (!($117)) {
     $$0 = -1;
     break L1;
    }
    if ($10) {
     $arglist_current2 = HEAP32[$2>>2]|0;
     $118 = $arglist_current2;
     $119 = ((0) + 4|0);
     $expanded11 = $119;
     $expanded10 = (($expanded11) - 1)|0;
     $120 = (($118) + ($expanded10))|0;
     $121 = ((0) + 4|0);
     $expanded15 = $121;
     $expanded14 = (($expanded15) - 1)|0;
     $expanded13 = $expanded14 ^ -1;
     $122 = $120 & $expanded13;
     $123 = $122;
     $124 = HEAP32[$123>>2]|0;
     $arglist_next3 = ((($123)) + 4|0);
     HEAP32[$2>>2] = $arglist_next3;
     $330 = $124;
    } else {
     $330 = 0;
    }
    HEAP32[$5>>2] = $99;
    $$0254 = $330;$$pre347 = $99;
   } else {
    $$0254 = -1;$$pre347 = $94;
   }
  } while(0);
  $$0252 = 0;$128 = $$pre347;
  while(1) {
   $127 = HEAP8[$128>>0]|0;
   $129 = $127 << 24 >> 24;
   $130 = (($129) + -65)|0;
   $131 = ($130>>>0)>(57);
   if ($131) {
    $$0 = -1;
    break L1;
   }
   $132 = ((($128)) + 1|0);
   HEAP32[$5>>2] = $132;
   $133 = HEAP8[$128>>0]|0;
   $134 = $133 << 24 >> 24;
   $135 = (($134) + -65)|0;
   $136 = ((199307 + (($$0252*58)|0)|0) + ($135)|0);
   $137 = HEAP8[$136>>0]|0;
   $138 = $137&255;
   $139 = (($138) + -1)|0;
   $140 = ($139>>>0)<(8);
   if ($140) {
    $$0252 = $138;$128 = $132;
   } else {
    break;
   }
  }
  $141 = ($137<<24>>24)==(0);
  if ($141) {
   $$0 = -1;
   break;
  }
  $142 = ($137<<24>>24)==(19);
  $143 = ($$0253|0)>(-1);
  do {
   if ($142) {
    if ($143) {
     $$0 = -1;
     break L1;
    } else {
     label = 49;
    }
   } else {
    if ($143) {
     $144 = (($4) + ($$0253<<2)|0);
     HEAP32[$144>>2] = $138;
     $145 = (($3) + ($$0253<<3)|0);
     $146 = $145;
     $147 = $146;
     $148 = HEAP32[$147>>2]|0;
     $149 = (($146) + 4)|0;
     $150 = $149;
     $151 = HEAP32[$150>>2]|0;
     $152 = $6;
     $153 = $152;
     HEAP32[$153>>2] = $148;
     $154 = (($152) + 4)|0;
     $155 = $154;
     HEAP32[$155>>2] = $151;
     label = 49;
     break;
    }
    if (!($10)) {
     $$0 = 0;
     break L1;
    }
    _pop_arg($6,$138,$2);
   }
  } while(0);
  if ((label|0) == 49) {
   label = 0;
   if (!($10)) {
    $$0243 = 0;$$0247 = $$1248;$$0269 = $$3272;$21 = $132;
    continue;
   }
  }
  $156 = HEAP8[$128>>0]|0;
  $157 = $156 << 24 >> 24;
  $158 = ($$0252|0)!=(0);
  $159 = $157 & 15;
  $160 = ($159|0)==(3);
  $or$cond281 = $158 & $160;
  $161 = $157 & -33;
  $$0235 = $or$cond281 ? $161 : $157;
  $162 = $$1263 & 8192;
  $163 = ($162|0)==(0);
  $164 = $$1263 & -65537;
  $$1263$ = $163 ? $$1263 : $164;
  L71: do {
   switch ($$0235|0) {
   case 110:  {
    $trunc = $$0252&255;
    switch ($trunc<<24>>24) {
    case 0:  {
     $171 = HEAP32[$6>>2]|0;
     HEAP32[$171>>2] = $$1248;
     $$0243 = 0;$$0247 = $$1248;$$0269 = $$3272;$21 = $132;
     continue L1;
     break;
    }
    case 1:  {
     $172 = HEAP32[$6>>2]|0;
     HEAP32[$172>>2] = $$1248;
     $$0243 = 0;$$0247 = $$1248;$$0269 = $$3272;$21 = $132;
     continue L1;
     break;
    }
    case 2:  {
     $173 = ($$1248|0)<(0);
     $174 = $173 << 31 >> 31;
     $175 = HEAP32[$6>>2]|0;
     $176 = $175;
     $177 = $176;
     HEAP32[$177>>2] = $$1248;
     $178 = (($176) + 4)|0;
     $179 = $178;
     HEAP32[$179>>2] = $174;
     $$0243 = 0;$$0247 = $$1248;$$0269 = $$3272;$21 = $132;
     continue L1;
     break;
    }
    case 3:  {
     $180 = $$1248&65535;
     $181 = HEAP32[$6>>2]|0;
     HEAP16[$181>>1] = $180;
     $$0243 = 0;$$0247 = $$1248;$$0269 = $$3272;$21 = $132;
     continue L1;
     break;
    }
    case 4:  {
     $182 = $$1248&255;
     $183 = HEAP32[$6>>2]|0;
     HEAP8[$183>>0] = $182;
     $$0243 = 0;$$0247 = $$1248;$$0269 = $$3272;$21 = $132;
     continue L1;
     break;
    }
    case 6:  {
     $184 = HEAP32[$6>>2]|0;
     HEAP32[$184>>2] = $$1248;
     $$0243 = 0;$$0247 = $$1248;$$0269 = $$3272;$21 = $132;
     continue L1;
     break;
    }
    case 7:  {
     $185 = ($$1248|0)<(0);
     $186 = $185 << 31 >> 31;
     $187 = HEAP32[$6>>2]|0;
     $188 = $187;
     $189 = $188;
     HEAP32[$189>>2] = $$1248;
     $190 = (($188) + 4)|0;
     $191 = $190;
     HEAP32[$191>>2] = $186;
     $$0243 = 0;$$0247 = $$1248;$$0269 = $$3272;$21 = $132;
     continue L1;
     break;
    }
    default: {
     $$0243 = 0;$$0247 = $$1248;$$0269 = $$3272;$21 = $132;
     continue L1;
    }
    }
    break;
   }
   case 112:  {
    $192 = ($$0254>>>0)>(8);
    $193 = $192 ? $$0254 : 8;
    $194 = $$1263$ | 8;
    $$1236 = 120;$$1255 = $193;$$3265 = $194;
    label = 61;
    break;
   }
   case 88: case 120:  {
    $$1236 = $$0235;$$1255 = $$0254;$$3265 = $$1263$;
    label = 61;
    break;
   }
   case 111:  {
    $210 = $6;
    $211 = $210;
    $212 = HEAP32[$211>>2]|0;
    $213 = (($210) + 4)|0;
    $214 = $213;
    $215 = HEAP32[$214>>2]|0;
    $216 = (_fmt_o($212,$215,$11)|0);
    $217 = $$1263$ & 8;
    $218 = ($217|0)==(0);
    $219 = $216;
    $220 = (($12) - ($219))|0;
    $221 = ($$0254|0)>($220|0);
    $222 = (($220) + 1)|0;
    $223 = $218 | $221;
    $$0254$$0254$ = $223 ? $$0254 : $222;
    $$0228 = $216;$$1233 = 0;$$1238 = 199771;$$2256 = $$0254$$0254$;$$4266 = $$1263$;$247 = $212;$249 = $215;
    label = 67;
    break;
   }
   case 105: case 100:  {
    $224 = $6;
    $225 = $224;
    $226 = HEAP32[$225>>2]|0;
    $227 = (($224) + 4)|0;
    $228 = $227;
    $229 = HEAP32[$228>>2]|0;
    $230 = ($229|0)<(0);
    if ($230) {
     $231 = (_i64Subtract(0,0,($226|0),($229|0))|0);
     $232 = tempRet0;
     $233 = $6;
     $234 = $233;
     HEAP32[$234>>2] = $231;
     $235 = (($233) + 4)|0;
     $236 = $235;
     HEAP32[$236>>2] = $232;
     $$0232 = 1;$$0237 = 199771;$242 = $231;$243 = $232;
     label = 66;
     break L71;
    } else {
     $237 = $$1263$ & 2048;
     $238 = ($237|0)==(0);
     $239 = $$1263$ & 1;
     $240 = ($239|0)==(0);
     $$ = $240 ? 199771 : (199773);
     $$$ = $238 ? $$ : (199772);
     $241 = $$1263$ & 2049;
     $narrow = ($241|0)!=(0);
     $$284$ = $narrow&1;
     $$0232 = $$284$;$$0237 = $$$;$242 = $226;$243 = $229;
     label = 66;
     break L71;
    }
    break;
   }
   case 117:  {
    $165 = $6;
    $166 = $165;
    $167 = HEAP32[$166>>2]|0;
    $168 = (($165) + 4)|0;
    $169 = $168;
    $170 = HEAP32[$169>>2]|0;
    $$0232 = 0;$$0237 = 199771;$242 = $167;$243 = $170;
    label = 66;
    break;
   }
   case 99:  {
    $259 = $6;
    $260 = $259;
    $261 = HEAP32[$260>>2]|0;
    $262 = (($259) + 4)|0;
    $263 = $262;
    $264 = HEAP32[$263>>2]|0;
    $265 = $261&255;
    HEAP8[$13>>0] = $265;
    $$2 = $13;$$2234 = 0;$$2239 = 199771;$$2251 = $11;$$5 = 1;$$6268 = $164;
    break;
   }
   case 109:  {
    $266 = (___errno_location()|0);
    $267 = HEAP32[$266>>2]|0;
    $268 = (_strerror($267)|0);
    $$1 = $268;
    label = 71;
    break;
   }
   case 115:  {
    $269 = HEAP32[$6>>2]|0;
    $270 = ($269|0)!=(0|0);
    $271 = $270 ? $269 : 199781;
    $$1 = $271;
    label = 71;
    break;
   }
   case 67:  {
    $278 = $6;
    $279 = $278;
    $280 = HEAP32[$279>>2]|0;
    $281 = (($278) + 4)|0;
    $282 = $281;
    $283 = HEAP32[$282>>2]|0;
    HEAP32[$8>>2] = $280;
    HEAP32[$14>>2] = 0;
    HEAP32[$6>>2] = $8;
    $$4258355 = -1;$331 = $8;
    label = 75;
    break;
   }
   case 83:  {
    $$pre349 = HEAP32[$6>>2]|0;
    $284 = ($$0254|0)==(0);
    if ($284) {
     _pad_452($0,32,$$1260,0,$$1263$);
     $$0240$lcssa357 = 0;
     label = 84;
    } else {
     $$4258355 = $$0254;$331 = $$pre349;
     label = 75;
    }
    break;
   }
   case 65: case 71: case 70: case 69: case 97: case 103: case 102: case 101:  {
    $306 = +HEAPF64[$6>>3];
    $307 = (_fmt_fp($0,$306,$$1260,$$0254,$$1263$,$$0235)|0);
    $$0243 = $307;$$0247 = $$1248;$$0269 = $$3272;$21 = $132;
    continue L1;
    break;
   }
   default: {
    $$2 = $21;$$2234 = 0;$$2239 = 199771;$$2251 = $11;$$5 = $$0254;$$6268 = $$1263$;
   }
   }
  } while(0);
  L95: do {
   if ((label|0) == 61) {
    label = 0;
    $195 = $6;
    $196 = $195;
    $197 = HEAP32[$196>>2]|0;
    $198 = (($195) + 4)|0;
    $199 = $198;
    $200 = HEAP32[$199>>2]|0;
    $201 = $$1236 & 32;
    $202 = (_fmt_x($197,$200,$11,$201)|0);
    $203 = ($197|0)==(0);
    $204 = ($200|0)==(0);
    $205 = $203 & $204;
    $206 = $$3265 & 8;
    $207 = ($206|0)==(0);
    $or$cond283 = $207 | $205;
    $208 = $$1236 >> 4;
    $209 = (199771 + ($208)|0);
    $$289 = $or$cond283 ? 199771 : $209;
    $$290 = $or$cond283 ? 0 : 2;
    $$0228 = $202;$$1233 = $$290;$$1238 = $$289;$$2256 = $$1255;$$4266 = $$3265;$247 = $197;$249 = $200;
    label = 67;
   }
   else if ((label|0) == 66) {
    label = 0;
    $244 = (_fmt_u($242,$243,$11)|0);
    $$0228 = $244;$$1233 = $$0232;$$1238 = $$0237;$$2256 = $$0254;$$4266 = $$1263$;$247 = $242;$249 = $243;
    label = 67;
   }
   else if ((label|0) == 71) {
    label = 0;
    $272 = (_memchr($$1,0,$$0254)|0);
    $273 = ($272|0)==(0|0);
    $274 = $272;
    $275 = $$1;
    $276 = (($274) - ($275))|0;
    $277 = (($$1) + ($$0254)|0);
    $$3257 = $273 ? $$0254 : $276;
    $$1250 = $273 ? $277 : $272;
    $$2 = $$1;$$2234 = 0;$$2239 = 199771;$$2251 = $$1250;$$5 = $$3257;$$6268 = $164;
   }
   else if ((label|0) == 75) {
    label = 0;
    $$0229322 = $331;$$0240321 = 0;$$1244320 = 0;
    while(1) {
     $285 = HEAP32[$$0229322>>2]|0;
     $286 = ($285|0)==(0);
     if ($286) {
      $$0240$lcssa = $$0240321;$$2245 = $$1244320;
      break;
     }
     $287 = (_wctomb($9,$285)|0);
     $288 = ($287|0)<(0);
     $289 = (($$4258355) - ($$0240321))|0;
     $290 = ($287>>>0)>($289>>>0);
     $or$cond286 = $288 | $290;
     if ($or$cond286) {
      $$0240$lcssa = $$0240321;$$2245 = $287;
      break;
     }
     $291 = ((($$0229322)) + 4|0);
     $292 = (($287) + ($$0240321))|0;
     $293 = ($$4258355>>>0)>($292>>>0);
     if ($293) {
      $$0229322 = $291;$$0240321 = $292;$$1244320 = $287;
     } else {
      $$0240$lcssa = $292;$$2245 = $287;
      break;
     }
    }
    $294 = ($$2245|0)<(0);
    if ($294) {
     $$0 = -1;
     break L1;
    }
    _pad_452($0,32,$$1260,$$0240$lcssa,$$1263$);
    $295 = ($$0240$lcssa|0)==(0);
    if ($295) {
     $$0240$lcssa357 = 0;
     label = 84;
    } else {
     $$1230333 = $331;$$1241332 = 0;
     while(1) {
      $296 = HEAP32[$$1230333>>2]|0;
      $297 = ($296|0)==(0);
      if ($297) {
       $$0240$lcssa357 = $$0240$lcssa;
       label = 84;
       break L95;
      }
      $298 = (_wctomb($9,$296)|0);
      $299 = (($298) + ($$1241332))|0;
      $300 = ($299|0)>($$0240$lcssa|0);
      if ($300) {
       $$0240$lcssa357 = $$0240$lcssa;
       label = 84;
       break L95;
      }
      $301 = ((($$1230333)) + 4|0);
      _out($0,$9,$298);
      $302 = ($299>>>0)<($$0240$lcssa>>>0);
      if ($302) {
       $$1230333 = $301;$$1241332 = $299;
      } else {
       $$0240$lcssa357 = $$0240$lcssa;
       label = 84;
       break;
      }
     }
    }
   }
  } while(0);
  if ((label|0) == 67) {
   label = 0;
   $245 = ($$2256|0)>(-1);
   $246 = $$4266 & -65537;
   $$$4266 = $245 ? $246 : $$4266;
   $248 = ($247|0)!=(0);
   $250 = ($249|0)!=(0);
   $251 = $248 | $250;
   $252 = ($$2256|0)!=(0);
   $or$cond = $252 | $251;
   $253 = $$0228;
   $254 = (($12) - ($253))|0;
   $255 = $251 ^ 1;
   $256 = $255&1;
   $257 = (($256) + ($254))|0;
   $258 = ($$2256|0)>($257|0);
   $$2256$ = $258 ? $$2256 : $257;
   $$2256$$$2256 = $or$cond ? $$2256$ : $$2256;
   $$0228$ = $or$cond ? $$0228 : $11;
   $$2 = $$0228$;$$2234 = $$1233;$$2239 = $$1238;$$2251 = $11;$$5 = $$2256$$$2256;$$6268 = $$$4266;
  }
  else if ((label|0) == 84) {
   label = 0;
   $303 = $$1263$ ^ 8192;
   _pad_452($0,32,$$1260,$$0240$lcssa357,$303);
   $304 = ($$1260|0)>($$0240$lcssa357|0);
   $305 = $304 ? $$1260 : $$0240$lcssa357;
   $$0243 = $305;$$0247 = $$1248;$$0269 = $$3272;$21 = $132;
   continue;
  }
  $308 = $$2251;
  $309 = $$2;
  $310 = (($308) - ($309))|0;
  $311 = ($$5|0)<($310|0);
  $$$5 = $311 ? $310 : $$5;
  $312 = (($$$5) + ($$2234))|0;
  $313 = ($$1260|0)<($312|0);
  $$2261 = $313 ? $312 : $$1260;
  _pad_452($0,32,$$2261,$312,$$6268);
  _out($0,$$2239,$$2234);
  $314 = $$6268 ^ 65536;
  _pad_452($0,48,$$2261,$312,$314);
  _pad_452($0,48,$$$5,$310,0);
  _out($0,$$2,$310);
  $315 = $$6268 ^ 8192;
  _pad_452($0,32,$$2261,$312,$315);
  $$0243 = $$2261;$$0247 = $$1248;$$0269 = $$3272;$21 = $132;
 }
 L114: do {
  if ((label|0) == 87) {
   $316 = ($0|0)==(0|0);
   if ($316) {
    $317 = ($$0269|0)==(0);
    if ($317) {
     $$0 = 0;
    } else {
     $$2242305 = 1;
     while(1) {
      $318 = (($4) + ($$2242305<<2)|0);
      $319 = HEAP32[$318>>2]|0;
      $320 = ($319|0)==(0);
      if ($320) {
       $$3303 = $$2242305;
       break;
      }
      $321 = (($3) + ($$2242305<<3)|0);
      _pop_arg($321,$319,$2);
      $322 = (($$2242305) + 1)|0;
      $323 = ($322|0)<(10);
      if ($323) {
       $$2242305 = $322;
      } else {
       $$0 = 1;
       break L114;
      }
     }
     while(1) {
      $326 = (($4) + ($$3303<<2)|0);
      $327 = HEAP32[$326>>2]|0;
      $328 = ($327|0)==(0);
      $324 = (($$3303) + 1)|0;
      if (!($328)) {
       $$0 = -1;
       break L114;
      }
      $325 = ($324|0)<(10);
      if ($325) {
       $$3303 = $324;
      } else {
       $$0 = 1;
       break;
      }
     }
    }
   } else {
    $$0 = $$1248;
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function ___lockfile($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function ___unlockfile($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function _out($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = HEAP32[$0>>2]|0;
 $4 = $3 & 32;
 $5 = ($4|0)==(0);
 if ($5) {
  (___fwritex($1,$2,$0)|0);
 }
 return;
}
function _getint($0) {
 $0 = $0|0;
 var $$0$lcssa = 0, $$06 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $isdigit = 0, $isdigit5 = 0, $isdigittmp = 0, $isdigittmp4 = 0, $isdigittmp7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$1>>0]|0;
 $3 = $2 << 24 >> 24;
 $isdigittmp4 = (($3) + -48)|0;
 $isdigit5 = ($isdigittmp4>>>0)<(10);
 if ($isdigit5) {
  $$06 = 0;$7 = $1;$isdigittmp7 = $isdigittmp4;
  while(1) {
   $4 = ($$06*10)|0;
   $5 = (($isdigittmp7) + ($4))|0;
   $6 = ((($7)) + 1|0);
   HEAP32[$0>>2] = $6;
   $8 = HEAP8[$6>>0]|0;
   $9 = $8 << 24 >> 24;
   $isdigittmp = (($9) + -48)|0;
   $isdigit = ($isdigittmp>>>0)<(10);
   if ($isdigit) {
    $$06 = $5;$7 = $6;$isdigittmp7 = $isdigittmp;
   } else {
    $$0$lcssa = $5;
    break;
   }
  }
 } else {
  $$0$lcssa = 0;
 }
 return ($$0$lcssa|0);
}
function _pop_arg($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$mask = 0, $$mask31 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0.0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0.0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $arglist_current = 0, $arglist_current11 = 0, $arglist_current14 = 0, $arglist_current17 = 0;
 var $arglist_current2 = 0, $arglist_current20 = 0, $arglist_current23 = 0, $arglist_current26 = 0, $arglist_current5 = 0, $arglist_current8 = 0, $arglist_next = 0, $arglist_next12 = 0, $arglist_next15 = 0, $arglist_next18 = 0, $arglist_next21 = 0, $arglist_next24 = 0, $arglist_next27 = 0, $arglist_next3 = 0, $arglist_next6 = 0, $arglist_next9 = 0, $expanded = 0, $expanded28 = 0, $expanded30 = 0, $expanded31 = 0;
 var $expanded32 = 0, $expanded34 = 0, $expanded35 = 0, $expanded37 = 0, $expanded38 = 0, $expanded39 = 0, $expanded41 = 0, $expanded42 = 0, $expanded44 = 0, $expanded45 = 0, $expanded46 = 0, $expanded48 = 0, $expanded49 = 0, $expanded51 = 0, $expanded52 = 0, $expanded53 = 0, $expanded55 = 0, $expanded56 = 0, $expanded58 = 0, $expanded59 = 0;
 var $expanded60 = 0, $expanded62 = 0, $expanded63 = 0, $expanded65 = 0, $expanded66 = 0, $expanded67 = 0, $expanded69 = 0, $expanded70 = 0, $expanded72 = 0, $expanded73 = 0, $expanded74 = 0, $expanded76 = 0, $expanded77 = 0, $expanded79 = 0, $expanded80 = 0, $expanded81 = 0, $expanded83 = 0, $expanded84 = 0, $expanded86 = 0, $expanded87 = 0;
 var $expanded88 = 0, $expanded90 = 0, $expanded91 = 0, $expanded93 = 0, $expanded94 = 0, $expanded95 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($1>>>0)>(20);
 L1: do {
  if (!($3)) {
   do {
    switch ($1|0) {
    case 9:  {
     $arglist_current = HEAP32[$2>>2]|0;
     $4 = $arglist_current;
     $5 = ((0) + 4|0);
     $expanded28 = $5;
     $expanded = (($expanded28) - 1)|0;
     $6 = (($4) + ($expanded))|0;
     $7 = ((0) + 4|0);
     $expanded32 = $7;
     $expanded31 = (($expanded32) - 1)|0;
     $expanded30 = $expanded31 ^ -1;
     $8 = $6 & $expanded30;
     $9 = $8;
     $10 = HEAP32[$9>>2]|0;
     $arglist_next = ((($9)) + 4|0);
     HEAP32[$2>>2] = $arglist_next;
     HEAP32[$0>>2] = $10;
     break L1;
     break;
    }
    case 10:  {
     $arglist_current2 = HEAP32[$2>>2]|0;
     $11 = $arglist_current2;
     $12 = ((0) + 4|0);
     $expanded35 = $12;
     $expanded34 = (($expanded35) - 1)|0;
     $13 = (($11) + ($expanded34))|0;
     $14 = ((0) + 4|0);
     $expanded39 = $14;
     $expanded38 = (($expanded39) - 1)|0;
     $expanded37 = $expanded38 ^ -1;
     $15 = $13 & $expanded37;
     $16 = $15;
     $17 = HEAP32[$16>>2]|0;
     $arglist_next3 = ((($16)) + 4|0);
     HEAP32[$2>>2] = $arglist_next3;
     $18 = ($17|0)<(0);
     $19 = $18 << 31 >> 31;
     $20 = $0;
     $21 = $20;
     HEAP32[$21>>2] = $17;
     $22 = (($20) + 4)|0;
     $23 = $22;
     HEAP32[$23>>2] = $19;
     break L1;
     break;
    }
    case 11:  {
     $arglist_current5 = HEAP32[$2>>2]|0;
     $24 = $arglist_current5;
     $25 = ((0) + 4|0);
     $expanded42 = $25;
     $expanded41 = (($expanded42) - 1)|0;
     $26 = (($24) + ($expanded41))|0;
     $27 = ((0) + 4|0);
     $expanded46 = $27;
     $expanded45 = (($expanded46) - 1)|0;
     $expanded44 = $expanded45 ^ -1;
     $28 = $26 & $expanded44;
     $29 = $28;
     $30 = HEAP32[$29>>2]|0;
     $arglist_next6 = ((($29)) + 4|0);
     HEAP32[$2>>2] = $arglist_next6;
     $31 = $0;
     $32 = $31;
     HEAP32[$32>>2] = $30;
     $33 = (($31) + 4)|0;
     $34 = $33;
     HEAP32[$34>>2] = 0;
     break L1;
     break;
    }
    case 12:  {
     $arglist_current8 = HEAP32[$2>>2]|0;
     $35 = $arglist_current8;
     $36 = ((0) + 8|0);
     $expanded49 = $36;
     $expanded48 = (($expanded49) - 1)|0;
     $37 = (($35) + ($expanded48))|0;
     $38 = ((0) + 8|0);
     $expanded53 = $38;
     $expanded52 = (($expanded53) - 1)|0;
     $expanded51 = $expanded52 ^ -1;
     $39 = $37 & $expanded51;
     $40 = $39;
     $41 = $40;
     $42 = $41;
     $43 = HEAP32[$42>>2]|0;
     $44 = (($41) + 4)|0;
     $45 = $44;
     $46 = HEAP32[$45>>2]|0;
     $arglist_next9 = ((($40)) + 8|0);
     HEAP32[$2>>2] = $arglist_next9;
     $47 = $0;
     $48 = $47;
     HEAP32[$48>>2] = $43;
     $49 = (($47) + 4)|0;
     $50 = $49;
     HEAP32[$50>>2] = $46;
     break L1;
     break;
    }
    case 13:  {
     $arglist_current11 = HEAP32[$2>>2]|0;
     $51 = $arglist_current11;
     $52 = ((0) + 4|0);
     $expanded56 = $52;
     $expanded55 = (($expanded56) - 1)|0;
     $53 = (($51) + ($expanded55))|0;
     $54 = ((0) + 4|0);
     $expanded60 = $54;
     $expanded59 = (($expanded60) - 1)|0;
     $expanded58 = $expanded59 ^ -1;
     $55 = $53 & $expanded58;
     $56 = $55;
     $57 = HEAP32[$56>>2]|0;
     $arglist_next12 = ((($56)) + 4|0);
     HEAP32[$2>>2] = $arglist_next12;
     $58 = $57&65535;
     $59 = $58 << 16 >> 16;
     $60 = ($59|0)<(0);
     $61 = $60 << 31 >> 31;
     $62 = $0;
     $63 = $62;
     HEAP32[$63>>2] = $59;
     $64 = (($62) + 4)|0;
     $65 = $64;
     HEAP32[$65>>2] = $61;
     break L1;
     break;
    }
    case 14:  {
     $arglist_current14 = HEAP32[$2>>2]|0;
     $66 = $arglist_current14;
     $67 = ((0) + 4|0);
     $expanded63 = $67;
     $expanded62 = (($expanded63) - 1)|0;
     $68 = (($66) + ($expanded62))|0;
     $69 = ((0) + 4|0);
     $expanded67 = $69;
     $expanded66 = (($expanded67) - 1)|0;
     $expanded65 = $expanded66 ^ -1;
     $70 = $68 & $expanded65;
     $71 = $70;
     $72 = HEAP32[$71>>2]|0;
     $arglist_next15 = ((($71)) + 4|0);
     HEAP32[$2>>2] = $arglist_next15;
     $$mask31 = $72 & 65535;
     $73 = $0;
     $74 = $73;
     HEAP32[$74>>2] = $$mask31;
     $75 = (($73) + 4)|0;
     $76 = $75;
     HEAP32[$76>>2] = 0;
     break L1;
     break;
    }
    case 15:  {
     $arglist_current17 = HEAP32[$2>>2]|0;
     $77 = $arglist_current17;
     $78 = ((0) + 4|0);
     $expanded70 = $78;
     $expanded69 = (($expanded70) - 1)|0;
     $79 = (($77) + ($expanded69))|0;
     $80 = ((0) + 4|0);
     $expanded74 = $80;
     $expanded73 = (($expanded74) - 1)|0;
     $expanded72 = $expanded73 ^ -1;
     $81 = $79 & $expanded72;
     $82 = $81;
     $83 = HEAP32[$82>>2]|0;
     $arglist_next18 = ((($82)) + 4|0);
     HEAP32[$2>>2] = $arglist_next18;
     $84 = $83&255;
     $85 = $84 << 24 >> 24;
     $86 = ($85|0)<(0);
     $87 = $86 << 31 >> 31;
     $88 = $0;
     $89 = $88;
     HEAP32[$89>>2] = $85;
     $90 = (($88) + 4)|0;
     $91 = $90;
     HEAP32[$91>>2] = $87;
     break L1;
     break;
    }
    case 16:  {
     $arglist_current20 = HEAP32[$2>>2]|0;
     $92 = $arglist_current20;
     $93 = ((0) + 4|0);
     $expanded77 = $93;
     $expanded76 = (($expanded77) - 1)|0;
     $94 = (($92) + ($expanded76))|0;
     $95 = ((0) + 4|0);
     $expanded81 = $95;
     $expanded80 = (($expanded81) - 1)|0;
     $expanded79 = $expanded80 ^ -1;
     $96 = $94 & $expanded79;
     $97 = $96;
     $98 = HEAP32[$97>>2]|0;
     $arglist_next21 = ((($97)) + 4|0);
     HEAP32[$2>>2] = $arglist_next21;
     $$mask = $98 & 255;
     $99 = $0;
     $100 = $99;
     HEAP32[$100>>2] = $$mask;
     $101 = (($99) + 4)|0;
     $102 = $101;
     HEAP32[$102>>2] = 0;
     break L1;
     break;
    }
    case 17:  {
     $arglist_current23 = HEAP32[$2>>2]|0;
     $103 = $arglist_current23;
     $104 = ((0) + 8|0);
     $expanded84 = $104;
     $expanded83 = (($expanded84) - 1)|0;
     $105 = (($103) + ($expanded83))|0;
     $106 = ((0) + 8|0);
     $expanded88 = $106;
     $expanded87 = (($expanded88) - 1)|0;
     $expanded86 = $expanded87 ^ -1;
     $107 = $105 & $expanded86;
     $108 = $107;
     $109 = +HEAPF64[$108>>3];
     $arglist_next24 = ((($108)) + 8|0);
     HEAP32[$2>>2] = $arglist_next24;
     HEAPF64[$0>>3] = $109;
     break L1;
     break;
    }
    case 18:  {
     $arglist_current26 = HEAP32[$2>>2]|0;
     $110 = $arglist_current26;
     $111 = ((0) + 8|0);
     $expanded91 = $111;
     $expanded90 = (($expanded91) - 1)|0;
     $112 = (($110) + ($expanded90))|0;
     $113 = ((0) + 8|0);
     $expanded95 = $113;
     $expanded94 = (($expanded95) - 1)|0;
     $expanded93 = $expanded94 ^ -1;
     $114 = $112 & $expanded93;
     $115 = $114;
     $116 = +HEAPF64[$115>>3];
     $arglist_next27 = ((($115)) + 8|0);
     HEAP32[$2>>2] = $arglist_next27;
     HEAPF64[$0>>3] = $116;
     break L1;
     break;
    }
    default: {
     break L1;
    }
    }
   } while(0);
  }
 } while(0);
 return;
}
function _fmt_x($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$05$lcssa = 0, $$056 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $4 = ($0|0)==(0);
 $5 = ($1|0)==(0);
 $6 = $4 & $5;
 if ($6) {
  $$05$lcssa = $2;
 } else {
  $$056 = $2;$15 = $1;$8 = $0;
  while(1) {
   $7 = $8 & 15;
   $9 = (199823 + ($7)|0);
   $10 = HEAP8[$9>>0]|0;
   $11 = $10&255;
   $12 = $11 | $3;
   $13 = $12&255;
   $14 = ((($$056)) + -1|0);
   HEAP8[$14>>0] = $13;
   $16 = (_bitshift64Lshr(($8|0),($15|0),4)|0);
   $17 = tempRet0;
   $18 = ($16|0)==(0);
   $19 = ($17|0)==(0);
   $20 = $18 & $19;
   if ($20) {
    $$05$lcssa = $14;
    break;
   } else {
    $$056 = $14;$15 = $17;$8 = $16;
   }
  }
 }
 return ($$05$lcssa|0);
}
function _fmt_o($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$lcssa = 0, $$06 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($0|0)==(0);
 $4 = ($1|0)==(0);
 $5 = $3 & $4;
 if ($5) {
  $$0$lcssa = $2;
 } else {
  $$06 = $2;$11 = $1;$7 = $0;
  while(1) {
   $6 = $7&255;
   $8 = $6 & 7;
   $9 = $8 | 48;
   $10 = ((($$06)) + -1|0);
   HEAP8[$10>>0] = $9;
   $12 = (_bitshift64Lshr(($7|0),($11|0),3)|0);
   $13 = tempRet0;
   $14 = ($12|0)==(0);
   $15 = ($13|0)==(0);
   $16 = $14 & $15;
   if ($16) {
    $$0$lcssa = $10;
    break;
   } else {
    $$06 = $10;$11 = $13;$7 = $12;
   }
  }
 }
 return ($$0$lcssa|0);
}
function _fmt_u($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$010$lcssa$off0 = 0, $$012 = 0, $$09$lcssa = 0, $$0914 = 0, $$1$lcssa = 0, $$111 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($1>>>0)>(0);
 $4 = ($0>>>0)>(4294967295);
 $5 = ($1|0)==(0);
 $6 = $5 & $4;
 $7 = $3 | $6;
 if ($7) {
  $$0914 = $2;$8 = $0;$9 = $1;
  while(1) {
   $10 = (___uremdi3(($8|0),($9|0),10,0)|0);
   $11 = tempRet0;
   $12 = $10&255;
   $13 = $12 | 48;
   $14 = ((($$0914)) + -1|0);
   HEAP8[$14>>0] = $13;
   $15 = (___udivdi3(($8|0),($9|0),10,0)|0);
   $16 = tempRet0;
   $17 = ($9>>>0)>(9);
   $18 = ($8>>>0)>(4294967295);
   $19 = ($9|0)==(9);
   $20 = $19 & $18;
   $21 = $17 | $20;
   if ($21) {
    $$0914 = $14;$8 = $15;$9 = $16;
   } else {
    break;
   }
  }
  $$010$lcssa$off0 = $15;$$09$lcssa = $14;
 } else {
  $$010$lcssa$off0 = $0;$$09$lcssa = $2;
 }
 $22 = ($$010$lcssa$off0|0)==(0);
 if ($22) {
  $$1$lcssa = $$09$lcssa;
 } else {
  $$012 = $$010$lcssa$off0;$$111 = $$09$lcssa;
  while(1) {
   $23 = (($$012>>>0) % 10)&-1;
   $24 = $23 | 48;
   $25 = $24&255;
   $26 = ((($$111)) + -1|0);
   HEAP8[$26>>0] = $25;
   $27 = (($$012>>>0) / 10)&-1;
   $28 = ($$012>>>0)<(10);
   if ($28) {
    $$1$lcssa = $26;
    break;
   } else {
    $$012 = $27;$$111 = $26;
   }
  }
 }
 return ($$1$lcssa|0);
}
function _strerror($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (___pthread_self_879()|0);
 $2 = ((($1)) + 188|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (___strerror_l($0,$3)|0);
 return ($4|0);
}
function _memchr($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$lcssa = 0, $$035$lcssa = 0, $$035$lcssa65 = 0, $$03555 = 0, $$036$lcssa = 0, $$036$lcssa64 = 0, $$03654 = 0, $$046 = 0, $$137$lcssa = 0, $$13745 = 0, $$140 = 0, $$2 = 0, $$23839 = 0, $$3 = 0, $$lcssa = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond53 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = $1 & 255;
 $4 = $0;
 $5 = $4 & 3;
 $6 = ($5|0)!=(0);
 $7 = ($2|0)!=(0);
 $or$cond53 = $7 & $6;
 L1: do {
  if ($or$cond53) {
   $8 = $1&255;
   $$03555 = $0;$$03654 = $2;
   while(1) {
    $9 = HEAP8[$$03555>>0]|0;
    $10 = ($9<<24>>24)==($8<<24>>24);
    if ($10) {
     $$035$lcssa65 = $$03555;$$036$lcssa64 = $$03654;
     label = 6;
     break L1;
    }
    $11 = ((($$03555)) + 1|0);
    $12 = (($$03654) + -1)|0;
    $13 = $11;
    $14 = $13 & 3;
    $15 = ($14|0)!=(0);
    $16 = ($12|0)!=(0);
    $or$cond = $16 & $15;
    if ($or$cond) {
     $$03555 = $11;$$03654 = $12;
    } else {
     $$035$lcssa = $11;$$036$lcssa = $12;$$lcssa = $16;
     label = 5;
     break;
    }
   }
  } else {
   $$035$lcssa = $0;$$036$lcssa = $2;$$lcssa = $7;
   label = 5;
  }
 } while(0);
 if ((label|0) == 5) {
  if ($$lcssa) {
   $$035$lcssa65 = $$035$lcssa;$$036$lcssa64 = $$036$lcssa;
   label = 6;
  } else {
   $$2 = $$035$lcssa;$$3 = 0;
  }
 }
 L8: do {
  if ((label|0) == 6) {
   $17 = HEAP8[$$035$lcssa65>>0]|0;
   $18 = $1&255;
   $19 = ($17<<24>>24)==($18<<24>>24);
   if ($19) {
    $$2 = $$035$lcssa65;$$3 = $$036$lcssa64;
   } else {
    $20 = Math_imul($3, 16843009)|0;
    $21 = ($$036$lcssa64>>>0)>(3);
    L11: do {
     if ($21) {
      $$046 = $$035$lcssa65;$$13745 = $$036$lcssa64;
      while(1) {
       $22 = HEAP32[$$046>>2]|0;
       $23 = $22 ^ $20;
       $24 = (($23) + -16843009)|0;
       $25 = $23 & -2139062144;
       $26 = $25 ^ -2139062144;
       $27 = $26 & $24;
       $28 = ($27|0)==(0);
       if (!($28)) {
        break;
       }
       $29 = ((($$046)) + 4|0);
       $30 = (($$13745) + -4)|0;
       $31 = ($30>>>0)>(3);
       if ($31) {
        $$046 = $29;$$13745 = $30;
       } else {
        $$0$lcssa = $29;$$137$lcssa = $30;
        label = 11;
        break L11;
       }
      }
      $$140 = $$046;$$23839 = $$13745;
     } else {
      $$0$lcssa = $$035$lcssa65;$$137$lcssa = $$036$lcssa64;
      label = 11;
     }
    } while(0);
    if ((label|0) == 11) {
     $32 = ($$137$lcssa|0)==(0);
     if ($32) {
      $$2 = $$0$lcssa;$$3 = 0;
      break;
     } else {
      $$140 = $$0$lcssa;$$23839 = $$137$lcssa;
     }
    }
    while(1) {
     $33 = HEAP8[$$140>>0]|0;
     $34 = ($33<<24>>24)==($18<<24>>24);
     if ($34) {
      $$2 = $$140;$$3 = $$23839;
      break L8;
     }
     $35 = ((($$140)) + 1|0);
     $36 = (($$23839) + -1)|0;
     $37 = ($36|0)==(0);
     if ($37) {
      $$2 = $35;$$3 = 0;
      break;
     } else {
      $$140 = $35;$$23839 = $36;
     }
    }
   }
  }
 } while(0);
 $38 = ($$3|0)!=(0);
 $39 = $38 ? $$2 : 0;
 return ($39|0);
}
function _pad_452($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0$lcssa = 0, $$011 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 256|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(256|0);
 $5 = sp;
 $6 = $4 & 73728;
 $7 = ($6|0)==(0);
 $8 = ($2|0)>($3|0);
 $or$cond = $8 & $7;
 if ($or$cond) {
  $9 = (($2) - ($3))|0;
  $10 = ($9>>>0)<(256);
  $11 = $10 ? $9 : 256;
  _memset(($5|0),($1|0),($11|0))|0;
  $12 = ($9>>>0)>(255);
  if ($12) {
   $13 = (($2) - ($3))|0;
   $$011 = $9;
   while(1) {
    _out($0,$5,256);
    $14 = (($$011) + -256)|0;
    $15 = ($14>>>0)>(255);
    if ($15) {
     $$011 = $14;
    } else {
     break;
    }
   }
   $16 = $13 & 255;
   $$0$lcssa = $16;
  } else {
   $$0$lcssa = $9;
  }
  _out($0,$5,$$0$lcssa);
 }
 STACKTOP = sp;return;
}
function _wctomb($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($0|0)==(0|0);
 if ($2) {
  $$0 = 0;
 } else {
  $3 = (_wcrtomb($0,$1,0)|0);
  $$0 = $3;
 }
 return ($$0|0);
}
function _fmt_fp($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = +$1;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$ = 0, $$$ = 0, $$$$559 = 0.0, $$$3484 = 0, $$$3484691 = 0, $$$3484692 = 0, $$$3501 = 0, $$$4502 = 0, $$$542 = 0.0, $$$559 = 0.0, $$0 = 0, $$0463$lcssa = 0, $$0463584 = 0, $$0464594 = 0, $$0471 = 0.0, $$0479 = 0, $$0487642 = 0, $$0488 = 0, $$0488653 = 0, $$0488655 = 0;
 var $$0496$$9 = 0, $$0497654 = 0, $$0498 = 0, $$0509582 = 0.0, $$0510 = 0, $$0511 = 0, $$0514637 = 0, $$0520 = 0, $$0521 = 0, $$0521$ = 0, $$0523 = 0, $$0525 = 0, $$0527 = 0, $$0527629 = 0, $$0527631 = 0, $$0530636 = 0, $$1465 = 0, $$1467 = 0.0, $$1469 = 0.0, $$1472 = 0.0;
 var $$1480 = 0, $$1482$lcssa = 0, $$1482661 = 0, $$1489641 = 0, $$1499$lcssa = 0, $$1499660 = 0, $$1508583 = 0, $$1512$lcssa = 0, $$1512607 = 0, $$1515 = 0, $$1524 = 0, $$1526 = 0, $$1528614 = 0, $$1531$lcssa = 0, $$1531630 = 0, $$1598 = 0, $$2 = 0, $$2473 = 0.0, $$2476 = 0, $$2476$$547 = 0;
 var $$2476$$549 = 0, $$2483$ph = 0, $$2500 = 0, $$2513 = 0, $$2516618 = 0, $$2529 = 0, $$2532617 = 0, $$3 = 0.0, $$3477 = 0, $$3484$lcssa = 0, $$3484648 = 0, $$3501$lcssa = 0, $$3501647 = 0, $$3533613 = 0, $$4 = 0.0, $$4478$lcssa = 0, $$4478590 = 0, $$4492 = 0, $$4502 = 0, $$4518 = 0;
 var $$5$lcssa = 0, $$534$ = 0, $$539 = 0, $$539$ = 0, $$542 = 0.0, $$546 = 0, $$548 = 0, $$5486$lcssa = 0, $$5486623 = 0, $$5493597 = 0, $$5519$ph = 0, $$555 = 0, $$556 = 0, $$559 = 0.0, $$5602 = 0, $$6 = 0, $$6494589 = 0, $$7495601 = 0, $$7505 = 0, $$7505$ = 0;
 var $$7505$ph = 0, $$8 = 0, $$9$ph = 0, $$lcssa673 = 0, $$neg = 0, $$neg567 = 0, $$pn = 0, $$pn566 = 0, $$pr = 0, $$pr564 = 0, $$pre = 0, $$pre$phi690Z2D = 0, $$pre689 = 0, $$sink545$lcssa = 0, $$sink545622 = 0, $$sink562 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0.0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0.0, $117 = 0.0, $118 = 0.0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0;
 var $14 = 0.0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0;
 var $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0;
 var $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0;
 var $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0;
 var $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0.0, $229 = 0.0, $23 = 0;
 var $230 = 0, $231 = 0.0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0;
 var $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0;
 var $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0;
 var $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0;
 var $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0;
 var $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0;
 var $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0.0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0;
 var $358 = 0, $359 = 0, $36 = 0.0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0;
 var $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0.0, $52 = 0, $53 = 0, $54 = 0, $55 = 0.0, $56 = 0.0, $57 = 0.0, $58 = 0.0, $59 = 0.0, $6 = 0, $60 = 0.0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0.0, $88 = 0.0, $89 = 0.0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0;
 var $narrow = 0, $not$ = 0, $notlhs = 0, $notrhs = 0, $or$cond = 0, $or$cond3$not = 0, $or$cond537 = 0, $or$cond541 = 0, $or$cond544 = 0, $or$cond554 = 0, $or$cond6 = 0, $scevgep684 = 0, $scevgep684685 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 560|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(560|0);
 $6 = sp + 8|0;
 $7 = sp;
 $8 = sp + 524|0;
 $9 = $8;
 $10 = sp + 512|0;
 HEAP32[$7>>2] = 0;
 $11 = ((($10)) + 12|0);
 (___DOUBLE_BITS_453($1)|0);
 $12 = tempRet0;
 $13 = ($12|0)<(0);
 if ($13) {
  $14 = -$1;
  $$0471 = $14;$$0520 = 1;$$0521 = 199788;
 } else {
  $15 = $4 & 2048;
  $16 = ($15|0)==(0);
  $17 = $4 & 1;
  $18 = ($17|0)==(0);
  $$ = $18 ? (199789) : (199794);
  $$$ = $16 ? $$ : (199791);
  $19 = $4 & 2049;
  $narrow = ($19|0)!=(0);
  $$534$ = $narrow&1;
  $$0471 = $1;$$0520 = $$534$;$$0521 = $$$;
 }
 (___DOUBLE_BITS_453($$0471)|0);
 $20 = tempRet0;
 $21 = $20 & 2146435072;
 $22 = ($21>>>0)<(2146435072);
 $23 = (0)<(0);
 $24 = ($21|0)==(2146435072);
 $25 = $24 & $23;
 $26 = $22 | $25;
 do {
  if ($26) {
   $35 = (+_frexpl($$0471,$7));
   $36 = $35 * 2.0;
   $37 = $36 != 0.0;
   if ($37) {
    $38 = HEAP32[$7>>2]|0;
    $39 = (($38) + -1)|0;
    HEAP32[$7>>2] = $39;
   }
   $40 = $5 | 32;
   $41 = ($40|0)==(97);
   if ($41) {
    $42 = $5 & 32;
    $43 = ($42|0)==(0);
    $44 = ((($$0521)) + 9|0);
    $$0521$ = $43 ? $$0521 : $44;
    $45 = $$0520 | 2;
    $46 = ($3>>>0)>(11);
    $47 = (12 - ($3))|0;
    $48 = ($47|0)==(0);
    $49 = $46 | $48;
    do {
     if ($49) {
      $$1472 = $36;
     } else {
      $$0509582 = 8.0;$$1508583 = $47;
      while(1) {
       $50 = (($$1508583) + -1)|0;
       $51 = $$0509582 * 16.0;
       $52 = ($50|0)==(0);
       if ($52) {
        break;
       } else {
        $$0509582 = $51;$$1508583 = $50;
       }
      }
      $53 = HEAP8[$$0521$>>0]|0;
      $54 = ($53<<24>>24)==(45);
      if ($54) {
       $55 = -$36;
       $56 = $55 - $51;
       $57 = $51 + $56;
       $58 = -$57;
       $$1472 = $58;
       break;
      } else {
       $59 = $36 + $51;
       $60 = $59 - $51;
       $$1472 = $60;
       break;
      }
     }
    } while(0);
    $61 = HEAP32[$7>>2]|0;
    $62 = ($61|0)<(0);
    $63 = (0 - ($61))|0;
    $64 = $62 ? $63 : $61;
    $65 = ($64|0)<(0);
    $66 = $65 << 31 >> 31;
    $67 = (_fmt_u($64,$66,$11)|0);
    $68 = ($67|0)==($11|0);
    if ($68) {
     $69 = ((($10)) + 11|0);
     HEAP8[$69>>0] = 48;
     $$0511 = $69;
    } else {
     $$0511 = $67;
    }
    $70 = $61 >> 31;
    $71 = $70 & 2;
    $72 = (($71) + 43)|0;
    $73 = $72&255;
    $74 = ((($$0511)) + -1|0);
    HEAP8[$74>>0] = $73;
    $75 = (($5) + 15)|0;
    $76 = $75&255;
    $77 = ((($$0511)) + -2|0);
    HEAP8[$77>>0] = $76;
    $notrhs = ($3|0)<(1);
    $78 = $4 & 8;
    $79 = ($78|0)==(0);
    $$0523 = $8;$$2473 = $$1472;
    while(1) {
     $80 = (~~(($$2473)));
     $81 = (199823 + ($80)|0);
     $82 = HEAP8[$81>>0]|0;
     $83 = $82&255;
     $84 = $83 | $42;
     $85 = $84&255;
     $86 = ((($$0523)) + 1|0);
     HEAP8[$$0523>>0] = $85;
     $87 = (+($80|0));
     $88 = $$2473 - $87;
     $89 = $88 * 16.0;
     $90 = $86;
     $91 = (($90) - ($9))|0;
     $92 = ($91|0)==(1);
     if ($92) {
      $notlhs = $89 == 0.0;
      $or$cond3$not = $notrhs & $notlhs;
      $or$cond = $79 & $or$cond3$not;
      if ($or$cond) {
       $$1524 = $86;
      } else {
       $93 = ((($$0523)) + 2|0);
       HEAP8[$86>>0] = 46;
       $$1524 = $93;
      }
     } else {
      $$1524 = $86;
     }
     $94 = $89 != 0.0;
     if ($94) {
      $$0523 = $$1524;$$2473 = $89;
     } else {
      break;
     }
    }
    $95 = ($3|0)!=(0);
    $96 = $77;
    $97 = $11;
    $98 = $$1524;
    $99 = (($98) - ($9))|0;
    $100 = (($97) - ($96))|0;
    $101 = (($99) + -2)|0;
    $102 = ($101|0)<($3|0);
    $or$cond537 = $95 & $102;
    $103 = (($3) + 2)|0;
    $$pn = $or$cond537 ? $103 : $99;
    $$0525 = (($100) + ($45))|0;
    $104 = (($$0525) + ($$pn))|0;
    _pad_452($0,32,$2,$104,$4);
    _out($0,$$0521$,$45);
    $105 = $4 ^ 65536;
    _pad_452($0,48,$2,$104,$105);
    _out($0,$8,$99);
    $106 = (($$pn) - ($99))|0;
    _pad_452($0,48,$106,0,0);
    _out($0,$77,$100);
    $107 = $4 ^ 8192;
    _pad_452($0,32,$2,$104,$107);
    $$sink562 = $104;
    break;
   }
   $108 = ($3|0)<(0);
   $$539 = $108 ? 6 : $3;
   if ($37) {
    $109 = $36 * 268435456.0;
    $110 = HEAP32[$7>>2]|0;
    $111 = (($110) + -28)|0;
    HEAP32[$7>>2] = $111;
    $$3 = $109;$$pr = $111;
   } else {
    $$pre = HEAP32[$7>>2]|0;
    $$3 = $36;$$pr = $$pre;
   }
   $112 = ($$pr|0)<(0);
   $113 = ((($6)) + 288|0);
   $$556 = $112 ? $6 : $113;
   $$0498 = $$556;$$4 = $$3;
   while(1) {
    $114 = (~~(($$4))>>>0);
    HEAP32[$$0498>>2] = $114;
    $115 = ((($$0498)) + 4|0);
    $116 = (+($114>>>0));
    $117 = $$4 - $116;
    $118 = $117 * 1.0E+9;
    $119 = $118 != 0.0;
    if ($119) {
     $$0498 = $115;$$4 = $118;
    } else {
     break;
    }
   }
   $120 = ($$pr|0)>(0);
   if ($120) {
    $$1482661 = $$556;$$1499660 = $115;$121 = $$pr;
    while(1) {
     $122 = ($121|0)<(29);
     $123 = $122 ? $121 : 29;
     $$0488653 = ((($$1499660)) + -4|0);
     $124 = ($$0488653>>>0)<($$1482661>>>0);
     if ($124) {
      $$2483$ph = $$1482661;
     } else {
      $$0488655 = $$0488653;$$0497654 = 0;
      while(1) {
       $125 = HEAP32[$$0488655>>2]|0;
       $126 = (_bitshift64Shl(($125|0),0,($123|0))|0);
       $127 = tempRet0;
       $128 = (_i64Add(($126|0),($127|0),($$0497654|0),0)|0);
       $129 = tempRet0;
       $130 = (___uremdi3(($128|0),($129|0),1000000000,0)|0);
       $131 = tempRet0;
       HEAP32[$$0488655>>2] = $130;
       $132 = (___udivdi3(($128|0),($129|0),1000000000,0)|0);
       $133 = tempRet0;
       $$0488 = ((($$0488655)) + -4|0);
       $134 = ($$0488>>>0)<($$1482661>>>0);
       if ($134) {
        break;
       } else {
        $$0488655 = $$0488;$$0497654 = $132;
       }
      }
      $135 = ($132|0)==(0);
      if ($135) {
       $$2483$ph = $$1482661;
      } else {
       $136 = ((($$1482661)) + -4|0);
       HEAP32[$136>>2] = $132;
       $$2483$ph = $136;
      }
     }
     $$2500 = $$1499660;
     while(1) {
      $137 = ($$2500>>>0)>($$2483$ph>>>0);
      if (!($137)) {
       break;
      }
      $138 = ((($$2500)) + -4|0);
      $139 = HEAP32[$138>>2]|0;
      $140 = ($139|0)==(0);
      if ($140) {
       $$2500 = $138;
      } else {
       break;
      }
     }
     $141 = HEAP32[$7>>2]|0;
     $142 = (($141) - ($123))|0;
     HEAP32[$7>>2] = $142;
     $143 = ($142|0)>(0);
     if ($143) {
      $$1482661 = $$2483$ph;$$1499660 = $$2500;$121 = $142;
     } else {
      $$1482$lcssa = $$2483$ph;$$1499$lcssa = $$2500;$$pr564 = $142;
      break;
     }
    }
   } else {
    $$1482$lcssa = $$556;$$1499$lcssa = $115;$$pr564 = $$pr;
   }
   $144 = ($$pr564|0)<(0);
   if ($144) {
    $145 = (($$539) + 25)|0;
    $146 = (($145|0) / 9)&-1;
    $147 = (($146) + 1)|0;
    $148 = ($40|0)==(102);
    $$3484648 = $$1482$lcssa;$$3501647 = $$1499$lcssa;$150 = $$pr564;
    while(1) {
     $149 = (0 - ($150))|0;
     $151 = ($149|0)<(9);
     $152 = $151 ? $149 : 9;
     $153 = ($$3484648>>>0)<($$3501647>>>0);
     if ($153) {
      $157 = 1 << $152;
      $158 = (($157) + -1)|0;
      $159 = 1000000000 >>> $152;
      $$0487642 = 0;$$1489641 = $$3484648;
      while(1) {
       $160 = HEAP32[$$1489641>>2]|0;
       $161 = $160 & $158;
       $162 = $160 >>> $152;
       $163 = (($162) + ($$0487642))|0;
       HEAP32[$$1489641>>2] = $163;
       $164 = Math_imul($161, $159)|0;
       $165 = ((($$1489641)) + 4|0);
       $166 = ($165>>>0)<($$3501647>>>0);
       if ($166) {
        $$0487642 = $164;$$1489641 = $165;
       } else {
        break;
       }
      }
      $167 = HEAP32[$$3484648>>2]|0;
      $168 = ($167|0)==(0);
      $169 = ((($$3484648)) + 4|0);
      $$$3484 = $168 ? $169 : $$3484648;
      $170 = ($164|0)==(0);
      if ($170) {
       $$$3484692 = $$$3484;$$4502 = $$3501647;
      } else {
       $171 = ((($$3501647)) + 4|0);
       HEAP32[$$3501647>>2] = $164;
       $$$3484692 = $$$3484;$$4502 = $171;
      }
     } else {
      $154 = HEAP32[$$3484648>>2]|0;
      $155 = ($154|0)==(0);
      $156 = ((($$3484648)) + 4|0);
      $$$3484691 = $155 ? $156 : $$3484648;
      $$$3484692 = $$$3484691;$$4502 = $$3501647;
     }
     $172 = $148 ? $$556 : $$$3484692;
     $173 = $$4502;
     $174 = $172;
     $175 = (($173) - ($174))|0;
     $176 = $175 >> 2;
     $177 = ($176|0)>($147|0);
     $178 = (($172) + ($147<<2)|0);
     $$$4502 = $177 ? $178 : $$4502;
     $179 = HEAP32[$7>>2]|0;
     $180 = (($179) + ($152))|0;
     HEAP32[$7>>2] = $180;
     $181 = ($180|0)<(0);
     if ($181) {
      $$3484648 = $$$3484692;$$3501647 = $$$4502;$150 = $180;
     } else {
      $$3484$lcssa = $$$3484692;$$3501$lcssa = $$$4502;
      break;
     }
    }
   } else {
    $$3484$lcssa = $$1482$lcssa;$$3501$lcssa = $$1499$lcssa;
   }
   $182 = ($$3484$lcssa>>>0)<($$3501$lcssa>>>0);
   $183 = $$556;
   if ($182) {
    $184 = $$3484$lcssa;
    $185 = (($183) - ($184))|0;
    $186 = $185 >> 2;
    $187 = ($186*9)|0;
    $188 = HEAP32[$$3484$lcssa>>2]|0;
    $189 = ($188>>>0)<(10);
    if ($189) {
     $$1515 = $187;
    } else {
     $$0514637 = $187;$$0530636 = 10;
     while(1) {
      $190 = ($$0530636*10)|0;
      $191 = (($$0514637) + 1)|0;
      $192 = ($188>>>0)<($190>>>0);
      if ($192) {
       $$1515 = $191;
       break;
      } else {
       $$0514637 = $191;$$0530636 = $190;
      }
     }
    }
   } else {
    $$1515 = 0;
   }
   $193 = ($40|0)!=(102);
   $194 = $193 ? $$1515 : 0;
   $195 = (($$539) - ($194))|0;
   $196 = ($40|0)==(103);
   $197 = ($$539|0)!=(0);
   $198 = $197 & $196;
   $$neg = $198 << 31 >> 31;
   $199 = (($195) + ($$neg))|0;
   $200 = $$3501$lcssa;
   $201 = (($200) - ($183))|0;
   $202 = $201 >> 2;
   $203 = ($202*9)|0;
   $204 = (($203) + -9)|0;
   $205 = ($199|0)<($204|0);
   if ($205) {
    $206 = ((($$556)) + 4|0);
    $207 = (($199) + 9216)|0;
    $208 = (($207|0) / 9)&-1;
    $209 = (($208) + -1024)|0;
    $210 = (($206) + ($209<<2)|0);
    $211 = (($207|0) % 9)&-1;
    $$0527629 = (($211) + 1)|0;
    $212 = ($$0527629|0)<(9);
    if ($212) {
     $$0527631 = $$0527629;$$1531630 = 10;
     while(1) {
      $213 = ($$1531630*10)|0;
      $$0527 = (($$0527631) + 1)|0;
      $exitcond = ($$0527|0)==(9);
      if ($exitcond) {
       $$1531$lcssa = $213;
       break;
      } else {
       $$0527631 = $$0527;$$1531630 = $213;
      }
     }
    } else {
     $$1531$lcssa = 10;
    }
    $214 = HEAP32[$210>>2]|0;
    $215 = (($214>>>0) % ($$1531$lcssa>>>0))&-1;
    $216 = ($215|0)==(0);
    $217 = ((($210)) + 4|0);
    $218 = ($217|0)==($$3501$lcssa|0);
    $or$cond541 = $218 & $216;
    if ($or$cond541) {
     $$4492 = $210;$$4518 = $$1515;$$8 = $$3484$lcssa;
    } else {
     $219 = (($214>>>0) / ($$1531$lcssa>>>0))&-1;
     $220 = $219 & 1;
     $221 = ($220|0)==(0);
     $$542 = $221 ? 9007199254740992.0 : 9007199254740994.0;
     $222 = (($$1531$lcssa|0) / 2)&-1;
     $223 = ($215>>>0)<($222>>>0);
     $224 = ($215|0)==($222|0);
     $or$cond544 = $218 & $224;
     $$559 = $or$cond544 ? 1.0 : 1.5;
     $$$559 = $223 ? 0.5 : $$559;
     $225 = ($$0520|0)==(0);
     if ($225) {
      $$1467 = $$$559;$$1469 = $$542;
     } else {
      $226 = HEAP8[$$0521>>0]|0;
      $227 = ($226<<24>>24)==(45);
      $228 = -$$542;
      $229 = -$$$559;
      $$$542 = $227 ? $228 : $$542;
      $$$$559 = $227 ? $229 : $$$559;
      $$1467 = $$$$559;$$1469 = $$$542;
     }
     $230 = (($214) - ($215))|0;
     HEAP32[$210>>2] = $230;
     $231 = $$1469 + $$1467;
     $232 = $231 != $$1469;
     if ($232) {
      $233 = (($230) + ($$1531$lcssa))|0;
      HEAP32[$210>>2] = $233;
      $234 = ($233>>>0)>(999999999);
      if ($234) {
       $$5486623 = $$3484$lcssa;$$sink545622 = $210;
       while(1) {
        $235 = ((($$sink545622)) + -4|0);
        HEAP32[$$sink545622>>2] = 0;
        $236 = ($235>>>0)<($$5486623>>>0);
        if ($236) {
         $237 = ((($$5486623)) + -4|0);
         HEAP32[$237>>2] = 0;
         $$6 = $237;
        } else {
         $$6 = $$5486623;
        }
        $238 = HEAP32[$235>>2]|0;
        $239 = (($238) + 1)|0;
        HEAP32[$235>>2] = $239;
        $240 = ($239>>>0)>(999999999);
        if ($240) {
         $$5486623 = $$6;$$sink545622 = $235;
        } else {
         $$5486$lcssa = $$6;$$sink545$lcssa = $235;
         break;
        }
       }
      } else {
       $$5486$lcssa = $$3484$lcssa;$$sink545$lcssa = $210;
      }
      $241 = $$5486$lcssa;
      $242 = (($183) - ($241))|0;
      $243 = $242 >> 2;
      $244 = ($243*9)|0;
      $245 = HEAP32[$$5486$lcssa>>2]|0;
      $246 = ($245>>>0)<(10);
      if ($246) {
       $$4492 = $$sink545$lcssa;$$4518 = $244;$$8 = $$5486$lcssa;
      } else {
       $$2516618 = $244;$$2532617 = 10;
       while(1) {
        $247 = ($$2532617*10)|0;
        $248 = (($$2516618) + 1)|0;
        $249 = ($245>>>0)<($247>>>0);
        if ($249) {
         $$4492 = $$sink545$lcssa;$$4518 = $248;$$8 = $$5486$lcssa;
         break;
        } else {
         $$2516618 = $248;$$2532617 = $247;
        }
       }
      }
     } else {
      $$4492 = $210;$$4518 = $$1515;$$8 = $$3484$lcssa;
     }
    }
    $250 = ((($$4492)) + 4|0);
    $251 = ($$3501$lcssa>>>0)>($250>>>0);
    $$$3501 = $251 ? $250 : $$3501$lcssa;
    $$5519$ph = $$4518;$$7505$ph = $$$3501;$$9$ph = $$8;
   } else {
    $$5519$ph = $$1515;$$7505$ph = $$3501$lcssa;$$9$ph = $$3484$lcssa;
   }
   $$7505 = $$7505$ph;
   while(1) {
    $252 = ($$7505>>>0)>($$9$ph>>>0);
    if (!($252)) {
     $$lcssa673 = 0;
     break;
    }
    $253 = ((($$7505)) + -4|0);
    $254 = HEAP32[$253>>2]|0;
    $255 = ($254|0)==(0);
    if ($255) {
     $$7505 = $253;
    } else {
     $$lcssa673 = 1;
     break;
    }
   }
   $256 = (0 - ($$5519$ph))|0;
   do {
    if ($196) {
     $not$ = $197 ^ 1;
     $257 = $not$&1;
     $$539$ = (($257) + ($$539))|0;
     $258 = ($$539$|0)>($$5519$ph|0);
     $259 = ($$5519$ph|0)>(-5);
     $or$cond6 = $258 & $259;
     if ($or$cond6) {
      $260 = (($5) + -1)|0;
      $$neg567 = (($$539$) + -1)|0;
      $261 = (($$neg567) - ($$5519$ph))|0;
      $$0479 = $260;$$2476 = $261;
     } else {
      $262 = (($5) + -2)|0;
      $263 = (($$539$) + -1)|0;
      $$0479 = $262;$$2476 = $263;
     }
     $264 = $4 & 8;
     $265 = ($264|0)==(0);
     if ($265) {
      if ($$lcssa673) {
       $266 = ((($$7505)) + -4|0);
       $267 = HEAP32[$266>>2]|0;
       $268 = ($267|0)==(0);
       if ($268) {
        $$2529 = 9;
       } else {
        $269 = (($267>>>0) % 10)&-1;
        $270 = ($269|0)==(0);
        if ($270) {
         $$1528614 = 0;$$3533613 = 10;
         while(1) {
          $271 = ($$3533613*10)|0;
          $272 = (($$1528614) + 1)|0;
          $273 = (($267>>>0) % ($271>>>0))&-1;
          $274 = ($273|0)==(0);
          if ($274) {
           $$1528614 = $272;$$3533613 = $271;
          } else {
           $$2529 = $272;
           break;
          }
         }
        } else {
         $$2529 = 0;
        }
       }
      } else {
       $$2529 = 9;
      }
      $275 = $$0479 | 32;
      $276 = ($275|0)==(102);
      $277 = $$7505;
      $278 = (($277) - ($183))|0;
      $279 = $278 >> 2;
      $280 = ($279*9)|0;
      $281 = (($280) + -9)|0;
      if ($276) {
       $282 = (($281) - ($$2529))|0;
       $283 = ($282|0)>(0);
       $$546 = $283 ? $282 : 0;
       $284 = ($$2476|0)<($$546|0);
       $$2476$$547 = $284 ? $$2476 : $$546;
       $$1480 = $$0479;$$3477 = $$2476$$547;$$pre$phi690Z2D = 0;
       break;
      } else {
       $285 = (($281) + ($$5519$ph))|0;
       $286 = (($285) - ($$2529))|0;
       $287 = ($286|0)>(0);
       $$548 = $287 ? $286 : 0;
       $288 = ($$2476|0)<($$548|0);
       $$2476$$549 = $288 ? $$2476 : $$548;
       $$1480 = $$0479;$$3477 = $$2476$$549;$$pre$phi690Z2D = 0;
       break;
      }
     } else {
      $$1480 = $$0479;$$3477 = $$2476;$$pre$phi690Z2D = $264;
     }
    } else {
     $$pre689 = $4 & 8;
     $$1480 = $5;$$3477 = $$539;$$pre$phi690Z2D = $$pre689;
    }
   } while(0);
   $289 = $$3477 | $$pre$phi690Z2D;
   $290 = ($289|0)!=(0);
   $291 = $290&1;
   $292 = $$1480 | 32;
   $293 = ($292|0)==(102);
   if ($293) {
    $294 = ($$5519$ph|0)>(0);
    $295 = $294 ? $$5519$ph : 0;
    $$2513 = 0;$$pn566 = $295;
   } else {
    $296 = ($$5519$ph|0)<(0);
    $297 = $296 ? $256 : $$5519$ph;
    $298 = ($297|0)<(0);
    $299 = $298 << 31 >> 31;
    $300 = (_fmt_u($297,$299,$11)|0);
    $301 = $11;
    $302 = $300;
    $303 = (($301) - ($302))|0;
    $304 = ($303|0)<(2);
    if ($304) {
     $$1512607 = $300;
     while(1) {
      $305 = ((($$1512607)) + -1|0);
      HEAP8[$305>>0] = 48;
      $306 = $305;
      $307 = (($301) - ($306))|0;
      $308 = ($307|0)<(2);
      if ($308) {
       $$1512607 = $305;
      } else {
       $$1512$lcssa = $305;
       break;
      }
     }
    } else {
     $$1512$lcssa = $300;
    }
    $309 = $$5519$ph >> 31;
    $310 = $309 & 2;
    $311 = (($310) + 43)|0;
    $312 = $311&255;
    $313 = ((($$1512$lcssa)) + -1|0);
    HEAP8[$313>>0] = $312;
    $314 = $$1480&255;
    $315 = ((($$1512$lcssa)) + -2|0);
    HEAP8[$315>>0] = $314;
    $316 = $315;
    $317 = (($301) - ($316))|0;
    $$2513 = $315;$$pn566 = $317;
   }
   $318 = (($$0520) + 1)|0;
   $319 = (($318) + ($$3477))|0;
   $$1526 = (($319) + ($291))|0;
   $320 = (($$1526) + ($$pn566))|0;
   _pad_452($0,32,$2,$320,$4);
   _out($0,$$0521,$$0520);
   $321 = $4 ^ 65536;
   _pad_452($0,48,$2,$320,$321);
   if ($293) {
    $322 = ($$9$ph>>>0)>($$556>>>0);
    $$0496$$9 = $322 ? $$556 : $$9$ph;
    $323 = ((($8)) + 9|0);
    $324 = $323;
    $325 = ((($8)) + 8|0);
    $$5493597 = $$0496$$9;
    while(1) {
     $326 = HEAP32[$$5493597>>2]|0;
     $327 = (_fmt_u($326,0,$323)|0);
     $328 = ($$5493597|0)==($$0496$$9|0);
     if ($328) {
      $334 = ($327|0)==($323|0);
      if ($334) {
       HEAP8[$325>>0] = 48;
       $$1465 = $325;
      } else {
       $$1465 = $327;
      }
     } else {
      $329 = ($327>>>0)>($8>>>0);
      if ($329) {
       $330 = $327;
       $331 = (($330) - ($9))|0;
       _memset(($8|0),48,($331|0))|0;
       $$0464594 = $327;
       while(1) {
        $332 = ((($$0464594)) + -1|0);
        $333 = ($332>>>0)>($8>>>0);
        if ($333) {
         $$0464594 = $332;
        } else {
         $$1465 = $332;
         break;
        }
       }
      } else {
       $$1465 = $327;
      }
     }
     $335 = $$1465;
     $336 = (($324) - ($335))|0;
     _out($0,$$1465,$336);
     $337 = ((($$5493597)) + 4|0);
     $338 = ($337>>>0)>($$556>>>0);
     if ($338) {
      break;
     } else {
      $$5493597 = $337;
     }
    }
    $339 = ($289|0)==(0);
    if (!($339)) {
     _out($0,199839,1);
    }
    $340 = ($337>>>0)<($$7505>>>0);
    $341 = ($$3477|0)>(0);
    $342 = $340 & $341;
    if ($342) {
     $$4478590 = $$3477;$$6494589 = $337;
     while(1) {
      $343 = HEAP32[$$6494589>>2]|0;
      $344 = (_fmt_u($343,0,$323)|0);
      $345 = ($344>>>0)>($8>>>0);
      if ($345) {
       $346 = $344;
       $347 = (($346) - ($9))|0;
       _memset(($8|0),48,($347|0))|0;
       $$0463584 = $344;
       while(1) {
        $348 = ((($$0463584)) + -1|0);
        $349 = ($348>>>0)>($8>>>0);
        if ($349) {
         $$0463584 = $348;
        } else {
         $$0463$lcssa = $348;
         break;
        }
       }
      } else {
       $$0463$lcssa = $344;
      }
      $350 = ($$4478590|0)<(9);
      $351 = $350 ? $$4478590 : 9;
      _out($0,$$0463$lcssa,$351);
      $352 = ((($$6494589)) + 4|0);
      $353 = (($$4478590) + -9)|0;
      $354 = ($352>>>0)<($$7505>>>0);
      $355 = ($$4478590|0)>(9);
      $356 = $354 & $355;
      if ($356) {
       $$4478590 = $353;$$6494589 = $352;
      } else {
       $$4478$lcssa = $353;
       break;
      }
     }
    } else {
     $$4478$lcssa = $$3477;
    }
    $357 = (($$4478$lcssa) + 9)|0;
    _pad_452($0,48,$357,9,0);
   } else {
    $358 = ((($$9$ph)) + 4|0);
    $$7505$ = $$lcssa673 ? $$7505 : $358;
    $359 = ($$3477|0)>(-1);
    if ($359) {
     $360 = ((($8)) + 9|0);
     $361 = ($$pre$phi690Z2D|0)==(0);
     $362 = $360;
     $363 = (0 - ($9))|0;
     $364 = ((($8)) + 8|0);
     $$5602 = $$3477;$$7495601 = $$9$ph;
     while(1) {
      $365 = HEAP32[$$7495601>>2]|0;
      $366 = (_fmt_u($365,0,$360)|0);
      $367 = ($366|0)==($360|0);
      if ($367) {
       HEAP8[$364>>0] = 48;
       $$0 = $364;
      } else {
       $$0 = $366;
      }
      $368 = ($$7495601|0)==($$9$ph|0);
      do {
       if ($368) {
        $372 = ((($$0)) + 1|0);
        _out($0,$$0,1);
        $373 = ($$5602|0)<(1);
        $or$cond554 = $361 & $373;
        if ($or$cond554) {
         $$2 = $372;
         break;
        }
        _out($0,199839,1);
        $$2 = $372;
       } else {
        $369 = ($$0>>>0)>($8>>>0);
        if (!($369)) {
         $$2 = $$0;
         break;
        }
        $scevgep684 = (($$0) + ($363)|0);
        $scevgep684685 = $scevgep684;
        _memset(($8|0),48,($scevgep684685|0))|0;
        $$1598 = $$0;
        while(1) {
         $370 = ((($$1598)) + -1|0);
         $371 = ($370>>>0)>($8>>>0);
         if ($371) {
          $$1598 = $370;
         } else {
          $$2 = $370;
          break;
         }
        }
       }
      } while(0);
      $374 = $$2;
      $375 = (($362) - ($374))|0;
      $376 = ($$5602|0)>($375|0);
      $377 = $376 ? $375 : $$5602;
      _out($0,$$2,$377);
      $378 = (($$5602) - ($375))|0;
      $379 = ((($$7495601)) + 4|0);
      $380 = ($379>>>0)<($$7505$>>>0);
      $381 = ($378|0)>(-1);
      $382 = $380 & $381;
      if ($382) {
       $$5602 = $378;$$7495601 = $379;
      } else {
       $$5$lcssa = $378;
       break;
      }
     }
    } else {
     $$5$lcssa = $$3477;
    }
    $383 = (($$5$lcssa) + 18)|0;
    _pad_452($0,48,$383,18,0);
    $384 = $11;
    $385 = $$2513;
    $386 = (($384) - ($385))|0;
    _out($0,$$2513,$386);
   }
   $387 = $4 ^ 8192;
   _pad_452($0,32,$2,$320,$387);
   $$sink562 = $320;
  } else {
   $27 = $5 & 32;
   $28 = ($27|0)!=(0);
   $29 = $28 ? 199807 : 199811;
   $30 = ($$0471 != $$0471) | (0.0 != 0.0);
   $31 = $28 ? 199815 : 199819;
   $$0510 = $30 ? $31 : $29;
   $32 = (($$0520) + 3)|0;
   $33 = $4 & -65537;
   _pad_452($0,32,$2,$32,$33);
   _out($0,$$0521,$$0520);
   _out($0,$$0510,3);
   $34 = $4 ^ 8192;
   _pad_452($0,32,$2,$32,$34);
   $$sink562 = $32;
  }
 } while(0);
 $388 = ($$sink562|0)<($2|0);
 $$555 = $388 ? $2 : $$sink562;
 STACKTOP = sp;return ($$555|0);
}
function ___DOUBLE_BITS_453($0) {
 $0 = +$0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF64[tempDoublePtr>>3] = $0;$1 = HEAP32[tempDoublePtr>>2]|0;
 $2 = HEAP32[tempDoublePtr+4>>2]|0;
 tempRet0 = ($2);
 return ($1|0);
}
function _frexpl($0,$1) {
 $0 = +$0;
 $1 = $1|0;
 var $2 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (+_frexp($0,$1));
 return (+$2);
}
function _frexp($0,$1) {
 $0 = +$0;
 $1 = $1|0;
 var $$0 = 0.0, $$016 = 0.0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0.0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0.0, $9 = 0.0, $storemerge = 0, $trunc$clear = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 HEAPF64[tempDoublePtr>>3] = $0;$2 = HEAP32[tempDoublePtr>>2]|0;
 $3 = HEAP32[tempDoublePtr+4>>2]|0;
 $4 = (_bitshift64Lshr(($2|0),($3|0),52)|0);
 $5 = tempRet0;
 $6 = $4&65535;
 $trunc$clear = $6 & 2047;
 switch ($trunc$clear<<16>>16) {
 case 0:  {
  $7 = $0 != 0.0;
  if ($7) {
   $8 = $0 * 1.8446744073709552E+19;
   $9 = (+_frexp($8,$1));
   $10 = HEAP32[$1>>2]|0;
   $11 = (($10) + -64)|0;
   $$016 = $9;$storemerge = $11;
  } else {
   $$016 = $0;$storemerge = 0;
  }
  HEAP32[$1>>2] = $storemerge;
  $$0 = $$016;
  break;
 }
 case 2047:  {
  $$0 = $0;
  break;
 }
 default: {
  $12 = $4 & 2047;
  $13 = (($12) + -1022)|0;
  HEAP32[$1>>2] = $13;
  $14 = $3 & -2146435073;
  $15 = $14 | 1071644672;
  HEAP32[tempDoublePtr>>2] = $2;HEAP32[tempDoublePtr+4>>2] = $15;$16 = +HEAPF64[tempDoublePtr>>3];
  $$0 = $16;
 }
 }
 return (+$$0);
}
function _wcrtomb($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $not$ = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($0|0)==(0|0);
 do {
  if ($3) {
   $$0 = 1;
  } else {
   $4 = ($1>>>0)<(128);
   if ($4) {
    $5 = $1&255;
    HEAP8[$0>>0] = $5;
    $$0 = 1;
    break;
   }
   $6 = (___pthread_self_289()|0);
   $7 = ((($6)) + 188|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = HEAP32[$8>>2]|0;
   $not$ = ($9|0)==(0|0);
   if ($not$) {
    $10 = $1 & -128;
    $11 = ($10|0)==(57216);
    if ($11) {
     $13 = $1&255;
     HEAP8[$0>>0] = $13;
     $$0 = 1;
     break;
    } else {
     $12 = (___errno_location()|0);
     HEAP32[$12>>2] = 84;
     $$0 = -1;
     break;
    }
   }
   $14 = ($1>>>0)<(2048);
   if ($14) {
    $15 = $1 >>> 6;
    $16 = $15 | 192;
    $17 = $16&255;
    $18 = ((($0)) + 1|0);
    HEAP8[$0>>0] = $17;
    $19 = $1 & 63;
    $20 = $19 | 128;
    $21 = $20&255;
    HEAP8[$18>>0] = $21;
    $$0 = 2;
    break;
   }
   $22 = ($1>>>0)<(55296);
   $23 = $1 & -8192;
   $24 = ($23|0)==(57344);
   $or$cond = $22 | $24;
   if ($or$cond) {
    $25 = $1 >>> 12;
    $26 = $25 | 224;
    $27 = $26&255;
    $28 = ((($0)) + 1|0);
    HEAP8[$0>>0] = $27;
    $29 = $1 >>> 6;
    $30 = $29 & 63;
    $31 = $30 | 128;
    $32 = $31&255;
    $33 = ((($0)) + 2|0);
    HEAP8[$28>>0] = $32;
    $34 = $1 & 63;
    $35 = $34 | 128;
    $36 = $35&255;
    HEAP8[$33>>0] = $36;
    $$0 = 3;
    break;
   }
   $37 = (($1) + -65536)|0;
   $38 = ($37>>>0)<(1048576);
   if ($38) {
    $39 = $1 >>> 18;
    $40 = $39 | 240;
    $41 = $40&255;
    $42 = ((($0)) + 1|0);
    HEAP8[$0>>0] = $41;
    $43 = $1 >>> 12;
    $44 = $43 & 63;
    $45 = $44 | 128;
    $46 = $45&255;
    $47 = ((($0)) + 2|0);
    HEAP8[$42>>0] = $46;
    $48 = $1 >>> 6;
    $49 = $48 & 63;
    $50 = $49 | 128;
    $51 = $50&255;
    $52 = ((($0)) + 3|0);
    HEAP8[$47>>0] = $51;
    $53 = $1 & 63;
    $54 = $53 | 128;
    $55 = $54&255;
    HEAP8[$52>>0] = $55;
    $$0 = 4;
    break;
   } else {
    $56 = (___errno_location()|0);
    HEAP32[$56>>2] = 84;
    $$0 = -1;
    break;
   }
  }
 } while(0);
 return ($$0|0);
}
function ___pthread_self_289() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_pthread_self()|0);
 return ($0|0);
}
function ___pthread_self_879() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_pthread_self()|0);
 return ($0|0);
}
function ___strerror_l($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$012$lcssa = 0, $$01214 = 0, $$016 = 0, $$113 = 0, $$115 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $$016 = 0;
 while(1) {
  $3 = (199841 + ($$016)|0);
  $4 = HEAP8[$3>>0]|0;
  $5 = $4&255;
  $6 = ($5|0)==($0|0);
  if ($6) {
   label = 2;
   break;
  }
  $7 = (($$016) + 1)|0;
  $8 = ($7|0)==(87);
  if ($8) {
   $$01214 = 199929;$$115 = 87;
   label = 5;
   break;
  } else {
   $$016 = $7;
  }
 }
 if ((label|0) == 2) {
  $2 = ($$016|0)==(0);
  if ($2) {
   $$012$lcssa = 199929;
  } else {
   $$01214 = 199929;$$115 = $$016;
   label = 5;
  }
 }
 if ((label|0) == 5) {
  while(1) {
   label = 0;
   $$113 = $$01214;
   while(1) {
    $9 = HEAP8[$$113>>0]|0;
    $10 = ($9<<24>>24)==(0);
    $11 = ((($$113)) + 1|0);
    if ($10) {
     break;
    } else {
     $$113 = $11;
    }
   }
   $12 = (($$115) + -1)|0;
   $13 = ($12|0)==(0);
   if ($13) {
    $$012$lcssa = $11;
    break;
   } else {
    $$01214 = $11;$$115 = $12;
    label = 5;
   }
  }
 }
 $14 = ((($1)) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (___lctrans($$012$lcssa,$15)|0);
 return ($16|0);
}
function ___lctrans($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (___lctrans_impl($0,$1)|0);
 return ($2|0);
}
function ___lctrans_impl($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0 = 0;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = ((($1)) + 4|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (___mo_lookup($3,$5,$0)|0);
  $$0 = $6;
 }
 $7 = ($$0|0)!=(0|0);
 $8 = $7 ? $$0 : $0;
 return ($8|0);
}
function ___mo_lookup($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$ = 0, $$090 = 0, $$094 = 0, $$191 = 0, $$195 = 0, $$4 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond102 = 0, $or$cond104 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = HEAP32[$0>>2]|0;
 $4 = (($3) + 1794895138)|0;
 $5 = ((($0)) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (_swapc($6,$4)|0);
 $8 = ((($0)) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (_swapc($9,$4)|0);
 $11 = ((($0)) + 16|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (_swapc($12,$4)|0);
 $14 = $1 >>> 2;
 $15 = ($7>>>0)<($14>>>0);
 L1: do {
  if ($15) {
   $16 = $7 << 2;
   $17 = (($1) - ($16))|0;
   $18 = ($10>>>0)<($17>>>0);
   $19 = ($13>>>0)<($17>>>0);
   $or$cond = $18 & $19;
   if ($or$cond) {
    $20 = $13 | $10;
    $21 = $20 & 3;
    $22 = ($21|0)==(0);
    if ($22) {
     $23 = $10 >>> 2;
     $24 = $13 >>> 2;
     $$090 = 0;$$094 = $7;
     while(1) {
      $25 = $$094 >>> 1;
      $26 = (($$090) + ($25))|0;
      $27 = $26 << 1;
      $28 = (($27) + ($23))|0;
      $29 = (($0) + ($28<<2)|0);
      $30 = HEAP32[$29>>2]|0;
      $31 = (_swapc($30,$4)|0);
      $32 = (($28) + 1)|0;
      $33 = (($0) + ($32<<2)|0);
      $34 = HEAP32[$33>>2]|0;
      $35 = (_swapc($34,$4)|0);
      $36 = ($35>>>0)<($1>>>0);
      $37 = (($1) - ($35))|0;
      $38 = ($31>>>0)<($37>>>0);
      $or$cond102 = $36 & $38;
      if (!($or$cond102)) {
       $$4 = 0;
       break L1;
      }
      $39 = (($35) + ($31))|0;
      $40 = (($0) + ($39)|0);
      $41 = HEAP8[$40>>0]|0;
      $42 = ($41<<24>>24)==(0);
      if (!($42)) {
       $$4 = 0;
       break L1;
      }
      $43 = (($0) + ($35)|0);
      $44 = (_strcmp($2,$43)|0);
      $45 = ($44|0)==(0);
      if ($45) {
       break;
      }
      $62 = ($$094|0)==(1);
      $63 = ($44|0)<(0);
      $64 = (($$094) - ($25))|0;
      $$195 = $63 ? $25 : $64;
      $$191 = $63 ? $$090 : $26;
      if ($62) {
       $$4 = 0;
       break L1;
      } else {
       $$090 = $$191;$$094 = $$195;
      }
     }
     $46 = (($27) + ($24))|0;
     $47 = (($0) + ($46<<2)|0);
     $48 = HEAP32[$47>>2]|0;
     $49 = (_swapc($48,$4)|0);
     $50 = (($46) + 1)|0;
     $51 = (($0) + ($50<<2)|0);
     $52 = HEAP32[$51>>2]|0;
     $53 = (_swapc($52,$4)|0);
     $54 = ($53>>>0)<($1>>>0);
     $55 = (($1) - ($53))|0;
     $56 = ($49>>>0)<($55>>>0);
     $or$cond104 = $54 & $56;
     if ($or$cond104) {
      $57 = (($0) + ($53)|0);
      $58 = (($53) + ($49))|0;
      $59 = (($0) + ($58)|0);
      $60 = HEAP8[$59>>0]|0;
      $61 = ($60<<24>>24)==(0);
      $$ = $61 ? $57 : 0;
      $$4 = $$;
     } else {
      $$4 = 0;
     }
    } else {
     $$4 = 0;
    }
   } else {
    $$4 = 0;
   }
  } else {
   $$4 = 0;
  }
 } while(0);
 return ($$4|0);
}
function _swapc($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$ = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0);
 $3 = (_llvm_bswap_i32(($0|0))|0);
 $$ = $2 ? $0 : $3;
 return ($$|0);
}
function _strcmp($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$011 = 0, $$0710 = 0, $$lcssa = 0, $$lcssa8 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $2 = HEAP8[$0>>0]|0;
 $3 = HEAP8[$1>>0]|0;
 $4 = ($2<<24>>24)!=($3<<24>>24);
 $5 = ($2<<24>>24)==(0);
 $or$cond9 = $5 | $4;
 if ($or$cond9) {
  $$lcssa = $3;$$lcssa8 = $2;
 } else {
  $$011 = $1;$$0710 = $0;
  while(1) {
   $6 = ((($$0710)) + 1|0);
   $7 = ((($$011)) + 1|0);
   $8 = HEAP8[$6>>0]|0;
   $9 = HEAP8[$7>>0]|0;
   $10 = ($8<<24>>24)!=($9<<24>>24);
   $11 = ($8<<24>>24)==(0);
   $or$cond = $11 | $10;
   if ($or$cond) {
    $$lcssa = $9;$$lcssa8 = $8;
    break;
   } else {
    $$011 = $7;$$0710 = $6;
   }
  }
 }
 $12 = $$lcssa8&255;
 $13 = $$lcssa&255;
 $14 = (($12) - ($13))|0;
 return ($14|0);
}
function ___fwritex($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$038 = 0, $$042 = 0, $$1 = 0, $$139 = 0, $$141 = 0, $$143 = 0, $$pre = 0, $$pre47 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($2)) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  $7 = (___towrite($2)|0);
  $8 = ($7|0)==(0);
  if ($8) {
   $$pre = HEAP32[$3>>2]|0;
   $12 = $$pre;
   label = 5;
  } else {
   $$1 = 0;
  }
 } else {
  $6 = $4;
  $12 = $6;
  label = 5;
 }
 L5: do {
  if ((label|0) == 5) {
   $9 = ((($2)) + 20|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (($12) - ($10))|0;
   $13 = ($11>>>0)<($1>>>0);
   $14 = $10;
   if ($13) {
    $15 = ((($2)) + 36|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = (FUNCTION_TABLE_iiii[$16 & 8191]($2,$0,$1)|0);
    $$1 = $17;
    break;
   }
   $18 = ((($2)) + 75|0);
   $19 = HEAP8[$18>>0]|0;
   $20 = ($19<<24>>24)>(-1);
   L10: do {
    if ($20) {
     $$038 = $1;
     while(1) {
      $21 = ($$038|0)==(0);
      if ($21) {
       $$139 = 0;$$141 = $0;$$143 = $1;$31 = $14;
       break L10;
      }
      $22 = (($$038) + -1)|0;
      $23 = (($0) + ($22)|0);
      $24 = HEAP8[$23>>0]|0;
      $25 = ($24<<24>>24)==(10);
      if ($25) {
       break;
      } else {
       $$038 = $22;
      }
     }
     $26 = ((($2)) + 36|0);
     $27 = HEAP32[$26>>2]|0;
     $28 = (FUNCTION_TABLE_iiii[$27 & 8191]($2,$0,$$038)|0);
     $29 = ($28>>>0)<($$038>>>0);
     if ($29) {
      $$1 = $28;
      break L5;
     }
     $30 = (($0) + ($$038)|0);
     $$042 = (($1) - ($$038))|0;
     $$pre47 = HEAP32[$9>>2]|0;
     $$139 = $$038;$$141 = $30;$$143 = $$042;$31 = $$pre47;
    } else {
     $$139 = 0;$$141 = $0;$$143 = $1;$31 = $14;
    }
   } while(0);
   _memcpy(($31|0),($$141|0),($$143|0))|0;
   $32 = HEAP32[$9>>2]|0;
   $33 = (($32) + ($$143)|0);
   HEAP32[$9>>2] = $33;
   $34 = (($$139) + ($$143))|0;
   $$1 = $34;
  }
 } while(0);
 return ($$1|0);
}
function ___towrite($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 74|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = $2 << 24 >> 24;
 $4 = (($3) + 255)|0;
 $5 = $4 | $3;
 $6 = $5&255;
 HEAP8[$1>>0] = $6;
 $7 = HEAP32[$0>>2]|0;
 $8 = $7 & 8;
 $9 = ($8|0)==(0);
 if ($9) {
  $11 = ((($0)) + 8|0);
  HEAP32[$11>>2] = 0;
  $12 = ((($0)) + 4|0);
  HEAP32[$12>>2] = 0;
  $13 = ((($0)) + 44|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = ((($0)) + 28|0);
  HEAP32[$15>>2] = $14;
  $16 = ((($0)) + 20|0);
  HEAP32[$16>>2] = $14;
  $17 = ((($0)) + 48|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (($14) + ($18)|0);
  $20 = ((($0)) + 16|0);
  HEAP32[$20>>2] = $19;
  $$0 = 0;
 } else {
  $10 = $7 | 32;
  HEAP32[$0>>2] = $10;
  $$0 = -1;
 }
 return ($$0|0);
}
function _sn_write($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$ = 0, $10 = 0, $11 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $6;
 $8 = (($4) - ($7))|0;
 $9 = ($8>>>0)>($2>>>0);
 $$ = $9 ? $2 : $8;
 _memcpy(($6|0),($1|0),($$|0))|0;
 $10 = HEAP32[$5>>2]|0;
 $11 = (($10) + ($$)|0);
 HEAP32[$5>>2] = $11;
 return ($2|0);
}
function _strtof($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0.0, $3 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (+_strtox_13($0,$1,0));
 $3 = $2;
 return (+$3);
}
function _strtold($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (+_strtox_13($0,$1,2));
 return (+$2);
}
function _strtof_l($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (+_strtof($0,$1));
 return (+$3);
}
function _strtod_l($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (+_strtod($0,$1));
 return (+$3);
}
function _strtold_l($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (+_strtold($0,$1));
 return (+$3);
}
function _srand($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (($0) + -1)|0;
 $2 = 207024;
 $3 = $2;
 HEAP32[$3>>2] = $1;
 $4 = (($2) + 4)|0;
 $5 = $4;
 HEAP32[$5>>2] = 0;
 return;
}
function _rand() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = 207024;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (___muldi3(($2|0),($5|0),1284865837,1481765933)|0);
 $7 = tempRet0;
 $8 = (_i64Add(($6|0),($7|0),1,0)|0);
 $9 = tempRet0;
 $10 = 207024;
 $11 = $10;
 HEAP32[$11>>2] = $8;
 $12 = (($10) + 4)|0;
 $13 = $12;
 HEAP32[$13>>2] = $9;
 $14 = (_bitshift64Lshr(($8|0),($9|0),33)|0);
 $15 = tempRet0;
 return ($14|0);
}
function ___procfdname($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$02324 = 0, $$027 = 0, $$126 = 0, $$225 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep = 0, dest = 0, label = 0;
 var sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 dest=$0; src=201733; stop=dest+15|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $2 = ($1|0)==(0);
 if ($2) {
  $scevgep = ((($0)) + 14|0);
  HEAP8[$scevgep>>0] = 48;
  $3 = ((($0)) + 15|0);
  HEAP8[$3>>0] = 0;
 } else {
  $$027 = $1;$$126 = 14;
  while(1) {
   $4 = (($$027>>>0) / 10)&-1;
   $5 = (($$126) + 1)|0;
   $6 = ($$027>>>0)<(10);
   if ($6) {
    break;
   } else {
    $$027 = $4;$$126 = $5;
   }
  }
  $7 = (($0) + ($5)|0);
  HEAP8[$7>>0] = 0;
  $$02324 = $1;$$225 = $5;
  while(1) {
   $8 = (($$02324>>>0) % 10)&-1;
   $9 = $8 | 48;
   $10 = $9&255;
   $11 = (($$225) + -1)|0;
   $12 = (($0) + ($11)|0);
   HEAP8[$12>>0] = $10;
   $13 = (($$02324>>>0) / 10)&-1;
   $14 = ($$02324>>>0)<(10);
   if ($14) {
    break;
   } else {
    $$02324 = $13;$$225 = $11;
   }
  }
 }
 return;
}
function _readlink($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $3 = $0;
 $4 = $1;
 HEAP32[$vararg_buffer>>2] = $3;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $4;
 $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $2;
 $5 = (___syscall85(85,($vararg_buffer|0))|0);
 $6 = (___syscall_ret($5)|0);
 STACKTOP = sp;return ($6|0);
}
function ___strdup($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (_strlen($0)|0);
 $2 = (($1) + 1)|0;
 $3 = (_malloc($2)|0);
 $4 = ($3|0)==(0|0);
 if ($4) {
  $$0 = 0;
 } else {
  _memcpy(($3|0),($0|0),($2|0))|0;
  $$0 = $3;
 }
 return ($$0|0);
}
function _strcpy($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (___stpcpy($0,$1)|0);
 return ($0|0);
}
function ___stpcpy($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$lcssa = 0, $$025$lcssa = 0, $$02536 = 0, $$026$lcssa = 0, $$02642 = 0, $$027$lcssa = 0, $$02741 = 0, $$029 = 0, $$037 = 0, $$1$ph = 0, $$128$ph = 0, $$12834 = 0, $$135 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = $1;
 $3 = $0;
 $4 = $2 ^ $3;
 $5 = $4 & 3;
 $6 = ($5|0)==(0);
 L1: do {
  if ($6) {
   $7 = $2 & 3;
   $8 = ($7|0)==(0);
   if ($8) {
    $$026$lcssa = $1;$$027$lcssa = $0;
   } else {
    $$02642 = $1;$$02741 = $0;
    while(1) {
     $9 = HEAP8[$$02642>>0]|0;
     HEAP8[$$02741>>0] = $9;
     $10 = ($9<<24>>24)==(0);
     if ($10) {
      $$029 = $$02741;
      break L1;
     }
     $11 = ((($$02642)) + 1|0);
     $12 = ((($$02741)) + 1|0);
     $13 = $11;
     $14 = $13 & 3;
     $15 = ($14|0)==(0);
     if ($15) {
      $$026$lcssa = $11;$$027$lcssa = $12;
      break;
     } else {
      $$02642 = $11;$$02741 = $12;
     }
    }
   }
   $16 = HEAP32[$$026$lcssa>>2]|0;
   $17 = (($16) + -16843009)|0;
   $18 = $16 & -2139062144;
   $19 = $18 ^ -2139062144;
   $20 = $19 & $17;
   $21 = ($20|0)==(0);
   if ($21) {
    $$02536 = $$027$lcssa;$$037 = $$026$lcssa;$24 = $16;
    while(1) {
     $22 = ((($$037)) + 4|0);
     $23 = ((($$02536)) + 4|0);
     HEAP32[$$02536>>2] = $24;
     $25 = HEAP32[$22>>2]|0;
     $26 = (($25) + -16843009)|0;
     $27 = $25 & -2139062144;
     $28 = $27 ^ -2139062144;
     $29 = $28 & $26;
     $30 = ($29|0)==(0);
     if ($30) {
      $$02536 = $23;$$037 = $22;$24 = $25;
     } else {
      $$0$lcssa = $22;$$025$lcssa = $23;
      break;
     }
    }
   } else {
    $$0$lcssa = $$026$lcssa;$$025$lcssa = $$027$lcssa;
   }
   $$1$ph = $$0$lcssa;$$128$ph = $$025$lcssa;
   label = 8;
  } else {
   $$1$ph = $1;$$128$ph = $0;
   label = 8;
  }
 } while(0);
 if ((label|0) == 8) {
  $31 = HEAP8[$$1$ph>>0]|0;
  HEAP8[$$128$ph>>0] = $31;
  $32 = ($31<<24>>24)==(0);
  if ($32) {
   $$029 = $$128$ph;
  } else {
   $$12834 = $$128$ph;$$135 = $$1$ph;
   while(1) {
    $33 = ((($$135)) + 1|0);
    $34 = ((($$12834)) + 1|0);
    $35 = HEAP8[$33>>0]|0;
    HEAP8[$34>>0] = $35;
    $36 = ($35<<24>>24)==(0);
    if ($36) {
     $$029 = $34;
     break;
    } else {
     $$12834 = $34;$$135 = $33;
    }
   }
  }
 }
 return ($$029|0);
}
function _close($0) {
 $0 = $0|0;
 var $$ = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $1 = (_dummy($0)|0);
 HEAP32[$vararg_buffer>>2] = $1;
 $2 = (___syscall6(6,($vararg_buffer|0))|0);
 $3 = ($2|0)==(-4);
 $$ = $3 ? 0 : $2;
 $4 = (___syscall_ret($$)|0);
 STACKTOP = sp;return ($4|0);
}
function _access($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $2 = $0;
 HEAP32[$vararg_buffer>>2] = $2;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $1;
 $3 = (___syscall33(33,($vararg_buffer|0))|0);
 $4 = (___syscall_ret($3)|0);
 STACKTOP = sp;return ($4|0);
}
function _wmemcpy($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$058 = 0, $$067 = 0, $$09 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($2|0)==(0);
 if (!($3)) {
  $$058 = $2;$$067 = $1;$$09 = $0;
  while(1) {
   $4 = (($$058) + -1)|0;
   $5 = ((($$067)) + 4|0);
   $6 = HEAP32[$$067>>2]|0;
   $7 = ((($$09)) + 4|0);
   HEAP32[$$09>>2] = $6;
   $8 = ($4|0)==(0);
   if ($8) {
    break;
   } else {
    $$058 = $4;$$067 = $5;$$09 = $7;
   }
  }
 }
 return ($0|0);
}
function _memcmp($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$01318 = 0, $$01417 = 0, $$019 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($2|0)==(0);
 L1: do {
  if ($3) {
   $14 = 0;
  } else {
   $$01318 = $0;$$01417 = $2;$$019 = $1;
   while(1) {
    $4 = HEAP8[$$01318>>0]|0;
    $5 = HEAP8[$$019>>0]|0;
    $6 = ($4<<24>>24)==($5<<24>>24);
    if (!($6)) {
     break;
    }
    $7 = (($$01417) + -1)|0;
    $8 = ((($$01318)) + 1|0);
    $9 = ((($$019)) + 1|0);
    $10 = ($7|0)==(0);
    if ($10) {
     $14 = 0;
     break L1;
    } else {
     $$01318 = $8;$$01417 = $7;$$019 = $9;
    }
   }
   $11 = $4&255;
   $12 = $5&255;
   $13 = (($11) - ($12))|0;
   $14 = $13;
  }
 } while(0);
 return ($14|0);
}
function _strncasecmp($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$lcssa = 0, $$02125 = 0, $$02227 = 0, $$02227$in = 0, $$023 = 0, $$026 = 0, $$lcssa = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($2|0)==(0);
 if ($3) {
  $$023 = 0;
 } else {
  $4 = HEAP8[$0>>0]|0;
  $5 = $4&255;
  $6 = ($4<<24>>24)==(0);
  L3: do {
   if ($6) {
    $$0$lcssa = $1;$$lcssa = $5;
   } else {
    $$02125 = $0;$$02227$in = $2;$$026 = $1;$11 = $4;$13 = $5;
    while(1) {
     $$02227 = (($$02227$in) + -1)|0;
     $7 = HEAP8[$$026>>0]|0;
     $8 = $7&255;
     $9 = ($7<<24>>24)!=(0);
     $10 = ($$02227|0)!=(0);
     $or$cond = $10 & $9;
     if (!($or$cond)) {
      $$0$lcssa = $$026;$$lcssa = $13;
      break L3;
     }
     $12 = ($11<<24>>24)==($7<<24>>24);
     if (!($12)) {
      $14 = (_tolower($13)|0);
      $15 = (_tolower($8)|0);
      $16 = ($14|0)==($15|0);
      if (!($16)) {
       $$0$lcssa = $$026;$$lcssa = $13;
       break L3;
      }
     }
     $17 = ((($$02125)) + 1|0);
     $18 = ((($$026)) + 1|0);
     $19 = HEAP8[$17>>0]|0;
     $20 = $19&255;
     $21 = ($19<<24>>24)==(0);
     if ($21) {
      $$0$lcssa = $18;$$lcssa = $20;
      break;
     } else {
      $$02125 = $17;$$02227$in = $$02227;$$026 = $18;$11 = $19;$13 = $20;
     }
    }
   }
  } while(0);
  $22 = (_tolower($$lcssa)|0);
  $23 = HEAP8[$$0$lcssa>>0]|0;
  $24 = $23&255;
  $25 = (_tolower($24)|0);
  $26 = (($22) - ($25))|0;
  $$023 = $26;
 }
 return ($$023|0);
}
function _tolower($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (_isupper($0)|0);
 $2 = ($1|0)==(0);
 $3 = $0 | 32;
 $$0 = $2 ? $0 : $3;
 return ($$0|0);
}
function _isupper($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (($0) + -65)|0;
 $2 = ($1>>>0)<(26);
 $3 = $2&1;
 return ($3|0);
}
function _strncmp($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$01824 = 0, $$01926 = 0, $$01926$in = 0, $$020 = 0, $$025 = 0, $$lcssa = 0, $$lcssa22 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond21 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($2|0)==(0);
 if ($3) {
  $$020 = 0;
 } else {
  $4 = HEAP8[$0>>0]|0;
  $5 = $4&255;
  $6 = ($4<<24>>24)==(0);
  $7 = HEAP8[$1>>0]|0;
  $8 = $7&255;
  L3: do {
   if ($6) {
    $$lcssa = $8;$$lcssa22 = $5;
   } else {
    $$01824 = $0;$$01926$in = $2;$$025 = $1;$12 = $4;$22 = $8;$23 = $5;$9 = $7;
    while(1) {
     $$01926 = (($$01926$in) + -1)|0;
     $10 = ($9<<24>>24)!=(0);
     $11 = ($$01926|0)!=(0);
     $or$cond = $11 & $10;
     $13 = ($12<<24>>24)==($9<<24>>24);
     $or$cond21 = $13 & $or$cond;
     if (!($or$cond21)) {
      $$lcssa = $22;$$lcssa22 = $23;
      break L3;
     }
     $14 = ((($$01824)) + 1|0);
     $15 = ((($$025)) + 1|0);
     $16 = HEAP8[$14>>0]|0;
     $17 = $16&255;
     $18 = ($16<<24>>24)==(0);
     $19 = HEAP8[$15>>0]|0;
     $20 = $19&255;
     if ($18) {
      $$lcssa = $20;$$lcssa22 = $17;
      break;
     } else {
      $$01824 = $14;$$01926$in = $$01926;$$025 = $15;$12 = $16;$22 = $20;$23 = $17;$9 = $19;
     }
    }
   }
  } while(0);
  $21 = (($$lcssa22) - ($$lcssa))|0;
  $$020 = $21;
 }
 return ($$020|0);
}
function _wmemset($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$056 = 0, $$07 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($2|0)==(0);
 if (!($3)) {
  $$056 = $2;$$07 = $0;
  while(1) {
   $4 = (($$056) + -1)|0;
   $5 = ((($$07)) + 4|0);
   HEAP32[$$07>>2] = $1;
   $6 = ($4|0)==(0);
   if ($6) {
    break;
   } else {
    $$056 = $4;$$07 = $5;
   }
  }
 }
 return ($0|0);
}
function _strchr($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (___strchrnul($0,$1)|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = $1&255;
 $5 = ($3<<24>>24)==($4<<24>>24);
 $6 = $5 ? $2 : 0;
 return ($6|0);
}
function _strstr($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 do {
  if ($3) {
   $$0 = $0;
  } else {
   $4 = $2 << 24 >> 24;
   $5 = (_strchr($0,$4)|0);
   $6 = ($5|0)==(0|0);
   if ($6) {
    $$0 = 0;
   } else {
    $7 = ((($1)) + 1|0);
    $8 = HEAP8[$7>>0]|0;
    $9 = ($8<<24>>24)==(0);
    if ($9) {
     $$0 = $5;
    } else {
     $10 = ((($5)) + 1|0);
     $11 = HEAP8[$10>>0]|0;
     $12 = ($11<<24>>24)==(0);
     if ($12) {
      $$0 = 0;
     } else {
      $13 = ((($1)) + 2|0);
      $14 = HEAP8[$13>>0]|0;
      $15 = ($14<<24>>24)==(0);
      if ($15) {
       $16 = (_twobyte_strstr($5,$1)|0);
       $$0 = $16;
       break;
      }
      $17 = ((($5)) + 2|0);
      $18 = HEAP8[$17>>0]|0;
      $19 = ($18<<24>>24)==(0);
      if ($19) {
       $$0 = 0;
      } else {
       $20 = ((($1)) + 3|0);
       $21 = HEAP8[$20>>0]|0;
       $22 = ($21<<24>>24)==(0);
       if ($22) {
        $23 = (_threebyte_strstr($5,$1)|0);
        $$0 = $23;
        break;
       }
       $24 = ((($5)) + 3|0);
       $25 = HEAP8[$24>>0]|0;
       $26 = ($25<<24>>24)==(0);
       if ($26) {
        $$0 = 0;
       } else {
        $27 = ((($1)) + 4|0);
        $28 = HEAP8[$27>>0]|0;
        $29 = ($28<<24>>24)==(0);
        if ($29) {
         $30 = (_fourbyte_strstr($5,$1)|0);
         $$0 = $30;
         break;
        } else {
         $31 = (_twoway_strstr($5,$1)|0);
         $$0 = $31;
         break;
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 return ($$0|0);
}
function _twobyte_strstr($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$lcssa = 0, $$sink = 0, $$sink$in = 0, $$sink$masked = 0, $$sink17$sink = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP8[$1>>0]|0;
 $3 = $2&255;
 $4 = $3 << 8;
 $5 = ((($1)) + 1|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = $6&255;
 $8 = $4 | $7;
 $9 = HEAP8[$0>>0]|0;
 $10 = $9&255;
 $$sink$in = $10;$$sink17$sink = $0;
 while(1) {
  $11 = ((($$sink17$sink)) + 1|0);
  $12 = HEAP8[$11>>0]|0;
  $13 = ($12<<24>>24)==(0);
  if ($13) {
   $$lcssa = 0;
   break;
  }
  $$sink = $$sink$in << 8;
  $14 = $12&255;
  $$sink$masked = $$sink & 65280;
  $15 = $14 | $$sink$masked;
  $16 = ($15|0)==($8|0);
  if ($16) {
   $$lcssa = $$sink17$sink;
   break;
  } else {
   $$sink$in = $15;$$sink17$sink = $11;
  }
 }
 return ($$lcssa|0);
}
function _threebyte_strstr($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$016$lcssa = 0, $$01619 = 0, $$020 = 0, $$lcssa = 0, $$not = 0, $$not17 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond18 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP8[$1>>0]|0;
 $3 = $2&255;
 $4 = $3 << 24;
 $5 = ((($1)) + 1|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = $6&255;
 $8 = $7 << 16;
 $9 = $8 | $4;
 $10 = ((($1)) + 2|0);
 $11 = HEAP8[$10>>0]|0;
 $12 = $11&255;
 $13 = $12 << 8;
 $14 = $9 | $13;
 $15 = HEAP8[$0>>0]|0;
 $16 = $15&255;
 $17 = $16 << 24;
 $18 = ((($0)) + 1|0);
 $19 = HEAP8[$18>>0]|0;
 $20 = $19&255;
 $21 = $20 << 16;
 $22 = $21 | $17;
 $23 = ((($0)) + 2|0);
 $24 = HEAP8[$23>>0]|0;
 $25 = $24&255;
 $26 = $25 << 8;
 $27 = $22 | $26;
 $28 = ($24<<24>>24)!=(0);
 $$not17 = $28 ^ 1;
 $29 = ($27|0)==($14|0);
 $or$cond18 = $29 | $$not17;
 if ($or$cond18) {
  $$016$lcssa = $23;$$lcssa = $28;
 } else {
  $$01619 = $23;$$020 = $27;
  while(1) {
   $30 = ((($$01619)) + 1|0);
   $31 = HEAP8[$30>>0]|0;
   $32 = $31&255;
   $33 = $32 | $$020;
   $34 = $33 << 8;
   $35 = ($31<<24>>24)!=(0);
   $$not = $35 ^ 1;
   $36 = ($34|0)==($14|0);
   $or$cond = $36 | $$not;
   if ($or$cond) {
    $$016$lcssa = $30;$$lcssa = $35;
    break;
   } else {
    $$01619 = $30;$$020 = $34;
   }
  }
 }
 $37 = ((($$016$lcssa)) + -2|0);
 $38 = $$lcssa ? $37 : 0;
 return ($38|0);
}
function _fourbyte_strstr($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$lcssa = 0, $$not = 0, $$not22 = 0, $$sink21$lcssa = 0, $$sink2124 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond23 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP8[$1>>0]|0;
 $3 = $2&255;
 $4 = $3 << 24;
 $5 = ((($1)) + 1|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = $6&255;
 $8 = $7 << 16;
 $9 = $8 | $4;
 $10 = ((($1)) + 2|0);
 $11 = HEAP8[$10>>0]|0;
 $12 = $11&255;
 $13 = $12 << 8;
 $14 = $9 | $13;
 $15 = ((($1)) + 3|0);
 $16 = HEAP8[$15>>0]|0;
 $17 = $16&255;
 $18 = $14 | $17;
 $19 = HEAP8[$0>>0]|0;
 $20 = $19&255;
 $21 = $20 << 24;
 $22 = ((($0)) + 1|0);
 $23 = HEAP8[$22>>0]|0;
 $24 = $23&255;
 $25 = $24 << 16;
 $26 = $25 | $21;
 $27 = ((($0)) + 2|0);
 $28 = HEAP8[$27>>0]|0;
 $29 = $28&255;
 $30 = $29 << 8;
 $31 = $26 | $30;
 $32 = ((($0)) + 3|0);
 $33 = HEAP8[$32>>0]|0;
 $34 = $33&255;
 $35 = $34 | $31;
 $36 = ($33<<24>>24)!=(0);
 $$not22 = $36 ^ 1;
 $37 = ($35|0)==($18|0);
 $or$cond23 = $37 | $$not22;
 if ($or$cond23) {
  $$lcssa = $36;$$sink21$lcssa = $32;
 } else {
  $$sink2124 = $32;$39 = $35;
  while(1) {
   $38 = $39 << 8;
   $40 = ((($$sink2124)) + 1|0);
   $41 = HEAP8[$40>>0]|0;
   $42 = $41&255;
   $43 = $42 | $38;
   $44 = ($41<<24>>24)!=(0);
   $$not = $44 ^ 1;
   $45 = ($43|0)==($18|0);
   $or$cond = $45 | $$not;
   if ($or$cond) {
    $$lcssa = $44;$$sink21$lcssa = $40;
    break;
   } else {
    $$sink2124 = $40;$39 = $43;
   }
  }
 }
 $46 = ((($$sink21$lcssa)) + -3|0);
 $47 = $$lcssa ? $46 : 0;
 return ($47|0);
}
function _twoway_strstr($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0166 = 0, $$0168 = 0, $$0169 = 0, $$0169$be = 0, $$0170 = 0, $$0175$ph$ph$lcssa220 = 0, $$0175$ph$ph$lcssa220323 = 0, $$0175$ph$ph256 = 0, $$0179244 = 0, $$0183$ph200$ph255 = 0, $$0183$ph200250 = 0, $$0183$ph262 = 0, $$0185$ph$lcssa = 0, $$0185$ph$lcssa322 = 0, $$0185$ph261 = 0, $$0187$lcssa320321 = 0, $$0187266 = 0, $$1176$$0175 = 0, $$1176$ph$ph$lcssa211 = 0, $$1176$ph$ph235 = 0;
 var $$1180224 = 0, $$1184$ph196$ph234 = 0, $$1184$ph196229 = 0, $$1184$ph241 = 0, $$1186$$0185 = 0, $$1186$$0185$ = 0, $$1186$ph$lcssa = 0, $$1186$ph240 = 0, $$2181 = 0, $$2181$sink = 0, $$3 = 0, $$3173 = 0, $$3178 = 0, $$3182223 = 0, $$4 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0;
 var $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0;
 var $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $cond = 0, $cond191 = 0, $cond191222 = 0, $cond265 = 0, $div = 0, $div188 = 0, $or$cond = 0, $or$cond190 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1056|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(1056|0);
 $2 = sp + 1024|0;
 $3 = sp;
 ;HEAP32[$2>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;HEAP32[$2+12>>2]=0|0;HEAP32[$2+16>>2]=0|0;HEAP32[$2+20>>2]=0|0;HEAP32[$2+24>>2]=0|0;HEAP32[$2+28>>2]=0|0;
 $4 = HEAP8[$1>>0]|0;
 $cond265 = ($4<<24>>24)==(0);
 L1: do {
  if ($cond265) {
   $$0175$ph$ph$lcssa220323 = 1;$$0185$ph$lcssa322 = -1;$$0187$lcssa320321 = 0;$$1176$ph$ph$lcssa211 = 1;$$1186$ph$lcssa = -1;
   label = 27;
  } else {
   $5 = $4&255;
   $$0187266 = 0;$12 = $4;$20 = $5;
   while(1) {
    $8 = (($0) + ($$0187266)|0);
    $9 = HEAP8[$8>>0]|0;
    $10 = ($9<<24>>24)==(0);
    if ($10) {
     $$3 = 0;
     break L1;
    }
    $11 = $12 & 31;
    $13 = $11&255;
    $14 = 1 << $13;
    $div188 = ($12&255) >>> 5;
    $15 = $div188&255;
    $16 = (($2) + ($15<<2)|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = $17 | $14;
    HEAP32[$16>>2] = $18;
    $6 = (($$0187266) + 1)|0;
    $19 = (($3) + ($20<<2)|0);
    HEAP32[$19>>2] = $6;
    $21 = (($1) + ($6)|0);
    $22 = HEAP8[$21>>0]|0;
    $23 = $22&255;
    $cond = ($22<<24>>24)==(0);
    if ($cond) {
     break;
    } else {
     $$0187266 = $6;$12 = $22;$20 = $23;
    }
   }
   $7 = ($6>>>0)>(1);
   if ($7) {
    $$0183$ph262 = 0;$$0185$ph261 = -1;$129 = 1;
    L7: while(1) {
     $$0175$ph$ph256 = 1;$$0183$ph200$ph255 = $$0183$ph262;$132 = $129;
     while(1) {
      $$0183$ph200250 = $$0183$ph200$ph255;$131 = $132;
      L11: while(1) {
       $$0179244 = 1;$31 = $131;
       while(1) {
        $27 = (($$0179244) + ($$0185$ph261))|0;
        $28 = (($1) + ($27)|0);
        $29 = HEAP8[$28>>0]|0;
        $30 = (($1) + ($31)|0);
        $32 = HEAP8[$30>>0]|0;
        $33 = ($29<<24>>24)==($32<<24>>24);
        if (!($33)) {
         break L11;
        }
        $34 = ($$0179244|0)==($$0175$ph$ph256|0);
        $25 = (($$0179244) + 1)|0;
        if ($34) {
         break;
        }
        $24 = (($25) + ($$0183$ph200250))|0;
        $26 = ($24>>>0)<($6>>>0);
        if ($26) {
         $$0179244 = $25;$31 = $24;
        } else {
         $$0175$ph$ph$lcssa220 = $$0175$ph$ph256;$$0185$ph$lcssa = $$0185$ph261;
         break L7;
        }
       }
       $35 = (($$0175$ph$ph256) + ($$0183$ph200250))|0;
       $36 = (($35) + 1)|0;
       $37 = ($36>>>0)<($6>>>0);
       if ($37) {
        $$0183$ph200250 = $35;$131 = $36;
       } else {
        $$0175$ph$ph$lcssa220 = $$0175$ph$ph256;$$0185$ph$lcssa = $$0185$ph261;
        break L7;
       }
      }
      $38 = ($29&255)>($32&255);
      $39 = (($31) - ($$0185$ph261))|0;
      if (!($38)) {
       break;
      }
      $43 = (($31) + 1)|0;
      $44 = ($43>>>0)<($6>>>0);
      if ($44) {
       $$0175$ph$ph256 = $39;$$0183$ph200$ph255 = $31;$132 = $43;
      } else {
       $$0175$ph$ph$lcssa220 = $39;$$0185$ph$lcssa = $$0185$ph261;
       break L7;
      }
     }
     $40 = (($$0183$ph200250) + 1)|0;
     $41 = (($$0183$ph200250) + 2)|0;
     $42 = ($41>>>0)<($6>>>0);
     if ($42) {
      $$0183$ph262 = $40;$$0185$ph261 = $$0183$ph200250;$129 = $41;
     } else {
      $$0175$ph$ph$lcssa220 = 1;$$0185$ph$lcssa = $$0183$ph200250;
      break;
     }
    }
    if ($7) {
     $$1184$ph241 = 0;$$1186$ph240 = -1;$130 = 1;
     while(1) {
      $$1176$ph$ph235 = 1;$$1184$ph196$ph234 = $$1184$ph241;$134 = $130;
      while(1) {
       $$1184$ph196229 = $$1184$ph196$ph234;$133 = $134;
       L26: while(1) {
        $$1180224 = 1;$52 = $133;
        while(1) {
         $48 = (($$1180224) + ($$1186$ph240))|0;
         $49 = (($1) + ($48)|0);
         $50 = HEAP8[$49>>0]|0;
         $51 = (($1) + ($52)|0);
         $53 = HEAP8[$51>>0]|0;
         $54 = ($50<<24>>24)==($53<<24>>24);
         if (!($54)) {
          break L26;
         }
         $55 = ($$1180224|0)==($$1176$ph$ph235|0);
         $46 = (($$1180224) + 1)|0;
         if ($55) {
          break;
         }
         $45 = (($46) + ($$1184$ph196229))|0;
         $47 = ($45>>>0)<($6>>>0);
         if ($47) {
          $$1180224 = $46;$52 = $45;
         } else {
          $$0175$ph$ph$lcssa220323 = $$0175$ph$ph$lcssa220;$$0185$ph$lcssa322 = $$0185$ph$lcssa;$$0187$lcssa320321 = $6;$$1176$ph$ph$lcssa211 = $$1176$ph$ph235;$$1186$ph$lcssa = $$1186$ph240;
          label = 27;
          break L1;
         }
        }
        $56 = (($$1176$ph$ph235) + ($$1184$ph196229))|0;
        $57 = (($56) + 1)|0;
        $58 = ($57>>>0)<($6>>>0);
        if ($58) {
         $$1184$ph196229 = $56;$133 = $57;
        } else {
         $$0175$ph$ph$lcssa220323 = $$0175$ph$ph$lcssa220;$$0185$ph$lcssa322 = $$0185$ph$lcssa;$$0187$lcssa320321 = $6;$$1176$ph$ph$lcssa211 = $$1176$ph$ph235;$$1186$ph$lcssa = $$1186$ph240;
         label = 27;
         break L1;
        }
       }
       $59 = ($50&255)<($53&255);
       $60 = (($52) - ($$1186$ph240))|0;
       if (!($59)) {
        break;
       }
       $64 = (($52) + 1)|0;
       $65 = ($64>>>0)<($6>>>0);
       if ($65) {
        $$1176$ph$ph235 = $60;$$1184$ph196$ph234 = $52;$134 = $64;
       } else {
        $$0175$ph$ph$lcssa220323 = $$0175$ph$ph$lcssa220;$$0185$ph$lcssa322 = $$0185$ph$lcssa;$$0187$lcssa320321 = $6;$$1176$ph$ph$lcssa211 = $60;$$1186$ph$lcssa = $$1186$ph240;
        label = 27;
        break L1;
       }
      }
      $61 = (($$1184$ph196229) + 1)|0;
      $62 = (($$1184$ph196229) + 2)|0;
      $63 = ($62>>>0)<($6>>>0);
      if ($63) {
       $$1184$ph241 = $61;$$1186$ph240 = $$1184$ph196229;$130 = $62;
      } else {
       $$0175$ph$ph$lcssa220323 = $$0175$ph$ph$lcssa220;$$0185$ph$lcssa322 = $$0185$ph$lcssa;$$0187$lcssa320321 = $6;$$1176$ph$ph$lcssa211 = 1;$$1186$ph$lcssa = $$1184$ph196229;
       label = 27;
       break;
      }
     }
    } else {
     $$0175$ph$ph$lcssa220323 = $$0175$ph$ph$lcssa220;$$0185$ph$lcssa322 = $$0185$ph$lcssa;$$0187$lcssa320321 = $6;$$1176$ph$ph$lcssa211 = 1;$$1186$ph$lcssa = -1;
     label = 27;
    }
   } else {
    $$0175$ph$ph$lcssa220323 = 1;$$0185$ph$lcssa322 = -1;$$0187$lcssa320321 = $6;$$1176$ph$ph$lcssa211 = 1;$$1186$ph$lcssa = -1;
    label = 27;
   }
  }
 } while(0);
 L36: do {
  if ((label|0) == 27) {
   $66 = (($$1186$ph$lcssa) + 1)|0;
   $67 = (($$0185$ph$lcssa322) + 1)|0;
   $68 = ($66>>>0)>($67>>>0);
   $$1176$$0175 = $68 ? $$1176$ph$ph$lcssa211 : $$0175$ph$ph$lcssa220323;
   $$1186$$0185 = $68 ? $$1186$ph$lcssa : $$0185$ph$lcssa322;
   $69 = (($1) + ($$1176$$0175)|0);
   $70 = (($$1186$$0185) + 1)|0;
   $71 = (_memcmp($1,$69,$70)|0);
   $72 = ($71|0)==(0);
   if ($72) {
    $77 = (($$0187$lcssa320321) - ($$1176$$0175))|0;
    $$0168 = $77;$$3178 = $$1176$$0175;
   } else {
    $73 = (($$0187$lcssa320321) - ($$1186$$0185))|0;
    $74 = (($73) + -1)|0;
    $75 = ($$1186$$0185>>>0)>($74>>>0);
    $$1186$$0185$ = $75 ? $$1186$$0185 : $74;
    $76 = (($$1186$$0185$) + 1)|0;
    $$0168 = 0;$$3178 = $76;
   }
   $78 = $$0187$lcssa320321 | 63;
   $79 = (($$0187$lcssa320321) + -1)|0;
   $80 = ($$0168|0)!=(0);
   $81 = (($$0187$lcssa320321) - ($$3178))|0;
   $$0166 = $0;$$0169 = 0;$$0170 = $0;
   while(1) {
    $82 = $$0170;
    $83 = $$0166;
    $84 = (($82) - ($83))|0;
    $85 = ($84>>>0)<($$0187$lcssa320321>>>0);
    do {
     if ($85) {
      $86 = (_memchr($$0170,0,$78)|0);
      $87 = ($86|0)==(0|0);
      if ($87) {
       $91 = (($$0170) + ($78)|0);
       $$3173 = $91;
       break;
      } else {
       $88 = $86;
       $89 = (($88) - ($83))|0;
       $90 = ($89>>>0)<($$0187$lcssa320321>>>0);
       if ($90) {
        $$3 = 0;
        break L36;
       } else {
        $$3173 = $86;
        break;
       }
      }
     } else {
      $$3173 = $$0170;
     }
    } while(0);
    $92 = (($$0166) + ($79)|0);
    $93 = HEAP8[$92>>0]|0;
    $div = ($93&255) >>> 5;
    $94 = $div&255;
    $95 = (($2) + ($94<<2)|0);
    $96 = HEAP32[$95>>2]|0;
    $97 = $93 & 31;
    $98 = $97&255;
    $99 = 1 << $98;
    $100 = $99 & $96;
    $101 = ($100|0)==(0);
    L50: do {
     if ($101) {
      $$0169$be = 0;$$2181$sink = $$0187$lcssa320321;
     } else {
      $102 = $93&255;
      $103 = (($3) + ($102<<2)|0);
      $104 = HEAP32[$103>>2]|0;
      $105 = (($$0187$lcssa320321) - ($104))|0;
      $106 = ($105|0)==(0);
      if (!($106)) {
       $107 = ($$0169|0)!=(0);
       $or$cond = $80 & $107;
       $108 = ($105>>>0)<($$3178>>>0);
       $or$cond190 = $or$cond & $108;
       $$2181 = $or$cond190 ? $81 : $105;
       $$0169$be = 0;$$2181$sink = $$2181;
       break;
      }
      $110 = ($70>>>0)>($$0169>>>0);
      $111 = $110 ? $70 : $$0169;
      $112 = (($1) + ($111)|0);
      $113 = HEAP8[$112>>0]|0;
      $cond191222 = ($113<<24>>24)==(0);
      L55: do {
       if ($cond191222) {
        $$4 = $70;
       } else {
        $$3182223 = $111;$116 = $113;
        while(1) {
         $114 = (($$0166) + ($$3182223)|0);
         $115 = HEAP8[$114>>0]|0;
         $117 = ($116<<24>>24)==($115<<24>>24);
         if (!($117)) {
          break;
         }
         $118 = (($$3182223) + 1)|0;
         $119 = (($1) + ($118)|0);
         $120 = HEAP8[$119>>0]|0;
         $cond191 = ($120<<24>>24)==(0);
         if ($cond191) {
          $$4 = $70;
          break L55;
         } else {
          $$3182223 = $118;$116 = $120;
         }
        }
        $121 = (($$3182223) - ($$1186$$0185))|0;
        $$0169$be = 0;$$2181$sink = $121;
        break L50;
       }
      } while(0);
      while(1) {
       $122 = ($$4>>>0)>($$0169>>>0);
       if (!($122)) {
        $$3 = $$0166;
        break L36;
       }
       $123 = (($$4) + -1)|0;
       $124 = (($1) + ($123)|0);
       $125 = HEAP8[$124>>0]|0;
       $126 = (($$0166) + ($123)|0);
       $127 = HEAP8[$126>>0]|0;
       $128 = ($125<<24>>24)==($127<<24>>24);
       if ($128) {
        $$4 = $123;
       } else {
        $$0169$be = $$0168;$$2181$sink = $$3178;
        break;
       }
      }
     }
    } while(0);
    $109 = (($$0166) + ($$2181$sink)|0);
    $$0166 = $109;$$0169 = $$0169$be;$$0170 = $$3173;
   }
  }
 } while(0);
 STACKTOP = sp;return ($$3|0);
}
function _strcasecmp($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$lcssa = 0, $$01718 = 0, $$019 = 0, $$lcssa = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP8[$0>>0]|0;
 $3 = $2&255;
 $4 = ($2<<24>>24)==(0);
 L1: do {
  if ($4) {
   $$0$lcssa = $1;$$lcssa = $3;
  } else {
   $$01718 = $0;$$019 = $1;$10 = $3;$8 = $2;
   while(1) {
    $5 = HEAP8[$$019>>0]|0;
    $6 = $5&255;
    $7 = ($5<<24>>24)==(0);
    if ($7) {
     $$0$lcssa = $$019;$$lcssa = $10;
     break L1;
    }
    $9 = ($8<<24>>24)==($5<<24>>24);
    if (!($9)) {
     $11 = (_tolower($10)|0);
     $12 = (_tolower($6)|0);
     $13 = ($11|0)==($12|0);
     if (!($13)) {
      $$0$lcssa = $$019;$$lcssa = $10;
      break L1;
     }
    }
    $14 = ((($$01718)) + 1|0);
    $15 = ((($$019)) + 1|0);
    $16 = HEAP8[$14>>0]|0;
    $17 = $16&255;
    $18 = ($16<<24>>24)==(0);
    if ($18) {
     $$0$lcssa = $15;$$lcssa = $17;
     break;
    } else {
     $$01718 = $14;$$019 = $15;$10 = $17;$8 = $16;
    }
   }
  }
 } while(0);
 $19 = (_tolower($$lcssa)|0);
 $20 = HEAP8[$$0$lcssa>>0]|0;
 $21 = $20&255;
 $22 = (_tolower($21)|0);
 $23 = (($19) - ($22))|0;
 return ($23|0);
}
function _wmemmove($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$01417 = 0, $$019 = 0, $$118 = 0, $$in = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $3 = $0;
 $4 = $1;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 $7 = ($6>>>0)<($2>>>0);
 if ($7) {
  $$in = $2;
  while(1) {
   $9 = (($$in) + -1)|0;
   $10 = (($1) + ($9<<2)|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (($0) + ($9<<2)|0);
   HEAP32[$12>>2] = $11;
   $13 = ($9|0)==(0);
   if ($13) {
    break;
   } else {
    $$in = $9;
   }
  }
 } else {
  $8 = ($2|0)==(0);
  if (!($8)) {
   $$01417 = $1;$$019 = $0;$$118 = $2;
   while(1) {
    $14 = (($$118) + -1)|0;
    $15 = ((($$01417)) + 4|0);
    $16 = HEAP32[$$01417>>2]|0;
    $17 = ((($$019)) + 4|0);
    HEAP32[$$019>>2] = $16;
    $18 = ($14|0)==(0);
    if ($18) {
     break;
    } else {
     $$01417 = $15;$$019 = $17;$$118 = $14;
    }
   }
  }
 }
 return ($0|0);
}
function _strerror_r($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (_strerror($0)|0);
 $4 = (_strlen($3)|0);
 $5 = ($4>>>0)<($2>>>0);
 if ($5) {
  $9 = (($4) + 1)|0;
  _memcpy(($1|0),($3|0),($9|0))|0;
  $$0 = 0;
 } else {
  $6 = ($2|0)==(0);
  $7 = (($2) + -1)|0;
  if ($6) {
   $$0 = 34;
  } else {
   $8 = (($1) + ($7)|0);
   _memcpy(($1|0),($3|0),($7|0))|0;
   HEAP8[$8>>0] = 0;
   $$0 = 34;
  }
 }
 return ($$0|0);
}
function _dummy_269() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function _open($0,$1,$varargs) {
 $0 = $0|0;
 $1 = $1|0;
 $varargs = $varargs|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $arglist_current = 0, $arglist_next = 0;
 var $expanded = 0, $expanded2 = 0, $expanded4 = 0, $expanded5 = 0, $expanded6 = 0, $or$cond14 = 0, $vararg_buffer = 0, $vararg_buffer3 = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, $vararg_ptr6 = 0, $vararg_ptr7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $vararg_buffer3 = sp + 16|0;
 $vararg_buffer = sp;
 $2 = sp + 32|0;
 $3 = $1 & 4194368;
 $4 = ($3|0)==(0);
 if ($4) {
  $$0 = 0;
 } else {
  HEAP32[$2>>2] = $varargs;
  $arglist_current = HEAP32[$2>>2]|0;
  $5 = $arglist_current;
  $6 = ((0) + 4|0);
  $expanded2 = $6;
  $expanded = (($expanded2) - 1)|0;
  $7 = (($5) + ($expanded))|0;
  $8 = ((0) + 4|0);
  $expanded6 = $8;
  $expanded5 = (($expanded6) - 1)|0;
  $expanded4 = $expanded5 ^ -1;
  $9 = $7 & $expanded4;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $arglist_next = ((($10)) + 4|0);
  HEAP32[$2>>2] = $arglist_next;
  $$0 = $11;
 }
 $12 = $0;
 $13 = $1 | 32768;
 HEAP32[$vararg_buffer>>2] = $12;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $13;
 $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $$0;
 $14 = (___syscall5(5,($vararg_buffer|0))|0);
 $15 = ($14|0)<(0);
 $16 = $1 & 524288;
 $17 = ($16|0)==(0);
 $or$cond14 = $17 | $15;
 if (!($or$cond14)) {
  HEAP32[$vararg_buffer3>>2] = $14;
  $vararg_ptr6 = ((($vararg_buffer3)) + 4|0);
  HEAP32[$vararg_ptr6>>2] = 2;
  $vararg_ptr7 = ((($vararg_buffer3)) + 8|0);
  HEAP32[$vararg_ptr7>>2] = 1;
  (___syscall221(221,($vararg_buffer3|0))|0);
 }
 $18 = (___syscall_ret($14)|0);
 STACKTOP = sp;return ($18|0);
}
function ___munmap($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 _dummy_269();
 $2 = $0;
 HEAP32[$vararg_buffer>>2] = $2;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $1;
 $3 = (___syscall91(91,($vararg_buffer|0))|0);
 $4 = (___syscall_ret($3)|0);
 STACKTOP = sp;return ($4|0);
}
function _mbsnrtowcs($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$ = 0, $$04975 = 0, $$05274 = 0, $$055$ = 0, $$05573 = 0, $$064 = 0, $$076 = 0, $$1 = 0, $$150 = 0, $$153 = 0, $$156 = 0, $$25170 = 0, $$25469 = 0, $$257 = 0, $$271 = 0, $$3 = 0, $$35868 = 0, $$59 = 0, $$cast = 0, $$pr$pre = 0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $or$cond = 0, $or$cond72 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1040|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(1040|0);
 $5 = sp + 8|0;
 $6 = sp;
 $7 = HEAP32[$1>>2]|0;
 HEAP32[$6>>2] = $7;
 $8 = ($0|0)!=(0|0);
 $$ = $8 ? $3 : 256;
 $$59 = $8 ? $0 : $5;
 $$cast = $7;
 $9 = ($7|0)!=(0);
 $10 = ($$|0)!=(0);
 $or$cond72 = $10 & $9;
 L1: do {
  if ($or$cond72) {
   $$04975 = 0;$$05274 = $2;$$05573 = $$;$$076 = $$59;$44 = $$cast;
   while(1) {
    $11 = $$05274 >>> 2;
    $12 = ($11>>>0)>=($$05573>>>0);
    $13 = ($$05274>>>0)>(131);
    $14 = $13 | $12;
    if (!($14)) {
     $$064 = $$076;$$150 = $$04975;$$153 = $$05274;$$257 = $$05573;$25 = $44;
     break L1;
    }
    $$055$ = $12 ? $$05573 : $11;
    $15 = (($$05274) - ($$055$))|0;
    $16 = (_mbsrtowcs($$076,$6,$$055$,$4)|0);
    $17 = ($16|0)==(-1);
    if ($17) {
     break;
    }
    $18 = ($$076|0)==($5|0);
    $19 = (($$076) + ($16<<2)|0);
    $20 = $18 ? 0 : $16;
    $$156 = (($$05573) - ($20))|0;
    $$1 = $18 ? $$076 : $19;
    $21 = (($16) + ($$04975))|0;
    $22 = HEAP32[$6>>2]|0;
    $23 = ($22|0)!=(0|0);
    $24 = ($$156|0)!=(0);
    $or$cond = $24 & $23;
    if ($or$cond) {
     $$04975 = $21;$$05274 = $15;$$05573 = $$156;$$076 = $$1;$44 = $22;
    } else {
     $$064 = $$1;$$150 = $21;$$153 = $15;$$257 = $$156;$25 = $22;
     break L1;
    }
   }
   $$pr$pre = HEAP32[$6>>2]|0;
   $$064 = $$076;$$150 = -1;$$153 = $15;$$257 = 0;$25 = $$pr$pre;
  } else {
   $$064 = $$59;$$150 = 0;$$153 = $2;$$257 = $$;$25 = $$cast;
  }
 } while(0);
 $26 = ($25|0)==(0|0);
 L8: do {
  if ($26) {
   $$3 = $$150;
  } else {
   $27 = ($$257|0)!=(0);
   $28 = ($$153|0)!=(0);
   $29 = $27 & $28;
   if ($29) {
    $$25170 = $$150;$$25469 = $$153;$$271 = $$064;$$35868 = $$257;$30 = $25;
    while(1) {
     $31 = (_mbrtowc($$271,$30,$$25469,$4)|0);
     $32 = (($31) + 2)|0;
     $33 = ($32>>>0)<(3);
     if ($33) {
      break;
     }
     $34 = HEAP32[$6>>2]|0;
     $35 = (($34) + ($31)|0);
     HEAP32[$6>>2] = $35;
     $36 = (($$25469) - ($31))|0;
     $37 = ((($$271)) + 4|0);
     $38 = (($$35868) + -1)|0;
     $39 = (($$25170) + 1)|0;
     $40 = ($38|0)!=(0);
     $41 = ($36|0)!=(0);
     $42 = $40 & $41;
     if ($42) {
      $$25170 = $39;$$25469 = $36;$$271 = $37;$$35868 = $38;$30 = $35;
     } else {
      $$3 = $39;
      break L8;
     }
    }
    switch ($31|0) {
    case -1:  {
     $$3 = -1;
     break L8;
     break;
    }
    case 0:  {
     HEAP32[$6>>2] = 0;
     $$3 = $$25170;
     break L8;
     break;
    }
    default: {
     HEAP32[$4>>2] = 0;
     $$3 = $$25170;
     break L8;
    }
    }
   } else {
    $$3 = $$150;
   }
  }
 } while(0);
 if ($8) {
  $43 = HEAP32[$6>>2]|0;
  HEAP32[$1>>2] = $43;
 }
 STACKTOP = sp;return ($$3|0);
}
function _mbsrtowcs($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0100$lcssa = 0, $$0100136 = 0, $$0107135 = 0, $$0113134 = 0, $$099 = 0, $$10 = 0, $$1101 = 0, $$1101$ph = 0, $$1108$ph = 0, $$1108138 = 0, $$11124 = 0, $$1114 = 0, $$1114$ph = 0, $$11163 = 0, $$2 = 0, $$2102144 = 0, $$2109 = 0, $$2115143 = 0, $$3103 = 0, $$3110 = 0;
 var $$3116 = 0, $$4 = 0, $$4104 = 0, $$4111 = 0, $$4117 = 0, $$5 = 0, $$5105 = 0, $$5112 = 0, $$5112123 = 0, $$5112162 = 0, $$5118$ph = 0, $$5118137 = 0, $$6 = 0, $$6106$lcssa = 0, $$6106$ph = 0, $$6106139 = 0, $$6119 = 0, $$7 = 0, $$7120 = 0, $$8 = 0;
 var $$8121 = 0, $$9 = 0, $$9$sink = 0, $$9122 = 0, $$9122161 = 0, $$old1 = 0, $$pre$pre = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $not$ = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = HEAP32[$1>>2]|0;
 $5 = ($3|0)==(0|0);
 if ($5) {
  label = 5;
 } else {
  $6 = HEAP32[$3>>2]|0;
  $7 = ($6|0)==(0);
  if ($7) {
   label = 5;
  } else {
   $8 = ($0|0)==(0|0);
   if ($8) {
    $$2 = $6;$$4104 = $4;$$4117 = $2;
    label = 25;
   } else {
    HEAP32[$3>>2] = 0;
    $$4 = $6;$$4111 = $0;$$8121 = $2;$$9 = $4;
    label = 43;
   }
  }
 }
 L5: do {
  if ((label|0) == 5) {
   $9 = (___pthread_self_286()|0);
   $10 = ((($9)) + 188|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = HEAP32[$11>>2]|0;
   $not$ = ($12|0)==(0|0);
   $13 = ($0|0)!=(0|0);
   if (!($not$)) {
    if ($13) {
     $$1108$ph = $0;$$5118$ph = $2;$$6106$ph = $4;
     label = 15;
     break;
    } else {
     $$1101$ph = $4;$$1114$ph = $2;
     label = 14;
     break;
    }
   }
   if (!($13)) {
    $15 = (_strlen($4)|0);
    $$099 = $15;
    label = 59;
    break;
   }
   $14 = ($2|0)==(0);
   L13: do {
    if ($14) {
     $$0100$lcssa = $4;
    } else {
     $$0100136 = $4;$$0107135 = $0;$$0113134 = $2;
     while(1) {
      $16 = HEAP8[$$0100136>>0]|0;
      $17 = ($16<<24>>24)==(0);
      if ($17) {
       break;
      }
      $18 = ((($$0100136)) + 1|0);
      $19 = $16 << 24 >> 24;
      $20 = $19 & 57343;
      $21 = ((($$0107135)) + 4|0);
      HEAP32[$$0107135>>2] = $20;
      $22 = (($$0113134) + -1)|0;
      $23 = ($22|0)==(0);
      if ($23) {
       $$0100$lcssa = $18;
       break L13;
      } else {
       $$0100136 = $18;$$0107135 = $21;$$0113134 = $22;
      }
     }
     HEAP32[$$0107135>>2] = 0;
     HEAP32[$1>>2] = 0;
     $24 = (($2) - ($$0113134))|0;
     $$099 = $24;
     label = 59;
     break L5;
    }
   } while(0);
   HEAP32[$1>>2] = $$0100$lcssa;
   $$099 = $2;
   label = 59;
  }
 } while(0);
 L19: while(1) {
  L20: do {
   if ((label|0) == 14) {
    label = 0;
    $$1101 = $$1101$ph;$$1114 = $$1114$ph;
    while(1) {
     $26 = HEAP8[$$1101>>0]|0;
     $27 = $26&255;
     $28 = (($27) + -1)|0;
     $29 = ($28>>>0)<(127);
     if ($29) {
      $30 = $$1101;
      $31 = $30 & 3;
      $32 = ($31|0)==(0);
      if ($32) {
       $33 = HEAP32[$$1101>>2]|0;
       $34 = (($33) + -16843009)|0;
       $35 = $34 | $33;
       $36 = $35 & -2139062144;
       $37 = ($36|0)==(0);
       $38 = $33&255;
       if ($37) {
        $$2102144 = $$1101;$$2115143 = $$1114;
        while(1) {
         $39 = ((($$2102144)) + 4|0);
         $40 = (($$2115143) + -4)|0;
         $41 = HEAP32[$39>>2]|0;
         $42 = (($41) + -16843009)|0;
         $43 = $42 | $41;
         $44 = $43 & -2139062144;
         $45 = ($44|0)==(0);
         if ($45) {
          $$2102144 = $39;$$2115143 = $40;
         } else {
          break;
         }
        }
        $46 = $41&255;
        $$3103 = $39;$$3116 = $40;$48 = $46;
       } else {
        $$3103 = $$1101;$$3116 = $$1114;$48 = $38;
       }
      } else {
       $$3103 = $$1101;$$3116 = $$1114;$48 = $26;
      }
     } else {
      $$3103 = $$1101;$$3116 = $$1114;$48 = $26;
     }
     $47 = $48&255;
     $49 = (($47) + -1)|0;
     $50 = ($49>>>0)<(127);
     if (!($50)) {
      break;
     }
     $51 = ((($$3103)) + 1|0);
     $52 = (($$3116) + -1)|0;
     $$1101 = $51;$$1114 = $52;
    }
    $53 = (($47) + -194)|0;
    $54 = ($53>>>0)>(50);
    if ($54) {
     $$11163 = $$3103;$$5112162 = $0;$$9122161 = $$3116;
     label = 53;
    } else {
     $55 = ((($$3103)) + 1|0);
     $56 = (91900 + ($53<<2)|0);
     $57 = HEAP32[$56>>2]|0;
     $$2 = $57;$$4104 = $55;$$4117 = $$3116;
     label = 25;
     continue L19;
    }
   }
   else if ((label|0) == 15) {
    label = 0;
    $25 = ($$5118$ph|0)==(0);
    L22: do {
     if ($25) {
      $$6106$lcssa = $$6106$ph;
     } else {
      $$1108138 = $$1108$ph;$$5118137 = $$5118$ph;$$6106139 = $$6106$ph;
      while(1) {
       $80 = HEAP8[$$6106139>>0]|0;
       $81 = $80&255;
       $82 = (($81) + -1)|0;
       $83 = ($82>>>0)<(127);
       do {
        if ($83) {
         $84 = $$6106139;
         $85 = $84 & 3;
         $86 = ($85|0)==(0);
         $87 = ($$5118137>>>0)>(4);
         $or$cond = $87 & $86;
         if ($or$cond) {
          $$2109 = $$1108138;$$6119 = $$5118137;$$7 = $$6106139;
          while(1) {
           $88 = HEAP32[$$7>>2]|0;
           $89 = (($88) + -16843009)|0;
           $90 = $89 | $88;
           $91 = $90 & -2139062144;
           $92 = ($91|0)==(0);
           if (!($92)) {
            label = 38;
            break;
           }
           $93 = ((($$7)) + 1|0);
           $94 = $88 & 255;
           $95 = ((($$2109)) + 4|0);
           HEAP32[$$2109>>2] = $94;
           $96 = ((($$7)) + 2|0);
           $97 = HEAP8[$93>>0]|0;
           $98 = $97&255;
           $99 = ((($$2109)) + 8|0);
           HEAP32[$95>>2] = $98;
           $100 = ((($$7)) + 3|0);
           $101 = HEAP8[$96>>0]|0;
           $102 = $101&255;
           $103 = ((($$2109)) + 12|0);
           HEAP32[$99>>2] = $102;
           $104 = ((($$7)) + 4|0);
           $105 = HEAP8[$100>>0]|0;
           $106 = $105&255;
           $107 = ((($$2109)) + 16|0);
           HEAP32[$103>>2] = $106;
           $108 = (($$6119) + -4)|0;
           $$old1 = ($108>>>0)>(4);
           if ($$old1) {
            $$2109 = $107;$$6119 = $108;$$7 = $104;
           } else {
            label = 37;
            break;
           }
          }
          if ((label|0) == 37) {
           label = 0;
           $$pre$pre = HEAP8[$104>>0]|0;
           $$3110 = $107;$$7120 = $108;$$8 = $104;$111 = $$pre$pre;
           break;
          }
          else if ((label|0) == 38) {
           label = 0;
           $109 = $88&255;
           $$3110 = $$2109;$$7120 = $$6119;$$8 = $$7;$111 = $109;
           break;
          }
         } else {
          $$3110 = $$1108138;$$7120 = $$5118137;$$8 = $$6106139;$111 = $80;
         }
        } else {
         $$3110 = $$1108138;$$7120 = $$5118137;$$8 = $$6106139;$111 = $80;
        }
       } while(0);
       $110 = $111&255;
       $112 = (($110) + -1)|0;
       $113 = ($112>>>0)<(127);
       if (!($113)) {
        break;
       }
       $114 = ((($$8)) + 1|0);
       $115 = ((($$3110)) + 4|0);
       HEAP32[$$3110>>2] = $110;
       $116 = (($$7120) + -1)|0;
       $117 = ($116|0)==(0);
       if ($117) {
        $$6106$lcssa = $114;
        break L22;
       } else {
        $$1108138 = $115;$$5118137 = $116;$$6106139 = $114;
       }
      }
      $118 = (($110) + -194)|0;
      $119 = ($118>>>0)>(50);
      if ($119) {
       $$11163 = $$8;$$5112162 = $$3110;$$9122161 = $$7120;
       label = 53;
       break L20;
      }
      $120 = ((($$8)) + 1|0);
      $121 = (91900 + ($118<<2)|0);
      $122 = HEAP32[$121>>2]|0;
      $$4 = $122;$$4111 = $$3110;$$8121 = $$7120;$$9 = $120;
      label = 43;
      continue L19;
     }
    } while(0);
    HEAP32[$1>>2] = $$6106$lcssa;
    $$099 = $2;
    label = 59;
    continue L19;
   }
   else if ((label|0) == 25) {
    label = 0;
    $58 = HEAP8[$$4104>>0]|0;
    $59 = $58&255;
    $60 = $59 >>> 3;
    $61 = (($60) + -16)|0;
    $62 = $$2 >> 26;
    $63 = (($60) + ($62))|0;
    $64 = $61 | $63;
    $65 = ($64>>>0)>(7);
    if ($65) {
     $$5112 = $0;$$6 = $$2;$$9$sink = $$4104;$$9122 = $$4117;
     label = 52;
    } else {
     $66 = ((($$4104)) + 1|0);
     $67 = $$2 & 33554432;
     $68 = ($67|0)==(0);
     if ($68) {
      $$5105 = $66;
     } else {
      $69 = HEAP8[$66>>0]|0;
      $70 = $69 & -64;
      $71 = ($70<<24>>24)==(-128);
      if (!($71)) {
       $$5112 = $0;$$6 = $$2;$$9$sink = $$4104;$$9122 = $$4117;
       label = 52;
       break;
      }
      $72 = ((($$4104)) + 2|0);
      $73 = $$2 & 524288;
      $74 = ($73|0)==(0);
      if ($74) {
       $$5105 = $72;
      } else {
       $75 = HEAP8[$72>>0]|0;
       $76 = $75 & -64;
       $77 = ($76<<24>>24)==(-128);
       if (!($77)) {
        $$5112 = $0;$$6 = $$2;$$9$sink = $$4104;$$9122 = $$4117;
        label = 52;
        break;
       }
       $78 = ((($$4104)) + 3|0);
       $$5105 = $78;
      }
     }
     $79 = (($$4117) + -1)|0;
     $$1101$ph = $$5105;$$1114$ph = $79;
     label = 14;
     continue L19;
    }
   }
   else if ((label|0) == 43) {
    label = 0;
    $123 = HEAP8[$$9>>0]|0;
    $124 = $123&255;
    $125 = $124 >>> 3;
    $126 = (($125) + -16)|0;
    $127 = $$4 >> 26;
    $128 = (($125) + ($127))|0;
    $129 = $126 | $128;
    $130 = ($129>>>0)>(7);
    if ($130) {
     $$5112 = $$4111;$$6 = $$4;$$9$sink = $$9;$$9122 = $$8121;
     label = 52;
    } else {
     $131 = $$4 << 6;
     $132 = ((($$9)) + 1|0);
     $133 = (($124) + -128)|0;
     $134 = $133 | $131;
     $135 = ($134|0)<(0);
     do {
      if ($135) {
       $136 = HEAP8[$132>>0]|0;
       $137 = $136&255;
       $138 = (($137) + -128)|0;
       $139 = ($138>>>0)>(63);
       if ($139) {
        $140 = ((($$9)) + -1|0);
        $$11124 = $140;$$5112123 = $$4111;
        break L20;
       }
       $141 = $134 << 6;
       $142 = ((($$9)) + 2|0);
       $143 = $138 | $141;
       $144 = ($143|0)<(0);
       if ($144) {
        $145 = HEAP8[$142>>0]|0;
        $146 = $145&255;
        $147 = (($146) + -128)|0;
        $148 = ($147>>>0)>(63);
        if ($148) {
         $149 = ((($$9)) + -1|0);
         $$11124 = $149;$$5112123 = $$4111;
         break L20;
        } else {
         $150 = $143 << 6;
         $151 = ((($$9)) + 3|0);
         $152 = $147 | $150;
         $$10 = $151;$$5 = $152;
         break;
        }
       } else {
        $$10 = $142;$$5 = $143;
       }
      } else {
       $$10 = $132;$$5 = $134;
      }
     } while(0);
     $153 = ((($$4111)) + 4|0);
     HEAP32[$$4111>>2] = $$5;
     $154 = (($$8121) + -1)|0;
     $$1108$ph = $153;$$5118$ph = $154;$$6106$ph = $$10;
     label = 15;
     continue L19;
    }
   }
   else if ((label|0) == 59) {
    label = 0;
    return ($$099|0);
   }
  } while(0);
  if ((label|0) == 52) {
   label = 0;
   $155 = ((($$9$sink)) + -1|0);
   $156 = ($$6|0)==(0);
   if ($156) {
    $$11163 = $155;$$5112162 = $$5112;$$9122161 = $$9122;
    label = 53;
   } else {
    $$11124 = $155;$$5112123 = $$5112;
   }
  }
  if ((label|0) == 53) {
   label = 0;
   $157 = HEAP8[$$11163>>0]|0;
   $158 = ($157<<24>>24)==(0);
   if ($158) {
    $159 = ($$5112162|0)==(0|0);
    if (!($159)) {
     HEAP32[$$5112162>>2] = 0;
     HEAP32[$1>>2] = 0;
    }
    $160 = (($2) - ($$9122161))|0;
    $$099 = $160;
    label = 59;
    continue;
   } else {
    $$11124 = $$11163;$$5112123 = $$5112162;
   }
  }
  $161 = (___errno_location()|0);
  HEAP32[$161>>2] = 84;
  $162 = ($$5112123|0)==(0|0);
  if ($162) {
   $$099 = -1;
   label = 59;
   continue;
  }
  HEAP32[$1>>2] = $$11124;
  $$099 = -1;
  label = 59;
 }
 return (0)|0;
}
function _mbrtowc($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$ = 0, $$0 = 0, $$03952 = 0, $$04051 = 0, $$04350 = 0, $$1 = 0, $$141 = 0, $$144 = 0, $$2 = 0, $$47 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $not$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $4 = sp;
 $5 = ($3|0)==(0|0);
 $$ = $5 ? 214108 : $3;
 $6 = HEAP32[$$>>2]|0;
 $7 = ($1|0)==(0|0);
 L1: do {
  if ($7) {
   $8 = ($6|0)==(0);
   if ($8) {
    $$0 = 0;
   } else {
    label = 17;
   }
  } else {
   $9 = ($0|0)==(0|0);
   $$47 = $9 ? $4 : $0;
   $10 = ($2|0)==(0);
   if ($10) {
    $$0 = -2;
   } else {
    $11 = ($6|0)==(0);
    if ($11) {
     $12 = HEAP8[$1>>0]|0;
     $13 = ($12<<24>>24)>(-1);
     if ($13) {
      $14 = $12&255;
      HEAP32[$$47>>2] = $14;
      $15 = ($12<<24>>24)!=(0);
      $16 = $15&1;
      $$0 = $16;
      break;
     }
     $17 = (___pthread_self()|0);
     $18 = ((($17)) + 188|0);
     $19 = HEAP32[$18>>2]|0;
     $20 = HEAP32[$19>>2]|0;
     $not$ = ($20|0)==(0|0);
     $21 = HEAP8[$1>>0]|0;
     if ($not$) {
      $22 = $21 << 24 >> 24;
      $23 = $22 & 57343;
      HEAP32[$$47>>2] = $23;
      $$0 = 1;
      break;
     }
     $24 = $21&255;
     $25 = (($24) + -194)|0;
     $26 = ($25>>>0)>(50);
     if ($26) {
      label = 17;
      break;
     }
     $27 = ((($1)) + 1|0);
     $28 = (91900 + ($25<<2)|0);
     $29 = HEAP32[$28>>2]|0;
     $30 = (($2) + -1)|0;
     $31 = ($30|0)==(0);
     if ($31) {
      $$2 = $29;
     } else {
      $$03952 = $27;$$04051 = $29;$$04350 = $30;
      label = 11;
     }
    } else {
     $$03952 = $1;$$04051 = $6;$$04350 = $2;
     label = 11;
    }
    L14: do {
     if ((label|0) == 11) {
      $32 = HEAP8[$$03952>>0]|0;
      $33 = $32&255;
      $34 = $33 >>> 3;
      $35 = (($34) + -16)|0;
      $36 = $$04051 >> 26;
      $37 = (($34) + ($36))|0;
      $38 = $35 | $37;
      $39 = ($38>>>0)>(7);
      if ($39) {
       label = 17;
       break L1;
      } else {
       $$1 = $$03952;$$141 = $$04051;$$144 = $$04350;$43 = $32;
      }
      while(1) {
       $40 = $$141 << 6;
       $41 = ((($$1)) + 1|0);
       $42 = $43&255;
       $44 = (($42) + -128)|0;
       $45 = $44 | $40;
       $46 = (($$144) + -1)|0;
       $47 = ($45|0)<(0);
       if (!($47)) {
        break;
       }
       $49 = ($46|0)==(0);
       if ($49) {
        $$2 = $45;
        break L14;
       }
       $50 = HEAP8[$41>>0]|0;
       $51 = $50 & -64;
       $52 = ($51<<24>>24)==(-128);
       if ($52) {
        $$1 = $41;$$141 = $45;$$144 = $46;$43 = $50;
       } else {
        label = 17;
        break L1;
       }
      }
      HEAP32[$$>>2] = 0;
      HEAP32[$$47>>2] = $45;
      $48 = (($2) - ($46))|0;
      $$0 = $48;
      break L1;
     }
    } while(0);
    HEAP32[$$>>2] = $$2;
    $$0 = -2;
   }
  }
 } while(0);
 if ((label|0) == 17) {
  HEAP32[$$>>2] = 0;
  $53 = (___errno_location()|0);
  HEAP32[$53>>2] = 84;
  $$0 = -1;
 }
 STACKTOP = sp;return ($$0|0);
}
function ___pthread_self() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_pthread_self()|0);
 return ($0|0);
}
function ___pthread_self_286() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_pthread_self()|0);
 return ($0|0);
}
function _mbtowc($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$ = 0, $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $not$ = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = ($1|0)==(0|0);
 L1: do {
  if ($4) {
   $$0 = 0;
  } else {
   $5 = ($2|0)==(0);
   do {
    if (!($5)) {
     $6 = ($0|0)==(0|0);
     $$ = $6 ? $3 : $0;
     $7 = HEAP8[$1>>0]|0;
     $8 = ($7<<24>>24)>(-1);
     if ($8) {
      $9 = $7&255;
      HEAP32[$$>>2] = $9;
      $10 = ($7<<24>>24)!=(0);
      $11 = $10&1;
      $$0 = $11;
      break L1;
     }
     $12 = (___pthread_self_283()|0);
     $13 = ((($12)) + 188|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = HEAP32[$14>>2]|0;
     $not$ = ($15|0)==(0|0);
     $16 = HEAP8[$1>>0]|0;
     if ($not$) {
      $17 = $16 << 24 >> 24;
      $18 = $17 & 57343;
      HEAP32[$$>>2] = $18;
      $$0 = 1;
      break L1;
     }
     $19 = $16&255;
     $20 = (($19) + -194)|0;
     $21 = ($20>>>0)>(50);
     if (!($21)) {
      $22 = ((($1)) + 1|0);
      $23 = (91900 + ($20<<2)|0);
      $24 = HEAP32[$23>>2]|0;
      $25 = ($2>>>0)<(4);
      if ($25) {
       $26 = ($2*6)|0;
       $27 = (($26) + -6)|0;
       $28 = -2147483648 >>> $27;
       $29 = $24 & $28;
       $30 = ($29|0)==(0);
       if (!($30)) {
        break;
       }
      }
      $31 = HEAP8[$22>>0]|0;
      $32 = $31&255;
      $33 = $32 >>> 3;
      $34 = (($33) + -16)|0;
      $35 = $24 >> 26;
      $36 = (($33) + ($35))|0;
      $37 = $34 | $36;
      $38 = ($37>>>0)>(7);
      if (!($38)) {
       $39 = $24 << 6;
       $40 = (($32) + -128)|0;
       $41 = $40 | $39;
       $42 = ($41|0)<(0);
       if (!($42)) {
        HEAP32[$$>>2] = $41;
        $$0 = 2;
        break L1;
       }
       $43 = ((($1)) + 2|0);
       $44 = HEAP8[$43>>0]|0;
       $45 = $44&255;
       $46 = (($45) + -128)|0;
       $47 = ($46>>>0)>(63);
       if (!($47)) {
        $48 = $41 << 6;
        $49 = $46 | $48;
        $50 = ($49|0)<(0);
        if (!($50)) {
         HEAP32[$$>>2] = $49;
         $$0 = 3;
         break L1;
        }
        $51 = ((($1)) + 3|0);
        $52 = HEAP8[$51>>0]|0;
        $53 = $52&255;
        $54 = (($53) + -128)|0;
        $55 = ($54>>>0)>(63);
        if (!($55)) {
         $56 = $49 << 6;
         $57 = $54 | $56;
         HEAP32[$$>>2] = $57;
         $$0 = 4;
         break L1;
        }
       }
      }
     }
    }
   } while(0);
   $58 = (___errno_location()|0);
   HEAP32[$58>>2] = 84;
   $$0 = -1;
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function ___pthread_self_283() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_pthread_self()|0);
 return ($0|0);
}
function _mbrlen($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($2|0)!=(0|0);
 $4 = $3 ? $2 : 214112;
 $5 = (_mbrtowc(0,$0,$1,$4)|0);
 return ($5|0);
}
function _wcsnrtombs($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$ = 0, $$04773 = 0, $$05072 = 0, $$053$$050 = 0, $$05371 = 0, $$062 = 0, $$074 = 0, $$1 = 0, $$148 = 0, $$151 = 0, $$154 = 0, $$24968 = 0, $$25267 = 0, $$255 = 0, $$269 = 0, $$3 = 0, $$35666 = 0, $$57 = 0, $$cast = 0, $$pr$pre = 0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $or$cond = 0, $or$cond70 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 272|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(272|0);
 $5 = sp + 8|0;
 $6 = sp;
 $7 = HEAP32[$1>>2]|0;
 HEAP32[$6>>2] = $7;
 $8 = ($0|0)!=(0|0);
 $$ = $8 ? $3 : 256;
 $$57 = $8 ? $0 : $5;
 $$cast = $7;
 $9 = ($7|0)!=(0);
 $10 = ($$|0)!=(0);
 $or$cond70 = $10 & $9;
 L1: do {
  if ($or$cond70) {
   $$04773 = 0;$$05072 = $2;$$05371 = $$;$$074 = $$57;$45 = $$cast;
   while(1) {
    $11 = ($$05072>>>0)>=($$05371>>>0);
    $12 = ($$05072>>>0)>(32);
    $13 = $11 | $12;
    if (!($13)) {
     $$062 = $$074;$$148 = $$04773;$$151 = $$05072;$$255 = $$05371;$24 = $45;
     break L1;
    }
    $$053$$050 = $11 ? $$05371 : $$05072;
    $14 = (($$05072) - ($$053$$050))|0;
    $15 = (_wcsrtombs($$074,$6,$$053$$050,0)|0);
    $16 = ($15|0)==(-1);
    if ($16) {
     break;
    }
    $17 = ($$074|0)==($5|0);
    $18 = (($$074) + ($15)|0);
    $19 = $17 ? 0 : $15;
    $$154 = (($$05371) - ($19))|0;
    $$1 = $17 ? $$074 : $18;
    $20 = (($15) + ($$04773))|0;
    $21 = HEAP32[$6>>2]|0;
    $22 = ($21|0)!=(0|0);
    $23 = ($$154|0)!=(0);
    $or$cond = $23 & $22;
    if ($or$cond) {
     $$04773 = $20;$$05072 = $14;$$05371 = $$154;$$074 = $$1;$45 = $21;
    } else {
     $$062 = $$1;$$148 = $20;$$151 = $14;$$255 = $$154;$24 = $21;
     break L1;
    }
   }
   $$pr$pre = HEAP32[$6>>2]|0;
   $$062 = $$074;$$148 = -1;$$151 = $14;$$255 = 0;$24 = $$pr$pre;
  } else {
   $$062 = $$57;$$148 = 0;$$151 = $2;$$255 = $$;$24 = $$cast;
  }
 } while(0);
 $25 = ($24|0)==(0|0);
 L8: do {
  if ($25) {
   $$3 = $$148;
  } else {
   $26 = ($$255|0)!=(0);
   $27 = ($$151|0)!=(0);
   $28 = $26 & $27;
   if ($28) {
    $$24968 = $$148;$$25267 = $$151;$$269 = $$062;$$35666 = $$255;$30 = $24;
    while(1) {
     $29 = HEAP32[$30>>2]|0;
     $31 = (_wcrtomb($$269,$29,0)|0);
     $32 = (($31) + 1)|0;
     $33 = ($32>>>0)<(2);
     if ($33) {
      break;
     }
     $35 = HEAP32[$6>>2]|0;
     $36 = ((($35)) + 4|0);
     HEAP32[$6>>2] = $36;
     $37 = (($$25267) + -1)|0;
     $38 = (($$269) + ($31)|0);
     $39 = (($$35666) - ($31))|0;
     $40 = (($31) + ($$24968))|0;
     $41 = ($39|0)!=(0);
     $42 = ($37|0)!=(0);
     $43 = $41 & $42;
     if ($43) {
      $$24968 = $40;$$25267 = $37;$$269 = $38;$$35666 = $39;$30 = $36;
     } else {
      $$3 = $40;
      break L8;
     }
    }
    $34 = ($31|0)==(0);
    if ($34) {
     HEAP32[$6>>2] = 0;
     $$3 = $$24968;
    } else {
     $$3 = -1;
    }
   } else {
    $$3 = $$148;
   }
  }
 } while(0);
 if ($8) {
  $44 = HEAP32[$6>>2]|0;
  HEAP32[$1>>2] = $44;
 }
 STACKTOP = sp;return ($$3|0);
}
function _wcsrtombs($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $$05675 = 0, $$057$lcssa = 0, $$05785 = 0, $$05874 = 0, $$1 = 0, $$159 = 0, $$260$lcssa = 0, $$26084 = 0, $$279 = 0, $$3 = 0, $$361 = 0, $$478 = 0, $$5 = 0, $$pn = 0, $$pre = 0, $$pre100 = 0, $$pre101 = 0, $$pre102 = 0, $10 = 0;
 var $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $4 = sp;
 $5 = ($0|0)==(0|0);
 L1: do {
  if ($5) {
   $7 = HEAP32[$1>>2]|0;
   $8 = HEAP32[$7>>2]|0;
   $9 = ($8|0)==(0);
   if ($9) {
    $$0 = 0;
   } else {
    $$05675 = $7;$$05874 = 0;$10 = $8;
    while(1) {
     $11 = ($10>>>0)>(127);
     if ($11) {
      $12 = (_wcrtomb($4,$10,0)|0);
      $13 = ($12|0)==(-1);
      if ($13) {
       $$0 = -1;
       break L1;
      } else {
       $$pn = $12;
      }
     } else {
      $$pn = 1;
     }
     $$159 = (($$pn) + ($$05874))|0;
     $14 = ((($$05675)) + 4|0);
     $15 = HEAP32[$14>>2]|0;
     $16 = ($15|0)==(0);
     if ($16) {
      $$0 = $$159;
      break;
     } else {
      $$05675 = $14;$$05874 = $$159;$10 = $15;
     }
    }
   }
  } else {
   $6 = ($2>>>0)>(3);
   L9: do {
    if ($6) {
     $$pre = HEAP32[$1>>2]|0;
     $$05785 = $0;$$26084 = $2;$19 = $$pre;
     while(1) {
      $18 = HEAP32[$19>>2]|0;
      $20 = (($18) + -1)|0;
      $21 = ($20>>>0)>(126);
      if ($21) {
       $22 = ($18|0)==(0);
       if ($22) {
        break;
       }
       $24 = (_wcrtomb($$05785,$18,0)|0);
       $25 = ($24|0)==(-1);
       if ($25) {
        $$0 = -1;
        break L1;
       }
       $26 = (($$05785) + ($24)|0);
       $27 = (($$26084) - ($24))|0;
       $$1 = $26;$$361 = $27;$32 = $19;
      } else {
       $28 = $18&255;
       $29 = ((($$05785)) + 1|0);
       HEAP8[$$05785>>0] = $28;
       $30 = (($$26084) + -1)|0;
       $$pre100 = HEAP32[$1>>2]|0;
       $$1 = $29;$$361 = $30;$32 = $$pre100;
      }
      $31 = ((($32)) + 4|0);
      HEAP32[$1>>2] = $31;
      $33 = ($$361>>>0)>(3);
      if ($33) {
       $$05785 = $$1;$$26084 = $$361;$19 = $31;
      } else {
       $$057$lcssa = $$1;$$260$lcssa = $$361;
       break L9;
      }
     }
     HEAP8[$$05785>>0] = 0;
     HEAP32[$1>>2] = 0;
     $23 = (($2) - ($$26084))|0;
     $$0 = $23;
     break L1;
    } else {
     $$057$lcssa = $0;$$260$lcssa = $2;
    }
   } while(0);
   $17 = ($$260$lcssa|0)==(0);
   if ($17) {
    $$0 = $2;
   } else {
    $$pre101 = HEAP32[$1>>2]|0;
    $$279 = $$057$lcssa;$$478 = $$260$lcssa;$35 = $$pre101;
    while(1) {
     $34 = HEAP32[$35>>2]|0;
     $36 = (($34) + -1)|0;
     $37 = ($36>>>0)>(126);
     if ($37) {
      $38 = ($34|0)==(0);
      if ($38) {
       label = 19;
       break;
      }
      $40 = (_wcrtomb($4,$34,0)|0);
      $41 = ($40|0)==(-1);
      if ($41) {
       $$0 = -1;
       break L1;
      }
      $42 = ($$478>>>0)<($40>>>0);
      if ($42) {
       label = 22;
       break;
      }
      $44 = HEAP32[$35>>2]|0;
      (_wcrtomb($$279,$44,0)|0);
      $45 = (($$279) + ($40)|0);
      $46 = (($$478) - ($40))|0;
      $$3 = $45;$$5 = $46;$51 = $35;
     } else {
      $47 = $34&255;
      $48 = ((($$279)) + 1|0);
      HEAP8[$$279>>0] = $47;
      $49 = (($$478) + -1)|0;
      $$pre102 = HEAP32[$1>>2]|0;
      $$3 = $48;$$5 = $49;$51 = $$pre102;
     }
     $50 = ((($51)) + 4|0);
     HEAP32[$1>>2] = $50;
     $52 = ($$5|0)==(0);
     if ($52) {
      $$0 = $2;
      break L1;
     } else {
      $$279 = $$3;$$478 = $$5;$35 = $50;
     }
    }
    if ((label|0) == 19) {
     HEAP8[$$279>>0] = 0;
     HEAP32[$1>>2] = 0;
     $39 = (($2) - ($$478))|0;
     $$0 = $39;
     break;
    }
    else if ((label|0) == 22) {
     $43 = (($2) - ($$478))|0;
     $$0 = $43;
     break;
    }
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function _mbsinit($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ($0|0)==(0|0);
 if ($1) {
  $5 = 1;
 } else {
  $2 = HEAP32[$0>>2]|0;
  $3 = ($2|0)==(0);
  $5 = $3;
 }
 $4 = $5&1;
 return ($4|0);
}
function _opendir($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $1 = (_open($0,589824,$vararg_buffer)|0);
 $2 = ($1|0)<(0);
 do {
  if ($2) {
   $$0 = 0;
  } else {
   $3 = (_calloc(1,2072)|0);
   $4 = ($3|0)==(0|0);
   if ($4) {
    HEAP32[$vararg_buffer1>>2] = $1;
    (___syscall6(6,($vararg_buffer1|0))|0);
    $$0 = 0;
    break;
   } else {
    HEAP32[$3>>2] = $1;
    $$0 = $3;
    break;
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function _stat($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $2 = $0;
 $3 = $1;
 HEAP32[$vararg_buffer>>2] = $2;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $3;
 $4 = (___syscall195(195,($vararg_buffer|0))|0);
 $5 = (___syscall_ret($4)|0);
 STACKTOP = sp;return ($5|0);
}
function _closedir($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = (_close($1)|0);
 _free($0);
 return ($2|0);
}
function _readdir($0) {
 $0 = $0|0;
 var $$1 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $1 = ((($0)) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2|0)<($4|0);
 L1: do {
  if ($5) {
   $14 = $2;
   label = 6;
  } else {
   $6 = HEAP32[$0>>2]|0;
   $7 = ((($0)) + 24|0);
   $8 = $7;
   HEAP32[$vararg_buffer>>2] = $6;
   $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
   HEAP32[$vararg_ptr1>>2] = $8;
   $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
   HEAP32[$vararg_ptr2>>2] = 2048;
   $9 = (___syscall220(220,($vararg_buffer|0))|0);
   $10 = ($9|0)<(1);
   if (!($10)) {
    HEAP32[$3>>2] = $9;
    HEAP32[$1>>2] = 0;
    $14 = 0;
    label = 6;
    break;
   }
   switch ($9|0) {
   case 0: case -2:  {
    $$1 = 0;
    break L1;
    break;
   }
   default: {
   }
   }
   $11 = (0 - ($9))|0;
   $12 = (___errno_location()|0);
   HEAP32[$12>>2] = $11;
   $$1 = 0;
  }
 } while(0);
 if ((label|0) == 6) {
  $13 = (((($0)) + 24|0) + ($14)|0);
  $15 = ((($13)) + 8|0);
  $16 = HEAP16[$15>>1]|0;
  $17 = $16&65535;
  $18 = (($17) + ($14))|0;
  HEAP32[$1>>2] = $18;
  $19 = ((($13)) + 4|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = ((($0)) + 4|0);
  HEAP32[$21>>2] = $20;
  $$1 = $13;
 }
 STACKTOP = sp;return ($$1|0);
}
function _snprintf($0,$1,$2,$varargs) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $varargs = $varargs|0;
 var $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 HEAP32[$3>>2] = $varargs;
 $4 = (_vsnprintf($0,$1,$2,$3)|0);
 STACKTOP = sp;return ($4|0);
}
function _mkdir($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $2 = $0;
 HEAP32[$vararg_buffer>>2] = $2;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $1;
 $3 = (___syscall39(39,($vararg_buffer|0))|0);
 $4 = (___syscall_ret($3)|0);
 STACKTOP = sp;return ($4|0);
}
function _fstat($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer2 = 0, $vararg_buffer6 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, $vararg_ptr9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(64|0);
 $vararg_buffer6 = sp + 16|0;
 $vararg_buffer2 = sp + 8|0;
 $vararg_buffer = sp;
 $2 = sp + 24|0;
 $3 = $1;
 HEAP32[$vararg_buffer>>2] = $0;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $3;
 $4 = (___syscall197(197,($vararg_buffer|0))|0);
 $5 = ($4|0)==(-9);
 if ($5) {
  HEAP32[$vararg_buffer2>>2] = $0;
  $vararg_ptr5 = ((($vararg_buffer2)) + 4|0);
  HEAP32[$vararg_ptr5>>2] = 1;
  $6 = (___syscall221(221,($vararg_buffer2|0))|0);
  $7 = ($6|0)<(0);
  if ($7) {
   label = 3;
  } else {
   ___procfdname($2,$0);
   $9 = $2;
   HEAP32[$vararg_buffer6>>2] = $9;
   $vararg_ptr9 = ((($vararg_buffer6)) + 4|0);
   HEAP32[$vararg_ptr9>>2] = $3;
   $10 = (___syscall195(195,($vararg_buffer6|0))|0);
   $11 = (___syscall_ret($10)|0);
   $$0 = $11;
  }
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (___syscall_ret($4)|0);
  $$0 = $8;
 }
 STACKTOP = sp;return ($$0|0);
}
function _strtoull_l($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = (_strtoull($0,$1,$2)|0);
 $5 = tempRet0;
 tempRet0 = ($5);
 return ($4|0);
}
function _strtoll_l($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = (_strtoll($0,$1,$2)|0);
 $5 = tempRet0;
 tempRet0 = ($5);
 return ($4|0);
}
function _toupper($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (_islower($0)|0);
 $2 = ($1|0)==(0);
 $3 = $0 & 95;
 $$0 = $2 ? $0 : $3;
 return ($$0|0);
}
function _islower($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (($0) + -97)|0;
 $2 = ($1>>>0)<(26);
 $3 = $2&1;
 return ($3|0);
}
function ___ctype_get_mb_cur_max() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (___pthread_self_389()|0);
 $1 = ((($0)) + 188|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)!=(0|0);
 $5 = $4 ? 4 : 1;
 return ($5|0);
}
function ___pthread_self_389() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_pthread_self()|0);
 return ($0|0);
}
function ___ctype_b_loc() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (92972|0);
}
function ___ctype_tolower_loc() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (92976|0);
}
function ___ctype_toupper_loc() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (94516|0);
}
function _isxdigit($0) {
 $0 = $0|0;
 var $$ = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $isdigit = 0, $isdigittmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $isdigittmp = (($0) + -48)|0;
 $isdigit = ($isdigittmp>>>0)<(10);
 $1 = $0 | 32;
 $2 = (($1) + -97)|0;
 $3 = ($2>>>0)<(6);
 $$ = $isdigit | $3;
 $4 = $$&1;
 return ($4|0);
}
function _vfscanf($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$ = 0, $$$0266 = 0, $$$0268 = 0, $$$0305 = 0, $$$3 = 0, $$0266$lcssa = 0, $$0266417 = 0, $$0268 = 0, $$0272 = 0, $$0273429 = 0, $$0276$ph = 0, $$0278$ph = 0, $$0278$ph$phi = 0, $$0278$ph336 = 0, $$0283428 = 0, $$0286420 = 0, $$0288$ = 0, $$0288425 = 0, $$0292 = 0, $$0293 = 0;
 var $$0305423 = 0, $$10 = 0, $$11 = 0, $$1267 = 0, $$1271 = 0, $$1274 = 0, $$1277$ph = 0, $$1279 = 0, $$1284 = 0, $$1289 = 0, $$2 = 0, $$2275 = 0, $$2280 = 0, $$2280$ph = 0, $$2280$ph$phi = 0, $$2285 = 0, $$2290 = 0, $$2307$ph = 0, $$3$lcssa = 0, $$319 = 0;
 var $$320 = 0, $$321 = 0, $$322 = 0, $$327 = 0, $$328$le439 = 0, $$328$le441 = 0, $$3281 = 0, $$3291 = 0, $$3416 = 0, $$4282 = 0, $$4309 = 0, $$5 = 0, $$5299 = 0, $$5310 = 0, $$6 = 0, $$6311 = 0, $$7 = 0, $$7$ph = 0, $$7312 = 0, $$8 = 0;
 var $$8313 = 0, $$9 = 0, $$9314 = 0, $$9314$ph = 0, $$lcssa355 = 0, $$not = 0, $$old4 = 0, $$ph = 0, $$ph353 = 0, $$pre = 0, $$pre$phi516Z2D = 0, $$pre507 = 0, $$pre509 = 0, $$pre511 = 0, $$pre512 = 0, $$pre513 = 0, $$pre514 = 0, $$pre515 = 0, $$sink443 = 0, $$sroa$2$0$$sroa_idx13 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0;
 var $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0;
 var $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0;
 var $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0;
 var $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0;
 var $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0;
 var $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0;
 var $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0;
 var $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0;
 var $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0.0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0.0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0;
 var $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $arglist_current = 0, $arglist_next = 0, $expanded = 0, $expanded1 = 0, $expanded3 = 0, $expanded4 = 0, $expanded5 = 0, $factor = 0, $factor331 = 0, $isdigit = 0;
 var $isdigit316 = 0, $isdigit316415 = 0, $isdigittmp = 0, $isdigittmp315 = 0, $isdigittmp315414 = 0, $narrow = 0, $narrow469 = 0, $or$cond = 0, $or$cond3 = 0, $or$cond318 = 0, $or$cond5 = 0, $trunc = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 288|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(288|0);
 $3 = sp + 8|0;
 $4 = sp + 17|0;
 $5 = sp;
 $6 = sp + 16|0;
 $7 = ((($0)) + 76|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)>(-1);
 if ($9) {
  $10 = (___lockfile($0)|0);
  $305 = $10;
 } else {
  $305 = 0;
 }
 $11 = HEAP8[$1>>0]|0;
 $12 = ($11<<24>>24)==(0);
 L4: do {
  if ($12) {
   $$3291 = 0;
  } else {
   $13 = ((($0)) + 4|0);
   $14 = ((($0)) + 100|0);
   $15 = ((($0)) + 108|0);
   $16 = ((($0)) + 8|0);
   $17 = ((($4)) + 10|0);
   $18 = ((($4)) + 33|0);
   $$sroa$2$0$$sroa_idx13 = ((($3)) + 4|0);
   $19 = ((($4)) + 46|0);
   $20 = ((($4)) + 94|0);
   $21 = ((($4)) + 1|0);
   $22 = ((($4)) + 1|0);
   $$0273429 = $1;$$0283428 = 0;$$0288425 = 0;$$0305423 = 0;$102 = 0;$24 = $11;
   L6: while(1) {
    $23 = $24&255;
    $25 = (_isspace($23)|0);
    $26 = ($25|0)==(0);
    L8: do {
     if ($26) {
      $53 = ($24<<24>>24)==(37);
      L10: do {
       if ($53) {
        $54 = ((($$0273429)) + 1|0);
        $55 = HEAP8[$54>>0]|0;
        L12: do {
         switch ($55<<24>>24) {
         case 37:  {
          break L10;
          break;
         }
         case 42:  {
          $76 = ((($$0273429)) + 2|0);
          $$0293 = 0;$$2275 = $76;
          break;
         }
         default: {
          $77 = $55&255;
          $isdigittmp = (($77) + -48)|0;
          $isdigit = ($isdigittmp>>>0)<(10);
          if ($isdigit) {
           $78 = ((($$0273429)) + 2|0);
           $79 = HEAP8[$78>>0]|0;
           $80 = ($79<<24>>24)==(36);
           if ($80) {
            $81 = (_arg_n_585($2,$isdigittmp)|0);
            $82 = ((($$0273429)) + 3|0);
            $$0293 = $81;$$2275 = $82;
            break L12;
           }
          }
          $arglist_current = HEAP32[$2>>2]|0;
          $83 = $arglist_current;
          $84 = ((0) + 4|0);
          $expanded1 = $84;
          $expanded = (($expanded1) - 1)|0;
          $85 = (($83) + ($expanded))|0;
          $86 = ((0) + 4|0);
          $expanded5 = $86;
          $expanded4 = (($expanded5) - 1)|0;
          $expanded3 = $expanded4 ^ -1;
          $87 = $85 & $expanded3;
          $88 = $87;
          $89 = HEAP32[$88>>2]|0;
          $arglist_next = ((($88)) + 4|0);
          HEAP32[$2>>2] = $arglist_next;
          $$0293 = $89;$$2275 = $54;
         }
         }
        } while(0);
        $90 = HEAP8[$$2275>>0]|0;
        $91 = $90&255;
        $isdigittmp315414 = (($91) + -48)|0;
        $isdigit316415 = ($isdigittmp315414>>>0)<(10);
        if ($isdigit316415) {
         $$0266417 = 0;$$3416 = $$2275;$95 = $91;
         while(1) {
          $92 = ($$0266417*10)|0;
          $93 = (($92) + -48)|0;
          $94 = (($93) + ($95))|0;
          $96 = ((($$3416)) + 1|0);
          $97 = HEAP8[$96>>0]|0;
          $98 = $97&255;
          $isdigittmp315 = (($98) + -48)|0;
          $isdigit316 = ($isdigittmp315>>>0)<(10);
          if ($isdigit316) {
           $$0266417 = $94;$$3416 = $96;$95 = $98;
          } else {
           $$0266$lcssa = $94;$$3$lcssa = $96;$$lcssa355 = $97;
           break;
          }
         }
        } else {
         $$0266$lcssa = 0;$$3$lcssa = $$2275;$$lcssa355 = $90;
        }
        $99 = ($$lcssa355<<24>>24)==(109);
        $100 = ($$0293|0)!=(0|0);
        $101 = ((($$3$lcssa)) + 1|0);
        $$$0305 = $99 ? 0 : $$0305423;
        $$327 = $99 ? 0 : $102;
        $$$3 = $99 ? $101 : $$3$lcssa;
        $narrow = $100 & $99;
        $103 = ((($$$3)) + 1|0);
        $104 = HEAP8[$$$3>>0]|0;
        switch ($104<<24>>24) {
        case 104:  {
         $105 = HEAP8[$103>>0]|0;
         $106 = ($105<<24>>24)==(104);
         $107 = ((($$$3)) + 2|0);
         $$319 = $106 ? $107 : $103;
         $$320 = $106 ? -2 : -1;
         $$0268 = $$320;$$5 = $$319;
         break;
        }
        case 108:  {
         $108 = HEAP8[$103>>0]|0;
         $109 = ($108<<24>>24)==(108);
         $110 = ((($$$3)) + 2|0);
         $$321 = $109 ? $110 : $103;
         $$322 = $109 ? 3 : 1;
         $$0268 = $$322;$$5 = $$321;
         break;
        }
        case 106:  {
         $$0268 = 3;$$5 = $103;
         break;
        }
        case 116: case 122:  {
         $$0268 = 1;$$5 = $103;
         break;
        }
        case 76:  {
         $$0268 = 2;$$5 = $103;
         break;
        }
        case 110: case 112: case 67: case 83: case 91: case 99: case 115: case 88: case 71: case 70: case 69: case 65: case 103: case 102: case 101: case 97: case 120: case 117: case 111: case 105: case 100:  {
         $$0268 = 0;$$5 = $$$3;
         break;
        }
        default: {
         $$7312 = $$$0305;$309 = $$327;$narrow469 = $narrow;
         label = 137;
         break L6;
        }
        }
        $111 = HEAP8[$$5>>0]|0;
        $112 = $111&255;
        $113 = $112 & 47;
        $114 = ($113|0)==(3);
        $115 = $112 | 32;
        $$ = $114 ? $115 : $112;
        $$$0268 = $114 ? 1 : $$0268;
        $trunc = $$&255;
        switch ($trunc<<24>>24) {
        case 99:  {
         $116 = ($$0266$lcssa|0)>(1);
         $$$0266 = $116 ? $$0266$lcssa : 1;
         $$1267 = $$$0266;$$1284 = $$0283428;
         break;
        }
        case 91:  {
         $$1267 = $$0266$lcssa;$$1284 = $$0283428;
         break;
        }
        case 110:  {
         $117 = ($$0283428|0)<(0);
         $118 = $117 << 31 >> 31;
         _store_int_586($$0293,$$$0268,$$0283428,$118);
         $$11 = $$5;$$1289 = $$0288425;$$2285 = $$0283428;$$6311 = $$$0305;$307 = $$327;
         break L8;
         break;
        }
        default: {
         ___shlim($0,0);
         while(1) {
          $119 = HEAP32[$13>>2]|0;
          $120 = HEAP32[$14>>2]|0;
          $121 = ($119>>>0)<($120>>>0);
          if ($121) {
           $122 = ((($119)) + 1|0);
           HEAP32[$13>>2] = $122;
           $123 = HEAP8[$119>>0]|0;
           $124 = $123&255;
           $126 = $124;
          } else {
           $125 = (___shgetc($0)|0);
           $126 = $125;
          }
          $127 = (_isspace($126)|0);
          $128 = ($127|0)==(0);
          if ($128) {
           break;
          }
         }
         $129 = HEAP32[$14>>2]|0;
         $130 = ($129|0)==(0|0);
         if ($130) {
          $$pre507 = HEAP32[$13>>2]|0;
          $138 = $$pre507;
         } else {
          $131 = HEAP32[$13>>2]|0;
          $132 = ((($131)) + -1|0);
          HEAP32[$13>>2] = $132;
          $133 = $132;
          $138 = $133;
         }
         $134 = HEAP32[$15>>2]|0;
         $135 = HEAP32[$16>>2]|0;
         $136 = (($134) + ($$0283428))|0;
         $137 = (($136) + ($138))|0;
         $139 = (($137) - ($135))|0;
         $$1267 = $$0266$lcssa;$$1284 = $139;
        }
        }
        ___shlim($0,$$1267);
        $140 = HEAP32[$13>>2]|0;
        $141 = HEAP32[$14>>2]|0;
        $142 = ($140>>>0)<($141>>>0);
        if ($142) {
         $143 = ((($140)) + 1|0);
         HEAP32[$13>>2] = $143;
         $146 = $141;
        } else {
         $144 = (___shgetc($0)|0);
         $145 = ($144|0)<(0);
         if ($145) {
          $$7312 = $$$0305;$309 = $$327;$narrow469 = $narrow;
          label = 137;
          break L6;
         }
         $$pre509 = HEAP32[$14>>2]|0;
         $146 = $$pre509;
        }
        $147 = ($146|0)==(0|0);
        if (!($147)) {
         $148 = HEAP32[$13>>2]|0;
         $149 = ((($148)) + -1|0);
         HEAP32[$13>>2] = $149;
        }
        L55: do {
         switch ($trunc<<24>>24) {
         case 91: case 99: case 115:  {
          $150 = ($$|0)==(99);
          $151 = $$ | 16;
          $152 = ($151|0)==(115);
          L57: do {
           if ($152) {
            $153 = ($$|0)==(115);
            _memset(($21|0),-1,256)|0;
            HEAP8[$4>>0] = 0;
            if ($153) {
             HEAP8[$18>>0] = 0;
             ;HEAP8[$17>>0]=0|0;HEAP8[$17+1>>0]=0|0;HEAP8[$17+2>>0]=0|0;HEAP8[$17+3>>0]=0|0;HEAP8[$17+4>>0]=0|0;
             $$9 = $$5;
            } else {
             $$9 = $$5;
            }
           } else {
            $154 = ((($$5)) + 1|0);
            $155 = HEAP8[$154>>0]|0;
            $156 = ($155<<24>>24)==(94);
            $157 = ((($$5)) + 2|0);
            $$0292 = $156&1;
            $$6 = $156 ? $157 : $154;
            $158 = $156&1;
            _memset(($22|0),($158|0),256)|0;
            HEAP8[$4>>0] = 0;
            $159 = HEAP8[$$6>>0]|0;
            switch ($159<<24>>24) {
            case 45:  {
             $$sink443 = $19;
             label = 64;
             break;
            }
            case 93:  {
             $$sink443 = $20;
             label = 64;
             break;
            }
            default: {
             $$pre514 = $$0292 ^ 1;
             $$pre515 = $$pre514&255;
             $$7$ph = $$6;$$pre$phi516Z2D = $$pre515;
            }
            }
            if ((label|0) == 64) {
             label = 0;
             $160 = ((($$6)) + 1|0);
             $161 = $$0292 ^ 1;
             $162 = $161&255;
             HEAP8[$$sink443>>0] = $162;
             $$7$ph = $160;$$pre$phi516Z2D = $162;
            }
            $$7 = $$7$ph;
            while(1) {
             $163 = HEAP8[$$7>>0]|0;
             L69: do {
              switch ($163<<24>>24) {
              case 0:  {
               $$7312 = $$$0305;$309 = $$327;$narrow469 = $narrow;
               label = 137;
               break L6;
               break;
              }
              case 93:  {
               $$9 = $$7;
               break L57;
               break;
              }
              case 45:  {
               $164 = ((($$7)) + 1|0);
               $165 = HEAP8[$164>>0]|0;
               switch ($165<<24>>24) {
               case 93: case 0:  {
                $$8 = $$7;$176 = 45;
                break L69;
                break;
               }
               default: {
               }
               }
               $166 = ((($$7)) + -1|0);
               $167 = HEAP8[$166>>0]|0;
               $168 = ($167&255)<($165&255);
               if ($168) {
                $169 = $167&255;
                $$0286420 = $169;
                while(1) {
                 $170 = (($$0286420) + 1)|0;
                 $171 = (($4) + ($170)|0);
                 HEAP8[$171>>0] = $$pre$phi516Z2D;
                 $172 = HEAP8[$164>>0]|0;
                 $173 = $172&255;
                 $174 = ($170|0)<($173|0);
                 if ($174) {
                  $$0286420 = $170;
                 } else {
                  $$8 = $164;$176 = $172;
                  break;
                 }
                }
               } else {
                $$8 = $164;$176 = $165;
               }
               break;
              }
              default: {
               $$8 = $$7;$176 = $163;
              }
              }
             } while(0);
             $175 = $176&255;
             $177 = (($175) + 1)|0;
             $178 = (($4) + ($177)|0);
             HEAP8[$178>>0] = $$pre$phi516Z2D;
             $179 = ((($$8)) + 1|0);
             $$7 = $179;
            }
           }
          } while(0);
          $180 = (($$1267) + 1)|0;
          $181 = $150 ? $180 : 31;
          $182 = ($$$0268|0)==(1);
          L77: do {
           if ($182) {
            if ($narrow) {
             $183 = $181 << 2;
             $184 = (_malloc($183)|0);
             $185 = ($184|0)==(0|0);
             if ($185) {
              $$7312 = 0;$309 = 0;$narrow469 = 1;
              label = 137;
              break L6;
             } else {
              $311 = $184;
             }
            } else {
             $311 = $$0293;
            }
            HEAP32[$3>>2] = 0;
            HEAP32[$$sroa$2$0$$sroa_idx13>>2] = 0;
            $$0276$ph = $181;$$0278$ph = 0;$$ph = $311;
            L82: while(1) {
             $186 = ($$ph|0)==(0|0);
             $$0278$ph336 = $$0278$ph;
             while(1) {
              L86: while(1) {
               $187 = HEAP32[$13>>2]|0;
               $188 = HEAP32[$14>>2]|0;
               $189 = ($187>>>0)<($188>>>0);
               if ($189) {
                $190 = ((($187)) + 1|0);
                HEAP32[$13>>2] = $190;
                $191 = HEAP8[$187>>0]|0;
                $192 = $191&255;
                $195 = $192;
               } else {
                $193 = (___shgetc($0)|0);
                $195 = $193;
               }
               $194 = (($195) + 1)|0;
               $196 = (($4) + ($194)|0);
               $197 = HEAP8[$196>>0]|0;
               $198 = ($197<<24>>24)==(0);
               if ($198) {
                break L82;
               }
               $199 = $195&255;
               HEAP8[$6>>0] = $199;
               $200 = (_mbrtowc($5,$6,1,$3)|0);
               switch ($200|0) {
               case -1:  {
                $$7312 = 0;$309 = $$ph;$narrow469 = $narrow;
                label = 137;
                break L6;
                break;
               }
               case -2:  {
                break;
               }
               default: {
                break L86;
               }
               }
              }
              if ($186) {
               $$1279 = $$0278$ph336;
              } else {
               $201 = (($$ph) + ($$0278$ph336<<2)|0);
               $202 = (($$0278$ph336) + 1)|0;
               $203 = HEAP32[$5>>2]|0;
               HEAP32[$201>>2] = $203;
               $$1279 = $202;
              }
              $204 = ($$1279|0)==($$0276$ph|0);
              $or$cond = $narrow & $204;
              if ($or$cond) {
               break;
              } else {
               $$0278$ph336 = $$1279;
              }
             }
             $factor331 = $$0276$ph << 1;
             $205 = $factor331 | 1;
             $206 = $205 << 2;
             $207 = (_realloc($$ph,$206)|0);
             $208 = ($207|0)==(0|0);
             if ($208) {
              $$7312 = 0;$309 = $$ph;$narrow469 = 1;
              label = 137;
              break L6;
             } else {
              $$0278$ph$phi = $$0276$ph;$$0276$ph = $205;$$ph = $207;$$0278$ph = $$0278$ph$phi;
             }
            }
            $209 = (_mbsinit($3)|0);
            $210 = ($209|0)==(0);
            if ($210) {
             $$7312 = 0;$309 = $$ph;$narrow469 = $narrow;
             label = 137;
             break L6;
            } else {
             $$4282 = $$0278$ph336;$$4309 = 0;$$5299 = $$ph;$312 = $$ph;
            }
           } else {
            if ($narrow) {
             $211 = (_malloc($181)|0);
             $212 = ($211|0)==(0|0);
             if ($212) {
              $$7312 = 0;$309 = 0;$narrow469 = 1;
              label = 137;
              break L6;
             } else {
              $$1277$ph = $181;$$2280$ph = 0;$$2307$ph = $211;
             }
             while(1) {
              $$2280 = $$2280$ph;
              while(1) {
               $213 = HEAP32[$13>>2]|0;
               $214 = HEAP32[$14>>2]|0;
               $215 = ($213>>>0)<($214>>>0);
               if ($215) {
                $216 = ((($213)) + 1|0);
                HEAP32[$13>>2] = $216;
                $217 = HEAP8[$213>>0]|0;
                $218 = $217&255;
                $221 = $218;
               } else {
                $219 = (___shgetc($0)|0);
                $221 = $219;
               }
               $220 = (($221) + 1)|0;
               $222 = (($4) + ($220)|0);
               $223 = HEAP8[$222>>0]|0;
               $224 = ($223<<24>>24)==(0);
               if ($224) {
                $$4282 = $$2280;$$4309 = $$2307$ph;$$5299 = 0;$312 = 0;
                break L77;
               }
               $225 = $221&255;
               $226 = (($$2280) + 1)|0;
               $227 = (($$2307$ph) + ($$2280)|0);
               HEAP8[$227>>0] = $225;
               $228 = ($226|0)==($$1277$ph|0);
               if ($228) {
                break;
               } else {
                $$2280 = $226;
               }
              }
              $factor = $$1277$ph << 1;
              $229 = $factor | 1;
              $230 = (_realloc($$2307$ph,$229)|0);
              $231 = ($230|0)==(0|0);
              if ($231) {
               $$7312 = $$2307$ph;$309 = 0;$narrow469 = 1;
               label = 137;
               break L6;
              } else {
               $$2280$ph$phi = $$1277$ph;$$1277$ph = $229;$$2307$ph = $230;$$2280$ph = $$2280$ph$phi;
              }
             }
            }
            $232 = ($$0293|0)==(0|0);
            if ($232) {
             $250 = $146;
             while(1) {
              $248 = HEAP32[$13>>2]|0;
              $249 = ($248>>>0)<($250>>>0);
              if ($249) {
               $251 = ((($248)) + 1|0);
               HEAP32[$13>>2] = $251;
               $252 = HEAP8[$248>>0]|0;
               $253 = $252&255;
               $256 = $253;
              } else {
               $254 = (___shgetc($0)|0);
               $256 = $254;
              }
              $255 = (($256) + 1)|0;
              $257 = (($4) + ($255)|0);
              $258 = HEAP8[$257>>0]|0;
              $259 = ($258<<24>>24)==(0);
              if ($259) {
               $$4282 = 0;$$4309 = 0;$$5299 = 0;$312 = 0;
               break L77;
              }
              $$pre512 = HEAP32[$14>>2]|0;
              $250 = $$pre512;
             }
            } else {
             $$3281 = 0;$235 = $146;
             while(1) {
              $233 = HEAP32[$13>>2]|0;
              $234 = ($233>>>0)<($235>>>0);
              if ($234) {
               $236 = ((($233)) + 1|0);
               HEAP32[$13>>2] = $236;
               $237 = HEAP8[$233>>0]|0;
               $238 = $237&255;
               $241 = $238;
              } else {
               $239 = (___shgetc($0)|0);
               $241 = $239;
              }
              $240 = (($241) + 1)|0;
              $242 = (($4) + ($240)|0);
              $243 = HEAP8[$242>>0]|0;
              $244 = ($243<<24>>24)==(0);
              if ($244) {
               $$4282 = $$3281;$$4309 = $$0293;$$5299 = 0;$312 = 0;
               break L77;
              }
              $245 = $241&255;
              $246 = (($$3281) + 1)|0;
              $247 = (($$0293) + ($$3281)|0);
              HEAP8[$247>>0] = $245;
              $$pre511 = HEAP32[$14>>2]|0;
              $$3281 = $246;$235 = $$pre511;
             }
            }
           }
          } while(0);
          $260 = HEAP32[$14>>2]|0;
          $261 = ($260|0)==(0|0);
          if ($261) {
           $$pre513 = HEAP32[$13>>2]|0;
           $268 = $$pre513;
          } else {
           $262 = HEAP32[$13>>2]|0;
           $263 = ((($262)) + -1|0);
           HEAP32[$13>>2] = $263;
           $264 = $263;
           $268 = $264;
          }
          $265 = HEAP32[$15>>2]|0;
          $266 = HEAP32[$16>>2]|0;
          $267 = (($268) - ($266))|0;
          $269 = (($267) + ($265))|0;
          $270 = ($269|0)==(0);
          if ($270) {
           $$9314$ph = $$4309;$$ph353 = $312;
           label = 139;
           break L6;
          }
          $$not = $150 ^ 1;
          $271 = ($269|0)==($$1267|0);
          $or$cond318 = $271 | $$not;
          if (!($or$cond318)) {
           $$9314$ph = $$4309;$$ph353 = $312;
           label = 139;
           break L6;
          }
          do {
           if ($narrow) {
            if ($182) {
             HEAP32[$$0293>>2] = $$5299;
             break;
            } else {
             HEAP32[$$0293>>2] = $$4309;
             break;
            }
           }
          } while(0);
          if ($150) {
           $$10 = $$9;$$5310 = $$4309;$310 = $312;
          } else {
           $272 = ($$5299|0)==(0|0);
           if (!($272)) {
            $273 = (($$5299) + ($$4282<<2)|0);
            HEAP32[$273>>2] = 0;
           }
           $274 = ($$4309|0)==(0|0);
           if ($274) {
            $$10 = $$9;$$5310 = 0;$310 = $312;
            break L55;
           }
           $275 = (($$4309) + ($$4282)|0);
           HEAP8[$275>>0] = 0;
           $$10 = $$9;$$5310 = $$4309;$310 = $312;
          }
          break;
         }
         case 120: case 88: case 112:  {
          $$0272 = 16;
          label = 125;
          break;
         }
         case 111:  {
          $$0272 = 8;
          label = 125;
          break;
         }
         case 117: case 100:  {
          $$0272 = 10;
          label = 125;
          break;
         }
         case 105:  {
          $$0272 = 0;
          label = 125;
          break;
         }
         case 71: case 103: case 70: case 102: case 69: case 101: case 65: case 97:  {
          $285 = (+___floatscan($0,$$$0268,0));
          $286 = HEAP32[$15>>2]|0;
          $287 = HEAP32[$13>>2]|0;
          $288 = HEAP32[$16>>2]|0;
          $289 = (($288) - ($287))|0;
          $290 = ($286|0)==($289|0);
          if ($290) {
           $$9314$ph = $$$0305;$$ph353 = $$327;
           label = 139;
           break L6;
          }
          $291 = ($$0293|0)==(0|0);
          if ($291) {
           $$10 = $$5;$$5310 = $$$0305;$310 = $$327;
          } else {
           switch ($$$0268|0) {
           case 0:  {
            $292 = $285;
            HEAPF32[$$0293>>2] = $292;
            $$10 = $$5;$$5310 = $$$0305;$310 = $$327;
            break L55;
            break;
           }
           case 1:  {
            HEAPF64[$$0293>>3] = $285;
            $$10 = $$5;$$5310 = $$$0305;$310 = $$327;
            break L55;
            break;
           }
           case 2:  {
            HEAPF64[$$0293>>3] = $285;
            $$10 = $$5;$$5310 = $$$0305;$310 = $$327;
            break L55;
            break;
           }
           default: {
            $$10 = $$5;$$5310 = $$$0305;$310 = $$327;
            break L55;
           }
           }
          }
          break;
         }
         default: {
          $$10 = $$5;$$5310 = $$$0305;$310 = $$327;
         }
         }
        } while(0);
        do {
         if ((label|0) == 125) {
          label = 0;
          $276 = (___intscan($0,$$0272,0,-1,-1)|0);
          $277 = tempRet0;
          $278 = HEAP32[$15>>2]|0;
          $279 = HEAP32[$13>>2]|0;
          $280 = HEAP32[$16>>2]|0;
          $281 = (($280) - ($279))|0;
          $282 = ($278|0)==($281|0);
          if ($282) {
           $$9314$ph = $$$0305;$$ph353 = $$327;
           label = 139;
           break L6;
          }
          $283 = ($$|0)==(112);
          $or$cond3 = $100 & $283;
          if ($or$cond3) {
           $284 = $276;
           HEAP32[$$0293>>2] = $284;
           $$10 = $$5;$$5310 = $$$0305;$310 = $$327;
           break;
          } else {
           _store_int_586($$0293,$$$0268,$276,$277);
           $$10 = $$5;$$5310 = $$$0305;$310 = $$327;
           break;
          }
         }
        } while(0);
        $293 = HEAP32[$15>>2]|0;
        $294 = HEAP32[$13>>2]|0;
        $295 = HEAP32[$16>>2]|0;
        $296 = (($293) + ($$1284))|0;
        $297 = (($296) + ($294))|0;
        $298 = (($297) - ($295))|0;
        $299 = $100&1;
        $$0288$ = (($299) + ($$0288425))|0;
        $$11 = $$10;$$1289 = $$0288$;$$2285 = $298;$$6311 = $$5310;$307 = $310;
        break L8;
       }
      } while(0);
      $56 = $53&1;
      $57 = (($$0273429) + ($56)|0);
      ___shlim($0,0);
      $58 = HEAP32[$13>>2]|0;
      $59 = HEAP32[$14>>2]|0;
      $60 = ($58>>>0)<($59>>>0);
      if ($60) {
       $61 = ((($58)) + 1|0);
       HEAP32[$13>>2] = $61;
       $62 = HEAP8[$58>>0]|0;
       $63 = $62&255;
       $67 = $63;
      } else {
       $64 = (___shgetc($0)|0);
       $67 = $64;
      }
      $65 = HEAP8[$57>>0]|0;
      $66 = $65&255;
      $68 = ($67|0)==($66|0);
      if (!($68)) {
       label = 22;
       break L6;
      }
      $75 = (($$0283428) + 1)|0;
      $$11 = $57;$$1289 = $$0288425;$$2285 = $75;$$6311 = $$0305423;$307 = $102;
     } else {
      $$1274 = $$0273429;
      while(1) {
       $27 = ((($$1274)) + 1|0);
       $28 = HEAP8[$27>>0]|0;
       $29 = $28&255;
       $30 = (_isspace($29)|0);
       $31 = ($30|0)==(0);
       if ($31) {
        break;
       } else {
        $$1274 = $27;
       }
      }
      ___shlim($0,0);
      while(1) {
       $32 = HEAP32[$13>>2]|0;
       $33 = HEAP32[$14>>2]|0;
       $34 = ($32>>>0)<($33>>>0);
       if ($34) {
        $35 = ((($32)) + 1|0);
        HEAP32[$13>>2] = $35;
        $36 = HEAP8[$32>>0]|0;
        $37 = $36&255;
        $39 = $37;
       } else {
        $38 = (___shgetc($0)|0);
        $39 = $38;
       }
       $40 = (_isspace($39)|0);
       $41 = ($40|0)==(0);
       if ($41) {
        break;
       }
      }
      $42 = HEAP32[$14>>2]|0;
      $43 = ($42|0)==(0|0);
      if ($43) {
       $$pre = HEAP32[$13>>2]|0;
       $51 = $$pre;
      } else {
       $44 = HEAP32[$13>>2]|0;
       $45 = ((($44)) + -1|0);
       HEAP32[$13>>2] = $45;
       $46 = $45;
       $51 = $46;
      }
      $47 = HEAP32[$15>>2]|0;
      $48 = HEAP32[$16>>2]|0;
      $49 = (($47) + ($$0283428))|0;
      $50 = (($49) + ($51))|0;
      $52 = (($50) - ($48))|0;
      $$11 = $$1274;$$1289 = $$0288425;$$2285 = $52;$$6311 = $$0305423;$307 = $102;
     }
    } while(0);
    $300 = ((($$11)) + 1|0);
    $301 = HEAP8[$300>>0]|0;
    $302 = ($301<<24>>24)==(0);
    if ($302) {
     $$3291 = $$1289;
     break L4;
    } else {
     $$0273429 = $300;$$0283428 = $$2285;$$0288425 = $$1289;$$0305423 = $$6311;$102 = $307;$24 = $301;
    }
   }
   if ((label|0) == 22) {
    $69 = HEAP32[$14>>2]|0;
    $70 = ($69|0)==(0|0);
    if (!($70)) {
     $71 = HEAP32[$13>>2]|0;
     $72 = ((($71)) + -1|0);
     HEAP32[$13>>2] = $72;
    }
    $73 = ($67|0)>(-1);
    $74 = ($$0288425|0)!=(0);
    $or$cond5 = $74 | $73;
    if ($or$cond5) {
     $$3291 = $$0288425;
     break;
    } else {
     $$1271 = 0;$$8313 = $$0305423;$308 = $102;
     label = 138;
    }
   }
   else if ((label|0) == 137) {
    $$328$le441 = $narrow469&1;
    $$old4 = ($$0288425|0)==(0);
    if ($$old4) {
     $$1271 = $$328$le441;$$8313 = $$7312;$308 = $309;
     label = 138;
    } else {
     $$2 = $$328$le441;$$2290 = $$0288425;$$9314 = $$7312;$304 = $309;
    }
   }
   else if ((label|0) == 139) {
    $$328$le439 = $narrow&1;
    $$2 = $$328$le439;$$2290 = $$0288425;$$9314 = $$9314$ph;$304 = $$ph353;
   }
   if ((label|0) == 138) {
    $$2 = $$1271;$$2290 = -1;$$9314 = $$8313;$304 = $308;
   }
   $303 = ($$2|0)==(0);
   if ($303) {
    $$3291 = $$2290;
   } else {
    _free($$9314);
    _free($304);
    $$3291 = $$2290;
   }
  }
 } while(0);
 $306 = ($305|0)==(0);
 if (!($306)) {
  ___unlockfile($0);
 }
 STACKTOP = sp;return ($$3291|0);
}
function _arg_n_585($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $arglist_current = 0, $arglist_next = 0, $expanded = 0, $expanded1 = 0, $expanded3 = 0, $expanded4 = 0, $expanded5 = 0, $vacopy_currentptr = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $vacopy_currentptr = HEAP32[$0>>2]|0;
 HEAP32[$2>>2] = $vacopy_currentptr;
 $$0 = $1;
 while(1) {
  $3 = ($$0>>>0)>(1);
  $arglist_current = HEAP32[$2>>2]|0;
  $4 = $arglist_current;
  $5 = ((0) + 4|0);
  $expanded1 = $5;
  $expanded = (($expanded1) - 1)|0;
  $6 = (($4) + ($expanded))|0;
  $7 = ((0) + 4|0);
  $expanded5 = $7;
  $expanded4 = (($expanded5) - 1)|0;
  $expanded3 = $expanded4 ^ -1;
  $8 = $6 & $expanded3;
  $9 = $8;
  $10 = HEAP32[$9>>2]|0;
  $arglist_next = ((($9)) + 4|0);
  HEAP32[$2>>2] = $arglist_next;
  $11 = (($$0) + -1)|0;
  if ($3) {
   $$0 = $11;
  } else {
   break;
  }
 }
 STACKTOP = sp;return ($10|0);
}
function _store_int_586($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $10 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ($0|0)==(0|0);
 L1: do {
  if (!($4)) {
   switch ($1|0) {
   case -2:  {
    $5 = $2&255;
    HEAP8[$0>>0] = $5;
    break L1;
    break;
   }
   case -1:  {
    $6 = $2&65535;
    HEAP16[$0>>1] = $6;
    break L1;
    break;
   }
   case 0:  {
    HEAP32[$0>>2] = $2;
    break L1;
    break;
   }
   case 1:  {
    HEAP32[$0>>2] = $2;
    break L1;
    break;
   }
   case 3:  {
    $7 = $0;
    $8 = $7;
    HEAP32[$8>>2] = $2;
    $9 = (($7) + 4)|0;
    $10 = $9;
    HEAP32[$10>>2] = $3;
    break L1;
    break;
   }
   default: {
    break L1;
   }
   }
  }
 } while(0);
 return;
}
function ___fseeko_unlocked($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$019 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($2|0)==(1);
 if ($3) {
  $4 = ((($0)) + 8|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ((($0)) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($1) - ($5))|0;
  $9 = (($8) + ($7))|0;
  $$019 = $9;
 } else {
  $$019 = $1;
 }
 $10 = ((($0)) + 20|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($0)) + 28|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($11>>>0)>($13>>>0);
 if ($14) {
  $15 = ((($0)) + 36|0);
  $16 = HEAP32[$15>>2]|0;
  (FUNCTION_TABLE_iiii[$16 & 8191]($0,0,0)|0);
  $17 = HEAP32[$10>>2]|0;
  $18 = ($17|0)==(0|0);
  if ($18) {
   $$0 = -1;
  } else {
   label = 5;
  }
 } else {
  label = 5;
 }
 if ((label|0) == 5) {
  $19 = ((($0)) + 16|0);
  HEAP32[$19>>2] = 0;
  HEAP32[$12>>2] = 0;
  HEAP32[$10>>2] = 0;
  $20 = ((($0)) + 40|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = (FUNCTION_TABLE_iiii[$21 & 8191]($0,$$019,$2)|0);
  $23 = ($22|0)<(0);
  if ($23) {
   $$0 = -1;
  } else {
   $24 = ((($0)) + 8|0);
   HEAP32[$24>>2] = 0;
   $25 = ((($0)) + 4|0);
   HEAP32[$25>>2] = 0;
   $26 = HEAP32[$0>>2]|0;
   $27 = $26 & -17;
   HEAP32[$0>>2] = $27;
   $$0 = 0;
  }
 }
 return ($$0|0);
}
function _fclose($0) {
 $0 = $0|0;
 var $$pre = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 76|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)>(-1);
 if ($3) {
  $4 = (___lockfile($0)|0);
  $28 = $4;
 } else {
  $28 = 0;
 }
 ___unlist_locked_file($0);
 $5 = HEAP32[$0>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)!=(0);
 if (!($7)) {
  $8 = (___ofl_lock()|0);
  $9 = ((($0)) + 52|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10|0)==(0|0);
  $12 = $10;
  $$pre = ((($0)) + 56|0);
  if (!($11)) {
   $13 = HEAP32[$$pre>>2]|0;
   $14 = ((($10)) + 56|0);
   HEAP32[$14>>2] = $13;
  }
  $15 = HEAP32[$$pre>>2]|0;
  $16 = ($15|0)==(0|0);
  if (!($16)) {
   $17 = ((($15)) + 52|0);
   HEAP32[$17>>2] = $12;
  }
  $18 = HEAP32[$8>>2]|0;
  $19 = ($18|0)==($0|0);
  if ($19) {
   HEAP32[$8>>2] = $15;
  }
  ___ofl_unlock();
 }
 $20 = (_fflush($0)|0);
 $21 = ((($0)) + 12|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (FUNCTION_TABLE_ii[$22 & 8191]($0)|0);
 $24 = $23 | $20;
 $25 = ((($0)) + 92|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($26|0)==(0|0);
 if (!($27)) {
  _free($26);
 }
 if ($7) {
  $29 = ($28|0)==(0);
  if (!($29)) {
   ___unlockfile($0);
  }
 } else {
  _free($0);
 }
 return ($24|0);
}
function ___unlist_locked_file($0) {
 $0 = $0|0;
 var $$pre = 0, $$sink = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 68|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if (!($3)) {
  $4 = ((($0)) + 116|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0|0);
  $$pre = ((($0)) + 112|0);
  if (!($6)) {
   $7 = HEAP32[$$pre>>2]|0;
   $8 = ((($5)) + 112|0);
   HEAP32[$8>>2] = $7;
  }
  $9 = HEAP32[$$pre>>2]|0;
  $10 = ($9|0)==(0|0);
  if ($10) {
   $12 = (___pthread_self_462()|0);
   $13 = ((($12)) + 232|0);
   $$sink = $13;
  } else {
   $11 = ((($9)) + 116|0);
   $$sink = $11;
  }
  HEAP32[$$sink>>2] = $5;
 }
 return;
}
function ___ofl_lock() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 ___lock((214116|0));
 return (214124|0);
}
function ___ofl_unlock() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 ___unlock((214116|0));
 return;
}
function _fflush($0) {
 $0 = $0|0;
 var $$0 = 0, $$023 = 0, $$02325 = 0, $$02327 = 0, $$024$lcssa = 0, $$02426 = 0, $$1 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ($0|0)==(0|0);
 do {
  if ($1) {
   $8 = HEAP32[23119]|0;
   $9 = ($8|0)==(0|0);
   if ($9) {
    $29 = 0;
   } else {
    $10 = HEAP32[23119]|0;
    $11 = (_fflush($10)|0);
    $29 = $11;
   }
   $12 = (___ofl_lock()|0);
   $$02325 = HEAP32[$12>>2]|0;
   $13 = ($$02325|0)==(0|0);
   if ($13) {
    $$024$lcssa = $29;
   } else {
    $$02327 = $$02325;$$02426 = $29;
    while(1) {
     $14 = ((($$02327)) + 76|0);
     $15 = HEAP32[$14>>2]|0;
     $16 = ($15|0)>(-1);
     if ($16) {
      $17 = (___lockfile($$02327)|0);
      $25 = $17;
     } else {
      $25 = 0;
     }
     $18 = ((($$02327)) + 20|0);
     $19 = HEAP32[$18>>2]|0;
     $20 = ((($$02327)) + 28|0);
     $21 = HEAP32[$20>>2]|0;
     $22 = ($19>>>0)>($21>>>0);
     if ($22) {
      $23 = (___fflush_unlocked($$02327)|0);
      $24 = $23 | $$02426;
      $$1 = $24;
     } else {
      $$1 = $$02426;
     }
     $26 = ($25|0)==(0);
     if (!($26)) {
      ___unlockfile($$02327);
     }
     $27 = ((($$02327)) + 56|0);
     $$023 = HEAP32[$27>>2]|0;
     $28 = ($$023|0)==(0|0);
     if ($28) {
      $$024$lcssa = $$1;
      break;
     } else {
      $$02327 = $$023;$$02426 = $$1;
     }
    }
   }
   ___ofl_unlock();
   $$0 = $$024$lcssa;
  } else {
   $2 = ((($0)) + 76|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = ($3|0)>(-1);
   if (!($4)) {
    $5 = (___fflush_unlocked($0)|0);
    $$0 = $5;
    break;
   }
   $6 = (___lockfile($0)|0);
   $phitmp = ($6|0)==(0);
   $7 = (___fflush_unlocked($0)|0);
   if ($phitmp) {
    $$0 = $7;
   } else {
    ___unlockfile($0);
    $$0 = $7;
   }
  }
 } while(0);
 return ($$0|0);
}
function ___fflush_unlocked($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 20|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)>($4>>>0);
 if ($5) {
  $6 = ((($0)) + 36|0);
  $7 = HEAP32[$6>>2]|0;
  (FUNCTION_TABLE_iiii[$7 & 8191]($0,0,0)|0);
  $8 = HEAP32[$1>>2]|0;
  $9 = ($8|0)==(0|0);
  if ($9) {
   $$0 = -1;
  } else {
   label = 3;
  }
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $10 = ((($0)) + 4|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ((($0)) + 8|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($11>>>0)<($13>>>0);
  if ($14) {
   $15 = $11;
   $16 = $13;
   $17 = (($15) - ($16))|0;
   $18 = ((($0)) + 40|0);
   $19 = HEAP32[$18>>2]|0;
   (FUNCTION_TABLE_iiii[$19 & 8191]($0,$17,1)|0);
  }
  $20 = ((($0)) + 16|0);
  HEAP32[$20>>2] = 0;
  HEAP32[$3>>2] = 0;
  HEAP32[$1>>2] = 0;
  HEAP32[$12>>2] = 0;
  HEAP32[$10>>2] = 0;
  $$0 = 0;
 }
 return ($$0|0);
}
function ___pthread_self_462() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_pthread_self()|0);
 return ($0|0);
}
function _ungetc($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$1 = 0, $$pr = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($0|0)==(-1);
 do {
  if ($2) {
   $$1 = -1;
  } else {
   $3 = ((($1)) + 76|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = ($4|0)>(-1);
   if ($5) {
    $6 = (___lockfile($1)|0);
    $10 = $6;
   } else {
    $10 = 0;
   }
   $7 = ((($1)) + 4|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ($8|0)==(0|0);
   if ($9) {
    (___toread($1)|0);
    $$pr = HEAP32[$7>>2]|0;
    $12 = ($$pr|0)==(0|0);
    $13 = ($10|0)!=(0);
    if ($12) {
     $24 = $13;
    } else {
     $17 = $$pr;$23 = $13;
     label = 7;
    }
   } else {
    $11 = ($10|0)!=(0);
    $17 = $8;$23 = $11;
    label = 7;
   }
   if ((label|0) == 7) {
    $14 = ((($1)) + 44|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = ((($15)) + -8|0);
    $18 = ($17>>>0)>($16>>>0);
    if ($18) {
     $19 = $0&255;
     $20 = ((($17)) + -1|0);
     HEAP32[$7>>2] = $20;
     HEAP8[$20>>0] = $19;
     $21 = HEAP32[$1>>2]|0;
     $22 = $21 & -17;
     HEAP32[$1>>2] = $22;
     if (!($23)) {
      $$1 = $0;
      break;
     }
     ___unlockfile($1);
     $$1 = $0;
     break;
    } else {
     $24 = $23;
    }
   }
   if ($24) {
    ___unlockfile($1);
    $$1 = -1;
   } else {
    $$1 = -1;
   }
  }
 } while(0);
 return ($$1|0);
}
function _fwrite($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$ = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = Math_imul($2, $1)|0;
 $5 = ($1|0)==(0);
 $$ = $5 ? 0 : $2;
 $6 = ((($3)) + 76|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)>(-1);
 if ($8) {
  $10 = (___lockfile($3)|0);
  $phitmp = ($10|0)==(0);
  $11 = (___fwritex($0,$4,$3)|0);
  if ($phitmp) {
   $12 = $11;
  } else {
   ___unlockfile($3);
   $12 = $11;
  }
 } else {
  $9 = (___fwritex($0,$4,$3)|0);
  $12 = $9;
 }
 $13 = ($12|0)==($4|0);
 if ($13) {
  $15 = $$;
 } else {
  $14 = (($12>>>0) / ($1>>>0))&-1;
  $15 = $14;
 }
 return ($15|0);
}
function ___ftello_unlocked($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 40|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$0>>2]|0;
 $4 = $3 & 128;
 $5 = ($4|0)==(0);
 if ($5) {
  $11 = 1;
 } else {
  $6 = ((($0)) + 20|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ((($0)) + 28|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($7>>>0)>($9>>>0);
  $phitmp = $10 ? 2 : 1;
  $11 = $phitmp;
 }
 $12 = (FUNCTION_TABLE_iiii[$2 & 8191]($0,0,$11)|0);
 $13 = ($12|0)<(0);
 if ($13) {
  $$0 = $12;
 } else {
  $14 = ((($0)) + 8|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = ((($0)) + 4|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = ((($0)) + 20|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = ((($0)) + 28|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = (($12) - ($15))|0;
  $23 = (($22) + ($17))|0;
  $24 = (($23) + ($19))|0;
  $25 = (($24) - ($21))|0;
  $$0 = $25;
 }
 return ($$0|0);
}
function ___ftello($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 76|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)>(-1);
 if ($3) {
  $5 = (___lockfile($0)|0);
  $phitmp = ($5|0)==(0);
  $6 = (___ftello_unlocked($0)|0);
  if ($phitmp) {
   $7 = $6;
  } else {
   ___unlockfile($0);
   $7 = $6;
  }
 } else {
  $4 = (___ftello_unlocked($0)|0);
  $7 = $4;
 }
 return ($7|0);
}
function ___fdopen($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$pre = 0, $$pre31 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $memchr = 0, $vararg_buffer = 0, $vararg_buffer12 = 0, $vararg_buffer3 = 0, $vararg_buffer7 = 0, $vararg_ptr1 = 0, $vararg_ptr10 = 0, $vararg_ptr11 = 0, $vararg_ptr15 = 0, $vararg_ptr16 = 0, $vararg_ptr2 = 0, $vararg_ptr6 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(64|0);
 $vararg_buffer12 = sp + 40|0;
 $vararg_buffer7 = sp + 24|0;
 $vararg_buffer3 = sp + 16|0;
 $vararg_buffer = sp;
 $2 = sp + 56|0;
 $3 = HEAP8[$1>>0]|0;
 $4 = $3 << 24 >> 24;
 $memchr = (_memchr(201748,$4,4)|0);
 $5 = ($memchr|0)==(0|0);
 if ($5) {
  $6 = (___errno_location()|0);
  HEAP32[$6>>2] = 22;
  $$0 = 0;
 } else {
  $7 = (_malloc(1156)|0);
  $8 = ($7|0)==(0|0);
  if ($8) {
   $$0 = 0;
  } else {
   dest=$7; stop=dest+124|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
   $9 = (_strchr($1,43)|0);
   $10 = ($9|0)==(0|0);
   if ($10) {
    $11 = ($3<<24>>24)==(114);
    $12 = $11 ? 8 : 4;
    HEAP32[$7>>2] = $12;
   }
   $13 = (_strchr($1,101)|0);
   $14 = ($13|0)==(0|0);
   if ($14) {
    $15 = $3;
   } else {
    HEAP32[$vararg_buffer>>2] = $0;
    $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
    HEAP32[$vararg_ptr1>>2] = 2;
    $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
    HEAP32[$vararg_ptr2>>2] = 1;
    (___syscall221(221,($vararg_buffer|0))|0);
    $$pre = HEAP8[$1>>0]|0;
    $15 = $$pre;
   }
   $16 = ($15<<24>>24)==(97);
   if ($16) {
    HEAP32[$vararg_buffer3>>2] = $0;
    $vararg_ptr6 = ((($vararg_buffer3)) + 4|0);
    HEAP32[$vararg_ptr6>>2] = 3;
    $17 = (___syscall221(221,($vararg_buffer3|0))|0);
    $18 = $17 & 1024;
    $19 = ($18|0)==(0);
    if ($19) {
     $20 = $17 | 1024;
     HEAP32[$vararg_buffer7>>2] = $0;
     $vararg_ptr10 = ((($vararg_buffer7)) + 4|0);
     HEAP32[$vararg_ptr10>>2] = 4;
     $vararg_ptr11 = ((($vararg_buffer7)) + 8|0);
     HEAP32[$vararg_ptr11>>2] = $20;
     (___syscall221(221,($vararg_buffer7|0))|0);
    }
    $21 = HEAP32[$7>>2]|0;
    $22 = $21 | 128;
    HEAP32[$7>>2] = $22;
    $29 = $22;
   } else {
    $$pre31 = HEAP32[$7>>2]|0;
    $29 = $$pre31;
   }
   $23 = ((($7)) + 60|0);
   HEAP32[$23>>2] = $0;
   $24 = ((($7)) + 132|0);
   $25 = ((($7)) + 44|0);
   HEAP32[$25>>2] = $24;
   $26 = ((($7)) + 48|0);
   HEAP32[$26>>2] = 1024;
   $27 = ((($7)) + 75|0);
   HEAP8[$27>>0] = -1;
   $28 = $29 & 8;
   $30 = ($28|0)==(0);
   if ($30) {
    $31 = $2;
    HEAP32[$vararg_buffer12>>2] = $0;
    $vararg_ptr15 = ((($vararg_buffer12)) + 4|0);
    HEAP32[$vararg_ptr15>>2] = 21523;
    $vararg_ptr16 = ((($vararg_buffer12)) + 8|0);
    HEAP32[$vararg_ptr16>>2] = $31;
    $32 = (___syscall54(54,($vararg_buffer12|0))|0);
    $33 = ($32|0)==(0);
    if ($33) {
     HEAP8[$27>>0] = 10;
    }
   }
   $34 = ((($7)) + 32|0);
   HEAP32[$34>>2] = 2904;
   $35 = ((($7)) + 36|0);
   HEAP32[$35>>2] = 2905;
   $36 = ((($7)) + 40|0);
   HEAP32[$36>>2] = 2903;
   $37 = ((($7)) + 12|0);
   HEAP32[$37>>2] = 2901;
   $38 = HEAP32[(214024)>>2]|0;
   $39 = ($38|0)==(0);
   if ($39) {
    $40 = ((($7)) + 76|0);
    HEAP32[$40>>2] = -1;
   }
   $41 = (___ofl_add($7)|0);
   $$0 = $7;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function ___ofl_add($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (___ofl_lock()|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 56|0);
 HEAP32[$3>>2] = $2;
 $4 = HEAP32[$1>>2]|0;
 $5 = ($4|0)==(0|0);
 if (!($5)) {
  $6 = ((($4)) + 52|0);
  HEAP32[$6>>2] = $0;
 }
 HEAP32[$1>>2] = $0;
 ___ofl_unlock();
 return ($0|0);
}
function _sscanf($0,$1,$varargs) {
 $0 = $0|0;
 $1 = $1|0;
 $varargs = $varargs|0;
 var $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 HEAP32[$2>>2] = $varargs;
 $3 = (_vsscanf($0,$1,$2)|0);
 STACKTOP = sp;return ($3|0);
}
function _vsscanf($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(128|0);
 $3 = sp;
 dest=$3; stop=dest+124|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $4 = ((($3)) + 32|0);
 HEAP32[$4>>2] = 4658;
 $5 = ((($3)) + 44|0);
 HEAP32[$5>>2] = $0;
 $6 = ((($3)) + 76|0);
 HEAP32[$6>>2] = -1;
 $7 = ((($3)) + 84|0);
 HEAP32[$7>>2] = $0;
 $8 = (_vfscanf($3,$1,$2)|0);
 STACKTOP = sp;return ($8|0);
}
function _do_read_447($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (___string_read($0,$1,$2)|0);
 return ($3|0);
}
function ___string_read($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$027 = 0, $$027$ = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 84|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 256)|0;
 $6 = (_memchr($4,0,$5)|0);
 $7 = ($6|0)==(0|0);
 $8 = $6;
 $9 = $4;
 $10 = (($8) - ($9))|0;
 $$027 = $7 ? $5 : $10;
 $11 = ($$027>>>0)<($2>>>0);
 $$027$ = $11 ? $$027 : $2;
 _memcpy(($1|0),($4|0),($$027$|0))|0;
 $12 = (($4) + ($$027$)|0);
 $13 = ((($0)) + 4|0);
 HEAP32[$13>>2] = $12;
 $14 = (($4) + ($$027)|0);
 $15 = ((($0)) + 8|0);
 HEAP32[$15>>2] = $14;
 HEAP32[$3>>2] = $14;
 return ($$027$|0);
}
function _fprintf($0,$1,$varargs) {
 $0 = $0|0;
 $1 = $1|0;
 $varargs = $varargs|0;
 var $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 HEAP32[$2>>2] = $varargs;
 $3 = (_vfprintf($0,$1,$2)|0);
 STACKTOP = sp;return ($3|0);
}
function ___overflow($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$pre = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = $1&255;
 HEAP8[$2>>0] = $3;
 $4 = ((($0)) + 16|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $7 = (___towrite($0)|0);
  $8 = ($7|0)==(0);
  if ($8) {
   $$pre = HEAP32[$4>>2]|0;
   $12 = $$pre;
   label = 4;
  } else {
   $$0 = -1;
  }
 } else {
  $12 = $5;
  label = 4;
 }
 do {
  if ((label|0) == 4) {
   $9 = ((($0)) + 20|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($10>>>0)<($12>>>0);
   if ($11) {
    $13 = $1 & 255;
    $14 = ((($0)) + 75|0);
    $15 = HEAP8[$14>>0]|0;
    $16 = $15 << 24 >> 24;
    $17 = ($13|0)==($16|0);
    if (!($17)) {
     $18 = ((($10)) + 1|0);
     HEAP32[$9>>2] = $18;
     HEAP8[$10>>0] = $3;
     $$0 = $13;
     break;
    }
   }
   $19 = ((($0)) + 36|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (FUNCTION_TABLE_iiii[$20 & 8191]($0,$2,1)|0);
   $22 = ($21|0)==(1);
   if ($22) {
    $23 = HEAP8[$2>>0]|0;
    $24 = $23&255;
    $$0 = $24;
   } else {
    $$0 = -1;
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function _fgets($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$06266 = 0, $$063 = 0, $$064 = 0, $$1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond3 = 0;
 var $sext$mask = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($2)) + 76|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)>(-1);
 if ($5) {
  $6 = (___lockfile($2)|0);
  $16 = $6;
 } else {
  $16 = 0;
 }
 $7 = (($1) + -1)|0;
 $8 = ($1|0)<(2);
 $9 = ($7|0)!=(0);
 if ($8) {
  $10 = ((($2)) + 74|0);
  $11 = HEAP8[$10>>0]|0;
  $12 = $11 << 24 >> 24;
  $13 = (($12) + 255)|0;
  $14 = $13 | $12;
  $15 = $14&255;
  HEAP8[$10>>0] = $15;
  $17 = ($16|0)==(0);
  if (!($17)) {
   ___unlockfile($2);
  }
  if ($9) {
   $$0 = 0;
  } else {
   HEAP8[$0>>0] = 0;
   $$0 = $0;
  }
 } else {
  L11: do {
   if ($9) {
    $18 = ((($2)) + 4|0);
    $19 = ((($2)) + 8|0);
    $$063 = $7;$$064 = $0;
    while(1) {
     $20 = HEAP32[$18>>2]|0;
     $21 = HEAP32[$19>>2]|0;
     $22 = $20;
     $23 = (($21) - ($22))|0;
     $24 = (_memchr($20,10,$23)|0);
     $25 = ($24|0)==(0|0);
     $26 = $24;
     $27 = (1 - ($22))|0;
     $28 = (($27) + ($26))|0;
     $29 = $25 ? $23 : $28;
     $30 = ($29>>>0)<($$063>>>0);
     $31 = $30 ? $29 : $$063;
     _memcpy(($$064|0),($20|0),($31|0))|0;
     $32 = HEAP32[$18>>2]|0;
     $33 = (($32) + ($31)|0);
     HEAP32[$18>>2] = $33;
     $34 = (($$064) + ($31)|0);
     $35 = (($$063) - ($31))|0;
     $36 = ($35|0)!=(0);
     $or$cond = $25 & $36;
     if (!($or$cond)) {
      $$1 = $34;
      label = 17;
      break L11;
     }
     $37 = HEAP32[$19>>2]|0;
     $38 = ($33>>>0)<($37>>>0);
     if ($38) {
      $39 = ((($33)) + 1|0);
      HEAP32[$18>>2] = $39;
      $40 = HEAP8[$33>>0]|0;
      $41 = $40&255;
      $50 = $41;
     } else {
      $42 = (___uflow($2)|0);
      $43 = ($42|0)<(0);
      if ($43) {
       break;
      } else {
       $50 = $42;
      }
     }
     $48 = (($35) + -1)|0;
     $49 = $50&255;
     $51 = ((($34)) + 1|0);
     HEAP8[$34>>0] = $49;
     $sext$mask = $50 & 255;
     $52 = ($sext$mask|0)!=(10);
     $53 = ($48|0)!=(0);
     $or$cond3 = $53 & $52;
     if ($or$cond3) {
      $$063 = $48;$$064 = $51;
     } else {
      $$1 = $51;
      label = 17;
      break L11;
     }
    }
    $44 = ($34|0)==($0|0);
    if ($44) {
     $$06266 = 0;
    } else {
     $45 = HEAP32[$2>>2]|0;
     $46 = $45 & 16;
     $47 = ($46|0)==(0);
     if ($47) {
      $$06266 = 0;
     } else {
      $$1 = $34;
      label = 17;
     }
    }
   } else {
    $$1 = $0;
    label = 17;
   }
  } while(0);
  if ((label|0) == 17) {
   $54 = ($0|0)==(0|0);
   if ($54) {
    $$06266 = 0;
   } else {
    HEAP8[$$1>>0] = 0;
    $$06266 = $0;
   }
  }
  $55 = ($16|0)==(0);
  if ($55) {
   $$0 = $$06266;
  } else {
   ___unlockfile($2);
   $$0 = $$06266;
  }
 }
 return ($$0|0);
}
function ___fseeko($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 76|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)>(-1);
 if ($5) {
  $7 = (___lockfile($0)|0);
  $phitmp = ($7|0)==(0);
  $8 = (___fseeko_unlocked($0,$1,$2)|0);
  if ($phitmp) {
   $9 = $8;
  } else {
   ___unlockfile($0);
   $9 = $8;
  }
 } else {
  $6 = (___fseeko_unlocked($0,$1,$2)|0);
  $9 = $6;
 }
 return ($9|0);
}
function _vasprintf($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vacopy_currentptr = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $vacopy_currentptr = HEAP32[$2>>2]|0;
 HEAP32[$3>>2] = $vacopy_currentptr;
 $4 = (_vsnprintf(0,0,$1,$3)|0);
 $5 = ($4|0)<(0);
 if ($5) {
  $$0 = -1;
 } else {
  $6 = (($4) + 1)|0;
  $7 = (_malloc($6)|0);
  HEAP32[$0>>2] = $7;
  $8 = ($7|0)==(0|0);
  if ($8) {
   $$0 = -1;
  } else {
   $9 = (_vsnprintf($7,$6,$1,$2)|0);
   $$0 = $9;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function _fputc($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)<(0);
 $5 = $0&255;
 $6 = $0 & 255;
 if ($4) {
  label = 3;
 } else {
  $7 = (___lockfile($1)|0);
  $8 = ($7|0)==(0);
  if ($8) {
   label = 3;
  } else {
   $20 = ((($1)) + 75|0);
   $21 = HEAP8[$20>>0]|0;
   $22 = $21 << 24 >> 24;
   $23 = ($6|0)==($22|0);
   if ($23) {
    label = 10;
   } else {
    $24 = ((($1)) + 20|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = ((($1)) + 16|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = ($25>>>0)<($27>>>0);
    if ($28) {
     $29 = ((($25)) + 1|0);
     HEAP32[$24>>2] = $29;
     HEAP8[$25>>0] = $5;
     $31 = $6;
    } else {
     label = 10;
    }
   }
   if ((label|0) == 10) {
    $30 = (___overflow($1,$0)|0);
    $31 = $30;
   }
   ___unlockfile($1);
   $$0 = $31;
  }
 }
 do {
  if ((label|0) == 3) {
   $9 = ((($1)) + 75|0);
   $10 = HEAP8[$9>>0]|0;
   $11 = $10 << 24 >> 24;
   $12 = ($6|0)==($11|0);
   if (!($12)) {
    $13 = ((($1)) + 20|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ((($1)) + 16|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = ($14>>>0)<($16>>>0);
    if ($17) {
     $18 = ((($14)) + 1|0);
     HEAP32[$13>>2] = $18;
     HEAP8[$14>>0] = $5;
     $$0 = $6;
     break;
    }
   }
   $19 = (___overflow($1,$0)|0);
   $$0 = $19;
  }
 } while(0);
 return ($$0|0);
}
function _ferror($0) {
 $0 = $0|0;
 var $$lobit = 0, $$lobit8 = 0, $$lobit9 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 76|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)>(-1);
 if ($3) {
  $6 = (___lockfile($0)|0);
  $phitmp = ($6|0)==(0);
  $7 = HEAP32[$0>>2]|0;
  $8 = $7 >>> 5;
  $$lobit = $8 & 1;
  if ($phitmp) {
   $$lobit9 = $$lobit;
  } else {
   ___unlockfile($0);
   $$lobit9 = $$lobit;
  }
 } else {
  $4 = HEAP32[$0>>2]|0;
  $5 = $4 >>> 5;
  $$lobit8 = $5 & 1;
  $$lobit9 = $$lobit8;
 }
 return ($$lobit9|0);
}
function _fread($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$ = 0, $$0 = 0, $$054$ph = 0, $$05460 = 0, $$056$ph = 0, $$05659 = 0, $$57 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = Math_imul($2, $1)|0;
 $5 = ($1|0)==(0);
 $$ = $5 ? 0 : $2;
 $6 = ((($3)) + 76|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)>(-1);
 if ($8) {
  $9 = (___lockfile($3)|0);
  $35 = $9;
 } else {
  $35 = 0;
 }
 $10 = ((($3)) + 74|0);
 $11 = HEAP8[$10>>0]|0;
 $12 = $11 << 24 >> 24;
 $13 = (($12) + 255)|0;
 $14 = $13 | $12;
 $15 = $14&255;
 HEAP8[$10>>0] = $15;
 $16 = ((($3)) + 8|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ((($3)) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = $19;
 $21 = (($17) - ($20))|0;
 $22 = ($21|0)>(0);
 $23 = ($21>>>0)<($4>>>0);
 $$57 = $23 ? $21 : $4;
 if ($22) {
  $24 = (($4) - ($$57))|0;
  $25 = (($0) + ($$57)|0);
  _memcpy(($0|0),($19|0),($$57|0))|0;
  $26 = (($19) + ($$57)|0);
  HEAP32[$18>>2] = $26;
  $$054$ph = $24;$$056$ph = $25;
 } else {
  $$054$ph = $4;$$056$ph = $0;
 }
 $27 = ($$054$ph|0)==(0);
 L7: do {
  if ($27) {
   label = 13;
  } else {
   $28 = ((($3)) + 32|0);
   $$05460 = $$054$ph;$$05659 = $$056$ph;
   while(1) {
    $29 = (___toread($3)|0);
    $30 = ($29|0)==(0);
    if (!($30)) {
     break;
    }
    $31 = HEAP32[$28>>2]|0;
    $32 = (FUNCTION_TABLE_iiii[$31 & 8191]($3,$$05659,$$05460)|0);
    $33 = (($32) + 1)|0;
    $34 = ($33>>>0)<(2);
    if ($34) {
     break;
    }
    $39 = (($$05460) - ($32))|0;
    $40 = (($$05659) + ($32)|0);
    $41 = ($39|0)==(0);
    if ($41) {
     label = 13;
     break L7;
    } else {
     $$05460 = $39;$$05659 = $40;
    }
   }
   $36 = ($35|0)==(0);
   if (!($36)) {
    ___unlockfile($3);
   }
   $37 = (($4) - ($$05460))|0;
   $38 = (($37>>>0) / ($1>>>0))&-1;
   $$0 = $38;
  }
 } while(0);
 if ((label|0) == 13) {
  $42 = ($35|0)==(0);
  if ($42) {
   $$0 = $$;
  } else {
   ___unlockfile($3);
   $$0 = $$;
  }
 }
 return ($$0|0);
}
function _fputs($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $not$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_strlen($0)|0);
 $3 = (_fwrite($0,1,$2,$1)|0);
 $not$ = ($3|0)!=($2|0);
 $4 = $not$ << 31 >> 31;
 return ($4|0);
}
function _getc($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 76|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)<(0);
 if ($3) {
  label = 3;
 } else {
  $4 = (___lockfile($0)|0);
  $5 = ($4|0)==(0);
  if ($5) {
   label = 3;
  } else {
   $15 = ((($0)) + 4|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ((($0)) + 8|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = ($16>>>0)<($18>>>0);
   if ($19) {
    $20 = ((($16)) + 1|0);
    HEAP32[$15>>2] = $20;
    $21 = HEAP8[$16>>0]|0;
    $22 = $21&255;
    $24 = $22;
   } else {
    $23 = (___uflow($0)|0);
    $24 = $23;
   }
   $$0 = $24;
  }
 }
 do {
  if ((label|0) == 3) {
   $6 = ((($0)) + 4|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ((($0)) + 8|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = ($7>>>0)<($9>>>0);
   if ($10) {
    $11 = ((($7)) + 1|0);
    HEAP32[$6>>2] = $11;
    $12 = HEAP8[$7>>0]|0;
    $13 = $12&255;
    $$0 = $13;
    break;
   } else {
    $14 = (___uflow($0)|0);
    $$0 = $14;
    break;
   }
  }
 } while(0);
 return ($$0|0);
}
function ___fmodeflags($0) {
 $0 = $0|0;
 var $$ = 0, $$$4 = 0, $$0 = 0, $$0$ = 0, $$2 = 0, $$2$ = 0, $$4 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $not$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (_strchr($0,43)|0);
 $2 = ($1|0)==(0|0);
 $3 = HEAP8[$0>>0]|0;
 $not$ = ($3<<24>>24)!=(114);
 $$ = $not$&1;
 $$0 = $2 ? $$ : 2;
 $4 = (_strchr($0,120)|0);
 $5 = ($4|0)==(0|0);
 $6 = $$0 | 128;
 $$0$ = $5 ? $$0 : $6;
 $7 = (_strchr($0,101)|0);
 $8 = ($7|0)==(0|0);
 $9 = $$0$ | 524288;
 $$2 = $8 ? $$0$ : $9;
 $10 = ($3<<24>>24)==(114);
 $11 = $$2 | 64;
 $$2$ = $10 ? $$2 : $11;
 $12 = ($3<<24>>24)==(119);
 $13 = $$2$ | 512;
 $$4 = $12 ? $13 : $$2$;
 $14 = ($3<<24>>24)==(97);
 $15 = $$4 | 1024;
 $$$4 = $14 ? $15 : $$4;
 return ($$$4|0);
}
function _fopen($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $memchr = 0, $vararg_buffer = 0, $vararg_buffer3 = 0, $vararg_buffer8 = 0, $vararg_ptr1 = 0;
 var $vararg_ptr2 = 0, $vararg_ptr6 = 0, $vararg_ptr7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $vararg_buffer8 = sp + 32|0;
 $vararg_buffer3 = sp + 16|0;
 $vararg_buffer = sp;
 $2 = HEAP8[$1>>0]|0;
 $3 = $2 << 24 >> 24;
 $memchr = (_memchr(201748,$3,4)|0);
 $4 = ($memchr|0)==(0|0);
 if ($4) {
  $5 = (___errno_location()|0);
  HEAP32[$5>>2] = 22;
  $$0 = 0;
 } else {
  $6 = (___fmodeflags($1)|0);
  $7 = $0;
  $8 = $6 | 32768;
  HEAP32[$vararg_buffer>>2] = $7;
  $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
  HEAP32[$vararg_ptr1>>2] = $8;
  $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
  HEAP32[$vararg_ptr2>>2] = 438;
  $9 = (___syscall5(5,($vararg_buffer|0))|0);
  $10 = (___syscall_ret($9)|0);
  $11 = ($10|0)<(0);
  if ($11) {
   $$0 = 0;
  } else {
   $12 = $6 & 524288;
   $13 = ($12|0)==(0);
   if (!($13)) {
    HEAP32[$vararg_buffer3>>2] = $10;
    $vararg_ptr6 = ((($vararg_buffer3)) + 4|0);
    HEAP32[$vararg_ptr6>>2] = 2;
    $vararg_ptr7 = ((($vararg_buffer3)) + 8|0);
    HEAP32[$vararg_ptr7>>2] = 1;
    (___syscall221(221,($vararg_buffer3|0))|0);
   }
   $14 = (___fdopen($10,$1)|0);
   $15 = ($14|0)==(0|0);
   if ($15) {
    HEAP32[$vararg_buffer8>>2] = $10;
    (___syscall6(6,($vararg_buffer8|0))|0);
    $$0 = 0;
   } else {
    $$0 = $14;
   }
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function _printf($0,$varargs) {
 $0 = $0|0;
 $varargs = $varargs|0;
 var $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 HEAP32[$1>>2] = $varargs;
 $2 = HEAP32[23026]|0;
 $3 = (_vfprintf($2,$0,$1)|0);
 STACKTOP = sp;return ($3|0);
}
function ___loc_is_allocated($0) {
 $0 = $0|0;
 var $$ = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ($0|0)!=(0|0);
 $2 = ($0|0)!=(214084|0);
 $or$cond = $1 & $2;
 $3 = ($0|0)!=(92784|0);
 $$ = $3 & $or$cond;
 $4 = $$&1;
 return ($4|0);
}
function ___newlocale($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$033$ = 0, $$03339 = 0, $$03440 = 0, $$036 = 0, $$13538 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $brmerge = 0, $exitcond = 0, $exitcond41 = 0, $not$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $3 = sp;
 $4 = (___loc_is_allocated($2)|0);
 $5 = ($4|0)==(0);
 L1: do {
  if ($5) {
   $6 = ($2|0)==(0|0);
   $$03339 = 0;$$13538 = 0;
   while(1) {
    $13 = 1 << $$13538;
    $14 = $13 & $0;
    $15 = ($14|0)!=(0);
    $brmerge = $6 | $15;
    if ($brmerge) {
     $18 = $15 ? $1 : 221531;
     $19 = (___get_locale($$13538,$18)|0);
     $$0 = $19;
    } else {
     $16 = (($2) + ($$13538<<2)|0);
     $17 = HEAP32[$16>>2]|0;
     $$0 = $17;
    }
    $not$ = ($$0|0)!=(0|0);
    $20 = $not$&1;
    $$033$ = (($20) + ($$03339))|0;
    $21 = (($3) + ($$13538<<2)|0);
    HEAP32[$21>>2] = $$0;
    $22 = (($$13538) + 1)|0;
    $exitcond = ($22|0)==(6);
    if ($exitcond) {
     break;
    } else {
     $$03339 = $$033$;$$13538 = $22;
    }
   }
   switch ($$033$|0) {
   case 0:  {
    $$036 = 214084;
    break L1;
    break;
   }
   case 1:  {
    $23 = HEAP32[$3>>2]|0;
    $24 = ($23|0)==(92736|0);
    if ($24) {
     $$036 = 92784;
     break L1;
    }
    break;
   }
   default: {
   }
   }
   $$036 = $2;
  } else {
   $$03440 = 0;
   while(1) {
    $7 = 1 << $$03440;
    $8 = $7 & $0;
    $9 = ($8|0)==(0);
    if (!($9)) {
     $10 = (($2) + ($$03440<<2)|0);
     $11 = (___get_locale($$03440,$1)|0);
     HEAP32[$10>>2] = $11;
    }
    $12 = (($$03440) + 1)|0;
    $exitcond41 = ($12|0)==(6);
    if ($exitcond41) {
     $$036 = $2;
     break;
    } else {
     $$03440 = $12;
    }
   }
  }
 } while(0);
 STACKTOP = sp;return ($$036|0);
}
function ___get_locale($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$093$lcssa = 0, $$093118 = 0, $$094114 = 0, $$1 = 0, $$1100111 = 0, $$195112 = 0, $$2122 = 0, $$2123 = 0, $$2124 = 0, $$4 = 0, $$neg = 0, $$pre121 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__c_dot_utf8$$4 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 272|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(272|0);
 $2 = sp + 8|0;
 $3 = sp;
 $4 = HEAP8[$1>>0]|0;
 $5 = ($4<<24>>24)==(0);
 do {
  if ($5) {
   $6 = (_getenv((201752|0))|0);
   $7 = ($6|0)==(0|0);
   if (!($7)) {
    $8 = HEAP8[$6>>0]|0;
    $9 = ($8<<24>>24)==(0);
    if (!($9)) {
     $$1 = $6;
     break;
    }
   }
   $10 = (201759 + (($0*12)|0)|0);
   $11 = (_getenv(($10|0))|0);
   $12 = ($11|0)==(0|0);
   if (!($12)) {
    $13 = HEAP8[$11>>0]|0;
    $14 = ($13<<24>>24)==(0);
    if (!($14)) {
     $$1 = $11;
     break;
    }
   }
   $15 = (_getenv((201831|0))|0);
   $16 = ($15|0)==(0|0);
   if (!($16)) {
    $17 = HEAP8[$15>>0]|0;
    $18 = ($17<<24>>24)==(0);
    if (!($18)) {
     $$1 = $15;
     break;
    }
   }
   $$1 = 201836;
  } else {
   $$1 = $1;
  }
 } while(0);
 $$093118 = 0;
 L13: while(1) {
  $19 = (($$1) + ($$093118)|0);
  $20 = HEAP8[$19>>0]|0;
  switch ($20<<24>>24) {
  case 47: case 0:  {
   $$093$lcssa = $$093118;
   break L13;
   break;
  }
  default: {
  }
  }
  $21 = (($$093118) + 1)|0;
  $22 = ($21>>>0)<(15);
  if ($22) {
   $$093118 = $21;
  } else {
   $$093$lcssa = $21;
   break;
  }
 }
 $23 = HEAP8[$$1>>0]|0;
 $24 = ($23<<24>>24)==(46);
 if ($24) {
  $$2122 = 201836;
  label = 15;
 } else {
  $25 = (($$1) + ($$093$lcssa)|0);
  $26 = HEAP8[$25>>0]|0;
  $27 = ($26<<24>>24)==(0);
  if ($27) {
   $28 = ($23<<24>>24)==(67);
   if ($28) {
    $$2122 = $$1;
    label = 15;
   } else {
    $$2123 = $$1;
    label = 16;
   }
  } else {
   $$2122 = 201836;
   label = 15;
  }
 }
 if ((label|0) == 15) {
  $29 = ((($$2122)) + 1|0);
  $30 = HEAP8[$29>>0]|0;
  $31 = ($30<<24>>24)==(0);
  if ($31) {
   $$2124 = $$2122;
   label = 18;
  } else {
   $$2123 = $$2122;
   label = 16;
  }
 }
 L22: do {
  if ((label|0) == 16) {
   $32 = (_strcmp($$2123,201836)|0);
   $33 = ($32|0)==(0);
   if ($33) {
    $$2124 = $$2123;
    label = 18;
   } else {
    $34 = (_strcmp($$2123,201844)|0);
    $35 = ($34|0)==(0);
    if ($35) {
     $$2124 = $$2123;
     label = 18;
    } else {
     $40 = HEAP32[53532]|0;
     $41 = ($40|0)==(0|0);
     if (!($41)) {
      $$094114 = $40;
      while(1) {
       $42 = ((($$094114)) + 8|0);
       $43 = (_strcmp($$2123,$42)|0);
       $44 = ($43|0)==(0);
       if ($44) {
        $$0 = $$094114;
        break L22;
       }
       $45 = ((($$094114)) + 24|0);
       $46 = HEAP32[$45>>2]|0;
       $47 = ($46|0)==(0|0);
       if ($47) {
        break;
       } else {
        $$094114 = $46;
       }
      }
     }
     ___lock((214132|0));
     $48 = HEAP32[53532]|0;
     $49 = ($48|0)==(0|0);
     L32: do {
      if (!($49)) {
       $$195112 = $48;
       while(1) {
        $50 = ((($$195112)) + 8|0);
        $51 = (_strcmp($$2123,$50)|0);
        $52 = ($51|0)==(0);
        if ($52) {
         break;
        }
        $53 = ((($$195112)) + 24|0);
        $54 = HEAP32[$53>>2]|0;
        $55 = ($54|0)==(0|0);
        if ($55) {
         break L32;
        } else {
         $$195112 = $54;
        }
       }
       ___unlock((214132|0));
       $$0 = $$195112;
       break L22;
      }
     } while(0);
     $56 = HEAP32[(214028)>>2]|0;
     $57 = ($56|0)==(0);
     L39: do {
      if ($57) {
       $58 = (_getenv((201850|0))|0);
       $59 = ($58|0)==(0|0);
       if ($59) {
        label = 41;
       } else {
        $60 = HEAP8[$58>>0]|0;
        $61 = ($60<<24>>24)==(0);
        if ($61) {
         label = 41;
        } else {
         $62 = (254 - ($$093$lcssa))|0;
         $63 = (($$093$lcssa) + 1)|0;
         $$1100111 = $58;
         while(1) {
          $64 = (___strchrnul($$1100111,58)|0);
          $65 = $64;
          $66 = $$1100111;
          $67 = (($65) - ($66))|0;
          $68 = HEAP8[$64>>0]|0;
          $69 = ($68<<24>>24)!=(0);
          $$neg = $69 << 31 >> 31;
          $70 = (($$neg) + ($67))|0;
          $71 = ($70>>>0)<($62>>>0);
          if ($71) {
           _memcpy(($2|0),($$1100111|0),($70|0))|0;
           $72 = (($2) + ($70)|0);
           HEAP8[$72>>0] = 47;
           $73 = ((($72)) + 1|0);
           _memcpy(($73|0),($$2123|0),($$093$lcssa|0))|0;
           $74 = (($63) + ($70))|0;
           $75 = (($2) + ($74)|0);
           HEAP8[$75>>0] = 0;
           $76 = (___map_file(($2|0),($3|0))|0);
           $77 = ($76|0)==(0|0);
           if (!($77)) {
            break;
           }
           $$pre121 = HEAP8[$64>>0]|0;
           $86 = $$pre121;
          } else {
           $86 = $68;
          }
          $87 = ($86<<24>>24)!=(0);
          $88 = $87&1;
          $89 = (($64) + ($88)|0);
          $90 = HEAP8[$89>>0]|0;
          $91 = ($90<<24>>24)==(0);
          if ($91) {
           label = 41;
           break L39;
          } else {
           $$1100111 = $89;
          }
         }
         $78 = (_malloc(28)|0);
         $79 = ($78|0)==(0|0);
         $80 = HEAP32[$3>>2]|0;
         if ($79) {
          (___munmap($76,$80)|0);
          label = 41;
          break;
         } else {
          HEAP32[$78>>2] = $76;
          $81 = ((($78)) + 4|0);
          HEAP32[$81>>2] = $80;
          $82 = ((($78)) + 8|0);
          _memcpy(($82|0),($$2123|0),($$093$lcssa|0))|0;
          $83 = (($82) + ($$093$lcssa)|0);
          HEAP8[$83>>0] = 0;
          $84 = HEAP32[53532]|0;
          $85 = ((($78)) + 24|0);
          HEAP32[$85>>2] = $84;
          HEAP32[53532] = $78;
          $$4 = $78;
          break;
         }
        }
       }
      } else {
       label = 41;
      }
     } while(0);
     if ((label|0) == 41) {
      $92 = (_malloc(28)|0);
      $93 = ($92|0)==(0|0);
      if ($93) {
       $$4 = $92;
      } else {
       $94 = HEAP32[23184]|0;
       HEAP32[$92>>2] = $94;
       $95 = HEAP32[(92740)>>2]|0;
       $96 = ((($92)) + 4|0);
       HEAP32[$96>>2] = $95;
       $97 = ((($92)) + 8|0);
       _memcpy(($97|0),($$2123|0),($$093$lcssa|0))|0;
       $98 = (($97) + ($$093$lcssa)|0);
       HEAP8[$98>>0] = 0;
       $99 = HEAP32[53532]|0;
       $100 = ((($92)) + 24|0);
       HEAP32[$100>>2] = $99;
       HEAP32[53532] = $92;
       $$4 = $92;
      }
     }
     $101 = ($$4|0)==(0|0);
     $102 = ($0|0)==(0);
     $or$cond = $102 & $101;
     $__c_dot_utf8$$4 = $or$cond ? 92736 : $$4;
     ___unlock((214132|0));
     $$0 = $__c_dot_utf8$$4;
    }
   }
  }
 } while(0);
 do {
  if ((label|0) == 18) {
   $36 = ($0|0)==(0);
   if ($36) {
    $37 = ((($$2124)) + 1|0);
    $38 = HEAP8[$37>>0]|0;
    $39 = ($38<<24>>24)==(46);
    if ($39) {
     $$0 = 92736;
     break;
    }
   }
   $$0 = 0;
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function ___uselocale($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (___pthread_self_598()|0);
 $2 = ((($1)) + 188|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($0|0)==(0|0);
 if (!($4)) {
  $5 = ($0|0)==((-1)|0);
  $6 = $5 ? (214060) : $0;
  HEAP32[$2>>2] = $6;
 }
 $7 = ($3|0)==((214060)|0);
 $8 = $7 ? (-1) : $3;
 return ($8|0);
}
function ___pthread_self_598() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_pthread_self()|0);
 return ($0|0);
}
function _catclose($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function _catopen($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ((-1)|0);
}
function _catgets($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ($3|0);
}
function _isxdigit_l($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_isxdigit($0)|0);
 return ($2|0);
}
function _freelocale($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (___loc_is_allocated($0)|0);
 $2 = ($1|0)==(0);
 if (!($2)) {
  _free($0);
 }
 return;
}
function _isdigit_l($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $isdigit = 0, $isdigittmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $isdigittmp = (($0) + -48)|0;
 $isdigit = ($isdigittmp>>>0)<(10);
 $2 = $isdigit&1;
 return ($2|0);
}
function _realpath($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer2 = 0, $vararg_buffer5 = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 4304|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(4304|0);
 $vararg_buffer5 = sp + 16|0;
 $vararg_buffer2 = sp + 8|0;
 $vararg_buffer = sp;
 $2 = sp + 96|0;
 $3 = sp + 20|0;
 $4 = sp + 4272|0;
 $5 = sp + 176|0;
 $6 = ($0|0)==(0|0);
 do {
  if ($6) {
   $7 = (___errno_location()|0);
   HEAP32[$7>>2] = 22;
   $$0 = 0;
  } else {
   $8 = $0;
   HEAP32[$vararg_buffer>>2] = $8;
   $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
   HEAP32[$vararg_ptr1>>2] = 2656256;
   $9 = (___syscall5(5,($vararg_buffer|0))|0);
   $10 = (___syscall_ret($9)|0);
   $11 = ($10|0)<(0);
   if ($11) {
    $$0 = 0;
   } else {
    ___procfdname($4,$10);
    $12 = (_readlink($4,$5,4095)|0);
    $13 = ($12|0)<(0);
    if (!($13)) {
     $14 = (($5) + ($12)|0);
     HEAP8[$14>>0] = 0;
     (_fstat($10,$2)|0);
     $15 = (_stat($5,$3)|0);
     $16 = ($15|0)<(0);
     if (!($16)) {
      $17 = HEAP32[$2>>2]|0;
      $18 = HEAP32[$3>>2]|0;
      $19 = ($17|0)==($18|0);
      if ($19) {
       $20 = ((($2)) + 72|0);
       $21 = HEAP32[$20>>2]|0;
       $22 = ((($3)) + 72|0);
       $23 = HEAP32[$22>>2]|0;
       $24 = ($21|0)==($23|0);
       if ($24) {
        HEAP32[$vararg_buffer2>>2] = $10;
        (___syscall6(6,($vararg_buffer2|0))|0);
        $27 = ($1|0)==(0|0);
        if ($27) {
         $29 = (___strdup($5)|0);
         $$0 = $29;
         break;
        } else {
         $28 = (_strcpy($1,$5)|0);
         $$0 = $1;
         break;
        }
       }
      }
      $25 = ($15|0)==(0);
      if ($25) {
       $26 = (___errno_location()|0);
       HEAP32[$26>>2] = 40;
      }
     }
    }
    HEAP32[$vararg_buffer5>>2] = $10;
    (___syscall6(6,($vararg_buffer5|0))|0);
    $$0 = 0;
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function __ZNSt3__26__sortIRNS_6__lessIiiEEPiEEvT0_S5_T_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$$0174 = 0, $$0 = 0, $$0$ph = 0, $$0154 = 0, $$0160 = 0, $$0167 = 0, $$0174 = 0, $$0180$ph = 0, $$1 = 0, $$1155 = 0, $$1161 = 0, $$2156 = 0, $$2162 = 0, $$2176 = 0, $$3157 = 0, $$3163 = 0, $$3170 = 0, $$4158 = 0, $$4164 = 0, $$4171 = 0;
 var $$5159 = 0, $$5165 = 0, $$5172 = 0, $$6166 = 0, $$6173 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$0$ph = $0;$$0180$ph = $1;
 L1: while(1) {
  $3 = $$0180$ph;
  $4 = ((($$0180$ph)) + -4|0);
  $$0 = $$0$ph;
  while(1) {
   $$1 = $$0;
   L5: while(1) {
    $5 = $$1;
    $6 = (($3) - ($5))|0;
    $7 = $6 >> 2;
    $8 = ((($$1)) + 4|0);
    switch ($7|0) {
    case 1: case 0:  {
     break L1;
     break;
    }
    case 2:  {
     label = 5;
     break L1;
     break;
    }
    case 3:  {
     label = 7;
     break L1;
     break;
    }
    case 4:  {
     label = 8;
     break L1;
     break;
    }
    case 5:  {
     label = 9;
     break L1;
     break;
    }
    default: {
    }
    }
    $15 = ($6|0)<(124);
    if ($15) {
     label = 11;
     break L1;
    }
    $16 = ($6|0)>(3996);
    $17 = (($7|0) / 2)&-1;
    $18 = (($$1) + ($17<<2)|0);
    if ($16) {
     $19 = (($7|0) / 4)&-1;
     $20 = (($$1) + ($19<<2)|0);
     $21 = (($18) + ($19<<2)|0);
     $22 = (__ZNSt3__27__sort5IRNS_6__lessIiiEEPiEEjT0_S5_S5_S5_S5_T_($$1,$20,$18,$21,$4,$2)|0);
     $$0167 = $22;
    } else {
     $23 = (__ZNSt3__27__sort3IRNS_6__lessIiiEEPiEEjT0_S5_S5_T_($$1,$18,$4,$2)|0);
     $$0167 = $23;
    }
    $24 = HEAP32[$$1>>2]|0;
    $25 = HEAP32[$18>>2]|0;
    $26 = ($24|0)<($25|0);
    if ($26) {
     $$3157 = $4;$$3170 = $$0167;
     break;
    } else {
     $$0154 = $4;
    }
    while(1) {
     $27 = ((($$0154)) + -4|0);
     $28 = ($$1|0)==($27|0);
     if ($28) {
      break;
     }
     $44 = HEAP32[$27>>2]|0;
     $45 = ($44|0)<($25|0);
     if ($45) {
      label = 28;
      break L5;
     } else {
      $$0154 = $27;
     }
    }
    $29 = HEAP32[$4>>2]|0;
    $30 = ($24|0)<($29|0);
    if ($30) {
     $$1161 = $8;
    } else {
     $$0160 = $8;
     while(1) {
      $31 = ($$0160|0)==($4|0);
      if ($31) {
       break L1;
      }
      $32 = HEAP32[$$0160>>2]|0;
      $33 = ($24|0)<($32|0);
      $34 = ((($$0160)) + 4|0);
      if ($33) {
       break;
      } else {
       $$0160 = $34;
      }
     }
     HEAP32[$$0160>>2] = $29;
     HEAP32[$4>>2] = $32;
     $$1161 = $34;
    }
    $35 = ($$1161|0)==($4|0);
    if ($35) {
     break L1;
    } else {
     $$1155 = $4;$$2162 = $$1161;
    }
    while(1) {
     $36 = HEAP32[$$1>>2]|0;
     $$3163 = $$2162;
     while(1) {
      $37 = HEAP32[$$3163>>2]|0;
      $38 = ($36|0)<($37|0);
      $39 = ((($$3163)) + 4|0);
      if ($38) {
       $$2156 = $$1155;
       break;
      } else {
       $$3163 = $39;
      }
     }
     while(1) {
      $40 = ((($$2156)) + -4|0);
      $41 = HEAP32[$40>>2]|0;
      $42 = ($36|0)<($41|0);
      if ($42) {
       $$2156 = $40;
      } else {
       break;
      }
     }
     $43 = ($$3163>>>0)<($40>>>0);
     if (!($43)) {
      $$1 = $$3163;
      continue L5;
     }
     HEAP32[$$3163>>2] = $41;
     HEAP32[$40>>2] = $37;
     $$1155 = $40;$$2162 = $39;
    }
   }
   if ((label|0) == 28) {
    label = 0;
    $46 = (($$0167) + 1)|0;
    HEAP32[$$1>>2] = $44;
    HEAP32[$27>>2] = $24;
    $$3157 = $27;$$3170 = $46;
   }
   $47 = ($8>>>0)<($$3157>>>0);
   L34: do {
    if ($47) {
     $$0174 = $18;$$4158 = $$3157;$$4164 = $8;$$4171 = $$3170;
     while(1) {
      $48 = HEAP32[$$0174>>2]|0;
      $$5165 = $$4164;
      while(1) {
       $49 = HEAP32[$$5165>>2]|0;
       $50 = ($49|0)<($48|0);
       $51 = ((($$5165)) + 4|0);
       if ($50) {
        $$5165 = $51;
       } else {
        $$5159 = $$4158;
        break;
       }
      }
      while(1) {
       $52 = ((($$5159)) + -4|0);
       $53 = HEAP32[$52>>2]|0;
       $54 = ($53|0)<($48|0);
       if ($54) {
        break;
       } else {
        $$5159 = $52;
       }
      }
      $55 = ($$5165>>>0)>($52>>>0);
      if ($55) {
       $$2176 = $$0174;$$5172 = $$4171;$$6166 = $$5165;
       break L34;
      }
      HEAP32[$$5165>>2] = $53;
      HEAP32[$52>>2] = $49;
      $56 = (($$4171) + 1)|0;
      $57 = ($$0174|0)==($$5165|0);
      $$$0174 = $57 ? $52 : $$0174;
      $$0174 = $$$0174;$$4158 = $52;$$4164 = $51;$$4171 = $56;
     }
    } else {
     $$2176 = $18;$$5172 = $$3170;$$6166 = $8;
    }
   } while(0);
   $58 = ($$6166|0)==($$2176|0);
   if ($58) {
    $$6173 = $$5172;
   } else {
    $59 = HEAP32[$$2176>>2]|0;
    $60 = HEAP32[$$6166>>2]|0;
    $61 = ($59|0)<($60|0);
    if ($61) {
     $62 = (($$5172) + 1)|0;
     HEAP32[$$6166>>2] = $59;
     HEAP32[$$2176>>2] = $60;
     $$6173 = $62;
    } else {
     $$6173 = $$5172;
    }
   }
   $63 = ($$6173|0)==(0);
   if ($63) {
    $64 = (__ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIiiEEPiEEbT0_S5_T_($$1,$$6166,$2)|0);
    $65 = ((($$6166)) + 4|0);
    $66 = (__ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIiiEEPiEEbT0_S5_T_($65,$$0180$ph,$2)|0);
    if ($66) {
     label = 44;
     break;
    }
    if ($64) {
     $$0 = $65;
     continue;
    }
   }
   $67 = $$6166;
   $68 = (($67) - ($5))|0;
   $69 = (($3) - ($67))|0;
   $70 = ($68|0)<($69|0);
   if (!($70)) {
    label = 43;
    break;
   }
   __ZNSt3__26__sortIRNS_6__lessIiiEEPiEEvT0_S5_T_($$1,$$6166,$2);
   $71 = ((($$6166)) + 4|0);
   $$0 = $71;
  }
  if ((label|0) == 43) {
   label = 0;
   $72 = ((($$6166)) + 4|0);
   __ZNSt3__26__sortIRNS_6__lessIiiEEPiEEvT0_S5_T_($72,$$0180$ph,$2);
   $$0$ph = $$1;$$0180$ph = $$6166;
   continue;
  }
  else if ((label|0) == 44) {
   label = 0;
   if ($64) {
    break;
   } else {
    $$0$ph = $$1;$$0180$ph = $$6166;
    continue;
   }
  }
 }
 if ((label|0) == 5) {
  $9 = HEAP32[$4>>2]|0;
  $10 = HEAP32[$$1>>2]|0;
  $11 = ($9|0)<($10|0);
  if ($11) {
   HEAP32[$$1>>2] = $9;
   HEAP32[$4>>2] = $10;
  }
 }
 else if ((label|0) == 7) {
  (__ZNSt3__27__sort3IRNS_6__lessIiiEEPiEEjT0_S5_S5_T_($$1,$8,$4,$2)|0);
 }
 else if ((label|0) == 8) {
  $12 = ((($$1)) + 8|0);
  (__ZNSt3__27__sort4IRNS_6__lessIiiEEPiEEjT0_S5_S5_S5_T_($$1,$8,$12,$4,$2)|0);
 }
 else if ((label|0) == 9) {
  $13 = ((($$1)) + 8|0);
  $14 = ((($$1)) + 12|0);
  (__ZNSt3__27__sort5IRNS_6__lessIiiEEPiEEjT0_S5_S5_S5_S5_T_($$1,$8,$13,$14,$4,$2)|0);
 }
 else if ((label|0) == 11) {
  __ZNSt3__218__insertion_sort_3IRNS_6__lessIiiEEPiEEvT0_S5_T_($$1,$$0180$ph,$2);
 }
 return;
}
function __ZNSt3__27__sort3IRNS_6__lessIiiEEPiEEjT0_S5_S5_T_($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$026 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = HEAP32[$1>>2]|0;
 $5 = HEAP32[$0>>2]|0;
 $6 = ($4|0)<($5|0);
 $7 = HEAP32[$2>>2]|0;
 $8 = ($7|0)<($4|0);
 do {
  if ($6) {
   if ($8) {
    HEAP32[$0>>2] = $7;
    HEAP32[$2>>2] = $5;
    $$026 = 1;
    break;
   }
   HEAP32[$0>>2] = $4;
   HEAP32[$1>>2] = $5;
   $12 = HEAP32[$2>>2]|0;
   $13 = ($12|0)<($5|0);
   if ($13) {
    HEAP32[$1>>2] = $12;
    HEAP32[$2>>2] = $5;
    $$026 = 2;
   } else {
    $$026 = 1;
   }
  } else {
   if ($8) {
    HEAP32[$1>>2] = $7;
    HEAP32[$2>>2] = $4;
    $9 = HEAP32[$1>>2]|0;
    $10 = HEAP32[$0>>2]|0;
    $11 = ($9|0)<($10|0);
    if ($11) {
     HEAP32[$0>>2] = $9;
     HEAP32[$1>>2] = $10;
     $$026 = 2;
    } else {
     $$026 = 1;
    }
   } else {
    $$026 = 0;
   }
  }
 } while(0);
 return ($$026|0);
}
function __ZNSt3__27__sort4IRNS_6__lessIiiEEPiEEjT0_S5_S5_S5_T_($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = (__ZNSt3__27__sort3IRNS_6__lessIiiEEPiEEjT0_S5_S5_T_($0,$1,$2,$4)|0);
 $6 = HEAP32[$3>>2]|0;
 $7 = HEAP32[$2>>2]|0;
 $8 = ($6|0)<($7|0);
 if ($8) {
  HEAP32[$2>>2] = $6;
  HEAP32[$3>>2] = $7;
  $9 = (($5) + 1)|0;
  $10 = HEAP32[$2>>2]|0;
  $11 = HEAP32[$1>>2]|0;
  $12 = ($10|0)<($11|0);
  if ($12) {
   HEAP32[$1>>2] = $10;
   HEAP32[$2>>2] = $11;
   $13 = (($5) + 2)|0;
   $14 = HEAP32[$1>>2]|0;
   $15 = HEAP32[$0>>2]|0;
   $16 = ($14|0)<($15|0);
   if ($16) {
    $17 = (($5) + 3)|0;
    HEAP32[$0>>2] = $14;
    HEAP32[$1>>2] = $15;
    $$0 = $17;
   } else {
    $$0 = $13;
   }
  } else {
   $$0 = $9;
  }
 } else {
  $$0 = $5;
 }
 return ($$0|0);
}
function __ZNSt3__27__sort5IRNS_6__lessIiiEEPiEEjT0_S5_S5_S5_S5_T_($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $6 = (__ZNSt3__27__sort4IRNS_6__lessIiiEEPiEEjT0_S5_S5_S5_T_($0,$1,$2,$3,$5)|0);
 $7 = HEAP32[$4>>2]|0;
 $8 = HEAP32[$3>>2]|0;
 $9 = ($7|0)<($8|0);
 if ($9) {
  HEAP32[$3>>2] = $7;
  HEAP32[$4>>2] = $8;
  $10 = (($6) + 1)|0;
  $11 = HEAP32[$3>>2]|0;
  $12 = HEAP32[$2>>2]|0;
  $13 = ($11|0)<($12|0);
  if ($13) {
   HEAP32[$2>>2] = $11;
   HEAP32[$3>>2] = $12;
   $14 = (($6) + 2)|0;
   $15 = HEAP32[$2>>2]|0;
   $16 = HEAP32[$1>>2]|0;
   $17 = ($15|0)<($16|0);
   if ($17) {
    HEAP32[$1>>2] = $15;
    HEAP32[$2>>2] = $16;
    $18 = (($6) + 3)|0;
    $19 = HEAP32[$1>>2]|0;
    $20 = HEAP32[$0>>2]|0;
    $21 = ($19|0)<($20|0);
    if ($21) {
     $22 = (($6) + 4)|0;
     HEAP32[$0>>2] = $19;
     HEAP32[$1>>2] = $20;
     $$0 = $22;
    } else {
     $$0 = $18;
    }
   } else {
    $$0 = $14;
   }
  } else {
   $$0 = $10;
  }
 } else {
  $$0 = $6;
 }
 return ($$0|0);
}
function __ZNSt3__218__insertion_sort_3IRNS_6__lessIiiEEPiEEvT0_S5_T_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$0$lcssa = 0, $$029 = 0, $$030 = 0, $$030$phi = 0, $$1 = 0, $$1$phi = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 8|0);
 $4 = ((($0)) + 4|0);
 (__ZNSt3__27__sort3IRNS_6__lessIiiEEPiEEjT0_S5_S5_T_($0,$4,$3,$2)|0);
 $5 = ((($0)) + 12|0);
 $$029 = $5;$$030 = $3;
 while(1) {
  $6 = ($$029|0)==($1|0);
  if ($6) {
   break;
  }
  $7 = HEAP32[$$029>>2]|0;
  $8 = HEAP32[$$030>>2]|0;
  $9 = ($7|0)<($8|0);
  if ($9) {
   $$0 = $$030;$$1 = $$029;$10 = $8;
   while(1) {
    HEAP32[$$1>>2] = $10;
    $11 = ($$0|0)==($0|0);
    if ($11) {
     $$0$lcssa = $0;
     break;
    }
    $12 = ((($$0)) + -4|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = ($7|0)<($13|0);
    if ($14) {
     $$1$phi = $$0;$$0 = $12;$10 = $13;$$1 = $$1$phi;
    } else {
     $$0$lcssa = $$0;
     break;
    }
   }
   HEAP32[$$0$lcssa>>2] = $7;
  }
  $15 = ((($$029)) + 4|0);
  $$030$phi = $$029;$$029 = $15;$$030 = $$030$phi;
 }
 return;
}
function __ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIiiEEPiEEbT0_S5_T_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$$3 = 0, $$0 = 0, $$0$lcssa = 0, $$062 = 0, $$064 = 0, $$069 = 0, $$069$phi = 0, $$1 = 0, $$165 = 0, $$170 = 0, $$170$phi = 0, $$3 = 0, $$5 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $3 = $1;
 $4 = $0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 $7 = ((($0)) + 4|0);
 $8 = ((($1)) + -4|0);
 $9 = ((($0)) + 8|0);
 switch ($6|0) {
 case 1: case 0:  {
  $$5 = 1;
  break;
 }
 case 2:  {
  $10 = HEAP32[$8>>2]|0;
  $11 = HEAP32[$0>>2]|0;
  $12 = ($10|0)<($11|0);
  if ($12) {
   HEAP32[$0>>2] = $10;
   HEAP32[$8>>2] = $11;
   $$5 = 1;
  } else {
   $$5 = 1;
  }
  break;
 }
 case 3:  {
  (__ZNSt3__27__sort3IRNS_6__lessIiiEEPiEEjT0_S5_S5_T_($0,$7,$8,$2)|0);
  $$5 = 1;
  break;
 }
 case 4:  {
  (__ZNSt3__27__sort4IRNS_6__lessIiiEEPiEEjT0_S5_S5_S5_T_($0,$7,$9,$8,$2)|0);
  $$5 = 1;
  break;
 }
 case 5:  {
  $13 = ((($0)) + 12|0);
  (__ZNSt3__27__sort5IRNS_6__lessIiiEEPiEEjT0_S5_S5_S5_S5_T_($0,$7,$9,$13,$8,$2)|0);
  $$5 = 1;
  break;
 }
 default: {
  (__ZNSt3__27__sort3IRNS_6__lessIiiEEPiEEjT0_S5_S5_T_($0,$7,$9,$2)|0);
  $14 = ((($0)) + 12|0);
  $$062 = $14;$$064 = 0;$$069 = $9;
  while(1) {
   $15 = ($$062|0)==($1|0);
   if ($15) {
    $$1 = 1;$$3 = 0;
    break;
   }
   $16 = HEAP32[$$062>>2]|0;
   $17 = HEAP32[$$069>>2]|0;
   $18 = ($16|0)<($17|0);
   if ($18) {
    $$0 = $$069;$$170 = $$062;$19 = $17;
    while(1) {
     HEAP32[$$170>>2] = $19;
     $20 = ($$0|0)==($0|0);
     if ($20) {
      $$0$lcssa = $0;
      break;
     }
     $21 = ((($$0)) + -4|0);
     $22 = HEAP32[$21>>2]|0;
     $23 = ($16|0)<($22|0);
     if ($23) {
      $$170$phi = $$0;$$0 = $21;$19 = $22;$$170 = $$170$phi;
     } else {
      $$0$lcssa = $$0;
      break;
     }
    }
    HEAP32[$$0$lcssa>>2] = $16;
    $24 = (($$064) + 1)|0;
    $25 = ($24|0)==(8);
    $26 = ((($$062)) + 4|0);
    $27 = ($26|0)==($1|0);
    if ($25) {
     $$1 = 0;$$3 = $27;
     break;
    } else {
     $$165 = $24;
    }
   } else {
    $$165 = $$064;
   }
   $28 = ((($$062)) + 4|0);
   $$069$phi = $$062;$$062 = $28;$$064 = $$165;$$069 = $$069$phi;
  }
  $$$3 = $$3 | $$1;
  $$5 = $$$3;
 }
 }
 return ($$5|0);
}
function __ZNSt3__29basic_iosIcNS_11char_traitsIcEEED2Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__28ios_baseD2Ev($0);
 return;
}
function __ZNSt3__29basic_iosIcNS_11char_traitsIcEEED0Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__29basic_iosIcNS_11char_traitsIcEEED2Ev($0);
 __ZdlPv($0);
 return;
}
function __ZNSt3__28ios_baseD2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (96080);
 __THREW__ = 0;
 invoke_vii(4659,($0|0),0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $12 = ___cxa_find_matching_catch_3(0|0)|0;
  $13 = tempRet0;
  ___clang_call_terminate($12);
  // unreachable;
 } else {
  $3 = ((($0)) + 28|0);
  __ZNSt3__26localeD2Ev($3);
  $4 = ((($0)) + 32|0);
  $5 = HEAP32[$4>>2]|0;
  _free($5);
  $6 = ((($0)) + 36|0);
  $7 = HEAP32[$6>>2]|0;
  _free($7);
  $8 = ((($0)) + 48|0);
  $9 = HEAP32[$8>>2]|0;
  _free($9);
  $10 = ((($0)) + 60|0);
  $11 = HEAP32[$10>>2]|0;
  _free($11);
  return;
 }
}
function __ZNSt3__28ios_base16__call_callbacksENS0_5eventE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 40|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 32|0);
 $5 = ((($0)) + 36|0);
 $$0 = $3;
 while(1) {
  $6 = ($$0|0)==(0);
  if ($6) {
   break;
  }
  $7 = (($$0) + -1)|0;
  $8 = HEAP32[$4>>2]|0;
  $9 = (($8) + ($7<<2)|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = HEAP32[$5>>2]|0;
  $12 = (($11) + ($7<<2)|0);
  $13 = HEAP32[$12>>2]|0;
  FUNCTION_TABLE_viii[$10 & 8191]($1,$0,$13);
  $$0 = $7;
 }
 return;
}
function __ZNSt3__28ios_baseD0Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__28ios_baseD2Ev($0);
 __ZdlPv($0);
 return;
}
function __ZNSt3__29basic_iosIwNS_11char_traitsIwEEED2Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__28ios_baseD2Ev($0);
 return;
}
function __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (96096);
 $1 = ((($0)) + 4|0);
 __ZNSt3__26localeD2Ev($1);
 return;
}
function __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEED0Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEED2Ev($0);
 __ZdlPv($0);
 return;
}
function __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE5imbueERKNS_6localeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE6setbufEPci($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ($0|0);
}
function __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE7seekoffExNS_8ios_base7seekdirEj($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $6 = $0;
 $7 = $6;
 HEAP32[$7>>2] = 0;
 $8 = (($6) + 4)|0;
 $9 = $8;
 HEAP32[$9>>2] = 0;
 $10 = ((($0)) + 8|0);
 $11 = $10;
 $12 = $11;
 HEAP32[$12>>2] = -1;
 $13 = (($11) + 4)|0;
 $14 = $13;
 HEAP32[$14>>2] = -1;
 return;
}
function __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE7seekposENS_4fposI11__mbstate_tEEj($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $10 = 0, $11 = 0, $12 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = $0;
 $5 = $4;
 HEAP32[$5>>2] = 0;
 $6 = (($4) + 4)|0;
 $7 = $6;
 HEAP32[$7>>2] = 0;
 $8 = ((($0)) + 8|0);
 $9 = $8;
 $10 = $9;
 HEAP32[$10>>2] = -1;
 $11 = (($9) + 4)|0;
 $12 = $11;
 HEAP32[$12>>2] = -1;
 return;
}
function __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE4syncEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE9showmanycEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE6xsgetnEPci($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$023 = 0, $$sroa$speculated = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZNSt3__211char_traitsIcE3eofEv()|0);
 $3 = ((($0)) + 12|0);
 $4 = ((($0)) + 16|0);
 $$0 = $1;$$023 = 0;
 while(1) {
  $5 = ($$023|0)<($2|0);
  if (!($5)) {
   break;
  }
  $6 = HEAP32[$3>>2]|0;
  $7 = HEAP32[$4>>2]|0;
  $8 = ($6>>>0)<($7>>>0);
  if ($8) {
   $9 = $7;
   $10 = $6;
   $11 = (($9) - ($10))|0;
   $12 = (($2) - ($$023))|0;
   $13 = ($12|0)<($11|0);
   $$sroa$speculated = $13 ? $12 : $11;
   (__ZNSt3__211char_traitsIcE4copyEPcPKcj($$0,$6,$$sroa$speculated)|0);
   $14 = (($$0) + ($$sroa$speculated)|0);
   $15 = (($$sroa$speculated) + ($$023))|0;
   $16 = HEAP32[$3>>2]|0;
   $17 = (($16) + ($$sroa$speculated)|0);
   HEAP32[$3>>2] = $17;
   $$0 = $14;$$023 = $15;
   continue;
  }
  $18 = HEAP32[$0>>2]|0;
  $19 = ((($18)) + 40|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = (FUNCTION_TABLE_ii[$20 & 8191]($0)|0);
  $22 = ($21|0)==(-1);
  if ($22) {
   break;
  }
  $23 = (__ZNSt3__211char_traitsIcE12to_char_typeEi($21)|0);
  HEAP8[$$0>>0] = $23;
  $24 = ((($$0)) + 1|0);
  $25 = (($$023) + 1)|0;
  $$0 = $24;$$023 = $25;
 }
 return ($$023|0);
}
function __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE9underflowEv($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
 return ($1|0);
}
function __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE5uflowEv($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + 36|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (FUNCTION_TABLE_ii[$3 & 8191]($0)|0);
 $5 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
 $6 = ($4|0)==($5|0);
 if ($6) {
  $7 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
  $$0 = $7;
 } else {
  $8 = ((($0)) + 12|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ((($9)) + 1|0);
  HEAP32[$8>>2] = $10;
  $11 = HEAP8[$9>>0]|0;
  $12 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($11)|0);
  $$0 = $12;
 }
 return ($$0|0);
}
function __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE9pbackfailEi($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
 return ($2|0);
}
function __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE6xsputnEPKci($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$021 = 0, $$sroa$speculated = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
 $4 = ((($0)) + 24|0);
 $5 = ((($0)) + 28|0);
 $$0 = $1;$$021 = 0;
 while(1) {
  $6 = ($$021|0)<($2|0);
  if (!($6)) {
   break;
  }
  $7 = HEAP32[$4>>2]|0;
  $8 = HEAP32[$5>>2]|0;
  $9 = ($7>>>0)<($8>>>0);
  if ($9) {
   $19 = $8;
   $20 = $7;
   $21 = (($19) - ($20))|0;
   $22 = (($2) - ($$021))|0;
   $23 = ($22|0)<($21|0);
   $$sroa$speculated = $23 ? $22 : $21;
   (__ZNSt3__211char_traitsIcE4copyEPcPKcj($7,$$0,$$sroa$speculated)|0);
   $24 = HEAP32[$4>>2]|0;
   $25 = (($24) + ($$sroa$speculated)|0);
   HEAP32[$4>>2] = $25;
   $26 = (($$0) + ($$sroa$speculated)|0);
   $27 = (($$sroa$speculated) + ($$021))|0;
   $$0 = $26;$$021 = $27;
   continue;
  }
  $10 = HEAP32[$0>>2]|0;
  $11 = ((($10)) + 52|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = HEAP8[$$0>>0]|0;
  $14 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($13)|0);
  $15 = (FUNCTION_TABLE_iii[$12 & 8191]($0,$14)|0);
  $16 = ($15|0)==($3|0);
  if ($16) {
   break;
  }
  $17 = ((($$0)) + 1|0);
  $18 = (($$021) + 1)|0;
  $$0 = $17;$$021 = $18;
 }
 return ($$021|0);
}
function __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE8overflowEi($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
 return ($2|0);
}
function __ZNSt3__211char_traitsIcE12to_char_typeEi($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = $0&255;
 return ($1|0);
}
function __ZNSt3__215basic_streambufIwNS_11char_traitsIwEEED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (96160);
 $1 = ((($0)) + 4|0);
 __ZNSt3__26localeD2Ev($1);
 return;
}
function __ZNSt3__215basic_streambufIwNS_11char_traitsIwEEED0Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__215basic_streambufIwNS_11char_traitsIwEEED2Ev($0);
 __ZdlPv($0);
 return;
}
function __ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE5imbueERKNS_6localeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE6setbufEPwi($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ($0|0);
}
function __ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE7seekoffExNS_8ios_base7seekdirEj($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $6 = $0;
 $7 = $6;
 HEAP32[$7>>2] = 0;
 $8 = (($6) + 4)|0;
 $9 = $8;
 HEAP32[$9>>2] = 0;
 $10 = ((($0)) + 8|0);
 $11 = $10;
 $12 = $11;
 HEAP32[$12>>2] = -1;
 $13 = (($11) + 4)|0;
 $14 = $13;
 HEAP32[$14>>2] = -1;
 return;
}
function __ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE7seekposENS_4fposI11__mbstate_tEEj($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $10 = 0, $11 = 0, $12 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = $0;
 $5 = $4;
 HEAP32[$5>>2] = 0;
 $6 = (($4) + 4)|0;
 $7 = $6;
 HEAP32[$7>>2] = 0;
 $8 = ((($0)) + 8|0);
 $9 = $8;
 $10 = $9;
 HEAP32[$10>>2] = -1;
 $11 = (($9) + 4)|0;
 $12 = $11;
 HEAP32[$12>>2] = -1;
 return;
}
function __ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE4syncEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function __ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE9showmanycEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function __ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE6xsgetnEPwi($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$023 = 0, $$sroa$speculated = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZNSt3__211char_traitsIwE3eofEv()|0);
 $3 = ((($0)) + 12|0);
 $4 = ((($0)) + 16|0);
 $$0 = $1;$$023 = 0;
 while(1) {
  $5 = ($$023|0)<($2|0);
  if (!($5)) {
   break;
  }
  $6 = HEAP32[$3>>2]|0;
  $7 = HEAP32[$4>>2]|0;
  $8 = ($6>>>0)<($7>>>0);
  if ($8) {
   $9 = $7;
   $10 = $6;
   $11 = (($9) - ($10))|0;
   $12 = $11 >> 2;
   $13 = (($2) - ($$023))|0;
   $14 = ($13|0)<($12|0);
   $$sroa$speculated = $14 ? $13 : $12;
   (__ZNSt3__211char_traitsIwE4copyEPwPKwj($$0,$6,$$sroa$speculated)|0);
   $15 = (($$0) + ($$sroa$speculated<<2)|0);
   $16 = (($$sroa$speculated) + ($$023))|0;
   $17 = HEAP32[$3>>2]|0;
   $18 = (($17) + ($$sroa$speculated<<2)|0);
   HEAP32[$3>>2] = $18;
   $$0 = $15;$$023 = $16;
   continue;
  }
  $19 = HEAP32[$0>>2]|0;
  $20 = ((($19)) + 40|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = (FUNCTION_TABLE_ii[$21 & 8191]($0)|0);
  $23 = ($22|0)==(-1);
  if ($23) {
   break;
  }
  $24 = (__ZNSt3__211char_traitsIwE12to_char_typeEj($22)|0);
  HEAP32[$$0>>2] = $24;
  $25 = ((($$0)) + 4|0);
  $26 = (($$023) + 1)|0;
  $$0 = $25;$$023 = $26;
 }
 return ($$023|0);
}
function __ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE9underflowEv($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
 return ($1|0);
}
function __ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE5uflowEv($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + 36|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (FUNCTION_TABLE_ii[$3 & 8191]($0)|0);
 $5 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
 $6 = ($4|0)==($5|0);
 if ($6) {
  $7 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
  $$0 = $7;
 } else {
  $8 = ((($0)) + 12|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ((($9)) + 4|0);
  HEAP32[$8>>2] = $10;
  $11 = HEAP32[$9>>2]|0;
  $12 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($11)|0);
  $$0 = $12;
 }
 return ($$0|0);
}
function __ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE9pbackfailEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
 return ($2|0);
}
function __ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE6xsputnEPKwi($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$021 = 0, $$sroa$speculated = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
 $4 = ((($0)) + 24|0);
 $5 = ((($0)) + 28|0);
 $$0 = $1;$$021 = 0;
 while(1) {
  $6 = ($$021|0)<($2|0);
  if (!($6)) {
   break;
  }
  $7 = HEAP32[$4>>2]|0;
  $8 = HEAP32[$5>>2]|0;
  $9 = ($7>>>0)<($8>>>0);
  if ($9) {
   $19 = $8;
   $20 = $7;
   $21 = (($19) - ($20))|0;
   $22 = $21 >> 2;
   $23 = (($2) - ($$021))|0;
   $24 = ($23|0)<($22|0);
   $$sroa$speculated = $24 ? $23 : $22;
   (__ZNSt3__211char_traitsIwE4copyEPwPKwj($7,$$0,$$sroa$speculated)|0);
   $25 = HEAP32[$4>>2]|0;
   $26 = (($25) + ($$sroa$speculated<<2)|0);
   HEAP32[$4>>2] = $26;
   $27 = (($$0) + ($$sroa$speculated<<2)|0);
   $28 = (($$sroa$speculated) + ($$021))|0;
   $$0 = $27;$$021 = $28;
   continue;
  }
  $10 = HEAP32[$0>>2]|0;
  $11 = ((($10)) + 52|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = HEAP32[$$0>>2]|0;
  $14 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($13)|0);
  $15 = (FUNCTION_TABLE_iii[$12 & 8191]($0,$14)|0);
  $16 = ($15|0)==($3|0);
  if ($16) {
   break;
  }
  $17 = ((($$0)) + 4|0);
  $18 = (($$021) + 1)|0;
  $$0 = $17;$$021 = $18;
 }
 return ($$021|0);
}
function __ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE8overflowEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
 return ($2|0);
}
function __ZNSt3__211char_traitsIwE3eofEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 return -1;
}
function __ZNSt3__211char_traitsIwE11to_int_typeEw($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ($0|0);
}
function __ZNSt3__211char_traitsIwE4copyEPwPKwj($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($2|0)==(0);
 if ($3) {
  $7 = $0;
 } else {
  __THREW__ = 0;
  $4 = (invoke_iiii(4660,($0|0),($1|0),($2|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if ($6) {
   $8 = ___cxa_find_matching_catch_3(0|0)|0;
   $9 = tempRet0;
   ___clang_call_terminate($8);
   // unreachable;
  } else {
   $7 = $0;
  }
 }
 return ($7|0);
}
function __ZNSt3__211char_traitsIwE12to_char_typeEj($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ($0|0);
}
function __ZNSt3__213basic_istreamIcNS_11char_traitsIcEEED1Ev($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__213basic_istreamIcNS_11char_traitsIcEEED2Ev($0,96256);
 $1 = ((($0)) + 8|0);
 __ZNSt3__29basic_iosIcNS_11char_traitsIcEEED2Ev($1);
 return;
}
function __ZNSt3__213basic_istreamIcNS_11char_traitsIcEEED0Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__213basic_istreamIcNS_11char_traitsIcEEED1Ev($0);
 __ZdlPv($0);
 return;
}
function __ZTv0_n12_NSt3__213basic_istreamIcNS_11char_traitsIcEEED1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __ZNSt3__213basic_istreamIcNS_11char_traitsIcEEED1Ev($4);
 return;
}
function __ZTv0_n12_NSt3__213basic_istreamIcNS_11char_traitsIcEEED0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __ZNSt3__213basic_istreamIcNS_11char_traitsIcEEED0Ev($4);
 return;
}
function __ZNSt3__213basic_istreamIcNS_11char_traitsIcEEED2Ev($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZNSt3__213basic_istreamIwNS_11char_traitsIwEEED1Ev($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__213basic_istreamIwNS_11char_traitsIwEEED2Ev($0,96304);
 $1 = ((($0)) + 8|0);
 __ZNSt3__29basic_iosIwNS_11char_traitsIwEEED2Ev($1);
 return;
}
function __ZNSt3__213basic_istreamIwNS_11char_traitsIwEEED0Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__213basic_istreamIwNS_11char_traitsIwEEED1Ev($0);
 __ZdlPv($0);
 return;
}
function __ZTv0_n12_NSt3__213basic_istreamIwNS_11char_traitsIwEEED1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __ZNSt3__213basic_istreamIwNS_11char_traitsIwEEED1Ev($4);
 return;
}
function __ZTv0_n12_NSt3__213basic_istreamIwNS_11char_traitsIwEEED0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __ZNSt3__213basic_istreamIwNS_11char_traitsIwEEED0Ev($4);
 return;
}
function __ZNSt3__213basic_istreamIwNS_11char_traitsIwEEED2Ev($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEED1Ev($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEED2Ev($0,96312);
 $1 = ((($0)) + 4|0);
 __ZNSt3__29basic_iosIcNS_11char_traitsIcEEED2Ev($1);
 return;
}
function __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEED0Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEED1Ev($0);
 __ZdlPv($0);
 return;
}
function __ZTv0_n12_NSt3__213basic_ostreamIcNS_11char_traitsIcEEED1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEED1Ev($4);
 return;
}
function __ZTv0_n12_NSt3__213basic_ostreamIcNS_11char_traitsIcEEED0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEED0Ev($4);
 return;
}
function __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEED2Ev($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEED1Ev($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEED2Ev($0,96360);
 $1 = ((($0)) + 4|0);
 __ZNSt3__29basic_iosIwNS_11char_traitsIwEEED2Ev($1);
 return;
}
function __ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEED0Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEED1Ev($0);
 __ZdlPv($0);
 return;
}
function __ZTv0_n12_NSt3__213basic_ostreamIwNS_11char_traitsIwEEED1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEED1Ev($4);
 return;
}
function __ZTv0_n12_NSt3__213basic_ostreamIwNS_11char_traitsIwEEED0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEED0Ev($4);
 return;
}
function __ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEED2Ev($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZNSt3__214basic_iostreamIcNS_11char_traitsIcEEED1Ev($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__214basic_iostreamIcNS_11char_traitsIcEEED2Ev($0,96428);
 $1 = ((($0)) + 12|0);
 __ZNSt3__29basic_iosIcNS_11char_traitsIcEEED2Ev($1);
 return;
}
function __ZNSt3__214basic_iostreamIcNS_11char_traitsIcEEED0Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__214basic_iostreamIcNS_11char_traitsIcEEED1Ev($0);
 __ZdlPv($0);
 return;
}
function __ZThn8_NSt3__214basic_iostreamIcNS_11char_traitsIcEEED1Ev($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -8|0);
 __ZNSt3__214basic_iostreamIcNS_11char_traitsIcEEED1Ev($1);
 return;
}
function __ZThn8_NSt3__214basic_iostreamIcNS_11char_traitsIcEEED0Ev($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -8|0);
 __ZNSt3__214basic_iostreamIcNS_11char_traitsIcEEED0Ev($1);
 return;
}
function __ZTv0_n12_NSt3__214basic_iostreamIcNS_11char_traitsIcEEED1Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __ZNSt3__214basic_iostreamIcNS_11char_traitsIcEEED1Ev($4);
 return;
}
function __ZTv0_n12_NSt3__214basic_iostreamIcNS_11char_traitsIcEEED0Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + ($3)|0);
 __ZNSt3__214basic_iostreamIcNS_11char_traitsIcEEED0Ev($4);
 return;
}
function __ZNSt3__214basic_iostreamIcNS_11char_traitsIcEEED2Ev($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 8|0);
 $3 = ((($1)) + 12|0);
 __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEED2Ev($2,$3);
 $4 = ((($1)) + 4|0);
 __ZNSt3__213basic_istreamIcNS_11char_traitsIcEEED2Ev($0,$4);
 return;
}
function __ZNSt3__219__iostream_categoryD0Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($0);
 return;
}
function __ZNKSt3__219__iostream_category4nameEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (202335|0);
}
function __ZNKSt3__219__iostream_category7messageEi($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = ($2|0)!=(1);
 $5 = ($2|0)<(257);
 $or$cond = $4 & $5;
 if ($or$cond) {
  __ZNKSt3__212__do_message7messageEi($0,$1,$2);
 } else {
  ;HEAP32[$0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;
  $6 = (__ZNSt3__211char_traitsIcE6lengthEPKc(202299)|0);
  $7 = ($6>>>0)>(4294967279);
  if ($7) {
   __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv($0);
   // unreachable;
  }
  $8 = ($6>>>0)<(11);
  if ($8) {
   $9 = $6&255;
   $10 = ((($0)) + 11|0);
   HEAP8[$10>>0] = $9;
   $$0$i$i = $0;
  } else {
   $11 = (($6) + 16)|0;
   $12 = $11 & -16;
   $13 = (__Znwj($12)|0);
   HEAP32[$0>>2] = $13;
   $14 = $12 | -2147483648;
   $15 = ((($0)) + 8|0);
   HEAP32[$15>>2] = $14;
   $16 = ((($0)) + 4|0);
   HEAP32[$16>>2] = $6;
   $$0$i$i = $13;
  }
  (__ZNSt3__211char_traitsIcE4copyEPcPKcj($$0$i$i,202299,$6)|0);
  $17 = (($$0$i$i) + ($6)|0);
  HEAP8[$3>>0] = 0;
  __ZNSt3__211char_traitsIcE6assignERcRKc($17,$3);
 }
 STACKTOP = sp;return;
}
function __ZNSt3__28ios_base7failureD2Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__212system_errorD2Ev($0);
 return;
}
function __ZNSt3__28ios_base7failureD0Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__28ios_base7failureD2Ev($0);
 __ZdlPv($0);
 return;
}
function __ZNSt3__28ios_base5clearEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$index = 0, $$index2 = 0, $$sink = 0, $$sroa_idx2$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $not$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = ((($0)) + 24|0);
 $4 = HEAP32[$3>>2]|0;
 $not$ = ($4|0)==(0|0);
 $5 = $not$&1;
 $$sink = $5 | $1;
 $6 = ((($0)) + 16|0);
 HEAP32[$6>>2] = $$sink;
 $7 = ((($0)) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $$sink & $8;
 $10 = ($9|0)==(0);
 if ($10) {
  STACKTOP = sp;return;
 }
 $11 = (___cxa_allocate_exception(16)|0);
 (__ZNSt3__217iostream_categoryEv()|0);
 HEAP32[$2>>2] = 1;
 $$sroa_idx2$i = ((($2)) + 4|0);
 HEAP32[$$sroa_idx2$i>>2] = (96512);
 __THREW__ = 0;
 invoke_viii(4661,($11|0),(202400|0),($2|0));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $17 = ___cxa_find_matching_catch_2()|0;
  $18 = tempRet0;
  ___cxa_free_exception(($11|0));
  $$index = $17;$$index2 = $18;
 } else {
  __THREW__ = 0;
  invoke_viii(3695,($11|0),(33232|0),(2942|0));
  $14 = __THREW__; __THREW__ = 0;
  $15 = ___cxa_find_matching_catch_2()|0;
  $16 = tempRet0;
  $$index = $15;$$index2 = $16;
 }
 ___resumeException($$index|0);
 // unreachable;
}
function __ZNSt3__217iostream_categoryEv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[207032]|0;
 $1 = ($0<<24>>24)==(0);
 if ($1) {
  $2 = (___cxa_guard_acquire(207032)|0);
  $3 = ($2|0)==(0);
  if (!($3)) {
   (___cxa_atexit((2935|0),(96512|0),(___dso_handle|0))|0);
  }
 }
 return (96512|0);
}
function __ZNSt3__28ios_base7failureC2EPKcRKNS_10error_codeE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $tmpcast$byval_copy = sp + 8|0;
 $3 = sp;
 $4 = $2;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + 4)|0;
 $8 = $7;
 $9 = HEAP32[$8>>2]|0;
 $10 = $3;
 $11 = $10;
 HEAP32[$11>>2] = $6;
 $12 = (($10) + 4)|0;
 $13 = $12;
 HEAP32[$13>>2] = $9;
 ;HEAP32[$tmpcast$byval_copy>>2]=HEAP32[$3>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;
 __ZNSt3__212system_errorC2ENS_10error_codeEPKc($0,$tmpcast$byval_copy,$1);
 HEAP32[$0>>2] = (96500);
 STACKTOP = sp;return;
}
function __ZNSt3__28ios_base4initEPv($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $not$ = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 24|0);
 HEAP32[$2>>2] = $1;
 $not$ = ($1|0)==(0|0);
 $3 = $not$&1;
 $4 = ((($0)) + 16|0);
 HEAP32[$4>>2] = $3;
 $5 = ((($0)) + 20|0);
 HEAP32[$5>>2] = 0;
 $6 = ((($0)) + 4|0);
 HEAP32[$6>>2] = 4098;
 $7 = ((($0)) + 12|0);
 HEAP32[$7>>2] = 0;
 $8 = ((($0)) + 8|0);
 HEAP32[$8>>2] = 6;
 $9 = ((($0)) + 32|0);
 $10 = ((($0)) + 28|0);
 dest=$9; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 __ZNSt3__26localeC2Ev($10);
 return;
}
function __ZNKSt3__28ios_base6getlocEv($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 28|0);
 __ZNSt3__26localeC2ERKS0_($0,$2);
 return;
}
function __ZNSt3__211char_traitsIwE11eq_int_typeEjj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($0|0)==($1|0);
 return ($2|0);
}
function __ZNSt3__211char_traitsIcE2eqEcc($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($0<<24>>24)==($1<<24>>24);
 return ($2|0);
}
function __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEEC2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (96096);
 $1 = ((($0)) + 4|0);
 __ZNSt3__26localeC2Ev($1);
 $2 = ((($0)) + 8|0);
 ;HEAP32[$2>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;HEAP32[$2+12>>2]=0|0;HEAP32[$2+16>>2]=0|0;HEAP32[$2+20>>2]=0|0;
 return;
}
function __ZNSt3__215basic_streambufIwNS_11char_traitsIwEEEC2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (96160);
 $1 = ((($0)) + 4|0);
 __ZNSt3__26localeC2Ev($1);
 $2 = ((($0)) + 8|0);
 ;HEAP32[$2>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;HEAP32[$2+12>>2]=0|0;HEAP32[$2+16>>2]=0|0;HEAP32[$2+20>>2]=0|0;
 return;
}
function __ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE6sentryC2ERS3_b($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$$sroa$028$0 = 0, $$0$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i14 = 0, $$pre$phiZ2D = 0, $$sroa$028$138 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $12 = 0;
 var $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $sext = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 HEAP8[$0>>0] = 0;
 $4 = HEAP32[$1>>2]|0;
 $5 = ((($4)) + -12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($1) + ($6)|0);
 $8 = ((($7)) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0);
 if ($10) {
  $11 = ((($7)) + 72|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($12|0)==(0|0);
  if (!($13)) {
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($12)|0);
  }
  do {
   if (!($2)) {
    $14 = HEAP32[$1>>2]|0;
    $15 = ((($14)) + -12|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = (($1) + ($16)|0);
    $18 = ((($17)) + 4|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = $19 & 4096;
    $21 = ($20|0)==(0);
    if (!($21)) {
     __ZNKSt3__28ios_base6getlocEv($3,$17);
     __THREW__ = 0;
     $22 = (invoke_iii(3255,($3|0),(215188|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      $69 = ___cxa_find_matching_catch_2()|0;
      $70 = tempRet0;
      __ZNSt3__26localeD2Ev($3);
      ___resumeException($69|0);
      // unreachable;
     }
     __ZNSt3__26localeD2Ev($3);
     $25 = HEAP32[$1>>2]|0;
     $26 = ((($25)) + -12|0);
     $27 = HEAP32[$26>>2]|0;
     $28 = (($1) + ($27)|0);
     $29 = ((($28)) + 24|0);
     $30 = HEAP32[$29>>2]|0;
     $31 = ((($22)) + 8|0);
     $32 = $30;
     $33 = ($30|0)==(0);
     $34 = ((($32)) + 12|0);
     $35 = ((($32)) + 16|0);
     $36 = $30;
     while(1) {
      if ($33) {
       $$pre$phiZ2D = 0;$$sroa$028$138 = 0;
       break;
      }
      $37 = HEAP32[$34>>2]|0;
      $38 = HEAP32[$35>>2]|0;
      $39 = ($37|0)==($38|0);
      if ($39) {
       $40 = HEAP32[$36>>2]|0;
       $41 = ((($40)) + 36|0);
       $42 = HEAP32[$41>>2]|0;
       $43 = (FUNCTION_TABLE_ii[$42 & 8191]($32)|0);
       $$0$i$i$i$i14 = $43;
      } else {
       $44 = HEAP8[$37>>0]|0;
       $45 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($44)|0);
       $$0$i$i$i$i14 = $45;
      }
      $46 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
      $47 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i$i$i14,$46)|0);
      $$$sroa$028$0 = $47 ? 0 : $30;
      if ($47) {
       $$pre$phiZ2D = 0;$$sroa$028$138 = 0;
       break;
      }
      $48 = $$$sroa$028$0;
      $49 = ((($48)) + 12|0);
      $50 = HEAP32[$49>>2]|0;
      $51 = ((($48)) + 16|0);
      $52 = HEAP32[$51>>2]|0;
      $53 = ($50|0)==($52|0);
      if ($53) {
       $54 = $$$sroa$028$0;
       $55 = HEAP32[$54>>2]|0;
       $56 = ((($55)) + 36|0);
       $57 = HEAP32[$56>>2]|0;
       $58 = (FUNCTION_TABLE_ii[$57 & 8191]($48)|0);
       $$0$i$i = $58;
      } else {
       $59 = HEAP8[$50>>0]|0;
       $60 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($59)|0);
       $$0$i$i = $60;
      }
      $61 = $$0$i$i&255;
      $62 = ($61<<24>>24)>(-1);
      if (!($62)) {
       $$pre$phiZ2D = $48;$$sroa$028$138 = $30;
       break;
      }
      $sext = $$0$i$i << 24;
      $63 = $sext >> 24;
      $64 = HEAP32[$31>>2]|0;
      $65 = (($64) + ($63<<1)|0);
      $66 = HEAP16[$65>>1]|0;
      $67 = $66 & 8192;
      $68 = ($67<<16>>16)==(0);
      if ($68) {
       $$pre$phiZ2D = $48;$$sroa$028$138 = $30;
       break;
      }
      $71 = HEAP32[$49>>2]|0;
      $72 = HEAP32[$51>>2]|0;
      $73 = ($71|0)==($72|0);
      if ($73) {
       $74 = $$$sroa$028$0;
       $75 = HEAP32[$74>>2]|0;
       $76 = ((($75)) + 40|0);
       $77 = HEAP32[$76>>2]|0;
       (FUNCTION_TABLE_ii[$77 & 8191]($48)|0);
       continue;
      } else {
       $78 = ((($71)) + 1|0);
       HEAP32[$49>>2] = $78;
       $79 = HEAP8[$71>>0]|0;
       (__ZNSt3__211char_traitsIcE11to_int_typeEc($79)|0);
       continue;
      }
     }
     $80 = ($$sroa$028$138|0)==(0);
     if (!($80)) {
      $81 = ((($$pre$phiZ2D)) + 12|0);
      $82 = HEAP32[$81>>2]|0;
      $83 = ((($$pre$phiZ2D)) + 16|0);
      $84 = HEAP32[$83>>2]|0;
      $85 = ($82|0)==($84|0);
      if ($85) {
       $86 = $$sroa$028$138;
       $87 = HEAP32[$86>>2]|0;
       $88 = ((($87)) + 36|0);
       $89 = HEAP32[$88>>2]|0;
       $90 = (FUNCTION_TABLE_ii[$89 & 8191]($$pre$phiZ2D)|0);
       $$0$i$i$i$i = $90;
      } else {
       $91 = HEAP8[$82>>0]|0;
       $92 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($91)|0);
       $$0$i$i$i$i = $92;
      }
      $93 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
      $94 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i$i$i,$93)|0);
      if (!($94)) {
       break;
      }
     }
     $95 = HEAP32[$1>>2]|0;
     $96 = ((($95)) + -12|0);
     $97 = HEAP32[$96>>2]|0;
     $98 = (($1) + ($97)|0);
     $99 = ((($98)) + 16|0);
     $100 = HEAP32[$99>>2]|0;
     $101 = $100 | 6;
     __ZNSt3__28ios_base5clearEj($98,$101);
    }
   }
  } while(0);
  $102 = HEAP32[$1>>2]|0;
  $103 = ((($102)) + -12|0);
  $104 = HEAP32[$103>>2]|0;
  $105 = (($1) + ($104)|0);
  $106 = ((($105)) + 16|0);
  $107 = HEAP32[$106>>2]|0;
  $108 = ($107|0)==(0);
  $109 = $108&1;
  HEAP8[$0>>0] = $109;
 } else {
  $110 = $9 | 4;
  __ZNSt3__28ios_base5clearEj($7,$110);
 }
 STACKTOP = sp;return;
}
function __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $2 = HEAP32[$0>>2]|0;
 $3 = ((($2)) + -12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($0) + ($4)|0);
 $6 = ((($5)) + 24|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 L1: do {
  if (!($8)) {
   __THREW__ = 0;
   invoke_vii(3256,($1|0),($0|0));
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   L3: do {
    if ($10) {
     $35 = ___cxa_find_matching_catch_3(0|0)|0;
     $36 = tempRet0;
     $$0 = $35;
    } else {
     $11 = HEAP8[$1>>0]|0;
     $12 = ($11<<24>>24)==(0);
     do {
      if (!($12)) {
       $13 = HEAP32[$0>>2]|0;
       $14 = ((($13)) + -12|0);
       $15 = HEAP32[$14>>2]|0;
       $16 = (($0) + ($15)|0);
       $17 = ((($16)) + 24|0);
       $18 = HEAP32[$17>>2]|0;
       $19 = HEAP32[$18>>2]|0;
       $20 = ((($19)) + 24|0);
       $21 = HEAP32[$20>>2]|0;
       __THREW__ = 0;
       $22 = (invoke_ii($21|0,($18|0))|0);
       $23 = __THREW__; __THREW__ = 0;
       $24 = $23&1;
       if (!($24)) {
        $25 = ($22|0)==(-1);
        if (!($25)) {
         break;
        }
        $26 = HEAP32[$0>>2]|0;
        $27 = ((($26)) + -12|0);
        $28 = HEAP32[$27>>2]|0;
        $29 = (($0) + ($28)|0);
        $30 = ((($29)) + 16|0);
        $31 = HEAP32[$30>>2]|0;
        $32 = $31 | 1;
        __THREW__ = 0;
        invoke_vii(3259,($29|0),($32|0));
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if (!($34)) {
         break;
        }
       }
       $37 = ___cxa_find_matching_catch_3(0|0)|0;
       $38 = tempRet0;
       __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE6sentryD2Ev($1);
       $$0 = $37;
       break L3;
      }
     } while(0);
     __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE6sentryD2Ev($1);
     break L1;
    }
   } while(0);
   (___cxa_begin_catch(($$0|0))|0);
   $39 = HEAP32[$0>>2]|0;
   $40 = ((($39)) + -12|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = (($0) + ($41)|0);
   __THREW__ = 0;
   invoke_vi(3260,($42|0));
   $43 = __THREW__; __THREW__ = 0;
   $44 = $43&1;
   if (!($44)) {
    ___cxa_end_catch();
    break;
   }
   $45 = ___cxa_find_matching_catch_2()|0;
   $46 = tempRet0;
   __THREW__ = 0;
   invoke_v(3261);
   $47 = __THREW__; __THREW__ = 0;
   $48 = $47&1;
   if ($48) {
    $49 = ___cxa_find_matching_catch_3(0|0)|0;
    $50 = tempRet0;
    ___clang_call_terminate($49);
    // unreachable;
   } else {
    ___resumeException($45|0);
    // unreachable;
   }
  }
 } while(0);
 STACKTOP = sp;return ($0|0);
}
function __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE6sentryC2ERS3_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP8[$0>>0] = 0;
 $2 = ((($0)) + 4|0);
 HEAP32[$2>>2] = $1;
 $3 = HEAP32[$1>>2]|0;
 $4 = ((($3)) + -12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($1) + ($5)|0);
 $7 = ((($6)) + 16|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0);
 if ($9) {
  $10 = ((($6)) + 72|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($11|0)==(0|0);
  if (!($12)) {
   (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv($11)|0);
  }
  HEAP8[$0>>0] = 1;
 }
 return;
}
function __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE6sentryD2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + -12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($2) + ($5)|0);
 $7 = ((($6)) + 24|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 do {
  if (!($9)) {
   $10 = ((($6)) + 16|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = ($11|0)==(0);
   if ($12) {
    $13 = ((($6)) + 4|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = $14 & 8192;
    $16 = ($15|0)==(0);
    if (!($16)) {
     $17 = (__ZSt18uncaught_exceptionv()|0);
     if (!($17)) {
      $18 = HEAP32[$1>>2]|0;
      $19 = HEAP32[$18>>2]|0;
      $20 = ((($19)) + -12|0);
      $21 = HEAP32[$20>>2]|0;
      $22 = (($18) + ($21)|0);
      $23 = ((($22)) + 24|0);
      $24 = HEAP32[$23>>2]|0;
      $25 = HEAP32[$24>>2]|0;
      $26 = ((($25)) + 24|0);
      $27 = HEAP32[$26>>2]|0;
      __THREW__ = 0;
      $28 = (invoke_ii($27|0,($24|0))|0);
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if (!($30)) {
       $31 = ($28|0)==(-1);
       if (!($31)) {
        break;
       }
       $32 = HEAP32[$1>>2]|0;
       $33 = HEAP32[$32>>2]|0;
       $34 = ((($33)) + -12|0);
       $35 = HEAP32[$34>>2]|0;
       $36 = (($32) + ($35)|0);
       $37 = ((($36)) + 16|0);
       $38 = HEAP32[$37>>2]|0;
       $39 = $38 | 1;
       __THREW__ = 0;
       invoke_vii(3259,($36|0),($39|0));
       $40 = __THREW__; __THREW__ = 0;
       $41 = $40&1;
       if (!($41)) {
        break;
       }
      }
      $42 = ___cxa_find_matching_catch_3(0|0)|0;
      $43 = tempRet0;
      (___cxa_begin_catch(($42|0))|0);
      __THREW__ = 0;
      invoke_v(3261);
      $44 = __THREW__; __THREW__ = 0;
      $45 = $44&1;
      if ($45) {
       $46 = ___cxa_find_matching_catch_3(0|0)|0;
       $47 = tempRet0;
       ___clang_call_terminate($46);
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 return;
}
function __ZNSt3__28ios_base33__set_badbit_and_consider_rethrowEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 | 1;
 HEAP32[$1>>2] = $3;
 $4 = ((($0)) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  return;
 } else {
  ___cxa_rethrow();
  // unreachable;
 }
}
function __ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERi($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$1 = 0, $$byval_copy = 0, $$byval_copy1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $$byval_copy1 = sp + 24|0;
 $$byval_copy = sp + 20|0;
 $2 = sp + 16|0;
 $3 = sp + 12|0;
 $4 = sp + 28|0;
 $5 = sp + 8|0;
 $6 = sp + 4|0;
 $7 = sp;
 __THREW__ = 0;
 invoke_viii(4662,($4|0),($0|0),0);
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 L1: do {
  if ($9) {
   $30 = ___cxa_find_matching_catch_3(0|0)|0;
   $31 = tempRet0;
   $$1 = $30;
   label = 12;
  } else {
   $10 = HEAP8[$4>>0]|0;
   $11 = ($10<<24>>24)==(0);
   L4: do {
    if (!($11)) {
     HEAP32[$5>>2] = 0;
     $12 = HEAP32[$0>>2]|0;
     $13 = ((($12)) + -12|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = (($0) + ($14)|0);
     __ZNKSt3__28ios_base6getlocEv($7,$15);
     __THREW__ = 0;
     $16 = (invoke_iii(3255,($7|0),(215212|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     do {
      if ($18) {
       label = 6;
      } else {
       $19 = HEAP32[$0>>2]|0;
       $20 = ((($19)) + -12|0);
       $21 = HEAP32[$20>>2]|0;
       $22 = (($0) + ($21)|0);
       $23 = ((($22)) + 24|0);
       $24 = HEAP32[$23>>2]|0;
       $25 = HEAP32[$16>>2]|0;
       $26 = ((($25)) + 16|0);
       $27 = HEAP32[$26>>2]|0;
       HEAP32[$2>>2] = $24;
       HEAP32[$3>>2] = 0;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy>>2]=HEAP32[$2>>2]|0;
       ;HEAP32[$$byval_copy1>>2]=HEAP32[$3>>2]|0;
       (invoke_iiiiiii($27|0,($16|0),($$byval_copy|0),($$byval_copy1|0),($22|0),($5|0),($6|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if ($29) {
        label = 6;
       } else {
        __ZNSt3__26localeD2Ev($7);
        $34 = HEAP32[$6>>2]|0;
        HEAP32[$1>>2] = $34;
        $35 = HEAP32[$0>>2]|0;
        $36 = ((($35)) + -12|0);
        $37 = HEAP32[$36>>2]|0;
        $38 = (($0) + ($37)|0);
        $39 = HEAP32[$5>>2]|0;
        $40 = ((($38)) + 16|0);
        $41 = HEAP32[$40>>2]|0;
        $42 = $41 | $39;
        __THREW__ = 0;
        invoke_vii(3259,($38|0),($42|0));
        $43 = __THREW__; __THREW__ = 0;
        $44 = $43&1;
        if ($44) {
         $45 = ___cxa_find_matching_catch_3(0|0)|0;
         $46 = tempRet0;
         $$0 = $45;
         break;
        } else {
         break L4;
        }
       }
      }
     } while(0);
     if ((label|0) == 6) {
      $32 = ___cxa_find_matching_catch_3(0|0)|0;
      $33 = tempRet0;
      __ZNSt3__26localeD2Ev($7);
      $$0 = $32;
     }
     $$1 = $$0;
     label = 12;
     break L1;
    }
   } while(0);
  }
 } while(0);
 do {
  if ((label|0) == 12) {
   (___cxa_begin_catch(($$1|0))|0);
   $47 = HEAP32[$0>>2]|0;
   $48 = ((($47)) + -12|0);
   $49 = HEAP32[$48>>2]|0;
   $50 = (($0) + ($49)|0);
   __THREW__ = 0;
   invoke_vi(3260,($50|0));
   $51 = __THREW__; __THREW__ = 0;
   $52 = $51&1;
   if (!($52)) {
    ___cxa_end_catch();
    break;
   }
   $53 = ___cxa_find_matching_catch_2()|0;
   $54 = tempRet0;
   __THREW__ = 0;
   invoke_v(3261);
   $55 = __THREW__; __THREW__ = 0;
   $56 = $55&1;
   if ($56) {
    $57 = ___cxa_find_matching_catch_3(0|0)|0;
    $58 = tempRet0;
    ___clang_call_terminate($57);
    // unreachable;
   } else {
    ___resumeException($53|0);
    // unreachable;
   }
  }
 } while(0);
 STACKTOP = sp;return ($0|0);
}
function __ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEE5flushEv($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $2 = HEAP32[$0>>2]|0;
 $3 = ((($2)) + -12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($0) + ($4)|0);
 $6 = ((($5)) + 24|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 L1: do {
  if (!($8)) {
   __THREW__ = 0;
   invoke_vii(4663,($1|0),($0|0));
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   L3: do {
    if ($10) {
     $35 = ___cxa_find_matching_catch_3(0|0)|0;
     $36 = tempRet0;
     $$0 = $35;
    } else {
     $11 = HEAP8[$1>>0]|0;
     $12 = ($11<<24>>24)==(0);
     do {
      if (!($12)) {
       $13 = HEAP32[$0>>2]|0;
       $14 = ((($13)) + -12|0);
       $15 = HEAP32[$14>>2]|0;
       $16 = (($0) + ($15)|0);
       $17 = ((($16)) + 24|0);
       $18 = HEAP32[$17>>2]|0;
       $19 = HEAP32[$18>>2]|0;
       $20 = ((($19)) + 24|0);
       $21 = HEAP32[$20>>2]|0;
       __THREW__ = 0;
       $22 = (invoke_ii($21|0,($18|0))|0);
       $23 = __THREW__; __THREW__ = 0;
       $24 = $23&1;
       if (!($24)) {
        $25 = ($22|0)==(-1);
        if (!($25)) {
         break;
        }
        $26 = HEAP32[$0>>2]|0;
        $27 = ((($26)) + -12|0);
        $28 = HEAP32[$27>>2]|0;
        $29 = (($0) + ($28)|0);
        $30 = ((($29)) + 16|0);
        $31 = HEAP32[$30>>2]|0;
        $32 = $31 | 1;
        __THREW__ = 0;
        invoke_vii(3259,($29|0),($32|0));
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if (!($34)) {
         break;
        }
       }
       $37 = ___cxa_find_matching_catch_3(0|0)|0;
       $38 = tempRet0;
       __ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEE6sentryD2Ev($1);
       $$0 = $37;
       break L3;
      }
     } while(0);
     __ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEE6sentryD2Ev($1);
     break L1;
    }
   } while(0);
   (___cxa_begin_catch(($$0|0))|0);
   $39 = HEAP32[$0>>2]|0;
   $40 = ((($39)) + -12|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = (($0) + ($41)|0);
   __THREW__ = 0;
   invoke_vi(3260,($42|0));
   $43 = __THREW__; __THREW__ = 0;
   $44 = $43&1;
   if (!($44)) {
    ___cxa_end_catch();
    break;
   }
   $45 = ___cxa_find_matching_catch_2()|0;
   $46 = tempRet0;
   __THREW__ = 0;
   invoke_v(3261);
   $47 = __THREW__; __THREW__ = 0;
   $48 = $47&1;
   if ($48) {
    $49 = ___cxa_find_matching_catch_3(0|0)|0;
    $50 = tempRet0;
    ___clang_call_terminate($49);
    // unreachable;
   } else {
    ___resumeException($45|0);
    // unreachable;
   }
  }
 } while(0);
 STACKTOP = sp;return ($0|0);
}
function __ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEE6sentryC2ERS3_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP8[$0>>0] = 0;
 $2 = ((($0)) + 4|0);
 HEAP32[$2>>2] = $1;
 $3 = HEAP32[$1>>2]|0;
 $4 = ((($3)) + -12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($1) + ($5)|0);
 $7 = ((($6)) + 16|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0);
 if ($9) {
  $10 = ((($6)) + 72|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($11|0)==(0|0);
  if (!($12)) {
   (__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEE5flushEv($11)|0);
  }
  HEAP8[$0>>0] = 1;
 }
 return;
}
function __ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEE6sentryD2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + -12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($2) + ($5)|0);
 $7 = ((($6)) + 24|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 do {
  if (!($9)) {
   $10 = ((($6)) + 16|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = ($11|0)==(0);
   if ($12) {
    $13 = ((($6)) + 4|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = $14 & 8192;
    $16 = ($15|0)==(0);
    if (!($16)) {
     $17 = (__ZSt18uncaught_exceptionv()|0);
     if (!($17)) {
      $18 = HEAP32[$1>>2]|0;
      $19 = HEAP32[$18>>2]|0;
      $20 = ((($19)) + -12|0);
      $21 = HEAP32[$20>>2]|0;
      $22 = (($18) + ($21)|0);
      $23 = ((($22)) + 24|0);
      $24 = HEAP32[$23>>2]|0;
      $25 = HEAP32[$24>>2]|0;
      $26 = ((($25)) + 24|0);
      $27 = HEAP32[$26>>2]|0;
      __THREW__ = 0;
      $28 = (invoke_ii($27|0,($24|0))|0);
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if (!($30)) {
       $31 = ($28|0)==(-1);
       if (!($31)) {
        break;
       }
       $32 = HEAP32[$1>>2]|0;
       $33 = HEAP32[$32>>2]|0;
       $34 = ((($33)) + -12|0);
       $35 = HEAP32[$34>>2]|0;
       $36 = (($32) + ($35)|0);
       $37 = ((($36)) + 16|0);
       $38 = HEAP32[$37>>2]|0;
       $39 = $38 | 1;
       __THREW__ = 0;
       invoke_vii(3259,($36|0),($39|0));
       $40 = __THREW__; __THREW__ = 0;
       $41 = $40&1;
       if (!($41)) {
        break;
       }
      }
      $42 = ___cxa_find_matching_catch_3(0|0)|0;
      $43 = tempRet0;
      (___cxa_begin_catch(($42|0))|0);
      __THREW__ = 0;
      invoke_v(3261);
      $44 = __THREW__; __THREW__ = 0;
      $45 = $44&1;
      if ($45) {
       $46 = ___cxa_find_matching_catch_3(0|0)|0;
       $47 = tempRet0;
       ___clang_call_terminate($46);
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 return;
}
function __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEb($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$1 = 0, $$2 = 0, $$byval_copy = 0, $$pre$i = 0, $$pre$phiZ2D = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $8 = 0, $9 = 0;
 var $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $$byval_copy = sp + 24|0;
 $2 = sp + 20|0;
 $3 = sp + 16|0;
 $4 = sp + 8|0;
 $5 = sp;
 __THREW__ = 0;
 invoke_vii(3256,($4|0),($0|0));
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 L1: do {
  if ($7) {
   $57 = ___cxa_find_matching_catch_3(0|0)|0;
   $58 = tempRet0;
   $$2 = $57;
   label = 20;
  } else {
   $8 = HEAP8[$4>>0]|0;
   $9 = ($8<<24>>24)==(0);
   L4: do {
    if (!($9)) {
     $10 = HEAP32[$0>>2]|0;
     $11 = ((($10)) + -12|0);
     $12 = HEAP32[$11>>2]|0;
     $13 = (($0) + ($12)|0);
     __ZNKSt3__28ios_base6getlocEv($5,$13);
     __THREW__ = 0;
     $14 = (invoke_iii(3255,($5|0),(215244|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     L6: do {
      if ($16) {
       $59 = ___cxa_find_matching_catch_3(0|0)|0;
       $60 = tempRet0;
       __ZNSt3__26localeD2Ev($5);
       $$1 = $59;
      } else {
       __ZNSt3__26localeD2Ev($5);
       $17 = HEAP32[$0>>2]|0;
       $18 = ((($17)) + -12|0);
       $19 = HEAP32[$18>>2]|0;
       $20 = (($0) + ($19)|0);
       $21 = ((($20)) + 24|0);
       $22 = HEAP32[$21>>2]|0;
       $23 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
       $24 = ((($20)) + 76|0);
       $25 = HEAP32[$24>>2]|0;
       $26 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($23,$25)|0);
       do {
        if ($26) {
         __ZNKSt3__28ios_base6getlocEv($3,$20);
         __THREW__ = 0;
         $27 = (invoke_iii(3255,($3|0),(215188|0))|0);
         $28 = __THREW__; __THREW__ = 0;
         $29 = $28&1;
         if (!($29)) {
          $30 = HEAP32[$27>>2]|0;
          $31 = ((($30)) + 28|0);
          $32 = HEAP32[$31>>2]|0;
          __THREW__ = 0;
          $33 = (invoke_iii($32|0,($27|0),32)|0);
          $34 = __THREW__; __THREW__ = 0;
          $35 = $34&1;
          if (!($35)) {
           __ZNSt3__26localeD2Ev($3);
           $38 = $33 << 24 >> 24;
           HEAP32[$24>>2] = $38;
           $$pre$phiZ2D = $20;$40 = $38;
           label = 10;
           break;
          }
         }
         $36 = ___cxa_find_matching_catch_3(0|0)|0;
         $37 = tempRet0;
         __ZNSt3__26localeD2Ev($3);
         $eh$lpad$body$indexZ2D = $36;
        } else {
         $$pre$i = HEAP32[$24>>2]|0;
         $$pre$phiZ2D = $20;$40 = $$pre$i;
         label = 10;
        }
       } while(0);
       do {
        if ((label|0) == 10) {
         $39 = $40&255;
         $41 = HEAP32[$14>>2]|0;
         $42 = ((($41)) + 12|0);
         $43 = HEAP32[$42>>2]|0;
         HEAP32[$2>>2] = $22;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy>>2]=HEAP32[$2>>2]|0;
         $44 = (invoke_iiiiii($43|0,($14|0),($$byval_copy|0),($$pre$phiZ2D|0),($39|0),($1|0))|0);
         $45 = __THREW__; __THREW__ = 0;
         $46 = $45&1;
         if ($46) {
          $61 = ___cxa_find_matching_catch_3(0|0)|0;
          $62 = tempRet0;
          $eh$lpad$body$indexZ2D = $61;
          break;
         }
         $47 = ($44|0)==(0|0);
         if (!($47)) {
          break L4;
         }
         $48 = HEAP32[$0>>2]|0;
         $49 = ((($48)) + -12|0);
         $50 = HEAP32[$49>>2]|0;
         $51 = (($0) + ($50)|0);
         $52 = ((($51)) + 16|0);
         $53 = HEAP32[$52>>2]|0;
         $54 = $53 | 5;
         __THREW__ = 0;
         invoke_vii(3259,($51|0),($54|0));
         $55 = __THREW__; __THREW__ = 0;
         $56 = $55&1;
         if (!($56)) {
          break L4;
         }
         $63 = ___cxa_find_matching_catch_3(0|0)|0;
         $64 = tempRet0;
         $$1 = $63;
         break L6;
        }
       } while(0);
       $$1 = $eh$lpad$body$indexZ2D;
      }
     } while(0);
     __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE6sentryD2Ev($4);
     $$2 = $$1;
     label = 20;
     break L1;
    }
   } while(0);
   __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE6sentryD2Ev($4);
  }
 } while(0);
 do {
  if ((label|0) == 20) {
   (___cxa_begin_catch(($$2|0))|0);
   $65 = HEAP32[$0>>2]|0;
   $66 = ((($65)) + -12|0);
   $67 = HEAP32[$66>>2]|0;
   $68 = (($0) + ($67)|0);
   __THREW__ = 0;
   invoke_vi(3260,($68|0));
   $69 = __THREW__; __THREW__ = 0;
   $70 = $69&1;
   if (!($70)) {
    ___cxa_end_catch();
    break;
   }
   $71 = ___cxa_find_matching_catch_2()|0;
   $72 = tempRet0;
   __THREW__ = 0;
   invoke_v(3261);
   $73 = __THREW__; __THREW__ = 0;
   $74 = $73&1;
   if ($74) {
    $75 = ___cxa_find_matching_catch_3(0|0)|0;
    $76 = tempRet0;
    ___clang_call_terminate($75);
    // unreachable;
   } else {
    ___resumeException($71|0);
    // unreachable;
   }
  }
 } while(0);
 STACKTOP = sp;return ($0|0);
}
function __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$1 = 0, $$2 = 0, $$byval_copy = 0, $$pre$i = 0, $$pre$phiZ2D = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $8 = 0, $9 = 0;
 var $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $$byval_copy = sp + 24|0;
 $2 = sp + 20|0;
 $3 = sp + 16|0;
 $4 = sp + 8|0;
 $5 = sp;
 __THREW__ = 0;
 invoke_vii(3256,($4|0),($0|0));
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 L1: do {
  if ($7) {
   $57 = ___cxa_find_matching_catch_3(0|0)|0;
   $58 = tempRet0;
   $$2 = $57;
   label = 20;
  } else {
   $8 = HEAP8[$4>>0]|0;
   $9 = ($8<<24>>24)==(0);
   L4: do {
    if (!($9)) {
     $10 = HEAP32[$0>>2]|0;
     $11 = ((($10)) + -12|0);
     $12 = HEAP32[$11>>2]|0;
     $13 = (($0) + ($12)|0);
     __ZNKSt3__28ios_base6getlocEv($5,$13);
     __THREW__ = 0;
     $14 = (invoke_iii(3255,($5|0),(215244|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     L6: do {
      if ($16) {
       $59 = ___cxa_find_matching_catch_3(0|0)|0;
       $60 = tempRet0;
       __ZNSt3__26localeD2Ev($5);
       $$1 = $59;
      } else {
       __ZNSt3__26localeD2Ev($5);
       $17 = HEAP32[$0>>2]|0;
       $18 = ((($17)) + -12|0);
       $19 = HEAP32[$18>>2]|0;
       $20 = (($0) + ($19)|0);
       $21 = ((($20)) + 24|0);
       $22 = HEAP32[$21>>2]|0;
       $23 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
       $24 = ((($20)) + 76|0);
       $25 = HEAP32[$24>>2]|0;
       $26 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($23,$25)|0);
       do {
        if ($26) {
         __ZNKSt3__28ios_base6getlocEv($3,$20);
         __THREW__ = 0;
         $27 = (invoke_iii(3255,($3|0),(215188|0))|0);
         $28 = __THREW__; __THREW__ = 0;
         $29 = $28&1;
         if (!($29)) {
          $30 = HEAP32[$27>>2]|0;
          $31 = ((($30)) + 28|0);
          $32 = HEAP32[$31>>2]|0;
          __THREW__ = 0;
          $33 = (invoke_iii($32|0,($27|0),32)|0);
          $34 = __THREW__; __THREW__ = 0;
          $35 = $34&1;
          if (!($35)) {
           __ZNSt3__26localeD2Ev($3);
           $38 = $33 << 24 >> 24;
           HEAP32[$24>>2] = $38;
           $$pre$phiZ2D = $20;$40 = $38;
           label = 10;
           break;
          }
         }
         $36 = ___cxa_find_matching_catch_3(0|0)|0;
         $37 = tempRet0;
         __ZNSt3__26localeD2Ev($3);
         $eh$lpad$body$indexZ2D = $36;
        } else {
         $$pre$i = HEAP32[$24>>2]|0;
         $$pre$phiZ2D = $20;$40 = $$pre$i;
         label = 10;
        }
       } while(0);
       do {
        if ((label|0) == 10) {
         $39 = $40&255;
         $41 = HEAP32[$14>>2]|0;
         $42 = ((($41)) + 16|0);
         $43 = HEAP32[$42>>2]|0;
         HEAP32[$2>>2] = $22;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy>>2]=HEAP32[$2>>2]|0;
         $44 = (invoke_iiiiii($43|0,($14|0),($$byval_copy|0),($$pre$phiZ2D|0),($39|0),($1|0))|0);
         $45 = __THREW__; __THREW__ = 0;
         $46 = $45&1;
         if ($46) {
          $61 = ___cxa_find_matching_catch_3(0|0)|0;
          $62 = tempRet0;
          $eh$lpad$body$indexZ2D = $61;
          break;
         }
         $47 = ($44|0)==(0|0);
         if (!($47)) {
          break L4;
         }
         $48 = HEAP32[$0>>2]|0;
         $49 = ((($48)) + -12|0);
         $50 = HEAP32[$49>>2]|0;
         $51 = (($0) + ($50)|0);
         $52 = ((($51)) + 16|0);
         $53 = HEAP32[$52>>2]|0;
         $54 = $53 | 5;
         __THREW__ = 0;
         invoke_vii(3259,($51|0),($54|0));
         $55 = __THREW__; __THREW__ = 0;
         $56 = $55&1;
         if (!($56)) {
          break L4;
         }
         $63 = ___cxa_find_matching_catch_3(0|0)|0;
         $64 = tempRet0;
         $$1 = $63;
         break L6;
        }
       } while(0);
       $$1 = $eh$lpad$body$indexZ2D;
      }
     } while(0);
     __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE6sentryD2Ev($4);
     $$2 = $$1;
     label = 20;
     break L1;
    }
   } while(0);
   __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE6sentryD2Ev($4);
  }
 } while(0);
 do {
  if ((label|0) == 20) {
   (___cxa_begin_catch(($$2|0))|0);
   $65 = HEAP32[$0>>2]|0;
   $66 = ((($65)) + -12|0);
   $67 = HEAP32[$66>>2]|0;
   $68 = (($0) + ($67)|0);
   __THREW__ = 0;
   invoke_vi(3260,($68|0));
   $69 = __THREW__; __THREW__ = 0;
   $70 = $69&1;
   if (!($70)) {
    ___cxa_end_catch();
    break;
   }
   $71 = ___cxa_find_matching_catch_2()|0;
   $72 = tempRet0;
   __THREW__ = 0;
   invoke_v(3261);
   $73 = __THREW__; __THREW__ = 0;
   $74 = $73&1;
   if ($74) {
    $75 = ___cxa_find_matching_catch_3(0|0)|0;
    $76 = tempRet0;
    ___clang_call_terminate($75);
    // unreachable;
   } else {
    ___resumeException($71|0);
    // unreachable;
   }
  }
 } while(0);
 STACKTOP = sp;return ($0|0);
}
function __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$1 = 0, $$2 = 0, $$byval_copy = 0, $$pre$i = 0, $$pre$phiZ2D = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $8 = 0, $9 = 0;
 var $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $$byval_copy = sp + 24|0;
 $2 = sp + 20|0;
 $3 = sp + 16|0;
 $4 = sp + 8|0;
 $5 = sp;
 __THREW__ = 0;
 invoke_vii(3256,($4|0),($0|0));
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 L1: do {
  if ($7) {
   $57 = ___cxa_find_matching_catch_3(0|0)|0;
   $58 = tempRet0;
   $$2 = $57;
   label = 20;
  } else {
   $8 = HEAP8[$4>>0]|0;
   $9 = ($8<<24>>24)==(0);
   L4: do {
    if (!($9)) {
     $10 = HEAP32[$0>>2]|0;
     $11 = ((($10)) + -12|0);
     $12 = HEAP32[$11>>2]|0;
     $13 = (($0) + ($12)|0);
     __ZNKSt3__28ios_base6getlocEv($5,$13);
     __THREW__ = 0;
     $14 = (invoke_iii(3255,($5|0),(215244|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     L6: do {
      if ($16) {
       $59 = ___cxa_find_matching_catch_3(0|0)|0;
       $60 = tempRet0;
       __ZNSt3__26localeD2Ev($5);
       $$1 = $59;
      } else {
       __ZNSt3__26localeD2Ev($5);
       $17 = HEAP32[$0>>2]|0;
       $18 = ((($17)) + -12|0);
       $19 = HEAP32[$18>>2]|0;
       $20 = (($0) + ($19)|0);
       $21 = ((($20)) + 24|0);
       $22 = HEAP32[$21>>2]|0;
       $23 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
       $24 = ((($20)) + 76|0);
       $25 = HEAP32[$24>>2]|0;
       $26 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($23,$25)|0);
       do {
        if ($26) {
         __ZNKSt3__28ios_base6getlocEv($3,$20);
         __THREW__ = 0;
         $27 = (invoke_iii(3255,($3|0),(215188|0))|0);
         $28 = __THREW__; __THREW__ = 0;
         $29 = $28&1;
         if (!($29)) {
          $30 = HEAP32[$27>>2]|0;
          $31 = ((($30)) + 28|0);
          $32 = HEAP32[$31>>2]|0;
          __THREW__ = 0;
          $33 = (invoke_iii($32|0,($27|0),32)|0);
          $34 = __THREW__; __THREW__ = 0;
          $35 = $34&1;
          if (!($35)) {
           __ZNSt3__26localeD2Ev($3);
           $38 = $33 << 24 >> 24;
           HEAP32[$24>>2] = $38;
           $$pre$phiZ2D = $20;$40 = $38;
           label = 10;
           break;
          }
         }
         $36 = ___cxa_find_matching_catch_3(0|0)|0;
         $37 = tempRet0;
         __ZNSt3__26localeD2Ev($3);
         $eh$lpad$body$indexZ2D = $36;
        } else {
         $$pre$i = HEAP32[$24>>2]|0;
         $$pre$phiZ2D = $20;$40 = $$pre$i;
         label = 10;
        }
       } while(0);
       do {
        if ((label|0) == 10) {
         $39 = $40&255;
         $41 = HEAP32[$14>>2]|0;
         $42 = ((($41)) + 24|0);
         $43 = HEAP32[$42>>2]|0;
         HEAP32[$2>>2] = $22;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy>>2]=HEAP32[$2>>2]|0;
         $44 = (invoke_iiiiii($43|0,($14|0),($$byval_copy|0),($$pre$phiZ2D|0),($39|0),($1|0))|0);
         $45 = __THREW__; __THREW__ = 0;
         $46 = $45&1;
         if ($46) {
          $61 = ___cxa_find_matching_catch_3(0|0)|0;
          $62 = tempRet0;
          $eh$lpad$body$indexZ2D = $61;
          break;
         }
         $47 = ($44|0)==(0|0);
         if (!($47)) {
          break L4;
         }
         $48 = HEAP32[$0>>2]|0;
         $49 = ((($48)) + -12|0);
         $50 = HEAP32[$49>>2]|0;
         $51 = (($0) + ($50)|0);
         $52 = ((($51)) + 16|0);
         $53 = HEAP32[$52>>2]|0;
         $54 = $53 | 5;
         __THREW__ = 0;
         invoke_vii(3259,($51|0),($54|0));
         $55 = __THREW__; __THREW__ = 0;
         $56 = $55&1;
         if (!($56)) {
          break L4;
         }
         $63 = ___cxa_find_matching_catch_3(0|0)|0;
         $64 = tempRet0;
         $$1 = $63;
         break L6;
        }
       } while(0);
       $$1 = $eh$lpad$body$indexZ2D;
      }
     } while(0);
     __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE6sentryD2Ev($4);
     $$2 = $$1;
     label = 20;
     break L1;
    }
   } while(0);
   __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE6sentryD2Ev($4);
  }
 } while(0);
 do {
  if ((label|0) == 20) {
   (___cxa_begin_catch(($$2|0))|0);
   $65 = HEAP32[$0>>2]|0;
   $66 = ((($65)) + -12|0);
   $67 = HEAP32[$66>>2]|0;
   $68 = (($0) + ($67)|0);
   __THREW__ = 0;
   invoke_vi(3260,($68|0));
   $69 = __THREW__; __THREW__ = 0;
   $70 = $69&1;
   if (!($70)) {
    ___cxa_end_catch();
    break;
   }
   $71 = ___cxa_find_matching_catch_2()|0;
   $72 = tempRet0;
   __THREW__ = 0;
   invoke_v(3261);
   $73 = __THREW__; __THREW__ = 0;
   $74 = $73&1;
   if ($74) {
    $75 = ___cxa_find_matching_catch_3(0|0)|0;
    $76 = tempRet0;
    ___clang_call_terminate($75);
    // unreachable;
   } else {
    ___resumeException($71|0);
    // unreachable;
   }
  }
 } while(0);
 STACKTOP = sp;return ($0|0);
}
function __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEf($0,$1) {
 $0 = $0|0;
 $1 = +$1;
 var $$1 = 0, $$2 = 0, $$byval_copy = 0, $$pre$i = 0, $$pre$phiZ2D = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0.0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $8 = 0;
 var $9 = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $$byval_copy = sp + 24|0;
 $2 = sp + 20|0;
 $3 = sp + 16|0;
 $4 = sp + 8|0;
 $5 = sp;
 __THREW__ = 0;
 invoke_vii(3256,($4|0),($0|0));
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 L1: do {
  if ($7) {
   $58 = ___cxa_find_matching_catch_3(0|0)|0;
   $59 = tempRet0;
   $$2 = $58;
   label = 20;
  } else {
   $8 = HEAP8[$4>>0]|0;
   $9 = ($8<<24>>24)==(0);
   L4: do {
    if (!($9)) {
     $10 = HEAP32[$0>>2]|0;
     $11 = ((($10)) + -12|0);
     $12 = HEAP32[$11>>2]|0;
     $13 = (($0) + ($12)|0);
     __ZNKSt3__28ios_base6getlocEv($5,$13);
     __THREW__ = 0;
     $14 = (invoke_iii(3255,($5|0),(215244|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     L6: do {
      if ($16) {
       $60 = ___cxa_find_matching_catch_3(0|0)|0;
       $61 = tempRet0;
       __ZNSt3__26localeD2Ev($5);
       $$1 = $60;
      } else {
       __ZNSt3__26localeD2Ev($5);
       $17 = HEAP32[$0>>2]|0;
       $18 = ((($17)) + -12|0);
       $19 = HEAP32[$18>>2]|0;
       $20 = (($0) + ($19)|0);
       $21 = ((($20)) + 24|0);
       $22 = HEAP32[$21>>2]|0;
       $23 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
       $24 = ((($20)) + 76|0);
       $25 = HEAP32[$24>>2]|0;
       $26 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($23,$25)|0);
       do {
        if ($26) {
         __ZNKSt3__28ios_base6getlocEv($3,$20);
         __THREW__ = 0;
         $27 = (invoke_iii(3255,($3|0),(215188|0))|0);
         $28 = __THREW__; __THREW__ = 0;
         $29 = $28&1;
         if (!($29)) {
          $30 = HEAP32[$27>>2]|0;
          $31 = ((($30)) + 28|0);
          $32 = HEAP32[$31>>2]|0;
          __THREW__ = 0;
          $33 = (invoke_iii($32|0,($27|0),32)|0);
          $34 = __THREW__; __THREW__ = 0;
          $35 = $34&1;
          if (!($35)) {
           __ZNSt3__26localeD2Ev($3);
           $38 = $33 << 24 >> 24;
           HEAP32[$24>>2] = $38;
           $$pre$phiZ2D = $20;$40 = $38;
           label = 10;
           break;
          }
         }
         $36 = ___cxa_find_matching_catch_3(0|0)|0;
         $37 = tempRet0;
         __ZNSt3__26localeD2Ev($3);
         $eh$lpad$body$indexZ2D = $36;
        } else {
         $$pre$i = HEAP32[$24>>2]|0;
         $$pre$phiZ2D = $20;$40 = $$pre$i;
         label = 10;
        }
       } while(0);
       do {
        if ((label|0) == 10) {
         $39 = $40&255;
         $41 = $1;
         $42 = HEAP32[$14>>2]|0;
         $43 = ((($42)) + 32|0);
         $44 = HEAP32[$43>>2]|0;
         HEAP32[$2>>2] = $22;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy>>2]=HEAP32[$2>>2]|0;
         $45 = (invoke_iiiiid($44|0,($14|0),($$byval_copy|0),($$pre$phiZ2D|0),($39|0),(+$41))|0);
         $46 = __THREW__; __THREW__ = 0;
         $47 = $46&1;
         if ($47) {
          $62 = ___cxa_find_matching_catch_3(0|0)|0;
          $63 = tempRet0;
          $eh$lpad$body$indexZ2D = $62;
          break;
         }
         $48 = ($45|0)==(0|0);
         if (!($48)) {
          break L4;
         }
         $49 = HEAP32[$0>>2]|0;
         $50 = ((($49)) + -12|0);
         $51 = HEAP32[$50>>2]|0;
         $52 = (($0) + ($51)|0);
         $53 = ((($52)) + 16|0);
         $54 = HEAP32[$53>>2]|0;
         $55 = $54 | 5;
         __THREW__ = 0;
         invoke_vii(3259,($52|0),($55|0));
         $56 = __THREW__; __THREW__ = 0;
         $57 = $56&1;
         if (!($57)) {
          break L4;
         }
         $64 = ___cxa_find_matching_catch_3(0|0)|0;
         $65 = tempRet0;
         $$1 = $64;
         break L6;
        }
       } while(0);
       $$1 = $eh$lpad$body$indexZ2D;
      }
     } while(0);
     __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE6sentryD2Ev($4);
     $$2 = $$1;
     label = 20;
     break L1;
    }
   } while(0);
   __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE6sentryD2Ev($4);
  }
 } while(0);
 do {
  if ((label|0) == 20) {
   (___cxa_begin_catch(($$2|0))|0);
   $66 = HEAP32[$0>>2]|0;
   $67 = ((($66)) + -12|0);
   $68 = HEAP32[$67>>2]|0;
   $69 = (($0) + ($68)|0);
   __THREW__ = 0;
   invoke_vi(3260,($69|0));
   $70 = __THREW__; __THREW__ = 0;
   $71 = $70&1;
   if (!($71)) {
    ___cxa_end_catch();
    break;
   }
   $72 = ___cxa_find_matching_catch_2()|0;
   $73 = tempRet0;
   __THREW__ = 0;
   invoke_v(3261);
   $74 = __THREW__; __THREW__ = 0;
   $75 = $74&1;
   if ($75) {
    $76 = ___cxa_find_matching_catch_3(0|0)|0;
    $77 = tempRet0;
    ___clang_call_terminate($76);
    // unreachable;
   } else {
    ___resumeException($72|0);
    // unreachable;
   }
  }
 } while(0);
 STACKTOP = sp;return ($0|0);
}
function __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEd($0,$1) {
 $0 = $0|0;
 $1 = +$1;
 var $$1 = 0, $$2 = 0, $$byval_copy = 0, $$pre$i = 0, $$pre$phiZ2D = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $8 = 0, $9 = 0;
 var $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $$byval_copy = sp + 24|0;
 $2 = sp + 20|0;
 $3 = sp + 16|0;
 $4 = sp + 8|0;
 $5 = sp;
 __THREW__ = 0;
 invoke_vii(3256,($4|0),($0|0));
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 L1: do {
  if ($7) {
   $57 = ___cxa_find_matching_catch_3(0|0)|0;
   $58 = tempRet0;
   $$2 = $57;
   label = 20;
  } else {
   $8 = HEAP8[$4>>0]|0;
   $9 = ($8<<24>>24)==(0);
   L4: do {
    if (!($9)) {
     $10 = HEAP32[$0>>2]|0;
     $11 = ((($10)) + -12|0);
     $12 = HEAP32[$11>>2]|0;
     $13 = (($0) + ($12)|0);
     __ZNKSt3__28ios_base6getlocEv($5,$13);
     __THREW__ = 0;
     $14 = (invoke_iii(3255,($5|0),(215244|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     L6: do {
      if ($16) {
       $59 = ___cxa_find_matching_catch_3(0|0)|0;
       $60 = tempRet0;
       __ZNSt3__26localeD2Ev($5);
       $$1 = $59;
      } else {
       __ZNSt3__26localeD2Ev($5);
       $17 = HEAP32[$0>>2]|0;
       $18 = ((($17)) + -12|0);
       $19 = HEAP32[$18>>2]|0;
       $20 = (($0) + ($19)|0);
       $21 = ((($20)) + 24|0);
       $22 = HEAP32[$21>>2]|0;
       $23 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
       $24 = ((($20)) + 76|0);
       $25 = HEAP32[$24>>2]|0;
       $26 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($23,$25)|0);
       do {
        if ($26) {
         __ZNKSt3__28ios_base6getlocEv($3,$20);
         __THREW__ = 0;
         $27 = (invoke_iii(3255,($3|0),(215188|0))|0);
         $28 = __THREW__; __THREW__ = 0;
         $29 = $28&1;
         if (!($29)) {
          $30 = HEAP32[$27>>2]|0;
          $31 = ((($30)) + 28|0);
          $32 = HEAP32[$31>>2]|0;
          __THREW__ = 0;
          $33 = (invoke_iii($32|0,($27|0),32)|0);
          $34 = __THREW__; __THREW__ = 0;
          $35 = $34&1;
          if (!($35)) {
           __ZNSt3__26localeD2Ev($3);
           $38 = $33 << 24 >> 24;
           HEAP32[$24>>2] = $38;
           $$pre$phiZ2D = $20;$40 = $38;
           label = 10;
           break;
          }
         }
         $36 = ___cxa_find_matching_catch_3(0|0)|0;
         $37 = tempRet0;
         __ZNSt3__26localeD2Ev($3);
         $eh$lpad$body$indexZ2D = $36;
        } else {
         $$pre$i = HEAP32[$24>>2]|0;
         $$pre$phiZ2D = $20;$40 = $$pre$i;
         label = 10;
        }
       } while(0);
       do {
        if ((label|0) == 10) {
         $39 = $40&255;
         $41 = HEAP32[$14>>2]|0;
         $42 = ((($41)) + 32|0);
         $43 = HEAP32[$42>>2]|0;
         HEAP32[$2>>2] = $22;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy>>2]=HEAP32[$2>>2]|0;
         $44 = (invoke_iiiiid($43|0,($14|0),($$byval_copy|0),($$pre$phiZ2D|0),($39|0),(+$1))|0);
         $45 = __THREW__; __THREW__ = 0;
         $46 = $45&1;
         if ($46) {
          $61 = ___cxa_find_matching_catch_3(0|0)|0;
          $62 = tempRet0;
          $eh$lpad$body$indexZ2D = $61;
          break;
         }
         $47 = ($44|0)==(0|0);
         if (!($47)) {
          break L4;
         }
         $48 = HEAP32[$0>>2]|0;
         $49 = ((($48)) + -12|0);
         $50 = HEAP32[$49>>2]|0;
         $51 = (($0) + ($50)|0);
         $52 = ((($51)) + 16|0);
         $53 = HEAP32[$52>>2]|0;
         $54 = $53 | 5;
         __THREW__ = 0;
         invoke_vii(3259,($51|0),($54|0));
         $55 = __THREW__; __THREW__ = 0;
         $56 = $55&1;
         if (!($56)) {
          break L4;
         }
         $63 = ___cxa_find_matching_catch_3(0|0)|0;
         $64 = tempRet0;
         $$1 = $63;
         break L6;
        }
       } while(0);
       $$1 = $eh$lpad$body$indexZ2D;
      }
     } while(0);
     __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE6sentryD2Ev($4);
     $$2 = $$1;
     label = 20;
     break L1;
    }
   } while(0);
   __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE6sentryD2Ev($4);
  }
 } while(0);
 do {
  if ((label|0) == 20) {
   (___cxa_begin_catch(($$2|0))|0);
   $65 = HEAP32[$0>>2]|0;
   $66 = ((($65)) + -12|0);
   $67 = HEAP32[$66>>2]|0;
   $68 = (($0) + ($67)|0);
   __THREW__ = 0;
   invoke_vi(3260,($68|0));
   $69 = __THREW__; __THREW__ = 0;
   $70 = $69&1;
   if (!($70)) {
    ___cxa_end_catch();
    break;
   }
   $71 = ___cxa_find_matching_catch_2()|0;
   $72 = tempRet0;
   __THREW__ = 0;
   invoke_v(3261);
   $73 = __THREW__; __THREW__ = 0;
   $74 = $73&1;
   if ($74) {
    $75 = ___cxa_find_matching_catch_3(0|0)|0;
    $76 = tempRet0;
    ___clang_call_terminate($75);
    // unreachable;
   } else {
    ___resumeException($71|0);
    // unreachable;
   }
  }
 } while(0);
 STACKTOP = sp;return ($0|0);
}
function __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEPKv($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$1 = 0, $$2 = 0, $$byval_copy = 0, $$pre$i = 0, $$pre$phiZ2D = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $8 = 0, $9 = 0;
 var $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $$byval_copy = sp + 24|0;
 $2 = sp + 20|0;
 $3 = sp + 16|0;
 $4 = sp + 8|0;
 $5 = sp;
 __THREW__ = 0;
 invoke_vii(3256,($4|0),($0|0));
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 L1: do {
  if ($7) {
   $57 = ___cxa_find_matching_catch_3(0|0)|0;
   $58 = tempRet0;
   $$2 = $57;
   label = 20;
  } else {
   $8 = HEAP8[$4>>0]|0;
   $9 = ($8<<24>>24)==(0);
   L4: do {
    if (!($9)) {
     $10 = HEAP32[$0>>2]|0;
     $11 = ((($10)) + -12|0);
     $12 = HEAP32[$11>>2]|0;
     $13 = (($0) + ($12)|0);
     __ZNKSt3__28ios_base6getlocEv($5,$13);
     __THREW__ = 0;
     $14 = (invoke_iii(3255,($5|0),(215244|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     L6: do {
      if ($16) {
       $59 = ___cxa_find_matching_catch_3(0|0)|0;
       $60 = tempRet0;
       __ZNSt3__26localeD2Ev($5);
       $$1 = $59;
      } else {
       __ZNSt3__26localeD2Ev($5);
       $17 = HEAP32[$0>>2]|0;
       $18 = ((($17)) + -12|0);
       $19 = HEAP32[$18>>2]|0;
       $20 = (($0) + ($19)|0);
       $21 = ((($20)) + 24|0);
       $22 = HEAP32[$21>>2]|0;
       $23 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
       $24 = ((($20)) + 76|0);
       $25 = HEAP32[$24>>2]|0;
       $26 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($23,$25)|0);
       do {
        if ($26) {
         __ZNKSt3__28ios_base6getlocEv($3,$20);
         __THREW__ = 0;
         $27 = (invoke_iii(3255,($3|0),(215188|0))|0);
         $28 = __THREW__; __THREW__ = 0;
         $29 = $28&1;
         if (!($29)) {
          $30 = HEAP32[$27>>2]|0;
          $31 = ((($30)) + 28|0);
          $32 = HEAP32[$31>>2]|0;
          __THREW__ = 0;
          $33 = (invoke_iii($32|0,($27|0),32)|0);
          $34 = __THREW__; __THREW__ = 0;
          $35 = $34&1;
          if (!($35)) {
           __ZNSt3__26localeD2Ev($3);
           $38 = $33 << 24 >> 24;
           HEAP32[$24>>2] = $38;
           $$pre$phiZ2D = $20;$40 = $38;
           label = 10;
           break;
          }
         }
         $36 = ___cxa_find_matching_catch_3(0|0)|0;
         $37 = tempRet0;
         __ZNSt3__26localeD2Ev($3);
         $eh$lpad$body$indexZ2D = $36;
        } else {
         $$pre$i = HEAP32[$24>>2]|0;
         $$pre$phiZ2D = $20;$40 = $$pre$i;
         label = 10;
        }
       } while(0);
       do {
        if ((label|0) == 10) {
         $39 = $40&255;
         $41 = HEAP32[$14>>2]|0;
         $42 = ((($41)) + 40|0);
         $43 = HEAP32[$42>>2]|0;
         HEAP32[$2>>2] = $22;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy>>2]=HEAP32[$2>>2]|0;
         $44 = (invoke_iiiiii($43|0,($14|0),($$byval_copy|0),($$pre$phiZ2D|0),($39|0),($1|0))|0);
         $45 = __THREW__; __THREW__ = 0;
         $46 = $45&1;
         if ($46) {
          $61 = ___cxa_find_matching_catch_3(0|0)|0;
          $62 = tempRet0;
          $eh$lpad$body$indexZ2D = $61;
          break;
         }
         $47 = ($44|0)==(0|0);
         if (!($47)) {
          break L4;
         }
         $48 = HEAP32[$0>>2]|0;
         $49 = ((($48)) + -12|0);
         $50 = HEAP32[$49>>2]|0;
         $51 = (($0) + ($50)|0);
         $52 = ((($51)) + 16|0);
         $53 = HEAP32[$52>>2]|0;
         $54 = $53 | 5;
         __THREW__ = 0;
         invoke_vii(3259,($51|0),($54|0));
         $55 = __THREW__; __THREW__ = 0;
         $56 = $55&1;
         if (!($56)) {
          break L4;
         }
         $63 = ___cxa_find_matching_catch_3(0|0)|0;
         $64 = tempRet0;
         $$1 = $63;
         break L6;
        }
       } while(0);
       $$1 = $eh$lpad$body$indexZ2D;
      }
     } while(0);
     __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE6sentryD2Ev($4);
     $$2 = $$1;
     label = 20;
     break L1;
    }
   } while(0);
   __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE6sentryD2Ev($4);
  }
 } while(0);
 do {
  if ((label|0) == 20) {
   (___cxa_begin_catch(($$2|0))|0);
   $65 = HEAP32[$0>>2]|0;
   $66 = ((($65)) + -12|0);
   $67 = HEAP32[$66>>2]|0;
   $68 = (($0) + ($67)|0);
   __THREW__ = 0;
   invoke_vi(3260,($68|0));
   $69 = __THREW__; __THREW__ = 0;
   $70 = $69&1;
   if (!($70)) {
    ___cxa_end_catch();
    break;
   }
   $71 = ___cxa_find_matching_catch_2()|0;
   $72 = tempRet0;
   __THREW__ = 0;
   invoke_v(3261);
   $73 = __THREW__; __THREW__ = 0;
   $74 = $73&1;
   if ($74) {
    $75 = ___cxa_find_matching_catch_3(0|0)|0;
    $76 = tempRet0;
    ___clang_call_terminate($75);
    // unreachable;
   } else {
    ___resumeException($71|0);
    // unreachable;
   }
  }
 } while(0);
 STACKTOP = sp;return ($0|0);
}
function __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$0$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 __THREW__ = 0;
 invoke_vii(3256,($2|0),($0|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 L1: do {
  if ($4) {
   $41 = ___cxa_find_matching_catch_3(0|0)|0;
   $42 = tempRet0;
   $$0 = $41;
   label = 12;
  } else {
   $5 = HEAP8[$2>>0]|0;
   $6 = ($5<<24>>24)==(0);
   L4: do {
    if (!($6)) {
     $7 = HEAP32[$0>>2]|0;
     $8 = ((($7)) + -12|0);
     $9 = HEAP32[$8>>2]|0;
     $10 = (($0) + ($9)|0);
     $11 = ((($10)) + 24|0);
     $12 = HEAP32[$11>>2]|0;
     $13 = $12;
     $14 = ($12|0)==(0);
     do {
      if ($14) {
       label = 8;
      } else {
       $15 = ((($13)) + 24|0);
       $16 = HEAP32[$15>>2]|0;
       $17 = ((($13)) + 28|0);
       $18 = HEAP32[$17>>2]|0;
       $19 = ($16|0)==($18|0);
       if ($19) {
        $20 = $12;
        $21 = HEAP32[$20>>2]|0;
        $22 = ((($21)) + 52|0);
        $23 = HEAP32[$22>>2]|0;
        $24 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($1)|0);
        __THREW__ = 0;
        $25 = (invoke_iii($23|0,($13|0),($24|0))|0);
        $26 = __THREW__; __THREW__ = 0;
        $27 = $26&1;
        if ($27) {
         break;
        } else {
         $$0$i$i = $25;
        }
       } else {
        $28 = ((($16)) + 1|0);
        HEAP32[$15>>2] = $28;
        HEAP8[$16>>0] = $1;
        $29 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($1)|0);
        $$0$i$i = $29;
       }
       $30 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
       $31 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i,$30)|0);
       if ($31) {
        label = 8;
       } else {
        break L4;
       }
      }
     } while(0);
     if ((label|0) == 8) {
      $32 = HEAP32[$0>>2]|0;
      $33 = ((($32)) + -12|0);
      $34 = HEAP32[$33>>2]|0;
      $35 = (($0) + ($34)|0);
      $36 = ((($35)) + 16|0);
      $37 = HEAP32[$36>>2]|0;
      $38 = $37 | 1;
      __THREW__ = 0;
      invoke_vii(3259,($35|0),($38|0));
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       break;
      }
     }
     $43 = ___cxa_find_matching_catch_3(0|0)|0;
     $44 = tempRet0;
     __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE6sentryD2Ev($2);
     $$0 = $43;
     label = 12;
     break L1;
    }
   } while(0);
   __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE6sentryD2Ev($2);
  }
 } while(0);
 do {
  if ((label|0) == 12) {
   (___cxa_begin_catch(($$0|0))|0);
   $45 = HEAP32[$0>>2]|0;
   $46 = ((($45)) + -12|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = (($0) + ($47)|0);
   __THREW__ = 0;
   invoke_vi(3260,($48|0));
   $49 = __THREW__; __THREW__ = 0;
   $50 = $49&1;
   if (!($50)) {
    ___cxa_end_catch();
    break;
   }
   $51 = ___cxa_find_matching_catch_2()|0;
   $52 = tempRet0;
   __THREW__ = 0;
   invoke_v(3261);
   $53 = __THREW__; __THREW__ = 0;
   $54 = $53&1;
   if ($54) {
    $55 = ___cxa_find_matching_catch_3(0|0)|0;
    $56 = tempRet0;
    ___clang_call_terminate($55);
    // unreachable;
   } else {
    ___resumeException($51|0);
    // unreachable;
   }
  }
 } while(0);
 STACKTOP = sp;return ($0|0);
}
function __GLOBAL__I_000101() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 ___cxx_global_var_init_6365();
 return;
}
function __GLOBAL__sub_I_iostream_cpp() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function ___cxx_global_var_init_6365() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__28ios_base4InitC2Ev(0);
 (___cxa_atexit((4664|0),(221530|0),(___dso_handle|0))|0);
 return;
}
function __ZNSt3__28ios_base4InitC2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[23120]|0;
 __ZNSt3__210__stdinbufIcEC2EP8_IO_FILEP11__mbstate_t(214820,$1,214876);
 HEAP32[53535] = (96228);
 HEAP32[(214148)>>2] = (96248);
 HEAP32[(214144)>>2] = 0;
 __THREW__ = 0;
 invoke_vii(3368,((214148)|0),(214820|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch_2()|0;
  $5 = tempRet0;
  __ZNSt3__29basic_iosIcNS_11char_traitsIcEEED2Ev((214148));
  ___resumeException($4|0);
  // unreachable;
 }
 HEAP32[(214220)>>2] = 0;
 $6 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
 HEAP32[(214224)>>2] = $6;
 __ZNSt3__210__stdinbufIwEC2EP8_IO_FILEP11__mbstate_t(214884,$1,214940);
 HEAP32[53557] = (96276);
 HEAP32[(214236)>>2] = (96296);
 HEAP32[(214232)>>2] = 0;
 __THREW__ = 0;
 invoke_vii(3368,((214236)|0),(214884|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch_2()|0;
  $10 = tempRet0;
  __ZNSt3__29basic_iosIwNS_11char_traitsIwEEED2Ev((214236));
  ___resumeException($9|0);
  // unreachable;
 }
 HEAP32[(214308)>>2] = 0;
 $11 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
 HEAP32[(214312)>>2] = $11;
 $12 = HEAP32[23026]|0;
 __ZNSt3__211__stdoutbufIcEC2EP8_IO_FILEP11__mbstate_t(214948,$12,214996);
 HEAP32[53579] = (3820);
 HEAP32[(214320)>>2] = (3840);
 __THREW__ = 0;
 invoke_vii(3368,((214320)|0),(214948|0));
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 if ($14) {
  $15 = ___cxa_find_matching_catch_2()|0;
  $16 = tempRet0;
  __ZNSt3__29basic_iosIcNS_11char_traitsIcEEED2Ev((214320));
  ___resumeException($15|0);
  // unreachable;
 }
 HEAP32[(214392)>>2] = 0;
 $17 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
 HEAP32[(214396)>>2] = $17;
 __ZNSt3__211__stdoutbufIwEC2EP8_IO_FILEP11__mbstate_t(215004,$12,215052);
 HEAP32[53600] = (96332);
 HEAP32[(214404)>>2] = (96352);
 __THREW__ = 0;
 invoke_vii(3368,((214404)|0),(215004|0));
 $18 = __THREW__; __THREW__ = 0;
 $19 = $18&1;
 if ($19) {
  $20 = ___cxa_find_matching_catch_2()|0;
  $21 = tempRet0;
  __ZNSt3__29basic_iosIwNS_11char_traitsIwEEED2Ev((214404));
  ___resumeException($20|0);
  // unreachable;
 }
 HEAP32[(214476)>>2] = 0;
 $22 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
 HEAP32[(214480)>>2] = $22;
 $23 = HEAP32[23152]|0;
 __ZNSt3__211__stdoutbufIcEC2EP8_IO_FILEP11__mbstate_t(215060,$23,215108);
 HEAP32[53621] = (3820);
 HEAP32[(214488)>>2] = (3840);
 __THREW__ = 0;
 invoke_vii(3368,((214488)|0),(215060|0));
 $24 = __THREW__; __THREW__ = 0;
 $25 = $24&1;
 if ($25) {
  $26 = ___cxa_find_matching_catch_2()|0;
  $27 = tempRet0;
  __ZNSt3__29basic_iosIcNS_11char_traitsIcEEED2Ev((214488));
  ___resumeException($26|0);
  // unreachable;
 }
 HEAP32[(214560)>>2] = 0;
 $28 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
 HEAP32[(214564)>>2] = $28;
 $29 = HEAP32[53621]|0;
 $30 = ((($29)) + -12|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (214484 + ($31)|0);
 $33 = ((($32)) + 24|0);
 $34 = HEAP32[$33>>2]|0;
 HEAP32[53663] = (3820);
 HEAP32[(214656)>>2] = (3840);
 __THREW__ = 0;
 invoke_vii(3368,((214656)|0),($34|0));
 $35 = __THREW__; __THREW__ = 0;
 $36 = $35&1;
 if ($36) {
  $37 = ___cxa_find_matching_catch_2()|0;
  $38 = tempRet0;
  __ZNSt3__29basic_iosIcNS_11char_traitsIcEEED2Ev((214656));
  ___resumeException($37|0);
  // unreachable;
 }
 HEAP32[(214728)>>2] = 0;
 $39 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
 HEAP32[(214732)>>2] = $39;
 __ZNSt3__211__stdoutbufIwEC2EP8_IO_FILEP11__mbstate_t(215116,$23,215164);
 HEAP32[53642] = (96332);
 HEAP32[(214572)>>2] = (96352);
 __THREW__ = 0;
 invoke_vii(3368,((214572)|0),(215116|0));
 $40 = __THREW__; __THREW__ = 0;
 $41 = $40&1;
 if ($41) {
  $42 = ___cxa_find_matching_catch_2()|0;
  $43 = tempRet0;
  __ZNSt3__29basic_iosIwNS_11char_traitsIwEEED2Ev((214572));
  ___resumeException($42|0);
  // unreachable;
 }
 HEAP32[(214644)>>2] = 0;
 $44 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
 HEAP32[(214648)>>2] = $44;
 $45 = HEAP32[53642]|0;
 $46 = ((($45)) + -12|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = (214568 + ($47)|0);
 $49 = ((($48)) + 24|0);
 $50 = HEAP32[$49>>2]|0;
 HEAP32[53684] = (96332);
 HEAP32[(214740)>>2] = (96352);
 __THREW__ = 0;
 invoke_vii(3368,((214740)|0),($50|0));
 $51 = __THREW__; __THREW__ = 0;
 $52 = $51&1;
 if ($52) {
  $53 = ___cxa_find_matching_catch_2()|0;
  $54 = tempRet0;
  __ZNSt3__29basic_iosIwNS_11char_traitsIwEEED2Ev((214740));
  ___resumeException($53|0);
  // unreachable;
 } else {
  HEAP32[(214812)>>2] = 0;
  $55 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
  HEAP32[(214816)>>2] = $55;
  $56 = HEAP32[53535]|0;
  $57 = ((($56)) + -12|0);
  $58 = HEAP32[$57>>2]|0;
  $59 = (214140 + ($58)|0);
  $60 = ((($59)) + 72|0);
  HEAP32[$60>>2] = 214316;
  $61 = HEAP32[53557]|0;
  $62 = ((($61)) + -12|0);
  $63 = HEAP32[$62>>2]|0;
  $64 = (214228 + ($63)|0);
  $65 = ((($64)) + 72|0);
  HEAP32[$65>>2] = 214400;
  $66 = HEAP32[53621]|0;
  $67 = ((($66)) + -12|0);
  $68 = HEAP32[$67>>2]|0;
  $69 = (214484 + ($68)|0);
  $70 = ((($69)) + 4|0);
  $71 = HEAP32[$70>>2]|0;
  $72 = $71 | 8192;
  HEAP32[$70>>2] = $72;
  $73 = HEAP32[53642]|0;
  $74 = ((($73)) + -12|0);
  $75 = HEAP32[$74>>2]|0;
  $76 = (214568 + ($75)|0);
  $77 = ((($76)) + 4|0);
  $78 = HEAP32[$77>>2]|0;
  $79 = $78 | 8192;
  HEAP32[$77>>2] = $79;
  $80 = HEAP32[53621]|0;
  $81 = ((($80)) + -12|0);
  $82 = HEAP32[$81>>2]|0;
  $83 = (214484 + ($82)|0);
  $84 = ((($83)) + 72|0);
  HEAP32[$84>>2] = 214316;
  $85 = HEAP32[53642]|0;
  $86 = ((($85)) + -12|0);
  $87 = HEAP32[$86>>2]|0;
  $88 = (214568 + ($87)|0);
  $89 = ((($88)) + 72|0);
  HEAP32[$89>>2] = 214400;
  return;
 }
}
function __ZNSt3__28ios_base4InitD2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 (invoke_ii(3269,(214316|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  (invoke_ii(4665,(214400|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   (invoke_ii(3269,(214652|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    (invoke_ii(4665,(214736|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     return;
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch_3(0|0)|0;
 $10 = tempRet0;
 ___clang_call_terminate($9);
 // unreachable;
}
function __ZNSt3__210__stdinbufIcEC2EP8_IO_FILEP11__mbstate_t($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEEC2Ev($0);
 HEAP32[$0>>2] = (96716);
 $4 = ((($0)) + 32|0);
 HEAP32[$4>>2] = $1;
 $5 = ((($0)) + 40|0);
 HEAP32[$5>>2] = $2;
 $6 = ((($0)) + 48|0);
 $7 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
 HEAP32[$6>>2] = $7;
 $8 = ((($0)) + 52|0);
 HEAP8[$8>>0] = 0;
 $9 = HEAP32[$0>>2]|0;
 $10 = ((($9)) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($0)) + 4|0);
 __ZNSt3__26localeC2ERKS0_($3,$12);
 __THREW__ = 0;
 invoke_vii($11|0,($0|0),($3|0));
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 if ($14) {
  $15 = ___cxa_find_matching_catch_2()|0;
  $16 = tempRet0;
  __ZNSt3__26localeD2Ev($3);
  __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEED2Ev($0);
  ___resumeException($15|0);
  // unreachable;
 } else {
  __ZNSt3__26localeD2Ev($3);
  STACKTOP = sp;return;
 }
}
function __ZNSt3__210__stdinbufIwEC2EP8_IO_FILEP11__mbstate_t($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 __ZNSt3__215basic_streambufIwNS_11char_traitsIwEEEC2Ev($0);
 HEAP32[$0>>2] = (96652);
 $4 = ((($0)) + 32|0);
 HEAP32[$4>>2] = $1;
 $5 = ((($0)) + 40|0);
 HEAP32[$5>>2] = $2;
 $6 = ((($0)) + 48|0);
 $7 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
 HEAP32[$6>>2] = $7;
 $8 = ((($0)) + 52|0);
 HEAP8[$8>>0] = 0;
 $9 = HEAP32[$0>>2]|0;
 $10 = ((($9)) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($0)) + 4|0);
 __ZNSt3__26localeC2ERKS0_($3,$12);
 __THREW__ = 0;
 invoke_vii($11|0,($0|0),($3|0));
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 if ($14) {
  $15 = ___cxa_find_matching_catch_2()|0;
  $16 = tempRet0;
  __ZNSt3__26localeD2Ev($3);
  __ZNSt3__215basic_streambufIwNS_11char_traitsIwEEED2Ev($0);
  ___resumeException($15|0);
  // unreachable;
 } else {
  __ZNSt3__26localeD2Ev($3);
  STACKTOP = sp;return;
 }
}
function __ZNSt3__211__stdoutbufIcEC2EP8_IO_FILEP11__mbstate_t($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEEC2Ev($0);
 HEAP32[$0>>2] = (96588);
 $4 = ((($0)) + 32|0);
 HEAP32[$4>>2] = $1;
 $5 = ((($0)) + 4|0);
 __ZNSt3__26localeC2ERKS0_($3,$5);
 __THREW__ = 0;
 $6 = (invoke_iii(3255,($3|0),(216980|0))|0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $17 = ___cxa_find_matching_catch_2()|0;
  $18 = tempRet0;
  __ZNSt3__26localeD2Ev($3);
  __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEED2Ev($0);
  ___resumeException($17|0);
  // unreachable;
 } else {
  $9 = ((($0)) + 36|0);
  __ZNSt3__26localeD2Ev($3);
  HEAP32[$9>>2] = $6;
  $10 = ((($0)) + 40|0);
  HEAP32[$10>>2] = $2;
  $11 = ((($0)) + 44|0);
  $12 = HEAP32[$6>>2]|0;
  $13 = ((($12)) + 28|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (FUNCTION_TABLE_ii[$14 & 8191]($6)|0);
  $16 = $15&1;
  HEAP8[$11>>0] = $16;
  STACKTOP = sp;return;
 }
}
function __ZNSt3__211__stdoutbufIwEC2EP8_IO_FILEP11__mbstate_t($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 __ZNSt3__215basic_streambufIwNS_11char_traitsIwEEEC2Ev($0);
 HEAP32[$0>>2] = (96524);
 $4 = ((($0)) + 32|0);
 HEAP32[$4>>2] = $1;
 $5 = ((($0)) + 4|0);
 __ZNSt3__26localeC2ERKS0_($3,$5);
 __THREW__ = 0;
 $6 = (invoke_iii(3255,($3|0),(216988|0))|0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $17 = ___cxa_find_matching_catch_2()|0;
  $18 = tempRet0;
  __ZNSt3__26localeD2Ev($3);
  __ZNSt3__215basic_streambufIwNS_11char_traitsIwEEED2Ev($0);
  ___resumeException($17|0);
  // unreachable;
 } else {
  $9 = ((($0)) + 36|0);
  __ZNSt3__26localeD2Ev($3);
  HEAP32[$9>>2] = $6;
  $10 = ((($0)) + 40|0);
  HEAP32[$10>>2] = $2;
  $11 = ((($0)) + 44|0);
  $12 = HEAP32[$6>>2]|0;
  $13 = ((($12)) + 28|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (FUNCTION_TABLE_ii[$14 & 8191]($6)|0);
  $16 = $15&1;
  HEAP8[$11>>0] = $16;
  STACKTOP = sp;return;
 }
}
function __ZNSt3__211__stdoutbufIwED2Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__215basic_streambufIwNS_11char_traitsIwEEED2Ev($0);
 return;
}
function __ZNSt3__211__stdoutbufIwED0Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__211__stdoutbufIwED2Ev($0);
 __ZdlPv($0);
 return;
}
function __ZNSt3__211__stdoutbufIwE5imbueERKNS_6localeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $3 = ((($2)) + 24|0);
 $4 = HEAP32[$3>>2]|0;
 (FUNCTION_TABLE_ii[$4 & 8191]($0)|0);
 $5 = (__ZNKSt3__26locale9use_facetERNS0_2idE($1,216988)|0);
 $6 = ((($0)) + 36|0);
 HEAP32[$6>>2] = $5;
 $7 = HEAP32[$5>>2]|0;
 $8 = ((($7)) + 28|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (FUNCTION_TABLE_ii[$9 & 8191]($5)|0);
 $11 = ((($0)) + 44|0);
 $12 = $10&1;
 HEAP8[$11>>0] = $12;
 return;
}
function __ZNSt3__211__stdoutbufIwE4syncEv($0) {
 $0 = $0|0;
 var $$10 = 0, $$2 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $not$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp + 8|0;
 $2 = sp;
 $3 = ((($0)) + 36|0);
 $4 = ((($0)) + 40|0);
 $5 = ((($1)) + 8|0);
 $6 = $1;
 $7 = ((($0)) + 32|0);
 L1: while(1) {
  $8 = HEAP32[$3>>2]|0;
  $9 = HEAP32[$4>>2]|0;
  $10 = HEAP32[$8>>2]|0;
  $11 = ((($10)) + 20|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (FUNCTION_TABLE_iiiiii[$12 & 8191]($8,$9,$1,$5,$2)|0);
  $14 = HEAP32[$2>>2]|0;
  $15 = (($14) - ($6))|0;
  $16 = HEAP32[$7>>2]|0;
  $17 = (_fwrite($1,1,$15,$16)|0);
  $18 = ($17|0)==($15|0);
  if (!($18)) {
   $$2 = -1;
   break;
  }
  switch ($13|0) {
  case 1:  {
   break;
  }
  case 2:  {
   $$2 = -1;
   break L1;
   break;
  }
  default: {
   label = 4;
   break L1;
  }
  }
 }
 if ((label|0) == 4) {
  $19 = HEAP32[$7>>2]|0;
  $20 = (_fflush($19)|0);
  $not$ = ($20|0)!=(0);
  $$10 = $not$ << 31 >> 31;
  $$2 = $$10;
 }
 STACKTOP = sp;return ($$2|0);
}
function __ZNSt3__211__stdoutbufIwE6xsputnEPKwi($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$010 = 0, $$011 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 44|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)==(0);
 L1: do {
  if ($5) {
   $$0 = 0;$$011 = $1;
   while(1) {
    $9 = ($$0|0)<($2|0);
    if (!($9)) {
     $$010 = $$0;
     break L1;
    }
    $10 = HEAP32[$0>>2]|0;
    $11 = ((($10)) + 52|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = HEAP32[$$011>>2]|0;
    $14 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($13)|0);
    $15 = (FUNCTION_TABLE_iii[$12 & 8191]($0,$14)|0);
    $16 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
    $17 = ($15|0)==($16|0);
    if ($17) {
     $$010 = $$0;
     break L1;
    }
    $18 = (($$0) + 1)|0;
    $19 = ((($$011)) + 4|0);
    $$0 = $18;$$011 = $19;
   }
  } else {
   $6 = ((($0)) + 32|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = (_fwrite($1,4,$2,$7)|0);
   $$010 = $8;
  }
 } while(0);
 return ($$010|0);
}
function __ZNSt3__211__stdoutbufIwE8overflowEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$$032 = 0, $$032 = 0, $$4 = 0, $$436 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $2 = sp + 16|0;
 $3 = sp + 8|0;
 $4 = sp + 4|0;
 $5 = sp;
 $6 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
 $7 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($1,$6)|0);
 do {
  if ($7) {
   label = 15;
  } else {
   $8 = (__ZNSt3__211char_traitsIwE12to_char_typeEj($1)|0);
   HEAP32[$3>>2] = $8;
   $9 = ((($0)) + 44|0);
   $10 = HEAP8[$9>>0]|0;
   $11 = ($10<<24>>24)==(0);
   $12 = ((($0)) + 32|0);
   if (!($11)) {
    $13 = HEAP32[$12>>2]|0;
    $14 = (_fwrite($3,4,1,$13)|0);
    $15 = ($14|0)==(1);
    if ($15) {
     label = 15;
     break;
    }
    $16 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
    $$4 = $16;
    break;
   }
   HEAP32[$4>>2] = $2;
   $17 = ((($3)) + 4|0);
   $18 = ((($0)) + 36|0);
   $19 = ((($0)) + 40|0);
   $20 = ((($2)) + 8|0);
   $21 = $2;
   $$032 = $3;
   while(1) {
    $22 = HEAP32[$18>>2]|0;
    $23 = HEAP32[$19>>2]|0;
    $24 = HEAP32[$22>>2]|0;
    $25 = ((($24)) + 12|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = (FUNCTION_TABLE_iiiiiiiii[$26 & 8191]($22,$23,$$032,$17,$5,$2,$20,$4)|0);
    $28 = HEAP32[$5>>2]|0;
    $29 = ($28|0)==($$032|0);
    $30 = ($27|0)==(1);
    if ($29) {
     label = 14;
     break;
    }
    $31 = ($27|0)==(3);
    if ($31) {
     $32 = HEAP32[$12>>2]|0;
     $33 = (_fwrite($$032,1,1,$32)|0);
     $34 = ($33|0)==(1);
     if ($34) {
      $$436 = $$032;
     } else {
      label = 14;
      break;
     }
    } else {
     $35 = $27 | 1;
     $36 = ($35|0)==(1);
     if (!($36)) {
      label = 14;
      break;
     }
     $37 = HEAP32[$4>>2]|0;
     $38 = (($37) - ($21))|0;
     $39 = HEAP32[$12>>2]|0;
     $40 = (_fwrite($2,1,$38,$39)|0);
     $41 = ($40|0)==($38|0);
     if (!($41)) {
      label = 14;
      break;
     }
     $42 = HEAP32[$5>>2]|0;
     $$$032 = $30 ? $42 : $$032;
     $$436 = $$$032;
    }
    if ($30) {
     $$032 = $$436;
    } else {
     label = 13;
     break;
    }
   }
   if ((label|0) == 13) {
    label = 15;
    break;
   }
   else if ((label|0) == 14) {
    $43 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
    $$4 = $43;
    break;
   }
  }
 } while(0);
 if ((label|0) == 15) {
  $44 = (__ZNSt3__211char_traitsIwE7not_eofEj($1)|0);
  $$4 = $44;
 }
 STACKTOP = sp;return ($$4|0);
}
function __ZNSt3__211char_traitsIwE7not_eofEj($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
 $2 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($0,$1)|0);
 if ($2) {
  $3 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
  $4 = $3 ^ -1;
  $5 = $4;
 } else {
  $5 = $0;
 }
 return ($5|0);
}
function __ZNSt3__211__stdoutbufIcED2Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEED2Ev($0);
 return;
}
function __ZNSt3__211__stdoutbufIcED0Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__211__stdoutbufIcED2Ev($0);
 __ZdlPv($0);
 return;
}
function __ZNSt3__211__stdoutbufIcE5imbueERKNS_6localeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $3 = ((($2)) + 24|0);
 $4 = HEAP32[$3>>2]|0;
 (FUNCTION_TABLE_ii[$4 & 8191]($0)|0);
 $5 = (__ZNKSt3__26locale9use_facetERNS0_2idE($1,216980)|0);
 $6 = ((($0)) + 36|0);
 HEAP32[$6>>2] = $5;
 $7 = HEAP32[$5>>2]|0;
 $8 = ((($7)) + 28|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (FUNCTION_TABLE_ii[$9 & 8191]($5)|0);
 $11 = ((($0)) + 44|0);
 $12 = $10&1;
 HEAP8[$11>>0] = $12;
 return;
}
function __ZNSt3__211__stdoutbufIcE4syncEv($0) {
 $0 = $0|0;
 var $$10 = 0, $$2 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $not$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp + 8|0;
 $2 = sp;
 $3 = ((($0)) + 36|0);
 $4 = ((($0)) + 40|0);
 $5 = ((($1)) + 8|0);
 $6 = $1;
 $7 = ((($0)) + 32|0);
 L1: while(1) {
  $8 = HEAP32[$3>>2]|0;
  $9 = HEAP32[$4>>2]|0;
  $10 = HEAP32[$8>>2]|0;
  $11 = ((($10)) + 20|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (FUNCTION_TABLE_iiiiii[$12 & 8191]($8,$9,$1,$5,$2)|0);
  $14 = HEAP32[$2>>2]|0;
  $15 = (($14) - ($6))|0;
  $16 = HEAP32[$7>>2]|0;
  $17 = (_fwrite($1,1,$15,$16)|0);
  $18 = ($17|0)==($15|0);
  if (!($18)) {
   $$2 = -1;
   break;
  }
  switch ($13|0) {
  case 1:  {
   break;
  }
  case 2:  {
   $$2 = -1;
   break L1;
   break;
  }
  default: {
   label = 4;
   break L1;
  }
  }
 }
 if ((label|0) == 4) {
  $19 = HEAP32[$7>>2]|0;
  $20 = (_fflush($19)|0);
  $not$ = ($20|0)!=(0);
  $$10 = $not$ << 31 >> 31;
  $$2 = $$10;
 }
 STACKTOP = sp;return ($$2|0);
}
function __ZNSt3__211__stdoutbufIcE6xsputnEPKci($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$010 = 0, $$011 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 44|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)==(0);
 L1: do {
  if ($5) {
   $$0 = 0;$$011 = $1;
   while(1) {
    $9 = ($$0|0)<($2|0);
    if (!($9)) {
     $$010 = $$0;
     break L1;
    }
    $10 = HEAP32[$0>>2]|0;
    $11 = ((($10)) + 52|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = HEAP8[$$011>>0]|0;
    $14 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($13)|0);
    $15 = (FUNCTION_TABLE_iii[$12 & 8191]($0,$14)|0);
    $16 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
    $17 = ($15|0)==($16|0);
    if ($17) {
     $$010 = $$0;
     break L1;
    }
    $18 = (($$0) + 1)|0;
    $19 = ((($$011)) + 1|0);
    $$0 = $18;$$011 = $19;
   }
  } else {
   $6 = ((($0)) + 32|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = (_fwrite($1,1,$2,$7)|0);
   $$010 = $8;
  }
 } while(0);
 return ($$010|0);
}
function __ZNSt3__211__stdoutbufIcE8overflowEi($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$$032 = 0, $$032 = 0, $$4 = 0, $$436 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $2 = sp + 16|0;
 $3 = sp + 8|0;
 $4 = sp + 4|0;
 $5 = sp;
 $6 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
 $7 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($1,$6)|0);
 do {
  if ($7) {
   label = 15;
  } else {
   $8 = (__ZNSt3__211char_traitsIcE12to_char_typeEi($1)|0);
   HEAP8[$3>>0] = $8;
   $9 = ((($0)) + 44|0);
   $10 = HEAP8[$9>>0]|0;
   $11 = ($10<<24>>24)==(0);
   $12 = ((($0)) + 32|0);
   if (!($11)) {
    $13 = HEAP32[$12>>2]|0;
    $14 = (_fwrite($3,1,1,$13)|0);
    $15 = ($14|0)==(1);
    if ($15) {
     label = 15;
     break;
    }
    $16 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
    $$4 = $16;
    break;
   }
   HEAP32[$4>>2] = $2;
   $17 = ((($3)) + 1|0);
   $18 = ((($0)) + 36|0);
   $19 = ((($0)) + 40|0);
   $20 = ((($2)) + 8|0);
   $21 = $2;
   $$032 = $3;
   while(1) {
    $22 = HEAP32[$18>>2]|0;
    $23 = HEAP32[$19>>2]|0;
    $24 = HEAP32[$22>>2]|0;
    $25 = ((($24)) + 12|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = (FUNCTION_TABLE_iiiiiiiii[$26 & 8191]($22,$23,$$032,$17,$5,$2,$20,$4)|0);
    $28 = HEAP32[$5>>2]|0;
    $29 = ($28|0)==($$032|0);
    $30 = ($27|0)==(1);
    if ($29) {
     label = 14;
     break;
    }
    $31 = ($27|0)==(3);
    if ($31) {
     $32 = HEAP32[$12>>2]|0;
     $33 = (_fwrite($$032,1,1,$32)|0);
     $34 = ($33|0)==(1);
     if ($34) {
      $$436 = $$032;
     } else {
      label = 14;
      break;
     }
    } else {
     $35 = $27 | 1;
     $36 = ($35|0)==(1);
     if (!($36)) {
      label = 14;
      break;
     }
     $37 = HEAP32[$4>>2]|0;
     $38 = (($37) - ($21))|0;
     $39 = HEAP32[$12>>2]|0;
     $40 = (_fwrite($2,1,$38,$39)|0);
     $41 = ($40|0)==($38|0);
     if (!($41)) {
      label = 14;
      break;
     }
     $42 = HEAP32[$5>>2]|0;
     $$$032 = $30 ? $42 : $$032;
     $$436 = $$$032;
    }
    if ($30) {
     $$032 = $$436;
    } else {
     label = 13;
     break;
    }
   }
   if ((label|0) == 13) {
    label = 15;
    break;
   }
   else if ((label|0) == 14) {
    $43 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
    $$4 = $43;
    break;
   }
  }
 } while(0);
 if ((label|0) == 15) {
  $44 = (__ZNSt3__211char_traitsIcE7not_eofEi($1)|0);
  $$4 = $44;
 }
 STACKTOP = sp;return ($$4|0);
}
function __ZNSt3__211char_traitsIcE7not_eofEi($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
 $2 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($0,$1)|0);
 if ($2) {
  $3 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
  $4 = $3 ^ -1;
  $5 = $4;
 } else {
  $5 = $0;
 }
 return ($5|0);
}
function __ZNSt3__210__stdinbufIwED2Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__215basic_streambufIwNS_11char_traitsIwEEED2Ev($0);
 return;
}
function __ZNSt3__210__stdinbufIwED0Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__210__stdinbufIwED2Ev($0);
 __ZdlPv($0);
 return;
}
function __ZNSt3__210__stdinbufIwE5imbueERKNS_6localeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__ZNKSt3__26locale9use_facetERNS0_2idE($1,216988)|0);
 $3 = ((($0)) + 36|0);
 HEAP32[$3>>2] = $2;
 $4 = HEAP32[$2>>2]|0;
 $5 = ((($4)) + 24|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_ii[$6 & 8191]($2)|0);
 $8 = ((($0)) + 44|0);
 HEAP32[$8>>2] = $7;
 $9 = HEAP32[$3>>2]|0;
 $10 = HEAP32[$9>>2]|0;
 $11 = ((($10)) + 28|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (FUNCTION_TABLE_ii[$12 & 8191]($9)|0);
 $14 = ((($0)) + 53|0);
 $15 = $13&1;
 HEAP8[$14>>0] = $15;
 $16 = HEAP32[$8>>2]|0;
 $17 = ($16|0)>(8);
 if ($17) {
  __ZNSt3__221__throw_runtime_errorEPKc(202466);
  // unreachable;
 } else {
  return;
 }
}
function __ZNSt3__210__stdinbufIwE9underflowEv($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__ZNSt3__210__stdinbufIwE9__getcharEb($0,0)|0);
 return ($1|0);
}
function __ZNSt3__210__stdinbufIwE5uflowEv($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__ZNSt3__210__stdinbufIwE9__getcharEb($0,1)|0);
 return ($1|0);
}
function __ZNSt3__210__stdinbufIwE9pbackfailEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$07 = 0, $$1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $2 = sp + 16|0;
 $3 = sp + 8|0;
 $4 = sp + 4|0;
 $5 = sp;
 $6 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
 $7 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($1,$6)|0);
 $8 = ((($0)) + 52|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = ($9<<24>>24)!=(0);
 $11 = ((($0)) + 48|0);
 do {
  if ($7) {
   if ($10) {
    $$1 = $1;
   } else {
    $12 = HEAP32[$11>>2]|0;
    $13 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
    $14 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($12,$13)|0);
    $15 = $14 ^ 1;
    $16 = $15&1;
    HEAP8[$8>>0] = $16;
    $$1 = $12;
   }
  } else {
   if ($10) {
    $17 = HEAP32[$11>>2]|0;
    $18 = (__ZNSt3__211char_traitsIwE12to_char_typeEj($17)|0);
    HEAP32[$4>>2] = $18;
    $19 = ((($0)) + 36|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = ((($0)) + 40|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = ((($4)) + 4|0);
    $24 = ((($2)) + 8|0);
    $25 = HEAP32[$20>>2]|0;
    $26 = ((($25)) + 12|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = (FUNCTION_TABLE_iiiiiiiii[$27 & 8191]($20,$22,$4,$23,$5,$2,$24,$3)|0);
    switch ($28|0) {
    case 1: case 2:  {
     label = 10;
     break;
    }
    case 3:  {
     $29 = HEAP32[$11>>2]|0;
     $30 = $29&255;
     HEAP8[$2>>0] = $30;
     $31 = ((($2)) + 1|0);
     HEAP32[$3>>2] = $31;
     label = 7;
     break;
    }
    default: {
     label = 7;
    }
    }
    L9: do {
     if ((label|0) == 7) {
      $32 = ((($0)) + 32|0);
      while(1) {
       $33 = HEAP32[$3>>2]|0;
       $34 = ($33>>>0)>($2>>>0);
       if (!($34)) {
        $$0 = 1;$$07 = 0;
        break L9;
       }
       $35 = ((($33)) + -1|0);
       HEAP32[$3>>2] = $35;
       $36 = HEAP8[$35>>0]|0;
       $37 = $36 << 24 >> 24;
       $38 = HEAP32[$32>>2]|0;
       $39 = (_ungetc($37,$38)|0);
       $40 = ($39|0)==(-1);
       if ($40) {
        label = 10;
        break;
       }
      }
     }
    } while(0);
    if ((label|0) == 10) {
     $41 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
     $$0 = 0;$$07 = $41;
    }
    if (!($$0)) {
     $$1 = $$07;
     break;
    }
   }
   HEAP32[$11>>2] = $1;
   HEAP8[$8>>0] = 1;
   $$1 = $1;
  }
 } while(0);
 STACKTOP = sp;return ($$1|0);
}
function __ZNSt3__210__stdinbufIwE9__getcharEb($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$048 = 0, $$052 = 0, $$10 = 0, $$11 = 0, $$351 = 0, $$9 = 0, $$sroa$speculated = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $2 = sp + 16|0;
 $3 = sp + 8|0;
 $4 = sp + 4|0;
 $5 = sp;
 $6 = ((($0)) + 52|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = ($7<<24>>24)==(0);
 $9 = ((($0)) + 48|0);
 if ($8) {
  $12 = ((($0)) + 44|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($13|0)>(1);
  $$sroa$speculated = $14 ? $13 : 1;
  $15 = ((($0)) + 32|0);
  $$052 = 0;
  while(1) {
   $16 = ($$052|0)<($$sroa$speculated|0);
   if (!($16)) {
    label = 9;
    break;
   }
   $17 = HEAP32[$15>>2]|0;
   $18 = (_getc($17)|0);
   $19 = ($18|0)==(-1);
   if ($19) {
    label = 8;
    break;
   }
   $20 = $18&255;
   $21 = (($2) + ($$052)|0);
   HEAP8[$21>>0] = $20;
   $22 = (($$052) + 1)|0;
   $$052 = $22;
  }
  if ((label|0) == 8) {
   $23 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
   $$10 = $23;
  }
  else if ((label|0) == 9) {
   $24 = ((($0)) + 53|0);
   $25 = HEAP8[$24>>0]|0;
   $26 = ($25<<24>>24)==(0);
   do {
    if ($26) {
     $29 = ((($0)) + 40|0);
     $30 = ((($0)) + 36|0);
     $31 = ((($3)) + 4|0);
     $$048 = $$sroa$speculated;
     L11: while(1) {
      $32 = HEAP32[$29>>2]|0;
      $33 = $32;
      $34 = $33;
      $35 = HEAP32[$34>>2]|0;
      $36 = (($33) + 4)|0;
      $37 = $36;
      $38 = HEAP32[$37>>2]|0;
      $39 = HEAP32[$30>>2]|0;
      $40 = (($2) + ($$048)|0);
      $41 = HEAP32[$39>>2]|0;
      $42 = ((($41)) + 16|0);
      $43 = HEAP32[$42>>2]|0;
      $44 = (FUNCTION_TABLE_iiiiiiiii[$43 & 8191]($39,$32,$2,$40,$4,$3,$31,$5)|0);
      switch ($44|0) {
      case 3:  {
       label = 16;
       break L11;
       break;
      }
      case 2:  {
       label = 18;
       break L11;
       break;
      }
      case 1:  {
       break;
      }
      default: {
       break L11;
      }
      }
      $45 = HEAP32[$29>>2]|0;
      $46 = $45;
      $47 = $46;
      HEAP32[$47>>2] = $35;
      $48 = (($46) + 4)|0;
      $49 = $48;
      HEAP32[$49>>2] = $38;
      $50 = ($$048|0)==(8);
      if ($50) {
       label = 18;
       break;
      }
      $51 = HEAP32[$15>>2]|0;
      $52 = (_getc($51)|0);
      $53 = ($52|0)==(-1);
      if ($53) {
       label = 18;
       break;
      }
      $54 = $52&255;
      HEAP8[$40>>0] = $54;
      $55 = (($$048) + 1)|0;
      $$048 = $55;
     }
     if ((label|0) == 16) {
      $56 = HEAP8[$2>>0]|0;
      $57 = $56 << 24 >> 24;
      HEAP32[$3>>2] = $57;
     }
     else if ((label|0) == 18) {
      $58 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
      $$9 = $58;
      break;
     }
     $$351 = $$048;
     label = 19;
    } else {
     $27 = HEAP8[$2>>0]|0;
     $28 = $27 << 24 >> 24;
     HEAP32[$3>>2] = $28;
     $$351 = $$sroa$speculated;
     label = 19;
    }
   } while(0);
   L21: do {
    if ((label|0) == 19) {
     L23: do {
      if ($1) {
       $69 = HEAP32[$3>>2]|0;
       $70 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($69)|0);
       HEAP32[$9>>2] = $70;
      } else {
       $$0 = $$351;
       while(1) {
        $59 = ($$0|0)>(0);
        if (!($59)) {
         break L23;
        }
        $60 = (($$0) + -1)|0;
        $61 = (($2) + ($60)|0);
        $62 = HEAP8[$61>>0]|0;
        $63 = $62 << 24 >> 24;
        $64 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($63)|0);
        $65 = HEAP32[$15>>2]|0;
        $66 = (_ungetc($64,$65)|0);
        $67 = ($66|0)==(-1);
        if ($67) {
         break;
        } else {
         $$0 = $60;
        }
       }
       $68 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
       $$9 = $68;
       break L21;
      }
     } while(0);
     $71 = HEAP32[$3>>2]|0;
     $72 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($71)|0);
     $$9 = $72;
    }
   } while(0);
   $$10 = $$9;
  }
  $$11 = $$10;
 } else {
  $10 = HEAP32[$9>>2]|0;
  if ($1) {
   $11 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
   HEAP32[$9>>2] = $11;
   HEAP8[$6>>0] = 0;
   $$11 = $10;
  } else {
   $$11 = $10;
  }
 }
 STACKTOP = sp;return ($$11|0);
}
function __ZNSt3__210__stdinbufIcED2Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEED2Ev($0);
 return;
}
function __ZNSt3__210__stdinbufIcED0Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__210__stdinbufIcED2Ev($0);
 __ZdlPv($0);
 return;
}
function __ZNSt3__210__stdinbufIcE5imbueERKNS_6localeE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__ZNKSt3__26locale9use_facetERNS0_2idE($1,216980)|0);
 $3 = ((($0)) + 36|0);
 HEAP32[$3>>2] = $2;
 $4 = HEAP32[$2>>2]|0;
 $5 = ((($4)) + 24|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_ii[$6 & 8191]($2)|0);
 $8 = ((($0)) + 44|0);
 HEAP32[$8>>2] = $7;
 $9 = HEAP32[$3>>2]|0;
 $10 = HEAP32[$9>>2]|0;
 $11 = ((($10)) + 28|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (FUNCTION_TABLE_ii[$12 & 8191]($9)|0);
 $14 = ((($0)) + 53|0);
 $15 = $13&1;
 HEAP8[$14>>0] = $15;
 $16 = HEAP32[$8>>2]|0;
 $17 = ($16|0)>(8);
 if ($17) {
  __ZNSt3__221__throw_runtime_errorEPKc(202466);
  // unreachable;
 } else {
  return;
 }
}
function __ZNSt3__210__stdinbufIcE9underflowEv($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__ZNSt3__210__stdinbufIcE9__getcharEb($0,0)|0);
 return ($1|0);
}
function __ZNSt3__210__stdinbufIcE5uflowEv($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__ZNSt3__210__stdinbufIcE9__getcharEb($0,1)|0);
 return ($1|0);
}
function __ZNSt3__210__stdinbufIcE9pbackfailEi($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$07 = 0, $$1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $2 = sp + 16|0;
 $3 = sp + 4|0;
 $4 = sp + 8|0;
 $5 = sp;
 $6 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
 $7 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($1,$6)|0);
 $8 = ((($0)) + 52|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = ($9<<24>>24)!=(0);
 $11 = ((($0)) + 48|0);
 do {
  if ($7) {
   if ($10) {
    $$1 = $1;
   } else {
    $12 = HEAP32[$11>>2]|0;
    $13 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
    $14 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($12,$13)|0);
    $15 = $14 ^ 1;
    $16 = $15&1;
    HEAP8[$8>>0] = $16;
    $$1 = $12;
   }
  } else {
   if ($10) {
    $17 = HEAP32[$11>>2]|0;
    $18 = (__ZNSt3__211char_traitsIcE12to_char_typeEi($17)|0);
    HEAP8[$4>>0] = $18;
    $19 = ((($0)) + 36|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = ((($0)) + 40|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = ((($4)) + 1|0);
    $24 = ((($2)) + 8|0);
    $25 = HEAP32[$20>>2]|0;
    $26 = ((($25)) + 12|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = (FUNCTION_TABLE_iiiiiiiii[$27 & 8191]($20,$22,$4,$23,$5,$2,$24,$3)|0);
    switch ($28|0) {
    case 1: case 2:  {
     label = 10;
     break;
    }
    case 3:  {
     $29 = HEAP32[$11>>2]|0;
     $30 = $29&255;
     HEAP8[$2>>0] = $30;
     $31 = ((($2)) + 1|0);
     HEAP32[$3>>2] = $31;
     label = 7;
     break;
    }
    default: {
     label = 7;
    }
    }
    L9: do {
     if ((label|0) == 7) {
      $32 = ((($0)) + 32|0);
      while(1) {
       $33 = HEAP32[$3>>2]|0;
       $34 = ($33>>>0)>($2>>>0);
       if (!($34)) {
        $$0 = 1;$$07 = 0;
        break L9;
       }
       $35 = ((($33)) + -1|0);
       HEAP32[$3>>2] = $35;
       $36 = HEAP8[$35>>0]|0;
       $37 = $36 << 24 >> 24;
       $38 = HEAP32[$32>>2]|0;
       $39 = (_ungetc($37,$38)|0);
       $40 = ($39|0)==(-1);
       if ($40) {
        label = 10;
        break;
       }
      }
     }
    } while(0);
    if ((label|0) == 10) {
     $41 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
     $$0 = 0;$$07 = $41;
    }
    if (!($$0)) {
     $$1 = $$07;
     break;
    }
   }
   HEAP32[$11>>2] = $1;
   HEAP8[$8>>0] = 1;
   $$1 = $1;
  }
 } while(0);
 STACKTOP = sp;return ($$1|0);
}
function __ZNSt3__210__stdinbufIcE9__getcharEb($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$048 = 0, $$052 = 0, $$10 = 0, $$11 = 0, $$351 = 0, $$9 = 0, $$sroa$speculated = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $2 = sp + 16|0;
 $3 = sp + 8|0;
 $4 = sp + 4|0;
 $5 = sp;
 $6 = ((($0)) + 52|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = ($7<<24>>24)==(0);
 $9 = ((($0)) + 48|0);
 if ($8) {
  $12 = ((($0)) + 44|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($13|0)>(1);
  $$sroa$speculated = $14 ? $13 : 1;
  $15 = ((($0)) + 32|0);
  $$052 = 0;
  while(1) {
   $16 = ($$052|0)<($$sroa$speculated|0);
   if (!($16)) {
    label = 9;
    break;
   }
   $17 = HEAP32[$15>>2]|0;
   $18 = (_getc($17)|0);
   $19 = ($18|0)==(-1);
   if ($19) {
    label = 8;
    break;
   }
   $20 = $18&255;
   $21 = (($2) + ($$052)|0);
   HEAP8[$21>>0] = $20;
   $22 = (($$052) + 1)|0;
   $$052 = $22;
  }
  if ((label|0) == 8) {
   $23 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
   $$10 = $23;
  }
  else if ((label|0) == 9) {
   $24 = ((($0)) + 53|0);
   $25 = HEAP8[$24>>0]|0;
   $26 = ($25<<24>>24)==(0);
   do {
    if ($26) {
     $28 = ((($0)) + 40|0);
     $29 = ((($0)) + 36|0);
     $30 = ((($3)) + 1|0);
     $$048 = $$sroa$speculated;
     L11: while(1) {
      $31 = HEAP32[$28>>2]|0;
      $32 = $31;
      $33 = $32;
      $34 = HEAP32[$33>>2]|0;
      $35 = (($32) + 4)|0;
      $36 = $35;
      $37 = HEAP32[$36>>2]|0;
      $38 = HEAP32[$29>>2]|0;
      $39 = (($2) + ($$048)|0);
      $40 = HEAP32[$38>>2]|0;
      $41 = ((($40)) + 16|0);
      $42 = HEAP32[$41>>2]|0;
      $43 = (FUNCTION_TABLE_iiiiiiiii[$42 & 8191]($38,$31,$2,$39,$4,$3,$30,$5)|0);
      switch ($43|0) {
      case 3:  {
       label = 16;
       break L11;
       break;
      }
      case 2:  {
       label = 18;
       break L11;
       break;
      }
      case 1:  {
       break;
      }
      default: {
       break L11;
      }
      }
      $44 = HEAP32[$28>>2]|0;
      $45 = $44;
      $46 = $45;
      HEAP32[$46>>2] = $34;
      $47 = (($45) + 4)|0;
      $48 = $47;
      HEAP32[$48>>2] = $37;
      $49 = ($$048|0)==(8);
      if ($49) {
       label = 18;
       break;
      }
      $50 = HEAP32[$15>>2]|0;
      $51 = (_getc($50)|0);
      $52 = ($51|0)==(-1);
      if ($52) {
       label = 18;
       break;
      }
      $53 = $51&255;
      HEAP8[$39>>0] = $53;
      $54 = (($$048) + 1)|0;
      $$048 = $54;
     }
     if ((label|0) == 16) {
      $55 = HEAP8[$2>>0]|0;
      HEAP8[$3>>0] = $55;
     }
     else if ((label|0) == 18) {
      $56 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
      $$9 = $56;
      break;
     }
     $$351 = $$048;
     label = 19;
    } else {
     $27 = HEAP8[$2>>0]|0;
     HEAP8[$3>>0] = $27;
     $$351 = $$sroa$speculated;
     label = 19;
    }
   } while(0);
   L21: do {
    if ((label|0) == 19) {
     L23: do {
      if ($1) {
       $66 = HEAP8[$3>>0]|0;
       $67 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($66)|0);
       HEAP32[$9>>2] = $67;
      } else {
       $$0 = $$351;
       while(1) {
        $57 = ($$0|0)>(0);
        if (!($57)) {
         break L23;
        }
        $58 = (($$0) + -1)|0;
        $59 = (($2) + ($58)|0);
        $60 = HEAP8[$59>>0]|0;
        $61 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($60)|0);
        $62 = HEAP32[$15>>2]|0;
        $63 = (_ungetc($61,$62)|0);
        $64 = ($63|0)==(-1);
        if ($64) {
         break;
        } else {
         $$0 = $58;
        }
       }
       $65 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
       $$9 = $65;
       break L21;
      }
     } while(0);
     $68 = HEAP8[$3>>0]|0;
     $69 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($68)|0);
     $$9 = $69;
    }
   } while(0);
   $$10 = $$9;
  }
  $$11 = $$10;
 } else {
  $10 = HEAP32[$9>>2]|0;
  if ($1) {
   $11 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
   HEAP32[$9>>2] = $11;
   HEAP8[$6>>0] = 0;
   $$11 = $10;
  } else {
   $$11 = $10;
  }
 }
 STACKTOP = sp;return ($$11|0);
}
function __ZNSt3__27collateIcED2Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__26locale5facetD2Ev($0);
 return;
}
function __ZNSt3__27collateIcED0Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__27collateIcED2Ev($0);
 __ZdlPv($0);
 return;
}
function __ZNSt3__26locale5facet16__on_zero_sharedEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = HEAP32[$0>>2]|0;
  $3 = ((($2)) + 4|0);
  $4 = HEAP32[$3>>2]|0;
  FUNCTION_TABLE_vi[$4 & 8191]($0);
 }
 return;
}
function __ZNKSt3__27collateIcE10do_compareEPKcS3_S3_S3_($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0 = 0, $$011 = 0, $$012 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$011 = $3;$$012 = $1;
 while(1) {
  $5 = ($$011|0)==($4|0);
  if ($5) {
   label = 7;
   break;
  }
  $6 = ($$012|0)==($2|0);
  if ($6) {
   $$0 = -1;
   break;
  }
  $7 = HEAP8[$$012>>0]|0;
  $8 = HEAP8[$$011>>0]|0;
  $9 = ($7<<24>>24)<($8<<24>>24);
  if ($9) {
   $$0 = -1;
   break;
  }
  $10 = ($8<<24>>24)<($7<<24>>24);
  if ($10) {
   $$0 = 1;
   break;
  }
  $11 = ((($$012)) + 1|0);
  $12 = ((($$011)) + 1|0);
  $$011 = $12;$$012 = $11;
 }
 if ((label|0) == 7) {
  $13 = ($$012|0)!=($2|0);
  $14 = $13&1;
  $$0 = $14;
 }
 return ($$0|0);
}
function __ZNKSt3__27collateIcE12do_transformEPKcS3_($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0$i$i = 0, $$021$i$i = 0, $$021$ph$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $scevgep23$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $4 = sp;
 ;HEAP32[$0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;
 $5 = $2;
 $6 = $3;
 $7 = (($6) - ($5))|0;
 $8 = ($7>>>0)>(4294967279);
 if ($8) {
  __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $9 = ($7>>>0)<(11);
 if ($9) {
  $10 = $7&255;
  $11 = ((($0)) + 11|0);
  HEAP8[$11>>0] = $10;
  $$021$ph$i$i = $0;
 } else {
  $12 = (($7) + 16)|0;
  $13 = $12 & -16;
  $14 = (__Znwj($13)|0);
  HEAP32[$0>>2] = $14;
  $15 = $13 | -2147483648;
  $16 = ((($0)) + 8|0);
  HEAP32[$16>>2] = $15;
  $17 = ((($0)) + 4|0);
  HEAP32[$17>>2] = $7;
  $$021$ph$i$i = $14;
 }
 $$0$i$i = $2;$$021$i$i = $$021$ph$i$i;
 while(1) {
  $18 = ($$0$i$i|0)==($3|0);
  if ($18) {
   break;
  }
  __ZNSt3__211char_traitsIcE6assignERcRKc($$021$i$i,$$0$i$i);
  $19 = ((($$0$i$i)) + 1|0);
  $20 = ((($$021$i$i)) + 1|0);
  $$0$i$i = $19;$$021$i$i = $20;
 }
 $scevgep23$i$i = (($$021$ph$i$i) + ($7)|0);
 HEAP8[$4>>0] = 0;
 __ZNSt3__211char_traitsIcE6assignERcRKc($scevgep23$i$i,$4);
 STACKTOP = sp;return;
}
function __ZNKSt3__27collateIcE7do_hashEPKcS3_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$020 = 0, $10 = 0, $11 = 0, $12 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$0 = 0;$$020 = $1;
 while(1) {
  $3 = ($$020|0)==($2|0);
  if ($3) {
   break;
  }
  $4 = $$0 << 4;
  $5 = HEAP8[$$020>>0]|0;
  $6 = $5 << 24 >> 24;
  $7 = (($6) + ($4))|0;
  $8 = $7 & -268435456;
  $9 = $8 >>> 24;
  $10 = $9 | $8;
  $11 = $10 ^ $7;
  $12 = ((($$020)) + 1|0);
  $$0 = $11;$$020 = $12;
 }
 return ($$0|0);
}
function __ZNSt3__26locale5facetD2Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZNSt3__27collateIwED2Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__26locale5facetD2Ev($0);
 return;
}
function __ZNSt3__27collateIwED0Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__27collateIwED2Ev($0);
 __ZdlPv($0);
 return;
}
function __ZNKSt3__27collateIwE10do_compareEPKwS3_S3_S3_($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0 = 0, $$011 = 0, $$012 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$011 = $3;$$012 = $1;
 while(1) {
  $5 = ($$011|0)==($4|0);
  if ($5) {
   label = 7;
   break;
  }
  $6 = ($$012|0)==($2|0);
  if ($6) {
   $$0 = -1;
   break;
  }
  $7 = HEAP32[$$012>>2]|0;
  $8 = HEAP32[$$011>>2]|0;
  $9 = ($7|0)<($8|0);
  if ($9) {
   $$0 = -1;
   break;
  }
  $10 = ($8|0)<($7|0);
  if ($10) {
   $$0 = 1;
   break;
  }
  $11 = ((($$012)) + 4|0);
  $12 = ((($$011)) + 4|0);
  $$011 = $12;$$012 = $11;
 }
 if ((label|0) == 7) {
  $13 = ($$012|0)!=($2|0);
  $14 = $13&1;
  $$0 = $14;
 }
 return ($$0|0);
}
function __ZNKSt3__27collateIwE12do_transformEPKwS3_($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0$i$i = 0, $$021$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $4 = sp;
 ;HEAP32[$0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;
 $5 = $3;
 $6 = $2;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 2;
 $9 = ($8>>>0)>(1073741807);
 if ($9) {
  __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $10 = ($8>>>0)<(2);
 do {
  if ($10) {
   $11 = $8&255;
   $12 = ((($0)) + 8|0);
   $13 = ((($12)) + 3|0);
   HEAP8[$13>>0] = $11;
   $$0$i$i = $2;$$021$i$i = $0;
  } else {
   $14 = (($8) + 4)|0;
   $15 = $14 & -4;
   $16 = ($15>>>0)>(1073741823);
   if (!($16)) {
    $22 = $15 << 2;
    $23 = (__Znwj($22)|0);
    HEAP32[$0>>2] = $23;
    $24 = $15 | -2147483648;
    $25 = ((($0)) + 8|0);
    HEAP32[$25>>2] = $24;
    $26 = ((($0)) + 4|0);
    HEAP32[$26>>2] = $8;
    $$0$i$i = $2;$$021$i$i = $23;
    break;
   }
   $17 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($17|0),(204840|0));
   $18 = __THREW__; __THREW__ = 0;
   $19 = $18&1;
   if ($19) {
    $20 = ___cxa_find_matching_catch_2()|0;
    $21 = tempRet0;
    ___cxa_free_exception(($17|0));
    ___resumeException($20|0);
    // unreachable;
   } else {
    HEAP32[$17>>2] = (99824);
    ___cxa_throw(($17|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 while(1) {
  $27 = ($$0$i$i|0)==($3|0);
  if ($27) {
   break;
  }
  __ZNSt3__211char_traitsIwE6assignERwRKw($$021$i$i,$$0$i$i);
  $28 = ((($$0$i$i)) + 4|0);
  $29 = ((($$021$i$i)) + 4|0);
  $$0$i$i = $28;$$021$i$i = $29;
 }
 HEAP32[$4>>2] = 0;
 __ZNSt3__211char_traitsIwE6assignERwRKw($$021$i$i,$4);
 STACKTOP = sp;return;
}
function __ZNKSt3__27collateIwE7do_hashEPKwS3_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$020 = 0, $10 = 0, $11 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$0 = 0;$$020 = $1;
 while(1) {
  $3 = ($$020|0)==($2|0);
  if ($3) {
   break;
  }
  $4 = $$0 << 4;
  $5 = HEAP32[$$020>>2]|0;
  $6 = (($5) + ($4))|0;
  $7 = $6 & -268435456;
  $8 = $7 >>> 24;
  $9 = $8 | $7;
  $10 = $9 ^ $6;
  $11 = ((($$020)) + 4|0);
  $$0 = $10;$$020 = $11;
 }
 return ($$0|0);
}
function __ZNSt3__211char_traitsIwE6assignERwRKw($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $2;
 return;
}
function __ZNSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEED2Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__26locale5facetD2Ev($0);
 return;
}
function __ZNSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEED0Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__26locale5facetD2Ev($0);
 __ZdlPv($0);
 return;
}
function __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRb($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$2 = 0, $$232 = 0, $$byval_copy = 0, $$byval_copy1 = 0, $$byval_copy2 = 0, $$ptr = 0, $$sroa$026$0 = 0, $$sroa$026$0$copyload = 0, $$sroa$026$0$copyload28 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(64|0);
 $$byval_copy2 = sp + 60|0;
 $$byval_copy1 = sp + 56|0;
 $$byval_copy = sp + 52|0;
 $6 = sp + 48|0;
 $7 = sp + 44|0;
 $8 = sp + 40|0;
 $9 = sp + 36|0;
 $10 = sp + 32|0;
 $11 = sp + 8|0;
 $12 = sp;
 $13 = ((($3)) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $14 & 1;
 $16 = ($15|0)==(0);
 L1: do {
  if ($16) {
   HEAP32[$6>>2] = -1;
   $17 = HEAP32[$0>>2]|0;
   $18 = ((($17)) + 16|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = HEAP32[$1>>2]|0;
   HEAP32[$7>>2] = $20;
   $21 = HEAP32[$2>>2]|0;
   HEAP32[$8>>2] = $21;
   ;HEAP32[$$byval_copy>>2]=HEAP32[$7>>2]|0;
   ;HEAP32[$$byval_copy1>>2]=HEAP32[$8>>2]|0;
   $22 = (FUNCTION_TABLE_iiiiiii[$19 & 8191]($0,$$byval_copy,$$byval_copy1,$3,$4,$6)|0);
   HEAP32[$1>>2] = $22;
   $23 = HEAP32[$6>>2]|0;
   switch ($23|0) {
   case 0:  {
    HEAP8[$5>>0] = 0;
    break;
   }
   case 1:  {
    HEAP8[$5>>0] = 1;
    break;
   }
   default: {
    HEAP8[$5>>0] = 1;
    HEAP32[$4>>2] = 4;
   }
   }
   $$sroa$026$0$copyload = HEAP32[$1>>2]|0;
   $$sroa$026$0 = $$sroa$026$0$copyload;
  } else {
   __ZNKSt3__28ios_base6getlocEv($9,$3);
   __THREW__ = 0;
   $24 = (invoke_iii(3255,($9|0),(215188|0))|0);
   $25 = __THREW__; __THREW__ = 0;
   $26 = $25&1;
   do {
    if ($26) {
     $49 = ___cxa_find_matching_catch_2()|0;
     $50 = tempRet0;
     __ZNSt3__26localeD2Ev($9);
     $$2 = $49;$$232 = $50;
    } else {
     __ZNSt3__26localeD2Ev($9);
     __ZNKSt3__28ios_base6getlocEv($10,$3);
     __THREW__ = 0;
     $27 = (invoke_iii(3255,($10|0),(215204|0))|0);
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      $51 = ___cxa_find_matching_catch_2()|0;
      $52 = tempRet0;
      __ZNSt3__26localeD2Ev($10);
      $$2 = $51;$$232 = $52;
      break;
     }
     __ZNSt3__26localeD2Ev($10);
     $30 = HEAP32[$27>>2]|0;
     $31 = ((($30)) + 24|0);
     $32 = HEAP32[$31>>2]|0;
     __THREW__ = 0;
     invoke_vii($32|0,($11|0),($27|0));
     $33 = __THREW__; __THREW__ = 0;
     $34 = $33&1;
     if ($34) {
      $35 = ___cxa_find_matching_catch_2()|0;
      $36 = tempRet0;
      $$2 = $35;$$232 = $36;
      break;
     }
     $$ptr = ((($11)) + 12|0);
     $37 = HEAP32[$27>>2]|0;
     $38 = ((($37)) + 28|0);
     $39 = HEAP32[$38>>2]|0;
     __THREW__ = 0;
     invoke_vii($39|0,($$ptr|0),($27|0));
     $40 = __THREW__; __THREW__ = 0;
     $41 = $40&1;
     if ($41) {
      $61 = ___cxa_find_matching_catch_2()|0;
      $62 = tempRet0;
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($11);
      $$2 = $61;$$232 = $62;
      break;
     }
     $42 = HEAP32[$2>>2]|0;
     HEAP32[$12>>2] = $42;
     $43 = ((($11)) + 24|0);
     __THREW__ = 0;
     ;HEAP32[$$byval_copy2>>2]=HEAP32[$12>>2]|0;
     $44 = (invoke_iiiiiiii(4666,($1|0),($$byval_copy2|0),($11|0),($43|0),($24|0),($4|0),1)|0);
     $45 = __THREW__; __THREW__ = 0;
     $46 = $45&1;
     if ($46) {
      $53 = ___cxa_find_matching_catch_2()|0;
      $54 = tempRet0;
      $59 = $43;
      while(1) {
       $58 = ((($59)) + -12|0);
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($58);
       $60 = ($58|0)==($11|0);
       if ($60) {
        break;
       } else {
        $59 = $58;
       }
      }
      $$2 = $53;$$232 = $54;
      break;
     } else {
      $47 = ($44|0)==($11|0);
      $48 = $47&1;
      HEAP8[$5>>0] = $48;
      $$sroa$026$0$copyload28 = HEAP32[$1>>2]|0;
      $56 = $43;
      while(1) {
       $55 = ((($56)) + -12|0);
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($55);
       $57 = ($55|0)==($11|0);
       if ($57) {
        break;
       } else {
        $56 = $55;
       }
      }
      $$sroa$026$0 = $$sroa$026$0$copyload28;
      break L1;
     }
    }
   } while(0);
   ___resumeException($$2|0);
   // unreachable;
  }
 } while(0);
 STACKTOP = sp;return ($$sroa$026$0|0);
}
function __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRl($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $10 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy1 = sp + 12|0;
 $$byval_copy = sp + 8|0;
 $6 = sp + 4|0;
 $7 = sp;
 $8 = HEAP32[$1>>2]|0;
 HEAP32[$6>>2] = $8;
 $9 = HEAP32[$2>>2]|0;
 HEAP32[$7>>2] = $9;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$6>>2]|0;
 ;HEAP32[$$byval_copy1>>2]=HEAP32[$7>>2]|0;
 $10 = (__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE15__do_get_signedIlEES4_S4_S4_RNS_8ios_baseERjRT_($0,$$byval_copy,$$byval_copy1,$3,$4,$5)|0);
 STACKTOP = sp;return ($10|0);
}
function __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRx($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $10 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy1 = sp + 12|0;
 $$byval_copy = sp + 8|0;
 $6 = sp + 4|0;
 $7 = sp;
 $8 = HEAP32[$1>>2]|0;
 HEAP32[$6>>2] = $8;
 $9 = HEAP32[$2>>2]|0;
 HEAP32[$7>>2] = $9;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$6>>2]|0;
 ;HEAP32[$$byval_copy1>>2]=HEAP32[$7>>2]|0;
 $10 = (__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE15__do_get_signedIxEES4_S4_S4_RNS_8ios_baseERjRT_($0,$$byval_copy,$$byval_copy1,$3,$4,$5)|0);
 STACKTOP = sp;return ($10|0);
}
function __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRt($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $10 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy1 = sp + 12|0;
 $$byval_copy = sp + 8|0;
 $6 = sp + 4|0;
 $7 = sp;
 $8 = HEAP32[$1>>2]|0;
 HEAP32[$6>>2] = $8;
 $9 = HEAP32[$2>>2]|0;
 HEAP32[$7>>2] = $9;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$6>>2]|0;
 ;HEAP32[$$byval_copy1>>2]=HEAP32[$7>>2]|0;
 $10 = (__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE17__do_get_unsignedItEES4_S4_S4_RNS_8ios_baseERjRT_($0,$$byval_copy,$$byval_copy1,$3,$4,$5)|0);
 STACKTOP = sp;return ($10|0);
}
function __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjS8_($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $10 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy1 = sp + 12|0;
 $$byval_copy = sp + 8|0;
 $6 = sp + 4|0;
 $7 = sp;
 $8 = HEAP32[$1>>2]|0;
 HEAP32[$6>>2] = $8;
 $9 = HEAP32[$2>>2]|0;
 HEAP32[$7>>2] = $9;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$6>>2]|0;
 ;HEAP32[$$byval_copy1>>2]=HEAP32[$7>>2]|0;
 $10 = (__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE17__do_get_unsignedIjEES4_S4_S4_RNS_8ios_baseERjRT_($0,$$byval_copy,$$byval_copy1,$3,$4,$5)|0);
 STACKTOP = sp;return ($10|0);
}
function __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRm($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $10 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy1 = sp + 12|0;
 $$byval_copy = sp + 8|0;
 $6 = sp + 4|0;
 $7 = sp;
 $8 = HEAP32[$1>>2]|0;
 HEAP32[$6>>2] = $8;
 $9 = HEAP32[$2>>2]|0;
 HEAP32[$7>>2] = $9;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$6>>2]|0;
 ;HEAP32[$$byval_copy1>>2]=HEAP32[$7>>2]|0;
 $10 = (__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE17__do_get_unsignedImEES4_S4_S4_RNS_8ios_baseERjRT_($0,$$byval_copy,$$byval_copy1,$3,$4,$5)|0);
 STACKTOP = sp;return ($10|0);
}
function __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRy($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $10 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy1 = sp + 12|0;
 $$byval_copy = sp + 8|0;
 $6 = sp + 4|0;
 $7 = sp;
 $8 = HEAP32[$1>>2]|0;
 HEAP32[$6>>2] = $8;
 $9 = HEAP32[$2>>2]|0;
 HEAP32[$7>>2] = $9;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$6>>2]|0;
 ;HEAP32[$$byval_copy1>>2]=HEAP32[$7>>2]|0;
 $10 = (__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE17__do_get_unsignedIyEES4_S4_S4_RNS_8ios_baseERjRT_($0,$$byval_copy,$$byval_copy1,$3,$4,$5)|0);
 STACKTOP = sp;return ($10|0);
}
function __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRf($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $10 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy1 = sp + 12|0;
 $$byval_copy = sp + 8|0;
 $6 = sp + 4|0;
 $7 = sp;
 $8 = HEAP32[$1>>2]|0;
 HEAP32[$6>>2] = $8;
 $9 = HEAP32[$2>>2]|0;
 HEAP32[$7>>2] = $9;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$6>>2]|0;
 ;HEAP32[$$byval_copy1>>2]=HEAP32[$7>>2]|0;
 $10 = (__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE23__do_get_floating_pointIfEES4_S4_S4_RNS_8ios_baseERjRT_($0,$$byval_copy,$$byval_copy1,$3,$4,$5)|0);
 STACKTOP = sp;return ($10|0);
}
function __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRd($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $10 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy1 = sp + 12|0;
 $$byval_copy = sp + 8|0;
 $6 = sp + 4|0;
 $7 = sp;
 $8 = HEAP32[$1>>2]|0;
 HEAP32[$6>>2] = $8;
 $9 = HEAP32[$2>>2]|0;
 HEAP32[$7>>2] = $9;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$6>>2]|0;
 ;HEAP32[$$byval_copy1>>2]=HEAP32[$7>>2]|0;
 $10 = (__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE23__do_get_floating_pointIdEES4_S4_S4_RNS_8ios_baseERjRT_($0,$$byval_copy,$$byval_copy1,$3,$4,$5)|0);
 STACKTOP = sp;return ($10|0);
}
function __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRe($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $10 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy1 = sp + 12|0;
 $$byval_copy = sp + 8|0;
 $6 = sp + 4|0;
 $7 = sp;
 $8 = HEAP32[$1>>2]|0;
 HEAP32[$6>>2] = $8;
 $9 = HEAP32[$2>>2]|0;
 HEAP32[$7>>2] = $9;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$6>>2]|0;
 ;HEAP32[$$byval_copy1>>2]=HEAP32[$7>>2]|0;
 $10 = (__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE23__do_get_floating_pointIeEES4_S4_S4_RNS_8ios_baseERjRT_($0,$$byval_copy,$$byval_copy1,$3,$4,$5)|0);
 STACKTOP = sp;return ($10|0);
}
function __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRPv($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$0 = 0, $$0$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i48 = 0, $$0$i$i2$i$i = 0, $$0$i$i2$i$i54 = 0, $$0$i$i30 = 0, $$0$i$i43 = 0, $$022 = 0, $$025 = 0, $$123 = 0, $$2 = 0, $$224 = 0, $$227 = 0, $$3 = 0, $$328 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i50 = 0, $$pre$i4$i$i56 = 0;
 var $$sroa$0$0$copyload = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0;
 var $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0;
 var $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0;
 var $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0;
 var $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0;
 var $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i$i = 0, $exitcond$i$i31 = 0, $phitmp$i = 0, $phitmp$i38 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 240|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(240|0);
 $vararg_buffer = sp;
 $6 = sp + 208|0;
 $7 = sp + 196|0;
 $8 = sp + 192|0;
 $9 = sp + 180|0;
 $10 = sp + 176|0;
 $11 = sp + 16|0;
 $12 = sp + 8|0;
 $13 = sp + 4|0;
 ;HEAP32[$7>>2]=0|0;HEAP32[$7+4>>2]=0|0;HEAP32[$7+8>>2]=0|0;
 $$0$i$i = 0;
 while(1) {
  $exitcond$i$i = ($$0$i$i|0)==(3);
  if ($exitcond$i$i) {
   break;
  }
  $14 = (($7) + ($$0$i$i<<2)|0);
  HEAP32[$14>>2] = 0;
  $15 = (($$0$i$i) + 1)|0;
  $$0$i$i = $15;
 }
 __THREW__ = 0;
 invoke_vii(3257,($8|0),($3|0));
 $16 = __THREW__; __THREW__ = 0;
 $17 = $16&1;
 do {
  if ($17) {
   $99 = ___cxa_find_matching_catch_2()|0;
   $100 = tempRet0;
   $$0 = $99;$$025 = $100;
   label = 36;
  } else {
   __THREW__ = 0;
   $18 = (invoke_iii(3255,($8|0),(215188|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    $21 = HEAP32[$18>>2]|0;
    $22 = ((($21)) + 32|0);
    $23 = HEAP32[$22>>2]|0;
    __THREW__ = 0;
    (invoke_iiiii($23|0,($18|0),(202614|0),((202640)|0),($6|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     __ZNSt3__26localeD2Ev($8);
     ;HEAP32[$9>>2]=0|0;HEAP32[$9+4>>2]=0|0;HEAP32[$9+8>>2]=0|0;
     $$0$i$i30 = 0;
     while(1) {
      $exitcond$i$i31 = ($$0$i$i30|0)==(3);
      if ($exitcond$i$i31) {
       break;
      }
      $26 = (($9) + ($$0$i$i30<<2)|0);
      HEAP32[$26>>2] = 0;
      $27 = (($$0$i$i30) + 1)|0;
      $$0$i$i30 = $27;
     }
     $28 = ((($9)) + 11|0);
     $29 = HEAP8[$28>>0]|0;
     $30 = ($29<<24>>24)<(0);
     if ($30) {
      $31 = ((($9)) + 8|0);
      $32 = HEAP32[$31>>2]|0;
      $33 = $32 & 2147483647;
      $phitmp$i = (($33) + -1)|0;
      $34 = $phitmp$i;
     } else {
      $34 = 10;
     }
     __THREW__ = 0;
     invoke_viii(3434,($9|0),($34|0),0);
     $35 = __THREW__; __THREW__ = 0;
     $36 = $35&1;
     if ($36) {
      $103 = ___cxa_find_matching_catch_2()|0;
      $104 = tempRet0;
      $$2 = $103;$$227 = $104;
     } else {
      $37 = HEAP8[$28>>0]|0;
      $38 = ($37<<24>>24)<(0);
      $39 = HEAP32[$9>>2]|0;
      $40 = $38 ? $39 : $9;
      HEAP32[$10>>2] = $40;
      HEAP32[$12>>2] = $11;
      HEAP32[$13>>2] = 0;
      $41 = ((($9)) + 4|0);
      $42 = ((($9)) + 8|0);
      $$pre = HEAP32[$1>>2]|0;
      $$022 = $40;$$pre$i$i$i = $$pre;$186 = $$pre;
      L21: while(1) {
       $43 = ($$pre$i$i$i|0)==(0|0);
       if ($43) {
        $$pre$i$i$i50 = 0;$156 = 0;$187 = 1;
       } else {
        $44 = ((($$pre$i$i$i)) + 12|0);
        $45 = HEAP32[$44>>2]|0;
        $46 = ((($$pre$i$i$i)) + 16|0);
        $47 = HEAP32[$46>>2]|0;
        $48 = ($45|0)==($47|0);
        if ($48) {
         $49 = HEAP32[$$pre$i$i$i>>2]|0;
         $50 = ((($49)) + 36|0);
         $51 = HEAP32[$50>>2]|0;
         __THREW__ = 0;
         $52 = (invoke_ii($51|0,($$pre$i$i$i|0))|0);
         $53 = __THREW__; __THREW__ = 0;
         $54 = $53&1;
         if ($54) {
          break;
         } else {
          $$0$i$i$i$i = $52;
         }
        } else {
         $55 = HEAP8[$45>>0]|0;
         $56 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($55)|0);
         $$0$i$i$i$i = $56;
        }
        $57 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
        $58 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i$i$i,$57)|0);
        if ($58) {
         HEAP32[$1>>2] = 0;
         $$pre$i$i$i50 = 0;$156 = 0;$187 = 1;
        } else {
         $$pre$i$i$i50 = $$pre$i$i$i;$156 = $186;$187 = 0;
        }
       }
       $59 = HEAP32[$2>>2]|0;
       $60 = ($59|0)==(0|0);
       do {
        if ($60) {
         label = 26;
        } else {
         $61 = ((($59)) + 12|0);
         $62 = HEAP32[$61>>2]|0;
         $63 = ((($59)) + 16|0);
         $64 = HEAP32[$63>>2]|0;
         $65 = ($62|0)==($64|0);
         if ($65) {
          $66 = HEAP32[$59>>2]|0;
          $67 = ((($66)) + 36|0);
          $68 = HEAP32[$67>>2]|0;
          __THREW__ = 0;
          $69 = (invoke_ii($68|0,($59|0))|0);
          $70 = __THREW__; __THREW__ = 0;
          $71 = $70&1;
          if ($71) {
           break L21;
          } else {
           $$0$i$i2$i$i = $69;
          }
         } else {
          $72 = HEAP8[$62>>0]|0;
          $73 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($72)|0);
          $$0$i$i2$i$i = $73;
         }
         $74 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
         $75 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i2$i$i,$74)|0);
         if ($75) {
          HEAP32[$2>>2] = 0;
          label = 26;
          break;
         } else {
          if ($187) {
           $188 = $59;
           break;
          } else {
           $$224 = $$022;$$pre$i4$i$i56 = $59;
           label = 46;
           break L21;
          }
         }
        }
       } while(0);
       if ((label|0) == 26) {
        label = 0;
        if ($187) {
         $$224 = $$022;$$pre$i4$i$i56 = 0;
         label = 46;
         break;
        } else {
         $188 = 0;
        }
       }
       $76 = HEAP32[$10>>2]|0;
       $77 = HEAP8[$28>>0]|0;
       $78 = ($77<<24>>24)<(0);
       $79 = HEAP32[$41>>2]|0;
       $80 = $77&255;
       $81 = $78 ? $79 : $80;
       $82 = (($$022) + ($81)|0);
       $83 = ($76|0)==($82|0);
       if ($83) {
        $84 = $81 << 1;
        __THREW__ = 0;
        invoke_viii(3434,($9|0),($84|0),0);
        $85 = __THREW__; __THREW__ = 0;
        $86 = $85&1;
        if ($86) {
         break;
        }
        $87 = HEAP8[$28>>0]|0;
        $88 = ($87<<24>>24)<(0);
        if ($88) {
         $89 = HEAP32[$42>>2]|0;
         $90 = $89 & 2147483647;
         $phitmp$i38 = (($90) + -1)|0;
         $91 = $phitmp$i38;
        } else {
         $91 = 10;
        }
        __THREW__ = 0;
        invoke_viii(3434,($9|0),($91|0),0);
        $92 = __THREW__; __THREW__ = 0;
        $93 = $92&1;
        if ($93) {
         break;
        }
        $94 = HEAP8[$28>>0]|0;
        $95 = ($94<<24>>24)<(0);
        $96 = HEAP32[$9>>2]|0;
        $97 = $95 ? $96 : $9;
        $98 = (($97) + ($81)|0);
        HEAP32[$10>>2] = $98;
        $$123 = $97;
       } else {
        $$123 = $$022;
       }
       $105 = ((($$pre$i$i$i50)) + 12|0);
       $106 = HEAP32[$105>>2]|0;
       $107 = ((($$pre$i$i$i50)) + 16|0);
       $108 = HEAP32[$107>>2]|0;
       $109 = ($106|0)==($108|0);
       if ($109) {
        $110 = HEAP32[$$pre$i$i$i50>>2]|0;
        $111 = ((($110)) + 36|0);
        $112 = HEAP32[$111>>2]|0;
        __THREW__ = 0;
        $113 = (invoke_ii($112|0,($$pre$i$i$i50|0))|0);
        $114 = __THREW__; __THREW__ = 0;
        $115 = $114&1;
        if ($115) {
         break;
        } else {
         $$0$i$i43 = $113;
        }
       } else {
        $116 = HEAP8[$106>>0]|0;
        $117 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($116)|0);
        $$0$i$i43 = $117;
       }
       $118 = $$0$i$i43&255;
       __THREW__ = 0;
       $119 = (invoke_iiiiiiiiiii(4667,($118|0),16,($$123|0),($10|0),($13|0),0,($7|0),($11|0),($12|0),($6|0))|0);
       $120 = __THREW__; __THREW__ = 0;
       $121 = $120&1;
       if ($121) {
        break;
       }
       $122 = ($119|0)==(0);
       if (!($122)) {
        $$224 = $$123;$$pre$i4$i$i56 = $188;
        label = 46;
        break;
       }
       $123 = HEAP32[$105>>2]|0;
       $124 = HEAP32[$107>>2]|0;
       $125 = ($123|0)==($124|0);
       if ($125) {
        $126 = HEAP32[$$pre$i$i$i50>>2]|0;
        $127 = ((($126)) + 40|0);
        $128 = HEAP32[$127>>2]|0;
        __THREW__ = 0;
        (invoke_ii($128|0,($$pre$i$i$i50|0))|0);
        $129 = __THREW__; __THREW__ = 0;
        $130 = $129&1;
        if ($130) {
         break;
        } else {
         $$022 = $$123;$$pre$i$i$i = $$pre$i$i$i50;$186 = $156;
         continue;
        }
       } else {
        $131 = ((($123)) + 1|0);
        HEAP32[$105>>2] = $131;
        $132 = HEAP8[$123>>0]|0;
        (__ZNSt3__211char_traitsIcE11to_int_typeEc($132)|0);
        $$022 = $$123;$$pre$i$i$i = $$pre$i$i$i50;$186 = $156;
        continue;
       }
      }
      L60: do {
       if ((label|0) == 46) {
        $133 = HEAP32[$10>>2]|0;
        $134 = $$224;
        $135 = (($133) - ($134))|0;
        __THREW__ = 0;
        invoke_viii(3434,($9|0),($135|0),0);
        $136 = __THREW__; __THREW__ = 0;
        $137 = $136&1;
        if (!($137)) {
         $138 = HEAP8[$28>>0]|0;
         $139 = HEAP32[$9>>2]|0;
         __THREW__ = 0;
         $140 = (invoke_i(4668)|0);
         $141 = __THREW__; __THREW__ = 0;
         $142 = $141&1;
         if (!($142)) {
          $143 = ($138<<24>>24)<(0);
          $144 = $143 ? $139 : $9;
          __THREW__ = 0;
          HEAP32[$vararg_buffer>>2] = $5;
          $145 = (invoke_iiiii(4669,($144|0),($140|0),(202647|0),($vararg_buffer|0))|0);
          $146 = __THREW__; __THREW__ = 0;
          $147 = $146&1;
          if (!($147)) {
           $148 = ($145|0)==(1);
           if (!($148)) {
            HEAP32[$4>>2] = 4;
           }
           $149 = ($$pre$i$i$i50|0)==(0|0);
           if ($149) {
            $189 = 1;
           } else {
            $150 = ((($$pre$i$i$i50)) + 12|0);
            $151 = HEAP32[$150>>2]|0;
            $152 = ((($$pre$i$i$i50)) + 16|0);
            $153 = HEAP32[$152>>2]|0;
            $154 = ($151|0)==($153|0);
            if ($154) {
             $155 = HEAP32[$156>>2]|0;
             $157 = ((($155)) + 36|0);
             $158 = HEAP32[$157>>2]|0;
             __THREW__ = 0;
             $159 = (invoke_ii($158|0,($$pre$i$i$i50|0))|0);
             $160 = __THREW__; __THREW__ = 0;
             $161 = $160&1;
             if ($161) {
              break;
             } else {
              $$0$i$i$i$i48 = $159;
             }
            } else {
             $162 = HEAP8[$151>>0]|0;
             $163 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($162)|0);
             $$0$i$i$i$i48 = $163;
            }
            $164 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
            $165 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i$i$i48,$164)|0);
            if ($165) {
             HEAP32[$1>>2] = 0;
             $189 = 1;
            } else {
             $189 = 0;
            }
           }
           $166 = ($$pre$i4$i$i56|0)==(0|0);
           do {
            if ($166) {
             label = 63;
            } else {
             $167 = ((($$pre$i4$i$i56)) + 12|0);
             $168 = HEAP32[$167>>2]|0;
             $169 = ((($$pre$i4$i$i56)) + 16|0);
             $170 = HEAP32[$169>>2]|0;
             $171 = ($168|0)==($170|0);
             if ($171) {
              $172 = HEAP32[$$pre$i4$i$i56>>2]|0;
              $173 = ((($172)) + 36|0);
              $174 = HEAP32[$173>>2]|0;
              __THREW__ = 0;
              $175 = (invoke_ii($174|0,($$pre$i4$i$i56|0))|0);
              $176 = __THREW__; __THREW__ = 0;
              $177 = $176&1;
              if ($177) {
               break L60;
              } else {
               $$0$i$i2$i$i54 = $175;
              }
             } else {
              $178 = HEAP8[$168>>0]|0;
              $179 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($178)|0);
              $$0$i$i2$i$i54 = $179;
             }
             $180 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
             $181 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i2$i$i54,$180)|0);
             if ($181) {
              HEAP32[$2>>2] = 0;
              label = 63;
              break;
             } else {
              if ($189) {
               break;
              } else {
               label = 65;
               break;
              }
             }
            }
           } while(0);
           if ((label|0) == 63) {
            if ($189) {
             label = 65;
            }
           }
           if ((label|0) == 65) {
            $182 = HEAP32[$4>>2]|0;
            $183 = $182 | 2;
            HEAP32[$4>>2] = $183;
           }
           $$sroa$0$0$copyload = HEAP32[$1>>2]|0;
           __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($9);
           __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($7);
           STACKTOP = sp;return ($$sroa$0$0$copyload|0);
          }
         }
        }
       }
      } while(0);
      $184 = ___cxa_find_matching_catch_2()|0;
      $185 = tempRet0;
      $$2 = $184;$$227 = $185;
     }
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($9);
     $$3 = $$2;$$328 = $$227;
     break;
    }
   }
   $101 = ___cxa_find_matching_catch_2()|0;
   $102 = tempRet0;
   __ZNSt3__26localeD2Ev($8);
   $$0 = $101;$$025 = $102;
   label = 36;
  }
 } while(0);
 if ((label|0) == 36) {
  $$3 = $$0;$$328 = $$025;
 }
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($7);
 ___resumeException($$3|0);
 // unreachable;
 return (0)|0;
}
function __ZNKSt3__26locale9use_facetERNS0_2idE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $3 = (__ZNSt3__26locale2id5__getEv($1)|0);
 $4 = (__ZNKSt3__26locale5__imp9use_facetEl($2,$3)|0);
 return ($4|0);
}
function __ZNSt3__26localeD2Ev($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 (__ZNSt3__214__shared_count16__release_sharedEv($1)|0);
 return;
}
function __ZNSt3__29__num_getIcE17__stage2_int_loopEciPcRS2_RjcRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjRSD_S2_($0,$1,$2,$3,$4,$5,$6,$7,$8,$9) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 $8 = $8|0;
 $9 = $9|0;
 var $$0$i$add = 0, $$0$i$idx = 0, $$0$i$ptr = 0, $$0$lcssa$i = 0, $$1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $10 = HEAP32[$3>>2]|0;
 $11 = ($10|0)==($2|0);
 do {
  if ($11) {
   $12 = ((($9)) + 24|0);
   $13 = HEAP8[$12>>0]|0;
   $14 = ($13<<24>>24)==($0<<24>>24);
   if (!($14)) {
    $15 = ((($9)) + 25|0);
    $16 = HEAP8[$15>>0]|0;
    $17 = ($16<<24>>24)==($0<<24>>24);
    if (!($17)) {
     label = 5;
     break;
    }
   }
   $18 = $14 ? 43 : 45;
   $19 = ((($2)) + 1|0);
   HEAP32[$3>>2] = $19;
   HEAP8[$2>>0] = $18;
   HEAP32[$4>>2] = 0;
   $$1 = 0;
  } else {
   label = 5;
  }
 } while(0);
 L6: do {
  if ((label|0) == 5) {
   $20 = ((($6)) + 11|0);
   $21 = HEAP8[$20>>0]|0;
   $22 = ($21<<24>>24)<(0);
   $23 = ((($6)) + 4|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = $21&255;
   $26 = $22 ? $24 : $25;
   $27 = ($26|0)!=(0);
   $28 = ($0<<24>>24)==($5<<24>>24);
   $or$cond = $28 & $27;
   if ($or$cond) {
    $29 = HEAP32[$8>>2]|0;
    $30 = $29;
    $31 = $7;
    $32 = (($30) - ($31))|0;
    $33 = ($32|0)<(160);
    if (!($33)) {
     $$1 = 0;
     break;
    }
    $34 = HEAP32[$4>>2]|0;
    $35 = ((($29)) + 4|0);
    HEAP32[$8>>2] = $35;
    HEAP32[$29>>2] = $34;
    HEAP32[$4>>2] = 0;
    $$1 = 0;
    break;
   }
   $36 = ((($9)) + 26|0);
   $$0$i$idx = 0;
   while(1) {
    $$0$i$ptr = (($9) + ($$0$i$idx)|0);
    $37 = ($$0$i$idx|0)==(26);
    if ($37) {
     $$0$lcssa$i = $36;
     break;
    }
    $38 = HEAP8[$$0$i$ptr>>0]|0;
    $39 = ($38<<24>>24)==($0<<24>>24);
    $$0$i$add = (($$0$i$idx) + 1)|0;
    if ($39) {
     $$0$lcssa$i = $$0$i$ptr;
     break;
    } else {
     $$0$i$idx = $$0$i$add;
    }
   }
   $40 = $$0$lcssa$i;
   $41 = $9;
   $42 = (($40) - ($41))|0;
   $43 = ($42|0)>(23);
   if ($43) {
    $$1 = -1;
   } else {
    $44 = (202614 + ($42)|0);
    switch ($1|0) {
    case 10: case 8:  {
     $45 = ($42|0)<($1|0);
     if (!($45)) {
      $$1 = -1;
      break L6;
     }
     break;
    }
    case 16:  {
     $46 = ($42|0)<(22);
     if (!($46)) {
      if ($11) {
       $$1 = -1;
       break L6;
      }
      $47 = $10;
      $48 = $2;
      $49 = (($47) - ($48))|0;
      $50 = ($49|0)<(3);
      if (!($50)) {
       $$1 = -1;
       break L6;
      }
      $51 = ((($10)) + -1|0);
      $52 = HEAP8[$51>>0]|0;
      $53 = ($52<<24>>24)==(48);
      if (!($53)) {
       $$1 = -1;
       break L6;
      }
      HEAP32[$4>>2] = 0;
      $54 = HEAP8[$44>>0]|0;
      $55 = ((($10)) + 1|0);
      HEAP32[$3>>2] = $55;
      HEAP8[$10>>0] = $54;
      $$1 = 0;
      break L6;
     }
     break;
    }
    default: {
    }
    }
    $56 = HEAP8[$44>>0]|0;
    $57 = ((($10)) + 1|0);
    HEAP32[$3>>2] = $57;
    HEAP8[$10>>0] = $56;
    $58 = HEAP32[$4>>2]|0;
    $59 = (($58) + 1)|0;
    HEAP32[$4>>2] = $59;
    $$1 = 0;
   }
  }
 } while(0);
 return ($$1|0);
}
function __ZNSt3__26__clocEv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[207040]|0;
 $1 = ($0<<24>>24)==(0);
 do {
  if ($1) {
   $2 = (___cxa_guard_acquire(207040)|0);
   $3 = ($2|0)==(0);
   if (!($3)) {
    __THREW__ = 0;
    $4 = (invoke_iiii(4670,2147483647,(202650|0),(0|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     $8 = ___cxa_find_matching_catch_2()|0;
     $9 = tempRet0;
     ___resumeException($8|0);
     // unreachable;
    } else {
     HEAP32[53799] = $4;
     break;
    }
   }
  }
 } while(0);
 $7 = HEAP32[53799]|0;
 return ($7|0);
}
function __ZNSt3__217__libcpp_sscanf_lEPKcP15__locale_structS1_z($0,$1,$2,$varargs) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $varargs = $varargs|0;
 var $10 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 HEAP32[$3>>2] = $varargs;
 $4 = (___uselocale($1)|0);
 $5 = (_vsscanf($0,$2,$3)|0);
 $6 = ($4|0)==(0|0);
 if (!($6)) {
  __THREW__ = 0;
  (invoke_ii(4671,($4|0))|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if ($8) {
   $9 = ___cxa_find_matching_catch_3(0|0)|0;
   $10 = tempRet0;
   ___clang_call_terminate($9);
   // unreachable;
  }
 }
 STACKTOP = sp;return ($5|0);
}
function __ZNSt3__26locale2id5__getEv($0) {
 $0 = $0|0;
 var $$byval_copy = 0, $$fca$1$gep = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $$byval_copy = sp + 32|0;
 $1 = sp + 24|0;
 $2 = sp + 20|0;
 $3 = sp + 8|0;
 $4 = sp;
 HEAP32[$4>>2] = (4672);
 $$fca$1$gep = ((($4)) + 4|0);
 HEAP32[$$fca$1$gep>>2] = 0;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$4>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$4+4>>2]|0;
 __ZNSt3__212_GLOBAL__N_111__fake_bindC2EMNS_6locale2idEFvvEPS3_($3,$$byval_copy,$0);
 $5 = HEAP32[$0>>2]|0;
 $6 = ($5|0)==(-1);
 if (!($6)) {
  HEAP32[$1>>2] = $3;
  HEAP32[$2>>2] = $1;
  __ZNSt3__211__call_onceERVmPvPFvS2_E($0,$2,4673);
 }
 $7 = ((($0)) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + -1)|0;
 STACKTOP = sp;return ($9|0);
}
function __ZNKSt3__26locale5__imp9use_facetEl($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__ZNKSt3__26locale5__imp9has_facetEl($0,$1)|0);
 if ($2) {
  $4 = ((($0)) + 8|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($5) + ($1<<2)|0);
  $7 = HEAP32[$6>>2]|0;
  return ($7|0);
 } else {
  $3 = (___cxa_allocate_exception(4)|0);
  __ZNSt8bad_castC2Ev($3);
  ___cxa_throw(($3|0),(34640|0),(3238|0));
  // unreachable;
 }
 return (0)|0;
}
function __ZNKSt3__26locale5__imp9has_facetEl($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 8|0);
 $3 = ((($0)) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$2>>2]|0;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 2;
 $8 = ($7>>>0)>($1>>>0);
 if ($8) {
  $9 = $5;
  $10 = (($9) + ($1<<2)|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($11|0)!=(0|0);
  $13 = $12;
 } else {
  $13 = 0;
 }
 return ($13|0);
}
function __ZNSt3__26locale2id6__initEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[53800]|0;HEAP32[53800] = (($1+1)|0);
 $2 = (($1) + 1)|0;
 $3 = ((($0)) + 4|0);
 HEAP32[$3>>2] = $2;
 return;
}
function __ZNSt3__212_GLOBAL__N_111__fake_bindC2EMNS_6locale2idEFvvEPS3_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$elt4 = 0, $$repack = 0, $$repack7 = 0, $$unpack = 0, $$unpack5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$unpack = HEAP32[$1>>2]|0;
 $$elt4 = ((($1)) + 4|0);
 $$unpack5 = HEAP32[$$elt4>>2]|0;
 HEAP32[$0>>2] = $2;
 $$repack = ((($0)) + 4|0);
 HEAP32[$$repack>>2] = $$unpack;
 $$repack7 = ((($0)) + 8|0);
 HEAP32[$$repack7>>2] = $$unpack5;
 return;
}
function __ZNSt3__217__call_once_proxyINS_5tupleIJONS_12_GLOBAL__N_111__fake_bindEEEEEEvPv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 __ZNKSt3__212_GLOBAL__N_111__fake_bindclEv($2);
 return;
}
function __ZNKSt3__212_GLOBAL__N_111__fake_bindclEv($0) {
 $0 = $0|0;
 var $$elt = 0, $$elt1 = 0, $$unpack = 0, $$unpack2 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $$elt = ((($0)) + 4|0);
 $$unpack = HEAP32[$$elt>>2]|0;
 $$elt1 = ((($0)) + 8|0);
 $$unpack2 = HEAP32[$$elt1>>2]|0;
 $2 = $$unpack2 >> 1;
 $3 = (($1) + ($2)|0);
 $4 = $$unpack2 & 1;
 $5 = ($4|0)==(0);
 if ($5) {
  $9 = $$unpack;
  $10 = $9;
 } else {
  $6 = HEAP32[$3>>2]|0;
  $7 = (($6) + ($$unpack)|0);
  $8 = HEAP32[$7>>2]|0;
  $10 = $8;
 }
 FUNCTION_TABLE_vi[$10 & 8191]($3);
 return;
}
function __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE23__do_get_floating_pointIeEES4_S4_S4_RNS_8ios_baseERjRT_($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$0$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i38 = 0, $$0$i$i2$i$i = 0, $$0$i$i2$i$i44 = 0, $$0$i$i34 = 0, $$018 = 0, $$1 = 0, $$119 = 0, $$121 = 0, $$2 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i40 = 0, $$pre$i4$i$i46 = 0, $$sroa$0$0$copyload = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0;
 var $14 = 0, $140 = 0.0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0;
 var $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0;
 var $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i$i = 0, $or$cond = 0, $phitmp$i = 0;
 var $phitmp$i29 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 240|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(240|0);
 $6 = sp + 200|0;
 $7 = sp + 199|0;
 $8 = sp + 198|0;
 $9 = sp + 184|0;
 $10 = sp + 172|0;
 $11 = sp + 168|0;
 $12 = sp + 8|0;
 $13 = sp + 4|0;
 $14 = sp;
 $15 = sp + 197|0;
 $16 = sp + 196|0;
 __ZNSt3__29__num_getIcE19__stage2_float_prepERNS_8ios_baseEPcRcS5_($9,$3,$6,$7,$8);
 ;HEAP32[$10>>2]=0|0;HEAP32[$10+4>>2]=0|0;HEAP32[$10+8>>2]=0|0;
 $$0$i$i = 0;
 while(1) {
  $exitcond$i$i = ($$0$i$i|0)==(3);
  if ($exitcond$i$i) {
   break;
  }
  $17 = (($10) + ($$0$i$i<<2)|0);
  HEAP32[$17>>2] = 0;
  $18 = (($$0$i$i) + 1)|0;
  $$0$i$i = $18;
 }
 $19 = ((($10)) + 11|0);
 $20 = HEAP8[$19>>0]|0;
 $21 = ($20<<24>>24)<(0);
 if ($21) {
  $22 = ((($10)) + 8|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = $23 & 2147483647;
  $phitmp$i = (($24) + -1)|0;
  $25 = $phitmp$i;
 } else {
  $25 = 10;
 }
 __THREW__ = 0;
 invoke_viii(3434,($10|0),($25|0),0);
 $26 = __THREW__; __THREW__ = 0;
 $27 = $26&1;
 if ($27) {
  $90 = ___cxa_find_matching_catch_2()|0;
  $91 = tempRet0;
  $$1 = $90;$$121 = $91;
 } else {
  $28 = HEAP8[$19>>0]|0;
  $29 = ($28<<24>>24)<(0);
  $30 = HEAP32[$10>>2]|0;
  $31 = $29 ? $30 : $10;
  HEAP32[$11>>2] = $31;
  HEAP32[$13>>2] = $12;
  HEAP32[$14>>2] = 0;
  HEAP8[$15>>0] = 1;
  HEAP8[$16>>0] = 69;
  $32 = ((($10)) + 4|0);
  $33 = ((($10)) + 8|0);
  $$pre = HEAP32[$1>>2]|0;
  $$018 = $31;$$pre$i$i$i = $$pre;$183 = $$pre;
  L11: while(1) {
   $34 = ($$pre$i$i$i|0)==(0|0);
   if ($34) {
    $$pre$i$i$i40 = 0;$153 = 0;$184 = 1;
   } else {
    $35 = ((($$pre$i$i$i)) + 12|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = ((($$pre$i$i$i)) + 16|0);
    $38 = HEAP32[$37>>2]|0;
    $39 = ($36|0)==($38|0);
    if ($39) {
     $40 = HEAP32[$$pre$i$i$i>>2]|0;
     $41 = ((($40)) + 36|0);
     $42 = HEAP32[$41>>2]|0;
     __THREW__ = 0;
     $43 = (invoke_ii($42|0,($$pre$i$i$i|0))|0);
     $44 = __THREW__; __THREW__ = 0;
     $45 = $44&1;
     if ($45) {
      break;
     } else {
      $$0$i$i$i$i = $43;
     }
    } else {
     $46 = HEAP8[$36>>0]|0;
     $47 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($46)|0);
     $$0$i$i$i$i = $47;
    }
    $48 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
    $49 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i$i$i,$48)|0);
    if ($49) {
     HEAP32[$1>>2] = 0;
     $$pre$i$i$i40 = 0;$153 = 0;$184 = 1;
    } else {
     $$pre$i$i$i40 = $$pre$i$i$i;$153 = $183;$184 = 0;
    }
   }
   $50 = HEAP32[$2>>2]|0;
   $51 = ($50|0)==(0|0);
   do {
    if ($51) {
     label = 20;
    } else {
     $52 = ((($50)) + 12|0);
     $53 = HEAP32[$52>>2]|0;
     $54 = ((($50)) + 16|0);
     $55 = HEAP32[$54>>2]|0;
     $56 = ($53|0)==($55|0);
     if ($56) {
      $57 = HEAP32[$50>>2]|0;
      $58 = ((($57)) + 36|0);
      $59 = HEAP32[$58>>2]|0;
      __THREW__ = 0;
      $60 = (invoke_ii($59|0,($50|0))|0);
      $61 = __THREW__; __THREW__ = 0;
      $62 = $61&1;
      if ($62) {
       break L11;
      } else {
       $$0$i$i2$i$i = $60;
      }
     } else {
      $63 = HEAP8[$53>>0]|0;
      $64 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($63)|0);
      $$0$i$i2$i$i = $64;
     }
     $65 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
     $66 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i2$i$i,$65)|0);
     if ($66) {
      HEAP32[$2>>2] = 0;
      label = 20;
      break;
     } else {
      if ($184) {
       $185 = $50;
       break;
      } else {
       $$2 = $$018;$$pre$i4$i$i46 = $50;
       label = 37;
       break L11;
      }
     }
    }
   } while(0);
   if ((label|0) == 20) {
    label = 0;
    if ($184) {
     $$2 = $$018;$$pre$i4$i$i46 = 0;
     label = 37;
     break;
    } else {
     $185 = 0;
    }
   }
   $67 = HEAP32[$11>>2]|0;
   $68 = HEAP8[$19>>0]|0;
   $69 = ($68<<24>>24)<(0);
   $70 = HEAP32[$32>>2]|0;
   $71 = $68&255;
   $72 = $69 ? $70 : $71;
   $73 = (($$018) + ($72)|0);
   $74 = ($67|0)==($73|0);
   if ($74) {
    $75 = $72 << 1;
    __THREW__ = 0;
    invoke_viii(3434,($10|0),($75|0),0);
    $76 = __THREW__; __THREW__ = 0;
    $77 = $76&1;
    if ($77) {
     break;
    }
    $78 = HEAP8[$19>>0]|0;
    $79 = ($78<<24>>24)<(0);
    if ($79) {
     $80 = HEAP32[$33>>2]|0;
     $81 = $80 & 2147483647;
     $phitmp$i29 = (($81) + -1)|0;
     $82 = $phitmp$i29;
    } else {
     $82 = 10;
    }
    __THREW__ = 0;
    invoke_viii(3434,($10|0),($82|0),0);
    $83 = __THREW__; __THREW__ = 0;
    $84 = $83&1;
    if ($84) {
     break;
    }
    $85 = HEAP8[$19>>0]|0;
    $86 = ($85<<24>>24)<(0);
    $87 = HEAP32[$10>>2]|0;
    $88 = $86 ? $87 : $10;
    $89 = (($88) + ($72)|0);
    HEAP32[$11>>2] = $89;
    $$119 = $88;
   } else {
    $$119 = $$018;
   }
   $92 = ((($$pre$i$i$i40)) + 12|0);
   $93 = HEAP32[$92>>2]|0;
   $94 = ((($$pre$i$i$i40)) + 16|0);
   $95 = HEAP32[$94>>2]|0;
   $96 = ($93|0)==($95|0);
   if ($96) {
    $97 = HEAP32[$$pre$i$i$i40>>2]|0;
    $98 = ((($97)) + 36|0);
    $99 = HEAP32[$98>>2]|0;
    __THREW__ = 0;
    $100 = (invoke_ii($99|0,($$pre$i$i$i40|0))|0);
    $101 = __THREW__; __THREW__ = 0;
    $102 = $101&1;
    if ($102) {
     break;
    } else {
     $$0$i$i34 = $100;
    }
   } else {
    $103 = HEAP8[$93>>0]|0;
    $104 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($103)|0);
    $$0$i$i34 = $104;
   }
   $105 = $$0$i$i34&255;
   $106 = HEAP8[$7>>0]|0;
   $107 = HEAP8[$8>>0]|0;
   __THREW__ = 0;
   $108 = (invoke_iiiiiiiiiiiii(4674,($105|0),($15|0),($16|0),($$119|0),($11|0),($106|0),($107|0),($9|0),($12|0),($13|0),($14|0),($6|0))|0);
   $109 = __THREW__; __THREW__ = 0;
   $110 = $109&1;
   if ($110) {
    break;
   }
   $111 = ($108|0)==(0);
   if (!($111)) {
    $$2 = $$119;$$pre$i4$i$i46 = $185;
    label = 37;
    break;
   }
   $112 = HEAP32[$92>>2]|0;
   $113 = HEAP32[$94>>2]|0;
   $114 = ($112|0)==($113|0);
   if ($114) {
    $115 = HEAP32[$$pre$i$i$i40>>2]|0;
    $116 = ((($115)) + 40|0);
    $117 = HEAP32[$116>>2]|0;
    __THREW__ = 0;
    (invoke_ii($117|0,($$pre$i$i$i40|0))|0);
    $118 = __THREW__; __THREW__ = 0;
    $119 = $118&1;
    if ($119) {
     break;
    } else {
     $$018 = $$119;$$pre$i$i$i = $$pre$i$i$i40;$183 = $153;
     continue;
    }
   } else {
    $120 = ((($112)) + 1|0);
    HEAP32[$92>>2] = $120;
    $121 = HEAP8[$112>>0]|0;
    (__ZNSt3__211char_traitsIcE11to_int_typeEc($121)|0);
    $$018 = $$119;$$pre$i$i$i = $$pre$i$i$i40;$183 = $153;
    continue;
   }
  }
  L50: do {
   if ((label|0) == 37) {
    $122 = ((($9)) + 11|0);
    $123 = HEAP8[$122>>0]|0;
    $124 = ($123<<24>>24)<(0);
    $125 = ((($9)) + 4|0);
    $126 = HEAP32[$125>>2]|0;
    $127 = $123&255;
    $128 = $124 ? $126 : $127;
    $129 = ($128|0)==(0);
    $130 = HEAP8[$15>>0]|0;
    $131 = ($130<<24>>24)==(0);
    $or$cond = $129 | $131;
    if (!($or$cond)) {
     $132 = HEAP32[$13>>2]|0;
     $133 = $132;
     $134 = $12;
     $135 = (($133) - ($134))|0;
     $136 = ($135|0)<(160);
     if ($136) {
      $137 = HEAP32[$14>>2]|0;
      $138 = ((($132)) + 4|0);
      HEAP32[$13>>2] = $138;
      HEAP32[$132>>2] = $137;
     }
    }
    $139 = HEAP32[$11>>2]|0;
    __THREW__ = 0;
    $140 = (+invoke_diii(4675,($$2|0),($139|0),($4|0)));
    $141 = __THREW__; __THREW__ = 0;
    $142 = $141&1;
    if (!($142)) {
     HEAPF64[$5>>3] = $140;
     $143 = HEAP32[$13>>2]|0;
     __THREW__ = 0;
     invoke_viiii(4676,($9|0),($12|0),($143|0),($4|0));
     $144 = __THREW__; __THREW__ = 0;
     $145 = $144&1;
     if (!($145)) {
      $146 = ($$pre$i$i$i40|0)==(0|0);
      if ($146) {
       $186 = 1;
      } else {
       $147 = ((($$pre$i$i$i40)) + 12|0);
       $148 = HEAP32[$147>>2]|0;
       $149 = ((($$pre$i$i$i40)) + 16|0);
       $150 = HEAP32[$149>>2]|0;
       $151 = ($148|0)==($150|0);
       if ($151) {
        $152 = HEAP32[$153>>2]|0;
        $154 = ((($152)) + 36|0);
        $155 = HEAP32[$154>>2]|0;
        __THREW__ = 0;
        $156 = (invoke_ii($155|0,($$pre$i$i$i40|0))|0);
        $157 = __THREW__; __THREW__ = 0;
        $158 = $157&1;
        if ($158) {
         break;
        } else {
         $$0$i$i$i$i38 = $156;
        }
       } else {
        $159 = HEAP8[$148>>0]|0;
        $160 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($159)|0);
        $$0$i$i$i$i38 = $160;
       }
       $161 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
       $162 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i$i$i38,$161)|0);
       if ($162) {
        HEAP32[$1>>2] = 0;
        $186 = 1;
       } else {
        $186 = 0;
       }
      }
      $163 = ($$pre$i4$i$i46|0)==(0|0);
      do {
       if ($163) {
        label = 54;
       } else {
        $164 = ((($$pre$i4$i$i46)) + 12|0);
        $165 = HEAP32[$164>>2]|0;
        $166 = ((($$pre$i4$i$i46)) + 16|0);
        $167 = HEAP32[$166>>2]|0;
        $168 = ($165|0)==($167|0);
        if ($168) {
         $169 = HEAP32[$$pre$i4$i$i46>>2]|0;
         $170 = ((($169)) + 36|0);
         $171 = HEAP32[$170>>2]|0;
         __THREW__ = 0;
         $172 = (invoke_ii($171|0,($$pre$i4$i$i46|0))|0);
         $173 = __THREW__; __THREW__ = 0;
         $174 = $173&1;
         if ($174) {
          break L50;
         } else {
          $$0$i$i2$i$i44 = $172;
         }
        } else {
         $175 = HEAP8[$165>>0]|0;
         $176 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($175)|0);
         $$0$i$i2$i$i44 = $176;
        }
        $177 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
        $178 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i2$i$i44,$177)|0);
        if ($178) {
         HEAP32[$2>>2] = 0;
         label = 54;
         break;
        } else {
         if ($186) {
          break;
         } else {
          label = 56;
          break;
         }
        }
       }
      } while(0);
      if ((label|0) == 54) {
       if ($186) {
        label = 56;
       }
      }
      if ((label|0) == 56) {
       $179 = HEAP32[$4>>2]|0;
       $180 = $179 | 2;
       HEAP32[$4>>2] = $180;
      }
      $$sroa$0$0$copyload = HEAP32[$1>>2]|0;
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($10);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($9);
      STACKTOP = sp;return ($$sroa$0$0$copyload|0);
     }
    }
   }
  } while(0);
  $181 = ___cxa_find_matching_catch_2()|0;
  $182 = tempRet0;
  $$1 = $181;$$121 = $182;
 }
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($10);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($9);
 ___resumeException($$1|0);
 // unreachable;
 return (0)|0;
}
function __ZNSt3__29__num_getIcE19__stage2_float_prepERNS_8ios_baseEPcRcS5_($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $5 = sp;
 __ZNKSt3__28ios_base6getlocEv($5,$1);
 __THREW__ = 0;
 $6 = (invoke_iii(3255,($5|0),(215188|0))|0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if (!($8)) {
  $9 = HEAP32[$6>>2]|0;
  $10 = ((($9)) + 32|0);
  $11 = HEAP32[$10>>2]|0;
  __THREW__ = 0;
  (invoke_iiiii($11|0,($6|0),(202614|0),((202646)|0),($2|0))|0);
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if (!($13)) {
   __THREW__ = 0;
   $14 = (invoke_iii(3255,($5|0),(215204|0))|0);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    $17 = HEAP32[$14>>2]|0;
    $18 = ((($17)) + 12|0);
    $19 = HEAP32[$18>>2]|0;
    __THREW__ = 0;
    $20 = (invoke_ii($19|0,($14|0))|0);
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if (!($22)) {
     HEAP8[$3>>0] = $20;
     $23 = HEAP32[$14>>2]|0;
     $24 = ((($23)) + 16|0);
     $25 = HEAP32[$24>>2]|0;
     __THREW__ = 0;
     $26 = (invoke_ii($25|0,($14|0))|0);
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     if (!($28)) {
      HEAP8[$4>>0] = $26;
      $29 = HEAP32[$14>>2]|0;
      $30 = ((($29)) + 20|0);
      $31 = HEAP32[$30>>2]|0;
      __THREW__ = 0;
      invoke_vii($31|0,($0|0),($14|0));
      $32 = __THREW__; __THREW__ = 0;
      $33 = $32&1;
      if (!($33)) {
       __ZNSt3__26localeD2Ev($5);
       STACKTOP = sp;return;
      }
     }
    }
   }
  }
 }
 $34 = ___cxa_find_matching_catch_2()|0;
 $35 = tempRet0;
 __ZNSt3__26localeD2Ev($5);
 ___resumeException($34|0);
 // unreachable;
}
function __ZNSt3__29__num_getIcE19__stage2_float_loopEcRbRcPcRS4_ccRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjRSE_RjS4_($0,$1,$2,$3,$4,$5,$6,$7,$8,$9,$10,$11) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 $8 = $8|0;
 $9 = $9|0;
 $10 = $10|0;
 $11 = $11|0;
 var $$0$i$add = 0, $$0$i$idx = 0, $$0$i$ptr = 0, $$0$lcssa$i = 0, $$2 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $12 = ($0<<24>>24)==($5<<24>>24);
 $13 = $8;
 L1: do {
  if ($12) {
   $14 = HEAP8[$1>>0]|0;
   $15 = ($14<<24>>24)==(0);
   if ($15) {
    $$2 = -1;
   } else {
    HEAP8[$1>>0] = 0;
    $16 = HEAP32[$4>>2]|0;
    $17 = ((($16)) + 1|0);
    HEAP32[$4>>2] = $17;
    HEAP8[$16>>0] = 46;
    $18 = ((($7)) + 11|0);
    $19 = HEAP8[$18>>0]|0;
    $20 = ($19<<24>>24)<(0);
    $21 = ((($7)) + 4|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = $19&255;
    $24 = $20 ? $22 : $23;
    $25 = ($24|0)==(0);
    if ($25) {
     $$2 = 0;
    } else {
     $26 = HEAP32[$9>>2]|0;
     $27 = $26;
     $28 = (($27) - ($13))|0;
     $29 = ($28|0)<(160);
     if ($29) {
      $30 = HEAP32[$10>>2]|0;
      $31 = ((($26)) + 4|0);
      HEAP32[$9>>2] = $31;
      HEAP32[$26>>2] = $30;
      $$2 = 0;
     } else {
      $$2 = 0;
     }
    }
   }
  } else {
   $32 = ($0<<24>>24)==($6<<24>>24);
   if ($32) {
    $33 = ((($7)) + 11|0);
    $34 = HEAP8[$33>>0]|0;
    $35 = ($34<<24>>24)<(0);
    $36 = ((($7)) + 4|0);
    $37 = HEAP32[$36>>2]|0;
    $38 = $34&255;
    $39 = $35 ? $37 : $38;
    $40 = ($39|0)==(0);
    if (!($40)) {
     $41 = HEAP8[$1>>0]|0;
     $42 = ($41<<24>>24)==(0);
     if ($42) {
      $$2 = -1;
      break;
     }
     $43 = HEAP32[$9>>2]|0;
     $44 = $43;
     $45 = (($44) - ($13))|0;
     $46 = ($45|0)<(160);
     if (!($46)) {
      $$2 = 0;
      break;
     }
     $47 = HEAP32[$10>>2]|0;
     $48 = ((($43)) + 4|0);
     HEAP32[$9>>2] = $48;
     HEAP32[$43>>2] = $47;
     HEAP32[$10>>2] = 0;
     $$2 = 0;
     break;
    }
   }
   $49 = ((($11)) + 32|0);
   $$0$i$idx = 0;
   while(1) {
    $$0$i$ptr = (($11) + ($$0$i$idx)|0);
    $50 = ($$0$i$idx|0)==(32);
    if ($50) {
     $$0$lcssa$i = $49;
     break;
    }
    $51 = HEAP8[$$0$i$ptr>>0]|0;
    $52 = ($51<<24>>24)==($0<<24>>24);
    $$0$i$add = (($$0$i$idx) + 1)|0;
    if ($52) {
     $$0$lcssa$i = $$0$i$ptr;
     break;
    } else {
     $$0$i$idx = $$0$i$add;
    }
   }
   $53 = $$0$lcssa$i;
   $54 = $11;
   $55 = (($53) - ($54))|0;
   $56 = ($55|0)>(31);
   if ($56) {
    $$2 = -1;
   } else {
    $57 = (202614 + ($55)|0);
    $58 = HEAP8[$57>>0]|0;
    switch ($55|0) {
    case 24: case 25:  {
     $59 = HEAP32[$4>>2]|0;
     $60 = ($59|0)==($3|0);
     if (!($60)) {
      $61 = ((($59)) + -1|0);
      $62 = HEAP8[$61>>0]|0;
      $63 = $62 & 95;
      $64 = HEAP8[$2>>0]|0;
      $65 = $64 & 127;
      $66 = ($63<<24>>24)==($65<<24>>24);
      if (!($66)) {
       $$2 = -1;
       break L1;
      }
     }
     $67 = ((($59)) + 1|0);
     HEAP32[$4>>2] = $67;
     HEAP8[$59>>0] = $58;
     $$2 = 0;
     break L1;
     break;
    }
    case 23: case 22:  {
     HEAP8[$2>>0] = 80;
     $68 = HEAP32[$4>>2]|0;
     $69 = ((($68)) + 1|0);
     HEAP32[$4>>2] = $69;
     HEAP8[$68>>0] = $58;
     $$2 = 0;
     break L1;
     break;
    }
    default: {
     $70 = $58 & 95;
     $71 = $70&255;
     $72 = HEAP8[$2>>0]|0;
     $73 = $72 << 24 >> 24;
     $74 = ($71|0)==($73|0);
     if ($74) {
      $75 = $71 | 128;
      $76 = $75&255;
      HEAP8[$2>>0] = $76;
      $77 = HEAP8[$1>>0]|0;
      $78 = ($77<<24>>24)==(0);
      if (!($78)) {
       HEAP8[$1>>0] = 0;
       $79 = ((($7)) + 11|0);
       $80 = HEAP8[$79>>0]|0;
       $81 = ($80<<24>>24)<(0);
       $82 = ((($7)) + 4|0);
       $83 = HEAP32[$82>>2]|0;
       $84 = $80&255;
       $85 = $81 ? $83 : $84;
       $86 = ($85|0)==(0);
       if (!($86)) {
        $87 = HEAP32[$9>>2]|0;
        $88 = $87;
        $89 = (($88) - ($13))|0;
        $90 = ($89|0)<(160);
        if ($90) {
         $91 = HEAP32[$10>>2]|0;
         $92 = ((($87)) + 4|0);
         HEAP32[$9>>2] = $92;
         HEAP32[$87>>2] = $91;
        }
       }
      }
     }
     $93 = HEAP32[$4>>2]|0;
     $94 = ((($93)) + 1|0);
     HEAP32[$4>>2] = $94;
     HEAP8[$93>>0] = $58;
     $95 = ($55|0)>(21);
     if ($95) {
      $$2 = 0;
      break L1;
     }
     $96 = HEAP32[$10>>2]|0;
     $97 = (($96) + 1)|0;
     HEAP32[$10>>2] = $97;
     $$2 = 0;
     break L1;
    }
    }
   }
  }
 } while(0);
 return ($$2|0);
}
function __ZNSt3__215__num_get_floatIeEET_PKcS3_Rj($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0.0, $$0$ph = 0.0, $$1 = 0.0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = ($0|0)==($1|0);
 if ($4) {
  HEAP32[$2>>2] = 4;
  $$1 = 0.0;
 } else {
  $5 = (___errno_location()|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (___errno_location()|0);
  HEAP32[$7>>2] = 0;
  $8 = (__ZNSt3__26__clocEv()|0);
  $9 = (+_strtold_l($0,$3,$8));
  $10 = (___errno_location()|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($11|0)==(0);
  if ($12) {
   $13 = (___errno_location()|0);
   HEAP32[$13>>2] = $6;
  }
  $14 = HEAP32[$3>>2]|0;
  $15 = ($14|0)==($1|0);
  if ($15) {
   $16 = ($11|0)==(34);
   if ($16) {
    $$0$ph = $9;
    label = 6;
   } else {
    $$0 = $9;
   }
  } else {
   $$0$ph = 0.0;
   label = 6;
  }
  if ((label|0) == 6) {
   HEAP32[$2>>2] = 4;
   $$0 = $$0$ph;
  }
  $$1 = $$0;
 }
 STACKTOP = sp;return (+$$1);
}
function __ZNSt3__216__check_groupingERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjS8_Rj($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$$030 = 0, $$0$i$i = 0, $$029 = 0, $$030 = 0, $$07$i$i = 0, $$pre = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $or$cond32 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ((($0)) + 11|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)<(0);
 $7 = ((($0)) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $5&255;
 $10 = $6 ? $8 : $9;
 $11 = ($10|0)==(0);
 do {
  if (!($11)) {
   $12 = ($1|0)==($2|0);
   if ($12) {
    $20 = $8;
   } else {
    $$0$i$i = $2;$$07$i$i = $1;
    while(1) {
     $13 = ((($$0$i$i)) + -4|0);
     $14 = ($$07$i$i>>>0)<($13>>>0);
     if (!($14)) {
      break;
     }
     $15 = HEAP32[$$07$i$i>>2]|0;
     $16 = HEAP32[$13>>2]|0;
     HEAP32[$$07$i$i>>2] = $16;
     HEAP32[$13>>2] = $15;
     $17 = ((($$07$i$i)) + 4|0);
     $$0$i$i = $13;$$07$i$i = $17;
    }
    $$pre = HEAP32[$7>>2]|0;
    $20 = $$pre;
   }
   $18 = HEAP32[$0>>2]|0;
   $19 = $6 ? $18 : $0;
   $21 = $6 ? $20 : $9;
   $22 = (($19) + ($21)|0);
   $23 = ((($2)) + -4|0);
   $24 = $22;
   $$029 = $1;$$030 = $19;
   while(1) {
    $25 = ($$029>>>0)<($23>>>0);
    $26 = HEAP8[$$030>>0]|0;
    $27 = ($26<<24>>24)>(0);
    $28 = ($26<<24>>24)!=(127);
    $or$cond32 = $27 & $28;
    if (!($25)) {
     break;
    }
    if ($or$cond32) {
     $29 = $26 << 24 >> 24;
     $30 = HEAP32[$$029>>2]|0;
     $31 = ($29|0)==($30|0);
     if (!($31)) {
      label = 10;
      break;
     }
    }
    $32 = $$030;
    $33 = (($24) - ($32))|0;
    $34 = ($33|0)>(1);
    $35 = ((($$030)) + 1|0);
    $$$030 = $34 ? $35 : $$030;
    $36 = ((($$029)) + 4|0);
    $$029 = $36;$$030 = $$$030;
   }
   if ((label|0) == 10) {
    HEAP32[$3>>2] = 4;
    break;
   }
   if ($or$cond32) {
    $37 = $26 << 24 >> 24;
    $38 = HEAP32[$23>>2]|0;
    $39 = (($38) + -1)|0;
    $40 = ($39>>>0)<($37>>>0);
    if (!($40)) {
     HEAP32[$3>>2] = 4;
    }
   }
  }
 } while(0);
 return;
}
function __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE23__do_get_floating_pointIdEES4_S4_S4_RNS_8ios_baseERjRT_($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$0$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i38 = 0, $$0$i$i2$i$i = 0, $$0$i$i2$i$i44 = 0, $$0$i$i34 = 0, $$018 = 0, $$1 = 0, $$119 = 0, $$121 = 0, $$2 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i40 = 0, $$pre$i4$i$i46 = 0, $$sroa$0$0$copyload = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0;
 var $14 = 0, $140 = 0.0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0;
 var $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0;
 var $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i$i = 0, $or$cond = 0, $phitmp$i = 0;
 var $phitmp$i29 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 240|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(240|0);
 $6 = sp + 200|0;
 $7 = sp + 199|0;
 $8 = sp + 198|0;
 $9 = sp + 184|0;
 $10 = sp + 172|0;
 $11 = sp + 168|0;
 $12 = sp + 8|0;
 $13 = sp + 4|0;
 $14 = sp;
 $15 = sp + 197|0;
 $16 = sp + 196|0;
 __ZNSt3__29__num_getIcE19__stage2_float_prepERNS_8ios_baseEPcRcS5_($9,$3,$6,$7,$8);
 ;HEAP32[$10>>2]=0|0;HEAP32[$10+4>>2]=0|0;HEAP32[$10+8>>2]=0|0;
 $$0$i$i = 0;
 while(1) {
  $exitcond$i$i = ($$0$i$i|0)==(3);
  if ($exitcond$i$i) {
   break;
  }
  $17 = (($10) + ($$0$i$i<<2)|0);
  HEAP32[$17>>2] = 0;
  $18 = (($$0$i$i) + 1)|0;
  $$0$i$i = $18;
 }
 $19 = ((($10)) + 11|0);
 $20 = HEAP8[$19>>0]|0;
 $21 = ($20<<24>>24)<(0);
 if ($21) {
  $22 = ((($10)) + 8|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = $23 & 2147483647;
  $phitmp$i = (($24) + -1)|0;
  $25 = $phitmp$i;
 } else {
  $25 = 10;
 }
 __THREW__ = 0;
 invoke_viii(3434,($10|0),($25|0),0);
 $26 = __THREW__; __THREW__ = 0;
 $27 = $26&1;
 if ($27) {
  $90 = ___cxa_find_matching_catch_2()|0;
  $91 = tempRet0;
  $$1 = $90;$$121 = $91;
 } else {
  $28 = HEAP8[$19>>0]|0;
  $29 = ($28<<24>>24)<(0);
  $30 = HEAP32[$10>>2]|0;
  $31 = $29 ? $30 : $10;
  HEAP32[$11>>2] = $31;
  HEAP32[$13>>2] = $12;
  HEAP32[$14>>2] = 0;
  HEAP8[$15>>0] = 1;
  HEAP8[$16>>0] = 69;
  $32 = ((($10)) + 4|0);
  $33 = ((($10)) + 8|0);
  $$pre = HEAP32[$1>>2]|0;
  $$018 = $31;$$pre$i$i$i = $$pre;$183 = $$pre;
  L11: while(1) {
   $34 = ($$pre$i$i$i|0)==(0|0);
   if ($34) {
    $$pre$i$i$i40 = 0;$153 = 0;$184 = 1;
   } else {
    $35 = ((($$pre$i$i$i)) + 12|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = ((($$pre$i$i$i)) + 16|0);
    $38 = HEAP32[$37>>2]|0;
    $39 = ($36|0)==($38|0);
    if ($39) {
     $40 = HEAP32[$$pre$i$i$i>>2]|0;
     $41 = ((($40)) + 36|0);
     $42 = HEAP32[$41>>2]|0;
     __THREW__ = 0;
     $43 = (invoke_ii($42|0,($$pre$i$i$i|0))|0);
     $44 = __THREW__; __THREW__ = 0;
     $45 = $44&1;
     if ($45) {
      break;
     } else {
      $$0$i$i$i$i = $43;
     }
    } else {
     $46 = HEAP8[$36>>0]|0;
     $47 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($46)|0);
     $$0$i$i$i$i = $47;
    }
    $48 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
    $49 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i$i$i,$48)|0);
    if ($49) {
     HEAP32[$1>>2] = 0;
     $$pre$i$i$i40 = 0;$153 = 0;$184 = 1;
    } else {
     $$pre$i$i$i40 = $$pre$i$i$i;$153 = $183;$184 = 0;
    }
   }
   $50 = HEAP32[$2>>2]|0;
   $51 = ($50|0)==(0|0);
   do {
    if ($51) {
     label = 20;
    } else {
     $52 = ((($50)) + 12|0);
     $53 = HEAP32[$52>>2]|0;
     $54 = ((($50)) + 16|0);
     $55 = HEAP32[$54>>2]|0;
     $56 = ($53|0)==($55|0);
     if ($56) {
      $57 = HEAP32[$50>>2]|0;
      $58 = ((($57)) + 36|0);
      $59 = HEAP32[$58>>2]|0;
      __THREW__ = 0;
      $60 = (invoke_ii($59|0,($50|0))|0);
      $61 = __THREW__; __THREW__ = 0;
      $62 = $61&1;
      if ($62) {
       break L11;
      } else {
       $$0$i$i2$i$i = $60;
      }
     } else {
      $63 = HEAP8[$53>>0]|0;
      $64 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($63)|0);
      $$0$i$i2$i$i = $64;
     }
     $65 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
     $66 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i2$i$i,$65)|0);
     if ($66) {
      HEAP32[$2>>2] = 0;
      label = 20;
      break;
     } else {
      if ($184) {
       $185 = $50;
       break;
      } else {
       $$2 = $$018;$$pre$i4$i$i46 = $50;
       label = 37;
       break L11;
      }
     }
    }
   } while(0);
   if ((label|0) == 20) {
    label = 0;
    if ($184) {
     $$2 = $$018;$$pre$i4$i$i46 = 0;
     label = 37;
     break;
    } else {
     $185 = 0;
    }
   }
   $67 = HEAP32[$11>>2]|0;
   $68 = HEAP8[$19>>0]|0;
   $69 = ($68<<24>>24)<(0);
   $70 = HEAP32[$32>>2]|0;
   $71 = $68&255;
   $72 = $69 ? $70 : $71;
   $73 = (($$018) + ($72)|0);
   $74 = ($67|0)==($73|0);
   if ($74) {
    $75 = $72 << 1;
    __THREW__ = 0;
    invoke_viii(3434,($10|0),($75|0),0);
    $76 = __THREW__; __THREW__ = 0;
    $77 = $76&1;
    if ($77) {
     break;
    }
    $78 = HEAP8[$19>>0]|0;
    $79 = ($78<<24>>24)<(0);
    if ($79) {
     $80 = HEAP32[$33>>2]|0;
     $81 = $80 & 2147483647;
     $phitmp$i29 = (($81) + -1)|0;
     $82 = $phitmp$i29;
    } else {
     $82 = 10;
    }
    __THREW__ = 0;
    invoke_viii(3434,($10|0),($82|0),0);
    $83 = __THREW__; __THREW__ = 0;
    $84 = $83&1;
    if ($84) {
     break;
    }
    $85 = HEAP8[$19>>0]|0;
    $86 = ($85<<24>>24)<(0);
    $87 = HEAP32[$10>>2]|0;
    $88 = $86 ? $87 : $10;
    $89 = (($88) + ($72)|0);
    HEAP32[$11>>2] = $89;
    $$119 = $88;
   } else {
    $$119 = $$018;
   }
   $92 = ((($$pre$i$i$i40)) + 12|0);
   $93 = HEAP32[$92>>2]|0;
   $94 = ((($$pre$i$i$i40)) + 16|0);
   $95 = HEAP32[$94>>2]|0;
   $96 = ($93|0)==($95|0);
   if ($96) {
    $97 = HEAP32[$$pre$i$i$i40>>2]|0;
    $98 = ((($97)) + 36|0);
    $99 = HEAP32[$98>>2]|0;
    __THREW__ = 0;
    $100 = (invoke_ii($99|0,($$pre$i$i$i40|0))|0);
    $101 = __THREW__; __THREW__ = 0;
    $102 = $101&1;
    if ($102) {
     break;
    } else {
     $$0$i$i34 = $100;
    }
   } else {
    $103 = HEAP8[$93>>0]|0;
    $104 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($103)|0);
    $$0$i$i34 = $104;
   }
   $105 = $$0$i$i34&255;
   $106 = HEAP8[$7>>0]|0;
   $107 = HEAP8[$8>>0]|0;
   __THREW__ = 0;
   $108 = (invoke_iiiiiiiiiiiii(4674,($105|0),($15|0),($16|0),($$119|0),($11|0),($106|0),($107|0),($9|0),($12|0),($13|0),($14|0),($6|0))|0);
   $109 = __THREW__; __THREW__ = 0;
   $110 = $109&1;
   if ($110) {
    break;
   }
   $111 = ($108|0)==(0);
   if (!($111)) {
    $$2 = $$119;$$pre$i4$i$i46 = $185;
    label = 37;
    break;
   }
   $112 = HEAP32[$92>>2]|0;
   $113 = HEAP32[$94>>2]|0;
   $114 = ($112|0)==($113|0);
   if ($114) {
    $115 = HEAP32[$$pre$i$i$i40>>2]|0;
    $116 = ((($115)) + 40|0);
    $117 = HEAP32[$116>>2]|0;
    __THREW__ = 0;
    (invoke_ii($117|0,($$pre$i$i$i40|0))|0);
    $118 = __THREW__; __THREW__ = 0;
    $119 = $118&1;
    if ($119) {
     break;
    } else {
     $$018 = $$119;$$pre$i$i$i = $$pre$i$i$i40;$183 = $153;
     continue;
    }
   } else {
    $120 = ((($112)) + 1|0);
    HEAP32[$92>>2] = $120;
    $121 = HEAP8[$112>>0]|0;
    (__ZNSt3__211char_traitsIcE11to_int_typeEc($121)|0);
    $$018 = $$119;$$pre$i$i$i = $$pre$i$i$i40;$183 = $153;
    continue;
   }
  }
  L50: do {
   if ((label|0) == 37) {
    $122 = ((($9)) + 11|0);
    $123 = HEAP8[$122>>0]|0;
    $124 = ($123<<24>>24)<(0);
    $125 = ((($9)) + 4|0);
    $126 = HEAP32[$125>>2]|0;
    $127 = $123&255;
    $128 = $124 ? $126 : $127;
    $129 = ($128|0)==(0);
    $130 = HEAP8[$15>>0]|0;
    $131 = ($130<<24>>24)==(0);
    $or$cond = $129 | $131;
    if (!($or$cond)) {
     $132 = HEAP32[$13>>2]|0;
     $133 = $132;
     $134 = $12;
     $135 = (($133) - ($134))|0;
     $136 = ($135|0)<(160);
     if ($136) {
      $137 = HEAP32[$14>>2]|0;
      $138 = ((($132)) + 4|0);
      HEAP32[$13>>2] = $138;
      HEAP32[$132>>2] = $137;
     }
    }
    $139 = HEAP32[$11>>2]|0;
    __THREW__ = 0;
    $140 = (+invoke_diii(4677,($$2|0),($139|0),($4|0)));
    $141 = __THREW__; __THREW__ = 0;
    $142 = $141&1;
    if (!($142)) {
     HEAPF64[$5>>3] = $140;
     $143 = HEAP32[$13>>2]|0;
     __THREW__ = 0;
     invoke_viiii(4676,($9|0),($12|0),($143|0),($4|0));
     $144 = __THREW__; __THREW__ = 0;
     $145 = $144&1;
     if (!($145)) {
      $146 = ($$pre$i$i$i40|0)==(0|0);
      if ($146) {
       $186 = 1;
      } else {
       $147 = ((($$pre$i$i$i40)) + 12|0);
       $148 = HEAP32[$147>>2]|0;
       $149 = ((($$pre$i$i$i40)) + 16|0);
       $150 = HEAP32[$149>>2]|0;
       $151 = ($148|0)==($150|0);
       if ($151) {
        $152 = HEAP32[$153>>2]|0;
        $154 = ((($152)) + 36|0);
        $155 = HEAP32[$154>>2]|0;
        __THREW__ = 0;
        $156 = (invoke_ii($155|0,($$pre$i$i$i40|0))|0);
        $157 = __THREW__; __THREW__ = 0;
        $158 = $157&1;
        if ($158) {
         break;
        } else {
         $$0$i$i$i$i38 = $156;
        }
       } else {
        $159 = HEAP8[$148>>0]|0;
        $160 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($159)|0);
        $$0$i$i$i$i38 = $160;
       }
       $161 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
       $162 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i$i$i38,$161)|0);
       if ($162) {
        HEAP32[$1>>2] = 0;
        $186 = 1;
       } else {
        $186 = 0;
       }
      }
      $163 = ($$pre$i4$i$i46|0)==(0|0);
      do {
       if ($163) {
        label = 54;
       } else {
        $164 = ((($$pre$i4$i$i46)) + 12|0);
        $165 = HEAP32[$164>>2]|0;
        $166 = ((($$pre$i4$i$i46)) + 16|0);
        $167 = HEAP32[$166>>2]|0;
        $168 = ($165|0)==($167|0);
        if ($168) {
         $169 = HEAP32[$$pre$i4$i$i46>>2]|0;
         $170 = ((($169)) + 36|0);
         $171 = HEAP32[$170>>2]|0;
         __THREW__ = 0;
         $172 = (invoke_ii($171|0,($$pre$i4$i$i46|0))|0);
         $173 = __THREW__; __THREW__ = 0;
         $174 = $173&1;
         if ($174) {
          break L50;
         } else {
          $$0$i$i2$i$i44 = $172;
         }
        } else {
         $175 = HEAP8[$165>>0]|0;
         $176 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($175)|0);
         $$0$i$i2$i$i44 = $176;
        }
        $177 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
        $178 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i2$i$i44,$177)|0);
        if ($178) {
         HEAP32[$2>>2] = 0;
         label = 54;
         break;
        } else {
         if ($186) {
          break;
         } else {
          label = 56;
          break;
         }
        }
       }
      } while(0);
      if ((label|0) == 54) {
       if ($186) {
        label = 56;
       }
      }
      if ((label|0) == 56) {
       $179 = HEAP32[$4>>2]|0;
       $180 = $179 | 2;
       HEAP32[$4>>2] = $180;
      }
      $$sroa$0$0$copyload = HEAP32[$1>>2]|0;
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($10);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($9);
      STACKTOP = sp;return ($$sroa$0$0$copyload|0);
     }
    }
   }
  } while(0);
  $181 = ___cxa_find_matching_catch_2()|0;
  $182 = tempRet0;
  $$1 = $181;$$121 = $182;
 }
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($10);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($9);
 ___resumeException($$1|0);
 // unreachable;
 return (0)|0;
}
function __ZNSt3__215__num_get_floatIdEET_PKcS3_Rj($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0.0, $$0$ph = 0.0, $$1 = 0.0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = ($0|0)==($1|0);
 if ($4) {
  HEAP32[$2>>2] = 4;
  $$1 = 0.0;
 } else {
  $5 = (___errno_location()|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (___errno_location()|0);
  HEAP32[$7>>2] = 0;
  $8 = (__ZNSt3__26__clocEv()|0);
  $9 = (+_strtod_l($0,$3,$8));
  $10 = (___errno_location()|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($11|0)==(0);
  if ($12) {
   $13 = (___errno_location()|0);
   HEAP32[$13>>2] = $6;
  }
  $14 = HEAP32[$3>>2]|0;
  $15 = ($14|0)==($1|0);
  if ($15) {
   $16 = ($11|0)==(34);
   if ($16) {
    $$0$ph = $9;
    label = 6;
   } else {
    $$0 = $9;
   }
  } else {
   $$0$ph = 0.0;
   label = 6;
  }
  if ((label|0) == 6) {
   HEAP32[$2>>2] = 4;
   $$0 = $$0$ph;
  }
  $$1 = $$0;
 }
 STACKTOP = sp;return (+$$1);
}
function __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE23__do_get_floating_pointIfEES4_S4_S4_RNS_8ios_baseERjRT_($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$0$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i38 = 0, $$0$i$i2$i$i = 0, $$0$i$i2$i$i44 = 0, $$0$i$i34 = 0, $$018 = 0, $$1 = 0, $$119 = 0, $$121 = 0, $$2 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i40 = 0, $$pre$i4$i$i46 = 0, $$sroa$0$0$copyload = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0;
 var $14 = 0, $140 = 0.0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0;
 var $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0;
 var $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i$i = 0, $or$cond = 0, $phitmp$i = 0;
 var $phitmp$i29 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 240|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(240|0);
 $6 = sp + 200|0;
 $7 = sp + 199|0;
 $8 = sp + 198|0;
 $9 = sp + 184|0;
 $10 = sp + 172|0;
 $11 = sp + 168|0;
 $12 = sp + 8|0;
 $13 = sp + 4|0;
 $14 = sp;
 $15 = sp + 197|0;
 $16 = sp + 196|0;
 __ZNSt3__29__num_getIcE19__stage2_float_prepERNS_8ios_baseEPcRcS5_($9,$3,$6,$7,$8);
 ;HEAP32[$10>>2]=0|0;HEAP32[$10+4>>2]=0|0;HEAP32[$10+8>>2]=0|0;
 $$0$i$i = 0;
 while(1) {
  $exitcond$i$i = ($$0$i$i|0)==(3);
  if ($exitcond$i$i) {
   break;
  }
  $17 = (($10) + ($$0$i$i<<2)|0);
  HEAP32[$17>>2] = 0;
  $18 = (($$0$i$i) + 1)|0;
  $$0$i$i = $18;
 }
 $19 = ((($10)) + 11|0);
 $20 = HEAP8[$19>>0]|0;
 $21 = ($20<<24>>24)<(0);
 if ($21) {
  $22 = ((($10)) + 8|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = $23 & 2147483647;
  $phitmp$i = (($24) + -1)|0;
  $25 = $phitmp$i;
 } else {
  $25 = 10;
 }
 __THREW__ = 0;
 invoke_viii(3434,($10|0),($25|0),0);
 $26 = __THREW__; __THREW__ = 0;
 $27 = $26&1;
 if ($27) {
  $90 = ___cxa_find_matching_catch_2()|0;
  $91 = tempRet0;
  $$1 = $90;$$121 = $91;
 } else {
  $28 = HEAP8[$19>>0]|0;
  $29 = ($28<<24>>24)<(0);
  $30 = HEAP32[$10>>2]|0;
  $31 = $29 ? $30 : $10;
  HEAP32[$11>>2] = $31;
  HEAP32[$13>>2] = $12;
  HEAP32[$14>>2] = 0;
  HEAP8[$15>>0] = 1;
  HEAP8[$16>>0] = 69;
  $32 = ((($10)) + 4|0);
  $33 = ((($10)) + 8|0);
  $$pre = HEAP32[$1>>2]|0;
  $$018 = $31;$$pre$i$i$i = $$pre;$183 = $$pre;
  L11: while(1) {
   $34 = ($$pre$i$i$i|0)==(0|0);
   if ($34) {
    $$pre$i$i$i40 = 0;$153 = 0;$184 = 1;
   } else {
    $35 = ((($$pre$i$i$i)) + 12|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = ((($$pre$i$i$i)) + 16|0);
    $38 = HEAP32[$37>>2]|0;
    $39 = ($36|0)==($38|0);
    if ($39) {
     $40 = HEAP32[$$pre$i$i$i>>2]|0;
     $41 = ((($40)) + 36|0);
     $42 = HEAP32[$41>>2]|0;
     __THREW__ = 0;
     $43 = (invoke_ii($42|0,($$pre$i$i$i|0))|0);
     $44 = __THREW__; __THREW__ = 0;
     $45 = $44&1;
     if ($45) {
      break;
     } else {
      $$0$i$i$i$i = $43;
     }
    } else {
     $46 = HEAP8[$36>>0]|0;
     $47 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($46)|0);
     $$0$i$i$i$i = $47;
    }
    $48 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
    $49 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i$i$i,$48)|0);
    if ($49) {
     HEAP32[$1>>2] = 0;
     $$pre$i$i$i40 = 0;$153 = 0;$184 = 1;
    } else {
     $$pre$i$i$i40 = $$pre$i$i$i;$153 = $183;$184 = 0;
    }
   }
   $50 = HEAP32[$2>>2]|0;
   $51 = ($50|0)==(0|0);
   do {
    if ($51) {
     label = 20;
    } else {
     $52 = ((($50)) + 12|0);
     $53 = HEAP32[$52>>2]|0;
     $54 = ((($50)) + 16|0);
     $55 = HEAP32[$54>>2]|0;
     $56 = ($53|0)==($55|0);
     if ($56) {
      $57 = HEAP32[$50>>2]|0;
      $58 = ((($57)) + 36|0);
      $59 = HEAP32[$58>>2]|0;
      __THREW__ = 0;
      $60 = (invoke_ii($59|0,($50|0))|0);
      $61 = __THREW__; __THREW__ = 0;
      $62 = $61&1;
      if ($62) {
       break L11;
      } else {
       $$0$i$i2$i$i = $60;
      }
     } else {
      $63 = HEAP8[$53>>0]|0;
      $64 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($63)|0);
      $$0$i$i2$i$i = $64;
     }
     $65 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
     $66 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i2$i$i,$65)|0);
     if ($66) {
      HEAP32[$2>>2] = 0;
      label = 20;
      break;
     } else {
      if ($184) {
       $185 = $50;
       break;
      } else {
       $$2 = $$018;$$pre$i4$i$i46 = $50;
       label = 37;
       break L11;
      }
     }
    }
   } while(0);
   if ((label|0) == 20) {
    label = 0;
    if ($184) {
     $$2 = $$018;$$pre$i4$i$i46 = 0;
     label = 37;
     break;
    } else {
     $185 = 0;
    }
   }
   $67 = HEAP32[$11>>2]|0;
   $68 = HEAP8[$19>>0]|0;
   $69 = ($68<<24>>24)<(0);
   $70 = HEAP32[$32>>2]|0;
   $71 = $68&255;
   $72 = $69 ? $70 : $71;
   $73 = (($$018) + ($72)|0);
   $74 = ($67|0)==($73|0);
   if ($74) {
    $75 = $72 << 1;
    __THREW__ = 0;
    invoke_viii(3434,($10|0),($75|0),0);
    $76 = __THREW__; __THREW__ = 0;
    $77 = $76&1;
    if ($77) {
     break;
    }
    $78 = HEAP8[$19>>0]|0;
    $79 = ($78<<24>>24)<(0);
    if ($79) {
     $80 = HEAP32[$33>>2]|0;
     $81 = $80 & 2147483647;
     $phitmp$i29 = (($81) + -1)|0;
     $82 = $phitmp$i29;
    } else {
     $82 = 10;
    }
    __THREW__ = 0;
    invoke_viii(3434,($10|0),($82|0),0);
    $83 = __THREW__; __THREW__ = 0;
    $84 = $83&1;
    if ($84) {
     break;
    }
    $85 = HEAP8[$19>>0]|0;
    $86 = ($85<<24>>24)<(0);
    $87 = HEAP32[$10>>2]|0;
    $88 = $86 ? $87 : $10;
    $89 = (($88) + ($72)|0);
    HEAP32[$11>>2] = $89;
    $$119 = $88;
   } else {
    $$119 = $$018;
   }
   $92 = ((($$pre$i$i$i40)) + 12|0);
   $93 = HEAP32[$92>>2]|0;
   $94 = ((($$pre$i$i$i40)) + 16|0);
   $95 = HEAP32[$94>>2]|0;
   $96 = ($93|0)==($95|0);
   if ($96) {
    $97 = HEAP32[$$pre$i$i$i40>>2]|0;
    $98 = ((($97)) + 36|0);
    $99 = HEAP32[$98>>2]|0;
    __THREW__ = 0;
    $100 = (invoke_ii($99|0,($$pre$i$i$i40|0))|0);
    $101 = __THREW__; __THREW__ = 0;
    $102 = $101&1;
    if ($102) {
     break;
    } else {
     $$0$i$i34 = $100;
    }
   } else {
    $103 = HEAP8[$93>>0]|0;
    $104 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($103)|0);
    $$0$i$i34 = $104;
   }
   $105 = $$0$i$i34&255;
   $106 = HEAP8[$7>>0]|0;
   $107 = HEAP8[$8>>0]|0;
   __THREW__ = 0;
   $108 = (invoke_iiiiiiiiiiiii(4674,($105|0),($15|0),($16|0),($$119|0),($11|0),($106|0),($107|0),($9|0),($12|0),($13|0),($14|0),($6|0))|0);
   $109 = __THREW__; __THREW__ = 0;
   $110 = $109&1;
   if ($110) {
    break;
   }
   $111 = ($108|0)==(0);
   if (!($111)) {
    $$2 = $$119;$$pre$i4$i$i46 = $185;
    label = 37;
    break;
   }
   $112 = HEAP32[$92>>2]|0;
   $113 = HEAP32[$94>>2]|0;
   $114 = ($112|0)==($113|0);
   if ($114) {
    $115 = HEAP32[$$pre$i$i$i40>>2]|0;
    $116 = ((($115)) + 40|0);
    $117 = HEAP32[$116>>2]|0;
    __THREW__ = 0;
    (invoke_ii($117|0,($$pre$i$i$i40|0))|0);
    $118 = __THREW__; __THREW__ = 0;
    $119 = $118&1;
    if ($119) {
     break;
    } else {
     $$018 = $$119;$$pre$i$i$i = $$pre$i$i$i40;$183 = $153;
     continue;
    }
   } else {
    $120 = ((($112)) + 1|0);
    HEAP32[$92>>2] = $120;
    $121 = HEAP8[$112>>0]|0;
    (__ZNSt3__211char_traitsIcE11to_int_typeEc($121)|0);
    $$018 = $$119;$$pre$i$i$i = $$pre$i$i$i40;$183 = $153;
    continue;
   }
  }
  L50: do {
   if ((label|0) == 37) {
    $122 = ((($9)) + 11|0);
    $123 = HEAP8[$122>>0]|0;
    $124 = ($123<<24>>24)<(0);
    $125 = ((($9)) + 4|0);
    $126 = HEAP32[$125>>2]|0;
    $127 = $123&255;
    $128 = $124 ? $126 : $127;
    $129 = ($128|0)==(0);
    $130 = HEAP8[$15>>0]|0;
    $131 = ($130<<24>>24)==(0);
    $or$cond = $129 | $131;
    if (!($or$cond)) {
     $132 = HEAP32[$13>>2]|0;
     $133 = $132;
     $134 = $12;
     $135 = (($133) - ($134))|0;
     $136 = ($135|0)<(160);
     if ($136) {
      $137 = HEAP32[$14>>2]|0;
      $138 = ((($132)) + 4|0);
      HEAP32[$13>>2] = $138;
      HEAP32[$132>>2] = $137;
     }
    }
    $139 = HEAP32[$11>>2]|0;
    __THREW__ = 0;
    $140 = (+invoke_diii(4678,($$2|0),($139|0),($4|0)));
    $141 = __THREW__; __THREW__ = 0;
    $142 = $141&1;
    if (!($142)) {
     HEAPF32[$5>>2] = $140;
     $143 = HEAP32[$13>>2]|0;
     __THREW__ = 0;
     invoke_viiii(4676,($9|0),($12|0),($143|0),($4|0));
     $144 = __THREW__; __THREW__ = 0;
     $145 = $144&1;
     if (!($145)) {
      $146 = ($$pre$i$i$i40|0)==(0|0);
      if ($146) {
       $186 = 1;
      } else {
       $147 = ((($$pre$i$i$i40)) + 12|0);
       $148 = HEAP32[$147>>2]|0;
       $149 = ((($$pre$i$i$i40)) + 16|0);
       $150 = HEAP32[$149>>2]|0;
       $151 = ($148|0)==($150|0);
       if ($151) {
        $152 = HEAP32[$153>>2]|0;
        $154 = ((($152)) + 36|0);
        $155 = HEAP32[$154>>2]|0;
        __THREW__ = 0;
        $156 = (invoke_ii($155|0,($$pre$i$i$i40|0))|0);
        $157 = __THREW__; __THREW__ = 0;
        $158 = $157&1;
        if ($158) {
         break;
        } else {
         $$0$i$i$i$i38 = $156;
        }
       } else {
        $159 = HEAP8[$148>>0]|0;
        $160 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($159)|0);
        $$0$i$i$i$i38 = $160;
       }
       $161 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
       $162 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i$i$i38,$161)|0);
       if ($162) {
        HEAP32[$1>>2] = 0;
        $186 = 1;
       } else {
        $186 = 0;
       }
      }
      $163 = ($$pre$i4$i$i46|0)==(0|0);
      do {
       if ($163) {
        label = 54;
       } else {
        $164 = ((($$pre$i4$i$i46)) + 12|0);
        $165 = HEAP32[$164>>2]|0;
        $166 = ((($$pre$i4$i$i46)) + 16|0);
        $167 = HEAP32[$166>>2]|0;
        $168 = ($165|0)==($167|0);
        if ($168) {
         $169 = HEAP32[$$pre$i4$i$i46>>2]|0;
         $170 = ((($169)) + 36|0);
         $171 = HEAP32[$170>>2]|0;
         __THREW__ = 0;
         $172 = (invoke_ii($171|0,($$pre$i4$i$i46|0))|0);
         $173 = __THREW__; __THREW__ = 0;
         $174 = $173&1;
         if ($174) {
          break L50;
         } else {
          $$0$i$i2$i$i44 = $172;
         }
        } else {
         $175 = HEAP8[$165>>0]|0;
         $176 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($175)|0);
         $$0$i$i2$i$i44 = $176;
        }
        $177 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
        $178 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i2$i$i44,$177)|0);
        if ($178) {
         HEAP32[$2>>2] = 0;
         label = 54;
         break;
        } else {
         if ($186) {
          break;
         } else {
          label = 56;
          break;
         }
        }
       }
      } while(0);
      if ((label|0) == 54) {
       if ($186) {
        label = 56;
       }
      }
      if ((label|0) == 56) {
       $179 = HEAP32[$4>>2]|0;
       $180 = $179 | 2;
       HEAP32[$4>>2] = $180;
      }
      $$sroa$0$0$copyload = HEAP32[$1>>2]|0;
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($10);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($9);
      STACKTOP = sp;return ($$sroa$0$0$copyload|0);
     }
    }
   }
  } while(0);
  $181 = ___cxa_find_matching_catch_2()|0;
  $182 = tempRet0;
  $$1 = $181;$$121 = $182;
 }
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($10);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($9);
 ___resumeException($$1|0);
 // unreachable;
 return (0)|0;
}
function __ZNSt3__215__num_get_floatIfEET_PKcS3_Rj($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0.0, $$0$ph = 0.0, $$1 = 0.0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = ($0|0)==($1|0);
 if ($4) {
  HEAP32[$2>>2] = 4;
  $$1 = 0.0;
 } else {
  $5 = (___errno_location()|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (___errno_location()|0);
  HEAP32[$7>>2] = 0;
  $8 = (__ZNSt3__26__clocEv()|0);
  $9 = (+_strtof_l($0,$3,$8));
  $10 = (___errno_location()|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($11|0)==(0);
  if ($12) {
   $13 = (___errno_location()|0);
   HEAP32[$13>>2] = $6;
  }
  $14 = HEAP32[$3>>2]|0;
  $15 = ($14|0)==($1|0);
  if ($15) {
   $16 = ($11|0)==(34);
   if ($16) {
    $$0$ph = $9;
    label = 6;
   } else {
    $$0 = $9;
   }
  } else {
   $$0$ph = 0.0;
   label = 6;
  }
  if ((label|0) == 6) {
   HEAP32[$2>>2] = 4;
   $$0 = $$0$ph;
  }
  $$1 = $$0;
 }
 STACKTOP = sp;return (+$$1);
}
function __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE17__do_get_unsignedIyEES4_S4_S4_RNS_8ios_baseERjRT_($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$0$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i43 = 0, $$0$i$i2$i$i = 0, $$0$i$i2$i$i49 = 0, $$0$i$i39 = 0, $$024 = 0, $$1 = 0, $$125 = 0, $$127 = 0, $$2 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i45 = 0, $$pre$i4$i$i51 = 0, $$sroa$0$0$copyload = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0;
 var $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0;
 var $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0;
 var $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i$i = 0, $phitmp$i = 0, $phitmp$i34 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(224|0);
 $6 = sp + 198|0;
 $7 = sp + 196|0;
 $8 = sp + 184|0;
 $9 = sp + 172|0;
 $10 = sp + 168|0;
 $11 = sp + 8|0;
 $12 = sp + 4|0;
 $13 = sp;
 $14 = (__ZNSt3__214__num_get_base10__get_baseERNS_8ios_baseE($3)|0);
 __ZNSt3__29__num_getIcE17__stage2_int_prepERNS_8ios_baseEPcRc($8,$3,$6,$7);
 ;HEAP32[$9>>2]=0|0;HEAP32[$9+4>>2]=0|0;HEAP32[$9+8>>2]=0|0;
 $$0$i$i = 0;
 while(1) {
  $exitcond$i$i = ($$0$i$i|0)==(3);
  if ($exitcond$i$i) {
   break;
  }
  $15 = (($9) + ($$0$i$i<<2)|0);
  HEAP32[$15>>2] = 0;
  $16 = (($$0$i$i) + 1)|0;
  $$0$i$i = $16;
 }
 $17 = ((($9)) + 11|0);
 $18 = HEAP8[$17>>0]|0;
 $19 = ($18<<24>>24)<(0);
 if ($19) {
  $20 = ((($9)) + 8|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = $21 & 2147483647;
  $phitmp$i = (($22) + -1)|0;
  $23 = $phitmp$i;
 } else {
  $23 = 10;
 }
 __THREW__ = 0;
 invoke_viii(3434,($9|0),($23|0),0);
 $24 = __THREW__; __THREW__ = 0;
 $25 = $24&1;
 if ($25) {
  $88 = ___cxa_find_matching_catch_2()|0;
  $89 = tempRet0;
  $$1 = $88;$$127 = $89;
 } else {
  $26 = HEAP8[$17>>0]|0;
  $27 = ($26<<24>>24)<(0);
  $28 = HEAP32[$9>>2]|0;
  $29 = $27 ? $28 : $9;
  HEAP32[$10>>2] = $29;
  HEAP32[$12>>2] = $11;
  HEAP32[$13>>2] = 0;
  $30 = ((($9)) + 4|0);
  $31 = ((($9)) + 8|0);
  $$pre = HEAP32[$1>>2]|0;
  $$024 = $29;$$pre$i$i$i = $$pre;$183 = $$pre;
  L11: while(1) {
   $32 = ($$pre$i$i$i|0)==(0|0);
   if ($32) {
    $$pre$i$i$i45 = 0;$153 = 0;$184 = 1;
   } else {
    $33 = ((($$pre$i$i$i)) + 12|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = ((($$pre$i$i$i)) + 16|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = ($34|0)==($36|0);
    if ($37) {
     $38 = HEAP32[$$pre$i$i$i>>2]|0;
     $39 = ((($38)) + 36|0);
     $40 = HEAP32[$39>>2]|0;
     __THREW__ = 0;
     $41 = (invoke_ii($40|0,($$pre$i$i$i|0))|0);
     $42 = __THREW__; __THREW__ = 0;
     $43 = $42&1;
     if ($43) {
      break;
     } else {
      $$0$i$i$i$i = $41;
     }
    } else {
     $44 = HEAP8[$34>>0]|0;
     $45 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($44)|0);
     $$0$i$i$i$i = $45;
    }
    $46 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
    $47 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i$i$i,$46)|0);
    if ($47) {
     HEAP32[$1>>2] = 0;
     $$pre$i$i$i45 = 0;$153 = 0;$184 = 1;
    } else {
     $$pre$i$i$i45 = $$pre$i$i$i;$153 = $183;$184 = 0;
    }
   }
   $48 = HEAP32[$2>>2]|0;
   $49 = ($48|0)==(0|0);
   do {
    if ($49) {
     label = 20;
    } else {
     $50 = ((($48)) + 12|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = ((($48)) + 16|0);
     $53 = HEAP32[$52>>2]|0;
     $54 = ($51|0)==($53|0);
     if ($54) {
      $55 = HEAP32[$48>>2]|0;
      $56 = ((($55)) + 36|0);
      $57 = HEAP32[$56>>2]|0;
      __THREW__ = 0;
      $58 = (invoke_ii($57|0,($48|0))|0);
      $59 = __THREW__; __THREW__ = 0;
      $60 = $59&1;
      if ($60) {
       break L11;
      } else {
       $$0$i$i2$i$i = $58;
      }
     } else {
      $61 = HEAP8[$51>>0]|0;
      $62 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($61)|0);
      $$0$i$i2$i$i = $62;
     }
     $63 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
     $64 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i2$i$i,$63)|0);
     if ($64) {
      HEAP32[$2>>2] = 0;
      label = 20;
      break;
     } else {
      if ($184) {
       $185 = $48;
       break;
      } else {
       $$2 = $$024;$$pre$i4$i$i51 = $48;
       label = 37;
       break L11;
      }
     }
    }
   } while(0);
   if ((label|0) == 20) {
    label = 0;
    if ($184) {
     $$2 = $$024;$$pre$i4$i$i51 = 0;
     label = 37;
     break;
    } else {
     $185 = 0;
    }
   }
   $65 = HEAP32[$10>>2]|0;
   $66 = HEAP8[$17>>0]|0;
   $67 = ($66<<24>>24)<(0);
   $68 = HEAP32[$30>>2]|0;
   $69 = $66&255;
   $70 = $67 ? $68 : $69;
   $71 = (($$024) + ($70)|0);
   $72 = ($65|0)==($71|0);
   if ($72) {
    $73 = $70 << 1;
    __THREW__ = 0;
    invoke_viii(3434,($9|0),($73|0),0);
    $74 = __THREW__; __THREW__ = 0;
    $75 = $74&1;
    if ($75) {
     break;
    }
    $76 = HEAP8[$17>>0]|0;
    $77 = ($76<<24>>24)<(0);
    if ($77) {
     $78 = HEAP32[$31>>2]|0;
     $79 = $78 & 2147483647;
     $phitmp$i34 = (($79) + -1)|0;
     $80 = $phitmp$i34;
    } else {
     $80 = 10;
    }
    __THREW__ = 0;
    invoke_viii(3434,($9|0),($80|0),0);
    $81 = __THREW__; __THREW__ = 0;
    $82 = $81&1;
    if ($82) {
     break;
    }
    $83 = HEAP8[$17>>0]|0;
    $84 = ($83<<24>>24)<(0);
    $85 = HEAP32[$9>>2]|0;
    $86 = $84 ? $85 : $9;
    $87 = (($86) + ($70)|0);
    HEAP32[$10>>2] = $87;
    $$125 = $86;
   } else {
    $$125 = $$024;
   }
   $90 = ((($$pre$i$i$i45)) + 12|0);
   $91 = HEAP32[$90>>2]|0;
   $92 = ((($$pre$i$i$i45)) + 16|0);
   $93 = HEAP32[$92>>2]|0;
   $94 = ($91|0)==($93|0);
   if ($94) {
    $95 = HEAP32[$$pre$i$i$i45>>2]|0;
    $96 = ((($95)) + 36|0);
    $97 = HEAP32[$96>>2]|0;
    __THREW__ = 0;
    $98 = (invoke_ii($97|0,($$pre$i$i$i45|0))|0);
    $99 = __THREW__; __THREW__ = 0;
    $100 = $99&1;
    if ($100) {
     break;
    } else {
     $$0$i$i39 = $98;
    }
   } else {
    $101 = HEAP8[$91>>0]|0;
    $102 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($101)|0);
    $$0$i$i39 = $102;
   }
   $103 = $$0$i$i39&255;
   $104 = HEAP8[$7>>0]|0;
   __THREW__ = 0;
   $105 = (invoke_iiiiiiiiiii(4667,($103|0),($14|0),($$125|0),($10|0),($13|0),($104|0),($8|0),($11|0),($12|0),($6|0))|0);
   $106 = __THREW__; __THREW__ = 0;
   $107 = $106&1;
   if ($107) {
    break;
   }
   $108 = ($105|0)==(0);
   if (!($108)) {
    $$2 = $$125;$$pre$i4$i$i51 = $185;
    label = 37;
    break;
   }
   $109 = HEAP32[$90>>2]|0;
   $110 = HEAP32[$92>>2]|0;
   $111 = ($109|0)==($110|0);
   if ($111) {
    $112 = HEAP32[$$pre$i$i$i45>>2]|0;
    $113 = ((($112)) + 40|0);
    $114 = HEAP32[$113>>2]|0;
    __THREW__ = 0;
    (invoke_ii($114|0,($$pre$i$i$i45|0))|0);
    $115 = __THREW__; __THREW__ = 0;
    $116 = $115&1;
    if ($116) {
     break;
    } else {
     $$024 = $$125;$$pre$i$i$i = $$pre$i$i$i45;$183 = $153;
     continue;
    }
   } else {
    $117 = ((($109)) + 1|0);
    HEAP32[$90>>2] = $117;
    $118 = HEAP8[$109>>0]|0;
    (__ZNSt3__211char_traitsIcE11to_int_typeEc($118)|0);
    $$024 = $$125;$$pre$i$i$i = $$pre$i$i$i45;$183 = $153;
    continue;
   }
  }
  L50: do {
   if ((label|0) == 37) {
    $119 = ((($8)) + 11|0);
    $120 = HEAP8[$119>>0]|0;
    $121 = ($120<<24>>24)<(0);
    $122 = ((($8)) + 4|0);
    $123 = HEAP32[$122>>2]|0;
    $124 = $120&255;
    $125 = $121 ? $123 : $124;
    $126 = ($125|0)==(0);
    if (!($126)) {
     $127 = HEAP32[$12>>2]|0;
     $128 = $127;
     $129 = $11;
     $130 = (($128) - ($129))|0;
     $131 = ($130|0)<(160);
     if ($131) {
      $132 = HEAP32[$13>>2]|0;
      $133 = ((($127)) + 4|0);
      HEAP32[$12>>2] = $133;
      HEAP32[$127>>2] = $132;
     }
    }
    $134 = HEAP32[$10>>2]|0;
    __THREW__ = 0;
    $135 = (invoke_iiiii(4679,($$2|0),($134|0),($4|0),($14|0))|0);
    $136 = tempRet0;
    $137 = __THREW__; __THREW__ = 0;
    $138 = $137&1;
    if (!($138)) {
     $139 = $5;
     $140 = $139;
     HEAP32[$140>>2] = $135;
     $141 = (($139) + 4)|0;
     $142 = $141;
     HEAP32[$142>>2] = $136;
     $143 = HEAP32[$12>>2]|0;
     __THREW__ = 0;
     invoke_viiii(4676,($8|0),($11|0),($143|0),($4|0));
     $144 = __THREW__; __THREW__ = 0;
     $145 = $144&1;
     if (!($145)) {
      $146 = ($$pre$i$i$i45|0)==(0|0);
      if ($146) {
       $186 = 1;
      } else {
       $147 = ((($$pre$i$i$i45)) + 12|0);
       $148 = HEAP32[$147>>2]|0;
       $149 = ((($$pre$i$i$i45)) + 16|0);
       $150 = HEAP32[$149>>2]|0;
       $151 = ($148|0)==($150|0);
       if ($151) {
        $152 = HEAP32[$153>>2]|0;
        $154 = ((($152)) + 36|0);
        $155 = HEAP32[$154>>2]|0;
        __THREW__ = 0;
        $156 = (invoke_ii($155|0,($$pre$i$i$i45|0))|0);
        $157 = __THREW__; __THREW__ = 0;
        $158 = $157&1;
        if ($158) {
         break;
        } else {
         $$0$i$i$i$i43 = $156;
        }
       } else {
        $159 = HEAP8[$148>>0]|0;
        $160 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($159)|0);
        $$0$i$i$i$i43 = $160;
       }
       $161 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
       $162 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i$i$i43,$161)|0);
       if ($162) {
        HEAP32[$1>>2] = 0;
        $186 = 1;
       } else {
        $186 = 0;
       }
      }
      $163 = ($$pre$i4$i$i51|0)==(0|0);
      do {
       if ($163) {
        label = 54;
       } else {
        $164 = ((($$pre$i4$i$i51)) + 12|0);
        $165 = HEAP32[$164>>2]|0;
        $166 = ((($$pre$i4$i$i51)) + 16|0);
        $167 = HEAP32[$166>>2]|0;
        $168 = ($165|0)==($167|0);
        if ($168) {
         $169 = HEAP32[$$pre$i4$i$i51>>2]|0;
         $170 = ((($169)) + 36|0);
         $171 = HEAP32[$170>>2]|0;
         __THREW__ = 0;
         $172 = (invoke_ii($171|0,($$pre$i4$i$i51|0))|0);
         $173 = __THREW__; __THREW__ = 0;
         $174 = $173&1;
         if ($174) {
          break L50;
         } else {
          $$0$i$i2$i$i49 = $172;
         }
        } else {
         $175 = HEAP8[$165>>0]|0;
         $176 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($175)|0);
         $$0$i$i2$i$i49 = $176;
        }
        $177 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
        $178 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i2$i$i49,$177)|0);
        if ($178) {
         HEAP32[$2>>2] = 0;
         label = 54;
         break;
        } else {
         if ($186) {
          break;
         } else {
          label = 56;
          break;
         }
        }
       }
      } while(0);
      if ((label|0) == 54) {
       if ($186) {
        label = 56;
       }
      }
      if ((label|0) == 56) {
       $179 = HEAP32[$4>>2]|0;
       $180 = $179 | 2;
       HEAP32[$4>>2] = $180;
      }
      $$sroa$0$0$copyload = HEAP32[$1>>2]|0;
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($9);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($8);
      STACKTOP = sp;return ($$sroa$0$0$copyload|0);
     }
    }
   }
  } while(0);
  $181 = ___cxa_find_matching_catch_2()|0;
  $182 = tempRet0;
  $$1 = $181;$$127 = $182;
 }
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($9);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($8);
 ___resumeException($$1|0);
 // unreachable;
 return (0)|0;
}
function __ZNSt3__214__num_get_base10__get_baseERNS_8ios_baseE($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $2 = 0, $3 = 0, $trunc = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 & 74;
 $trunc = $3&255;
 $trunc$clear = $trunc & 127;
 switch ($trunc$clear<<24>>24) {
 case 64:  {
  $$0 = 8;
  break;
 }
 case 8:  {
  $$0 = 16;
  break;
 }
 case 0:  {
  $$0 = 0;
  break;
 }
 default: {
  $$0 = 10;
 }
 }
 return ($$0|0);
}
function __ZNSt3__29__num_getIcE17__stage2_int_prepERNS_8ios_baseEPcRc($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $4 = sp;
 __ZNKSt3__28ios_base6getlocEv($4,$1);
 __THREW__ = 0;
 $5 = (invoke_iii(3255,($4|0),(215188|0))|0);
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if (!($7)) {
  $8 = HEAP32[$5>>2]|0;
  $9 = ((($8)) + 32|0);
  $10 = HEAP32[$9>>2]|0;
  __THREW__ = 0;
  (invoke_iiiii($10|0,($5|0),(202614|0),((202640)|0),($2|0))|0);
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if (!($12)) {
   __THREW__ = 0;
   $13 = (invoke_iii(3255,($4|0),(215204|0))|0);
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if (!($15)) {
    $16 = HEAP32[$13>>2]|0;
    $17 = ((($16)) + 16|0);
    $18 = HEAP32[$17>>2]|0;
    __THREW__ = 0;
    $19 = (invoke_ii($18|0,($13|0))|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if (!($21)) {
     HEAP8[$3>>0] = $19;
     $22 = HEAP32[$13>>2]|0;
     $23 = ((($22)) + 20|0);
     $24 = HEAP32[$23>>2]|0;
     __THREW__ = 0;
     invoke_vii($24|0,($0|0),($13|0));
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if (!($26)) {
      __ZNSt3__26localeD2Ev($4);
      STACKTOP = sp;return;
     }
    }
   }
  }
 }
 $27 = ___cxa_find_matching_catch_2()|0;
 $28 = tempRet0;
 __ZNSt3__26localeD2Ev($4);
 ___resumeException($27|0);
 // unreachable;
}
function __ZNSt3__227__num_get_unsigned_integralIyEET_PKcS3_Rji($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $4 = sp;
 $5 = ($0|0)==($1|0);
 do {
  if ($5) {
   HEAP32[$2>>2] = 4;
   $21 = 0;$22 = 0;
  } else {
   $6 = HEAP8[$0>>0]|0;
   $7 = ($6<<24>>24)==(45);
   if ($7) {
    HEAP32[$2>>2] = 4;
    $21 = 0;$22 = 0;
    break;
   }
   $8 = (___errno_location()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (___errno_location()|0);
   HEAP32[$10>>2] = 0;
   $11 = (__ZNSt3__26__clocEv()|0);
   $12 = (_strtoull_l($0,$4,$3,$11)|0);
   $13 = tempRet0;
   $14 = (___errno_location()|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = ($15|0)==(0);
   if ($16) {
    $17 = (___errno_location()|0);
    HEAP32[$17>>2] = $9;
   }
   $18 = HEAP32[$4>>2]|0;
   $19 = ($18|0)==($1|0);
   if ($19) {
    $20 = ($15|0)==(34);
    if ($20) {
     $23 = -1;$24 = -1;
     label = 8;
    } else {
     $25 = $12;$26 = $13;
    }
   } else {
    $23 = 0;$24 = 0;
    label = 8;
   }
   if ((label|0) == 8) {
    HEAP32[$2>>2] = 4;
    $25 = $23;$26 = $24;
   }
   $21 = $26;$22 = $25;
  }
 } while(0);
 tempRet0 = ($21);
 STACKTOP = sp;return ($22|0);
}
function __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE17__do_get_unsignedImEES4_S4_S4_RNS_8ios_baseERjRT_($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$0$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i43 = 0, $$0$i$i2$i$i = 0, $$0$i$i2$i$i49 = 0, $$0$i$i39 = 0, $$024 = 0, $$1 = 0, $$125 = 0, $$127 = 0, $$2 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i45 = 0, $$pre$i4$i$i51 = 0, $$sroa$0$0$copyload = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0;
 var $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0;
 var $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0;
 var $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i$i = 0, $phitmp$i = 0, $phitmp$i34 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(224|0);
 $6 = sp + 198|0;
 $7 = sp + 196|0;
 $8 = sp + 184|0;
 $9 = sp + 172|0;
 $10 = sp + 168|0;
 $11 = sp + 8|0;
 $12 = sp + 4|0;
 $13 = sp;
 $14 = (__ZNSt3__214__num_get_base10__get_baseERNS_8ios_baseE($3)|0);
 __ZNSt3__29__num_getIcE17__stage2_int_prepERNS_8ios_baseEPcRc($8,$3,$6,$7);
 ;HEAP32[$9>>2]=0|0;HEAP32[$9+4>>2]=0|0;HEAP32[$9+8>>2]=0|0;
 $$0$i$i = 0;
 while(1) {
  $exitcond$i$i = ($$0$i$i|0)==(3);
  if ($exitcond$i$i) {
   break;
  }
  $15 = (($9) + ($$0$i$i<<2)|0);
  HEAP32[$15>>2] = 0;
  $16 = (($$0$i$i) + 1)|0;
  $$0$i$i = $16;
 }
 $17 = ((($9)) + 11|0);
 $18 = HEAP8[$17>>0]|0;
 $19 = ($18<<24>>24)<(0);
 if ($19) {
  $20 = ((($9)) + 8|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = $21 & 2147483647;
  $phitmp$i = (($22) + -1)|0;
  $23 = $phitmp$i;
 } else {
  $23 = 10;
 }
 __THREW__ = 0;
 invoke_viii(3434,($9|0),($23|0),0);
 $24 = __THREW__; __THREW__ = 0;
 $25 = $24&1;
 if ($25) {
  $88 = ___cxa_find_matching_catch_2()|0;
  $89 = tempRet0;
  $$1 = $88;$$127 = $89;
 } else {
  $26 = HEAP8[$17>>0]|0;
  $27 = ($26<<24>>24)<(0);
  $28 = HEAP32[$9>>2]|0;
  $29 = $27 ? $28 : $9;
  HEAP32[$10>>2] = $29;
  HEAP32[$12>>2] = $11;
  HEAP32[$13>>2] = 0;
  $30 = ((($9)) + 4|0);
  $31 = ((($9)) + 8|0);
  $$pre = HEAP32[$1>>2]|0;
  $$024 = $29;$$pre$i$i$i = $$pre;$178 = $$pre;
  L11: while(1) {
   $32 = ($$pre$i$i$i|0)==(0|0);
   if ($32) {
    $$pre$i$i$i45 = 0;$148 = 0;$179 = 1;
   } else {
    $33 = ((($$pre$i$i$i)) + 12|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = ((($$pre$i$i$i)) + 16|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = ($34|0)==($36|0);
    if ($37) {
     $38 = HEAP32[$$pre$i$i$i>>2]|0;
     $39 = ((($38)) + 36|0);
     $40 = HEAP32[$39>>2]|0;
     __THREW__ = 0;
     $41 = (invoke_ii($40|0,($$pre$i$i$i|0))|0);
     $42 = __THREW__; __THREW__ = 0;
     $43 = $42&1;
     if ($43) {
      break;
     } else {
      $$0$i$i$i$i = $41;
     }
    } else {
     $44 = HEAP8[$34>>0]|0;
     $45 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($44)|0);
     $$0$i$i$i$i = $45;
    }
    $46 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
    $47 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i$i$i,$46)|0);
    if ($47) {
     HEAP32[$1>>2] = 0;
     $$pre$i$i$i45 = 0;$148 = 0;$179 = 1;
    } else {
     $$pre$i$i$i45 = $$pre$i$i$i;$148 = $178;$179 = 0;
    }
   }
   $48 = HEAP32[$2>>2]|0;
   $49 = ($48|0)==(0|0);
   do {
    if ($49) {
     label = 20;
    } else {
     $50 = ((($48)) + 12|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = ((($48)) + 16|0);
     $53 = HEAP32[$52>>2]|0;
     $54 = ($51|0)==($53|0);
     if ($54) {
      $55 = HEAP32[$48>>2]|0;
      $56 = ((($55)) + 36|0);
      $57 = HEAP32[$56>>2]|0;
      __THREW__ = 0;
      $58 = (invoke_ii($57|0,($48|0))|0);
      $59 = __THREW__; __THREW__ = 0;
      $60 = $59&1;
      if ($60) {
       break L11;
      } else {
       $$0$i$i2$i$i = $58;
      }
     } else {
      $61 = HEAP8[$51>>0]|0;
      $62 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($61)|0);
      $$0$i$i2$i$i = $62;
     }
     $63 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
     $64 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i2$i$i,$63)|0);
     if ($64) {
      HEAP32[$2>>2] = 0;
      label = 20;
      break;
     } else {
      if ($179) {
       $180 = $48;
       break;
      } else {
       $$2 = $$024;$$pre$i4$i$i51 = $48;
       label = 37;
       break L11;
      }
     }
    }
   } while(0);
   if ((label|0) == 20) {
    label = 0;
    if ($179) {
     $$2 = $$024;$$pre$i4$i$i51 = 0;
     label = 37;
     break;
    } else {
     $180 = 0;
    }
   }
   $65 = HEAP32[$10>>2]|0;
   $66 = HEAP8[$17>>0]|0;
   $67 = ($66<<24>>24)<(0);
   $68 = HEAP32[$30>>2]|0;
   $69 = $66&255;
   $70 = $67 ? $68 : $69;
   $71 = (($$024) + ($70)|0);
   $72 = ($65|0)==($71|0);
   if ($72) {
    $73 = $70 << 1;
    __THREW__ = 0;
    invoke_viii(3434,($9|0),($73|0),0);
    $74 = __THREW__; __THREW__ = 0;
    $75 = $74&1;
    if ($75) {
     break;
    }
    $76 = HEAP8[$17>>0]|0;
    $77 = ($76<<24>>24)<(0);
    if ($77) {
     $78 = HEAP32[$31>>2]|0;
     $79 = $78 & 2147483647;
     $phitmp$i34 = (($79) + -1)|0;
     $80 = $phitmp$i34;
    } else {
     $80 = 10;
    }
    __THREW__ = 0;
    invoke_viii(3434,($9|0),($80|0),0);
    $81 = __THREW__; __THREW__ = 0;
    $82 = $81&1;
    if ($82) {
     break;
    }
    $83 = HEAP8[$17>>0]|0;
    $84 = ($83<<24>>24)<(0);
    $85 = HEAP32[$9>>2]|0;
    $86 = $84 ? $85 : $9;
    $87 = (($86) + ($70)|0);
    HEAP32[$10>>2] = $87;
    $$125 = $86;
   } else {
    $$125 = $$024;
   }
   $90 = ((($$pre$i$i$i45)) + 12|0);
   $91 = HEAP32[$90>>2]|0;
   $92 = ((($$pre$i$i$i45)) + 16|0);
   $93 = HEAP32[$92>>2]|0;
   $94 = ($91|0)==($93|0);
   if ($94) {
    $95 = HEAP32[$$pre$i$i$i45>>2]|0;
    $96 = ((($95)) + 36|0);
    $97 = HEAP32[$96>>2]|0;
    __THREW__ = 0;
    $98 = (invoke_ii($97|0,($$pre$i$i$i45|0))|0);
    $99 = __THREW__; __THREW__ = 0;
    $100 = $99&1;
    if ($100) {
     break;
    } else {
     $$0$i$i39 = $98;
    }
   } else {
    $101 = HEAP8[$91>>0]|0;
    $102 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($101)|0);
    $$0$i$i39 = $102;
   }
   $103 = $$0$i$i39&255;
   $104 = HEAP8[$7>>0]|0;
   __THREW__ = 0;
   $105 = (invoke_iiiiiiiiiii(4667,($103|0),($14|0),($$125|0),($10|0),($13|0),($104|0),($8|0),($11|0),($12|0),($6|0))|0);
   $106 = __THREW__; __THREW__ = 0;
   $107 = $106&1;
   if ($107) {
    break;
   }
   $108 = ($105|0)==(0);
   if (!($108)) {
    $$2 = $$125;$$pre$i4$i$i51 = $180;
    label = 37;
    break;
   }
   $109 = HEAP32[$90>>2]|0;
   $110 = HEAP32[$92>>2]|0;
   $111 = ($109|0)==($110|0);
   if ($111) {
    $112 = HEAP32[$$pre$i$i$i45>>2]|0;
    $113 = ((($112)) + 40|0);
    $114 = HEAP32[$113>>2]|0;
    __THREW__ = 0;
    (invoke_ii($114|0,($$pre$i$i$i45|0))|0);
    $115 = __THREW__; __THREW__ = 0;
    $116 = $115&1;
    if ($116) {
     break;
    } else {
     $$024 = $$125;$$pre$i$i$i = $$pre$i$i$i45;$178 = $148;
     continue;
    }
   } else {
    $117 = ((($109)) + 1|0);
    HEAP32[$90>>2] = $117;
    $118 = HEAP8[$109>>0]|0;
    (__ZNSt3__211char_traitsIcE11to_int_typeEc($118)|0);
    $$024 = $$125;$$pre$i$i$i = $$pre$i$i$i45;$178 = $148;
    continue;
   }
  }
  L50: do {
   if ((label|0) == 37) {
    $119 = ((($8)) + 11|0);
    $120 = HEAP8[$119>>0]|0;
    $121 = ($120<<24>>24)<(0);
    $122 = ((($8)) + 4|0);
    $123 = HEAP32[$122>>2]|0;
    $124 = $120&255;
    $125 = $121 ? $123 : $124;
    $126 = ($125|0)==(0);
    if (!($126)) {
     $127 = HEAP32[$12>>2]|0;
     $128 = $127;
     $129 = $11;
     $130 = (($128) - ($129))|0;
     $131 = ($130|0)<(160);
     if ($131) {
      $132 = HEAP32[$13>>2]|0;
      $133 = ((($127)) + 4|0);
      HEAP32[$12>>2] = $133;
      HEAP32[$127>>2] = $132;
     }
    }
    $134 = HEAP32[$10>>2]|0;
    __THREW__ = 0;
    $135 = (invoke_iiiii(4680,($$2|0),($134|0),($4|0),($14|0))|0);
    $136 = __THREW__; __THREW__ = 0;
    $137 = $136&1;
    if (!($137)) {
     HEAP32[$5>>2] = $135;
     $138 = HEAP32[$12>>2]|0;
     __THREW__ = 0;
     invoke_viiii(4676,($8|0),($11|0),($138|0),($4|0));
     $139 = __THREW__; __THREW__ = 0;
     $140 = $139&1;
     if (!($140)) {
      $141 = ($$pre$i$i$i45|0)==(0|0);
      if ($141) {
       $181 = 1;
      } else {
       $142 = ((($$pre$i$i$i45)) + 12|0);
       $143 = HEAP32[$142>>2]|0;
       $144 = ((($$pre$i$i$i45)) + 16|0);
       $145 = HEAP32[$144>>2]|0;
       $146 = ($143|0)==($145|0);
       if ($146) {
        $147 = HEAP32[$148>>2]|0;
        $149 = ((($147)) + 36|0);
        $150 = HEAP32[$149>>2]|0;
        __THREW__ = 0;
        $151 = (invoke_ii($150|0,($$pre$i$i$i45|0))|0);
        $152 = __THREW__; __THREW__ = 0;
        $153 = $152&1;
        if ($153) {
         break;
        } else {
         $$0$i$i$i$i43 = $151;
        }
       } else {
        $154 = HEAP8[$143>>0]|0;
        $155 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($154)|0);
        $$0$i$i$i$i43 = $155;
       }
       $156 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
       $157 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i$i$i43,$156)|0);
       if ($157) {
        HEAP32[$1>>2] = 0;
        $181 = 1;
       } else {
        $181 = 0;
       }
      }
      $158 = ($$pre$i4$i$i51|0)==(0|0);
      do {
       if ($158) {
        label = 54;
       } else {
        $159 = ((($$pre$i4$i$i51)) + 12|0);
        $160 = HEAP32[$159>>2]|0;
        $161 = ((($$pre$i4$i$i51)) + 16|0);
        $162 = HEAP32[$161>>2]|0;
        $163 = ($160|0)==($162|0);
        if ($163) {
         $164 = HEAP32[$$pre$i4$i$i51>>2]|0;
         $165 = ((($164)) + 36|0);
         $166 = HEAP32[$165>>2]|0;
         __THREW__ = 0;
         $167 = (invoke_ii($166|0,($$pre$i4$i$i51|0))|0);
         $168 = __THREW__; __THREW__ = 0;
         $169 = $168&1;
         if ($169) {
          break L50;
         } else {
          $$0$i$i2$i$i49 = $167;
         }
        } else {
         $170 = HEAP8[$160>>0]|0;
         $171 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($170)|0);
         $$0$i$i2$i$i49 = $171;
        }
        $172 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
        $173 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i2$i$i49,$172)|0);
        if ($173) {
         HEAP32[$2>>2] = 0;
         label = 54;
         break;
        } else {
         if ($181) {
          break;
         } else {
          label = 56;
          break;
         }
        }
       }
      } while(0);
      if ((label|0) == 54) {
       if ($181) {
        label = 56;
       }
      }
      if ((label|0) == 56) {
       $174 = HEAP32[$4>>2]|0;
       $175 = $174 | 2;
       HEAP32[$4>>2] = $175;
      }
      $$sroa$0$0$copyload = HEAP32[$1>>2]|0;
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($9);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($8);
      STACKTOP = sp;return ($$sroa$0$0$copyload|0);
     }
    }
   }
  } while(0);
  $176 = ___cxa_find_matching_catch_2()|0;
  $177 = tempRet0;
  $$1 = $176;$$127 = $177;
 }
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($9);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($8);
 ___resumeException($$1|0);
 // unreachable;
 return (0)|0;
}
function __ZNSt3__227__num_get_unsigned_integralImEET_PKcS3_Rji($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $$1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $4 = sp;
 $5 = ($0|0)==($1|0);
 do {
  if ($5) {
   HEAP32[$2>>2] = 4;
   $$1 = 0;
  } else {
   $6 = HEAP8[$0>>0]|0;
   $7 = ($6<<24>>24)==(45);
   if ($7) {
    HEAP32[$2>>2] = 4;
    $$1 = 0;
    break;
   }
   $8 = (___errno_location()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (___errno_location()|0);
   HEAP32[$10>>2] = 0;
   $11 = (__ZNSt3__26__clocEv()|0);
   $12 = (_strtoull_l($0,$4,$3,$11)|0);
   $13 = tempRet0;
   $14 = (___errno_location()|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = ($15|0)==(0);
   if ($16) {
    $17 = (___errno_location()|0);
    HEAP32[$17>>2] = $9;
   }
   $18 = HEAP32[$4>>2]|0;
   $19 = ($18|0)==($1|0);
   do {
    if ($19) {
     $20 = ($15|0)==(34);
     $21 = ($13>>>0)>(0);
     $22 = ($12>>>0)>(4294967295);
     $23 = ($13|0)==(0);
     $24 = $23 & $22;
     $25 = $21 | $24;
     $or$cond = $25 | $20;
     if ($or$cond) {
      HEAP32[$2>>2] = 4;
      $$0 = -1;
      break;
     } else {
      $$0 = $12;
      break;
     }
    } else {
     HEAP32[$2>>2] = 4;
     $$0 = 0;
    }
   } while(0);
   $$1 = $$0;
  }
 } while(0);
 STACKTOP = sp;return ($$1|0);
}
function __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE17__do_get_unsignedIjEES4_S4_S4_RNS_8ios_baseERjRT_($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$0$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i43 = 0, $$0$i$i2$i$i = 0, $$0$i$i2$i$i49 = 0, $$0$i$i39 = 0, $$024 = 0, $$1 = 0, $$125 = 0, $$127 = 0, $$2 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i45 = 0, $$pre$i4$i$i51 = 0, $$sroa$0$0$copyload = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0;
 var $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0;
 var $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0;
 var $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i$i = 0, $phitmp$i = 0, $phitmp$i34 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(224|0);
 $6 = sp + 198|0;
 $7 = sp + 196|0;
 $8 = sp + 184|0;
 $9 = sp + 172|0;
 $10 = sp + 168|0;
 $11 = sp + 8|0;
 $12 = sp + 4|0;
 $13 = sp;
 $14 = (__ZNSt3__214__num_get_base10__get_baseERNS_8ios_baseE($3)|0);
 __ZNSt3__29__num_getIcE17__stage2_int_prepERNS_8ios_baseEPcRc($8,$3,$6,$7);
 ;HEAP32[$9>>2]=0|0;HEAP32[$9+4>>2]=0|0;HEAP32[$9+8>>2]=0|0;
 $$0$i$i = 0;
 while(1) {
  $exitcond$i$i = ($$0$i$i|0)==(3);
  if ($exitcond$i$i) {
   break;
  }
  $15 = (($9) + ($$0$i$i<<2)|0);
  HEAP32[$15>>2] = 0;
  $16 = (($$0$i$i) + 1)|0;
  $$0$i$i = $16;
 }
 $17 = ((($9)) + 11|0);
 $18 = HEAP8[$17>>0]|0;
 $19 = ($18<<24>>24)<(0);
 if ($19) {
  $20 = ((($9)) + 8|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = $21 & 2147483647;
  $phitmp$i = (($22) + -1)|0;
  $23 = $phitmp$i;
 } else {
  $23 = 10;
 }
 __THREW__ = 0;
 invoke_viii(3434,($9|0),($23|0),0);
 $24 = __THREW__; __THREW__ = 0;
 $25 = $24&1;
 if ($25) {
  $88 = ___cxa_find_matching_catch_2()|0;
  $89 = tempRet0;
  $$1 = $88;$$127 = $89;
 } else {
  $26 = HEAP8[$17>>0]|0;
  $27 = ($26<<24>>24)<(0);
  $28 = HEAP32[$9>>2]|0;
  $29 = $27 ? $28 : $9;
  HEAP32[$10>>2] = $29;
  HEAP32[$12>>2] = $11;
  HEAP32[$13>>2] = 0;
  $30 = ((($9)) + 4|0);
  $31 = ((($9)) + 8|0);
  $$pre = HEAP32[$1>>2]|0;
  $$024 = $29;$$pre$i$i$i = $$pre;$178 = $$pre;
  L11: while(1) {
   $32 = ($$pre$i$i$i|0)==(0|0);
   if ($32) {
    $$pre$i$i$i45 = 0;$148 = 0;$179 = 1;
   } else {
    $33 = ((($$pre$i$i$i)) + 12|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = ((($$pre$i$i$i)) + 16|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = ($34|0)==($36|0);
    if ($37) {
     $38 = HEAP32[$$pre$i$i$i>>2]|0;
     $39 = ((($38)) + 36|0);
     $40 = HEAP32[$39>>2]|0;
     __THREW__ = 0;
     $41 = (invoke_ii($40|0,($$pre$i$i$i|0))|0);
     $42 = __THREW__; __THREW__ = 0;
     $43 = $42&1;
     if ($43) {
      break;
     } else {
      $$0$i$i$i$i = $41;
     }
    } else {
     $44 = HEAP8[$34>>0]|0;
     $45 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($44)|0);
     $$0$i$i$i$i = $45;
    }
    $46 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
    $47 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i$i$i,$46)|0);
    if ($47) {
     HEAP32[$1>>2] = 0;
     $$pre$i$i$i45 = 0;$148 = 0;$179 = 1;
    } else {
     $$pre$i$i$i45 = $$pre$i$i$i;$148 = $178;$179 = 0;
    }
   }
   $48 = HEAP32[$2>>2]|0;
   $49 = ($48|0)==(0|0);
   do {
    if ($49) {
     label = 20;
    } else {
     $50 = ((($48)) + 12|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = ((($48)) + 16|0);
     $53 = HEAP32[$52>>2]|0;
     $54 = ($51|0)==($53|0);
     if ($54) {
      $55 = HEAP32[$48>>2]|0;
      $56 = ((($55)) + 36|0);
      $57 = HEAP32[$56>>2]|0;
      __THREW__ = 0;
      $58 = (invoke_ii($57|0,($48|0))|0);
      $59 = __THREW__; __THREW__ = 0;
      $60 = $59&1;
      if ($60) {
       break L11;
      } else {
       $$0$i$i2$i$i = $58;
      }
     } else {
      $61 = HEAP8[$51>>0]|0;
      $62 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($61)|0);
      $$0$i$i2$i$i = $62;
     }
     $63 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
     $64 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i2$i$i,$63)|0);
     if ($64) {
      HEAP32[$2>>2] = 0;
      label = 20;
      break;
     } else {
      if ($179) {
       $180 = $48;
       break;
      } else {
       $$2 = $$024;$$pre$i4$i$i51 = $48;
       label = 37;
       break L11;
      }
     }
    }
   } while(0);
   if ((label|0) == 20) {
    label = 0;
    if ($179) {
     $$2 = $$024;$$pre$i4$i$i51 = 0;
     label = 37;
     break;
    } else {
     $180 = 0;
    }
   }
   $65 = HEAP32[$10>>2]|0;
   $66 = HEAP8[$17>>0]|0;
   $67 = ($66<<24>>24)<(0);
   $68 = HEAP32[$30>>2]|0;
   $69 = $66&255;
   $70 = $67 ? $68 : $69;
   $71 = (($$024) + ($70)|0);
   $72 = ($65|0)==($71|0);
   if ($72) {
    $73 = $70 << 1;
    __THREW__ = 0;
    invoke_viii(3434,($9|0),($73|0),0);
    $74 = __THREW__; __THREW__ = 0;
    $75 = $74&1;
    if ($75) {
     break;
    }
    $76 = HEAP8[$17>>0]|0;
    $77 = ($76<<24>>24)<(0);
    if ($77) {
     $78 = HEAP32[$31>>2]|0;
     $79 = $78 & 2147483647;
     $phitmp$i34 = (($79) + -1)|0;
     $80 = $phitmp$i34;
    } else {
     $80 = 10;
    }
    __THREW__ = 0;
    invoke_viii(3434,($9|0),($80|0),0);
    $81 = __THREW__; __THREW__ = 0;
    $82 = $81&1;
    if ($82) {
     break;
    }
    $83 = HEAP8[$17>>0]|0;
    $84 = ($83<<24>>24)<(0);
    $85 = HEAP32[$9>>2]|0;
    $86 = $84 ? $85 : $9;
    $87 = (($86) + ($70)|0);
    HEAP32[$10>>2] = $87;
    $$125 = $86;
   } else {
    $$125 = $$024;
   }
   $90 = ((($$pre$i$i$i45)) + 12|0);
   $91 = HEAP32[$90>>2]|0;
   $92 = ((($$pre$i$i$i45)) + 16|0);
   $93 = HEAP32[$92>>2]|0;
   $94 = ($91|0)==($93|0);
   if ($94) {
    $95 = HEAP32[$$pre$i$i$i45>>2]|0;
    $96 = ((($95)) + 36|0);
    $97 = HEAP32[$96>>2]|0;
    __THREW__ = 0;
    $98 = (invoke_ii($97|0,($$pre$i$i$i45|0))|0);
    $99 = __THREW__; __THREW__ = 0;
    $100 = $99&1;
    if ($100) {
     break;
    } else {
     $$0$i$i39 = $98;
    }
   } else {
    $101 = HEAP8[$91>>0]|0;
    $102 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($101)|0);
    $$0$i$i39 = $102;
   }
   $103 = $$0$i$i39&255;
   $104 = HEAP8[$7>>0]|0;
   __THREW__ = 0;
   $105 = (invoke_iiiiiiiiiii(4667,($103|0),($14|0),($$125|0),($10|0),($13|0),($104|0),($8|0),($11|0),($12|0),($6|0))|0);
   $106 = __THREW__; __THREW__ = 0;
   $107 = $106&1;
   if ($107) {
    break;
   }
   $108 = ($105|0)==(0);
   if (!($108)) {
    $$2 = $$125;$$pre$i4$i$i51 = $180;
    label = 37;
    break;
   }
   $109 = HEAP32[$90>>2]|0;
   $110 = HEAP32[$92>>2]|0;
   $111 = ($109|0)==($110|0);
   if ($111) {
    $112 = HEAP32[$$pre$i$i$i45>>2]|0;
    $113 = ((($112)) + 40|0);
    $114 = HEAP32[$113>>2]|0;
    __THREW__ = 0;
    (invoke_ii($114|0,($$pre$i$i$i45|0))|0);
    $115 = __THREW__; __THREW__ = 0;
    $116 = $115&1;
    if ($116) {
     break;
    } else {
     $$024 = $$125;$$pre$i$i$i = $$pre$i$i$i45;$178 = $148;
     continue;
    }
   } else {
    $117 = ((($109)) + 1|0);
    HEAP32[$90>>2] = $117;
    $118 = HEAP8[$109>>0]|0;
    (__ZNSt3__211char_traitsIcE11to_int_typeEc($118)|0);
    $$024 = $$125;$$pre$i$i$i = $$pre$i$i$i45;$178 = $148;
    continue;
   }
  }
  L50: do {
   if ((label|0) == 37) {
    $119 = ((($8)) + 11|0);
    $120 = HEAP8[$119>>0]|0;
    $121 = ($120<<24>>24)<(0);
    $122 = ((($8)) + 4|0);
    $123 = HEAP32[$122>>2]|0;
    $124 = $120&255;
    $125 = $121 ? $123 : $124;
    $126 = ($125|0)==(0);
    if (!($126)) {
     $127 = HEAP32[$12>>2]|0;
     $128 = $127;
     $129 = $11;
     $130 = (($128) - ($129))|0;
     $131 = ($130|0)<(160);
     if ($131) {
      $132 = HEAP32[$13>>2]|0;
      $133 = ((($127)) + 4|0);
      HEAP32[$12>>2] = $133;
      HEAP32[$127>>2] = $132;
     }
    }
    $134 = HEAP32[$10>>2]|0;
    __THREW__ = 0;
    $135 = (invoke_iiiii(4681,($$2|0),($134|0),($4|0),($14|0))|0);
    $136 = __THREW__; __THREW__ = 0;
    $137 = $136&1;
    if (!($137)) {
     HEAP32[$5>>2] = $135;
     $138 = HEAP32[$12>>2]|0;
     __THREW__ = 0;
     invoke_viiii(4676,($8|0),($11|0),($138|0),($4|0));
     $139 = __THREW__; __THREW__ = 0;
     $140 = $139&1;
     if (!($140)) {
      $141 = ($$pre$i$i$i45|0)==(0|0);
      if ($141) {
       $181 = 1;
      } else {
       $142 = ((($$pre$i$i$i45)) + 12|0);
       $143 = HEAP32[$142>>2]|0;
       $144 = ((($$pre$i$i$i45)) + 16|0);
       $145 = HEAP32[$144>>2]|0;
       $146 = ($143|0)==($145|0);
       if ($146) {
        $147 = HEAP32[$148>>2]|0;
        $149 = ((($147)) + 36|0);
        $150 = HEAP32[$149>>2]|0;
        __THREW__ = 0;
        $151 = (invoke_ii($150|0,($$pre$i$i$i45|0))|0);
        $152 = __THREW__; __THREW__ = 0;
        $153 = $152&1;
        if ($153) {
         break;
        } else {
         $$0$i$i$i$i43 = $151;
        }
       } else {
        $154 = HEAP8[$143>>0]|0;
        $155 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($154)|0);
        $$0$i$i$i$i43 = $155;
       }
       $156 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
       $157 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i$i$i43,$156)|0);
       if ($157) {
        HEAP32[$1>>2] = 0;
        $181 = 1;
       } else {
        $181 = 0;
       }
      }
      $158 = ($$pre$i4$i$i51|0)==(0|0);
      do {
       if ($158) {
        label = 54;
       } else {
        $159 = ((($$pre$i4$i$i51)) + 12|0);
        $160 = HEAP32[$159>>2]|0;
        $161 = ((($$pre$i4$i$i51)) + 16|0);
        $162 = HEAP32[$161>>2]|0;
        $163 = ($160|0)==($162|0);
        if ($163) {
         $164 = HEAP32[$$pre$i4$i$i51>>2]|0;
         $165 = ((($164)) + 36|0);
         $166 = HEAP32[$165>>2]|0;
         __THREW__ = 0;
         $167 = (invoke_ii($166|0,($$pre$i4$i$i51|0))|0);
         $168 = __THREW__; __THREW__ = 0;
         $169 = $168&1;
         if ($169) {
          break L50;
         } else {
          $$0$i$i2$i$i49 = $167;
         }
        } else {
         $170 = HEAP8[$160>>0]|0;
         $171 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($170)|0);
         $$0$i$i2$i$i49 = $171;
        }
        $172 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
        $173 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i2$i$i49,$172)|0);
        if ($173) {
         HEAP32[$2>>2] = 0;
         label = 54;
         break;
        } else {
         if ($181) {
          break;
         } else {
          label = 56;
          break;
         }
        }
       }
      } while(0);
      if ((label|0) == 54) {
       if ($181) {
        label = 56;
       }
      }
      if ((label|0) == 56) {
       $174 = HEAP32[$4>>2]|0;
       $175 = $174 | 2;
       HEAP32[$4>>2] = $175;
      }
      $$sroa$0$0$copyload = HEAP32[$1>>2]|0;
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($9);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($8);
      STACKTOP = sp;return ($$sroa$0$0$copyload|0);
     }
    }
   }
  } while(0);
  $176 = ___cxa_find_matching_catch_2()|0;
  $177 = tempRet0;
  $$1 = $176;$$127 = $177;
 }
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($9);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($8);
 ___resumeException($$1|0);
 // unreachable;
 return (0)|0;
}
function __ZNSt3__227__num_get_unsigned_integralIjEET_PKcS3_Rji($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $$1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $4 = sp;
 $5 = ($0|0)==($1|0);
 do {
  if ($5) {
   HEAP32[$2>>2] = 4;
   $$1 = 0;
  } else {
   $6 = HEAP8[$0>>0]|0;
   $7 = ($6<<24>>24)==(45);
   if ($7) {
    HEAP32[$2>>2] = 4;
    $$1 = 0;
    break;
   }
   $8 = (___errno_location()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (___errno_location()|0);
   HEAP32[$10>>2] = 0;
   $11 = (__ZNSt3__26__clocEv()|0);
   $12 = (_strtoull_l($0,$4,$3,$11)|0);
   $13 = tempRet0;
   $14 = (___errno_location()|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = ($15|0)==(0);
   if ($16) {
    $17 = (___errno_location()|0);
    HEAP32[$17>>2] = $9;
   }
   $18 = HEAP32[$4>>2]|0;
   $19 = ($18|0)==($1|0);
   do {
    if ($19) {
     $20 = ($15|0)==(34);
     $21 = ($13>>>0)>(0);
     $22 = ($12>>>0)>(4294967295);
     $23 = ($13|0)==(0);
     $24 = $23 & $22;
     $25 = $21 | $24;
     $or$cond = $25 | $20;
     if ($or$cond) {
      HEAP32[$2>>2] = 4;
      $$0 = -1;
      break;
     } else {
      $$0 = $12;
      break;
     }
    } else {
     HEAP32[$2>>2] = 4;
     $$0 = 0;
    }
   } while(0);
   $$1 = $$0;
  }
 } while(0);
 STACKTOP = sp;return ($$1|0);
}
function __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE17__do_get_unsignedItEES4_S4_S4_RNS_8ios_baseERjRT_($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$0$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i43 = 0, $$0$i$i2$i$i = 0, $$0$i$i2$i$i49 = 0, $$0$i$i39 = 0, $$024 = 0, $$1 = 0, $$125 = 0, $$127 = 0, $$2 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i45 = 0, $$pre$i4$i$i51 = 0, $$sroa$0$0$copyload = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0;
 var $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0;
 var $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0;
 var $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i$i = 0, $phitmp$i = 0, $phitmp$i34 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(224|0);
 $6 = sp + 198|0;
 $7 = sp + 196|0;
 $8 = sp + 184|0;
 $9 = sp + 172|0;
 $10 = sp + 168|0;
 $11 = sp + 8|0;
 $12 = sp + 4|0;
 $13 = sp;
 $14 = (__ZNSt3__214__num_get_base10__get_baseERNS_8ios_baseE($3)|0);
 __ZNSt3__29__num_getIcE17__stage2_int_prepERNS_8ios_baseEPcRc($8,$3,$6,$7);
 ;HEAP32[$9>>2]=0|0;HEAP32[$9+4>>2]=0|0;HEAP32[$9+8>>2]=0|0;
 $$0$i$i = 0;
 while(1) {
  $exitcond$i$i = ($$0$i$i|0)==(3);
  if ($exitcond$i$i) {
   break;
  }
  $15 = (($9) + ($$0$i$i<<2)|0);
  HEAP32[$15>>2] = 0;
  $16 = (($$0$i$i) + 1)|0;
  $$0$i$i = $16;
 }
 $17 = ((($9)) + 11|0);
 $18 = HEAP8[$17>>0]|0;
 $19 = ($18<<24>>24)<(0);
 if ($19) {
  $20 = ((($9)) + 8|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = $21 & 2147483647;
  $phitmp$i = (($22) + -1)|0;
  $23 = $phitmp$i;
 } else {
  $23 = 10;
 }
 __THREW__ = 0;
 invoke_viii(3434,($9|0),($23|0),0);
 $24 = __THREW__; __THREW__ = 0;
 $25 = $24&1;
 if ($25) {
  $88 = ___cxa_find_matching_catch_2()|0;
  $89 = tempRet0;
  $$1 = $88;$$127 = $89;
 } else {
  $26 = HEAP8[$17>>0]|0;
  $27 = ($26<<24>>24)<(0);
  $28 = HEAP32[$9>>2]|0;
  $29 = $27 ? $28 : $9;
  HEAP32[$10>>2] = $29;
  HEAP32[$12>>2] = $11;
  HEAP32[$13>>2] = 0;
  $30 = ((($9)) + 4|0);
  $31 = ((($9)) + 8|0);
  $$pre = HEAP32[$1>>2]|0;
  $$024 = $29;$$pre$i$i$i = $$pre;$178 = $$pre;
  L11: while(1) {
   $32 = ($$pre$i$i$i|0)==(0|0);
   if ($32) {
    $$pre$i$i$i45 = 0;$148 = 0;$179 = 1;
   } else {
    $33 = ((($$pre$i$i$i)) + 12|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = ((($$pre$i$i$i)) + 16|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = ($34|0)==($36|0);
    if ($37) {
     $38 = HEAP32[$$pre$i$i$i>>2]|0;
     $39 = ((($38)) + 36|0);
     $40 = HEAP32[$39>>2]|0;
     __THREW__ = 0;
     $41 = (invoke_ii($40|0,($$pre$i$i$i|0))|0);
     $42 = __THREW__; __THREW__ = 0;
     $43 = $42&1;
     if ($43) {
      break;
     } else {
      $$0$i$i$i$i = $41;
     }
    } else {
     $44 = HEAP8[$34>>0]|0;
     $45 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($44)|0);
     $$0$i$i$i$i = $45;
    }
    $46 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
    $47 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i$i$i,$46)|0);
    if ($47) {
     HEAP32[$1>>2] = 0;
     $$pre$i$i$i45 = 0;$148 = 0;$179 = 1;
    } else {
     $$pre$i$i$i45 = $$pre$i$i$i;$148 = $178;$179 = 0;
    }
   }
   $48 = HEAP32[$2>>2]|0;
   $49 = ($48|0)==(0|0);
   do {
    if ($49) {
     label = 20;
    } else {
     $50 = ((($48)) + 12|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = ((($48)) + 16|0);
     $53 = HEAP32[$52>>2]|0;
     $54 = ($51|0)==($53|0);
     if ($54) {
      $55 = HEAP32[$48>>2]|0;
      $56 = ((($55)) + 36|0);
      $57 = HEAP32[$56>>2]|0;
      __THREW__ = 0;
      $58 = (invoke_ii($57|0,($48|0))|0);
      $59 = __THREW__; __THREW__ = 0;
      $60 = $59&1;
      if ($60) {
       break L11;
      } else {
       $$0$i$i2$i$i = $58;
      }
     } else {
      $61 = HEAP8[$51>>0]|0;
      $62 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($61)|0);
      $$0$i$i2$i$i = $62;
     }
     $63 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
     $64 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i2$i$i,$63)|0);
     if ($64) {
      HEAP32[$2>>2] = 0;
      label = 20;
      break;
     } else {
      if ($179) {
       $180 = $48;
       break;
      } else {
       $$2 = $$024;$$pre$i4$i$i51 = $48;
       label = 37;
       break L11;
      }
     }
    }
   } while(0);
   if ((label|0) == 20) {
    label = 0;
    if ($179) {
     $$2 = $$024;$$pre$i4$i$i51 = 0;
     label = 37;
     break;
    } else {
     $180 = 0;
    }
   }
   $65 = HEAP32[$10>>2]|0;
   $66 = HEAP8[$17>>0]|0;
   $67 = ($66<<24>>24)<(0);
   $68 = HEAP32[$30>>2]|0;
   $69 = $66&255;
   $70 = $67 ? $68 : $69;
   $71 = (($$024) + ($70)|0);
   $72 = ($65|0)==($71|0);
   if ($72) {
    $73 = $70 << 1;
    __THREW__ = 0;
    invoke_viii(3434,($9|0),($73|0),0);
    $74 = __THREW__; __THREW__ = 0;
    $75 = $74&1;
    if ($75) {
     break;
    }
    $76 = HEAP8[$17>>0]|0;
    $77 = ($76<<24>>24)<(0);
    if ($77) {
     $78 = HEAP32[$31>>2]|0;
     $79 = $78 & 2147483647;
     $phitmp$i34 = (($79) + -1)|0;
     $80 = $phitmp$i34;
    } else {
     $80 = 10;
    }
    __THREW__ = 0;
    invoke_viii(3434,($9|0),($80|0),0);
    $81 = __THREW__; __THREW__ = 0;
    $82 = $81&1;
    if ($82) {
     break;
    }
    $83 = HEAP8[$17>>0]|0;
    $84 = ($83<<24>>24)<(0);
    $85 = HEAP32[$9>>2]|0;
    $86 = $84 ? $85 : $9;
    $87 = (($86) + ($70)|0);
    HEAP32[$10>>2] = $87;
    $$125 = $86;
   } else {
    $$125 = $$024;
   }
   $90 = ((($$pre$i$i$i45)) + 12|0);
   $91 = HEAP32[$90>>2]|0;
   $92 = ((($$pre$i$i$i45)) + 16|0);
   $93 = HEAP32[$92>>2]|0;
   $94 = ($91|0)==($93|0);
   if ($94) {
    $95 = HEAP32[$$pre$i$i$i45>>2]|0;
    $96 = ((($95)) + 36|0);
    $97 = HEAP32[$96>>2]|0;
    __THREW__ = 0;
    $98 = (invoke_ii($97|0,($$pre$i$i$i45|0))|0);
    $99 = __THREW__; __THREW__ = 0;
    $100 = $99&1;
    if ($100) {
     break;
    } else {
     $$0$i$i39 = $98;
    }
   } else {
    $101 = HEAP8[$91>>0]|0;
    $102 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($101)|0);
    $$0$i$i39 = $102;
   }
   $103 = $$0$i$i39&255;
   $104 = HEAP8[$7>>0]|0;
   __THREW__ = 0;
   $105 = (invoke_iiiiiiiiiii(4667,($103|0),($14|0),($$125|0),($10|0),($13|0),($104|0),($8|0),($11|0),($12|0),($6|0))|0);
   $106 = __THREW__; __THREW__ = 0;
   $107 = $106&1;
   if ($107) {
    break;
   }
   $108 = ($105|0)==(0);
   if (!($108)) {
    $$2 = $$125;$$pre$i4$i$i51 = $180;
    label = 37;
    break;
   }
   $109 = HEAP32[$90>>2]|0;
   $110 = HEAP32[$92>>2]|0;
   $111 = ($109|0)==($110|0);
   if ($111) {
    $112 = HEAP32[$$pre$i$i$i45>>2]|0;
    $113 = ((($112)) + 40|0);
    $114 = HEAP32[$113>>2]|0;
    __THREW__ = 0;
    (invoke_ii($114|0,($$pre$i$i$i45|0))|0);
    $115 = __THREW__; __THREW__ = 0;
    $116 = $115&1;
    if ($116) {
     break;
    } else {
     $$024 = $$125;$$pre$i$i$i = $$pre$i$i$i45;$178 = $148;
     continue;
    }
   } else {
    $117 = ((($109)) + 1|0);
    HEAP32[$90>>2] = $117;
    $118 = HEAP8[$109>>0]|0;
    (__ZNSt3__211char_traitsIcE11to_int_typeEc($118)|0);
    $$024 = $$125;$$pre$i$i$i = $$pre$i$i$i45;$178 = $148;
    continue;
   }
  }
  L50: do {
   if ((label|0) == 37) {
    $119 = ((($8)) + 11|0);
    $120 = HEAP8[$119>>0]|0;
    $121 = ($120<<24>>24)<(0);
    $122 = ((($8)) + 4|0);
    $123 = HEAP32[$122>>2]|0;
    $124 = $120&255;
    $125 = $121 ? $123 : $124;
    $126 = ($125|0)==(0);
    if (!($126)) {
     $127 = HEAP32[$12>>2]|0;
     $128 = $127;
     $129 = $11;
     $130 = (($128) - ($129))|0;
     $131 = ($130|0)<(160);
     if ($131) {
      $132 = HEAP32[$13>>2]|0;
      $133 = ((($127)) + 4|0);
      HEAP32[$12>>2] = $133;
      HEAP32[$127>>2] = $132;
     }
    }
    $134 = HEAP32[$10>>2]|0;
    __THREW__ = 0;
    $135 = (invoke_iiiii(4682,($$2|0),($134|0),($4|0),($14|0))|0);
    $136 = __THREW__; __THREW__ = 0;
    $137 = $136&1;
    if (!($137)) {
     HEAP16[$5>>1] = $135;
     $138 = HEAP32[$12>>2]|0;
     __THREW__ = 0;
     invoke_viiii(4676,($8|0),($11|0),($138|0),($4|0));
     $139 = __THREW__; __THREW__ = 0;
     $140 = $139&1;
     if (!($140)) {
      $141 = ($$pre$i$i$i45|0)==(0|0);
      if ($141) {
       $181 = 1;
      } else {
       $142 = ((($$pre$i$i$i45)) + 12|0);
       $143 = HEAP32[$142>>2]|0;
       $144 = ((($$pre$i$i$i45)) + 16|0);
       $145 = HEAP32[$144>>2]|0;
       $146 = ($143|0)==($145|0);
       if ($146) {
        $147 = HEAP32[$148>>2]|0;
        $149 = ((($147)) + 36|0);
        $150 = HEAP32[$149>>2]|0;
        __THREW__ = 0;
        $151 = (invoke_ii($150|0,($$pre$i$i$i45|0))|0);
        $152 = __THREW__; __THREW__ = 0;
        $153 = $152&1;
        if ($153) {
         break;
        } else {
         $$0$i$i$i$i43 = $151;
        }
       } else {
        $154 = HEAP8[$143>>0]|0;
        $155 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($154)|0);
        $$0$i$i$i$i43 = $155;
       }
       $156 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
       $157 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i$i$i43,$156)|0);
       if ($157) {
        HEAP32[$1>>2] = 0;
        $181 = 1;
       } else {
        $181 = 0;
       }
      }
      $158 = ($$pre$i4$i$i51|0)==(0|0);
      do {
       if ($158) {
        label = 54;
       } else {
        $159 = ((($$pre$i4$i$i51)) + 12|0);
        $160 = HEAP32[$159>>2]|0;
        $161 = ((($$pre$i4$i$i51)) + 16|0);
        $162 = HEAP32[$161>>2]|0;
        $163 = ($160|0)==($162|0);
        if ($163) {
         $164 = HEAP32[$$pre$i4$i$i51>>2]|0;
         $165 = ((($164)) + 36|0);
         $166 = HEAP32[$165>>2]|0;
         __THREW__ = 0;
         $167 = (invoke_ii($166|0,($$pre$i4$i$i51|0))|0);
         $168 = __THREW__; __THREW__ = 0;
         $169 = $168&1;
         if ($169) {
          break L50;
         } else {
          $$0$i$i2$i$i49 = $167;
         }
        } else {
         $170 = HEAP8[$160>>0]|0;
         $171 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($170)|0);
         $$0$i$i2$i$i49 = $171;
        }
        $172 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
        $173 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i2$i$i49,$172)|0);
        if ($173) {
         HEAP32[$2>>2] = 0;
         label = 54;
         break;
        } else {
         if ($181) {
          break;
         } else {
          label = 56;
          break;
         }
        }
       }
      } while(0);
      if ((label|0) == 54) {
       if ($181) {
        label = 56;
       }
      }
      if ((label|0) == 56) {
       $174 = HEAP32[$4>>2]|0;
       $175 = $174 | 2;
       HEAP32[$4>>2] = $175;
      }
      $$sroa$0$0$copyload = HEAP32[$1>>2]|0;
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($9);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($8);
      STACKTOP = sp;return ($$sroa$0$0$copyload|0);
     }
    }
   }
  } while(0);
  $176 = ___cxa_find_matching_catch_2()|0;
  $177 = tempRet0;
  $$1 = $176;$$127 = $177;
 }
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($9);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($8);
 ___resumeException($$1|0);
 // unreachable;
 return (0)|0;
}
function __ZNSt3__227__num_get_unsigned_integralItEET_PKcS3_Rji($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $$1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $4 = sp;
 $5 = ($0|0)==($1|0);
 do {
  if ($5) {
   HEAP32[$2>>2] = 4;
   $$1 = 0;
  } else {
   $6 = HEAP8[$0>>0]|0;
   $7 = ($6<<24>>24)==(45);
   if ($7) {
    HEAP32[$2>>2] = 4;
    $$1 = 0;
    break;
   }
   $8 = (___errno_location()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (___errno_location()|0);
   HEAP32[$10>>2] = 0;
   $11 = (__ZNSt3__26__clocEv()|0);
   $12 = (_strtoull_l($0,$4,$3,$11)|0);
   $13 = tempRet0;
   $14 = (___errno_location()|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = ($15|0)==(0);
   if ($16) {
    $17 = (___errno_location()|0);
    HEAP32[$17>>2] = $9;
   }
   $18 = HEAP32[$4>>2]|0;
   $19 = ($18|0)==($1|0);
   do {
    if ($19) {
     $20 = ($15|0)==(34);
     $21 = ($13>>>0)>(0);
     $22 = ($12>>>0)>(65535);
     $23 = ($13|0)==(0);
     $24 = $23 & $22;
     $25 = $21 | $24;
     $or$cond = $25 | $20;
     if ($or$cond) {
      HEAP32[$2>>2] = 4;
      $$0 = -1;
      break;
     } else {
      $26 = $12&65535;
      $$0 = $26;
      break;
     }
    } else {
     HEAP32[$2>>2] = 4;
     $$0 = 0;
    }
   } while(0);
   $$1 = $$0;
  }
 } while(0);
 STACKTOP = sp;return ($$1|0);
}
function __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE15__do_get_signedIxEES4_S4_S4_RNS_8ios_baseERjRT_($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$0$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i43 = 0, $$0$i$i2$i$i = 0, $$0$i$i2$i$i49 = 0, $$0$i$i39 = 0, $$024 = 0, $$1 = 0, $$125 = 0, $$127 = 0, $$2 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i45 = 0, $$pre$i4$i$i51 = 0, $$sroa$0$0$copyload = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0;
 var $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0;
 var $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0;
 var $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i$i = 0, $phitmp$i = 0, $phitmp$i34 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(224|0);
 $6 = sp + 198|0;
 $7 = sp + 196|0;
 $8 = sp + 184|0;
 $9 = sp + 172|0;
 $10 = sp + 168|0;
 $11 = sp + 8|0;
 $12 = sp + 4|0;
 $13 = sp;
 $14 = (__ZNSt3__214__num_get_base10__get_baseERNS_8ios_baseE($3)|0);
 __ZNSt3__29__num_getIcE17__stage2_int_prepERNS_8ios_baseEPcRc($8,$3,$6,$7);
 ;HEAP32[$9>>2]=0|0;HEAP32[$9+4>>2]=0|0;HEAP32[$9+8>>2]=0|0;
 $$0$i$i = 0;
 while(1) {
  $exitcond$i$i = ($$0$i$i|0)==(3);
  if ($exitcond$i$i) {
   break;
  }
  $15 = (($9) + ($$0$i$i<<2)|0);
  HEAP32[$15>>2] = 0;
  $16 = (($$0$i$i) + 1)|0;
  $$0$i$i = $16;
 }
 $17 = ((($9)) + 11|0);
 $18 = HEAP8[$17>>0]|0;
 $19 = ($18<<24>>24)<(0);
 if ($19) {
  $20 = ((($9)) + 8|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = $21 & 2147483647;
  $phitmp$i = (($22) + -1)|0;
  $23 = $phitmp$i;
 } else {
  $23 = 10;
 }
 __THREW__ = 0;
 invoke_viii(3434,($9|0),($23|0),0);
 $24 = __THREW__; __THREW__ = 0;
 $25 = $24&1;
 if ($25) {
  $88 = ___cxa_find_matching_catch_2()|0;
  $89 = tempRet0;
  $$1 = $88;$$127 = $89;
 } else {
  $26 = HEAP8[$17>>0]|0;
  $27 = ($26<<24>>24)<(0);
  $28 = HEAP32[$9>>2]|0;
  $29 = $27 ? $28 : $9;
  HEAP32[$10>>2] = $29;
  HEAP32[$12>>2] = $11;
  HEAP32[$13>>2] = 0;
  $30 = ((($9)) + 4|0);
  $31 = ((($9)) + 8|0);
  $$pre = HEAP32[$1>>2]|0;
  $$024 = $29;$$pre$i$i$i = $$pre;$183 = $$pre;
  L11: while(1) {
   $32 = ($$pre$i$i$i|0)==(0|0);
   if ($32) {
    $$pre$i$i$i45 = 0;$153 = 0;$184 = 1;
   } else {
    $33 = ((($$pre$i$i$i)) + 12|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = ((($$pre$i$i$i)) + 16|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = ($34|0)==($36|0);
    if ($37) {
     $38 = HEAP32[$$pre$i$i$i>>2]|0;
     $39 = ((($38)) + 36|0);
     $40 = HEAP32[$39>>2]|0;
     __THREW__ = 0;
     $41 = (invoke_ii($40|0,($$pre$i$i$i|0))|0);
     $42 = __THREW__; __THREW__ = 0;
     $43 = $42&1;
     if ($43) {
      break;
     } else {
      $$0$i$i$i$i = $41;
     }
    } else {
     $44 = HEAP8[$34>>0]|0;
     $45 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($44)|0);
     $$0$i$i$i$i = $45;
    }
    $46 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
    $47 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i$i$i,$46)|0);
    if ($47) {
     HEAP32[$1>>2] = 0;
     $$pre$i$i$i45 = 0;$153 = 0;$184 = 1;
    } else {
     $$pre$i$i$i45 = $$pre$i$i$i;$153 = $183;$184 = 0;
    }
   }
   $48 = HEAP32[$2>>2]|0;
   $49 = ($48|0)==(0|0);
   do {
    if ($49) {
     label = 20;
    } else {
     $50 = ((($48)) + 12|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = ((($48)) + 16|0);
     $53 = HEAP32[$52>>2]|0;
     $54 = ($51|0)==($53|0);
     if ($54) {
      $55 = HEAP32[$48>>2]|0;
      $56 = ((($55)) + 36|0);
      $57 = HEAP32[$56>>2]|0;
      __THREW__ = 0;
      $58 = (invoke_ii($57|0,($48|0))|0);
      $59 = __THREW__; __THREW__ = 0;
      $60 = $59&1;
      if ($60) {
       break L11;
      } else {
       $$0$i$i2$i$i = $58;
      }
     } else {
      $61 = HEAP8[$51>>0]|0;
      $62 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($61)|0);
      $$0$i$i2$i$i = $62;
     }
     $63 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
     $64 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i2$i$i,$63)|0);
     if ($64) {
      HEAP32[$2>>2] = 0;
      label = 20;
      break;
     } else {
      if ($184) {
       $185 = $48;
       break;
      } else {
       $$2 = $$024;$$pre$i4$i$i51 = $48;
       label = 37;
       break L11;
      }
     }
    }
   } while(0);
   if ((label|0) == 20) {
    label = 0;
    if ($184) {
     $$2 = $$024;$$pre$i4$i$i51 = 0;
     label = 37;
     break;
    } else {
     $185 = 0;
    }
   }
   $65 = HEAP32[$10>>2]|0;
   $66 = HEAP8[$17>>0]|0;
   $67 = ($66<<24>>24)<(0);
   $68 = HEAP32[$30>>2]|0;
   $69 = $66&255;
   $70 = $67 ? $68 : $69;
   $71 = (($$024) + ($70)|0);
   $72 = ($65|0)==($71|0);
   if ($72) {
    $73 = $70 << 1;
    __THREW__ = 0;
    invoke_viii(3434,($9|0),($73|0),0);
    $74 = __THREW__; __THREW__ = 0;
    $75 = $74&1;
    if ($75) {
     break;
    }
    $76 = HEAP8[$17>>0]|0;
    $77 = ($76<<24>>24)<(0);
    if ($77) {
     $78 = HEAP32[$31>>2]|0;
     $79 = $78 & 2147483647;
     $phitmp$i34 = (($79) + -1)|0;
     $80 = $phitmp$i34;
    } else {
     $80 = 10;
    }
    __THREW__ = 0;
    invoke_viii(3434,($9|0),($80|0),0);
    $81 = __THREW__; __THREW__ = 0;
    $82 = $81&1;
    if ($82) {
     break;
    }
    $83 = HEAP8[$17>>0]|0;
    $84 = ($83<<24>>24)<(0);
    $85 = HEAP32[$9>>2]|0;
    $86 = $84 ? $85 : $9;
    $87 = (($86) + ($70)|0);
    HEAP32[$10>>2] = $87;
    $$125 = $86;
   } else {
    $$125 = $$024;
   }
   $90 = ((($$pre$i$i$i45)) + 12|0);
   $91 = HEAP32[$90>>2]|0;
   $92 = ((($$pre$i$i$i45)) + 16|0);
   $93 = HEAP32[$92>>2]|0;
   $94 = ($91|0)==($93|0);
   if ($94) {
    $95 = HEAP32[$$pre$i$i$i45>>2]|0;
    $96 = ((($95)) + 36|0);
    $97 = HEAP32[$96>>2]|0;
    __THREW__ = 0;
    $98 = (invoke_ii($97|0,($$pre$i$i$i45|0))|0);
    $99 = __THREW__; __THREW__ = 0;
    $100 = $99&1;
    if ($100) {
     break;
    } else {
     $$0$i$i39 = $98;
    }
   } else {
    $101 = HEAP8[$91>>0]|0;
    $102 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($101)|0);
    $$0$i$i39 = $102;
   }
   $103 = $$0$i$i39&255;
   $104 = HEAP8[$7>>0]|0;
   __THREW__ = 0;
   $105 = (invoke_iiiiiiiiiii(4667,($103|0),($14|0),($$125|0),($10|0),($13|0),($104|0),($8|0),($11|0),($12|0),($6|0))|0);
   $106 = __THREW__; __THREW__ = 0;
   $107 = $106&1;
   if ($107) {
    break;
   }
   $108 = ($105|0)==(0);
   if (!($108)) {
    $$2 = $$125;$$pre$i4$i$i51 = $185;
    label = 37;
    break;
   }
   $109 = HEAP32[$90>>2]|0;
   $110 = HEAP32[$92>>2]|0;
   $111 = ($109|0)==($110|0);
   if ($111) {
    $112 = HEAP32[$$pre$i$i$i45>>2]|0;
    $113 = ((($112)) + 40|0);
    $114 = HEAP32[$113>>2]|0;
    __THREW__ = 0;
    (invoke_ii($114|0,($$pre$i$i$i45|0))|0);
    $115 = __THREW__; __THREW__ = 0;
    $116 = $115&1;
    if ($116) {
     break;
    } else {
     $$024 = $$125;$$pre$i$i$i = $$pre$i$i$i45;$183 = $153;
     continue;
    }
   } else {
    $117 = ((($109)) + 1|0);
    HEAP32[$90>>2] = $117;
    $118 = HEAP8[$109>>0]|0;
    (__ZNSt3__211char_traitsIcE11to_int_typeEc($118)|0);
    $$024 = $$125;$$pre$i$i$i = $$pre$i$i$i45;$183 = $153;
    continue;
   }
  }
  L50: do {
   if ((label|0) == 37) {
    $119 = ((($8)) + 11|0);
    $120 = HEAP8[$119>>0]|0;
    $121 = ($120<<24>>24)<(0);
    $122 = ((($8)) + 4|0);
    $123 = HEAP32[$122>>2]|0;
    $124 = $120&255;
    $125 = $121 ? $123 : $124;
    $126 = ($125|0)==(0);
    if (!($126)) {
     $127 = HEAP32[$12>>2]|0;
     $128 = $127;
     $129 = $11;
     $130 = (($128) - ($129))|0;
     $131 = ($130|0)<(160);
     if ($131) {
      $132 = HEAP32[$13>>2]|0;
      $133 = ((($127)) + 4|0);
      HEAP32[$12>>2] = $133;
      HEAP32[$127>>2] = $132;
     }
    }
    $134 = HEAP32[$10>>2]|0;
    __THREW__ = 0;
    $135 = (invoke_iiiii(4683,($$2|0),($134|0),($4|0),($14|0))|0);
    $136 = tempRet0;
    $137 = __THREW__; __THREW__ = 0;
    $138 = $137&1;
    if (!($138)) {
     $139 = $5;
     $140 = $139;
     HEAP32[$140>>2] = $135;
     $141 = (($139) + 4)|0;
     $142 = $141;
     HEAP32[$142>>2] = $136;
     $143 = HEAP32[$12>>2]|0;
     __THREW__ = 0;
     invoke_viiii(4676,($8|0),($11|0),($143|0),($4|0));
     $144 = __THREW__; __THREW__ = 0;
     $145 = $144&1;
     if (!($145)) {
      $146 = ($$pre$i$i$i45|0)==(0|0);
      if ($146) {
       $186 = 1;
      } else {
       $147 = ((($$pre$i$i$i45)) + 12|0);
       $148 = HEAP32[$147>>2]|0;
       $149 = ((($$pre$i$i$i45)) + 16|0);
       $150 = HEAP32[$149>>2]|0;
       $151 = ($148|0)==($150|0);
       if ($151) {
        $152 = HEAP32[$153>>2]|0;
        $154 = ((($152)) + 36|0);
        $155 = HEAP32[$154>>2]|0;
        __THREW__ = 0;
        $156 = (invoke_ii($155|0,($$pre$i$i$i45|0))|0);
        $157 = __THREW__; __THREW__ = 0;
        $158 = $157&1;
        if ($158) {
         break;
        } else {
         $$0$i$i$i$i43 = $156;
        }
       } else {
        $159 = HEAP8[$148>>0]|0;
        $160 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($159)|0);
        $$0$i$i$i$i43 = $160;
       }
       $161 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
       $162 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i$i$i43,$161)|0);
       if ($162) {
        HEAP32[$1>>2] = 0;
        $186 = 1;
       } else {
        $186 = 0;
       }
      }
      $163 = ($$pre$i4$i$i51|0)==(0|0);
      do {
       if ($163) {
        label = 54;
       } else {
        $164 = ((($$pre$i4$i$i51)) + 12|0);
        $165 = HEAP32[$164>>2]|0;
        $166 = ((($$pre$i4$i$i51)) + 16|0);
        $167 = HEAP32[$166>>2]|0;
        $168 = ($165|0)==($167|0);
        if ($168) {
         $169 = HEAP32[$$pre$i4$i$i51>>2]|0;
         $170 = ((($169)) + 36|0);
         $171 = HEAP32[$170>>2]|0;
         __THREW__ = 0;
         $172 = (invoke_ii($171|0,($$pre$i4$i$i51|0))|0);
         $173 = __THREW__; __THREW__ = 0;
         $174 = $173&1;
         if ($174) {
          break L50;
         } else {
          $$0$i$i2$i$i49 = $172;
         }
        } else {
         $175 = HEAP8[$165>>0]|0;
         $176 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($175)|0);
         $$0$i$i2$i$i49 = $176;
        }
        $177 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
        $178 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i2$i$i49,$177)|0);
        if ($178) {
         HEAP32[$2>>2] = 0;
         label = 54;
         break;
        } else {
         if ($186) {
          break;
         } else {
          label = 56;
          break;
         }
        }
       }
      } while(0);
      if ((label|0) == 54) {
       if ($186) {
        label = 56;
       }
      }
      if ((label|0) == 56) {
       $179 = HEAP32[$4>>2]|0;
       $180 = $179 | 2;
       HEAP32[$4>>2] = $180;
      }
      $$sroa$0$0$copyload = HEAP32[$1>>2]|0;
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($9);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($8);
      STACKTOP = sp;return ($$sroa$0$0$copyload|0);
     }
    }
   }
  } while(0);
  $181 = ___cxa_find_matching_catch_2()|0;
  $182 = tempRet0;
  $$1 = $181;$$127 = $182;
 }
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($9);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($8);
 ___resumeException($$1|0);
 // unreachable;
 return (0)|0;
}
function __ZNSt3__225__num_get_signed_integralIxEET_PKcS3_Rji($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $4 = sp;
 $5 = ($0|0)==($1|0);
 if ($5) {
  HEAP32[$2>>2] = 4;
  $26 = 0;$27 = 0;
 } else {
  $6 = (___errno_location()|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (___errno_location()|0);
  HEAP32[$8>>2] = 0;
  $9 = (__ZNSt3__26__clocEv()|0);
  $10 = (_strtoll_l($0,$4,$3,$9)|0);
  $11 = tempRet0;
  $12 = (___errno_location()|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($13|0)==(0);
  if ($14) {
   $15 = (___errno_location()|0);
   HEAP32[$15>>2] = $7;
  }
  $16 = HEAP32[$4>>2]|0;
  $17 = ($16|0)==($1|0);
  if ($17) {
   $18 = ($13|0)==(34);
   if ($18) {
    HEAP32[$2>>2] = 4;
    $19 = ($11|0)>(0);
    $20 = ($10>>>0)>(0);
    $21 = ($11|0)==(0);
    $22 = $21 & $20;
    $23 = $19 | $22;
    $24 = $23 ? -1 : 0;
    $25 = $23 ? 2147483647 : -2147483648;
    $28 = $24;$29 = $25;
   } else {
    $28 = $10;$29 = $11;
   }
  } else {
   HEAP32[$2>>2] = 4;
   $28 = 0;$29 = 0;
  }
  $26 = $29;$27 = $28;
 }
 tempRet0 = ($26);
 STACKTOP = sp;return ($27|0);
}
function __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE15__do_get_signedIlEES4_S4_S4_RNS_8ios_baseERjRT_($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$0$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i43 = 0, $$0$i$i2$i$i = 0, $$0$i$i2$i$i49 = 0, $$0$i$i39 = 0, $$024 = 0, $$1 = 0, $$125 = 0, $$127 = 0, $$2 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i45 = 0, $$pre$i4$i$i51 = 0, $$sroa$0$0$copyload = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0;
 var $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0;
 var $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0;
 var $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i$i = 0, $phitmp$i = 0, $phitmp$i34 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(224|0);
 $6 = sp + 198|0;
 $7 = sp + 196|0;
 $8 = sp + 184|0;
 $9 = sp + 172|0;
 $10 = sp + 168|0;
 $11 = sp + 8|0;
 $12 = sp + 4|0;
 $13 = sp;
 $14 = (__ZNSt3__214__num_get_base10__get_baseERNS_8ios_baseE($3)|0);
 __ZNSt3__29__num_getIcE17__stage2_int_prepERNS_8ios_baseEPcRc($8,$3,$6,$7);
 ;HEAP32[$9>>2]=0|0;HEAP32[$9+4>>2]=0|0;HEAP32[$9+8>>2]=0|0;
 $$0$i$i = 0;
 while(1) {
  $exitcond$i$i = ($$0$i$i|0)==(3);
  if ($exitcond$i$i) {
   break;
  }
  $15 = (($9) + ($$0$i$i<<2)|0);
  HEAP32[$15>>2] = 0;
  $16 = (($$0$i$i) + 1)|0;
  $$0$i$i = $16;
 }
 $17 = ((($9)) + 11|0);
 $18 = HEAP8[$17>>0]|0;
 $19 = ($18<<24>>24)<(0);
 if ($19) {
  $20 = ((($9)) + 8|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = $21 & 2147483647;
  $phitmp$i = (($22) + -1)|0;
  $23 = $phitmp$i;
 } else {
  $23 = 10;
 }
 __THREW__ = 0;
 invoke_viii(3434,($9|0),($23|0),0);
 $24 = __THREW__; __THREW__ = 0;
 $25 = $24&1;
 if ($25) {
  $88 = ___cxa_find_matching_catch_2()|0;
  $89 = tempRet0;
  $$1 = $88;$$127 = $89;
 } else {
  $26 = HEAP8[$17>>0]|0;
  $27 = ($26<<24>>24)<(0);
  $28 = HEAP32[$9>>2]|0;
  $29 = $27 ? $28 : $9;
  HEAP32[$10>>2] = $29;
  HEAP32[$12>>2] = $11;
  HEAP32[$13>>2] = 0;
  $30 = ((($9)) + 4|0);
  $31 = ((($9)) + 8|0);
  $$pre = HEAP32[$1>>2]|0;
  $$024 = $29;$$pre$i$i$i = $$pre;$178 = $$pre;
  L11: while(1) {
   $32 = ($$pre$i$i$i|0)==(0|0);
   if ($32) {
    $$pre$i$i$i45 = 0;$148 = 0;$179 = 1;
   } else {
    $33 = ((($$pre$i$i$i)) + 12|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = ((($$pre$i$i$i)) + 16|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = ($34|0)==($36|0);
    if ($37) {
     $38 = HEAP32[$$pre$i$i$i>>2]|0;
     $39 = ((($38)) + 36|0);
     $40 = HEAP32[$39>>2]|0;
     __THREW__ = 0;
     $41 = (invoke_ii($40|0,($$pre$i$i$i|0))|0);
     $42 = __THREW__; __THREW__ = 0;
     $43 = $42&1;
     if ($43) {
      break;
     } else {
      $$0$i$i$i$i = $41;
     }
    } else {
     $44 = HEAP8[$34>>0]|0;
     $45 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($44)|0);
     $$0$i$i$i$i = $45;
    }
    $46 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
    $47 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i$i$i,$46)|0);
    if ($47) {
     HEAP32[$1>>2] = 0;
     $$pre$i$i$i45 = 0;$148 = 0;$179 = 1;
    } else {
     $$pre$i$i$i45 = $$pre$i$i$i;$148 = $178;$179 = 0;
    }
   }
   $48 = HEAP32[$2>>2]|0;
   $49 = ($48|0)==(0|0);
   do {
    if ($49) {
     label = 20;
    } else {
     $50 = ((($48)) + 12|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = ((($48)) + 16|0);
     $53 = HEAP32[$52>>2]|0;
     $54 = ($51|0)==($53|0);
     if ($54) {
      $55 = HEAP32[$48>>2]|0;
      $56 = ((($55)) + 36|0);
      $57 = HEAP32[$56>>2]|0;
      __THREW__ = 0;
      $58 = (invoke_ii($57|0,($48|0))|0);
      $59 = __THREW__; __THREW__ = 0;
      $60 = $59&1;
      if ($60) {
       break L11;
      } else {
       $$0$i$i2$i$i = $58;
      }
     } else {
      $61 = HEAP8[$51>>0]|0;
      $62 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($61)|0);
      $$0$i$i2$i$i = $62;
     }
     $63 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
     $64 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i2$i$i,$63)|0);
     if ($64) {
      HEAP32[$2>>2] = 0;
      label = 20;
      break;
     } else {
      if ($179) {
       $180 = $48;
       break;
      } else {
       $$2 = $$024;$$pre$i4$i$i51 = $48;
       label = 37;
       break L11;
      }
     }
    }
   } while(0);
   if ((label|0) == 20) {
    label = 0;
    if ($179) {
     $$2 = $$024;$$pre$i4$i$i51 = 0;
     label = 37;
     break;
    } else {
     $180 = 0;
    }
   }
   $65 = HEAP32[$10>>2]|0;
   $66 = HEAP8[$17>>0]|0;
   $67 = ($66<<24>>24)<(0);
   $68 = HEAP32[$30>>2]|0;
   $69 = $66&255;
   $70 = $67 ? $68 : $69;
   $71 = (($$024) + ($70)|0);
   $72 = ($65|0)==($71|0);
   if ($72) {
    $73 = $70 << 1;
    __THREW__ = 0;
    invoke_viii(3434,($9|0),($73|0),0);
    $74 = __THREW__; __THREW__ = 0;
    $75 = $74&1;
    if ($75) {
     break;
    }
    $76 = HEAP8[$17>>0]|0;
    $77 = ($76<<24>>24)<(0);
    if ($77) {
     $78 = HEAP32[$31>>2]|0;
     $79 = $78 & 2147483647;
     $phitmp$i34 = (($79) + -1)|0;
     $80 = $phitmp$i34;
    } else {
     $80 = 10;
    }
    __THREW__ = 0;
    invoke_viii(3434,($9|0),($80|0),0);
    $81 = __THREW__; __THREW__ = 0;
    $82 = $81&1;
    if ($82) {
     break;
    }
    $83 = HEAP8[$17>>0]|0;
    $84 = ($83<<24>>24)<(0);
    $85 = HEAP32[$9>>2]|0;
    $86 = $84 ? $85 : $9;
    $87 = (($86) + ($70)|0);
    HEAP32[$10>>2] = $87;
    $$125 = $86;
   } else {
    $$125 = $$024;
   }
   $90 = ((($$pre$i$i$i45)) + 12|0);
   $91 = HEAP32[$90>>2]|0;
   $92 = ((($$pre$i$i$i45)) + 16|0);
   $93 = HEAP32[$92>>2]|0;
   $94 = ($91|0)==($93|0);
   if ($94) {
    $95 = HEAP32[$$pre$i$i$i45>>2]|0;
    $96 = ((($95)) + 36|0);
    $97 = HEAP32[$96>>2]|0;
    __THREW__ = 0;
    $98 = (invoke_ii($97|0,($$pre$i$i$i45|0))|0);
    $99 = __THREW__; __THREW__ = 0;
    $100 = $99&1;
    if ($100) {
     break;
    } else {
     $$0$i$i39 = $98;
    }
   } else {
    $101 = HEAP8[$91>>0]|0;
    $102 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($101)|0);
    $$0$i$i39 = $102;
   }
   $103 = $$0$i$i39&255;
   $104 = HEAP8[$7>>0]|0;
   __THREW__ = 0;
   $105 = (invoke_iiiiiiiiiii(4667,($103|0),($14|0),($$125|0),($10|0),($13|0),($104|0),($8|0),($11|0),($12|0),($6|0))|0);
   $106 = __THREW__; __THREW__ = 0;
   $107 = $106&1;
   if ($107) {
    break;
   }
   $108 = ($105|0)==(0);
   if (!($108)) {
    $$2 = $$125;$$pre$i4$i$i51 = $180;
    label = 37;
    break;
   }
   $109 = HEAP32[$90>>2]|0;
   $110 = HEAP32[$92>>2]|0;
   $111 = ($109|0)==($110|0);
   if ($111) {
    $112 = HEAP32[$$pre$i$i$i45>>2]|0;
    $113 = ((($112)) + 40|0);
    $114 = HEAP32[$113>>2]|0;
    __THREW__ = 0;
    (invoke_ii($114|0,($$pre$i$i$i45|0))|0);
    $115 = __THREW__; __THREW__ = 0;
    $116 = $115&1;
    if ($116) {
     break;
    } else {
     $$024 = $$125;$$pre$i$i$i = $$pre$i$i$i45;$178 = $148;
     continue;
    }
   } else {
    $117 = ((($109)) + 1|0);
    HEAP32[$90>>2] = $117;
    $118 = HEAP8[$109>>0]|0;
    (__ZNSt3__211char_traitsIcE11to_int_typeEc($118)|0);
    $$024 = $$125;$$pre$i$i$i = $$pre$i$i$i45;$178 = $148;
    continue;
   }
  }
  L50: do {
   if ((label|0) == 37) {
    $119 = ((($8)) + 11|0);
    $120 = HEAP8[$119>>0]|0;
    $121 = ($120<<24>>24)<(0);
    $122 = ((($8)) + 4|0);
    $123 = HEAP32[$122>>2]|0;
    $124 = $120&255;
    $125 = $121 ? $123 : $124;
    $126 = ($125|0)==(0);
    if (!($126)) {
     $127 = HEAP32[$12>>2]|0;
     $128 = $127;
     $129 = $11;
     $130 = (($128) - ($129))|0;
     $131 = ($130|0)<(160);
     if ($131) {
      $132 = HEAP32[$13>>2]|0;
      $133 = ((($127)) + 4|0);
      HEAP32[$12>>2] = $133;
      HEAP32[$127>>2] = $132;
     }
    }
    $134 = HEAP32[$10>>2]|0;
    __THREW__ = 0;
    $135 = (invoke_iiiii(4684,($$2|0),($134|0),($4|0),($14|0))|0);
    $136 = __THREW__; __THREW__ = 0;
    $137 = $136&1;
    if (!($137)) {
     HEAP32[$5>>2] = $135;
     $138 = HEAP32[$12>>2]|0;
     __THREW__ = 0;
     invoke_viiii(4676,($8|0),($11|0),($138|0),($4|0));
     $139 = __THREW__; __THREW__ = 0;
     $140 = $139&1;
     if (!($140)) {
      $141 = ($$pre$i$i$i45|0)==(0|0);
      if ($141) {
       $181 = 1;
      } else {
       $142 = ((($$pre$i$i$i45)) + 12|0);
       $143 = HEAP32[$142>>2]|0;
       $144 = ((($$pre$i$i$i45)) + 16|0);
       $145 = HEAP32[$144>>2]|0;
       $146 = ($143|0)==($145|0);
       if ($146) {
        $147 = HEAP32[$148>>2]|0;
        $149 = ((($147)) + 36|0);
        $150 = HEAP32[$149>>2]|0;
        __THREW__ = 0;
        $151 = (invoke_ii($150|0,($$pre$i$i$i45|0))|0);
        $152 = __THREW__; __THREW__ = 0;
        $153 = $152&1;
        if ($153) {
         break;
        } else {
         $$0$i$i$i$i43 = $151;
        }
       } else {
        $154 = HEAP8[$143>>0]|0;
        $155 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($154)|0);
        $$0$i$i$i$i43 = $155;
       }
       $156 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
       $157 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i$i$i43,$156)|0);
       if ($157) {
        HEAP32[$1>>2] = 0;
        $181 = 1;
       } else {
        $181 = 0;
       }
      }
      $158 = ($$pre$i4$i$i51|0)==(0|0);
      do {
       if ($158) {
        label = 54;
       } else {
        $159 = ((($$pre$i4$i$i51)) + 12|0);
        $160 = HEAP32[$159>>2]|0;
        $161 = ((($$pre$i4$i$i51)) + 16|0);
        $162 = HEAP32[$161>>2]|0;
        $163 = ($160|0)==($162|0);
        if ($163) {
         $164 = HEAP32[$$pre$i4$i$i51>>2]|0;
         $165 = ((($164)) + 36|0);
         $166 = HEAP32[$165>>2]|0;
         __THREW__ = 0;
         $167 = (invoke_ii($166|0,($$pre$i4$i$i51|0))|0);
         $168 = __THREW__; __THREW__ = 0;
         $169 = $168&1;
         if ($169) {
          break L50;
         } else {
          $$0$i$i2$i$i49 = $167;
         }
        } else {
         $170 = HEAP8[$160>>0]|0;
         $171 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($170)|0);
         $$0$i$i2$i$i49 = $171;
        }
        $172 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
        $173 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i2$i$i49,$172)|0);
        if ($173) {
         HEAP32[$2>>2] = 0;
         label = 54;
         break;
        } else {
         if ($181) {
          break;
         } else {
          label = 56;
          break;
         }
        }
       }
      } while(0);
      if ((label|0) == 54) {
       if ($181) {
        label = 56;
       }
      }
      if ((label|0) == 56) {
       $174 = HEAP32[$4>>2]|0;
       $175 = $174 | 2;
       HEAP32[$4>>2] = $175;
      }
      $$sroa$0$0$copyload = HEAP32[$1>>2]|0;
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($9);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($8);
      STACKTOP = sp;return ($$sroa$0$0$copyload|0);
     }
    }
   }
  } while(0);
  $176 = ___cxa_find_matching_catch_2()|0;
  $177 = tempRet0;
  $$1 = $176;$$127 = $177;
 }
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($9);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($8);
 ___resumeException($$1|0);
 // unreachable;
 return (0)|0;
}
function __ZNSt3__225__num_get_signed_integralIlEET_PKcS3_Rji($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $$1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $4 = sp;
 $5 = ($0|0)==($1|0);
 if ($5) {
  HEAP32[$2>>2] = 4;
  $$1 = 0;
 } else {
  $6 = (___errno_location()|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (___errno_location()|0);
  HEAP32[$8>>2] = 0;
  $9 = (__ZNSt3__26__clocEv()|0);
  $10 = (_strtoll_l($0,$4,$3,$9)|0);
  $11 = tempRet0;
  $12 = (___errno_location()|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($13|0)==(0);
  if ($14) {
   $15 = (___errno_location()|0);
   HEAP32[$15>>2] = $7;
  }
  $16 = HEAP32[$4>>2]|0;
  $17 = ($16|0)==($1|0);
  L7: do {
   if ($17) {
    $18 = ($13|0)==(34);
    do {
     if ($18) {
      HEAP32[$2>>2] = 4;
      $29 = ($11|0)>(0);
      $30 = ($10>>>0)>(0);
      $31 = ($11|0)==(0);
      $32 = $31 & $30;
      $33 = $29 | $32;
      if ($33) {
       $$0 = 2147483647;
       break L7;
      }
     } else {
      $19 = ($11|0)<(-1);
      $20 = ($10>>>0)<(2147483648);
      $21 = ($11|0)==(-1);
      $22 = $21 & $20;
      $23 = $19 | $22;
      if ($23) {
       HEAP32[$2>>2] = 4;
       break;
      }
      $24 = ($11|0)>(0);
      $25 = ($10>>>0)>(2147483647);
      $26 = ($11|0)==(0);
      $27 = $26 & $25;
      $28 = $24 | $27;
      if ($28) {
       HEAP32[$2>>2] = 4;
       $$0 = 2147483647;
       break L7;
      } else {
       $$0 = $10;
       break L7;
      }
     }
    } while(0);
    $$0 = -2147483648;
   } else {
    HEAP32[$2>>2] = 4;
    $$0 = 0;
   }
  } while(0);
  $$1 = $$0;
 }
 STACKTOP = sp;return ($$1|0);
}
function __ZNSt3__214__scan_keywordINS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEPKNS_12basic_stringIcS3_NS_9allocatorIcEEEENS_5ctypeIcEEEET0_RT_SE_SD_SD_RKT1_Rjb($0,$1,$2,$3,$4,$5,$6) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 var $$0 = 0, $$0$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i137 = 0, $$0$i$i2$i$i = 0, $$0$i$i2$i$i143 = 0, $$0100 = 0, $$0101 = 0, $$0102 = 0, $$0103 = 0, $$0106 = 0, $$0110 = 0, $$0126 = 0, $$0127 = 0, $$0127191 = 0, $$097 = 0, $$098 = 0, $$099$off0 = 0, $$1104 = 0, $$1107 = 0;
 var $$1111 = 0, $$2$off0 = 0, $$2105 = 0, $$2108 = 0, $$2112 = 0, $$3 = 0, $$3109 = 0, $$3113 = 0, $$5 = 0, $$5115 = 0, $$6 = 0, $$7 = 0, $$pre$i$i$i = 0, $$pre$i$i$i139 = 0, $$pre$i4$i$i145 = 0, $$sink134$sink135199$index = 0, $$sink134$sink135199$index5 = 0, $$sroa$0159$0 = 0, $10 = 0, $100 = 0;
 var $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0;
 var $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0;
 var $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0;
 var $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0;
 var $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0;
 var $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $phitmp$i$i$i = 0, $phitmp$i$i$i140 = 0, $tmp$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(112|0);
 $7 = sp;
 $8 = $3;
 $9 = $2;
 $10 = (($8) - ($9))|0;
 $11 = (($10|0) / 12)&-1;
 $12 = ($11>>>0)>(100);
 do {
  if ($12) {
   $13 = (_malloc($11)|0);
   $14 = ($13|0)==(0|0);
   if ($14) {
    __THREW__ = 0;
    invoke_v(4685);
    $15 = __THREW__; __THREW__ = 0;
    $16 = ___cxa_find_matching_catch_2()|0;
    $17 = tempRet0;
    $$sink134$sink135199$index = $16;$$sink134$sink135199$index5 = $17;
    break;
   } else {
    $18 = $13;
    $$0126 = $13;$$sroa$0159$0 = $18;
    label = 5;
    break;
   }
  } else {
   $$0126 = $7;$$sroa$0159$0 = 0;
   label = 5;
  }
 } while(0);
 if ((label|0) == 5) {
  $$0102 = $2;$$0103 = $$0126;$$0106 = 0;$$0110 = $11;
  while(1) {
   $19 = ($$0102|0)==($3|0);
   if ($19) {
    break;
   }
   $20 = ((($$0102)) + 11|0);
   $21 = HEAP8[$20>>0]|0;
   $22 = ($21<<24>>24)<(0);
   if ($22) {
    $23 = ((($$0102)) + 4|0);
    $24 = HEAP32[$23>>2]|0;
    $26 = $24;
   } else {
    $25 = $21&255;
    $26 = $25;
   }
   $27 = ($26|0)==(0);
   if ($27) {
    HEAP8[$$0103>>0] = 2;
    $28 = (($$0110) + -1)|0;
    $29 = (($$0106) + 1)|0;
    $$1107 = $29;$$1111 = $28;
   } else {
    HEAP8[$$0103>>0] = 1;
    $$1107 = $$0106;$$1111 = $$0110;
   }
   $30 = ((($$0102)) + 12|0);
   $31 = ((($$0103)) + 1|0);
   $$0102 = $30;$$0103 = $31;$$0106 = $$1107;$$0110 = $$1111;
  }
  $$0101 = 0;$$2108 = $$0106;$$2112 = $$0110;
  L20: while(1) {
   $32 = HEAP32[$0>>2]|0;
   $33 = ($32|0)==(0|0);
   do {
    if ($33) {
     $67 = 1;
    } else {
     $34 = ((($32)) + 12|0);
     $35 = HEAP32[$34>>2]|0;
     $36 = ((($32)) + 16|0);
     $37 = HEAP32[$36>>2]|0;
     $38 = ($35|0)==($37|0);
     if ($38) {
      $39 = HEAP32[$32>>2]|0;
      $40 = ((($39)) + 36|0);
      $41 = HEAP32[$40>>2]|0;
      __THREW__ = 0;
      $42 = (invoke_ii($41|0,($32|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       break L20;
      } else {
       $$0$i$i$i$i = $42;
      }
     } else {
      $45 = HEAP8[$35>>0]|0;
      $46 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($45)|0);
      $$0$i$i$i$i = $46;
     }
     $47 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
     $48 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i$i$i,$47)|0);
     if ($48) {
      HEAP32[$0>>2] = 0;
      $67 = 1;
      break;
     } else {
      $$pre$i$i$i = HEAP32[$0>>2]|0;
      $phitmp$i$i$i = ($$pre$i$i$i|0)==(0|0);
      $67 = $phitmp$i$i$i;
      break;
     }
    }
   } while(0);
   $49 = HEAP32[$1>>2]|0;
   $50 = ($49|0)==(0|0);
   if ($50) {
    $$pre$i4$i$i145 = 0;$66 = 1;
   } else {
    $51 = ((($49)) + 12|0);
    $52 = HEAP32[$51>>2]|0;
    $53 = ((($49)) + 16|0);
    $54 = HEAP32[$53>>2]|0;
    $55 = ($52|0)==($54|0);
    if ($55) {
     $56 = HEAP32[$49>>2]|0;
     $57 = ((($56)) + 36|0);
     $58 = HEAP32[$57>>2]|0;
     __THREW__ = 0;
     $59 = (invoke_ii($58|0,($49|0))|0);
     $60 = __THREW__; __THREW__ = 0;
     $61 = $60&1;
     if ($61) {
      break;
     } else {
      $$0$i$i2$i$i = $59;
     }
    } else {
     $62 = HEAP8[$52>>0]|0;
     $63 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($62)|0);
     $$0$i$i2$i$i = $63;
    }
    $64 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
    $65 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i2$i$i,$64)|0);
    if ($65) {
     HEAP32[$1>>2] = 0;
     $$pre$i4$i$i145 = 0;$66 = 1;
    } else {
     $$pre$i4$i$i145 = $49;$66 = 0;
    }
   }
   $tmp$i$i = $67 ^ $66;
   $68 = ($$2112|0)!=(0);
   $69 = $68 & $tmp$i$i;
   $70 = HEAP32[$0>>2]|0;
   if (!($69)) {
    label = 29;
    break;
   }
   $103 = ((($70)) + 12|0);
   $104 = HEAP32[$103>>2]|0;
   $105 = ((($70)) + 16|0);
   $106 = HEAP32[$105>>2]|0;
   $107 = ($104|0)==($106|0);
   if ($107) {
    $108 = HEAP32[$70>>2]|0;
    $109 = ((($108)) + 36|0);
    $110 = HEAP32[$109>>2]|0;
    __THREW__ = 0;
    $111 = (invoke_ii($110|0,($70|0))|0);
    $112 = __THREW__; __THREW__ = 0;
    $113 = $112&1;
    if ($113) {
     break;
    } else {
     $$0$i$i = $111;
    }
   } else {
    $114 = HEAP8[$104>>0]|0;
    $115 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($114)|0);
    $$0$i$i = $115;
   }
   $116 = $$0$i$i&255;
   if ($6) {
    $$0100 = $116;
   } else {
    $117 = HEAP32[$4>>2]|0;
    $118 = ((($117)) + 12|0);
    $119 = HEAP32[$118>>2]|0;
    __THREW__ = 0;
    $120 = (invoke_iii($119|0,($4|0),($116|0))|0);
    $121 = __THREW__; __THREW__ = 0;
    $122 = $121&1;
    if ($122) {
     break;
    } else {
     $$0100 = $120;
    }
   }
   $123 = (($$0101) + 1)|0;
   $$098 = $2;$$099$off0 = 0;$$1104 = $$0126;$$3109 = $$2108;$$3113 = $$2112;
   while(1) {
    $124 = ($$098|0)==($3|0);
    if ($124) {
     break;
    }
    $125 = HEAP8[$$1104>>0]|0;
    $126 = ($125<<24>>24)==(1);
    do {
     if ($126) {
      $127 = ((($$098)) + 11|0);
      $128 = HEAP8[$127>>0]|0;
      $129 = ($128<<24>>24)<(0);
      if ($129) {
       $130 = HEAP32[$$098>>2]|0;
       $132 = $130;
      } else {
       $132 = $$098;
      }
      $131 = (($132) + ($$0101)|0);
      $133 = HEAP8[$131>>0]|0;
      if ($6) {
       $$097 = $133;
      } else {
       $134 = HEAP32[$4>>2]|0;
       $135 = ((($134)) + 12|0);
       $136 = HEAP32[$135>>2]|0;
       __THREW__ = 0;
       $137 = (invoke_iii($136|0,($4|0),($133|0))|0);
       $138 = __THREW__; __THREW__ = 0;
       $139 = $138&1;
       if ($139) {
        break L20;
       } else {
        $$097 = $137;
       }
      }
      $140 = ($$0100<<24>>24)==($$097<<24>>24);
      $141 = (($$3113) + -1)|0;
      if (!($140)) {
       HEAP8[$$1104>>0] = 0;
       $$2$off0 = $$099$off0;$$5 = $$3109;$$5115 = $141;
       break;
      }
      $142 = HEAP8[$127>>0]|0;
      $143 = ($142<<24>>24)<(0);
      if ($143) {
       $144 = ((($$098)) + 4|0);
       $145 = HEAP32[$144>>2]|0;
       $147 = $145;
      } else {
       $146 = $142&255;
       $147 = $146;
      }
      $148 = ($147|0)==($123|0);
      if ($148) {
       $149 = (($$3109) + 1)|0;
       HEAP8[$$1104>>0] = 2;
       $$2$off0 = 1;$$5 = $149;$$5115 = $141;
      } else {
       $$2$off0 = 1;$$5 = $$3109;$$5115 = $$3113;
      }
     } else {
      $$2$off0 = $$099$off0;$$5 = $$3109;$$5115 = $$3113;
     }
    } while(0);
    $150 = ((($$098)) + 12|0);
    $151 = ((($$1104)) + 1|0);
    $$098 = $150;$$099$off0 = $$2$off0;$$1104 = $151;$$3109 = $$5;$$3113 = $$5115;
   }
   if (!($$099$off0)) {
    $$0101 = $123;$$2108 = $$3109;$$2112 = $$3113;
    continue;
   }
   $152 = HEAP32[$0>>2]|0;
   $153 = ((($152)) + 12|0);
   $154 = HEAP32[$153>>2]|0;
   $155 = ((($152)) + 16|0);
   $156 = HEAP32[$155>>2]|0;
   $157 = ($154|0)==($156|0);
   if ($157) {
    $158 = HEAP32[$152>>2]|0;
    $159 = ((($158)) + 40|0);
    $160 = HEAP32[$159>>2]|0;
    __THREW__ = 0;
    (invoke_ii($160|0,($152|0))|0);
    $161 = __THREW__; __THREW__ = 0;
    $162 = $161&1;
    if ($162) {
     break;
    }
   } else {
    $163 = ((($154)) + 1|0);
    HEAP32[$153>>2] = $163;
    $164 = HEAP8[$154>>0]|0;
    (__ZNSt3__211char_traitsIcE11to_int_typeEc($164)|0);
   }
   $165 = (($$3109) + ($$3113))|0;
   $166 = ($165>>>0)>(1);
   if ($166) {
    $$0 = $2;$$2105 = $$0126;$$6 = $$3109;
   } else {
    $$0101 = $123;$$2108 = $$3109;$$2112 = $$3113;
    continue;
   }
   while(1) {
    $167 = ($$0|0)==($3|0);
    if ($167) {
     $$0101 = $123;$$2108 = $$6;$$2112 = $$3113;
     continue L20;
    }
    $168 = HEAP8[$$2105>>0]|0;
    $169 = ($168<<24>>24)==(2);
    if ($169) {
     $170 = ((($$0)) + 11|0);
     $171 = HEAP8[$170>>0]|0;
     $172 = ($171<<24>>24)<(0);
     if ($172) {
      $173 = ((($$0)) + 4|0);
      $174 = HEAP32[$173>>2]|0;
      $176 = $174;
     } else {
      $175 = $171&255;
      $176 = $175;
     }
     $177 = ($176|0)==($123|0);
     if ($177) {
      $$7 = $$6;
     } else {
      $178 = (($$6) + -1)|0;
      HEAP8[$$2105>>0] = 0;
      $$7 = $178;
     }
    } else {
     $$7 = $$6;
    }
    $179 = ((($$0)) + 12|0);
    $180 = ((($$2105)) + 1|0);
    $$0 = $179;$$2105 = $180;$$6 = $$7;
   }
  }
  L86: do {
   if ((label|0) == 29) {
    $71 = ($70|0)==(0|0);
    do {
     if ($71) {
      $196 = 1;
     } else {
      $72 = ((($70)) + 12|0);
      $73 = HEAP32[$72>>2]|0;
      $74 = ((($70)) + 16|0);
      $75 = HEAP32[$74>>2]|0;
      $76 = ($73|0)==($75|0);
      if ($76) {
       $77 = HEAP32[$70>>2]|0;
       $78 = ((($77)) + 36|0);
       $79 = HEAP32[$78>>2]|0;
       __THREW__ = 0;
       $80 = (invoke_ii($79|0,($70|0))|0);
       $81 = __THREW__; __THREW__ = 0;
       $82 = $81&1;
       if ($82) {
        break L86;
       } else {
        $$0$i$i$i$i137 = $80;
       }
      } else {
       $83 = HEAP8[$73>>0]|0;
       $84 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($83)|0);
       $$0$i$i$i$i137 = $84;
      }
      $85 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
      $86 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i$i$i137,$85)|0);
      if ($86) {
       HEAP32[$0>>2] = 0;
       $196 = 1;
       break;
      } else {
       $$pre$i$i$i139 = HEAP32[$0>>2]|0;
       $phitmp$i$i$i140 = ($$pre$i$i$i139|0)==(0|0);
       $196 = $phitmp$i$i$i140;
       break;
      }
     }
    } while(0);
    $87 = ($$pre$i4$i$i145|0)==(0|0);
    do {
     if ($87) {
      label = 76;
     } else {
      $88 = ((($$pre$i4$i$i145)) + 12|0);
      $89 = HEAP32[$88>>2]|0;
      $90 = ((($$pre$i4$i$i145)) + 16|0);
      $91 = HEAP32[$90>>2]|0;
      $92 = ($89|0)==($91|0);
      if ($92) {
       $93 = HEAP32[$$pre$i4$i$i145>>2]|0;
       $94 = ((($93)) + 36|0);
       $95 = HEAP32[$94>>2]|0;
       __THREW__ = 0;
       $96 = (invoke_ii($95|0,($$pre$i4$i$i145|0))|0);
       $97 = __THREW__; __THREW__ = 0;
       $98 = $97&1;
       if ($98) {
        break L86;
       } else {
        $$0$i$i2$i$i143 = $96;
       }
      } else {
       $99 = HEAP8[$89>>0]|0;
       $100 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($99)|0);
       $$0$i$i2$i$i143 = $100;
      }
      $101 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
      $102 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i2$i$i143,$101)|0);
      if ($102) {
       HEAP32[$1>>2] = 0;
       label = 76;
       break;
      } else {
       if ($196) {
        $$0127 = $2;$$3 = $$0126;
        break;
       } else {
        label = 78;
        break;
       }
      }
     }
    } while(0);
    if ((label|0) == 76) {
     if ($196) {
      label = 78;
     } else {
      $$0127 = $2;$$3 = $$0126;
     }
    }
    if ((label|0) == 78) {
     $181 = HEAP32[$5>>2]|0;
     $182 = $181 | 2;
     HEAP32[$5>>2] = $182;
     $$0127 = $2;$$3 = $$0126;
    }
    while(1) {
     $183 = ($$0127|0)==($3|0);
     if ($183) {
      label = 82;
      break;
     }
     $184 = HEAP8[$$3>>0]|0;
     $185 = ($184<<24>>24)==(2);
     if ($185) {
      $$0127191 = $$0127;
      break;
     }
     $186 = ((($$0127)) + 12|0);
     $187 = ((($$3)) + 1|0);
     $$0127 = $186;$$3 = $187;
    }
    if ((label|0) == 82) {
     $188 = HEAP32[$5>>2]|0;
     $189 = $188 | 4;
     HEAP32[$5>>2] = $189;
     $$0127191 = $3;
    }
    $190 = ($$sroa$0159$0|0)==(0);
    if (!($190)) {
     $191 = $$sroa$0159$0;
     _free($191);
    }
    STACKTOP = sp;return ($$0127191|0);
   }
  } while(0);
  $192 = ___cxa_find_matching_catch_2()|0;
  $193 = tempRet0;
  $194 = ($$sroa$0159$0|0)==(0);
  if ($194) {
   $$sink134$sink135199$index = $192;$$sink134$sink135199$index5 = $193;
  } else {
   $195 = $$sroa$0159$0;
   _free($195);
   $$sink134$sink135199$index = $192;$$sink134$sink135199$index5 = $193;
  }
 }
 ___resumeException($$sink134$sink135199$index|0);
 // unreachable;
 return (0)|0;
}
function __ZNSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEED2Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__26locale5facetD2Ev($0);
 return;
}
function __ZNSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEED0Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__26locale5facetD2Ev($0);
 __ZdlPv($0);
 return;
}
function __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRb($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$2 = 0, $$232 = 0, $$byval_copy = 0, $$byval_copy1 = 0, $$byval_copy2 = 0, $$ptr = 0, $$sroa$026$0 = 0, $$sroa$026$0$copyload = 0, $$sroa$026$0$copyload28 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(64|0);
 $$byval_copy2 = sp + 60|0;
 $$byval_copy1 = sp + 56|0;
 $$byval_copy = sp + 52|0;
 $6 = sp + 48|0;
 $7 = sp + 44|0;
 $8 = sp + 40|0;
 $9 = sp + 36|0;
 $10 = sp + 32|0;
 $11 = sp + 8|0;
 $12 = sp;
 $13 = ((($3)) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $14 & 1;
 $16 = ($15|0)==(0);
 L1: do {
  if ($16) {
   HEAP32[$6>>2] = -1;
   $17 = HEAP32[$0>>2]|0;
   $18 = ((($17)) + 16|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = HEAP32[$1>>2]|0;
   HEAP32[$7>>2] = $20;
   $21 = HEAP32[$2>>2]|0;
   HEAP32[$8>>2] = $21;
   ;HEAP32[$$byval_copy>>2]=HEAP32[$7>>2]|0;
   ;HEAP32[$$byval_copy1>>2]=HEAP32[$8>>2]|0;
   $22 = (FUNCTION_TABLE_iiiiiii[$19 & 8191]($0,$$byval_copy,$$byval_copy1,$3,$4,$6)|0);
   HEAP32[$1>>2] = $22;
   $23 = HEAP32[$6>>2]|0;
   switch ($23|0) {
   case 0:  {
    HEAP8[$5>>0] = 0;
    break;
   }
   case 1:  {
    HEAP8[$5>>0] = 1;
    break;
   }
   default: {
    HEAP8[$5>>0] = 1;
    HEAP32[$4>>2] = 4;
   }
   }
   $$sroa$026$0$copyload = HEAP32[$1>>2]|0;
   $$sroa$026$0 = $$sroa$026$0$copyload;
  } else {
   __ZNKSt3__28ios_base6getlocEv($9,$3);
   __THREW__ = 0;
   $24 = (invoke_iii(3255,($9|0),(215220|0))|0);
   $25 = __THREW__; __THREW__ = 0;
   $26 = $25&1;
   do {
    if ($26) {
     $49 = ___cxa_find_matching_catch_2()|0;
     $50 = tempRet0;
     __ZNSt3__26localeD2Ev($9);
     $$2 = $49;$$232 = $50;
    } else {
     __ZNSt3__26localeD2Ev($9);
     __ZNKSt3__28ios_base6getlocEv($10,$3);
     __THREW__ = 0;
     $27 = (invoke_iii(3255,($10|0),(215228|0))|0);
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      $51 = ___cxa_find_matching_catch_2()|0;
      $52 = tempRet0;
      __ZNSt3__26localeD2Ev($10);
      $$2 = $51;$$232 = $52;
      break;
     }
     __ZNSt3__26localeD2Ev($10);
     $30 = HEAP32[$27>>2]|0;
     $31 = ((($30)) + 24|0);
     $32 = HEAP32[$31>>2]|0;
     __THREW__ = 0;
     invoke_vii($32|0,($11|0),($27|0));
     $33 = __THREW__; __THREW__ = 0;
     $34 = $33&1;
     if ($34) {
      $35 = ___cxa_find_matching_catch_2()|0;
      $36 = tempRet0;
      $$2 = $35;$$232 = $36;
      break;
     }
     $$ptr = ((($11)) + 12|0);
     $37 = HEAP32[$27>>2]|0;
     $38 = ((($37)) + 28|0);
     $39 = HEAP32[$38>>2]|0;
     __THREW__ = 0;
     invoke_vii($39|0,($$ptr|0),($27|0));
     $40 = __THREW__; __THREW__ = 0;
     $41 = $40&1;
     if ($41) {
      $61 = ___cxa_find_matching_catch_2()|0;
      $62 = tempRet0;
      __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev($11);
      $$2 = $61;$$232 = $62;
      break;
     }
     $42 = HEAP32[$2>>2]|0;
     HEAP32[$12>>2] = $42;
     $43 = ((($11)) + 24|0);
     __THREW__ = 0;
     ;HEAP32[$$byval_copy2>>2]=HEAP32[$12>>2]|0;
     $44 = (invoke_iiiiiiii(4686,($1|0),($$byval_copy2|0),($11|0),($43|0),($24|0),($4|0),1)|0);
     $45 = __THREW__; __THREW__ = 0;
     $46 = $45&1;
     if ($46) {
      $53 = ___cxa_find_matching_catch_2()|0;
      $54 = tempRet0;
      $59 = $43;
      while(1) {
       $58 = ((($59)) + -12|0);
       __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev($58);
       $60 = ($58|0)==($11|0);
       if ($60) {
        break;
       } else {
        $59 = $58;
       }
      }
      $$2 = $53;$$232 = $54;
      break;
     } else {
      $47 = ($44|0)==($11|0);
      $48 = $47&1;
      HEAP8[$5>>0] = $48;
      $$sroa$026$0$copyload28 = HEAP32[$1>>2]|0;
      $56 = $43;
      while(1) {
       $55 = ((($56)) + -12|0);
       __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev($55);
       $57 = ($55|0)==($11|0);
       if ($57) {
        break;
       } else {
        $56 = $55;
       }
      }
      $$sroa$026$0 = $$sroa$026$0$copyload28;
      break L1;
     }
    }
   } while(0);
   ___resumeException($$2|0);
   // unreachable;
  }
 } while(0);
 STACKTOP = sp;return ($$sroa$026$0|0);
}
function __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRl($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $10 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy1 = sp + 12|0;
 $$byval_copy = sp + 8|0;
 $6 = sp + 4|0;
 $7 = sp;
 $8 = HEAP32[$1>>2]|0;
 HEAP32[$6>>2] = $8;
 $9 = HEAP32[$2>>2]|0;
 HEAP32[$7>>2] = $9;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$6>>2]|0;
 ;HEAP32[$$byval_copy1>>2]=HEAP32[$7>>2]|0;
 $10 = (__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE15__do_get_signedIlEES4_S4_S4_RNS_8ios_baseERjRT_($0,$$byval_copy,$$byval_copy1,$3,$4,$5)|0);
 STACKTOP = sp;return ($10|0);
}
function __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRx($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $10 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy1 = sp + 12|0;
 $$byval_copy = sp + 8|0;
 $6 = sp + 4|0;
 $7 = sp;
 $8 = HEAP32[$1>>2]|0;
 HEAP32[$6>>2] = $8;
 $9 = HEAP32[$2>>2]|0;
 HEAP32[$7>>2] = $9;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$6>>2]|0;
 ;HEAP32[$$byval_copy1>>2]=HEAP32[$7>>2]|0;
 $10 = (__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE15__do_get_signedIxEES4_S4_S4_RNS_8ios_baseERjRT_($0,$$byval_copy,$$byval_copy1,$3,$4,$5)|0);
 STACKTOP = sp;return ($10|0);
}
function __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRt($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $10 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy1 = sp + 12|0;
 $$byval_copy = sp + 8|0;
 $6 = sp + 4|0;
 $7 = sp;
 $8 = HEAP32[$1>>2]|0;
 HEAP32[$6>>2] = $8;
 $9 = HEAP32[$2>>2]|0;
 HEAP32[$7>>2] = $9;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$6>>2]|0;
 ;HEAP32[$$byval_copy1>>2]=HEAP32[$7>>2]|0;
 $10 = (__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE17__do_get_unsignedItEES4_S4_S4_RNS_8ios_baseERjRT_($0,$$byval_copy,$$byval_copy1,$3,$4,$5)|0);
 STACKTOP = sp;return ($10|0);
}
function __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjS8_($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $10 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy1 = sp + 12|0;
 $$byval_copy = sp + 8|0;
 $6 = sp + 4|0;
 $7 = sp;
 $8 = HEAP32[$1>>2]|0;
 HEAP32[$6>>2] = $8;
 $9 = HEAP32[$2>>2]|0;
 HEAP32[$7>>2] = $9;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$6>>2]|0;
 ;HEAP32[$$byval_copy1>>2]=HEAP32[$7>>2]|0;
 $10 = (__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE17__do_get_unsignedIjEES4_S4_S4_RNS_8ios_baseERjRT_($0,$$byval_copy,$$byval_copy1,$3,$4,$5)|0);
 STACKTOP = sp;return ($10|0);
}
function __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRm($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $10 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy1 = sp + 12|0;
 $$byval_copy = sp + 8|0;
 $6 = sp + 4|0;
 $7 = sp;
 $8 = HEAP32[$1>>2]|0;
 HEAP32[$6>>2] = $8;
 $9 = HEAP32[$2>>2]|0;
 HEAP32[$7>>2] = $9;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$6>>2]|0;
 ;HEAP32[$$byval_copy1>>2]=HEAP32[$7>>2]|0;
 $10 = (__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE17__do_get_unsignedImEES4_S4_S4_RNS_8ios_baseERjRT_($0,$$byval_copy,$$byval_copy1,$3,$4,$5)|0);
 STACKTOP = sp;return ($10|0);
}
function __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRy($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $10 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy1 = sp + 12|0;
 $$byval_copy = sp + 8|0;
 $6 = sp + 4|0;
 $7 = sp;
 $8 = HEAP32[$1>>2]|0;
 HEAP32[$6>>2] = $8;
 $9 = HEAP32[$2>>2]|0;
 HEAP32[$7>>2] = $9;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$6>>2]|0;
 ;HEAP32[$$byval_copy1>>2]=HEAP32[$7>>2]|0;
 $10 = (__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE17__do_get_unsignedIyEES4_S4_S4_RNS_8ios_baseERjRT_($0,$$byval_copy,$$byval_copy1,$3,$4,$5)|0);
 STACKTOP = sp;return ($10|0);
}
function __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRf($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $10 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy1 = sp + 12|0;
 $$byval_copy = sp + 8|0;
 $6 = sp + 4|0;
 $7 = sp;
 $8 = HEAP32[$1>>2]|0;
 HEAP32[$6>>2] = $8;
 $9 = HEAP32[$2>>2]|0;
 HEAP32[$7>>2] = $9;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$6>>2]|0;
 ;HEAP32[$$byval_copy1>>2]=HEAP32[$7>>2]|0;
 $10 = (__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE23__do_get_floating_pointIfEES4_S4_S4_RNS_8ios_baseERjRT_($0,$$byval_copy,$$byval_copy1,$3,$4,$5)|0);
 STACKTOP = sp;return ($10|0);
}
function __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRd($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $10 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy1 = sp + 12|0;
 $$byval_copy = sp + 8|0;
 $6 = sp + 4|0;
 $7 = sp;
 $8 = HEAP32[$1>>2]|0;
 HEAP32[$6>>2] = $8;
 $9 = HEAP32[$2>>2]|0;
 HEAP32[$7>>2] = $9;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$6>>2]|0;
 ;HEAP32[$$byval_copy1>>2]=HEAP32[$7>>2]|0;
 $10 = (__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE23__do_get_floating_pointIdEES4_S4_S4_RNS_8ios_baseERjRT_($0,$$byval_copy,$$byval_copy1,$3,$4,$5)|0);
 STACKTOP = sp;return ($10|0);
}
function __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRe($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $10 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy1 = sp + 12|0;
 $$byval_copy = sp + 8|0;
 $6 = sp + 4|0;
 $7 = sp;
 $8 = HEAP32[$1>>2]|0;
 HEAP32[$6>>2] = $8;
 $9 = HEAP32[$2>>2]|0;
 HEAP32[$7>>2] = $9;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$6>>2]|0;
 ;HEAP32[$$byval_copy1>>2]=HEAP32[$7>>2]|0;
 $10 = (__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE23__do_get_floating_pointIeEES4_S4_S4_RNS_8ios_baseERjRT_($0,$$byval_copy,$$byval_copy1,$3,$4,$5)|0);
 STACKTOP = sp;return ($10|0);
}
function __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRPv($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$0 = 0, $$0$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i51 = 0, $$0$i$i2$i$i = 0, $$0$i$i2$i$i57 = 0, $$0$i$i33 = 0, $$0$i$i46 = 0, $$025 = 0, $$028 = 0, $$126 = 0, $$2 = 0, $$227 = 0, $$230 = 0, $$3 = 0, $$331 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i53 = 0, $$pre$i4$i$i59 = 0;
 var $$sroa$0$0$copyload = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0;
 var $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0;
 var $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0;
 var $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0;
 var $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $19 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i$i = 0, $exitcond$i$i34 = 0, $phitmp$i = 0, $phitmp$i41 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 320|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(320|0);
 $vararg_buffer = sp;
 $6 = sp + 208|0;
 $7 = sp + 196|0;
 $8 = sp + 192|0;
 $9 = sp + 180|0;
 $10 = sp + 176|0;
 $11 = sp + 16|0;
 $12 = sp + 8|0;
 $13 = sp + 4|0;
 ;HEAP32[$7>>2]=0|0;HEAP32[$7+4>>2]=0|0;HEAP32[$7+8>>2]=0|0;
 $$0$i$i = 0;
 while(1) {
  $exitcond$i$i = ($$0$i$i|0)==(3);
  if ($exitcond$i$i) {
   break;
  }
  $14 = (($7) + ($$0$i$i<<2)|0);
  HEAP32[$14>>2] = 0;
  $15 = (($$0$i$i) + 1)|0;
  $$0$i$i = $15;
 }
 __THREW__ = 0;
 invoke_vii(3257,($8|0),($3|0));
 $16 = __THREW__; __THREW__ = 0;
 $17 = $16&1;
 do {
  if ($17) {
   $99 = ___cxa_find_matching_catch_2()|0;
   $100 = tempRet0;
   $$0 = $99;$$028 = $100;
   label = 36;
  } else {
   __THREW__ = 0;
   $18 = (invoke_iii(3255,($8|0),(215220|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    $21 = HEAP32[$18>>2]|0;
    $22 = ((($21)) + 48|0);
    $23 = HEAP32[$22>>2]|0;
    __THREW__ = 0;
    (invoke_iiiii($23|0,($18|0),(202614|0),((202640)|0),($6|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     __ZNSt3__26localeD2Ev($8);
     ;HEAP32[$9>>2]=0|0;HEAP32[$9+4>>2]=0|0;HEAP32[$9+8>>2]=0|0;
     $$0$i$i33 = 0;
     while(1) {
      $exitcond$i$i34 = ($$0$i$i33|0)==(3);
      if ($exitcond$i$i34) {
       break;
      }
      $26 = (($9) + ($$0$i$i33<<2)|0);
      HEAP32[$26>>2] = 0;
      $27 = (($$0$i$i33) + 1)|0;
      $$0$i$i33 = $27;
     }
     $28 = ((($9)) + 11|0);
     $29 = HEAP8[$28>>0]|0;
     $30 = ($29<<24>>24)<(0);
     if ($30) {
      $31 = ((($9)) + 8|0);
      $32 = HEAP32[$31>>2]|0;
      $33 = $32 & 2147483647;
      $phitmp$i = (($33) + -1)|0;
      $34 = $phitmp$i;
     } else {
      $34 = 10;
     }
     __THREW__ = 0;
     invoke_viii(3434,($9|0),($34|0),0);
     $35 = __THREW__; __THREW__ = 0;
     $36 = $35&1;
     if ($36) {
      $103 = ___cxa_find_matching_catch_2()|0;
      $104 = tempRet0;
      $$2 = $103;$$230 = $104;
     } else {
      $37 = HEAP8[$28>>0]|0;
      $38 = ($37<<24>>24)<(0);
      $39 = HEAP32[$9>>2]|0;
      $40 = $38 ? $39 : $9;
      HEAP32[$10>>2] = $40;
      HEAP32[$12>>2] = $11;
      HEAP32[$13>>2] = 0;
      $41 = ((($9)) + 4|0);
      $42 = ((($9)) + 8|0);
      $$pre = HEAP32[$1>>2]|0;
      $$025 = $40;$$pre$i$i$i = $$pre;$185 = $$pre;
      L21: while(1) {
       $43 = ($$pre$i$i$i|0)==(0|0);
       if ($43) {
        $$pre$i$i$i53 = 0;$155 = 0;$186 = 1;
       } else {
        $44 = ((($$pre$i$i$i)) + 12|0);
        $45 = HEAP32[$44>>2]|0;
        $46 = ((($$pre$i$i$i)) + 16|0);
        $47 = HEAP32[$46>>2]|0;
        $48 = ($45|0)==($47|0);
        if ($48) {
         $49 = HEAP32[$$pre$i$i$i>>2]|0;
         $50 = ((($49)) + 36|0);
         $51 = HEAP32[$50>>2]|0;
         __THREW__ = 0;
         $52 = (invoke_ii($51|0,($$pre$i$i$i|0))|0);
         $53 = __THREW__; __THREW__ = 0;
         $54 = $53&1;
         if ($54) {
          break;
         } else {
          $$0$i$i$i$i = $52;
         }
        } else {
         $55 = HEAP32[$45>>2]|0;
         $56 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($55)|0);
         $$0$i$i$i$i = $56;
        }
        $57 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
        $58 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i$i$i,$57)|0);
        if ($58) {
         HEAP32[$1>>2] = 0;
         $$pre$i$i$i53 = 0;$155 = 0;$186 = 1;
        } else {
         $$pre$i$i$i53 = $$pre$i$i$i;$155 = $185;$186 = 0;
        }
       }
       $59 = HEAP32[$2>>2]|0;
       $60 = ($59|0)==(0|0);
       do {
        if ($60) {
         label = 26;
        } else {
         $61 = ((($59)) + 12|0);
         $62 = HEAP32[$61>>2]|0;
         $63 = ((($59)) + 16|0);
         $64 = HEAP32[$63>>2]|0;
         $65 = ($62|0)==($64|0);
         if ($65) {
          $66 = HEAP32[$59>>2]|0;
          $67 = ((($66)) + 36|0);
          $68 = HEAP32[$67>>2]|0;
          __THREW__ = 0;
          $69 = (invoke_ii($68|0,($59|0))|0);
          $70 = __THREW__; __THREW__ = 0;
          $71 = $70&1;
          if ($71) {
           break L21;
          } else {
           $$0$i$i2$i$i = $69;
          }
         } else {
          $72 = HEAP32[$62>>2]|0;
          $73 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($72)|0);
          $$0$i$i2$i$i = $73;
         }
         $74 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
         $75 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i2$i$i,$74)|0);
         if ($75) {
          HEAP32[$2>>2] = 0;
          label = 26;
          break;
         } else {
          if ($186) {
           $187 = $59;
           break;
          } else {
           $$227 = $$025;$$pre$i4$i$i59 = $59;
           label = 46;
           break L21;
          }
         }
        }
       } while(0);
       if ((label|0) == 26) {
        label = 0;
        if ($186) {
         $$227 = $$025;$$pre$i4$i$i59 = 0;
         label = 46;
         break;
        } else {
         $187 = 0;
        }
       }
       $76 = HEAP32[$10>>2]|0;
       $77 = HEAP8[$28>>0]|0;
       $78 = ($77<<24>>24)<(0);
       $79 = HEAP32[$41>>2]|0;
       $80 = $77&255;
       $81 = $78 ? $79 : $80;
       $82 = (($$025) + ($81)|0);
       $83 = ($76|0)==($82|0);
       if ($83) {
        $84 = $81 << 1;
        __THREW__ = 0;
        invoke_viii(3434,($9|0),($84|0),0);
        $85 = __THREW__; __THREW__ = 0;
        $86 = $85&1;
        if ($86) {
         break;
        }
        $87 = HEAP8[$28>>0]|0;
        $88 = ($87<<24>>24)<(0);
        if ($88) {
         $89 = HEAP32[$42>>2]|0;
         $90 = $89 & 2147483647;
         $phitmp$i41 = (($90) + -1)|0;
         $91 = $phitmp$i41;
        } else {
         $91 = 10;
        }
        __THREW__ = 0;
        invoke_viii(3434,($9|0),($91|0),0);
        $92 = __THREW__; __THREW__ = 0;
        $93 = $92&1;
        if ($93) {
         break;
        }
        $94 = HEAP8[$28>>0]|0;
        $95 = ($94<<24>>24)<(0);
        $96 = HEAP32[$9>>2]|0;
        $97 = $95 ? $96 : $9;
        $98 = (($97) + ($81)|0);
        HEAP32[$10>>2] = $98;
        $$126 = $97;
       } else {
        $$126 = $$025;
       }
       $105 = ((($$pre$i$i$i53)) + 12|0);
       $106 = HEAP32[$105>>2]|0;
       $107 = ((($$pre$i$i$i53)) + 16|0);
       $108 = HEAP32[$107>>2]|0;
       $109 = ($106|0)==($108|0);
       if ($109) {
        $110 = HEAP32[$$pre$i$i$i53>>2]|0;
        $111 = ((($110)) + 36|0);
        $112 = HEAP32[$111>>2]|0;
        __THREW__ = 0;
        $113 = (invoke_ii($112|0,($$pre$i$i$i53|0))|0);
        $114 = __THREW__; __THREW__ = 0;
        $115 = $114&1;
        if ($115) {
         break;
        } else {
         $$0$i$i46 = $113;
        }
       } else {
        $116 = HEAP32[$106>>2]|0;
        $117 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($116)|0);
        $$0$i$i46 = $117;
       }
       __THREW__ = 0;
       $118 = (invoke_iiiiiiiiiii(4687,($$0$i$i46|0),16,($$126|0),($10|0),($13|0),0,($7|0),($11|0),($12|0),($6|0))|0);
       $119 = __THREW__; __THREW__ = 0;
       $120 = $119&1;
       if ($120) {
        break;
       }
       $121 = ($118|0)==(0);
       if (!($121)) {
        $$227 = $$126;$$pre$i4$i$i59 = $187;
        label = 46;
        break;
       }
       $122 = HEAP32[$105>>2]|0;
       $123 = HEAP32[$107>>2]|0;
       $124 = ($122|0)==($123|0);
       if ($124) {
        $125 = HEAP32[$$pre$i$i$i53>>2]|0;
        $126 = ((($125)) + 40|0);
        $127 = HEAP32[$126>>2]|0;
        __THREW__ = 0;
        (invoke_ii($127|0,($$pre$i$i$i53|0))|0);
        $128 = __THREW__; __THREW__ = 0;
        $129 = $128&1;
        if ($129) {
         break;
        } else {
         $$025 = $$126;$$pre$i$i$i = $$pre$i$i$i53;$185 = $155;
         continue;
        }
       } else {
        $130 = ((($122)) + 4|0);
        HEAP32[$105>>2] = $130;
        $131 = HEAP32[$122>>2]|0;
        (__ZNSt3__211char_traitsIwE11to_int_typeEw($131)|0);
        $$025 = $$126;$$pre$i$i$i = $$pre$i$i$i53;$185 = $155;
        continue;
       }
      }
      L60: do {
       if ((label|0) == 46) {
        $132 = HEAP32[$10>>2]|0;
        $133 = $$227;
        $134 = (($132) - ($133))|0;
        __THREW__ = 0;
        invoke_viii(3434,($9|0),($134|0),0);
        $135 = __THREW__; __THREW__ = 0;
        $136 = $135&1;
        if (!($136)) {
         $137 = HEAP8[$28>>0]|0;
         $138 = HEAP32[$9>>2]|0;
         __THREW__ = 0;
         $139 = (invoke_i(4668)|0);
         $140 = __THREW__; __THREW__ = 0;
         $141 = $140&1;
         if (!($141)) {
          $142 = ($137<<24>>24)<(0);
          $143 = $142 ? $138 : $9;
          __THREW__ = 0;
          HEAP32[$vararg_buffer>>2] = $5;
          $144 = (invoke_iiiii(4669,($143|0),($139|0),(202647|0),($vararg_buffer|0))|0);
          $145 = __THREW__; __THREW__ = 0;
          $146 = $145&1;
          if (!($146)) {
           $147 = ($144|0)==(1);
           if (!($147)) {
            HEAP32[$4>>2] = 4;
           }
           $148 = ($$pre$i$i$i53|0)==(0|0);
           if ($148) {
            $188 = 1;
           } else {
            $149 = ((($$pre$i$i$i53)) + 12|0);
            $150 = HEAP32[$149>>2]|0;
            $151 = ((($$pre$i$i$i53)) + 16|0);
            $152 = HEAP32[$151>>2]|0;
            $153 = ($150|0)==($152|0);
            if ($153) {
             $154 = HEAP32[$155>>2]|0;
             $156 = ((($154)) + 36|0);
             $157 = HEAP32[$156>>2]|0;
             __THREW__ = 0;
             $158 = (invoke_ii($157|0,($$pre$i$i$i53|0))|0);
             $159 = __THREW__; __THREW__ = 0;
             $160 = $159&1;
             if ($160) {
              break;
             } else {
              $$0$i$i$i$i51 = $158;
             }
            } else {
             $161 = HEAP32[$150>>2]|0;
             $162 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($161)|0);
             $$0$i$i$i$i51 = $162;
            }
            $163 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
            $164 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i$i$i51,$163)|0);
            if ($164) {
             HEAP32[$1>>2] = 0;
             $188 = 1;
            } else {
             $188 = 0;
            }
           }
           $165 = ($$pre$i4$i$i59|0)==(0|0);
           do {
            if ($165) {
             label = 63;
            } else {
             $166 = ((($$pre$i4$i$i59)) + 12|0);
             $167 = HEAP32[$166>>2]|0;
             $168 = ((($$pre$i4$i$i59)) + 16|0);
             $169 = HEAP32[$168>>2]|0;
             $170 = ($167|0)==($169|0);
             if ($170) {
              $171 = HEAP32[$$pre$i4$i$i59>>2]|0;
              $172 = ((($171)) + 36|0);
              $173 = HEAP32[$172>>2]|0;
              __THREW__ = 0;
              $174 = (invoke_ii($173|0,($$pre$i4$i$i59|0))|0);
              $175 = __THREW__; __THREW__ = 0;
              $176 = $175&1;
              if ($176) {
               break L60;
              } else {
               $$0$i$i2$i$i57 = $174;
              }
             } else {
              $177 = HEAP32[$167>>2]|0;
              $178 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($177)|0);
              $$0$i$i2$i$i57 = $178;
             }
             $179 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
             $180 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i2$i$i57,$179)|0);
             if ($180) {
              HEAP32[$2>>2] = 0;
              label = 63;
              break;
             } else {
              if ($188) {
               break;
              } else {
               label = 65;
               break;
              }
             }
            }
           } while(0);
           if ((label|0) == 63) {
            if ($188) {
             label = 65;
            }
           }
           if ((label|0) == 65) {
            $181 = HEAP32[$4>>2]|0;
            $182 = $181 | 2;
            HEAP32[$4>>2] = $182;
           }
           $$sroa$0$0$copyload = HEAP32[$1>>2]|0;
           __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($9);
           __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($7);
           STACKTOP = sp;return ($$sroa$0$0$copyload|0);
          }
         }
        }
       }
      } while(0);
      $183 = ___cxa_find_matching_catch_2()|0;
      $184 = tempRet0;
      $$2 = $183;$$230 = $184;
     }
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($9);
     $$3 = $$2;$$331 = $$230;
     break;
    }
   }
   $101 = ___cxa_find_matching_catch_2()|0;
   $102 = tempRet0;
   __ZNSt3__26localeD2Ev($8);
   $$0 = $101;$$028 = $102;
   label = 36;
  }
 } while(0);
 if ((label|0) == 36) {
  $$3 = $$0;$$331 = $$028;
 }
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($7);
 ___resumeException($$3|0);
 // unreachable;
 return (0)|0;
}
function __ZNSt3__29__num_getIwE17__stage2_int_loopEwiPcRS2_RjwRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjRSD_Pw($0,$1,$2,$3,$4,$5,$6,$7,$8,$9) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 $8 = $8|0;
 $9 = $9|0;
 var $$0$i$add = 0, $$0$i$idx = 0, $$0$i$ptr = 0, $$0$lcssa$i = 0, $$1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $10 = HEAP32[$3>>2]|0;
 $11 = ($10|0)==($2|0);
 do {
  if ($11) {
   $12 = ((($9)) + 96|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = ($13|0)==($0|0);
   if (!($14)) {
    $15 = ((($9)) + 100|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = ($16|0)==($0|0);
    if (!($17)) {
     label = 5;
     break;
    }
   }
   $18 = $14 ? 43 : 45;
   $19 = ((($2)) + 1|0);
   HEAP32[$3>>2] = $19;
   HEAP8[$2>>0] = $18;
   HEAP32[$4>>2] = 0;
   $$1 = 0;
  } else {
   label = 5;
  }
 } while(0);
 L6: do {
  if ((label|0) == 5) {
   $20 = ((($6)) + 11|0);
   $21 = HEAP8[$20>>0]|0;
   $22 = ($21<<24>>24)<(0);
   $23 = ((($6)) + 4|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = $21&255;
   $26 = $22 ? $24 : $25;
   $27 = ($26|0)!=(0);
   $28 = ($0|0)==($5|0);
   $or$cond = $28 & $27;
   if ($or$cond) {
    $29 = HEAP32[$8>>2]|0;
    $30 = $29;
    $31 = $7;
    $32 = (($30) - ($31))|0;
    $33 = ($32|0)<(160);
    if (!($33)) {
     $$1 = 0;
     break;
    }
    $34 = HEAP32[$4>>2]|0;
    $35 = ((($29)) + 4|0);
    HEAP32[$8>>2] = $35;
    HEAP32[$29>>2] = $34;
    HEAP32[$4>>2] = 0;
    $$1 = 0;
    break;
   }
   $36 = ((($9)) + 104|0);
   $$0$i$idx = 0;
   while(1) {
    $$0$i$ptr = (($9) + ($$0$i$idx<<2)|0);
    $37 = ($$0$i$idx|0)==(26);
    if ($37) {
     $$0$lcssa$i = $36;
     break;
    }
    $38 = HEAP32[$$0$i$ptr>>2]|0;
    $39 = ($38|0)==($0|0);
    $$0$i$add = (($$0$i$idx) + 1)|0;
    if ($39) {
     $$0$lcssa$i = $$0$i$ptr;
     break;
    } else {
     $$0$i$idx = $$0$i$add;
    }
   }
   $40 = $$0$lcssa$i;
   $41 = $9;
   $42 = (($40) - ($41))|0;
   $43 = $42 >> 2;
   $44 = ($42|0)>(92);
   if ($44) {
    $$1 = -1;
   } else {
    $45 = (202614 + ($43)|0);
    switch ($1|0) {
    case 10: case 8:  {
     $46 = ($43|0)<($1|0);
     if (!($46)) {
      $$1 = -1;
      break L6;
     }
     break;
    }
    case 16:  {
     $47 = ($42|0)<(88);
     if (!($47)) {
      if ($11) {
       $$1 = -1;
       break L6;
      }
      $48 = $10;
      $49 = $2;
      $50 = (($48) - ($49))|0;
      $51 = ($50|0)<(3);
      if (!($51)) {
       $$1 = -1;
       break L6;
      }
      $52 = ((($10)) + -1|0);
      $53 = HEAP8[$52>>0]|0;
      $54 = ($53<<24>>24)==(48);
      if (!($54)) {
       $$1 = -1;
       break L6;
      }
      HEAP32[$4>>2] = 0;
      $55 = HEAP8[$45>>0]|0;
      $56 = ((($10)) + 1|0);
      HEAP32[$3>>2] = $56;
      HEAP8[$10>>0] = $55;
      $$1 = 0;
      break L6;
     }
     break;
    }
    default: {
    }
    }
    $57 = HEAP8[$45>>0]|0;
    $58 = ((($10)) + 1|0);
    HEAP32[$3>>2] = $58;
    HEAP8[$10>>0] = $57;
    $59 = HEAP32[$4>>2]|0;
    $60 = (($59) + 1)|0;
    HEAP32[$4>>2] = $60;
    $$1 = 0;
   }
  }
 } while(0);
 return ($$1|0);
}
function __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE23__do_get_floating_pointIeEES4_S4_S4_RNS_8ios_baseERjRT_($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$0$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i38 = 0, $$0$i$i2$i$i = 0, $$0$i$i2$i$i44 = 0, $$0$i$i34 = 0, $$018 = 0, $$1 = 0, $$119 = 0, $$121 = 0, $$2 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i40 = 0, $$pre$i4$i$i46 = 0, $$sroa$0$0$copyload = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0.0;
 var $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0;
 var $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0;
 var $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i$i = 0, $or$cond = 0, $phitmp$i = 0, $phitmp$i29 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 352|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(352|0);
 $6 = sp + 208|0;
 $7 = sp + 200|0;
 $8 = sp + 196|0;
 $9 = sp + 184|0;
 $10 = sp + 172|0;
 $11 = sp + 168|0;
 $12 = sp + 8|0;
 $13 = sp + 4|0;
 $14 = sp;
 $15 = sp + 337|0;
 $16 = sp + 336|0;
 __ZNSt3__29__num_getIwE19__stage2_float_prepERNS_8ios_baseEPwRwS5_($9,$3,$6,$7,$8);
 ;HEAP32[$10>>2]=0|0;HEAP32[$10+4>>2]=0|0;HEAP32[$10+8>>2]=0|0;
 $$0$i$i = 0;
 while(1) {
  $exitcond$i$i = ($$0$i$i|0)==(3);
  if ($exitcond$i$i) {
   break;
  }
  $17 = (($10) + ($$0$i$i<<2)|0);
  HEAP32[$17>>2] = 0;
  $18 = (($$0$i$i) + 1)|0;
  $$0$i$i = $18;
 }
 $19 = ((($10)) + 11|0);
 $20 = HEAP8[$19>>0]|0;
 $21 = ($20<<24>>24)<(0);
 if ($21) {
  $22 = ((($10)) + 8|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = $23 & 2147483647;
  $phitmp$i = (($24) + -1)|0;
  $25 = $phitmp$i;
 } else {
  $25 = 10;
 }
 __THREW__ = 0;
 invoke_viii(3434,($10|0),($25|0),0);
 $26 = __THREW__; __THREW__ = 0;
 $27 = $26&1;
 if ($27) {
  $90 = ___cxa_find_matching_catch_2()|0;
  $91 = tempRet0;
  $$1 = $90;$$121 = $91;
 } else {
  $28 = HEAP8[$19>>0]|0;
  $29 = ($28<<24>>24)<(0);
  $30 = HEAP32[$10>>2]|0;
  $31 = $29 ? $30 : $10;
  HEAP32[$11>>2] = $31;
  HEAP32[$13>>2] = $12;
  HEAP32[$14>>2] = 0;
  HEAP8[$15>>0] = 1;
  HEAP8[$16>>0] = 69;
  $32 = ((($10)) + 4|0);
  $33 = ((($10)) + 8|0);
  $$pre = HEAP32[$1>>2]|0;
  $$018 = $31;$$pre$i$i$i = $$pre;$182 = $$pre;
  L11: while(1) {
   $34 = ($$pre$i$i$i|0)==(0|0);
   if ($34) {
    $$pre$i$i$i40 = 0;$152 = 0;$183 = 1;
   } else {
    $35 = ((($$pre$i$i$i)) + 12|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = ((($$pre$i$i$i)) + 16|0);
    $38 = HEAP32[$37>>2]|0;
    $39 = ($36|0)==($38|0);
    if ($39) {
     $40 = HEAP32[$$pre$i$i$i>>2]|0;
     $41 = ((($40)) + 36|0);
     $42 = HEAP32[$41>>2]|0;
     __THREW__ = 0;
     $43 = (invoke_ii($42|0,($$pre$i$i$i|0))|0);
     $44 = __THREW__; __THREW__ = 0;
     $45 = $44&1;
     if ($45) {
      break;
     } else {
      $$0$i$i$i$i = $43;
     }
    } else {
     $46 = HEAP32[$36>>2]|0;
     $47 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($46)|0);
     $$0$i$i$i$i = $47;
    }
    $48 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
    $49 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i$i$i,$48)|0);
    if ($49) {
     HEAP32[$1>>2] = 0;
     $$pre$i$i$i40 = 0;$152 = 0;$183 = 1;
    } else {
     $$pre$i$i$i40 = $$pre$i$i$i;$152 = $182;$183 = 0;
    }
   }
   $50 = HEAP32[$2>>2]|0;
   $51 = ($50|0)==(0|0);
   do {
    if ($51) {
     label = 20;
    } else {
     $52 = ((($50)) + 12|0);
     $53 = HEAP32[$52>>2]|0;
     $54 = ((($50)) + 16|0);
     $55 = HEAP32[$54>>2]|0;
     $56 = ($53|0)==($55|0);
     if ($56) {
      $57 = HEAP32[$50>>2]|0;
      $58 = ((($57)) + 36|0);
      $59 = HEAP32[$58>>2]|0;
      __THREW__ = 0;
      $60 = (invoke_ii($59|0,($50|0))|0);
      $61 = __THREW__; __THREW__ = 0;
      $62 = $61&1;
      if ($62) {
       break L11;
      } else {
       $$0$i$i2$i$i = $60;
      }
     } else {
      $63 = HEAP32[$53>>2]|0;
      $64 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($63)|0);
      $$0$i$i2$i$i = $64;
     }
     $65 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
     $66 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i2$i$i,$65)|0);
     if ($66) {
      HEAP32[$2>>2] = 0;
      label = 20;
      break;
     } else {
      if ($183) {
       $184 = $50;
       break;
      } else {
       $$2 = $$018;$$pre$i4$i$i46 = $50;
       label = 37;
       break L11;
      }
     }
    }
   } while(0);
   if ((label|0) == 20) {
    label = 0;
    if ($183) {
     $$2 = $$018;$$pre$i4$i$i46 = 0;
     label = 37;
     break;
    } else {
     $184 = 0;
    }
   }
   $67 = HEAP32[$11>>2]|0;
   $68 = HEAP8[$19>>0]|0;
   $69 = ($68<<24>>24)<(0);
   $70 = HEAP32[$32>>2]|0;
   $71 = $68&255;
   $72 = $69 ? $70 : $71;
   $73 = (($$018) + ($72)|0);
   $74 = ($67|0)==($73|0);
   if ($74) {
    $75 = $72 << 1;
    __THREW__ = 0;
    invoke_viii(3434,($10|0),($75|0),0);
    $76 = __THREW__; __THREW__ = 0;
    $77 = $76&1;
    if ($77) {
     break;
    }
    $78 = HEAP8[$19>>0]|0;
    $79 = ($78<<24>>24)<(0);
    if ($79) {
     $80 = HEAP32[$33>>2]|0;
     $81 = $80 & 2147483647;
     $phitmp$i29 = (($81) + -1)|0;
     $82 = $phitmp$i29;
    } else {
     $82 = 10;
    }
    __THREW__ = 0;
    invoke_viii(3434,($10|0),($82|0),0);
    $83 = __THREW__; __THREW__ = 0;
    $84 = $83&1;
    if ($84) {
     break;
    }
    $85 = HEAP8[$19>>0]|0;
    $86 = ($85<<24>>24)<(0);
    $87 = HEAP32[$10>>2]|0;
    $88 = $86 ? $87 : $10;
    $89 = (($88) + ($72)|0);
    HEAP32[$11>>2] = $89;
    $$119 = $88;
   } else {
    $$119 = $$018;
   }
   $92 = ((($$pre$i$i$i40)) + 12|0);
   $93 = HEAP32[$92>>2]|0;
   $94 = ((($$pre$i$i$i40)) + 16|0);
   $95 = HEAP32[$94>>2]|0;
   $96 = ($93|0)==($95|0);
   if ($96) {
    $97 = HEAP32[$$pre$i$i$i40>>2]|0;
    $98 = ((($97)) + 36|0);
    $99 = HEAP32[$98>>2]|0;
    __THREW__ = 0;
    $100 = (invoke_ii($99|0,($$pre$i$i$i40|0))|0);
    $101 = __THREW__; __THREW__ = 0;
    $102 = $101&1;
    if ($102) {
     break;
    } else {
     $$0$i$i34 = $100;
    }
   } else {
    $103 = HEAP32[$93>>2]|0;
    $104 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($103)|0);
    $$0$i$i34 = $104;
   }
   $105 = HEAP32[$7>>2]|0;
   $106 = HEAP32[$8>>2]|0;
   __THREW__ = 0;
   $107 = (invoke_iiiiiiiiiiiii(4688,($$0$i$i34|0),($15|0),($16|0),($$119|0),($11|0),($105|0),($106|0),($9|0),($12|0),($13|0),($14|0),($6|0))|0);
   $108 = __THREW__; __THREW__ = 0;
   $109 = $108&1;
   if ($109) {
    break;
   }
   $110 = ($107|0)==(0);
   if (!($110)) {
    $$2 = $$119;$$pre$i4$i$i46 = $184;
    label = 37;
    break;
   }
   $111 = HEAP32[$92>>2]|0;
   $112 = HEAP32[$94>>2]|0;
   $113 = ($111|0)==($112|0);
   if ($113) {
    $114 = HEAP32[$$pre$i$i$i40>>2]|0;
    $115 = ((($114)) + 40|0);
    $116 = HEAP32[$115>>2]|0;
    __THREW__ = 0;
    (invoke_ii($116|0,($$pre$i$i$i40|0))|0);
    $117 = __THREW__; __THREW__ = 0;
    $118 = $117&1;
    if ($118) {
     break;
    } else {
     $$018 = $$119;$$pre$i$i$i = $$pre$i$i$i40;$182 = $152;
     continue;
    }
   } else {
    $119 = ((($111)) + 4|0);
    HEAP32[$92>>2] = $119;
    $120 = HEAP32[$111>>2]|0;
    (__ZNSt3__211char_traitsIwE11to_int_typeEw($120)|0);
    $$018 = $$119;$$pre$i$i$i = $$pre$i$i$i40;$182 = $152;
    continue;
   }
  }
  L50: do {
   if ((label|0) == 37) {
    $121 = ((($9)) + 11|0);
    $122 = HEAP8[$121>>0]|0;
    $123 = ($122<<24>>24)<(0);
    $124 = ((($9)) + 4|0);
    $125 = HEAP32[$124>>2]|0;
    $126 = $122&255;
    $127 = $123 ? $125 : $126;
    $128 = ($127|0)==(0);
    $129 = HEAP8[$15>>0]|0;
    $130 = ($129<<24>>24)==(0);
    $or$cond = $128 | $130;
    if (!($or$cond)) {
     $131 = HEAP32[$13>>2]|0;
     $132 = $131;
     $133 = $12;
     $134 = (($132) - ($133))|0;
     $135 = ($134|0)<(160);
     if ($135) {
      $136 = HEAP32[$14>>2]|0;
      $137 = ((($131)) + 4|0);
      HEAP32[$13>>2] = $137;
      HEAP32[$131>>2] = $136;
     }
    }
    $138 = HEAP32[$11>>2]|0;
    __THREW__ = 0;
    $139 = (+invoke_diii(4675,($$2|0),($138|0),($4|0)));
    $140 = __THREW__; __THREW__ = 0;
    $141 = $140&1;
    if (!($141)) {
     HEAPF64[$5>>3] = $139;
     $142 = HEAP32[$13>>2]|0;
     __THREW__ = 0;
     invoke_viiii(4676,($9|0),($12|0),($142|0),($4|0));
     $143 = __THREW__; __THREW__ = 0;
     $144 = $143&1;
     if (!($144)) {
      $145 = ($$pre$i$i$i40|0)==(0|0);
      if ($145) {
       $185 = 1;
      } else {
       $146 = ((($$pre$i$i$i40)) + 12|0);
       $147 = HEAP32[$146>>2]|0;
       $148 = ((($$pre$i$i$i40)) + 16|0);
       $149 = HEAP32[$148>>2]|0;
       $150 = ($147|0)==($149|0);
       if ($150) {
        $151 = HEAP32[$152>>2]|0;
        $153 = ((($151)) + 36|0);
        $154 = HEAP32[$153>>2]|0;
        __THREW__ = 0;
        $155 = (invoke_ii($154|0,($$pre$i$i$i40|0))|0);
        $156 = __THREW__; __THREW__ = 0;
        $157 = $156&1;
        if ($157) {
         break;
        } else {
         $$0$i$i$i$i38 = $155;
        }
       } else {
        $158 = HEAP32[$147>>2]|0;
        $159 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($158)|0);
        $$0$i$i$i$i38 = $159;
       }
       $160 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
       $161 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i$i$i38,$160)|0);
       if ($161) {
        HEAP32[$1>>2] = 0;
        $185 = 1;
       } else {
        $185 = 0;
       }
      }
      $162 = ($$pre$i4$i$i46|0)==(0|0);
      do {
       if ($162) {
        label = 54;
       } else {
        $163 = ((($$pre$i4$i$i46)) + 12|0);
        $164 = HEAP32[$163>>2]|0;
        $165 = ((($$pre$i4$i$i46)) + 16|0);
        $166 = HEAP32[$165>>2]|0;
        $167 = ($164|0)==($166|0);
        if ($167) {
         $168 = HEAP32[$$pre$i4$i$i46>>2]|0;
         $169 = ((($168)) + 36|0);
         $170 = HEAP32[$169>>2]|0;
         __THREW__ = 0;
         $171 = (invoke_ii($170|0,($$pre$i4$i$i46|0))|0);
         $172 = __THREW__; __THREW__ = 0;
         $173 = $172&1;
         if ($173) {
          break L50;
         } else {
          $$0$i$i2$i$i44 = $171;
         }
        } else {
         $174 = HEAP32[$164>>2]|0;
         $175 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($174)|0);
         $$0$i$i2$i$i44 = $175;
        }
        $176 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
        $177 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i2$i$i44,$176)|0);
        if ($177) {
         HEAP32[$2>>2] = 0;
         label = 54;
         break;
        } else {
         if ($185) {
          break;
         } else {
          label = 56;
          break;
         }
        }
       }
      } while(0);
      if ((label|0) == 54) {
       if ($185) {
        label = 56;
       }
      }
      if ((label|0) == 56) {
       $178 = HEAP32[$4>>2]|0;
       $179 = $178 | 2;
       HEAP32[$4>>2] = $179;
      }
      $$sroa$0$0$copyload = HEAP32[$1>>2]|0;
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($10);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($9);
      STACKTOP = sp;return ($$sroa$0$0$copyload|0);
     }
    }
   }
  } while(0);
  $180 = ___cxa_find_matching_catch_2()|0;
  $181 = tempRet0;
  $$1 = $180;$$121 = $181;
 }
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($10);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($9);
 ___resumeException($$1|0);
 // unreachable;
 return (0)|0;
}
function __ZNSt3__29__num_getIwE19__stage2_float_prepERNS_8ios_baseEPwRwS5_($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $5 = sp;
 __ZNKSt3__28ios_base6getlocEv($5,$1);
 __THREW__ = 0;
 $6 = (invoke_iii(3255,($5|0),(215220|0))|0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if (!($8)) {
  $9 = HEAP32[$6>>2]|0;
  $10 = ((($9)) + 48|0);
  $11 = HEAP32[$10>>2]|0;
  __THREW__ = 0;
  (invoke_iiiii($11|0,($6|0),(202614|0),((202646)|0),($2|0))|0);
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if (!($13)) {
   __THREW__ = 0;
   $14 = (invoke_iii(3255,($5|0),(215228|0))|0);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    $17 = HEAP32[$14>>2]|0;
    $18 = ((($17)) + 12|0);
    $19 = HEAP32[$18>>2]|0;
    __THREW__ = 0;
    $20 = (invoke_ii($19|0,($14|0))|0);
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if (!($22)) {
     HEAP32[$3>>2] = $20;
     $23 = HEAP32[$14>>2]|0;
     $24 = ((($23)) + 16|0);
     $25 = HEAP32[$24>>2]|0;
     __THREW__ = 0;
     $26 = (invoke_ii($25|0,($14|0))|0);
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     if (!($28)) {
      HEAP32[$4>>2] = $26;
      $29 = HEAP32[$14>>2]|0;
      $30 = ((($29)) + 20|0);
      $31 = HEAP32[$30>>2]|0;
      __THREW__ = 0;
      invoke_vii($31|0,($0|0),($14|0));
      $32 = __THREW__; __THREW__ = 0;
      $33 = $32&1;
      if (!($33)) {
       __ZNSt3__26localeD2Ev($5);
       STACKTOP = sp;return;
      }
     }
    }
   }
  }
 }
 $34 = ___cxa_find_matching_catch_2()|0;
 $35 = tempRet0;
 __ZNSt3__26localeD2Ev($5);
 ___resumeException($34|0);
 // unreachable;
}
function __ZNSt3__29__num_getIwE19__stage2_float_loopEwRbRcPcRS4_wwRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjRSE_RjPw($0,$1,$2,$3,$4,$5,$6,$7,$8,$9,$10,$11) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 $8 = $8|0;
 $9 = $9|0;
 $10 = $10|0;
 $11 = $11|0;
 var $$0$i$add = 0, $$0$i$idx = 0, $$0$i$ptr = 0, $$0$lcssa$i = 0, $$2 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $12 = ($0|0)==($5|0);
 $13 = $8;
 L1: do {
  if ($12) {
   $14 = HEAP8[$1>>0]|0;
   $15 = ($14<<24>>24)==(0);
   if ($15) {
    $$2 = -1;
   } else {
    HEAP8[$1>>0] = 0;
    $16 = HEAP32[$4>>2]|0;
    $17 = ((($16)) + 1|0);
    HEAP32[$4>>2] = $17;
    HEAP8[$16>>0] = 46;
    $18 = ((($7)) + 11|0);
    $19 = HEAP8[$18>>0]|0;
    $20 = ($19<<24>>24)<(0);
    $21 = ((($7)) + 4|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = $19&255;
    $24 = $20 ? $22 : $23;
    $25 = ($24|0)==(0);
    if ($25) {
     $$2 = 0;
    } else {
     $26 = HEAP32[$9>>2]|0;
     $27 = $26;
     $28 = (($27) - ($13))|0;
     $29 = ($28|0)<(160);
     if ($29) {
      $30 = HEAP32[$10>>2]|0;
      $31 = ((($26)) + 4|0);
      HEAP32[$9>>2] = $31;
      HEAP32[$26>>2] = $30;
      $$2 = 0;
     } else {
      $$2 = 0;
     }
    }
   }
  } else {
   $32 = ($0|0)==($6|0);
   if ($32) {
    $33 = ((($7)) + 11|0);
    $34 = HEAP8[$33>>0]|0;
    $35 = ($34<<24>>24)<(0);
    $36 = ((($7)) + 4|0);
    $37 = HEAP32[$36>>2]|0;
    $38 = $34&255;
    $39 = $35 ? $37 : $38;
    $40 = ($39|0)==(0);
    if (!($40)) {
     $41 = HEAP8[$1>>0]|0;
     $42 = ($41<<24>>24)==(0);
     if ($42) {
      $$2 = -1;
      break;
     }
     $43 = HEAP32[$9>>2]|0;
     $44 = $43;
     $45 = (($44) - ($13))|0;
     $46 = ($45|0)<(160);
     if (!($46)) {
      $$2 = 0;
      break;
     }
     $47 = HEAP32[$10>>2]|0;
     $48 = ((($43)) + 4|0);
     HEAP32[$9>>2] = $48;
     HEAP32[$43>>2] = $47;
     HEAP32[$10>>2] = 0;
     $$2 = 0;
     break;
    }
   }
   $49 = ((($11)) + 128|0);
   $$0$i$idx = 0;
   while(1) {
    $$0$i$ptr = (($11) + ($$0$i$idx<<2)|0);
    $50 = ($$0$i$idx|0)==(32);
    if ($50) {
     $$0$lcssa$i = $49;
     break;
    }
    $51 = HEAP32[$$0$i$ptr>>2]|0;
    $52 = ($51|0)==($0|0);
    $$0$i$add = (($$0$i$idx) + 1)|0;
    if ($52) {
     $$0$lcssa$i = $$0$i$ptr;
     break;
    } else {
     $$0$i$idx = $$0$i$add;
    }
   }
   $53 = $$0$lcssa$i;
   $54 = $11;
   $55 = (($53) - ($54))|0;
   $56 = $55 >> 2;
   $57 = ($55|0)>(124);
   if ($57) {
    $$2 = -1;
   } else {
    $58 = (202614 + ($56)|0);
    $59 = HEAP8[$58>>0]|0;
    switch ($56|0) {
    case 24: case 25:  {
     $60 = HEAP32[$4>>2]|0;
     $61 = ($60|0)==($3|0);
     if (!($61)) {
      $62 = ((($60)) + -1|0);
      $63 = HEAP8[$62>>0]|0;
      $64 = $63 & 95;
      $65 = HEAP8[$2>>0]|0;
      $66 = $65 & 127;
      $67 = ($64<<24>>24)==($66<<24>>24);
      if (!($67)) {
       $$2 = -1;
       break L1;
      }
     }
     $68 = ((($60)) + 1|0);
     HEAP32[$4>>2] = $68;
     HEAP8[$60>>0] = $59;
     $$2 = 0;
     break L1;
     break;
    }
    case 23: case 22:  {
     HEAP8[$2>>0] = 80;
     break;
    }
    default: {
     $69 = $59 & 95;
     $70 = $69&255;
     $71 = HEAP8[$2>>0]|0;
     $72 = $71 << 24 >> 24;
     $73 = ($70|0)==($72|0);
     if ($73) {
      $74 = $70 | 128;
      $75 = $74&255;
      HEAP8[$2>>0] = $75;
      $76 = HEAP8[$1>>0]|0;
      $77 = ($76<<24>>24)==(0);
      if (!($77)) {
       HEAP8[$1>>0] = 0;
       $78 = ((($7)) + 11|0);
       $79 = HEAP8[$78>>0]|0;
       $80 = ($79<<24>>24)<(0);
       $81 = ((($7)) + 4|0);
       $82 = HEAP32[$81>>2]|0;
       $83 = $79&255;
       $84 = $80 ? $82 : $83;
       $85 = ($84|0)==(0);
       if (!($85)) {
        $86 = HEAP32[$9>>2]|0;
        $87 = $86;
        $88 = (($87) - ($13))|0;
        $89 = ($88|0)<(160);
        if ($89) {
         $90 = HEAP32[$10>>2]|0;
         $91 = ((($86)) + 4|0);
         HEAP32[$9>>2] = $91;
         HEAP32[$86>>2] = $90;
        }
       }
      }
     }
    }
    }
    $92 = HEAP32[$4>>2]|0;
    $93 = ((($92)) + 1|0);
    HEAP32[$4>>2] = $93;
    HEAP8[$92>>0] = $59;
    $94 = ($55|0)>(84);
    if ($94) {
     $$2 = 0;
    } else {
     $95 = HEAP32[$10>>2]|0;
     $96 = (($95) + 1)|0;
     HEAP32[$10>>2] = $96;
     $$2 = 0;
    }
   }
  }
 } while(0);
 return ($$2|0);
}
function __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE23__do_get_floating_pointIdEES4_S4_S4_RNS_8ios_baseERjRT_($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$0$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i38 = 0, $$0$i$i2$i$i = 0, $$0$i$i2$i$i44 = 0, $$0$i$i34 = 0, $$018 = 0, $$1 = 0, $$119 = 0, $$121 = 0, $$2 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i40 = 0, $$pre$i4$i$i46 = 0, $$sroa$0$0$copyload = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0.0;
 var $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0;
 var $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0;
 var $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i$i = 0, $or$cond = 0, $phitmp$i = 0, $phitmp$i29 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 352|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(352|0);
 $6 = sp + 208|0;
 $7 = sp + 200|0;
 $8 = sp + 196|0;
 $9 = sp + 184|0;
 $10 = sp + 172|0;
 $11 = sp + 168|0;
 $12 = sp + 8|0;
 $13 = sp + 4|0;
 $14 = sp;
 $15 = sp + 337|0;
 $16 = sp + 336|0;
 __ZNSt3__29__num_getIwE19__stage2_float_prepERNS_8ios_baseEPwRwS5_($9,$3,$6,$7,$8);
 ;HEAP32[$10>>2]=0|0;HEAP32[$10+4>>2]=0|0;HEAP32[$10+8>>2]=0|0;
 $$0$i$i = 0;
 while(1) {
  $exitcond$i$i = ($$0$i$i|0)==(3);
  if ($exitcond$i$i) {
   break;
  }
  $17 = (($10) + ($$0$i$i<<2)|0);
  HEAP32[$17>>2] = 0;
  $18 = (($$0$i$i) + 1)|0;
  $$0$i$i = $18;
 }
 $19 = ((($10)) + 11|0);
 $20 = HEAP8[$19>>0]|0;
 $21 = ($20<<24>>24)<(0);
 if ($21) {
  $22 = ((($10)) + 8|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = $23 & 2147483647;
  $phitmp$i = (($24) + -1)|0;
  $25 = $phitmp$i;
 } else {
  $25 = 10;
 }
 __THREW__ = 0;
 invoke_viii(3434,($10|0),($25|0),0);
 $26 = __THREW__; __THREW__ = 0;
 $27 = $26&1;
 if ($27) {
  $90 = ___cxa_find_matching_catch_2()|0;
  $91 = tempRet0;
  $$1 = $90;$$121 = $91;
 } else {
  $28 = HEAP8[$19>>0]|0;
  $29 = ($28<<24>>24)<(0);
  $30 = HEAP32[$10>>2]|0;
  $31 = $29 ? $30 : $10;
  HEAP32[$11>>2] = $31;
  HEAP32[$13>>2] = $12;
  HEAP32[$14>>2] = 0;
  HEAP8[$15>>0] = 1;
  HEAP8[$16>>0] = 69;
  $32 = ((($10)) + 4|0);
  $33 = ((($10)) + 8|0);
  $$pre = HEAP32[$1>>2]|0;
  $$018 = $31;$$pre$i$i$i = $$pre;$182 = $$pre;
  L11: while(1) {
   $34 = ($$pre$i$i$i|0)==(0|0);
   if ($34) {
    $$pre$i$i$i40 = 0;$152 = 0;$183 = 1;
   } else {
    $35 = ((($$pre$i$i$i)) + 12|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = ((($$pre$i$i$i)) + 16|0);
    $38 = HEAP32[$37>>2]|0;
    $39 = ($36|0)==($38|0);
    if ($39) {
     $40 = HEAP32[$$pre$i$i$i>>2]|0;
     $41 = ((($40)) + 36|0);
     $42 = HEAP32[$41>>2]|0;
     __THREW__ = 0;
     $43 = (invoke_ii($42|0,($$pre$i$i$i|0))|0);
     $44 = __THREW__; __THREW__ = 0;
     $45 = $44&1;
     if ($45) {
      break;
     } else {
      $$0$i$i$i$i = $43;
     }
    } else {
     $46 = HEAP32[$36>>2]|0;
     $47 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($46)|0);
     $$0$i$i$i$i = $47;
    }
    $48 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
    $49 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i$i$i,$48)|0);
    if ($49) {
     HEAP32[$1>>2] = 0;
     $$pre$i$i$i40 = 0;$152 = 0;$183 = 1;
    } else {
     $$pre$i$i$i40 = $$pre$i$i$i;$152 = $182;$183 = 0;
    }
   }
   $50 = HEAP32[$2>>2]|0;
   $51 = ($50|0)==(0|0);
   do {
    if ($51) {
     label = 20;
    } else {
     $52 = ((($50)) + 12|0);
     $53 = HEAP32[$52>>2]|0;
     $54 = ((($50)) + 16|0);
     $55 = HEAP32[$54>>2]|0;
     $56 = ($53|0)==($55|0);
     if ($56) {
      $57 = HEAP32[$50>>2]|0;
      $58 = ((($57)) + 36|0);
      $59 = HEAP32[$58>>2]|0;
      __THREW__ = 0;
      $60 = (invoke_ii($59|0,($50|0))|0);
      $61 = __THREW__; __THREW__ = 0;
      $62 = $61&1;
      if ($62) {
       break L11;
      } else {
       $$0$i$i2$i$i = $60;
      }
     } else {
      $63 = HEAP32[$53>>2]|0;
      $64 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($63)|0);
      $$0$i$i2$i$i = $64;
     }
     $65 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
     $66 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i2$i$i,$65)|0);
     if ($66) {
      HEAP32[$2>>2] = 0;
      label = 20;
      break;
     } else {
      if ($183) {
       $184 = $50;
       break;
      } else {
       $$2 = $$018;$$pre$i4$i$i46 = $50;
       label = 37;
       break L11;
      }
     }
    }
   } while(0);
   if ((label|0) == 20) {
    label = 0;
    if ($183) {
     $$2 = $$018;$$pre$i4$i$i46 = 0;
     label = 37;
     break;
    } else {
     $184 = 0;
    }
   }
   $67 = HEAP32[$11>>2]|0;
   $68 = HEAP8[$19>>0]|0;
   $69 = ($68<<24>>24)<(0);
   $70 = HEAP32[$32>>2]|0;
   $71 = $68&255;
   $72 = $69 ? $70 : $71;
   $73 = (($$018) + ($72)|0);
   $74 = ($67|0)==($73|0);
   if ($74) {
    $75 = $72 << 1;
    __THREW__ = 0;
    invoke_viii(3434,($10|0),($75|0),0);
    $76 = __THREW__; __THREW__ = 0;
    $77 = $76&1;
    if ($77) {
     break;
    }
    $78 = HEAP8[$19>>0]|0;
    $79 = ($78<<24>>24)<(0);
    if ($79) {
     $80 = HEAP32[$33>>2]|0;
     $81 = $80 & 2147483647;
     $phitmp$i29 = (($81) + -1)|0;
     $82 = $phitmp$i29;
    } else {
     $82 = 10;
    }
    __THREW__ = 0;
    invoke_viii(3434,($10|0),($82|0),0);
    $83 = __THREW__; __THREW__ = 0;
    $84 = $83&1;
    if ($84) {
     break;
    }
    $85 = HEAP8[$19>>0]|0;
    $86 = ($85<<24>>24)<(0);
    $87 = HEAP32[$10>>2]|0;
    $88 = $86 ? $87 : $10;
    $89 = (($88) + ($72)|0);
    HEAP32[$11>>2] = $89;
    $$119 = $88;
   } else {
    $$119 = $$018;
   }
   $92 = ((($$pre$i$i$i40)) + 12|0);
   $93 = HEAP32[$92>>2]|0;
   $94 = ((($$pre$i$i$i40)) + 16|0);
   $95 = HEAP32[$94>>2]|0;
   $96 = ($93|0)==($95|0);
   if ($96) {
    $97 = HEAP32[$$pre$i$i$i40>>2]|0;
    $98 = ((($97)) + 36|0);
    $99 = HEAP32[$98>>2]|0;
    __THREW__ = 0;
    $100 = (invoke_ii($99|0,($$pre$i$i$i40|0))|0);
    $101 = __THREW__; __THREW__ = 0;
    $102 = $101&1;
    if ($102) {
     break;
    } else {
     $$0$i$i34 = $100;
    }
   } else {
    $103 = HEAP32[$93>>2]|0;
    $104 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($103)|0);
    $$0$i$i34 = $104;
   }
   $105 = HEAP32[$7>>2]|0;
   $106 = HEAP32[$8>>2]|0;
   __THREW__ = 0;
   $107 = (invoke_iiiiiiiiiiiii(4688,($$0$i$i34|0),($15|0),($16|0),($$119|0),($11|0),($105|0),($106|0),($9|0),($12|0),($13|0),($14|0),($6|0))|0);
   $108 = __THREW__; __THREW__ = 0;
   $109 = $108&1;
   if ($109) {
    break;
   }
   $110 = ($107|0)==(0);
   if (!($110)) {
    $$2 = $$119;$$pre$i4$i$i46 = $184;
    label = 37;
    break;
   }
   $111 = HEAP32[$92>>2]|0;
   $112 = HEAP32[$94>>2]|0;
   $113 = ($111|0)==($112|0);
   if ($113) {
    $114 = HEAP32[$$pre$i$i$i40>>2]|0;
    $115 = ((($114)) + 40|0);
    $116 = HEAP32[$115>>2]|0;
    __THREW__ = 0;
    (invoke_ii($116|0,($$pre$i$i$i40|0))|0);
    $117 = __THREW__; __THREW__ = 0;
    $118 = $117&1;
    if ($118) {
     break;
    } else {
     $$018 = $$119;$$pre$i$i$i = $$pre$i$i$i40;$182 = $152;
     continue;
    }
   } else {
    $119 = ((($111)) + 4|0);
    HEAP32[$92>>2] = $119;
    $120 = HEAP32[$111>>2]|0;
    (__ZNSt3__211char_traitsIwE11to_int_typeEw($120)|0);
    $$018 = $$119;$$pre$i$i$i = $$pre$i$i$i40;$182 = $152;
    continue;
   }
  }
  L50: do {
   if ((label|0) == 37) {
    $121 = ((($9)) + 11|0);
    $122 = HEAP8[$121>>0]|0;
    $123 = ($122<<24>>24)<(0);
    $124 = ((($9)) + 4|0);
    $125 = HEAP32[$124>>2]|0;
    $126 = $122&255;
    $127 = $123 ? $125 : $126;
    $128 = ($127|0)==(0);
    $129 = HEAP8[$15>>0]|0;
    $130 = ($129<<24>>24)==(0);
    $or$cond = $128 | $130;
    if (!($or$cond)) {
     $131 = HEAP32[$13>>2]|0;
     $132 = $131;
     $133 = $12;
     $134 = (($132) - ($133))|0;
     $135 = ($134|0)<(160);
     if ($135) {
      $136 = HEAP32[$14>>2]|0;
      $137 = ((($131)) + 4|0);
      HEAP32[$13>>2] = $137;
      HEAP32[$131>>2] = $136;
     }
    }
    $138 = HEAP32[$11>>2]|0;
    __THREW__ = 0;
    $139 = (+invoke_diii(4677,($$2|0),($138|0),($4|0)));
    $140 = __THREW__; __THREW__ = 0;
    $141 = $140&1;
    if (!($141)) {
     HEAPF64[$5>>3] = $139;
     $142 = HEAP32[$13>>2]|0;
     __THREW__ = 0;
     invoke_viiii(4676,($9|0),($12|0),($142|0),($4|0));
     $143 = __THREW__; __THREW__ = 0;
     $144 = $143&1;
     if (!($144)) {
      $145 = ($$pre$i$i$i40|0)==(0|0);
      if ($145) {
       $185 = 1;
      } else {
       $146 = ((($$pre$i$i$i40)) + 12|0);
       $147 = HEAP32[$146>>2]|0;
       $148 = ((($$pre$i$i$i40)) + 16|0);
       $149 = HEAP32[$148>>2]|0;
       $150 = ($147|0)==($149|0);
       if ($150) {
        $151 = HEAP32[$152>>2]|0;
        $153 = ((($151)) + 36|0);
        $154 = HEAP32[$153>>2]|0;
        __THREW__ = 0;
        $155 = (invoke_ii($154|0,($$pre$i$i$i40|0))|0);
        $156 = __THREW__; __THREW__ = 0;
        $157 = $156&1;
        if ($157) {
         break;
        } else {
         $$0$i$i$i$i38 = $155;
        }
       } else {
        $158 = HEAP32[$147>>2]|0;
        $159 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($158)|0);
        $$0$i$i$i$i38 = $159;
       }
       $160 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
       $161 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i$i$i38,$160)|0);
       if ($161) {
        HEAP32[$1>>2] = 0;
        $185 = 1;
       } else {
        $185 = 0;
       }
      }
      $162 = ($$pre$i4$i$i46|0)==(0|0);
      do {
       if ($162) {
        label = 54;
       } else {
        $163 = ((($$pre$i4$i$i46)) + 12|0);
        $164 = HEAP32[$163>>2]|0;
        $165 = ((($$pre$i4$i$i46)) + 16|0);
        $166 = HEAP32[$165>>2]|0;
        $167 = ($164|0)==($166|0);
        if ($167) {
         $168 = HEAP32[$$pre$i4$i$i46>>2]|0;
         $169 = ((($168)) + 36|0);
         $170 = HEAP32[$169>>2]|0;
         __THREW__ = 0;
         $171 = (invoke_ii($170|0,($$pre$i4$i$i46|0))|0);
         $172 = __THREW__; __THREW__ = 0;
         $173 = $172&1;
         if ($173) {
          break L50;
         } else {
          $$0$i$i2$i$i44 = $171;
         }
        } else {
         $174 = HEAP32[$164>>2]|0;
         $175 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($174)|0);
         $$0$i$i2$i$i44 = $175;
        }
        $176 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
        $177 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i2$i$i44,$176)|0);
        if ($177) {
         HEAP32[$2>>2] = 0;
         label = 54;
         break;
        } else {
         if ($185) {
          break;
         } else {
          label = 56;
          break;
         }
        }
       }
      } while(0);
      if ((label|0) == 54) {
       if ($185) {
        label = 56;
       }
      }
      if ((label|0) == 56) {
       $178 = HEAP32[$4>>2]|0;
       $179 = $178 | 2;
       HEAP32[$4>>2] = $179;
      }
      $$sroa$0$0$copyload = HEAP32[$1>>2]|0;
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($10);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($9);
      STACKTOP = sp;return ($$sroa$0$0$copyload|0);
     }
    }
   }
  } while(0);
  $180 = ___cxa_find_matching_catch_2()|0;
  $181 = tempRet0;
  $$1 = $180;$$121 = $181;
 }
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($10);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($9);
 ___resumeException($$1|0);
 // unreachable;
 return (0)|0;
}
function __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE23__do_get_floating_pointIfEES4_S4_S4_RNS_8ios_baseERjRT_($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$0$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i38 = 0, $$0$i$i2$i$i = 0, $$0$i$i2$i$i44 = 0, $$0$i$i34 = 0, $$018 = 0, $$1 = 0, $$119 = 0, $$121 = 0, $$2 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i40 = 0, $$pre$i4$i$i46 = 0, $$sroa$0$0$copyload = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0.0;
 var $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0;
 var $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0;
 var $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i$i = 0, $or$cond = 0, $phitmp$i = 0, $phitmp$i29 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 352|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(352|0);
 $6 = sp + 208|0;
 $7 = sp + 200|0;
 $8 = sp + 196|0;
 $9 = sp + 184|0;
 $10 = sp + 172|0;
 $11 = sp + 168|0;
 $12 = sp + 8|0;
 $13 = sp + 4|0;
 $14 = sp;
 $15 = sp + 337|0;
 $16 = sp + 336|0;
 __ZNSt3__29__num_getIwE19__stage2_float_prepERNS_8ios_baseEPwRwS5_($9,$3,$6,$7,$8);
 ;HEAP32[$10>>2]=0|0;HEAP32[$10+4>>2]=0|0;HEAP32[$10+8>>2]=0|0;
 $$0$i$i = 0;
 while(1) {
  $exitcond$i$i = ($$0$i$i|0)==(3);
  if ($exitcond$i$i) {
   break;
  }
  $17 = (($10) + ($$0$i$i<<2)|0);
  HEAP32[$17>>2] = 0;
  $18 = (($$0$i$i) + 1)|0;
  $$0$i$i = $18;
 }
 $19 = ((($10)) + 11|0);
 $20 = HEAP8[$19>>0]|0;
 $21 = ($20<<24>>24)<(0);
 if ($21) {
  $22 = ((($10)) + 8|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = $23 & 2147483647;
  $phitmp$i = (($24) + -1)|0;
  $25 = $phitmp$i;
 } else {
  $25 = 10;
 }
 __THREW__ = 0;
 invoke_viii(3434,($10|0),($25|0),0);
 $26 = __THREW__; __THREW__ = 0;
 $27 = $26&1;
 if ($27) {
  $90 = ___cxa_find_matching_catch_2()|0;
  $91 = tempRet0;
  $$1 = $90;$$121 = $91;
 } else {
  $28 = HEAP8[$19>>0]|0;
  $29 = ($28<<24>>24)<(0);
  $30 = HEAP32[$10>>2]|0;
  $31 = $29 ? $30 : $10;
  HEAP32[$11>>2] = $31;
  HEAP32[$13>>2] = $12;
  HEAP32[$14>>2] = 0;
  HEAP8[$15>>0] = 1;
  HEAP8[$16>>0] = 69;
  $32 = ((($10)) + 4|0);
  $33 = ((($10)) + 8|0);
  $$pre = HEAP32[$1>>2]|0;
  $$018 = $31;$$pre$i$i$i = $$pre;$182 = $$pre;
  L11: while(1) {
   $34 = ($$pre$i$i$i|0)==(0|0);
   if ($34) {
    $$pre$i$i$i40 = 0;$152 = 0;$183 = 1;
   } else {
    $35 = ((($$pre$i$i$i)) + 12|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = ((($$pre$i$i$i)) + 16|0);
    $38 = HEAP32[$37>>2]|0;
    $39 = ($36|0)==($38|0);
    if ($39) {
     $40 = HEAP32[$$pre$i$i$i>>2]|0;
     $41 = ((($40)) + 36|0);
     $42 = HEAP32[$41>>2]|0;
     __THREW__ = 0;
     $43 = (invoke_ii($42|0,($$pre$i$i$i|0))|0);
     $44 = __THREW__; __THREW__ = 0;
     $45 = $44&1;
     if ($45) {
      break;
     } else {
      $$0$i$i$i$i = $43;
     }
    } else {
     $46 = HEAP32[$36>>2]|0;
     $47 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($46)|0);
     $$0$i$i$i$i = $47;
    }
    $48 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
    $49 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i$i$i,$48)|0);
    if ($49) {
     HEAP32[$1>>2] = 0;
     $$pre$i$i$i40 = 0;$152 = 0;$183 = 1;
    } else {
     $$pre$i$i$i40 = $$pre$i$i$i;$152 = $182;$183 = 0;
    }
   }
   $50 = HEAP32[$2>>2]|0;
   $51 = ($50|0)==(0|0);
   do {
    if ($51) {
     label = 20;
    } else {
     $52 = ((($50)) + 12|0);
     $53 = HEAP32[$52>>2]|0;
     $54 = ((($50)) + 16|0);
     $55 = HEAP32[$54>>2]|0;
     $56 = ($53|0)==($55|0);
     if ($56) {
      $57 = HEAP32[$50>>2]|0;
      $58 = ((($57)) + 36|0);
      $59 = HEAP32[$58>>2]|0;
      __THREW__ = 0;
      $60 = (invoke_ii($59|0,($50|0))|0);
      $61 = __THREW__; __THREW__ = 0;
      $62 = $61&1;
      if ($62) {
       break L11;
      } else {
       $$0$i$i2$i$i = $60;
      }
     } else {
      $63 = HEAP32[$53>>2]|0;
      $64 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($63)|0);
      $$0$i$i2$i$i = $64;
     }
     $65 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
     $66 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i2$i$i,$65)|0);
     if ($66) {
      HEAP32[$2>>2] = 0;
      label = 20;
      break;
     } else {
      if ($183) {
       $184 = $50;
       break;
      } else {
       $$2 = $$018;$$pre$i4$i$i46 = $50;
       label = 37;
       break L11;
      }
     }
    }
   } while(0);
   if ((label|0) == 20) {
    label = 0;
    if ($183) {
     $$2 = $$018;$$pre$i4$i$i46 = 0;
     label = 37;
     break;
    } else {
     $184 = 0;
    }
   }
   $67 = HEAP32[$11>>2]|0;
   $68 = HEAP8[$19>>0]|0;
   $69 = ($68<<24>>24)<(0);
   $70 = HEAP32[$32>>2]|0;
   $71 = $68&255;
   $72 = $69 ? $70 : $71;
   $73 = (($$018) + ($72)|0);
   $74 = ($67|0)==($73|0);
   if ($74) {
    $75 = $72 << 1;
    __THREW__ = 0;
    invoke_viii(3434,($10|0),($75|0),0);
    $76 = __THREW__; __THREW__ = 0;
    $77 = $76&1;
    if ($77) {
     break;
    }
    $78 = HEAP8[$19>>0]|0;
    $79 = ($78<<24>>24)<(0);
    if ($79) {
     $80 = HEAP32[$33>>2]|0;
     $81 = $80 & 2147483647;
     $phitmp$i29 = (($81) + -1)|0;
     $82 = $phitmp$i29;
    } else {
     $82 = 10;
    }
    __THREW__ = 0;
    invoke_viii(3434,($10|0),($82|0),0);
    $83 = __THREW__; __THREW__ = 0;
    $84 = $83&1;
    if ($84) {
     break;
    }
    $85 = HEAP8[$19>>0]|0;
    $86 = ($85<<24>>24)<(0);
    $87 = HEAP32[$10>>2]|0;
    $88 = $86 ? $87 : $10;
    $89 = (($88) + ($72)|0);
    HEAP32[$11>>2] = $89;
    $$119 = $88;
   } else {
    $$119 = $$018;
   }
   $92 = ((($$pre$i$i$i40)) + 12|0);
   $93 = HEAP32[$92>>2]|0;
   $94 = ((($$pre$i$i$i40)) + 16|0);
   $95 = HEAP32[$94>>2]|0;
   $96 = ($93|0)==($95|0);
   if ($96) {
    $97 = HEAP32[$$pre$i$i$i40>>2]|0;
    $98 = ((($97)) + 36|0);
    $99 = HEAP32[$98>>2]|0;
    __THREW__ = 0;
    $100 = (invoke_ii($99|0,($$pre$i$i$i40|0))|0);
    $101 = __THREW__; __THREW__ = 0;
    $102 = $101&1;
    if ($102) {
     break;
    } else {
     $$0$i$i34 = $100;
    }
   } else {
    $103 = HEAP32[$93>>2]|0;
    $104 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($103)|0);
    $$0$i$i34 = $104;
   }
   $105 = HEAP32[$7>>2]|0;
   $106 = HEAP32[$8>>2]|0;
   __THREW__ = 0;
   $107 = (invoke_iiiiiiiiiiiii(4688,($$0$i$i34|0),($15|0),($16|0),($$119|0),($11|0),($105|0),($106|0),($9|0),($12|0),($13|0),($14|0),($6|0))|0);
   $108 = __THREW__; __THREW__ = 0;
   $109 = $108&1;
   if ($109) {
    break;
   }
   $110 = ($107|0)==(0);
   if (!($110)) {
    $$2 = $$119;$$pre$i4$i$i46 = $184;
    label = 37;
    break;
   }
   $111 = HEAP32[$92>>2]|0;
   $112 = HEAP32[$94>>2]|0;
   $113 = ($111|0)==($112|0);
   if ($113) {
    $114 = HEAP32[$$pre$i$i$i40>>2]|0;
    $115 = ((($114)) + 40|0);
    $116 = HEAP32[$115>>2]|0;
    __THREW__ = 0;
    (invoke_ii($116|0,($$pre$i$i$i40|0))|0);
    $117 = __THREW__; __THREW__ = 0;
    $118 = $117&1;
    if ($118) {
     break;
    } else {
     $$018 = $$119;$$pre$i$i$i = $$pre$i$i$i40;$182 = $152;
     continue;
    }
   } else {
    $119 = ((($111)) + 4|0);
    HEAP32[$92>>2] = $119;
    $120 = HEAP32[$111>>2]|0;
    (__ZNSt3__211char_traitsIwE11to_int_typeEw($120)|0);
    $$018 = $$119;$$pre$i$i$i = $$pre$i$i$i40;$182 = $152;
    continue;
   }
  }
  L50: do {
   if ((label|0) == 37) {
    $121 = ((($9)) + 11|0);
    $122 = HEAP8[$121>>0]|0;
    $123 = ($122<<24>>24)<(0);
    $124 = ((($9)) + 4|0);
    $125 = HEAP32[$124>>2]|0;
    $126 = $122&255;
    $127 = $123 ? $125 : $126;
    $128 = ($127|0)==(0);
    $129 = HEAP8[$15>>0]|0;
    $130 = ($129<<24>>24)==(0);
    $or$cond = $128 | $130;
    if (!($or$cond)) {
     $131 = HEAP32[$13>>2]|0;
     $132 = $131;
     $133 = $12;
     $134 = (($132) - ($133))|0;
     $135 = ($134|0)<(160);
     if ($135) {
      $136 = HEAP32[$14>>2]|0;
      $137 = ((($131)) + 4|0);
      HEAP32[$13>>2] = $137;
      HEAP32[$131>>2] = $136;
     }
    }
    $138 = HEAP32[$11>>2]|0;
    __THREW__ = 0;
    $139 = (+invoke_diii(4678,($$2|0),($138|0),($4|0)));
    $140 = __THREW__; __THREW__ = 0;
    $141 = $140&1;
    if (!($141)) {
     HEAPF32[$5>>2] = $139;
     $142 = HEAP32[$13>>2]|0;
     __THREW__ = 0;
     invoke_viiii(4676,($9|0),($12|0),($142|0),($4|0));
     $143 = __THREW__; __THREW__ = 0;
     $144 = $143&1;
     if (!($144)) {
      $145 = ($$pre$i$i$i40|0)==(0|0);
      if ($145) {
       $185 = 1;
      } else {
       $146 = ((($$pre$i$i$i40)) + 12|0);
       $147 = HEAP32[$146>>2]|0;
       $148 = ((($$pre$i$i$i40)) + 16|0);
       $149 = HEAP32[$148>>2]|0;
       $150 = ($147|0)==($149|0);
       if ($150) {
        $151 = HEAP32[$152>>2]|0;
        $153 = ((($151)) + 36|0);
        $154 = HEAP32[$153>>2]|0;
        __THREW__ = 0;
        $155 = (invoke_ii($154|0,($$pre$i$i$i40|0))|0);
        $156 = __THREW__; __THREW__ = 0;
        $157 = $156&1;
        if ($157) {
         break;
        } else {
         $$0$i$i$i$i38 = $155;
        }
       } else {
        $158 = HEAP32[$147>>2]|0;
        $159 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($158)|0);
        $$0$i$i$i$i38 = $159;
       }
       $160 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
       $161 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i$i$i38,$160)|0);
       if ($161) {
        HEAP32[$1>>2] = 0;
        $185 = 1;
       } else {
        $185 = 0;
       }
      }
      $162 = ($$pre$i4$i$i46|0)==(0|0);
      do {
       if ($162) {
        label = 54;
       } else {
        $163 = ((($$pre$i4$i$i46)) + 12|0);
        $164 = HEAP32[$163>>2]|0;
        $165 = ((($$pre$i4$i$i46)) + 16|0);
        $166 = HEAP32[$165>>2]|0;
        $167 = ($164|0)==($166|0);
        if ($167) {
         $168 = HEAP32[$$pre$i4$i$i46>>2]|0;
         $169 = ((($168)) + 36|0);
         $170 = HEAP32[$169>>2]|0;
         __THREW__ = 0;
         $171 = (invoke_ii($170|0,($$pre$i4$i$i46|0))|0);
         $172 = __THREW__; __THREW__ = 0;
         $173 = $172&1;
         if ($173) {
          break L50;
         } else {
          $$0$i$i2$i$i44 = $171;
         }
        } else {
         $174 = HEAP32[$164>>2]|0;
         $175 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($174)|0);
         $$0$i$i2$i$i44 = $175;
        }
        $176 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
        $177 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i2$i$i44,$176)|0);
        if ($177) {
         HEAP32[$2>>2] = 0;
         label = 54;
         break;
        } else {
         if ($185) {
          break;
         } else {
          label = 56;
          break;
         }
        }
       }
      } while(0);
      if ((label|0) == 54) {
       if ($185) {
        label = 56;
       }
      }
      if ((label|0) == 56) {
       $178 = HEAP32[$4>>2]|0;
       $179 = $178 | 2;
       HEAP32[$4>>2] = $179;
      }
      $$sroa$0$0$copyload = HEAP32[$1>>2]|0;
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($10);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($9);
      STACKTOP = sp;return ($$sroa$0$0$copyload|0);
     }
    }
   }
  } while(0);
  $180 = ___cxa_find_matching_catch_2()|0;
  $181 = tempRet0;
  $$1 = $180;$$121 = $181;
 }
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($10);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($9);
 ___resumeException($$1|0);
 // unreachable;
 return (0)|0;
}
function __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE17__do_get_unsignedIyEES4_S4_S4_RNS_8ios_baseERjRT_($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$0$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i43 = 0, $$0$i$i2$i$i = 0, $$0$i$i2$i$i49 = 0, $$0$i$i39 = 0, $$024 = 0, $$1 = 0, $$125 = 0, $$127 = 0, $$2 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i45 = 0, $$pre$i4$i$i51 = 0, $$sroa$0$0$copyload = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0;
 var $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0;
 var $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0;
 var $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i$i = 0, $phitmp$i = 0, $phitmp$i34 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 304|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(304|0);
 $6 = sp + 200|0;
 $7 = sp + 196|0;
 $8 = sp + 184|0;
 $9 = sp + 172|0;
 $10 = sp + 168|0;
 $11 = sp + 8|0;
 $12 = sp + 4|0;
 $13 = sp;
 $14 = (__ZNSt3__214__num_get_base10__get_baseERNS_8ios_baseE($3)|0);
 __ZNSt3__29__num_getIwE17__stage2_int_prepERNS_8ios_baseEPwRw($8,$3,$6,$7);
 ;HEAP32[$9>>2]=0|0;HEAP32[$9+4>>2]=0|0;HEAP32[$9+8>>2]=0|0;
 $$0$i$i = 0;
 while(1) {
  $exitcond$i$i = ($$0$i$i|0)==(3);
  if ($exitcond$i$i) {
   break;
  }
  $15 = (($9) + ($$0$i$i<<2)|0);
  HEAP32[$15>>2] = 0;
  $16 = (($$0$i$i) + 1)|0;
  $$0$i$i = $16;
 }
 $17 = ((($9)) + 11|0);
 $18 = HEAP8[$17>>0]|0;
 $19 = ($18<<24>>24)<(0);
 if ($19) {
  $20 = ((($9)) + 8|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = $21 & 2147483647;
  $phitmp$i = (($22) + -1)|0;
  $23 = $phitmp$i;
 } else {
  $23 = 10;
 }
 __THREW__ = 0;
 invoke_viii(3434,($9|0),($23|0),0);
 $24 = __THREW__; __THREW__ = 0;
 $25 = $24&1;
 if ($25) {
  $88 = ___cxa_find_matching_catch_2()|0;
  $89 = tempRet0;
  $$1 = $88;$$127 = $89;
 } else {
  $26 = HEAP8[$17>>0]|0;
  $27 = ($26<<24>>24)<(0);
  $28 = HEAP32[$9>>2]|0;
  $29 = $27 ? $28 : $9;
  HEAP32[$10>>2] = $29;
  HEAP32[$12>>2] = $11;
  HEAP32[$13>>2] = 0;
  $30 = ((($9)) + 4|0);
  $31 = ((($9)) + 8|0);
  $$pre = HEAP32[$1>>2]|0;
  $$024 = $29;$$pre$i$i$i = $$pre;$182 = $$pre;
  L11: while(1) {
   $32 = ($$pre$i$i$i|0)==(0|0);
   if ($32) {
    $$pre$i$i$i45 = 0;$152 = 0;$183 = 1;
   } else {
    $33 = ((($$pre$i$i$i)) + 12|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = ((($$pre$i$i$i)) + 16|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = ($34|0)==($36|0);
    if ($37) {
     $38 = HEAP32[$$pre$i$i$i>>2]|0;
     $39 = ((($38)) + 36|0);
     $40 = HEAP32[$39>>2]|0;
     __THREW__ = 0;
     $41 = (invoke_ii($40|0,($$pre$i$i$i|0))|0);
     $42 = __THREW__; __THREW__ = 0;
     $43 = $42&1;
     if ($43) {
      break;
     } else {
      $$0$i$i$i$i = $41;
     }
    } else {
     $44 = HEAP32[$34>>2]|0;
     $45 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($44)|0);
     $$0$i$i$i$i = $45;
    }
    $46 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
    $47 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i$i$i,$46)|0);
    if ($47) {
     HEAP32[$1>>2] = 0;
     $$pre$i$i$i45 = 0;$152 = 0;$183 = 1;
    } else {
     $$pre$i$i$i45 = $$pre$i$i$i;$152 = $182;$183 = 0;
    }
   }
   $48 = HEAP32[$2>>2]|0;
   $49 = ($48|0)==(0|0);
   do {
    if ($49) {
     label = 20;
    } else {
     $50 = ((($48)) + 12|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = ((($48)) + 16|0);
     $53 = HEAP32[$52>>2]|0;
     $54 = ($51|0)==($53|0);
     if ($54) {
      $55 = HEAP32[$48>>2]|0;
      $56 = ((($55)) + 36|0);
      $57 = HEAP32[$56>>2]|0;
      __THREW__ = 0;
      $58 = (invoke_ii($57|0,($48|0))|0);
      $59 = __THREW__; __THREW__ = 0;
      $60 = $59&1;
      if ($60) {
       break L11;
      } else {
       $$0$i$i2$i$i = $58;
      }
     } else {
      $61 = HEAP32[$51>>2]|0;
      $62 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($61)|0);
      $$0$i$i2$i$i = $62;
     }
     $63 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
     $64 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i2$i$i,$63)|0);
     if ($64) {
      HEAP32[$2>>2] = 0;
      label = 20;
      break;
     } else {
      if ($183) {
       $184 = $48;
       break;
      } else {
       $$2 = $$024;$$pre$i4$i$i51 = $48;
       label = 37;
       break L11;
      }
     }
    }
   } while(0);
   if ((label|0) == 20) {
    label = 0;
    if ($183) {
     $$2 = $$024;$$pre$i4$i$i51 = 0;
     label = 37;
     break;
    } else {
     $184 = 0;
    }
   }
   $65 = HEAP32[$10>>2]|0;
   $66 = HEAP8[$17>>0]|0;
   $67 = ($66<<24>>24)<(0);
   $68 = HEAP32[$30>>2]|0;
   $69 = $66&255;
   $70 = $67 ? $68 : $69;
   $71 = (($$024) + ($70)|0);
   $72 = ($65|0)==($71|0);
   if ($72) {
    $73 = $70 << 1;
    __THREW__ = 0;
    invoke_viii(3434,($9|0),($73|0),0);
    $74 = __THREW__; __THREW__ = 0;
    $75 = $74&1;
    if ($75) {
     break;
    }
    $76 = HEAP8[$17>>0]|0;
    $77 = ($76<<24>>24)<(0);
    if ($77) {
     $78 = HEAP32[$31>>2]|0;
     $79 = $78 & 2147483647;
     $phitmp$i34 = (($79) + -1)|0;
     $80 = $phitmp$i34;
    } else {
     $80 = 10;
    }
    __THREW__ = 0;
    invoke_viii(3434,($9|0),($80|0),0);
    $81 = __THREW__; __THREW__ = 0;
    $82 = $81&1;
    if ($82) {
     break;
    }
    $83 = HEAP8[$17>>0]|0;
    $84 = ($83<<24>>24)<(0);
    $85 = HEAP32[$9>>2]|0;
    $86 = $84 ? $85 : $9;
    $87 = (($86) + ($70)|0);
    HEAP32[$10>>2] = $87;
    $$125 = $86;
   } else {
    $$125 = $$024;
   }
   $90 = ((($$pre$i$i$i45)) + 12|0);
   $91 = HEAP32[$90>>2]|0;
   $92 = ((($$pre$i$i$i45)) + 16|0);
   $93 = HEAP32[$92>>2]|0;
   $94 = ($91|0)==($93|0);
   if ($94) {
    $95 = HEAP32[$$pre$i$i$i45>>2]|0;
    $96 = ((($95)) + 36|0);
    $97 = HEAP32[$96>>2]|0;
    __THREW__ = 0;
    $98 = (invoke_ii($97|0,($$pre$i$i$i45|0))|0);
    $99 = __THREW__; __THREW__ = 0;
    $100 = $99&1;
    if ($100) {
     break;
    } else {
     $$0$i$i39 = $98;
    }
   } else {
    $101 = HEAP32[$91>>2]|0;
    $102 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($101)|0);
    $$0$i$i39 = $102;
   }
   $103 = HEAP32[$7>>2]|0;
   __THREW__ = 0;
   $104 = (invoke_iiiiiiiiiii(4687,($$0$i$i39|0),($14|0),($$125|0),($10|0),($13|0),($103|0),($8|0),($11|0),($12|0),($6|0))|0);
   $105 = __THREW__; __THREW__ = 0;
   $106 = $105&1;
   if ($106) {
    break;
   }
   $107 = ($104|0)==(0);
   if (!($107)) {
    $$2 = $$125;$$pre$i4$i$i51 = $184;
    label = 37;
    break;
   }
   $108 = HEAP32[$90>>2]|0;
   $109 = HEAP32[$92>>2]|0;
   $110 = ($108|0)==($109|0);
   if ($110) {
    $111 = HEAP32[$$pre$i$i$i45>>2]|0;
    $112 = ((($111)) + 40|0);
    $113 = HEAP32[$112>>2]|0;
    __THREW__ = 0;
    (invoke_ii($113|0,($$pre$i$i$i45|0))|0);
    $114 = __THREW__; __THREW__ = 0;
    $115 = $114&1;
    if ($115) {
     break;
    } else {
     $$024 = $$125;$$pre$i$i$i = $$pre$i$i$i45;$182 = $152;
     continue;
    }
   } else {
    $116 = ((($108)) + 4|0);
    HEAP32[$90>>2] = $116;
    $117 = HEAP32[$108>>2]|0;
    (__ZNSt3__211char_traitsIwE11to_int_typeEw($117)|0);
    $$024 = $$125;$$pre$i$i$i = $$pre$i$i$i45;$182 = $152;
    continue;
   }
  }
  L50: do {
   if ((label|0) == 37) {
    $118 = ((($8)) + 11|0);
    $119 = HEAP8[$118>>0]|0;
    $120 = ($119<<24>>24)<(0);
    $121 = ((($8)) + 4|0);
    $122 = HEAP32[$121>>2]|0;
    $123 = $119&255;
    $124 = $120 ? $122 : $123;
    $125 = ($124|0)==(0);
    if (!($125)) {
     $126 = HEAP32[$12>>2]|0;
     $127 = $126;
     $128 = $11;
     $129 = (($127) - ($128))|0;
     $130 = ($129|0)<(160);
     if ($130) {
      $131 = HEAP32[$13>>2]|0;
      $132 = ((($126)) + 4|0);
      HEAP32[$12>>2] = $132;
      HEAP32[$126>>2] = $131;
     }
    }
    $133 = HEAP32[$10>>2]|0;
    __THREW__ = 0;
    $134 = (invoke_iiiii(4679,($$2|0),($133|0),($4|0),($14|0))|0);
    $135 = tempRet0;
    $136 = __THREW__; __THREW__ = 0;
    $137 = $136&1;
    if (!($137)) {
     $138 = $5;
     $139 = $138;
     HEAP32[$139>>2] = $134;
     $140 = (($138) + 4)|0;
     $141 = $140;
     HEAP32[$141>>2] = $135;
     $142 = HEAP32[$12>>2]|0;
     __THREW__ = 0;
     invoke_viiii(4676,($8|0),($11|0),($142|0),($4|0));
     $143 = __THREW__; __THREW__ = 0;
     $144 = $143&1;
     if (!($144)) {
      $145 = ($$pre$i$i$i45|0)==(0|0);
      if ($145) {
       $185 = 1;
      } else {
       $146 = ((($$pre$i$i$i45)) + 12|0);
       $147 = HEAP32[$146>>2]|0;
       $148 = ((($$pre$i$i$i45)) + 16|0);
       $149 = HEAP32[$148>>2]|0;
       $150 = ($147|0)==($149|0);
       if ($150) {
        $151 = HEAP32[$152>>2]|0;
        $153 = ((($151)) + 36|0);
        $154 = HEAP32[$153>>2]|0;
        __THREW__ = 0;
        $155 = (invoke_ii($154|0,($$pre$i$i$i45|0))|0);
        $156 = __THREW__; __THREW__ = 0;
        $157 = $156&1;
        if ($157) {
         break;
        } else {
         $$0$i$i$i$i43 = $155;
        }
       } else {
        $158 = HEAP32[$147>>2]|0;
        $159 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($158)|0);
        $$0$i$i$i$i43 = $159;
       }
       $160 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
       $161 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i$i$i43,$160)|0);
       if ($161) {
        HEAP32[$1>>2] = 0;
        $185 = 1;
       } else {
        $185 = 0;
       }
      }
      $162 = ($$pre$i4$i$i51|0)==(0|0);
      do {
       if ($162) {
        label = 54;
       } else {
        $163 = ((($$pre$i4$i$i51)) + 12|0);
        $164 = HEAP32[$163>>2]|0;
        $165 = ((($$pre$i4$i$i51)) + 16|0);
        $166 = HEAP32[$165>>2]|0;
        $167 = ($164|0)==($166|0);
        if ($167) {
         $168 = HEAP32[$$pre$i4$i$i51>>2]|0;
         $169 = ((($168)) + 36|0);
         $170 = HEAP32[$169>>2]|0;
         __THREW__ = 0;
         $171 = (invoke_ii($170|0,($$pre$i4$i$i51|0))|0);
         $172 = __THREW__; __THREW__ = 0;
         $173 = $172&1;
         if ($173) {
          break L50;
         } else {
          $$0$i$i2$i$i49 = $171;
         }
        } else {
         $174 = HEAP32[$164>>2]|0;
         $175 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($174)|0);
         $$0$i$i2$i$i49 = $175;
        }
        $176 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
        $177 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i2$i$i49,$176)|0);
        if ($177) {
         HEAP32[$2>>2] = 0;
         label = 54;
         break;
        } else {
         if ($185) {
          break;
         } else {
          label = 56;
          break;
         }
        }
       }
      } while(0);
      if ((label|0) == 54) {
       if ($185) {
        label = 56;
       }
      }
      if ((label|0) == 56) {
       $178 = HEAP32[$4>>2]|0;
       $179 = $178 | 2;
       HEAP32[$4>>2] = $179;
      }
      $$sroa$0$0$copyload = HEAP32[$1>>2]|0;
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($9);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($8);
      STACKTOP = sp;return ($$sroa$0$0$copyload|0);
     }
    }
   }
  } while(0);
  $180 = ___cxa_find_matching_catch_2()|0;
  $181 = tempRet0;
  $$1 = $180;$$127 = $181;
 }
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($9);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($8);
 ___resumeException($$1|0);
 // unreachable;
 return (0)|0;
}
function __ZNSt3__29__num_getIwE17__stage2_int_prepERNS_8ios_baseEPwRw($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $4 = sp;
 __ZNKSt3__28ios_base6getlocEv($4,$1);
 __THREW__ = 0;
 $5 = (invoke_iii(3255,($4|0),(215220|0))|0);
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if (!($7)) {
  $8 = HEAP32[$5>>2]|0;
  $9 = ((($8)) + 48|0);
  $10 = HEAP32[$9>>2]|0;
  __THREW__ = 0;
  (invoke_iiiii($10|0,($5|0),(202614|0),((202640)|0),($2|0))|0);
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if (!($12)) {
   __THREW__ = 0;
   $13 = (invoke_iii(3255,($4|0),(215228|0))|0);
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if (!($15)) {
    $16 = HEAP32[$13>>2]|0;
    $17 = ((($16)) + 16|0);
    $18 = HEAP32[$17>>2]|0;
    __THREW__ = 0;
    $19 = (invoke_ii($18|0,($13|0))|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if (!($21)) {
     HEAP32[$3>>2] = $19;
     $22 = HEAP32[$13>>2]|0;
     $23 = ((($22)) + 20|0);
     $24 = HEAP32[$23>>2]|0;
     __THREW__ = 0;
     invoke_vii($24|0,($0|0),($13|0));
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if (!($26)) {
      __ZNSt3__26localeD2Ev($4);
      STACKTOP = sp;return;
     }
    }
   }
  }
 }
 $27 = ___cxa_find_matching_catch_2()|0;
 $28 = tempRet0;
 __ZNSt3__26localeD2Ev($4);
 ___resumeException($27|0);
 // unreachable;
}
function __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE17__do_get_unsignedImEES4_S4_S4_RNS_8ios_baseERjRT_($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$0$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i43 = 0, $$0$i$i2$i$i = 0, $$0$i$i2$i$i49 = 0, $$0$i$i39 = 0, $$024 = 0, $$1 = 0, $$125 = 0, $$127 = 0, $$2 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i45 = 0, $$pre$i4$i$i51 = 0, $$sroa$0$0$copyload = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0;
 var $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0;
 var $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0;
 var $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i$i = 0, $phitmp$i = 0, $phitmp$i34 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 304|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(304|0);
 $6 = sp + 200|0;
 $7 = sp + 196|0;
 $8 = sp + 184|0;
 $9 = sp + 172|0;
 $10 = sp + 168|0;
 $11 = sp + 8|0;
 $12 = sp + 4|0;
 $13 = sp;
 $14 = (__ZNSt3__214__num_get_base10__get_baseERNS_8ios_baseE($3)|0);
 __ZNSt3__29__num_getIwE17__stage2_int_prepERNS_8ios_baseEPwRw($8,$3,$6,$7);
 ;HEAP32[$9>>2]=0|0;HEAP32[$9+4>>2]=0|0;HEAP32[$9+8>>2]=0|0;
 $$0$i$i = 0;
 while(1) {
  $exitcond$i$i = ($$0$i$i|0)==(3);
  if ($exitcond$i$i) {
   break;
  }
  $15 = (($9) + ($$0$i$i<<2)|0);
  HEAP32[$15>>2] = 0;
  $16 = (($$0$i$i) + 1)|0;
  $$0$i$i = $16;
 }
 $17 = ((($9)) + 11|0);
 $18 = HEAP8[$17>>0]|0;
 $19 = ($18<<24>>24)<(0);
 if ($19) {
  $20 = ((($9)) + 8|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = $21 & 2147483647;
  $phitmp$i = (($22) + -1)|0;
  $23 = $phitmp$i;
 } else {
  $23 = 10;
 }
 __THREW__ = 0;
 invoke_viii(3434,($9|0),($23|0),0);
 $24 = __THREW__; __THREW__ = 0;
 $25 = $24&1;
 if ($25) {
  $88 = ___cxa_find_matching_catch_2()|0;
  $89 = tempRet0;
  $$1 = $88;$$127 = $89;
 } else {
  $26 = HEAP8[$17>>0]|0;
  $27 = ($26<<24>>24)<(0);
  $28 = HEAP32[$9>>2]|0;
  $29 = $27 ? $28 : $9;
  HEAP32[$10>>2] = $29;
  HEAP32[$12>>2] = $11;
  HEAP32[$13>>2] = 0;
  $30 = ((($9)) + 4|0);
  $31 = ((($9)) + 8|0);
  $$pre = HEAP32[$1>>2]|0;
  $$024 = $29;$$pre$i$i$i = $$pre;$177 = $$pre;
  L11: while(1) {
   $32 = ($$pre$i$i$i|0)==(0|0);
   if ($32) {
    $$pre$i$i$i45 = 0;$147 = 0;$178 = 1;
   } else {
    $33 = ((($$pre$i$i$i)) + 12|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = ((($$pre$i$i$i)) + 16|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = ($34|0)==($36|0);
    if ($37) {
     $38 = HEAP32[$$pre$i$i$i>>2]|0;
     $39 = ((($38)) + 36|0);
     $40 = HEAP32[$39>>2]|0;
     __THREW__ = 0;
     $41 = (invoke_ii($40|0,($$pre$i$i$i|0))|0);
     $42 = __THREW__; __THREW__ = 0;
     $43 = $42&1;
     if ($43) {
      break;
     } else {
      $$0$i$i$i$i = $41;
     }
    } else {
     $44 = HEAP32[$34>>2]|0;
     $45 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($44)|0);
     $$0$i$i$i$i = $45;
    }
    $46 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
    $47 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i$i$i,$46)|0);
    if ($47) {
     HEAP32[$1>>2] = 0;
     $$pre$i$i$i45 = 0;$147 = 0;$178 = 1;
    } else {
     $$pre$i$i$i45 = $$pre$i$i$i;$147 = $177;$178 = 0;
    }
   }
   $48 = HEAP32[$2>>2]|0;
   $49 = ($48|0)==(0|0);
   do {
    if ($49) {
     label = 20;
    } else {
     $50 = ((($48)) + 12|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = ((($48)) + 16|0);
     $53 = HEAP32[$52>>2]|0;
     $54 = ($51|0)==($53|0);
     if ($54) {
      $55 = HEAP32[$48>>2]|0;
      $56 = ((($55)) + 36|0);
      $57 = HEAP32[$56>>2]|0;
      __THREW__ = 0;
      $58 = (invoke_ii($57|0,($48|0))|0);
      $59 = __THREW__; __THREW__ = 0;
      $60 = $59&1;
      if ($60) {
       break L11;
      } else {
       $$0$i$i2$i$i = $58;
      }
     } else {
      $61 = HEAP32[$51>>2]|0;
      $62 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($61)|0);
      $$0$i$i2$i$i = $62;
     }
     $63 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
     $64 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i2$i$i,$63)|0);
     if ($64) {
      HEAP32[$2>>2] = 0;
      label = 20;
      break;
     } else {
      if ($178) {
       $179 = $48;
       break;
      } else {
       $$2 = $$024;$$pre$i4$i$i51 = $48;
       label = 37;
       break L11;
      }
     }
    }
   } while(0);
   if ((label|0) == 20) {
    label = 0;
    if ($178) {
     $$2 = $$024;$$pre$i4$i$i51 = 0;
     label = 37;
     break;
    } else {
     $179 = 0;
    }
   }
   $65 = HEAP32[$10>>2]|0;
   $66 = HEAP8[$17>>0]|0;
   $67 = ($66<<24>>24)<(0);
   $68 = HEAP32[$30>>2]|0;
   $69 = $66&255;
   $70 = $67 ? $68 : $69;
   $71 = (($$024) + ($70)|0);
   $72 = ($65|0)==($71|0);
   if ($72) {
    $73 = $70 << 1;
    __THREW__ = 0;
    invoke_viii(3434,($9|0),($73|0),0);
    $74 = __THREW__; __THREW__ = 0;
    $75 = $74&1;
    if ($75) {
     break;
    }
    $76 = HEAP8[$17>>0]|0;
    $77 = ($76<<24>>24)<(0);
    if ($77) {
     $78 = HEAP32[$31>>2]|0;
     $79 = $78 & 2147483647;
     $phitmp$i34 = (($79) + -1)|0;
     $80 = $phitmp$i34;
    } else {
     $80 = 10;
    }
    __THREW__ = 0;
    invoke_viii(3434,($9|0),($80|0),0);
    $81 = __THREW__; __THREW__ = 0;
    $82 = $81&1;
    if ($82) {
     break;
    }
    $83 = HEAP8[$17>>0]|0;
    $84 = ($83<<24>>24)<(0);
    $85 = HEAP32[$9>>2]|0;
    $86 = $84 ? $85 : $9;
    $87 = (($86) + ($70)|0);
    HEAP32[$10>>2] = $87;
    $$125 = $86;
   } else {
    $$125 = $$024;
   }
   $90 = ((($$pre$i$i$i45)) + 12|0);
   $91 = HEAP32[$90>>2]|0;
   $92 = ((($$pre$i$i$i45)) + 16|0);
   $93 = HEAP32[$92>>2]|0;
   $94 = ($91|0)==($93|0);
   if ($94) {
    $95 = HEAP32[$$pre$i$i$i45>>2]|0;
    $96 = ((($95)) + 36|0);
    $97 = HEAP32[$96>>2]|0;
    __THREW__ = 0;
    $98 = (invoke_ii($97|0,($$pre$i$i$i45|0))|0);
    $99 = __THREW__; __THREW__ = 0;
    $100 = $99&1;
    if ($100) {
     break;
    } else {
     $$0$i$i39 = $98;
    }
   } else {
    $101 = HEAP32[$91>>2]|0;
    $102 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($101)|0);
    $$0$i$i39 = $102;
   }
   $103 = HEAP32[$7>>2]|0;
   __THREW__ = 0;
   $104 = (invoke_iiiiiiiiiii(4687,($$0$i$i39|0),($14|0),($$125|0),($10|0),($13|0),($103|0),($8|0),($11|0),($12|0),($6|0))|0);
   $105 = __THREW__; __THREW__ = 0;
   $106 = $105&1;
   if ($106) {
    break;
   }
   $107 = ($104|0)==(0);
   if (!($107)) {
    $$2 = $$125;$$pre$i4$i$i51 = $179;
    label = 37;
    break;
   }
   $108 = HEAP32[$90>>2]|0;
   $109 = HEAP32[$92>>2]|0;
   $110 = ($108|0)==($109|0);
   if ($110) {
    $111 = HEAP32[$$pre$i$i$i45>>2]|0;
    $112 = ((($111)) + 40|0);
    $113 = HEAP32[$112>>2]|0;
    __THREW__ = 0;
    (invoke_ii($113|0,($$pre$i$i$i45|0))|0);
    $114 = __THREW__; __THREW__ = 0;
    $115 = $114&1;
    if ($115) {
     break;
    } else {
     $$024 = $$125;$$pre$i$i$i = $$pre$i$i$i45;$177 = $147;
     continue;
    }
   } else {
    $116 = ((($108)) + 4|0);
    HEAP32[$90>>2] = $116;
    $117 = HEAP32[$108>>2]|0;
    (__ZNSt3__211char_traitsIwE11to_int_typeEw($117)|0);
    $$024 = $$125;$$pre$i$i$i = $$pre$i$i$i45;$177 = $147;
    continue;
   }
  }
  L50: do {
   if ((label|0) == 37) {
    $118 = ((($8)) + 11|0);
    $119 = HEAP8[$118>>0]|0;
    $120 = ($119<<24>>24)<(0);
    $121 = ((($8)) + 4|0);
    $122 = HEAP32[$121>>2]|0;
    $123 = $119&255;
    $124 = $120 ? $122 : $123;
    $125 = ($124|0)==(0);
    if (!($125)) {
     $126 = HEAP32[$12>>2]|0;
     $127 = $126;
     $128 = $11;
     $129 = (($127) - ($128))|0;
     $130 = ($129|0)<(160);
     if ($130) {
      $131 = HEAP32[$13>>2]|0;
      $132 = ((($126)) + 4|0);
      HEAP32[$12>>2] = $132;
      HEAP32[$126>>2] = $131;
     }
    }
    $133 = HEAP32[$10>>2]|0;
    __THREW__ = 0;
    $134 = (invoke_iiiii(4680,($$2|0),($133|0),($4|0),($14|0))|0);
    $135 = __THREW__; __THREW__ = 0;
    $136 = $135&1;
    if (!($136)) {
     HEAP32[$5>>2] = $134;
     $137 = HEAP32[$12>>2]|0;
     __THREW__ = 0;
     invoke_viiii(4676,($8|0),($11|0),($137|0),($4|0));
     $138 = __THREW__; __THREW__ = 0;
     $139 = $138&1;
     if (!($139)) {
      $140 = ($$pre$i$i$i45|0)==(0|0);
      if ($140) {
       $180 = 1;
      } else {
       $141 = ((($$pre$i$i$i45)) + 12|0);
       $142 = HEAP32[$141>>2]|0;
       $143 = ((($$pre$i$i$i45)) + 16|0);
       $144 = HEAP32[$143>>2]|0;
       $145 = ($142|0)==($144|0);
       if ($145) {
        $146 = HEAP32[$147>>2]|0;
        $148 = ((($146)) + 36|0);
        $149 = HEAP32[$148>>2]|0;
        __THREW__ = 0;
        $150 = (invoke_ii($149|0,($$pre$i$i$i45|0))|0);
        $151 = __THREW__; __THREW__ = 0;
        $152 = $151&1;
        if ($152) {
         break;
        } else {
         $$0$i$i$i$i43 = $150;
        }
       } else {
        $153 = HEAP32[$142>>2]|0;
        $154 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($153)|0);
        $$0$i$i$i$i43 = $154;
       }
       $155 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
       $156 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i$i$i43,$155)|0);
       if ($156) {
        HEAP32[$1>>2] = 0;
        $180 = 1;
       } else {
        $180 = 0;
       }
      }
      $157 = ($$pre$i4$i$i51|0)==(0|0);
      do {
       if ($157) {
        label = 54;
       } else {
        $158 = ((($$pre$i4$i$i51)) + 12|0);
        $159 = HEAP32[$158>>2]|0;
        $160 = ((($$pre$i4$i$i51)) + 16|0);
        $161 = HEAP32[$160>>2]|0;
        $162 = ($159|0)==($161|0);
        if ($162) {
         $163 = HEAP32[$$pre$i4$i$i51>>2]|0;
         $164 = ((($163)) + 36|0);
         $165 = HEAP32[$164>>2]|0;
         __THREW__ = 0;
         $166 = (invoke_ii($165|0,($$pre$i4$i$i51|0))|0);
         $167 = __THREW__; __THREW__ = 0;
         $168 = $167&1;
         if ($168) {
          break L50;
         } else {
          $$0$i$i2$i$i49 = $166;
         }
        } else {
         $169 = HEAP32[$159>>2]|0;
         $170 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($169)|0);
         $$0$i$i2$i$i49 = $170;
        }
        $171 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
        $172 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i2$i$i49,$171)|0);
        if ($172) {
         HEAP32[$2>>2] = 0;
         label = 54;
         break;
        } else {
         if ($180) {
          break;
         } else {
          label = 56;
          break;
         }
        }
       }
      } while(0);
      if ((label|0) == 54) {
       if ($180) {
        label = 56;
       }
      }
      if ((label|0) == 56) {
       $173 = HEAP32[$4>>2]|0;
       $174 = $173 | 2;
       HEAP32[$4>>2] = $174;
      }
      $$sroa$0$0$copyload = HEAP32[$1>>2]|0;
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($9);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($8);
      STACKTOP = sp;return ($$sroa$0$0$copyload|0);
     }
    }
   }
  } while(0);
  $175 = ___cxa_find_matching_catch_2()|0;
  $176 = tempRet0;
  $$1 = $175;$$127 = $176;
 }
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($9);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($8);
 ___resumeException($$1|0);
 // unreachable;
 return (0)|0;
}
function __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE17__do_get_unsignedIjEES4_S4_S4_RNS_8ios_baseERjRT_($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$0$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i43 = 0, $$0$i$i2$i$i = 0, $$0$i$i2$i$i49 = 0, $$0$i$i39 = 0, $$024 = 0, $$1 = 0, $$125 = 0, $$127 = 0, $$2 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i45 = 0, $$pre$i4$i$i51 = 0, $$sroa$0$0$copyload = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0;
 var $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0;
 var $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0;
 var $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i$i = 0, $phitmp$i = 0, $phitmp$i34 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 304|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(304|0);
 $6 = sp + 200|0;
 $7 = sp + 196|0;
 $8 = sp + 184|0;
 $9 = sp + 172|0;
 $10 = sp + 168|0;
 $11 = sp + 8|0;
 $12 = sp + 4|0;
 $13 = sp;
 $14 = (__ZNSt3__214__num_get_base10__get_baseERNS_8ios_baseE($3)|0);
 __ZNSt3__29__num_getIwE17__stage2_int_prepERNS_8ios_baseEPwRw($8,$3,$6,$7);
 ;HEAP32[$9>>2]=0|0;HEAP32[$9+4>>2]=0|0;HEAP32[$9+8>>2]=0|0;
 $$0$i$i = 0;
 while(1) {
  $exitcond$i$i = ($$0$i$i|0)==(3);
  if ($exitcond$i$i) {
   break;
  }
  $15 = (($9) + ($$0$i$i<<2)|0);
  HEAP32[$15>>2] = 0;
  $16 = (($$0$i$i) + 1)|0;
  $$0$i$i = $16;
 }
 $17 = ((($9)) + 11|0);
 $18 = HEAP8[$17>>0]|0;
 $19 = ($18<<24>>24)<(0);
 if ($19) {
  $20 = ((($9)) + 8|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = $21 & 2147483647;
  $phitmp$i = (($22) + -1)|0;
  $23 = $phitmp$i;
 } else {
  $23 = 10;
 }
 __THREW__ = 0;
 invoke_viii(3434,($9|0),($23|0),0);
 $24 = __THREW__; __THREW__ = 0;
 $25 = $24&1;
 if ($25) {
  $88 = ___cxa_find_matching_catch_2()|0;
  $89 = tempRet0;
  $$1 = $88;$$127 = $89;
 } else {
  $26 = HEAP8[$17>>0]|0;
  $27 = ($26<<24>>24)<(0);
  $28 = HEAP32[$9>>2]|0;
  $29 = $27 ? $28 : $9;
  HEAP32[$10>>2] = $29;
  HEAP32[$12>>2] = $11;
  HEAP32[$13>>2] = 0;
  $30 = ((($9)) + 4|0);
  $31 = ((($9)) + 8|0);
  $$pre = HEAP32[$1>>2]|0;
  $$024 = $29;$$pre$i$i$i = $$pre;$177 = $$pre;
  L11: while(1) {
   $32 = ($$pre$i$i$i|0)==(0|0);
   if ($32) {
    $$pre$i$i$i45 = 0;$147 = 0;$178 = 1;
   } else {
    $33 = ((($$pre$i$i$i)) + 12|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = ((($$pre$i$i$i)) + 16|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = ($34|0)==($36|0);
    if ($37) {
     $38 = HEAP32[$$pre$i$i$i>>2]|0;
     $39 = ((($38)) + 36|0);
     $40 = HEAP32[$39>>2]|0;
     __THREW__ = 0;
     $41 = (invoke_ii($40|0,($$pre$i$i$i|0))|0);
     $42 = __THREW__; __THREW__ = 0;
     $43 = $42&1;
     if ($43) {
      break;
     } else {
      $$0$i$i$i$i = $41;
     }
    } else {
     $44 = HEAP32[$34>>2]|0;
     $45 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($44)|0);
     $$0$i$i$i$i = $45;
    }
    $46 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
    $47 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i$i$i,$46)|0);
    if ($47) {
     HEAP32[$1>>2] = 0;
     $$pre$i$i$i45 = 0;$147 = 0;$178 = 1;
    } else {
     $$pre$i$i$i45 = $$pre$i$i$i;$147 = $177;$178 = 0;
    }
   }
   $48 = HEAP32[$2>>2]|0;
   $49 = ($48|0)==(0|0);
   do {
    if ($49) {
     label = 20;
    } else {
     $50 = ((($48)) + 12|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = ((($48)) + 16|0);
     $53 = HEAP32[$52>>2]|0;
     $54 = ($51|0)==($53|0);
     if ($54) {
      $55 = HEAP32[$48>>2]|0;
      $56 = ((($55)) + 36|0);
      $57 = HEAP32[$56>>2]|0;
      __THREW__ = 0;
      $58 = (invoke_ii($57|0,($48|0))|0);
      $59 = __THREW__; __THREW__ = 0;
      $60 = $59&1;
      if ($60) {
       break L11;
      } else {
       $$0$i$i2$i$i = $58;
      }
     } else {
      $61 = HEAP32[$51>>2]|0;
      $62 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($61)|0);
      $$0$i$i2$i$i = $62;
     }
     $63 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
     $64 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i2$i$i,$63)|0);
     if ($64) {
      HEAP32[$2>>2] = 0;
      label = 20;
      break;
     } else {
      if ($178) {
       $179 = $48;
       break;
      } else {
       $$2 = $$024;$$pre$i4$i$i51 = $48;
       label = 37;
       break L11;
      }
     }
    }
   } while(0);
   if ((label|0) == 20) {
    label = 0;
    if ($178) {
     $$2 = $$024;$$pre$i4$i$i51 = 0;
     label = 37;
     break;
    } else {
     $179 = 0;
    }
   }
   $65 = HEAP32[$10>>2]|0;
   $66 = HEAP8[$17>>0]|0;
   $67 = ($66<<24>>24)<(0);
   $68 = HEAP32[$30>>2]|0;
   $69 = $66&255;
   $70 = $67 ? $68 : $69;
   $71 = (($$024) + ($70)|0);
   $72 = ($65|0)==($71|0);
   if ($72) {
    $73 = $70 << 1;
    __THREW__ = 0;
    invoke_viii(3434,($9|0),($73|0),0);
    $74 = __THREW__; __THREW__ = 0;
    $75 = $74&1;
    if ($75) {
     break;
    }
    $76 = HEAP8[$17>>0]|0;
    $77 = ($76<<24>>24)<(0);
    if ($77) {
     $78 = HEAP32[$31>>2]|0;
     $79 = $78 & 2147483647;
     $phitmp$i34 = (($79) + -1)|0;
     $80 = $phitmp$i34;
    } else {
     $80 = 10;
    }
    __THREW__ = 0;
    invoke_viii(3434,($9|0),($80|0),0);
    $81 = __THREW__; __THREW__ = 0;
    $82 = $81&1;
    if ($82) {
     break;
    }
    $83 = HEAP8[$17>>0]|0;
    $84 = ($83<<24>>24)<(0);
    $85 = HEAP32[$9>>2]|0;
    $86 = $84 ? $85 : $9;
    $87 = (($86) + ($70)|0);
    HEAP32[$10>>2] = $87;
    $$125 = $86;
   } else {
    $$125 = $$024;
   }
   $90 = ((($$pre$i$i$i45)) + 12|0);
   $91 = HEAP32[$90>>2]|0;
   $92 = ((($$pre$i$i$i45)) + 16|0);
   $93 = HEAP32[$92>>2]|0;
   $94 = ($91|0)==($93|0);
   if ($94) {
    $95 = HEAP32[$$pre$i$i$i45>>2]|0;
    $96 = ((($95)) + 36|0);
    $97 = HEAP32[$96>>2]|0;
    __THREW__ = 0;
    $98 = (invoke_ii($97|0,($$pre$i$i$i45|0))|0);
    $99 = __THREW__; __THREW__ = 0;
    $100 = $99&1;
    if ($100) {
     break;
    } else {
     $$0$i$i39 = $98;
    }
   } else {
    $101 = HEAP32[$91>>2]|0;
    $102 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($101)|0);
    $$0$i$i39 = $102;
   }
   $103 = HEAP32[$7>>2]|0;
   __THREW__ = 0;
   $104 = (invoke_iiiiiiiiiii(4687,($$0$i$i39|0),($14|0),($$125|0),($10|0),($13|0),($103|0),($8|0),($11|0),($12|0),($6|0))|0);
   $105 = __THREW__; __THREW__ = 0;
   $106 = $105&1;
   if ($106) {
    break;
   }
   $107 = ($104|0)==(0);
   if (!($107)) {
    $$2 = $$125;$$pre$i4$i$i51 = $179;
    label = 37;
    break;
   }
   $108 = HEAP32[$90>>2]|0;
   $109 = HEAP32[$92>>2]|0;
   $110 = ($108|0)==($109|0);
   if ($110) {
    $111 = HEAP32[$$pre$i$i$i45>>2]|0;
    $112 = ((($111)) + 40|0);
    $113 = HEAP32[$112>>2]|0;
    __THREW__ = 0;
    (invoke_ii($113|0,($$pre$i$i$i45|0))|0);
    $114 = __THREW__; __THREW__ = 0;
    $115 = $114&1;
    if ($115) {
     break;
    } else {
     $$024 = $$125;$$pre$i$i$i = $$pre$i$i$i45;$177 = $147;
     continue;
    }
   } else {
    $116 = ((($108)) + 4|0);
    HEAP32[$90>>2] = $116;
    $117 = HEAP32[$108>>2]|0;
    (__ZNSt3__211char_traitsIwE11to_int_typeEw($117)|0);
    $$024 = $$125;$$pre$i$i$i = $$pre$i$i$i45;$177 = $147;
    continue;
   }
  }
  L50: do {
   if ((label|0) == 37) {
    $118 = ((($8)) + 11|0);
    $119 = HEAP8[$118>>0]|0;
    $120 = ($119<<24>>24)<(0);
    $121 = ((($8)) + 4|0);
    $122 = HEAP32[$121>>2]|0;
    $123 = $119&255;
    $124 = $120 ? $122 : $123;
    $125 = ($124|0)==(0);
    if (!($125)) {
     $126 = HEAP32[$12>>2]|0;
     $127 = $126;
     $128 = $11;
     $129 = (($127) - ($128))|0;
     $130 = ($129|0)<(160);
     if ($130) {
      $131 = HEAP32[$13>>2]|0;
      $132 = ((($126)) + 4|0);
      HEAP32[$12>>2] = $132;
      HEAP32[$126>>2] = $131;
     }
    }
    $133 = HEAP32[$10>>2]|0;
    __THREW__ = 0;
    $134 = (invoke_iiiii(4681,($$2|0),($133|0),($4|0),($14|0))|0);
    $135 = __THREW__; __THREW__ = 0;
    $136 = $135&1;
    if (!($136)) {
     HEAP32[$5>>2] = $134;
     $137 = HEAP32[$12>>2]|0;
     __THREW__ = 0;
     invoke_viiii(4676,($8|0),($11|0),($137|0),($4|0));
     $138 = __THREW__; __THREW__ = 0;
     $139 = $138&1;
     if (!($139)) {
      $140 = ($$pre$i$i$i45|0)==(0|0);
      if ($140) {
       $180 = 1;
      } else {
       $141 = ((($$pre$i$i$i45)) + 12|0);
       $142 = HEAP32[$141>>2]|0;
       $143 = ((($$pre$i$i$i45)) + 16|0);
       $144 = HEAP32[$143>>2]|0;
       $145 = ($142|0)==($144|0);
       if ($145) {
        $146 = HEAP32[$147>>2]|0;
        $148 = ((($146)) + 36|0);
        $149 = HEAP32[$148>>2]|0;
        __THREW__ = 0;
        $150 = (invoke_ii($149|0,($$pre$i$i$i45|0))|0);
        $151 = __THREW__; __THREW__ = 0;
        $152 = $151&1;
        if ($152) {
         break;
        } else {
         $$0$i$i$i$i43 = $150;
        }
       } else {
        $153 = HEAP32[$142>>2]|0;
        $154 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($153)|0);
        $$0$i$i$i$i43 = $154;
       }
       $155 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
       $156 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i$i$i43,$155)|0);
       if ($156) {
        HEAP32[$1>>2] = 0;
        $180 = 1;
       } else {
        $180 = 0;
       }
      }
      $157 = ($$pre$i4$i$i51|0)==(0|0);
      do {
       if ($157) {
        label = 54;
       } else {
        $158 = ((($$pre$i4$i$i51)) + 12|0);
        $159 = HEAP32[$158>>2]|0;
        $160 = ((($$pre$i4$i$i51)) + 16|0);
        $161 = HEAP32[$160>>2]|0;
        $162 = ($159|0)==($161|0);
        if ($162) {
         $163 = HEAP32[$$pre$i4$i$i51>>2]|0;
         $164 = ((($163)) + 36|0);
         $165 = HEAP32[$164>>2]|0;
         __THREW__ = 0;
         $166 = (invoke_ii($165|0,($$pre$i4$i$i51|0))|0);
         $167 = __THREW__; __THREW__ = 0;
         $168 = $167&1;
         if ($168) {
          break L50;
         } else {
          $$0$i$i2$i$i49 = $166;
         }
        } else {
         $169 = HEAP32[$159>>2]|0;
         $170 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($169)|0);
         $$0$i$i2$i$i49 = $170;
        }
        $171 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
        $172 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i2$i$i49,$171)|0);
        if ($172) {
         HEAP32[$2>>2] = 0;
         label = 54;
         break;
        } else {
         if ($180) {
          break;
         } else {
          label = 56;
          break;
         }
        }
       }
      } while(0);
      if ((label|0) == 54) {
       if ($180) {
        label = 56;
       }
      }
      if ((label|0) == 56) {
       $173 = HEAP32[$4>>2]|0;
       $174 = $173 | 2;
       HEAP32[$4>>2] = $174;
      }
      $$sroa$0$0$copyload = HEAP32[$1>>2]|0;
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($9);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($8);
      STACKTOP = sp;return ($$sroa$0$0$copyload|0);
     }
    }
   }
  } while(0);
  $175 = ___cxa_find_matching_catch_2()|0;
  $176 = tempRet0;
  $$1 = $175;$$127 = $176;
 }
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($9);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($8);
 ___resumeException($$1|0);
 // unreachable;
 return (0)|0;
}
function __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE17__do_get_unsignedItEES4_S4_S4_RNS_8ios_baseERjRT_($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$0$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i43 = 0, $$0$i$i2$i$i = 0, $$0$i$i2$i$i49 = 0, $$0$i$i39 = 0, $$024 = 0, $$1 = 0, $$125 = 0, $$127 = 0, $$2 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i45 = 0, $$pre$i4$i$i51 = 0, $$sroa$0$0$copyload = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0;
 var $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0;
 var $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0;
 var $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i$i = 0, $phitmp$i = 0, $phitmp$i34 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 304|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(304|0);
 $6 = sp + 200|0;
 $7 = sp + 196|0;
 $8 = sp + 184|0;
 $9 = sp + 172|0;
 $10 = sp + 168|0;
 $11 = sp + 8|0;
 $12 = sp + 4|0;
 $13 = sp;
 $14 = (__ZNSt3__214__num_get_base10__get_baseERNS_8ios_baseE($3)|0);
 __ZNSt3__29__num_getIwE17__stage2_int_prepERNS_8ios_baseEPwRw($8,$3,$6,$7);
 ;HEAP32[$9>>2]=0|0;HEAP32[$9+4>>2]=0|0;HEAP32[$9+8>>2]=0|0;
 $$0$i$i = 0;
 while(1) {
  $exitcond$i$i = ($$0$i$i|0)==(3);
  if ($exitcond$i$i) {
   break;
  }
  $15 = (($9) + ($$0$i$i<<2)|0);
  HEAP32[$15>>2] = 0;
  $16 = (($$0$i$i) + 1)|0;
  $$0$i$i = $16;
 }
 $17 = ((($9)) + 11|0);
 $18 = HEAP8[$17>>0]|0;
 $19 = ($18<<24>>24)<(0);
 if ($19) {
  $20 = ((($9)) + 8|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = $21 & 2147483647;
  $phitmp$i = (($22) + -1)|0;
  $23 = $phitmp$i;
 } else {
  $23 = 10;
 }
 __THREW__ = 0;
 invoke_viii(3434,($9|0),($23|0),0);
 $24 = __THREW__; __THREW__ = 0;
 $25 = $24&1;
 if ($25) {
  $88 = ___cxa_find_matching_catch_2()|0;
  $89 = tempRet0;
  $$1 = $88;$$127 = $89;
 } else {
  $26 = HEAP8[$17>>0]|0;
  $27 = ($26<<24>>24)<(0);
  $28 = HEAP32[$9>>2]|0;
  $29 = $27 ? $28 : $9;
  HEAP32[$10>>2] = $29;
  HEAP32[$12>>2] = $11;
  HEAP32[$13>>2] = 0;
  $30 = ((($9)) + 4|0);
  $31 = ((($9)) + 8|0);
  $$pre = HEAP32[$1>>2]|0;
  $$024 = $29;$$pre$i$i$i = $$pre;$177 = $$pre;
  L11: while(1) {
   $32 = ($$pre$i$i$i|0)==(0|0);
   if ($32) {
    $$pre$i$i$i45 = 0;$147 = 0;$178 = 1;
   } else {
    $33 = ((($$pre$i$i$i)) + 12|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = ((($$pre$i$i$i)) + 16|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = ($34|0)==($36|0);
    if ($37) {
     $38 = HEAP32[$$pre$i$i$i>>2]|0;
     $39 = ((($38)) + 36|0);
     $40 = HEAP32[$39>>2]|0;
     __THREW__ = 0;
     $41 = (invoke_ii($40|0,($$pre$i$i$i|0))|0);
     $42 = __THREW__; __THREW__ = 0;
     $43 = $42&1;
     if ($43) {
      break;
     } else {
      $$0$i$i$i$i = $41;
     }
    } else {
     $44 = HEAP32[$34>>2]|0;
     $45 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($44)|0);
     $$0$i$i$i$i = $45;
    }
    $46 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
    $47 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i$i$i,$46)|0);
    if ($47) {
     HEAP32[$1>>2] = 0;
     $$pre$i$i$i45 = 0;$147 = 0;$178 = 1;
    } else {
     $$pre$i$i$i45 = $$pre$i$i$i;$147 = $177;$178 = 0;
    }
   }
   $48 = HEAP32[$2>>2]|0;
   $49 = ($48|0)==(0|0);
   do {
    if ($49) {
     label = 20;
    } else {
     $50 = ((($48)) + 12|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = ((($48)) + 16|0);
     $53 = HEAP32[$52>>2]|0;
     $54 = ($51|0)==($53|0);
     if ($54) {
      $55 = HEAP32[$48>>2]|0;
      $56 = ((($55)) + 36|0);
      $57 = HEAP32[$56>>2]|0;
      __THREW__ = 0;
      $58 = (invoke_ii($57|0,($48|0))|0);
      $59 = __THREW__; __THREW__ = 0;
      $60 = $59&1;
      if ($60) {
       break L11;
      } else {
       $$0$i$i2$i$i = $58;
      }
     } else {
      $61 = HEAP32[$51>>2]|0;
      $62 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($61)|0);
      $$0$i$i2$i$i = $62;
     }
     $63 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
     $64 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i2$i$i,$63)|0);
     if ($64) {
      HEAP32[$2>>2] = 0;
      label = 20;
      break;
     } else {
      if ($178) {
       $179 = $48;
       break;
      } else {
       $$2 = $$024;$$pre$i4$i$i51 = $48;
       label = 37;
       break L11;
      }
     }
    }
   } while(0);
   if ((label|0) == 20) {
    label = 0;
    if ($178) {
     $$2 = $$024;$$pre$i4$i$i51 = 0;
     label = 37;
     break;
    } else {
     $179 = 0;
    }
   }
   $65 = HEAP32[$10>>2]|0;
   $66 = HEAP8[$17>>0]|0;
   $67 = ($66<<24>>24)<(0);
   $68 = HEAP32[$30>>2]|0;
   $69 = $66&255;
   $70 = $67 ? $68 : $69;
   $71 = (($$024) + ($70)|0);
   $72 = ($65|0)==($71|0);
   if ($72) {
    $73 = $70 << 1;
    __THREW__ = 0;
    invoke_viii(3434,($9|0),($73|0),0);
    $74 = __THREW__; __THREW__ = 0;
    $75 = $74&1;
    if ($75) {
     break;
    }
    $76 = HEAP8[$17>>0]|0;
    $77 = ($76<<24>>24)<(0);
    if ($77) {
     $78 = HEAP32[$31>>2]|0;
     $79 = $78 & 2147483647;
     $phitmp$i34 = (($79) + -1)|0;
     $80 = $phitmp$i34;
    } else {
     $80 = 10;
    }
    __THREW__ = 0;
    invoke_viii(3434,($9|0),($80|0),0);
    $81 = __THREW__; __THREW__ = 0;
    $82 = $81&1;
    if ($82) {
     break;
    }
    $83 = HEAP8[$17>>0]|0;
    $84 = ($83<<24>>24)<(0);
    $85 = HEAP32[$9>>2]|0;
    $86 = $84 ? $85 : $9;
    $87 = (($86) + ($70)|0);
    HEAP32[$10>>2] = $87;
    $$125 = $86;
   } else {
    $$125 = $$024;
   }
   $90 = ((($$pre$i$i$i45)) + 12|0);
   $91 = HEAP32[$90>>2]|0;
   $92 = ((($$pre$i$i$i45)) + 16|0);
   $93 = HEAP32[$92>>2]|0;
   $94 = ($91|0)==($93|0);
   if ($94) {
    $95 = HEAP32[$$pre$i$i$i45>>2]|0;
    $96 = ((($95)) + 36|0);
    $97 = HEAP32[$96>>2]|0;
    __THREW__ = 0;
    $98 = (invoke_ii($97|0,($$pre$i$i$i45|0))|0);
    $99 = __THREW__; __THREW__ = 0;
    $100 = $99&1;
    if ($100) {
     break;
    } else {
     $$0$i$i39 = $98;
    }
   } else {
    $101 = HEAP32[$91>>2]|0;
    $102 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($101)|0);
    $$0$i$i39 = $102;
   }
   $103 = HEAP32[$7>>2]|0;
   __THREW__ = 0;
   $104 = (invoke_iiiiiiiiiii(4687,($$0$i$i39|0),($14|0),($$125|0),($10|0),($13|0),($103|0),($8|0),($11|0),($12|0),($6|0))|0);
   $105 = __THREW__; __THREW__ = 0;
   $106 = $105&1;
   if ($106) {
    break;
   }
   $107 = ($104|0)==(0);
   if (!($107)) {
    $$2 = $$125;$$pre$i4$i$i51 = $179;
    label = 37;
    break;
   }
   $108 = HEAP32[$90>>2]|0;
   $109 = HEAP32[$92>>2]|0;
   $110 = ($108|0)==($109|0);
   if ($110) {
    $111 = HEAP32[$$pre$i$i$i45>>2]|0;
    $112 = ((($111)) + 40|0);
    $113 = HEAP32[$112>>2]|0;
    __THREW__ = 0;
    (invoke_ii($113|0,($$pre$i$i$i45|0))|0);
    $114 = __THREW__; __THREW__ = 0;
    $115 = $114&1;
    if ($115) {
     break;
    } else {
     $$024 = $$125;$$pre$i$i$i = $$pre$i$i$i45;$177 = $147;
     continue;
    }
   } else {
    $116 = ((($108)) + 4|0);
    HEAP32[$90>>2] = $116;
    $117 = HEAP32[$108>>2]|0;
    (__ZNSt3__211char_traitsIwE11to_int_typeEw($117)|0);
    $$024 = $$125;$$pre$i$i$i = $$pre$i$i$i45;$177 = $147;
    continue;
   }
  }
  L50: do {
   if ((label|0) == 37) {
    $118 = ((($8)) + 11|0);
    $119 = HEAP8[$118>>0]|0;
    $120 = ($119<<24>>24)<(0);
    $121 = ((($8)) + 4|0);
    $122 = HEAP32[$121>>2]|0;
    $123 = $119&255;
    $124 = $120 ? $122 : $123;
    $125 = ($124|0)==(0);
    if (!($125)) {
     $126 = HEAP32[$12>>2]|0;
     $127 = $126;
     $128 = $11;
     $129 = (($127) - ($128))|0;
     $130 = ($129|0)<(160);
     if ($130) {
      $131 = HEAP32[$13>>2]|0;
      $132 = ((($126)) + 4|0);
      HEAP32[$12>>2] = $132;
      HEAP32[$126>>2] = $131;
     }
    }
    $133 = HEAP32[$10>>2]|0;
    __THREW__ = 0;
    $134 = (invoke_iiiii(4682,($$2|0),($133|0),($4|0),($14|0))|0);
    $135 = __THREW__; __THREW__ = 0;
    $136 = $135&1;
    if (!($136)) {
     HEAP16[$5>>1] = $134;
     $137 = HEAP32[$12>>2]|0;
     __THREW__ = 0;
     invoke_viiii(4676,($8|0),($11|0),($137|0),($4|0));
     $138 = __THREW__; __THREW__ = 0;
     $139 = $138&1;
     if (!($139)) {
      $140 = ($$pre$i$i$i45|0)==(0|0);
      if ($140) {
       $180 = 1;
      } else {
       $141 = ((($$pre$i$i$i45)) + 12|0);
       $142 = HEAP32[$141>>2]|0;
       $143 = ((($$pre$i$i$i45)) + 16|0);
       $144 = HEAP32[$143>>2]|0;
       $145 = ($142|0)==($144|0);
       if ($145) {
        $146 = HEAP32[$147>>2]|0;
        $148 = ((($146)) + 36|0);
        $149 = HEAP32[$148>>2]|0;
        __THREW__ = 0;
        $150 = (invoke_ii($149|0,($$pre$i$i$i45|0))|0);
        $151 = __THREW__; __THREW__ = 0;
        $152 = $151&1;
        if ($152) {
         break;
        } else {
         $$0$i$i$i$i43 = $150;
        }
       } else {
        $153 = HEAP32[$142>>2]|0;
        $154 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($153)|0);
        $$0$i$i$i$i43 = $154;
       }
       $155 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
       $156 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i$i$i43,$155)|0);
       if ($156) {
        HEAP32[$1>>2] = 0;
        $180 = 1;
       } else {
        $180 = 0;
       }
      }
      $157 = ($$pre$i4$i$i51|0)==(0|0);
      do {
       if ($157) {
        label = 54;
       } else {
        $158 = ((($$pre$i4$i$i51)) + 12|0);
        $159 = HEAP32[$158>>2]|0;
        $160 = ((($$pre$i4$i$i51)) + 16|0);
        $161 = HEAP32[$160>>2]|0;
        $162 = ($159|0)==($161|0);
        if ($162) {
         $163 = HEAP32[$$pre$i4$i$i51>>2]|0;
         $164 = ((($163)) + 36|0);
         $165 = HEAP32[$164>>2]|0;
         __THREW__ = 0;
         $166 = (invoke_ii($165|0,($$pre$i4$i$i51|0))|0);
         $167 = __THREW__; __THREW__ = 0;
         $168 = $167&1;
         if ($168) {
          break L50;
         } else {
          $$0$i$i2$i$i49 = $166;
         }
        } else {
         $169 = HEAP32[$159>>2]|0;
         $170 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($169)|0);
         $$0$i$i2$i$i49 = $170;
        }
        $171 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
        $172 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i2$i$i49,$171)|0);
        if ($172) {
         HEAP32[$2>>2] = 0;
         label = 54;
         break;
        } else {
         if ($180) {
          break;
         } else {
          label = 56;
          break;
         }
        }
       }
      } while(0);
      if ((label|0) == 54) {
       if ($180) {
        label = 56;
       }
      }
      if ((label|0) == 56) {
       $173 = HEAP32[$4>>2]|0;
       $174 = $173 | 2;
       HEAP32[$4>>2] = $174;
      }
      $$sroa$0$0$copyload = HEAP32[$1>>2]|0;
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($9);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($8);
      STACKTOP = sp;return ($$sroa$0$0$copyload|0);
     }
    }
   }
  } while(0);
  $175 = ___cxa_find_matching_catch_2()|0;
  $176 = tempRet0;
  $$1 = $175;$$127 = $176;
 }
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($9);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($8);
 ___resumeException($$1|0);
 // unreachable;
 return (0)|0;
}
function __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE15__do_get_signedIxEES4_S4_S4_RNS_8ios_baseERjRT_($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$0$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i43 = 0, $$0$i$i2$i$i = 0, $$0$i$i2$i$i49 = 0, $$0$i$i39 = 0, $$024 = 0, $$1 = 0, $$125 = 0, $$127 = 0, $$2 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i45 = 0, $$pre$i4$i$i51 = 0, $$sroa$0$0$copyload = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0;
 var $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0;
 var $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0;
 var $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i$i = 0, $phitmp$i = 0, $phitmp$i34 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 304|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(304|0);
 $6 = sp + 200|0;
 $7 = sp + 196|0;
 $8 = sp + 184|0;
 $9 = sp + 172|0;
 $10 = sp + 168|0;
 $11 = sp + 8|0;
 $12 = sp + 4|0;
 $13 = sp;
 $14 = (__ZNSt3__214__num_get_base10__get_baseERNS_8ios_baseE($3)|0);
 __ZNSt3__29__num_getIwE17__stage2_int_prepERNS_8ios_baseEPwRw($8,$3,$6,$7);
 ;HEAP32[$9>>2]=0|0;HEAP32[$9+4>>2]=0|0;HEAP32[$9+8>>2]=0|0;
 $$0$i$i = 0;
 while(1) {
  $exitcond$i$i = ($$0$i$i|0)==(3);
  if ($exitcond$i$i) {
   break;
  }
  $15 = (($9) + ($$0$i$i<<2)|0);
  HEAP32[$15>>2] = 0;
  $16 = (($$0$i$i) + 1)|0;
  $$0$i$i = $16;
 }
 $17 = ((($9)) + 11|0);
 $18 = HEAP8[$17>>0]|0;
 $19 = ($18<<24>>24)<(0);
 if ($19) {
  $20 = ((($9)) + 8|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = $21 & 2147483647;
  $phitmp$i = (($22) + -1)|0;
  $23 = $phitmp$i;
 } else {
  $23 = 10;
 }
 __THREW__ = 0;
 invoke_viii(3434,($9|0),($23|0),0);
 $24 = __THREW__; __THREW__ = 0;
 $25 = $24&1;
 if ($25) {
  $88 = ___cxa_find_matching_catch_2()|0;
  $89 = tempRet0;
  $$1 = $88;$$127 = $89;
 } else {
  $26 = HEAP8[$17>>0]|0;
  $27 = ($26<<24>>24)<(0);
  $28 = HEAP32[$9>>2]|0;
  $29 = $27 ? $28 : $9;
  HEAP32[$10>>2] = $29;
  HEAP32[$12>>2] = $11;
  HEAP32[$13>>2] = 0;
  $30 = ((($9)) + 4|0);
  $31 = ((($9)) + 8|0);
  $$pre = HEAP32[$1>>2]|0;
  $$024 = $29;$$pre$i$i$i = $$pre;$182 = $$pre;
  L11: while(1) {
   $32 = ($$pre$i$i$i|0)==(0|0);
   if ($32) {
    $$pre$i$i$i45 = 0;$152 = 0;$183 = 1;
   } else {
    $33 = ((($$pre$i$i$i)) + 12|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = ((($$pre$i$i$i)) + 16|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = ($34|0)==($36|0);
    if ($37) {
     $38 = HEAP32[$$pre$i$i$i>>2]|0;
     $39 = ((($38)) + 36|0);
     $40 = HEAP32[$39>>2]|0;
     __THREW__ = 0;
     $41 = (invoke_ii($40|0,($$pre$i$i$i|0))|0);
     $42 = __THREW__; __THREW__ = 0;
     $43 = $42&1;
     if ($43) {
      break;
     } else {
      $$0$i$i$i$i = $41;
     }
    } else {
     $44 = HEAP32[$34>>2]|0;
     $45 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($44)|0);
     $$0$i$i$i$i = $45;
    }
    $46 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
    $47 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i$i$i,$46)|0);
    if ($47) {
     HEAP32[$1>>2] = 0;
     $$pre$i$i$i45 = 0;$152 = 0;$183 = 1;
    } else {
     $$pre$i$i$i45 = $$pre$i$i$i;$152 = $182;$183 = 0;
    }
   }
   $48 = HEAP32[$2>>2]|0;
   $49 = ($48|0)==(0|0);
   do {
    if ($49) {
     label = 20;
    } else {
     $50 = ((($48)) + 12|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = ((($48)) + 16|0);
     $53 = HEAP32[$52>>2]|0;
     $54 = ($51|0)==($53|0);
     if ($54) {
      $55 = HEAP32[$48>>2]|0;
      $56 = ((($55)) + 36|0);
      $57 = HEAP32[$56>>2]|0;
      __THREW__ = 0;
      $58 = (invoke_ii($57|0,($48|0))|0);
      $59 = __THREW__; __THREW__ = 0;
      $60 = $59&1;
      if ($60) {
       break L11;
      } else {
       $$0$i$i2$i$i = $58;
      }
     } else {
      $61 = HEAP32[$51>>2]|0;
      $62 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($61)|0);
      $$0$i$i2$i$i = $62;
     }
     $63 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
     $64 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i2$i$i,$63)|0);
     if ($64) {
      HEAP32[$2>>2] = 0;
      label = 20;
      break;
     } else {
      if ($183) {
       $184 = $48;
       break;
      } else {
       $$2 = $$024;$$pre$i4$i$i51 = $48;
       label = 37;
       break L11;
      }
     }
    }
   } while(0);
   if ((label|0) == 20) {
    label = 0;
    if ($183) {
     $$2 = $$024;$$pre$i4$i$i51 = 0;
     label = 37;
     break;
    } else {
     $184 = 0;
    }
   }
   $65 = HEAP32[$10>>2]|0;
   $66 = HEAP8[$17>>0]|0;
   $67 = ($66<<24>>24)<(0);
   $68 = HEAP32[$30>>2]|0;
   $69 = $66&255;
   $70 = $67 ? $68 : $69;
   $71 = (($$024) + ($70)|0);
   $72 = ($65|0)==($71|0);
   if ($72) {
    $73 = $70 << 1;
    __THREW__ = 0;
    invoke_viii(3434,($9|0),($73|0),0);
    $74 = __THREW__; __THREW__ = 0;
    $75 = $74&1;
    if ($75) {
     break;
    }
    $76 = HEAP8[$17>>0]|0;
    $77 = ($76<<24>>24)<(0);
    if ($77) {
     $78 = HEAP32[$31>>2]|0;
     $79 = $78 & 2147483647;
     $phitmp$i34 = (($79) + -1)|0;
     $80 = $phitmp$i34;
    } else {
     $80 = 10;
    }
    __THREW__ = 0;
    invoke_viii(3434,($9|0),($80|0),0);
    $81 = __THREW__; __THREW__ = 0;
    $82 = $81&1;
    if ($82) {
     break;
    }
    $83 = HEAP8[$17>>0]|0;
    $84 = ($83<<24>>24)<(0);
    $85 = HEAP32[$9>>2]|0;
    $86 = $84 ? $85 : $9;
    $87 = (($86) + ($70)|0);
    HEAP32[$10>>2] = $87;
    $$125 = $86;
   } else {
    $$125 = $$024;
   }
   $90 = ((($$pre$i$i$i45)) + 12|0);
   $91 = HEAP32[$90>>2]|0;
   $92 = ((($$pre$i$i$i45)) + 16|0);
   $93 = HEAP32[$92>>2]|0;
   $94 = ($91|0)==($93|0);
   if ($94) {
    $95 = HEAP32[$$pre$i$i$i45>>2]|0;
    $96 = ((($95)) + 36|0);
    $97 = HEAP32[$96>>2]|0;
    __THREW__ = 0;
    $98 = (invoke_ii($97|0,($$pre$i$i$i45|0))|0);
    $99 = __THREW__; __THREW__ = 0;
    $100 = $99&1;
    if ($100) {
     break;
    } else {
     $$0$i$i39 = $98;
    }
   } else {
    $101 = HEAP32[$91>>2]|0;
    $102 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($101)|0);
    $$0$i$i39 = $102;
   }
   $103 = HEAP32[$7>>2]|0;
   __THREW__ = 0;
   $104 = (invoke_iiiiiiiiiii(4687,($$0$i$i39|0),($14|0),($$125|0),($10|0),($13|0),($103|0),($8|0),($11|0),($12|0),($6|0))|0);
   $105 = __THREW__; __THREW__ = 0;
   $106 = $105&1;
   if ($106) {
    break;
   }
   $107 = ($104|0)==(0);
   if (!($107)) {
    $$2 = $$125;$$pre$i4$i$i51 = $184;
    label = 37;
    break;
   }
   $108 = HEAP32[$90>>2]|0;
   $109 = HEAP32[$92>>2]|0;
   $110 = ($108|0)==($109|0);
   if ($110) {
    $111 = HEAP32[$$pre$i$i$i45>>2]|0;
    $112 = ((($111)) + 40|0);
    $113 = HEAP32[$112>>2]|0;
    __THREW__ = 0;
    (invoke_ii($113|0,($$pre$i$i$i45|0))|0);
    $114 = __THREW__; __THREW__ = 0;
    $115 = $114&1;
    if ($115) {
     break;
    } else {
     $$024 = $$125;$$pre$i$i$i = $$pre$i$i$i45;$182 = $152;
     continue;
    }
   } else {
    $116 = ((($108)) + 4|0);
    HEAP32[$90>>2] = $116;
    $117 = HEAP32[$108>>2]|0;
    (__ZNSt3__211char_traitsIwE11to_int_typeEw($117)|0);
    $$024 = $$125;$$pre$i$i$i = $$pre$i$i$i45;$182 = $152;
    continue;
   }
  }
  L50: do {
   if ((label|0) == 37) {
    $118 = ((($8)) + 11|0);
    $119 = HEAP8[$118>>0]|0;
    $120 = ($119<<24>>24)<(0);
    $121 = ((($8)) + 4|0);
    $122 = HEAP32[$121>>2]|0;
    $123 = $119&255;
    $124 = $120 ? $122 : $123;
    $125 = ($124|0)==(0);
    if (!($125)) {
     $126 = HEAP32[$12>>2]|0;
     $127 = $126;
     $128 = $11;
     $129 = (($127) - ($128))|0;
     $130 = ($129|0)<(160);
     if ($130) {
      $131 = HEAP32[$13>>2]|0;
      $132 = ((($126)) + 4|0);
      HEAP32[$12>>2] = $132;
      HEAP32[$126>>2] = $131;
     }
    }
    $133 = HEAP32[$10>>2]|0;
    __THREW__ = 0;
    $134 = (invoke_iiiii(4683,($$2|0),($133|0),($4|0),($14|0))|0);
    $135 = tempRet0;
    $136 = __THREW__; __THREW__ = 0;
    $137 = $136&1;
    if (!($137)) {
     $138 = $5;
     $139 = $138;
     HEAP32[$139>>2] = $134;
     $140 = (($138) + 4)|0;
     $141 = $140;
     HEAP32[$141>>2] = $135;
     $142 = HEAP32[$12>>2]|0;
     __THREW__ = 0;
     invoke_viiii(4676,($8|0),($11|0),($142|0),($4|0));
     $143 = __THREW__; __THREW__ = 0;
     $144 = $143&1;
     if (!($144)) {
      $145 = ($$pre$i$i$i45|0)==(0|0);
      if ($145) {
       $185 = 1;
      } else {
       $146 = ((($$pre$i$i$i45)) + 12|0);
       $147 = HEAP32[$146>>2]|0;
       $148 = ((($$pre$i$i$i45)) + 16|0);
       $149 = HEAP32[$148>>2]|0;
       $150 = ($147|0)==($149|0);
       if ($150) {
        $151 = HEAP32[$152>>2]|0;
        $153 = ((($151)) + 36|0);
        $154 = HEAP32[$153>>2]|0;
        __THREW__ = 0;
        $155 = (invoke_ii($154|0,($$pre$i$i$i45|0))|0);
        $156 = __THREW__; __THREW__ = 0;
        $157 = $156&1;
        if ($157) {
         break;
        } else {
         $$0$i$i$i$i43 = $155;
        }
       } else {
        $158 = HEAP32[$147>>2]|0;
        $159 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($158)|0);
        $$0$i$i$i$i43 = $159;
       }
       $160 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
       $161 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i$i$i43,$160)|0);
       if ($161) {
        HEAP32[$1>>2] = 0;
        $185 = 1;
       } else {
        $185 = 0;
       }
      }
      $162 = ($$pre$i4$i$i51|0)==(0|0);
      do {
       if ($162) {
        label = 54;
       } else {
        $163 = ((($$pre$i4$i$i51)) + 12|0);
        $164 = HEAP32[$163>>2]|0;
        $165 = ((($$pre$i4$i$i51)) + 16|0);
        $166 = HEAP32[$165>>2]|0;
        $167 = ($164|0)==($166|0);
        if ($167) {
         $168 = HEAP32[$$pre$i4$i$i51>>2]|0;
         $169 = ((($168)) + 36|0);
         $170 = HEAP32[$169>>2]|0;
         __THREW__ = 0;
         $171 = (invoke_ii($170|0,($$pre$i4$i$i51|0))|0);
         $172 = __THREW__; __THREW__ = 0;
         $173 = $172&1;
         if ($173) {
          break L50;
         } else {
          $$0$i$i2$i$i49 = $171;
         }
        } else {
         $174 = HEAP32[$164>>2]|0;
         $175 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($174)|0);
         $$0$i$i2$i$i49 = $175;
        }
        $176 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
        $177 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i2$i$i49,$176)|0);
        if ($177) {
         HEAP32[$2>>2] = 0;
         label = 54;
         break;
        } else {
         if ($185) {
          break;
         } else {
          label = 56;
          break;
         }
        }
       }
      } while(0);
      if ((label|0) == 54) {
       if ($185) {
        label = 56;
       }
      }
      if ((label|0) == 56) {
       $178 = HEAP32[$4>>2]|0;
       $179 = $178 | 2;
       HEAP32[$4>>2] = $179;
      }
      $$sroa$0$0$copyload = HEAP32[$1>>2]|0;
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($9);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($8);
      STACKTOP = sp;return ($$sroa$0$0$copyload|0);
     }
    }
   }
  } while(0);
  $180 = ___cxa_find_matching_catch_2()|0;
  $181 = tempRet0;
  $$1 = $180;$$127 = $181;
 }
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($9);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($8);
 ___resumeException($$1|0);
 // unreachable;
 return (0)|0;
}
function __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE15__do_get_signedIlEES4_S4_S4_RNS_8ios_baseERjRT_($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$0$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i43 = 0, $$0$i$i2$i$i = 0, $$0$i$i2$i$i49 = 0, $$0$i$i39 = 0, $$024 = 0, $$1 = 0, $$125 = 0, $$127 = 0, $$2 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i45 = 0, $$pre$i4$i$i51 = 0, $$sroa$0$0$copyload = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0;
 var $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0;
 var $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0;
 var $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i$i = 0, $phitmp$i = 0, $phitmp$i34 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 304|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(304|0);
 $6 = sp + 200|0;
 $7 = sp + 196|0;
 $8 = sp + 184|0;
 $9 = sp + 172|0;
 $10 = sp + 168|0;
 $11 = sp + 8|0;
 $12 = sp + 4|0;
 $13 = sp;
 $14 = (__ZNSt3__214__num_get_base10__get_baseERNS_8ios_baseE($3)|0);
 __ZNSt3__29__num_getIwE17__stage2_int_prepERNS_8ios_baseEPwRw($8,$3,$6,$7);
 ;HEAP32[$9>>2]=0|0;HEAP32[$9+4>>2]=0|0;HEAP32[$9+8>>2]=0|0;
 $$0$i$i = 0;
 while(1) {
  $exitcond$i$i = ($$0$i$i|0)==(3);
  if ($exitcond$i$i) {
   break;
  }
  $15 = (($9) + ($$0$i$i<<2)|0);
  HEAP32[$15>>2] = 0;
  $16 = (($$0$i$i) + 1)|0;
  $$0$i$i = $16;
 }
 $17 = ((($9)) + 11|0);
 $18 = HEAP8[$17>>0]|0;
 $19 = ($18<<24>>24)<(0);
 if ($19) {
  $20 = ((($9)) + 8|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = $21 & 2147483647;
  $phitmp$i = (($22) + -1)|0;
  $23 = $phitmp$i;
 } else {
  $23 = 10;
 }
 __THREW__ = 0;
 invoke_viii(3434,($9|0),($23|0),0);
 $24 = __THREW__; __THREW__ = 0;
 $25 = $24&1;
 if ($25) {
  $88 = ___cxa_find_matching_catch_2()|0;
  $89 = tempRet0;
  $$1 = $88;$$127 = $89;
 } else {
  $26 = HEAP8[$17>>0]|0;
  $27 = ($26<<24>>24)<(0);
  $28 = HEAP32[$9>>2]|0;
  $29 = $27 ? $28 : $9;
  HEAP32[$10>>2] = $29;
  HEAP32[$12>>2] = $11;
  HEAP32[$13>>2] = 0;
  $30 = ((($9)) + 4|0);
  $31 = ((($9)) + 8|0);
  $$pre = HEAP32[$1>>2]|0;
  $$024 = $29;$$pre$i$i$i = $$pre;$177 = $$pre;
  L11: while(1) {
   $32 = ($$pre$i$i$i|0)==(0|0);
   if ($32) {
    $$pre$i$i$i45 = 0;$147 = 0;$178 = 1;
   } else {
    $33 = ((($$pre$i$i$i)) + 12|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = ((($$pre$i$i$i)) + 16|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = ($34|0)==($36|0);
    if ($37) {
     $38 = HEAP32[$$pre$i$i$i>>2]|0;
     $39 = ((($38)) + 36|0);
     $40 = HEAP32[$39>>2]|0;
     __THREW__ = 0;
     $41 = (invoke_ii($40|0,($$pre$i$i$i|0))|0);
     $42 = __THREW__; __THREW__ = 0;
     $43 = $42&1;
     if ($43) {
      break;
     } else {
      $$0$i$i$i$i = $41;
     }
    } else {
     $44 = HEAP32[$34>>2]|0;
     $45 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($44)|0);
     $$0$i$i$i$i = $45;
    }
    $46 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
    $47 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i$i$i,$46)|0);
    if ($47) {
     HEAP32[$1>>2] = 0;
     $$pre$i$i$i45 = 0;$147 = 0;$178 = 1;
    } else {
     $$pre$i$i$i45 = $$pre$i$i$i;$147 = $177;$178 = 0;
    }
   }
   $48 = HEAP32[$2>>2]|0;
   $49 = ($48|0)==(0|0);
   do {
    if ($49) {
     label = 20;
    } else {
     $50 = ((($48)) + 12|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = ((($48)) + 16|0);
     $53 = HEAP32[$52>>2]|0;
     $54 = ($51|0)==($53|0);
     if ($54) {
      $55 = HEAP32[$48>>2]|0;
      $56 = ((($55)) + 36|0);
      $57 = HEAP32[$56>>2]|0;
      __THREW__ = 0;
      $58 = (invoke_ii($57|0,($48|0))|0);
      $59 = __THREW__; __THREW__ = 0;
      $60 = $59&1;
      if ($60) {
       break L11;
      } else {
       $$0$i$i2$i$i = $58;
      }
     } else {
      $61 = HEAP32[$51>>2]|0;
      $62 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($61)|0);
      $$0$i$i2$i$i = $62;
     }
     $63 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
     $64 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i2$i$i,$63)|0);
     if ($64) {
      HEAP32[$2>>2] = 0;
      label = 20;
      break;
     } else {
      if ($178) {
       $179 = $48;
       break;
      } else {
       $$2 = $$024;$$pre$i4$i$i51 = $48;
       label = 37;
       break L11;
      }
     }
    }
   } while(0);
   if ((label|0) == 20) {
    label = 0;
    if ($178) {
     $$2 = $$024;$$pre$i4$i$i51 = 0;
     label = 37;
     break;
    } else {
     $179 = 0;
    }
   }
   $65 = HEAP32[$10>>2]|0;
   $66 = HEAP8[$17>>0]|0;
   $67 = ($66<<24>>24)<(0);
   $68 = HEAP32[$30>>2]|0;
   $69 = $66&255;
   $70 = $67 ? $68 : $69;
   $71 = (($$024) + ($70)|0);
   $72 = ($65|0)==($71|0);
   if ($72) {
    $73 = $70 << 1;
    __THREW__ = 0;
    invoke_viii(3434,($9|0),($73|0),0);
    $74 = __THREW__; __THREW__ = 0;
    $75 = $74&1;
    if ($75) {
     break;
    }
    $76 = HEAP8[$17>>0]|0;
    $77 = ($76<<24>>24)<(0);
    if ($77) {
     $78 = HEAP32[$31>>2]|0;
     $79 = $78 & 2147483647;
     $phitmp$i34 = (($79) + -1)|0;
     $80 = $phitmp$i34;
    } else {
     $80 = 10;
    }
    __THREW__ = 0;
    invoke_viii(3434,($9|0),($80|0),0);
    $81 = __THREW__; __THREW__ = 0;
    $82 = $81&1;
    if ($82) {
     break;
    }
    $83 = HEAP8[$17>>0]|0;
    $84 = ($83<<24>>24)<(0);
    $85 = HEAP32[$9>>2]|0;
    $86 = $84 ? $85 : $9;
    $87 = (($86) + ($70)|0);
    HEAP32[$10>>2] = $87;
    $$125 = $86;
   } else {
    $$125 = $$024;
   }
   $90 = ((($$pre$i$i$i45)) + 12|0);
   $91 = HEAP32[$90>>2]|0;
   $92 = ((($$pre$i$i$i45)) + 16|0);
   $93 = HEAP32[$92>>2]|0;
   $94 = ($91|0)==($93|0);
   if ($94) {
    $95 = HEAP32[$$pre$i$i$i45>>2]|0;
    $96 = ((($95)) + 36|0);
    $97 = HEAP32[$96>>2]|0;
    __THREW__ = 0;
    $98 = (invoke_ii($97|0,($$pre$i$i$i45|0))|0);
    $99 = __THREW__; __THREW__ = 0;
    $100 = $99&1;
    if ($100) {
     break;
    } else {
     $$0$i$i39 = $98;
    }
   } else {
    $101 = HEAP32[$91>>2]|0;
    $102 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($101)|0);
    $$0$i$i39 = $102;
   }
   $103 = HEAP32[$7>>2]|0;
   __THREW__ = 0;
   $104 = (invoke_iiiiiiiiiii(4687,($$0$i$i39|0),($14|0),($$125|0),($10|0),($13|0),($103|0),($8|0),($11|0),($12|0),($6|0))|0);
   $105 = __THREW__; __THREW__ = 0;
   $106 = $105&1;
   if ($106) {
    break;
   }
   $107 = ($104|0)==(0);
   if (!($107)) {
    $$2 = $$125;$$pre$i4$i$i51 = $179;
    label = 37;
    break;
   }
   $108 = HEAP32[$90>>2]|0;
   $109 = HEAP32[$92>>2]|0;
   $110 = ($108|0)==($109|0);
   if ($110) {
    $111 = HEAP32[$$pre$i$i$i45>>2]|0;
    $112 = ((($111)) + 40|0);
    $113 = HEAP32[$112>>2]|0;
    __THREW__ = 0;
    (invoke_ii($113|0,($$pre$i$i$i45|0))|0);
    $114 = __THREW__; __THREW__ = 0;
    $115 = $114&1;
    if ($115) {
     break;
    } else {
     $$024 = $$125;$$pre$i$i$i = $$pre$i$i$i45;$177 = $147;
     continue;
    }
   } else {
    $116 = ((($108)) + 4|0);
    HEAP32[$90>>2] = $116;
    $117 = HEAP32[$108>>2]|0;
    (__ZNSt3__211char_traitsIwE11to_int_typeEw($117)|0);
    $$024 = $$125;$$pre$i$i$i = $$pre$i$i$i45;$177 = $147;
    continue;
   }
  }
  L50: do {
   if ((label|0) == 37) {
    $118 = ((($8)) + 11|0);
    $119 = HEAP8[$118>>0]|0;
    $120 = ($119<<24>>24)<(0);
    $121 = ((($8)) + 4|0);
    $122 = HEAP32[$121>>2]|0;
    $123 = $119&255;
    $124 = $120 ? $122 : $123;
    $125 = ($124|0)==(0);
    if (!($125)) {
     $126 = HEAP32[$12>>2]|0;
     $127 = $126;
     $128 = $11;
     $129 = (($127) - ($128))|0;
     $130 = ($129|0)<(160);
     if ($130) {
      $131 = HEAP32[$13>>2]|0;
      $132 = ((($126)) + 4|0);
      HEAP32[$12>>2] = $132;
      HEAP32[$126>>2] = $131;
     }
    }
    $133 = HEAP32[$10>>2]|0;
    __THREW__ = 0;
    $134 = (invoke_iiiii(4684,($$2|0),($133|0),($4|0),($14|0))|0);
    $135 = __THREW__; __THREW__ = 0;
    $136 = $135&1;
    if (!($136)) {
     HEAP32[$5>>2] = $134;
     $137 = HEAP32[$12>>2]|0;
     __THREW__ = 0;
     invoke_viiii(4676,($8|0),($11|0),($137|0),($4|0));
     $138 = __THREW__; __THREW__ = 0;
     $139 = $138&1;
     if (!($139)) {
      $140 = ($$pre$i$i$i45|0)==(0|0);
      if ($140) {
       $180 = 1;
      } else {
       $141 = ((($$pre$i$i$i45)) + 12|0);
       $142 = HEAP32[$141>>2]|0;
       $143 = ((($$pre$i$i$i45)) + 16|0);
       $144 = HEAP32[$143>>2]|0;
       $145 = ($142|0)==($144|0);
       if ($145) {
        $146 = HEAP32[$147>>2]|0;
        $148 = ((($146)) + 36|0);
        $149 = HEAP32[$148>>2]|0;
        __THREW__ = 0;
        $150 = (invoke_ii($149|0,($$pre$i$i$i45|0))|0);
        $151 = __THREW__; __THREW__ = 0;
        $152 = $151&1;
        if ($152) {
         break;
        } else {
         $$0$i$i$i$i43 = $150;
        }
       } else {
        $153 = HEAP32[$142>>2]|0;
        $154 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($153)|0);
        $$0$i$i$i$i43 = $154;
       }
       $155 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
       $156 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i$i$i43,$155)|0);
       if ($156) {
        HEAP32[$1>>2] = 0;
        $180 = 1;
       } else {
        $180 = 0;
       }
      }
      $157 = ($$pre$i4$i$i51|0)==(0|0);
      do {
       if ($157) {
        label = 54;
       } else {
        $158 = ((($$pre$i4$i$i51)) + 12|0);
        $159 = HEAP32[$158>>2]|0;
        $160 = ((($$pre$i4$i$i51)) + 16|0);
        $161 = HEAP32[$160>>2]|0;
        $162 = ($159|0)==($161|0);
        if ($162) {
         $163 = HEAP32[$$pre$i4$i$i51>>2]|0;
         $164 = ((($163)) + 36|0);
         $165 = HEAP32[$164>>2]|0;
         __THREW__ = 0;
         $166 = (invoke_ii($165|0,($$pre$i4$i$i51|0))|0);
         $167 = __THREW__; __THREW__ = 0;
         $168 = $167&1;
         if ($168) {
          break L50;
         } else {
          $$0$i$i2$i$i49 = $166;
         }
        } else {
         $169 = HEAP32[$159>>2]|0;
         $170 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($169)|0);
         $$0$i$i2$i$i49 = $170;
        }
        $171 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
        $172 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i2$i$i49,$171)|0);
        if ($172) {
         HEAP32[$2>>2] = 0;
         label = 54;
         break;
        } else {
         if ($180) {
          break;
         } else {
          label = 56;
          break;
         }
        }
       }
      } while(0);
      if ((label|0) == 54) {
       if ($180) {
        label = 56;
       }
      }
      if ((label|0) == 56) {
       $173 = HEAP32[$4>>2]|0;
       $174 = $173 | 2;
       HEAP32[$4>>2] = $174;
      }
      $$sroa$0$0$copyload = HEAP32[$1>>2]|0;
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($9);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($8);
      STACKTOP = sp;return ($$sroa$0$0$copyload|0);
     }
    }
   }
  } while(0);
  $175 = ___cxa_find_matching_catch_2()|0;
  $176 = tempRet0;
  $$1 = $175;$$127 = $176;
 }
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($9);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($8);
 ___resumeException($$1|0);
 // unreachable;
 return (0)|0;
}
function __ZNSt3__214__scan_keywordINS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEPKNS_12basic_stringIwS3_NS_9allocatorIwEEEENS_5ctypeIwEEEET0_RT_SE_SD_SD_RKT1_Rjb($0,$1,$2,$3,$4,$5,$6) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 var $$0 = 0, $$0$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i143 = 0, $$0$i$i2$i$i = 0, $$0$i$i2$i$i149 = 0, $$0103 = 0, $$0104 = 0, $$0105$off0 = 0, $$0106 = 0, $$0107 = 0, $$0108 = 0, $$0109 = 0, $$0112 = 0, $$0116 = 0, $$0132 = 0, $$0133 = 0, $$0133197 = 0, $$1110 = 0, $$1113 = 0;
 var $$1117 = 0, $$2$off0 = 0, $$2111 = 0, $$2114 = 0, $$2118 = 0, $$3 = 0, $$3115 = 0, $$3119 = 0, $$5 = 0, $$5121 = 0, $$6 = 0, $$7 = 0, $$pre$i$i$i = 0, $$pre$i$i$i145 = 0, $$pre$i4$i$i151 = 0, $$sink140$sink141205$index = 0, $$sink140$sink141205$index5 = 0, $$sroa$0165$0 = 0, $10 = 0, $100 = 0;
 var $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0;
 var $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0;
 var $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0;
 var $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0;
 var $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0;
 var $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $phitmp$i$i$i = 0, $phitmp$i$i$i146 = 0, $tmp$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(112|0);
 $7 = sp;
 $8 = $3;
 $9 = $2;
 $10 = (($8) - ($9))|0;
 $11 = (($10|0) / 12)&-1;
 $12 = ($11>>>0)>(100);
 do {
  if ($12) {
   $13 = (_malloc($11)|0);
   $14 = ($13|0)==(0|0);
   if ($14) {
    __THREW__ = 0;
    invoke_v(4685);
    $15 = __THREW__; __THREW__ = 0;
    $16 = ___cxa_find_matching_catch_2()|0;
    $17 = tempRet0;
    $$sink140$sink141205$index = $16;$$sink140$sink141205$index5 = $17;
    break;
   } else {
    $18 = $13;
    $$0132 = $13;$$sroa$0165$0 = $18;
    label = 5;
    break;
   }
  } else {
   $$0132 = $7;$$sroa$0165$0 = 0;
   label = 5;
  }
 } while(0);
 if ((label|0) == 5) {
  $$0108 = $2;$$0109 = $$0132;$$0112 = 0;$$0116 = $11;
  while(1) {
   $19 = ($$0108|0)==($3|0);
   if ($19) {
    break;
   }
   $20 = ((($$0108)) + 8|0);
   $21 = ((($20)) + 3|0);
   $22 = HEAP8[$21>>0]|0;
   $23 = ($22<<24>>24)<(0);
   if ($23) {
    $24 = ((($$0108)) + 4|0);
    $25 = HEAP32[$24>>2]|0;
    $27 = $25;
   } else {
    $26 = $22&255;
    $27 = $26;
   }
   $28 = ($27|0)==(0);
   if ($28) {
    HEAP8[$$0109>>0] = 2;
    $29 = (($$0116) + -1)|0;
    $30 = (($$0112) + 1)|0;
    $$1113 = $30;$$1117 = $29;
   } else {
    HEAP8[$$0109>>0] = 1;
    $$1113 = $$0112;$$1117 = $$0116;
   }
   $31 = ((($$0108)) + 12|0);
   $32 = ((($$0109)) + 1|0);
   $$0108 = $31;$$0109 = $32;$$0112 = $$1113;$$0116 = $$1117;
  }
  $$0107 = 0;$$2114 = $$0112;$$2118 = $$0116;
  L20: while(1) {
   $33 = HEAP32[$0>>2]|0;
   $34 = ($33|0)==(0|0);
   do {
    if ($34) {
     $68 = 1;
    } else {
     $35 = ((($33)) + 12|0);
     $36 = HEAP32[$35>>2]|0;
     $37 = ((($33)) + 16|0);
     $38 = HEAP32[$37>>2]|0;
     $39 = ($36|0)==($38|0);
     if ($39) {
      $40 = HEAP32[$33>>2]|0;
      $41 = ((($40)) + 36|0);
      $42 = HEAP32[$41>>2]|0;
      __THREW__ = 0;
      $43 = (invoke_ii($42|0,($33|0))|0);
      $44 = __THREW__; __THREW__ = 0;
      $45 = $44&1;
      if ($45) {
       break L20;
      } else {
       $$0$i$i$i$i = $43;
      }
     } else {
      $46 = HEAP32[$36>>2]|0;
      $47 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($46)|0);
      $$0$i$i$i$i = $47;
     }
     $48 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
     $49 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i$i$i,$48)|0);
     if ($49) {
      HEAP32[$0>>2] = 0;
      $68 = 1;
      break;
     } else {
      $$pre$i$i$i = HEAP32[$0>>2]|0;
      $phitmp$i$i$i = ($$pre$i$i$i|0)==(0|0);
      $68 = $phitmp$i$i$i;
      break;
     }
    }
   } while(0);
   $50 = HEAP32[$1>>2]|0;
   $51 = ($50|0)==(0|0);
   if ($51) {
    $$pre$i4$i$i151 = 0;$67 = 1;
   } else {
    $52 = ((($50)) + 12|0);
    $53 = HEAP32[$52>>2]|0;
    $54 = ((($50)) + 16|0);
    $55 = HEAP32[$54>>2]|0;
    $56 = ($53|0)==($55|0);
    if ($56) {
     $57 = HEAP32[$50>>2]|0;
     $58 = ((($57)) + 36|0);
     $59 = HEAP32[$58>>2]|0;
     __THREW__ = 0;
     $60 = (invoke_ii($59|0,($50|0))|0);
     $61 = __THREW__; __THREW__ = 0;
     $62 = $61&1;
     if ($62) {
      break;
     } else {
      $$0$i$i2$i$i = $60;
     }
    } else {
     $63 = HEAP32[$53>>2]|0;
     $64 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($63)|0);
     $$0$i$i2$i$i = $64;
    }
    $65 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
    $66 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i2$i$i,$65)|0);
    if ($66) {
     HEAP32[$1>>2] = 0;
     $$pre$i4$i$i151 = 0;$67 = 1;
    } else {
     $$pre$i4$i$i151 = $50;$67 = 0;
    }
   }
   $tmp$i$i = $68 ^ $67;
   $69 = ($$2118|0)!=(0);
   $70 = $69 & $tmp$i$i;
   $71 = HEAP32[$0>>2]|0;
   if (!($70)) {
    label = 29;
    break;
   }
   $104 = ((($71)) + 12|0);
   $105 = HEAP32[$104>>2]|0;
   $106 = ((($71)) + 16|0);
   $107 = HEAP32[$106>>2]|0;
   $108 = ($105|0)==($107|0);
   if ($108) {
    $109 = HEAP32[$71>>2]|0;
    $110 = ((($109)) + 36|0);
    $111 = HEAP32[$110>>2]|0;
    __THREW__ = 0;
    $112 = (invoke_ii($111|0,($71|0))|0);
    $113 = __THREW__; __THREW__ = 0;
    $114 = $113&1;
    if ($114) {
     break;
    } else {
     $$0$i$i = $112;
    }
   } else {
    $115 = HEAP32[$105>>2]|0;
    $116 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($115)|0);
    $$0$i$i = $116;
   }
   if ($6) {
    $$0106 = $$0$i$i;
   } else {
    $117 = HEAP32[$4>>2]|0;
    $118 = ((($117)) + 28|0);
    $119 = HEAP32[$118>>2]|0;
    __THREW__ = 0;
    $120 = (invoke_iii($119|0,($4|0),($$0$i$i|0))|0);
    $121 = __THREW__; __THREW__ = 0;
    $122 = $121&1;
    if ($122) {
     break;
    } else {
     $$0106 = $120;
    }
   }
   $123 = (($$0107) + 1)|0;
   $$0104 = $2;$$0105$off0 = 0;$$1110 = $$0132;$$3115 = $$2114;$$3119 = $$2118;
   while(1) {
    $124 = ($$0104|0)==($3|0);
    if ($124) {
     break;
    }
    $125 = HEAP8[$$1110>>0]|0;
    $126 = ($125<<24>>24)==(1);
    do {
     if ($126) {
      $127 = ((($$0104)) + 8|0);
      $128 = ((($127)) + 3|0);
      $129 = HEAP8[$128>>0]|0;
      $130 = ($129<<24>>24)<(0);
      if ($130) {
       $131 = HEAP32[$$0104>>2]|0;
       $133 = $131;
      } else {
       $133 = $$0104;
      }
      $132 = (($133) + ($$0107<<2)|0);
      $134 = HEAP32[$132>>2]|0;
      if ($6) {
       $$0103 = $134;
      } else {
       $135 = HEAP32[$4>>2]|0;
       $136 = ((($135)) + 28|0);
       $137 = HEAP32[$136>>2]|0;
       __THREW__ = 0;
       $138 = (invoke_iii($137|0,($4|0),($134|0))|0);
       $139 = __THREW__; __THREW__ = 0;
       $140 = $139&1;
       if ($140) {
        break L20;
       } else {
        $$0103 = $138;
       }
      }
      $141 = ($$0106|0)==($$0103|0);
      $142 = (($$3119) + -1)|0;
      if (!($141)) {
       HEAP8[$$1110>>0] = 0;
       $$2$off0 = $$0105$off0;$$5 = $$3115;$$5121 = $142;
       break;
      }
      $143 = HEAP8[$128>>0]|0;
      $144 = ($143<<24>>24)<(0);
      if ($144) {
       $145 = ((($$0104)) + 4|0);
       $146 = HEAP32[$145>>2]|0;
       $148 = $146;
      } else {
       $147 = $143&255;
       $148 = $147;
      }
      $149 = ($148|0)==($123|0);
      if ($149) {
       $150 = (($$3115) + 1)|0;
       HEAP8[$$1110>>0] = 2;
       $$2$off0 = 1;$$5 = $150;$$5121 = $142;
      } else {
       $$2$off0 = 1;$$5 = $$3115;$$5121 = $$3119;
      }
     } else {
      $$2$off0 = $$0105$off0;$$5 = $$3115;$$5121 = $$3119;
     }
    } while(0);
    $151 = ((($$0104)) + 12|0);
    $152 = ((($$1110)) + 1|0);
    $$0104 = $151;$$0105$off0 = $$2$off0;$$1110 = $152;$$3115 = $$5;$$3119 = $$5121;
   }
   if (!($$0105$off0)) {
    $$0107 = $123;$$2114 = $$3115;$$2118 = $$3119;
    continue;
   }
   $153 = HEAP32[$0>>2]|0;
   $154 = ((($153)) + 12|0);
   $155 = HEAP32[$154>>2]|0;
   $156 = ((($153)) + 16|0);
   $157 = HEAP32[$156>>2]|0;
   $158 = ($155|0)==($157|0);
   if ($158) {
    $159 = HEAP32[$153>>2]|0;
    $160 = ((($159)) + 40|0);
    $161 = HEAP32[$160>>2]|0;
    __THREW__ = 0;
    (invoke_ii($161|0,($153|0))|0);
    $162 = __THREW__; __THREW__ = 0;
    $163 = $162&1;
    if ($163) {
     break;
    }
   } else {
    $164 = ((($155)) + 4|0);
    HEAP32[$154>>2] = $164;
    $165 = HEAP32[$155>>2]|0;
    (__ZNSt3__211char_traitsIwE11to_int_typeEw($165)|0);
   }
   $166 = (($$3115) + ($$3119))|0;
   $167 = ($166>>>0)>(1);
   if ($167) {
    $$0 = $2;$$2111 = $$0132;$$6 = $$3115;
   } else {
    $$0107 = $123;$$2114 = $$3115;$$2118 = $$3119;
    continue;
   }
   while(1) {
    $168 = ($$0|0)==($3|0);
    if ($168) {
     $$0107 = $123;$$2114 = $$6;$$2118 = $$3119;
     continue L20;
    }
    $169 = HEAP8[$$2111>>0]|0;
    $170 = ($169<<24>>24)==(2);
    if ($170) {
     $171 = ((($$0)) + 8|0);
     $172 = ((($171)) + 3|0);
     $173 = HEAP8[$172>>0]|0;
     $174 = ($173<<24>>24)<(0);
     if ($174) {
      $175 = ((($$0)) + 4|0);
      $176 = HEAP32[$175>>2]|0;
      $178 = $176;
     } else {
      $177 = $173&255;
      $178 = $177;
     }
     $179 = ($178|0)==($123|0);
     if ($179) {
      $$7 = $$6;
     } else {
      $180 = (($$6) + -1)|0;
      HEAP8[$$2111>>0] = 0;
      $$7 = $180;
     }
    } else {
     $$7 = $$6;
    }
    $181 = ((($$0)) + 12|0);
    $182 = ((($$2111)) + 1|0);
    $$0 = $181;$$2111 = $182;$$6 = $$7;
   }
  }
  L86: do {
   if ((label|0) == 29) {
    $72 = ($71|0)==(0|0);
    do {
     if ($72) {
      $198 = 1;
     } else {
      $73 = ((($71)) + 12|0);
      $74 = HEAP32[$73>>2]|0;
      $75 = ((($71)) + 16|0);
      $76 = HEAP32[$75>>2]|0;
      $77 = ($74|0)==($76|0);
      if ($77) {
       $78 = HEAP32[$71>>2]|0;
       $79 = ((($78)) + 36|0);
       $80 = HEAP32[$79>>2]|0;
       __THREW__ = 0;
       $81 = (invoke_ii($80|0,($71|0))|0);
       $82 = __THREW__; __THREW__ = 0;
       $83 = $82&1;
       if ($83) {
        break L86;
       } else {
        $$0$i$i$i$i143 = $81;
       }
      } else {
       $84 = HEAP32[$74>>2]|0;
       $85 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($84)|0);
       $$0$i$i$i$i143 = $85;
      }
      $86 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
      $87 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i$i$i143,$86)|0);
      if ($87) {
       HEAP32[$0>>2] = 0;
       $198 = 1;
       break;
      } else {
       $$pre$i$i$i145 = HEAP32[$0>>2]|0;
       $phitmp$i$i$i146 = ($$pre$i$i$i145|0)==(0|0);
       $198 = $phitmp$i$i$i146;
       break;
      }
     }
    } while(0);
    $88 = ($$pre$i4$i$i151|0)==(0|0);
    do {
     if ($88) {
      label = 76;
     } else {
      $89 = ((($$pre$i4$i$i151)) + 12|0);
      $90 = HEAP32[$89>>2]|0;
      $91 = ((($$pre$i4$i$i151)) + 16|0);
      $92 = HEAP32[$91>>2]|0;
      $93 = ($90|0)==($92|0);
      if ($93) {
       $94 = HEAP32[$$pre$i4$i$i151>>2]|0;
       $95 = ((($94)) + 36|0);
       $96 = HEAP32[$95>>2]|0;
       __THREW__ = 0;
       $97 = (invoke_ii($96|0,($$pre$i4$i$i151|0))|0);
       $98 = __THREW__; __THREW__ = 0;
       $99 = $98&1;
       if ($99) {
        break L86;
       } else {
        $$0$i$i2$i$i149 = $97;
       }
      } else {
       $100 = HEAP32[$90>>2]|0;
       $101 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($100)|0);
       $$0$i$i2$i$i149 = $101;
      }
      $102 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
      $103 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i2$i$i149,$102)|0);
      if ($103) {
       HEAP32[$1>>2] = 0;
       label = 76;
       break;
      } else {
       if ($198) {
        $$0133 = $2;$$3 = $$0132;
        break;
       } else {
        label = 78;
        break;
       }
      }
     }
    } while(0);
    if ((label|0) == 76) {
     if ($198) {
      label = 78;
     } else {
      $$0133 = $2;$$3 = $$0132;
     }
    }
    if ((label|0) == 78) {
     $183 = HEAP32[$5>>2]|0;
     $184 = $183 | 2;
     HEAP32[$5>>2] = $184;
     $$0133 = $2;$$3 = $$0132;
    }
    while(1) {
     $185 = ($$0133|0)==($3|0);
     if ($185) {
      label = 82;
      break;
     }
     $186 = HEAP8[$$3>>0]|0;
     $187 = ($186<<24>>24)==(2);
     if ($187) {
      $$0133197 = $$0133;
      break;
     }
     $188 = ((($$0133)) + 12|0);
     $189 = ((($$3)) + 1|0);
     $$0133 = $188;$$3 = $189;
    }
    if ((label|0) == 82) {
     $190 = HEAP32[$5>>2]|0;
     $191 = $190 | 4;
     HEAP32[$5>>2] = $191;
     $$0133197 = $3;
    }
    $192 = ($$sroa$0165$0|0)==(0);
    if (!($192)) {
     $193 = $$sroa$0165$0;
     _free($193);
    }
    STACKTOP = sp;return ($$0133197|0);
   }
  } while(0);
  $194 = ___cxa_find_matching_catch_2()|0;
  $195 = tempRet0;
  $196 = ($$sroa$0165$0|0)==(0);
  if ($196) {
   $$sink140$sink141205$index = $194;$$sink140$sink141205$index5 = $195;
  } else {
   $197 = $$sroa$0165$0;
   _free($197);
   $$sink140$sink141205$index = $194;$$sink140$sink141205$index5 = $195;
  }
 }
 ___resumeException($$sink140$sink141205$index|0);
 // unreachable;
 return (0)|0;
}
function __ZNSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEED2Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__26locale5facetD2Ev($0);
 return;
}
function __ZNSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEED0Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__26locale5facetD2Ev($0);
 __ZdlPv($0);
 return;
}
function __ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcb($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0 = 0, $$0$i$i = 0, $$011 = 0, $$byval_copy = 0, $$pr = 0, $$pr$pre = 0, $$sroa$0$0 = 0, $$sroa$0$0$copyload = 0, $$sroa$013$0 = 0, $$sroa$013$0$ph = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $$byval_copy = sp + 20|0;
 $5 = sp + 16|0;
 $6 = sp + 12|0;
 $7 = sp;
 $8 = ((($2)) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $9 & 1;
 $11 = ($10|0)==(0);
 L1: do {
  if ($11) {
   $12 = HEAP32[$0>>2]|0;
   $13 = ((($12)) + 24|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = HEAP32[$1>>2]|0;
   HEAP32[$5>>2] = $15;
   $16 = $4&1;
   ;HEAP32[$$byval_copy>>2]=HEAP32[$5>>2]|0;
   $17 = (FUNCTION_TABLE_iiiiii[$14 & 8191]($0,$$byval_copy,$2,$3,$16)|0);
   $$sroa$0$0 = $17;
  } else {
   __ZNKSt3__28ios_base6getlocEv($6,$2);
   __THREW__ = 0;
   $18 = (invoke_iii(3255,($6|0),(215204|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   do {
    if ($20) {
     $40 = ___cxa_find_matching_catch_2()|0;
     $41 = tempRet0;
     __ZNSt3__26localeD2Ev($6);
     $$0 = $41;$$011 = $40;
    } else {
     __ZNSt3__26localeD2Ev($6);
     $21 = HEAP32[$18>>2]|0;
     if ($4) {
      $22 = ((($21)) + 24|0);
      $23 = HEAP32[$22>>2]|0;
      FUNCTION_TABLE_vii[$23 & 8191]($7,$18);
     } else {
      $24 = ((($21)) + 28|0);
      $25 = HEAP32[$24>>2]|0;
      FUNCTION_TABLE_vii[$25 & 8191]($7,$18);
     }
     $26 = ((($7)) + 11|0);
     $27 = HEAP8[$26>>0]|0;
     $28 = ($27<<24>>24)<(0);
     if ($28) {
      $29 = HEAP32[$7>>2]|0;
      $$pr = $27;$$sroa$013$0$ph = $29;
      label = 9;
     } else {
      $$sroa$013$0 = $7;$30 = $27;
     }
     while(1) {
      if ((label|0) == 9) {
       label = 0;
       $$sroa$013$0 = $$sroa$013$0$ph;$30 = $$pr;
      }
      $31 = ($30<<24>>24)<(0);
      $32 = HEAP32[$7>>2]|0;
      $33 = ((($7)) + 4|0);
      $34 = HEAP32[$33>>2]|0;
      $35 = $30&255;
      $36 = $31 ? $32 : $7;
      $37 = $31 ? $34 : $35;
      $38 = (($36) + ($37)|0);
      $39 = ($$sroa$013$0|0)==($38|0);
      if ($39) {
       label = 11;
       break;
      }
      $42 = HEAP8[$$sroa$013$0>>0]|0;
      $43 = HEAP32[$1>>2]|0;
      $44 = ($43|0)==(0|0);
      if (!($44)) {
       $45 = ((($43)) + 24|0);
       $46 = HEAP32[$45>>2]|0;
       $47 = ((($43)) + 28|0);
       $48 = HEAP32[$47>>2]|0;
       $49 = ($46|0)==($48|0);
       if ($49) {
        $50 = HEAP32[$43>>2]|0;
        $51 = ((($50)) + 52|0);
        $52 = HEAP32[$51>>2]|0;
        $53 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($42)|0);
        __THREW__ = 0;
        $54 = (invoke_iii($52|0,($43|0),($53|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 20;
         break;
        } else {
         $$0$i$i = $54;
        }
       } else {
        $57 = ((($46)) + 1|0);
        HEAP32[$45>>2] = $57;
        HEAP8[$46>>0] = $42;
        $58 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($42)|0);
        $$0$i$i = $58;
       }
       $59 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
       $60 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i,$59)|0);
       if ($60) {
        HEAP32[$1>>2] = 0;
       }
      }
      $61 = ((($$sroa$013$0)) + 1|0);
      $$pr$pre = HEAP8[$26>>0]|0;
      $$pr = $$pr$pre;$$sroa$013$0$ph = $61;
      label = 9;
     }
     if ((label|0) == 11) {
      $$sroa$0$0$copyload = HEAP32[$1>>2]|0;
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($7);
      $$sroa$0$0 = $$sroa$0$0$copyload;
      break L1;
     }
     else if ((label|0) == 20) {
      $62 = ___cxa_find_matching_catch_2()|0;
      $63 = tempRet0;
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($7);
      $$0 = $63;$$011 = $62;
      break;
     }
    }
   } while(0);
   ___resumeException($$011|0);
   // unreachable;
  }
 } while(0);
 STACKTOP = sp;return ($$sroa$0$0|0);
}
function __ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcl($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$byval_copy = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(80|0);
 $$byval_copy = sp + 20|0;
 $vararg_buffer = sp;
 $5 = sp + 60|0;
 $6 = sp + 47|0;
 $7 = sp + 24|0;
 $8 = sp + 16|0;
 $9 = sp + 12|0;
 $10 = sp + 8|0;
 $11 = sp + 4|0;
 ;HEAP8[$5>>0]=HEAP8[202868>>0]|0;HEAP8[$5+1>>0]=HEAP8[202868+1>>0]|0;HEAP8[$5+2>>0]=HEAP8[202868+2>>0]|0;HEAP8[$5+3>>0]=HEAP8[202868+3>>0]|0;HEAP8[$5+4>>0]=HEAP8[202868+4>>0]|0;HEAP8[$5+5>>0]=HEAP8[202868+5>>0]|0;
 $12 = ((($5)) + 1|0);
 $13 = ((($2)) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 __ZNSt3__214__num_put_base12__format_intEPcPKcbj($12,202874,1,$14);
 $15 = (__ZNSt3__26__clocEv()|0);
 HEAP32[$vararg_buffer>>2] = $4;
 $16 = (__ZNSt3__219__libcpp_snprintf_lEPcjP15__locale_structPKcz($6,13,$15,$5,$vararg_buffer)|0);
 $17 = (($6) + ($16)|0);
 $18 = (__ZNSt3__214__num_put_base18__identify_paddingEPcS1_RKNS_8ios_baseE($6,$17,$2)|0);
 __ZNKSt3__28ios_base6getlocEv($10,$2);
 __THREW__ = 0;
 invoke_viiiiiii(4689,($6|0),($18|0),($17|0),($7|0),($8|0),($9|0),($10|0));
 $19 = __THREW__; __THREW__ = 0;
 $20 = $19&1;
 if ($20) {
  $25 = ___cxa_find_matching_catch_2()|0;
  $26 = tempRet0;
  __ZNSt3__26localeD2Ev($10);
  ___resumeException($25|0);
  // unreachable;
 } else {
  __ZNSt3__26localeD2Ev($10);
  $21 = HEAP32[$1>>2]|0;
  HEAP32[$11>>2] = $21;
  $22 = HEAP32[$8>>2]|0;
  $23 = HEAP32[$9>>2]|0;
  ;HEAP32[$$byval_copy>>2]=HEAP32[$11>>2]|0;
  $24 = (__ZNSt3__216__pad_and_outputIcNS_11char_traitsIcEEEENS_19ostreambuf_iteratorIT_T0_EES6_PKS4_S8_S8_RNS_8ios_baseES4_($$byval_copy,$7,$22,$23,$2,$3)|0);
  STACKTOP = sp;return ($24|0);
 }
 return (0)|0;
}
function __ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcx($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$byval_copy = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(112|0);
 $$byval_copy = sp + 32|0;
 $vararg_buffer = sp + 8|0;
 $6 = sp;
 $7 = sp + 79|0;
 $8 = sp + 36|0;
 $9 = sp + 28|0;
 $10 = sp + 24|0;
 $11 = sp + 20|0;
 $12 = sp + 16|0;
 $13 = $6;
 $14 = $13;
 HEAP32[$14>>2] = 37;
 $15 = (($13) + 4)|0;
 $16 = $15;
 HEAP32[$16>>2] = 0;
 $17 = ((($6)) + 1|0);
 $18 = ((($2)) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 __ZNSt3__214__num_put_base12__format_intEPcPKcbj($17,202865,1,$19);
 $20 = (__ZNSt3__26__clocEv()|0);
 $21 = $vararg_buffer;
 $22 = $21;
 HEAP32[$22>>2] = $4;
 $23 = (($21) + 4)|0;
 $24 = $23;
 HEAP32[$24>>2] = $5;
 $25 = (__ZNSt3__219__libcpp_snprintf_lEPcjP15__locale_structPKcz($7,23,$20,$6,$vararg_buffer)|0);
 $26 = (($7) + ($25)|0);
 $27 = (__ZNSt3__214__num_put_base18__identify_paddingEPcS1_RKNS_8ios_baseE($7,$26,$2)|0);
 __ZNKSt3__28ios_base6getlocEv($11,$2);
 __THREW__ = 0;
 invoke_viiiiiii(4689,($7|0),($27|0),($26|0),($8|0),($9|0),($10|0),($11|0));
 $28 = __THREW__; __THREW__ = 0;
 $29 = $28&1;
 if ($29) {
  $34 = ___cxa_find_matching_catch_2()|0;
  $35 = tempRet0;
  __ZNSt3__26localeD2Ev($11);
  ___resumeException($34|0);
  // unreachable;
 } else {
  __ZNSt3__26localeD2Ev($11);
  $30 = HEAP32[$1>>2]|0;
  HEAP32[$12>>2] = $30;
  $31 = HEAP32[$9>>2]|0;
  $32 = HEAP32[$10>>2]|0;
  ;HEAP32[$$byval_copy>>2]=HEAP32[$12>>2]|0;
  $33 = (__ZNSt3__216__pad_and_outputIcNS_11char_traitsIcEEEENS_19ostreambuf_iteratorIT_T0_EES6_PKS4_S8_S8_RNS_8ios_baseES4_($$byval_copy,$8,$31,$32,$2,$3)|0);
  STACKTOP = sp;return ($33|0);
 }
 return (0)|0;
}
function __ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcm($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$byval_copy = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(80|0);
 $$byval_copy = sp + 20|0;
 $vararg_buffer = sp;
 $5 = sp + 60|0;
 $6 = sp + 48|0;
 $7 = sp + 24|0;
 $8 = sp + 16|0;
 $9 = sp + 12|0;
 $10 = sp + 8|0;
 $11 = sp + 4|0;
 ;HEAP8[$5>>0]=HEAP8[202868>>0]|0;HEAP8[$5+1>>0]=HEAP8[202868+1>>0]|0;HEAP8[$5+2>>0]=HEAP8[202868+2>>0]|0;HEAP8[$5+3>>0]=HEAP8[202868+3>>0]|0;HEAP8[$5+4>>0]=HEAP8[202868+4>>0]|0;HEAP8[$5+5>>0]=HEAP8[202868+5>>0]|0;
 $12 = ((($5)) + 1|0);
 $13 = ((($2)) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 __ZNSt3__214__num_put_base12__format_intEPcPKcbj($12,202874,0,$14);
 $15 = (__ZNSt3__26__clocEv()|0);
 HEAP32[$vararg_buffer>>2] = $4;
 $16 = (__ZNSt3__219__libcpp_snprintf_lEPcjP15__locale_structPKcz($6,12,$15,$5,$vararg_buffer)|0);
 $17 = (($6) + ($16)|0);
 $18 = (__ZNSt3__214__num_put_base18__identify_paddingEPcS1_RKNS_8ios_baseE($6,$17,$2)|0);
 __ZNKSt3__28ios_base6getlocEv($10,$2);
 __THREW__ = 0;
 invoke_viiiiiii(4689,($6|0),($18|0),($17|0),($7|0),($8|0),($9|0),($10|0));
 $19 = __THREW__; __THREW__ = 0;
 $20 = $19&1;
 if ($20) {
  $25 = ___cxa_find_matching_catch_2()|0;
  $26 = tempRet0;
  __ZNSt3__26localeD2Ev($10);
  ___resumeException($25|0);
  // unreachable;
 } else {
  __ZNSt3__26localeD2Ev($10);
  $21 = HEAP32[$1>>2]|0;
  HEAP32[$11>>2] = $21;
  $22 = HEAP32[$8>>2]|0;
  $23 = HEAP32[$9>>2]|0;
  ;HEAP32[$$byval_copy>>2]=HEAP32[$11>>2]|0;
  $24 = (__ZNSt3__216__pad_and_outputIcNS_11char_traitsIcEEEENS_19ostreambuf_iteratorIT_T0_EES6_PKS4_S8_S8_RNS_8ios_baseES4_($$byval_copy,$7,$22,$23,$2,$3)|0);
  STACKTOP = sp;return ($24|0);
 }
 return (0)|0;
}
function __ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcy($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$byval_copy = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(112|0);
 $$byval_copy = sp + 32|0;
 $vararg_buffer = sp + 8|0;
 $6 = sp;
 $7 = sp + 79|0;
 $8 = sp + 36|0;
 $9 = sp + 28|0;
 $10 = sp + 24|0;
 $11 = sp + 20|0;
 $12 = sp + 16|0;
 $13 = $6;
 $14 = $13;
 HEAP32[$14>>2] = 37;
 $15 = (($13) + 4)|0;
 $16 = $15;
 HEAP32[$16>>2] = 0;
 $17 = ((($6)) + 1|0);
 $18 = ((($2)) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 __ZNSt3__214__num_put_base12__format_intEPcPKcbj($17,202865,0,$19);
 $20 = (__ZNSt3__26__clocEv()|0);
 $21 = $vararg_buffer;
 $22 = $21;
 HEAP32[$22>>2] = $4;
 $23 = (($21) + 4)|0;
 $24 = $23;
 HEAP32[$24>>2] = $5;
 $25 = (__ZNSt3__219__libcpp_snprintf_lEPcjP15__locale_structPKcz($7,23,$20,$6,$vararg_buffer)|0);
 $26 = (($7) + ($25)|0);
 $27 = (__ZNSt3__214__num_put_base18__identify_paddingEPcS1_RKNS_8ios_baseE($7,$26,$2)|0);
 __ZNKSt3__28ios_base6getlocEv($11,$2);
 __THREW__ = 0;
 invoke_viiiiiii(4689,($7|0),($27|0),($26|0),($8|0),($9|0),($10|0),($11|0));
 $28 = __THREW__; __THREW__ = 0;
 $29 = $28&1;
 if ($29) {
  $34 = ___cxa_find_matching_catch_2()|0;
  $35 = tempRet0;
  __ZNSt3__26localeD2Ev($11);
  ___resumeException($34|0);
  // unreachable;
 } else {
  __ZNSt3__26localeD2Ev($11);
  $30 = HEAP32[$1>>2]|0;
  HEAP32[$12>>2] = $30;
  $31 = HEAP32[$9>>2]|0;
  $32 = HEAP32[$10>>2]|0;
  ;HEAP32[$$byval_copy>>2]=HEAP32[$12>>2]|0;
  $33 = (__ZNSt3__216__pad_and_outputIcNS_11char_traitsIcEEEENS_19ostreambuf_iteratorIT_T0_EES6_PKS4_S8_S8_RNS_8ios_baseES4_($$byval_copy,$8,$31,$32,$2,$3)|0);
  STACKTOP = sp;return ($33|0);
 }
 return (0)|0;
}
function __ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcd($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = +$4;
 var $$0 = 0, $$046 = 0, $$047 = 0, $$050 = 0, $$1 = 0, $$148 = 0, $$151 = 0, $$2 = 0, $$24982 = 0, $$25281 = 0, $$45484 = 0, $$485 = 0, $$byval_copy = 0, $$pre = 0, $$sroa$060$0 = 0, $$sroa$071$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer2 = 0, $vararg_buffer5 = 0, $vararg_buffer9 = 0, $vararg_ptr1 = 0, $vararg_ptr8 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(176|0);
 $$byval_copy = sp + 76|0;
 $vararg_buffer9 = sp + 48|0;
 $vararg_buffer5 = sp + 32|0;
 $vararg_buffer2 = sp + 24|0;
 $vararg_buffer = sp + 8|0;
 $5 = sp;
 $6 = sp + 138|0;
 $7 = sp + 72|0;
 $8 = sp + 80|0;
 $9 = sp + 68|0;
 $10 = sp + 64|0;
 $11 = sp + 60|0;
 $12 = sp + 56|0;
 $13 = $5;
 $14 = $13;
 HEAP32[$14>>2] = 37;
 $15 = (($13) + 4)|0;
 $16 = $15;
 HEAP32[$16>>2] = 0;
 $17 = ((($5)) + 1|0);
 $18 = ((($2)) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (__ZNSt3__214__num_put_base14__format_floatEPcPKcj($17,221531,$19)|0);
 HEAP32[$7>>2] = $6;
 $21 = (__ZNSt3__26__clocEv()|0);
 if ($20) {
  $22 = ((($2)) + 8|0);
  $23 = HEAP32[$22>>2]|0;
  HEAP32[$vararg_buffer>>2] = $23;
  $vararg_ptr1 = ((($vararg_buffer)) + 8|0);
  HEAPF64[$vararg_ptr1>>3] = $4;
  $24 = (__ZNSt3__219__libcpp_snprintf_lEPcjP15__locale_structPKcz($6,30,$21,$5,$vararg_buffer)|0);
  $$0 = $24;
 } else {
  HEAPF64[$vararg_buffer2>>3] = $4;
  $25 = (__ZNSt3__219__libcpp_snprintf_lEPcjP15__locale_structPKcz($6,30,$21,$5,$vararg_buffer2)|0);
  $$0 = $25;
 }
 $26 = ($$0|0)>(29);
 L5: do {
  if ($26) {
   if ($20) {
    __THREW__ = 0;
    $27 = (invoke_i(4668)|0);
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if (!($29)) {
     $30 = ((($2)) + 8|0);
     $31 = HEAP32[$30>>2]|0;
     __THREW__ = 0;
     HEAP32[$vararg_buffer5>>2] = $31;
     $vararg_ptr8 = ((($vararg_buffer5)) + 8|0);
     HEAPF64[$vararg_ptr8>>3] = $4;
     $32 = (invoke_iiiii(4690,($7|0),($27|0),($5|0),($vararg_buffer5|0))|0);
     $33 = __THREW__; __THREW__ = 0;
     $34 = $33&1;
     if (!($34)) {
      $$1 = $32;
      label = 12;
     }
    }
   } else {
    __THREW__ = 0;
    $37 = (invoke_i(4668)|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if (!($39)) {
     __THREW__ = 0;
     HEAPF64[$vararg_buffer9>>3] = $4;
     $40 = (invoke_iiiii(4690,($7|0),($37|0),($5|0),($vararg_buffer9|0))|0);
     $41 = __THREW__; __THREW__ = 0;
     $42 = $41&1;
     if (!($42)) {
      $$1 = $40;
      label = 12;
     }
    }
   }
   do {
    if ((label|0) == 12) {
     $43 = HEAP32[$7>>2]|0;
     $44 = ($43|0)==(0|0);
     if ($44) {
      __THREW__ = 0;
      invoke_v(4685);
      $45 = __THREW__; __THREW__ = 0;
      break;
     } else {
      $46 = $43;
      $$2 = $$1;$$sroa$071$0 = $46;$48 = $43;
      label = 15;
      break L5;
     }
    }
   } while(0);
   $35 = ___cxa_find_matching_catch_2()|0;
   $36 = tempRet0;
   $$45484 = $36;$$485 = $35;
  } else {
   $$pre = HEAP32[$7>>2]|0;
   $$2 = $$0;$$sroa$071$0 = 0;$48 = $$pre;
   label = 15;
  }
 } while(0);
 if ((label|0) == 15) {
  $47 = (($48) + ($$2)|0);
  $49 = (__ZNSt3__214__num_put_base18__identify_paddingEPcS1_RKNS_8ios_baseE($48,$47,$2)|0);
  $50 = ($48|0)==($6|0);
  do {
   if ($50) {
    $$046 = $8;$$sroa$060$0 = 0;
    label = 19;
   } else {
    $51 = $$2 << 1;
    $52 = (_malloc($51)|0);
    $53 = ($52|0)==(0|0);
    if ($53) {
     __THREW__ = 0;
     invoke_v(4685);
     $54 = __THREW__; __THREW__ = 0;
     $55 = ___cxa_find_matching_catch_2()|0;
     $56 = tempRet0;
     $$24982 = $55;$$25281 = $56;
     break;
    } else {
     $57 = $52;
     $$046 = $52;$$sroa$060$0 = $57;
     label = 19;
     break;
    }
   }
  } while(0);
  if ((label|0) == 19) {
   __THREW__ = 0;
   invoke_vii(3257,($11|0),($2|0));
   $58 = __THREW__; __THREW__ = 0;
   $59 = $58&1;
   do {
    if ($59) {
     $72 = ___cxa_find_matching_catch_2()|0;
     $73 = tempRet0;
     $$047 = $72;$$050 = $73;
     label = 29;
    } else {
     __THREW__ = 0;
     invoke_viiiiiii(4691,($48|0),($49|0),($47|0),($$046|0),($9|0),($10|0),($11|0));
     $60 = __THREW__; __THREW__ = 0;
     $61 = $60&1;
     if ($61) {
      $74 = ___cxa_find_matching_catch_2()|0;
      $75 = tempRet0;
      __ZNSt3__26localeD2Ev($11);
      $$047 = $74;$$050 = $75;
      label = 29;
      break;
     }
     __ZNSt3__26localeD2Ev($11);
     $62 = HEAP32[$1>>2]|0;
     HEAP32[$12>>2] = $62;
     $63 = HEAP32[$9>>2]|0;
     $64 = HEAP32[$10>>2]|0;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy>>2]=HEAP32[$12>>2]|0;
     $65 = (invoke_iiiiiii(3258,($$byval_copy|0),($$046|0),($63|0),($64|0),($2|0),($3|0))|0);
     $66 = __THREW__; __THREW__ = 0;
     $67 = $66&1;
     if ($67) {
      $76 = ___cxa_find_matching_catch_2()|0;
      $77 = tempRet0;
      $$148 = $76;$$151 = $77;
      break;
     }
     HEAP32[$1>>2] = $65;
     $68 = ($$sroa$060$0|0)==(0);
     if (!($68)) {
      $69 = $$sroa$060$0;
      _free($69);
     }
     $70 = ($$sroa$071$0|0)==(0);
     if (!($70)) {
      $71 = $$sroa$071$0;
      _free($71);
     }
     STACKTOP = sp;return ($65|0);
    }
   } while(0);
   if ((label|0) == 29) {
    $$148 = $$047;$$151 = $$050;
   }
   $78 = ($$sroa$060$0|0)==(0);
   if ($78) {
    $$24982 = $$148;$$25281 = $$151;
   } else {
    $79 = $$sroa$060$0;
    _free($79);
    $$24982 = $$148;$$25281 = $$151;
   }
  }
  $80 = ($$sroa$071$0|0)==(0);
  if ($80) {
   $$45484 = $$25281;$$485 = $$24982;
  } else {
   $81 = $$sroa$071$0;
   _free($81);
   $$45484 = $$25281;$$485 = $$24982;
  }
 }
 ___resumeException($$485|0);
 // unreachable;
 return (0)|0;
}
function __ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEce($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = +$4;
 var $$0 = 0, $$046 = 0, $$047 = 0, $$050 = 0, $$1 = 0, $$148 = 0, $$151 = 0, $$2 = 0, $$24982 = 0, $$25281 = 0, $$45484 = 0, $$485 = 0, $$byval_copy = 0, $$pre = 0, $$sroa$060$0 = 0, $$sroa$071$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer2 = 0, $vararg_buffer5 = 0, $vararg_buffer9 = 0, $vararg_ptr1 = 0, $vararg_ptr8 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(176|0);
 $$byval_copy = sp + 76|0;
 $vararg_buffer9 = sp + 48|0;
 $vararg_buffer5 = sp + 32|0;
 $vararg_buffer2 = sp + 24|0;
 $vararg_buffer = sp + 8|0;
 $5 = sp;
 $6 = sp + 138|0;
 $7 = sp + 72|0;
 $8 = sp + 80|0;
 $9 = sp + 68|0;
 $10 = sp + 64|0;
 $11 = sp + 60|0;
 $12 = sp + 56|0;
 $13 = $5;
 $14 = $13;
 HEAP32[$14>>2] = 37;
 $15 = (($13) + 4)|0;
 $16 = $15;
 HEAP32[$16>>2] = 0;
 $17 = ((($5)) + 1|0);
 $18 = ((($2)) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (__ZNSt3__214__num_put_base14__format_floatEPcPKcj($17,202863,$19)|0);
 HEAP32[$7>>2] = $6;
 $21 = (__ZNSt3__26__clocEv()|0);
 if ($20) {
  $22 = ((($2)) + 8|0);
  $23 = HEAP32[$22>>2]|0;
  HEAP32[$vararg_buffer>>2] = $23;
  $vararg_ptr1 = ((($vararg_buffer)) + 8|0);
  HEAPF64[$vararg_ptr1>>3] = $4;
  $24 = (__ZNSt3__219__libcpp_snprintf_lEPcjP15__locale_structPKcz($6,30,$21,$5,$vararg_buffer)|0);
  $$0 = $24;
 } else {
  HEAPF64[$vararg_buffer2>>3] = $4;
  $25 = (__ZNSt3__219__libcpp_snprintf_lEPcjP15__locale_structPKcz($6,30,$21,$5,$vararg_buffer2)|0);
  $$0 = $25;
 }
 $26 = ($$0|0)>(29);
 L5: do {
  if ($26) {
   if ($20) {
    __THREW__ = 0;
    $27 = (invoke_i(4668)|0);
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if (!($29)) {
     $30 = ((($2)) + 8|0);
     $31 = HEAP32[$30>>2]|0;
     __THREW__ = 0;
     HEAP32[$vararg_buffer5>>2] = $31;
     $vararg_ptr8 = ((($vararg_buffer5)) + 8|0);
     HEAPF64[$vararg_ptr8>>3] = $4;
     $32 = (invoke_iiiii(4690,($7|0),($27|0),($5|0),($vararg_buffer5|0))|0);
     $33 = __THREW__; __THREW__ = 0;
     $34 = $33&1;
     if (!($34)) {
      $$1 = $32;
      label = 12;
     }
    }
   } else {
    __THREW__ = 0;
    $37 = (invoke_i(4668)|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if (!($39)) {
     __THREW__ = 0;
     HEAPF64[$vararg_buffer9>>3] = $4;
     $40 = (invoke_iiiii(4690,($7|0),($37|0),($5|0),($vararg_buffer9|0))|0);
     $41 = __THREW__; __THREW__ = 0;
     $42 = $41&1;
     if (!($42)) {
      $$1 = $40;
      label = 12;
     }
    }
   }
   do {
    if ((label|0) == 12) {
     $43 = HEAP32[$7>>2]|0;
     $44 = ($43|0)==(0|0);
     if ($44) {
      __THREW__ = 0;
      invoke_v(4685);
      $45 = __THREW__; __THREW__ = 0;
      break;
     } else {
      $46 = $43;
      $$2 = $$1;$$sroa$071$0 = $46;$48 = $43;
      label = 15;
      break L5;
     }
    }
   } while(0);
   $35 = ___cxa_find_matching_catch_2()|0;
   $36 = tempRet0;
   $$45484 = $36;$$485 = $35;
  } else {
   $$pre = HEAP32[$7>>2]|0;
   $$2 = $$0;$$sroa$071$0 = 0;$48 = $$pre;
   label = 15;
  }
 } while(0);
 if ((label|0) == 15) {
  $47 = (($48) + ($$2)|0);
  $49 = (__ZNSt3__214__num_put_base18__identify_paddingEPcS1_RKNS_8ios_baseE($48,$47,$2)|0);
  $50 = ($48|0)==($6|0);
  do {
   if ($50) {
    $$046 = $8;$$sroa$060$0 = 0;
    label = 19;
   } else {
    $51 = $$2 << 1;
    $52 = (_malloc($51)|0);
    $53 = ($52|0)==(0|0);
    if ($53) {
     __THREW__ = 0;
     invoke_v(4685);
     $54 = __THREW__; __THREW__ = 0;
     $55 = ___cxa_find_matching_catch_2()|0;
     $56 = tempRet0;
     $$24982 = $55;$$25281 = $56;
     break;
    } else {
     $57 = $52;
     $$046 = $52;$$sroa$060$0 = $57;
     label = 19;
     break;
    }
   }
  } while(0);
  if ((label|0) == 19) {
   __THREW__ = 0;
   invoke_vii(3257,($11|0),($2|0));
   $58 = __THREW__; __THREW__ = 0;
   $59 = $58&1;
   do {
    if ($59) {
     $72 = ___cxa_find_matching_catch_2()|0;
     $73 = tempRet0;
     $$047 = $72;$$050 = $73;
     label = 29;
    } else {
     __THREW__ = 0;
     invoke_viiiiiii(4691,($48|0),($49|0),($47|0),($$046|0),($9|0),($10|0),($11|0));
     $60 = __THREW__; __THREW__ = 0;
     $61 = $60&1;
     if ($61) {
      $74 = ___cxa_find_matching_catch_2()|0;
      $75 = tempRet0;
      __ZNSt3__26localeD2Ev($11);
      $$047 = $74;$$050 = $75;
      label = 29;
      break;
     }
     __ZNSt3__26localeD2Ev($11);
     $62 = HEAP32[$1>>2]|0;
     HEAP32[$12>>2] = $62;
     $63 = HEAP32[$9>>2]|0;
     $64 = HEAP32[$10>>2]|0;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy>>2]=HEAP32[$12>>2]|0;
     $65 = (invoke_iiiiiii(3258,($$byval_copy|0),($$046|0),($63|0),($64|0),($2|0),($3|0))|0);
     $66 = __THREW__; __THREW__ = 0;
     $67 = $66&1;
     if ($67) {
      $76 = ___cxa_find_matching_catch_2()|0;
      $77 = tempRet0;
      $$148 = $76;$$151 = $77;
      break;
     }
     HEAP32[$1>>2] = $65;
     $68 = ($$sroa$060$0|0)==(0);
     if (!($68)) {
      $69 = $$sroa$060$0;
      _free($69);
     }
     $70 = ($$sroa$071$0|0)==(0);
     if (!($70)) {
      $71 = $$sroa$071$0;
      _free($71);
     }
     STACKTOP = sp;return ($65|0);
    }
   } while(0);
   if ((label|0) == 29) {
    $$148 = $$047;$$151 = $$050;
   }
   $78 = ($$sroa$060$0|0)==(0);
   if ($78) {
    $$24982 = $$148;$$25281 = $$151;
   } else {
    $79 = $$sroa$060$0;
    _free($79);
    $$24982 = $$148;$$25281 = $$151;
   }
  }
  $80 = ($$sroa$071$0|0)==(0);
  if ($80) {
   $$45484 = $$25281;$$485 = $$24982;
  } else {
   $81 = $$sroa$071$0;
   _free($81);
   $$45484 = $$25281;$$485 = $$24982;
  }
 }
 ___resumeException($$485|0);
 // unreachable;
 return (0)|0;
}
function __ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcPKv($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0 = 0, $$byval_copy = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(96|0);
 $$byval_copy = sp + 12|0;
 $vararg_buffer = sp;
 $5 = sp + 76|0;
 $6 = sp + 56|0;
 $7 = sp + 16|0;
 $8 = sp + 8|0;
 $9 = sp + 4|0;
 ;HEAP8[$5>>0]=HEAP8[202857>>0]|0;HEAP8[$5+1>>0]=HEAP8[202857+1>>0]|0;HEAP8[$5+2>>0]=HEAP8[202857+2>>0]|0;HEAP8[$5+3>>0]=HEAP8[202857+3>>0]|0;HEAP8[$5+4>>0]=HEAP8[202857+4>>0]|0;HEAP8[$5+5>>0]=HEAP8[202857+5>>0]|0;
 $10 = (__ZNSt3__26__clocEv()|0);
 HEAP32[$vararg_buffer>>2] = $4;
 $11 = (__ZNSt3__219__libcpp_snprintf_lEPcjP15__locale_structPKcz($6,20,$10,$5,$vararg_buffer)|0);
 $12 = (($6) + ($11)|0);
 $13 = (__ZNSt3__214__num_put_base18__identify_paddingEPcS1_RKNS_8ios_baseE($6,$12,$2)|0);
 __ZNKSt3__28ios_base6getlocEv($8,$2);
 __THREW__ = 0;
 $14 = (invoke_iii(3255,($8|0),(215188|0))|0);
 $15 = __THREW__; __THREW__ = 0;
 $16 = $15&1;
 if ($16) {
  $28 = ___cxa_find_matching_catch_2()|0;
  $29 = tempRet0;
  __ZNSt3__26localeD2Ev($8);
  ___resumeException($28|0);
  // unreachable;
 } else {
  __ZNSt3__26localeD2Ev($8);
  $17 = HEAP32[$14>>2]|0;
  $18 = ((($17)) + 32|0);
  $19 = HEAP32[$18>>2]|0;
  (FUNCTION_TABLE_iiiii[$19 & 8191]($14,$6,$12,$7)|0);
  $20 = (($7) + ($11)|0);
  $21 = ($13|0)==($12|0);
  $22 = $6;
  $23 = $13;
  $24 = (($23) - ($22))|0;
  $25 = (($7) + ($24)|0);
  $$0 = $21 ? $20 : $25;
  $26 = HEAP32[$1>>2]|0;
  HEAP32[$9>>2] = $26;
  ;HEAP32[$$byval_copy>>2]=HEAP32[$9>>2]|0;
  $27 = (__ZNSt3__216__pad_and_outputIcNS_11char_traitsIcEEEENS_19ostreambuf_iteratorIT_T0_EES6_PKS4_S8_S8_RNS_8ios_baseES4_($$byval_copy,$7,$$0,$20,$2,$3)|0);
  STACKTOP = sp;return ($27|0);
 }
 return (0)|0;
}
function __ZNSt3__219__libcpp_snprintf_lEPcjP15__locale_structPKcz($0,$1,$2,$3,$varargs) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $varargs = $varargs|0;
 var $10 = 0, $11 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $4 = sp;
 HEAP32[$4>>2] = $varargs;
 $5 = (___uselocale($2)|0);
 $6 = (_vsnprintf($0,$1,$3,$4)|0);
 $7 = ($5|0)==(0|0);
 if (!($7)) {
  __THREW__ = 0;
  (invoke_ii(4671,($5|0))|0);
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if ($9) {
   $10 = ___cxa_find_matching_catch_3(0|0)|0;
   $11 = tempRet0;
   ___clang_call_terminate($10);
   // unreachable;
  }
 }
 STACKTOP = sp;return ($6|0);
}
function __ZNSt3__214__num_put_base18__identify_paddingEPcS1_RKNS_8ios_baseE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $trunc = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($2)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 & 176;
 $trunc = $5&255;
 L1: do {
  switch ($trunc<<24>>24) {
  case 16:  {
   $6 = HEAP8[$0>>0]|0;
   $7 = ((($0)) + 1|0);
   switch ($6<<24>>24) {
   case 43: case 45:  {
    $$0 = $7;
    break L1;
    break;
   }
   default: {
   }
   }
   $8 = $1;
   $9 = $0;
   $10 = (($8) - ($9))|0;
   $11 = ($10|0)>(1);
   $12 = ($6<<24>>24)==(48);
   $or$cond = $11 & $12;
   if ($or$cond) {
    $13 = HEAP8[$7>>0]|0;
    switch ($13<<24>>24) {
    case 88: case 120:  {
     break;
    }
    default: {
     label = 6;
     break L1;
    }
    }
    $14 = ((($0)) + 2|0);
    $$0 = $14;
   } else {
    label = 6;
   }
   break;
  }
  case 32:  {
   $$0 = $1;
   break;
  }
  default: {
   label = 6;
  }
  }
 } while(0);
 if ((label|0) == 6) {
  $$0 = $0;
 }
 return ($$0|0);
}
function __ZNSt3__214__num_put_base14__format_floatEPcPKcj($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$026 = 0, $$027$off0$ph = 0, $$1 = 0, $$2 = 0, $$2$ph = 0, $$sink = 0, $$sink1 = 0, $$sink1$sink = 0, $$sink2 = 0, $$sink3 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $trunc = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = $2 & 2048;
 $4 = ($3|0)==(0);
 if ($4) {
  $$0 = $0;
 } else {
  $5 = ((($0)) + 1|0);
  HEAP8[$0>>0] = 43;
  $$0 = $5;
 }
 $6 = $2 & 1024;
 $7 = ($6|0)==(0);
 if ($7) {
  $$1 = $$0;
 } else {
  $8 = ((($$0)) + 1|0);
  HEAP8[$$0>>0] = 35;
  $$1 = $8;
 }
 $9 = $2 & 260;
 $10 = $2 & 16384;
 $11 = ($10|0)!=(0);
 $12 = ($9|0)==(260);
 if ($12) {
  $$027$off0$ph = 0;$$2$ph = $$1;
 } else {
  $13 = ((($$1)) + 1|0);
  HEAP8[$$1>>0] = 46;
  $14 = ((($$1)) + 2|0);
  HEAP8[$13>>0] = 42;
  $$027$off0$ph = 1;$$2$ph = $14;
 }
 $$026 = $1;$$2 = $$2$ph;
 while(1) {
  $15 = HEAP8[$$026>>0]|0;
  $16 = ($15<<24>>24)==(0);
  if ($16) {
   break;
  }
  $17 = ((($$026)) + 1|0);
  $18 = ((($$2)) + 1|0);
  HEAP8[$$2>>0] = $15;
  $$026 = $17;$$2 = $18;
 }
 $trunc = $9&65535;
 $trunc$clear = $trunc & 511;
 L14: do {
  switch ($trunc$clear<<16>>16) {
  case 4:  {
   $$sink = $11 ? 70 : 102;
   $$sink1$sink = $$sink;
   break;
  }
  case 256:  {
   $$sink1 = $11 ? 69 : 101;
   $$sink1$sink = $$sink1;
   break;
  }
  default: {
   if ($12) {
    $$sink2 = $11 ? 65 : 97;
    $$sink1$sink = $$sink2;
    break L14;
   } else {
    $$sink3 = $11 ? 71 : 103;
    $$sink1$sink = $$sink3;
    break L14;
   }
  }
  }
 } while(0);
 HEAP8[$$2>>0] = $$sink1$sink;
 return ($$027$off0$ph|0);
}
function __ZNSt3__219__libcpp_asprintf_lEPPcP15__locale_structPKcz($0,$1,$2,$varargs) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $varargs = $varargs|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 HEAP32[$3>>2] = $varargs;
 $4 = (___uselocale($1)|0);
 __THREW__ = 0;
 $5 = (invoke_iiii(4692,($0|0),($2|0),($3|0))|0);
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if ($7) {
  $13 = ___cxa_find_matching_catch_2()|0;
  $14 = tempRet0;
  $15 = ($4|0)==(0|0);
  if (!($15)) {
   __THREW__ = 0;
   (invoke_ii(4671,($4|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if ($17) {
    $18 = ___cxa_find_matching_catch_3(0|0)|0;
    $19 = tempRet0;
    ___clang_call_terminate($18);
    // unreachable;
   }
  }
  ___resumeException($13|0);
  // unreachable;
 } else {
  $8 = ($4|0)==(0|0);
  if (!($8)) {
   __THREW__ = 0;
   (invoke_ii(4671,($4|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if ($10) {
    $11 = ___cxa_find_matching_catch_3(0|0)|0;
    $12 = tempRet0;
    ___clang_call_terminate($11);
    // unreachable;
   }
  }
  STACKTOP = sp;return ($5|0);
 }
 return (0)|0;
}
function __ZNSt3__29__num_putIcE23__widen_and_group_floatEPcS2_S2_S2_RS2_S3_RKNS_6localeE($0,$1,$2,$3,$4,$5,$6) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 var $$$0108 = 0, $$0 = 0, $$0$i$i = 0, $$0$i$i128 = 0, $$0108 = 0, $$0109 = 0, $$0111 = 0, $$0113 = 0, $$07$i$i = 0, $$07$i$i127 = 0, $$1 = 0, $$1110 = 0, $$1112 = 0, $$1114 = 0, $$2 = 0, $$2115 = 0, $$3 = 0, $$pre$phiZ2D = 0, $10 = 0, $100 = 0;
 var $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0;
 var $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0;
 var $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0;
 var $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0;
 var $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $storemerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $7 = sp;
 $8 = (__ZNKSt3__26locale9use_facetERNS0_2idE($6,215188)|0);
 $9 = (__ZNKSt3__26locale9use_facetERNS0_2idE($6,215204)|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ((($10)) + 20|0);
 $12 = HEAP32[$11>>2]|0;
 FUNCTION_TABLE_vii[$12 & 8191]($7,$9);
 HEAP32[$5>>2] = $3;
 $13 = HEAP8[$0>>0]|0;
 switch ($13<<24>>24) {
 case 43: case 45:  {
  $14 = HEAP32[$8>>2]|0;
  $15 = ((($14)) + 28|0);
  $16 = HEAP32[$15>>2]|0;
  __THREW__ = 0;
  $17 = (invoke_iii($16|0,($8|0),($13|0))|0);
  $18 = __THREW__; __THREW__ = 0;
  $19 = $18&1;
  if (!($19)) {
   $20 = ((($0)) + 1|0);
   $21 = HEAP32[$5>>2]|0;
   $22 = ((($21)) + 1|0);
   HEAP32[$5>>2] = $22;
   HEAP8[$21>>0] = $17;
   $$0111 = $20;
   label = 4;
  }
  break;
 }
 default: {
  $$0111 = $0;
  label = 4;
 }
 }
 L4: do {
  if ((label|0) == 4) {
   $23 = $2;
   $24 = $$0111;
   $25 = (($23) - ($24))|0;
   $26 = ($25|0)>(1);
   L6: do {
    if ($26) {
     $27 = HEAP8[$$0111>>0]|0;
     $28 = ($27<<24>>24)==(48);
     if ($28) {
      $29 = ((($$0111)) + 1|0);
      $30 = HEAP8[$29>>0]|0;
      switch ($30<<24>>24) {
      case 88: case 120:  {
       break;
      }
      default: {
       $$1114 = $$0111;
       label = 15;
       break L6;
      }
      }
      $31 = HEAP32[$8>>2]|0;
      $32 = ((($31)) + 28|0);
      $33 = HEAP32[$32>>2]|0;
      __THREW__ = 0;
      $34 = (invoke_iii($33|0,($8|0),48)|0);
      $35 = __THREW__; __THREW__ = 0;
      $36 = $35&1;
      if ($36) {
       break L4;
      }
      $37 = HEAP32[$5>>2]|0;
      $38 = ((($37)) + 1|0);
      HEAP32[$5>>2] = $38;
      HEAP8[$37>>0] = $34;
      $39 = ((($$0111)) + 2|0);
      $40 = HEAP8[$29>>0]|0;
      $41 = HEAP32[$8>>2]|0;
      $42 = ((($41)) + 28|0);
      $43 = HEAP32[$42>>2]|0;
      __THREW__ = 0;
      $44 = (invoke_iii($43|0,($8|0),($40|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       break L4;
      }
      $47 = HEAP32[$5>>2]|0;
      $48 = ((($47)) + 1|0);
      HEAP32[$5>>2] = $48;
      HEAP8[$47>>0] = $44;
      $$0113 = $39;
      while(1) {
       $49 = ($$0113>>>0)<($2>>>0);
       if (!($49)) {
        $$1112 = $39;$$2115 = $$0113;
        break L6;
       }
       $50 = HEAP8[$$0113>>0]|0;
       __THREW__ = 0;
       $51 = (invoke_i(4668)|0);
       $52 = __THREW__; __THREW__ = 0;
       $53 = $52&1;
       if ($53) {
        break L4;
       }
       $54 = $50 << 24 >> 24;
       __THREW__ = 0;
       $55 = (invoke_iii(4693,($54|0),($51|0))|0);
       $56 = __THREW__; __THREW__ = 0;
       $57 = $56&1;
       if ($57) {
        break L4;
       }
       $58 = ($55|0)==(0);
       if ($58) {
        $$1112 = $39;$$2115 = $$0113;
        break L6;
       }
       $59 = ((($$0113)) + 1|0);
       $$0113 = $59;
      }
     } else {
      $$1114 = $$0111;
      label = 15;
     }
    } else {
     $$1114 = $$0111;
     label = 15;
    }
   } while(0);
   L18: do {
    if ((label|0) == 15) {
     while(1) {
      label = 0;
      $60 = ($$1114>>>0)<($2>>>0);
      if (!($60)) {
       $$1112 = $$0111;$$2115 = $$1114;
       break L18;
      }
      $61 = HEAP8[$$1114>>0]|0;
      __THREW__ = 0;
      $62 = (invoke_i(4668)|0);
      $63 = __THREW__; __THREW__ = 0;
      $64 = $63&1;
      if ($64) {
       break L4;
      }
      $65 = $61 << 24 >> 24;
      __THREW__ = 0;
      $66 = (invoke_iii(4694,($65|0),($62|0))|0);
      $67 = __THREW__; __THREW__ = 0;
      $68 = $67&1;
      if ($68) {
       break L4;
      }
      $69 = ($66|0)==(0);
      if ($69) {
       $$1112 = $$0111;$$2115 = $$1114;
       break L18;
      }
      $70 = ((($$1114)) + 1|0);
      $$1114 = $70;
      label = 15;
     }
    }
   } while(0);
   $71 = ((($7)) + 11|0);
   $72 = HEAP8[$71>>0]|0;
   $73 = ($72<<24>>24)<(0);
   $74 = ((($7)) + 4|0);
   $75 = HEAP32[$74>>2]|0;
   $76 = $72&255;
   $77 = $73 ? $75 : $76;
   $78 = ($77|0)==(0);
   $79 = $$1112;
   $80 = $0;
   L26: do {
    if ($78) {
     $81 = HEAP32[$5>>2]|0;
     $82 = HEAP32[$8>>2]|0;
     $83 = ((($82)) + 32|0);
     $84 = HEAP32[$83>>2]|0;
     __THREW__ = 0;
     (invoke_iiiii($84|0,($8|0),($$1112|0),($$2115|0),($81|0))|0);
     $85 = __THREW__; __THREW__ = 0;
     $86 = $85&1;
     if ($86) {
      break L4;
     }
     $87 = $$2115;
     $88 = (($87) - ($79))|0;
     $89 = HEAP32[$5>>2]|0;
     $90 = (($89) + ($88)|0);
     HEAP32[$5>>2] = $90;
     $$pre$phiZ2D = $8;
    } else {
     $91 = ($$1112|0)==($$2115|0);
     L30: do {
      if (!($91)) {
       $$0$i$i = $$2115;$$07$i$i = $$1112;
       while(1) {
        $92 = ((($$0$i$i)) + -1|0);
        $93 = ($$07$i$i>>>0)<($92>>>0);
        if (!($93)) {
         break L30;
        }
        $94 = HEAP8[$$07$i$i>>0]|0;
        $95 = HEAP8[$92>>0]|0;
        HEAP8[$$07$i$i>>0] = $95;
        HEAP8[$92>>0] = $94;
        $96 = ((($$07$i$i)) + 1|0);
        $$0$i$i = $92;$$07$i$i = $96;
       }
      }
     } while(0);
     $97 = HEAP32[$9>>2]|0;
     $98 = ((($97)) + 16|0);
     $99 = HEAP32[$98>>2]|0;
     __THREW__ = 0;
     $100 = (invoke_ii($99|0,($9|0))|0);
     $101 = __THREW__; __THREW__ = 0;
     $102 = $101&1;
     if ($102) {
      break L4;
     }
     $$0 = $$1112;$$0108 = 0;$$0109 = 0;
     while(1) {
      $103 = ($$0>>>0)<($$2115>>>0);
      if (!($103)) {
       break;
      }
      $113 = HEAP8[$71>>0]|0;
      $114 = ($113<<24>>24)<(0);
      $115 = HEAP32[$7>>2]|0;
      $116 = $114 ? $115 : $7;
      $117 = (($116) + ($$0108)|0);
      $118 = HEAP8[$117>>0]|0;
      $119 = ($118<<24>>24)>(0);
      $120 = $118 << 24 >> 24;
      $121 = ($$0109|0)==($120|0);
      $or$cond = $119 & $121;
      if ($or$cond) {
       $122 = HEAP32[$5>>2]|0;
       $123 = ((($122)) + 1|0);
       HEAP32[$5>>2] = $123;
       HEAP8[$122>>0] = $100;
       $124 = HEAP8[$71>>0]|0;
       $125 = ($124<<24>>24)<(0);
       $126 = HEAP32[$74>>2]|0;
       $127 = $124&255;
       $128 = $125 ? $126 : $127;
       $129 = (($128) + -1)|0;
       $130 = ($$0108>>>0)<($129>>>0);
       $131 = $130&1;
       $$$0108 = (($131) + ($$0108))|0;
       $$1 = $$$0108;$$1110 = 0;
      } else {
       $$1 = $$0108;$$1110 = $$0109;
      }
      $132 = HEAP8[$$0>>0]|0;
      $133 = HEAP32[$8>>2]|0;
      $134 = ((($133)) + 28|0);
      $135 = HEAP32[$134>>2]|0;
      __THREW__ = 0;
      $136 = (invoke_iii($135|0,($8|0),($132|0))|0);
      $137 = __THREW__; __THREW__ = 0;
      $138 = $137&1;
      if ($138) {
       break L4;
      }
      $139 = HEAP32[$5>>2]|0;
      $140 = ((($139)) + 1|0);
      HEAP32[$5>>2] = $140;
      HEAP8[$139>>0] = $136;
      $141 = (($$1110) + 1)|0;
      $142 = ((($$0)) + 1|0);
      $$0 = $142;$$0108 = $$1;$$0109 = $141;
     }
     $104 = (($79) - ($80))|0;
     $105 = (($3) + ($104)|0);
     $106 = HEAP32[$5>>2]|0;
     $107 = ($105|0)==($106|0);
     if ($107) {
      $$pre$phiZ2D = $8;
     } else {
      $$0$i$i128 = $106;$$07$i$i127 = $105;
      while(1) {
       $108 = ((($$0$i$i128)) + -1|0);
       $109 = ($$07$i$i127>>>0)<($108>>>0);
       if (!($109)) {
        $$pre$phiZ2D = $8;
        break L26;
       }
       $110 = HEAP8[$$07$i$i127>>0]|0;
       $111 = HEAP8[$108>>0]|0;
       HEAP8[$$07$i$i127>>0] = $111;
       HEAP8[$108>>0] = $110;
       $112 = ((($$07$i$i127)) + 1|0);
       $$0$i$i128 = $108;$$07$i$i127 = $112;
      }
     }
    }
   } while(0);
   $$2 = $$2115;
   while(1) {
    $143 = ($$2>>>0)<($2>>>0);
    if (!($143)) {
     $$3 = $$2;
     break;
    }
    $144 = HEAP8[$$2>>0]|0;
    $145 = ($144<<24>>24)==(46);
    $146 = ((($$2)) + 1|0);
    if ($145) {
     label = 39;
     break;
    }
    $155 = HEAP32[$$pre$phiZ2D>>2]|0;
    $156 = ((($155)) + 28|0);
    $157 = HEAP32[$156>>2]|0;
    __THREW__ = 0;
    $158 = (invoke_iii($157|0,($8|0),($144|0))|0);
    $159 = __THREW__; __THREW__ = 0;
    $160 = $159&1;
    if ($160) {
     break L4;
    }
    $161 = HEAP32[$5>>2]|0;
    $162 = ((($161)) + 1|0);
    HEAP32[$5>>2] = $162;
    HEAP8[$161>>0] = $158;
    $$2 = $146;
   }
   if ((label|0) == 39) {
    $147 = HEAP32[$9>>2]|0;
    $148 = ((($147)) + 12|0);
    $149 = HEAP32[$148>>2]|0;
    __THREW__ = 0;
    $150 = (invoke_ii($149|0,($9|0))|0);
    $151 = __THREW__; __THREW__ = 0;
    $152 = $151&1;
    if ($152) {
     break;
    }
    $153 = HEAP32[$5>>2]|0;
    $154 = ((($153)) + 1|0);
    HEAP32[$5>>2] = $154;
    HEAP8[$153>>0] = $150;
    $$3 = $146;
   }
   $163 = HEAP32[$5>>2]|0;
   $164 = HEAP32[$8>>2]|0;
   $165 = ((($164)) + 32|0);
   $166 = HEAP32[$165>>2]|0;
   __THREW__ = 0;
   (invoke_iiiii($166|0,($8|0),($$3|0),($2|0),($163|0))|0);
   $167 = __THREW__; __THREW__ = 0;
   $168 = $167&1;
   if (!($168)) {
    $169 = $$3;
    $170 = (($23) - ($169))|0;
    $171 = HEAP32[$5>>2]|0;
    $172 = (($171) + ($170)|0);
    HEAP32[$5>>2] = $172;
    $173 = ($1|0)==($2|0);
    $174 = $1;
    $175 = (($174) - ($80))|0;
    $176 = (($3) + ($175)|0);
    $storemerge = $173 ? $172 : $176;
    HEAP32[$4>>2] = $storemerge;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($7);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $177 = ___cxa_find_matching_catch_2()|0;
 $178 = tempRet0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($7);
 ___resumeException($177|0);
 // unreachable;
}
function __ZNSt3__214__num_put_base12__format_intEPcPKcbj($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $$014 = 0, $$1 = 0, $$sink = 0, $$sink$sink = 0, $$sink1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $trunc = 0;
 var $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = $3 & 2048;
 $5 = ($4|0)==(0);
 if ($5) {
  $$0 = $0;
 } else {
  $6 = ((($0)) + 1|0);
  HEAP8[$0>>0] = 43;
  $$0 = $6;
 }
 $7 = $3 & 512;
 $8 = ($7|0)==(0);
 if ($8) {
  $$014 = $1;$$1 = $$0;
 } else {
  $9 = ((($$0)) + 1|0);
  HEAP8[$$0>>0] = 35;
  $$014 = $1;$$1 = $9;
 }
 while(1) {
  $10 = HEAP8[$$014>>0]|0;
  $11 = ($10<<24>>24)==(0);
  if ($11) {
   break;
  }
  $12 = ((($$014)) + 1|0);
  $13 = ((($$1)) + 1|0);
  HEAP8[$$1>>0] = $10;
  $$014 = $12;$$1 = $13;
 }
 $14 = $3 & 74;
 $trunc = $14&255;
 $trunc$clear = $trunc & 127;
 switch ($trunc$clear<<24>>24) {
 case 64:  {
  $$sink$sink = 111;
  break;
 }
 case 8:  {
  $15 = $3 & 16384;
  $16 = ($15|0)!=(0);
  $$sink = $16 ? 88 : 120;
  $$sink$sink = $$sink;
  break;
 }
 default: {
  $$sink1 = $2 ? 100 : 117;
  $$sink$sink = $$sink1;
 }
 }
 HEAP8[$$1>>0] = $$sink$sink;
 return;
}
function __ZNSt3__29__num_putIcE21__widen_and_group_intEPcS2_S2_S2_RS2_S3_RKNS_6localeE($0,$1,$2,$3,$4,$5,$6) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 var $$$078 = 0, $$0 = 0, $$0$i$i = 0, $$0$i$i94 = 0, $$07$i$i = 0, $$07$i$i93 = 0, $$078 = 0, $$079 = 0, $$083 = 0, $$1 = 0, $$180 = 0, $$184 = 0, $$pre = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $storemerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $7 = sp;
 $8 = (__ZNKSt3__26locale9use_facetERNS0_2idE($6,215188)|0);
 $9 = (__ZNKSt3__26locale9use_facetERNS0_2idE($6,215204)|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ((($10)) + 20|0);
 $12 = HEAP32[$11>>2]|0;
 FUNCTION_TABLE_vii[$12 & 8191]($7,$9);
 $13 = ((($7)) + 11|0);
 $14 = HEAP8[$13>>0]|0;
 $15 = ($14<<24>>24)<(0);
 $16 = ((($7)) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = $14&255;
 $19 = $15 ? $17 : $18;
 $20 = ($19|0)==(0);
 $21 = $2;
 $22 = $0;
 L1: do {
  if ($20) {
   $23 = HEAP32[$8>>2]|0;
   $24 = ((($23)) + 32|0);
   $25 = HEAP32[$24>>2]|0;
   __THREW__ = 0;
   (invoke_iiiii($25|0,($8|0),($0|0),($2|0),($3|0))|0);
   $26 = __THREW__; __THREW__ = 0;
   $27 = $26&1;
   if ($27) {
    label = 28;
   } else {
    $28 = (($21) - ($22))|0;
    $29 = (($3) + ($28)|0);
    HEAP32[$5>>2] = $29;
    $122 = $29;
    label = 27;
   }
  } else {
   HEAP32[$5>>2] = $3;
   $30 = HEAP8[$0>>0]|0;
   switch ($30<<24>>24) {
   case 43: case 45:  {
    $31 = HEAP32[$8>>2]|0;
    $32 = ((($31)) + 28|0);
    $33 = HEAP32[$32>>2]|0;
    __THREW__ = 0;
    $34 = (invoke_iii($33|0,($8|0),($30|0))|0);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     label = 28;
     break L1;
    }
    $37 = ((($0)) + 1|0);
    $38 = HEAP32[$5>>2]|0;
    $39 = ((($38)) + 1|0);
    HEAP32[$5>>2] = $39;
    HEAP8[$38>>0] = $34;
    $$083 = $37;
    break;
   }
   default: {
    $$083 = $0;
   }
   }
   $40 = $$083;
   $41 = (($21) - ($40))|0;
   $42 = ($41|0)>(1);
   L9: do {
    if ($42) {
     $43 = HEAP8[$$083>>0]|0;
     $44 = ($43<<24>>24)==(48);
     if ($44) {
      $45 = ((($$083)) + 1|0);
      $46 = HEAP8[$45>>0]|0;
      switch ($46<<24>>24) {
      case 88: case 120:  {
       break;
      }
      default: {
       $$184 = $$083;
       break L9;
      }
      }
      $47 = HEAP32[$8>>2]|0;
      $48 = ((($47)) + 28|0);
      $49 = HEAP32[$48>>2]|0;
      __THREW__ = 0;
      $50 = (invoke_iii($49|0,($8|0),48)|0);
      $51 = __THREW__; __THREW__ = 0;
      $52 = $51&1;
      if ($52) {
       label = 28;
       break L1;
      }
      $53 = HEAP32[$5>>2]|0;
      $54 = ((($53)) + 1|0);
      HEAP32[$5>>2] = $54;
      HEAP8[$53>>0] = $50;
      $55 = HEAP8[$45>>0]|0;
      $56 = HEAP32[$8>>2]|0;
      $57 = ((($56)) + 28|0);
      $58 = HEAP32[$57>>2]|0;
      __THREW__ = 0;
      $59 = (invoke_iii($58|0,($8|0),($55|0))|0);
      $60 = __THREW__; __THREW__ = 0;
      $61 = $60&1;
      if ($61) {
       label = 28;
       break L1;
      }
      $62 = ((($$083)) + 2|0);
      $63 = HEAP32[$5>>2]|0;
      $64 = ((($63)) + 1|0);
      HEAP32[$5>>2] = $64;
      HEAP8[$63>>0] = $59;
      $$184 = $62;
     } else {
      $$184 = $$083;
     }
    } else {
     $$184 = $$083;
    }
   } while(0);
   $65 = ($$184|0)==($2|0);
   L16: do {
    if (!($65)) {
     $$0$i$i = $2;$$07$i$i = $$184;
     while(1) {
      $66 = ((($$0$i$i)) + -1|0);
      $67 = ($$07$i$i>>>0)<($66>>>0);
      if (!($67)) {
       break L16;
      }
      $68 = HEAP8[$$07$i$i>>0]|0;
      $69 = HEAP8[$66>>0]|0;
      HEAP8[$$07$i$i>>0] = $69;
      HEAP8[$66>>0] = $68;
      $70 = ((($$07$i$i)) + 1|0);
      $$0$i$i = $66;$$07$i$i = $70;
     }
    }
   } while(0);
   $71 = HEAP32[$9>>2]|0;
   $72 = ((($71)) + 16|0);
   $73 = HEAP32[$72>>2]|0;
   __THREW__ = 0;
   $74 = (invoke_ii($73|0,($9|0))|0);
   $75 = __THREW__; __THREW__ = 0;
   $76 = $75&1;
   if ($76) {
    label = 28;
   } else {
    $$0 = $$184;$$078 = 0;$$079 = 0;
    while(1) {
     $77 = ($$0>>>0)<($2>>>0);
     if (!($77)) {
      break;
     }
     $88 = HEAP8[$13>>0]|0;
     $89 = ($88<<24>>24)<(0);
     $90 = HEAP32[$7>>2]|0;
     $91 = $89 ? $90 : $7;
     $92 = (($91) + ($$078)|0);
     $93 = HEAP8[$92>>0]|0;
     $94 = ($93<<24>>24)!=(0);
     $95 = $93 << 24 >> 24;
     $96 = ($$079|0)==($95|0);
     $or$cond = $94 & $96;
     if ($or$cond) {
      $97 = HEAP32[$5>>2]|0;
      $98 = ((($97)) + 1|0);
      HEAP32[$5>>2] = $98;
      HEAP8[$97>>0] = $74;
      $99 = HEAP8[$13>>0]|0;
      $100 = ($99<<24>>24)<(0);
      $101 = HEAP32[$16>>2]|0;
      $102 = $99&255;
      $103 = $100 ? $101 : $102;
      $104 = (($103) + -1)|0;
      $105 = ($$078>>>0)<($104>>>0);
      $106 = $105&1;
      $$$078 = (($106) + ($$078))|0;
      $$1 = $$$078;$$180 = 0;
     } else {
      $$1 = $$078;$$180 = $$079;
     }
     $107 = HEAP8[$$0>>0]|0;
     $108 = HEAP32[$8>>2]|0;
     $109 = ((($108)) + 28|0);
     $110 = HEAP32[$109>>2]|0;
     __THREW__ = 0;
     $111 = (invoke_iii($110|0,($8|0),($107|0))|0);
     $112 = __THREW__; __THREW__ = 0;
     $113 = $112&1;
     if ($113) {
      label = 28;
      break L1;
     }
     $114 = HEAP32[$5>>2]|0;
     $115 = ((($114)) + 1|0);
     HEAP32[$5>>2] = $115;
     HEAP8[$114>>0] = $111;
     $116 = (($$180) + 1)|0;
     $117 = ((($$0)) + 1|0);
     $$0 = $117;$$078 = $$1;$$079 = $116;
    }
    $78 = $$184;
    $79 = (($78) - ($22))|0;
    $80 = (($3) + ($79)|0);
    $81 = HEAP32[$5>>2]|0;
    $82 = ($80|0)==($81|0);
    if ($82) {
     $122 = $80;
     label = 27;
    } else {
     $$0$i$i94 = $81;$$07$i$i93 = $80;
     while(1) {
      $83 = ((($$0$i$i94)) + -1|0);
      $84 = ($$07$i$i93>>>0)<($83>>>0);
      if (!($84)) {
       break;
      }
      $85 = HEAP8[$$07$i$i93>>0]|0;
      $86 = HEAP8[$83>>0]|0;
      HEAP8[$$07$i$i93>>0] = $86;
      HEAP8[$83>>0] = $85;
      $87 = ((($$07$i$i93)) + 1|0);
      $$0$i$i94 = $83;$$07$i$i93 = $87;
     }
     $$pre = HEAP32[$5>>2]|0;
     $122 = $$pre;
     label = 27;
    }
   }
  }
 } while(0);
 if ((label|0) == 27) {
  $118 = ($1|0)==($2|0);
  $119 = $1;
  $120 = (($119) - ($22))|0;
  $121 = (($3) + ($120)|0);
  $storemerge = $118 ? $122 : $121;
  HEAP32[$4>>2] = $storemerge;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($7);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 28) {
  $123 = ___cxa_find_matching_catch_2()|0;
  $124 = tempRet0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($7);
  ___resumeException($123|0);
  // unreachable;
 }
}
function __ZNSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEED2Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__26locale5facetD2Ev($0);
 return;
}
function __ZNSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEED0Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__26locale5facetD2Ev($0);
 __ZdlPv($0);
 return;
}
function __ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwb($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0 = 0, $$0$i$i = 0, $$011 = 0, $$byval_copy = 0, $$pre = 0, $$pre18 = 0, $$sroa$0$0 = 0, $$sroa$0$0$copyload = 0, $$sroa$013$0 = 0, $$sroa$013$0$ph = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $$byval_copy = sp + 20|0;
 $5 = sp + 16|0;
 $6 = sp + 12|0;
 $7 = sp;
 $8 = ((($2)) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $9 & 1;
 $11 = ($10|0)==(0);
 L1: do {
  if ($11) {
   $12 = HEAP32[$0>>2]|0;
   $13 = ((($12)) + 24|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = HEAP32[$1>>2]|0;
   HEAP32[$5>>2] = $15;
   $16 = $4&1;
   ;HEAP32[$$byval_copy>>2]=HEAP32[$5>>2]|0;
   $17 = (FUNCTION_TABLE_iiiiii[$14 & 8191]($0,$$byval_copy,$2,$3,$16)|0);
   $$sroa$0$0 = $17;
  } else {
   __ZNKSt3__28ios_base6getlocEv($6,$2);
   __THREW__ = 0;
   $18 = (invoke_iii(3255,($6|0),(215228|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   do {
    if ($20) {
     $41 = ___cxa_find_matching_catch_2()|0;
     $42 = tempRet0;
     __ZNSt3__26localeD2Ev($6);
     $$0 = $42;$$011 = $41;
    } else {
     __ZNSt3__26localeD2Ev($6);
     $21 = HEAP32[$18>>2]|0;
     if ($4) {
      $22 = ((($21)) + 24|0);
      $23 = HEAP32[$22>>2]|0;
      FUNCTION_TABLE_vii[$23 & 8191]($7,$18);
     } else {
      $24 = ((($21)) + 28|0);
      $25 = HEAP32[$24>>2]|0;
      FUNCTION_TABLE_vii[$25 & 8191]($7,$18);
     }
     $26 = ((($7)) + 8|0);
     $27 = ((($26)) + 3|0);
     $28 = HEAP8[$27>>0]|0;
     $29 = ($28<<24>>24)<(0);
     $30 = HEAP32[$7>>2]|0;
     $$sroa$013$0$ph = $29 ? $30 : $7;
     $31 = ((($7)) + 4|0);
     $$sroa$013$0 = $$sroa$013$0$ph;$32 = $28;$36 = $30;
     while(1) {
      $33 = ($32<<24>>24)<(0);
      $34 = HEAP32[$31>>2]|0;
      $35 = $32&255;
      $37 = $33 ? $36 : $7;
      $38 = $33 ? $34 : $35;
      $39 = (($37) + ($38<<2)|0);
      $40 = ($$sroa$013$0|0)==($39|0);
      if ($40) {
       label = 9;
       break;
      }
      $43 = HEAP32[$$sroa$013$0>>2]|0;
      $44 = HEAP32[$1>>2]|0;
      $45 = ($44|0)==(0|0);
      if (!($45)) {
       $46 = ((($44)) + 24|0);
       $47 = HEAP32[$46>>2]|0;
       $48 = ((($44)) + 28|0);
       $49 = HEAP32[$48>>2]|0;
       $50 = ($47|0)==($49|0);
       if ($50) {
        $51 = HEAP32[$44>>2]|0;
        $52 = ((($51)) + 52|0);
        $53 = HEAP32[$52>>2]|0;
        $54 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($43)|0);
        __THREW__ = 0;
        $55 = (invoke_iii($53|0,($44|0),($54|0))|0);
        $56 = __THREW__; __THREW__ = 0;
        $57 = $56&1;
        if ($57) {
         label = 18;
         break;
        } else {
         $$0$i$i = $55;
        }
       } else {
        $58 = ((($47)) + 4|0);
        HEAP32[$46>>2] = $58;
        HEAP32[$47>>2] = $43;
        $59 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($43)|0);
        $$0$i$i = $59;
       }
       $60 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
       $61 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i,$60)|0);
       if ($61) {
        HEAP32[$1>>2] = 0;
       }
      }
      $62 = ((($$sroa$013$0)) + 4|0);
      $$pre = HEAP8[$27>>0]|0;
      $$pre18 = HEAP32[$7>>2]|0;
      $$sroa$013$0 = $62;$32 = $$pre;$36 = $$pre18;
     }
     if ((label|0) == 9) {
      $$sroa$0$0$copyload = HEAP32[$1>>2]|0;
      __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev($7);
      $$sroa$0$0 = $$sroa$0$0$copyload;
      break L1;
     }
     else if ((label|0) == 18) {
      $63 = ___cxa_find_matching_catch_2()|0;
      $64 = tempRet0;
      __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev($7);
      $$0 = $64;$$011 = $63;
      break;
     }
    }
   } while(0);
   ___resumeException($$011|0);
   // unreachable;
  }
 } while(0);
 STACKTOP = sp;return ($$sroa$0$0|0);
}
function __ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwl($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$byval_copy = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(144|0);
 $$byval_copy = sp + 112|0;
 $vararg_buffer = sp;
 $5 = sp + 130|0;
 $6 = sp + 116|0;
 $7 = sp + 20|0;
 $8 = sp + 16|0;
 $9 = sp + 12|0;
 $10 = sp + 8|0;
 $11 = sp + 4|0;
 ;HEAP8[$5>>0]=HEAP8[202868>>0]|0;HEAP8[$5+1>>0]=HEAP8[202868+1>>0]|0;HEAP8[$5+2>>0]=HEAP8[202868+2>>0]|0;HEAP8[$5+3>>0]=HEAP8[202868+3>>0]|0;HEAP8[$5+4>>0]=HEAP8[202868+4>>0]|0;HEAP8[$5+5>>0]=HEAP8[202868+5>>0]|0;
 $12 = ((($5)) + 1|0);
 $13 = ((($2)) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 __ZNSt3__214__num_put_base12__format_intEPcPKcbj($12,202874,1,$14);
 $15 = (__ZNSt3__26__clocEv()|0);
 HEAP32[$vararg_buffer>>2] = $4;
 $16 = (__ZNSt3__219__libcpp_snprintf_lEPcjP15__locale_structPKcz($6,13,$15,$5,$vararg_buffer)|0);
 $17 = (($6) + ($16)|0);
 $18 = (__ZNSt3__214__num_put_base18__identify_paddingEPcS1_RKNS_8ios_baseE($6,$17,$2)|0);
 __ZNKSt3__28ios_base6getlocEv($10,$2);
 __THREW__ = 0;
 invoke_viiiiiii(4695,($6|0),($18|0),($17|0),($7|0),($8|0),($9|0),($10|0));
 $19 = __THREW__; __THREW__ = 0;
 $20 = $19&1;
 if ($20) {
  $25 = ___cxa_find_matching_catch_2()|0;
  $26 = tempRet0;
  __ZNSt3__26localeD2Ev($10);
  ___resumeException($25|0);
  // unreachable;
 } else {
  __ZNSt3__26localeD2Ev($10);
  $21 = HEAP32[$1>>2]|0;
  HEAP32[$11>>2] = $21;
  $22 = HEAP32[$8>>2]|0;
  $23 = HEAP32[$9>>2]|0;
  ;HEAP32[$$byval_copy>>2]=HEAP32[$11>>2]|0;
  $24 = (__ZNSt3__216__pad_and_outputIwNS_11char_traitsIwEEEENS_19ostreambuf_iteratorIT_T0_EES6_PKS4_S8_S8_RNS_8ios_baseES4_($$byval_copy,$7,$22,$23,$2,$3)|0);
  STACKTOP = sp;return ($24|0);
 }
 return (0)|0;
}
function __ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwx($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$byval_copy = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 240|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(240|0);
 $$byval_copy = sp + 204|0;
 $vararg_buffer = sp + 8|0;
 $6 = sp;
 $7 = sp + 208|0;
 $8 = sp + 32|0;
 $9 = sp + 28|0;
 $10 = sp + 24|0;
 $11 = sp + 20|0;
 $12 = sp + 16|0;
 $13 = $6;
 $14 = $13;
 HEAP32[$14>>2] = 37;
 $15 = (($13) + 4)|0;
 $16 = $15;
 HEAP32[$16>>2] = 0;
 $17 = ((($6)) + 1|0);
 $18 = ((($2)) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 __ZNSt3__214__num_put_base12__format_intEPcPKcbj($17,202865,1,$19);
 $20 = (__ZNSt3__26__clocEv()|0);
 $21 = $vararg_buffer;
 $22 = $21;
 HEAP32[$22>>2] = $4;
 $23 = (($21) + 4)|0;
 $24 = $23;
 HEAP32[$24>>2] = $5;
 $25 = (__ZNSt3__219__libcpp_snprintf_lEPcjP15__locale_structPKcz($7,23,$20,$6,$vararg_buffer)|0);
 $26 = (($7) + ($25)|0);
 $27 = (__ZNSt3__214__num_put_base18__identify_paddingEPcS1_RKNS_8ios_baseE($7,$26,$2)|0);
 __ZNKSt3__28ios_base6getlocEv($11,$2);
 __THREW__ = 0;
 invoke_viiiiiii(4695,($7|0),($27|0),($26|0),($8|0),($9|0),($10|0),($11|0));
 $28 = __THREW__; __THREW__ = 0;
 $29 = $28&1;
 if ($29) {
  $34 = ___cxa_find_matching_catch_2()|0;
  $35 = tempRet0;
  __ZNSt3__26localeD2Ev($11);
  ___resumeException($34|0);
  // unreachable;
 } else {
  __ZNSt3__26localeD2Ev($11);
  $30 = HEAP32[$1>>2]|0;
  HEAP32[$12>>2] = $30;
  $31 = HEAP32[$9>>2]|0;
  $32 = HEAP32[$10>>2]|0;
  ;HEAP32[$$byval_copy>>2]=HEAP32[$12>>2]|0;
  $33 = (__ZNSt3__216__pad_and_outputIwNS_11char_traitsIwEEEENS_19ostreambuf_iteratorIT_T0_EES6_PKS4_S8_S8_RNS_8ios_baseES4_($$byval_copy,$8,$31,$32,$2,$3)|0);
  STACKTOP = sp;return ($33|0);
 }
 return (0)|0;
}
function __ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwm($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$byval_copy = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(128|0);
 $$byval_copy = sp + 104|0;
 $vararg_buffer = sp;
 $5 = sp + 120|0;
 $6 = sp + 108|0;
 $7 = sp + 20|0;
 $8 = sp + 16|0;
 $9 = sp + 12|0;
 $10 = sp + 8|0;
 $11 = sp + 4|0;
 ;HEAP8[$5>>0]=HEAP8[202868>>0]|0;HEAP8[$5+1>>0]=HEAP8[202868+1>>0]|0;HEAP8[$5+2>>0]=HEAP8[202868+2>>0]|0;HEAP8[$5+3>>0]=HEAP8[202868+3>>0]|0;HEAP8[$5+4>>0]=HEAP8[202868+4>>0]|0;HEAP8[$5+5>>0]=HEAP8[202868+5>>0]|0;
 $12 = ((($5)) + 1|0);
 $13 = ((($2)) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 __ZNSt3__214__num_put_base12__format_intEPcPKcbj($12,202874,0,$14);
 $15 = (__ZNSt3__26__clocEv()|0);
 HEAP32[$vararg_buffer>>2] = $4;
 $16 = (__ZNSt3__219__libcpp_snprintf_lEPcjP15__locale_structPKcz($6,12,$15,$5,$vararg_buffer)|0);
 $17 = (($6) + ($16)|0);
 $18 = (__ZNSt3__214__num_put_base18__identify_paddingEPcS1_RKNS_8ios_baseE($6,$17,$2)|0);
 __ZNKSt3__28ios_base6getlocEv($10,$2);
 __THREW__ = 0;
 invoke_viiiiiii(4695,($6|0),($18|0),($17|0),($7|0),($8|0),($9|0),($10|0));
 $19 = __THREW__; __THREW__ = 0;
 $20 = $19&1;
 if ($20) {
  $25 = ___cxa_find_matching_catch_2()|0;
  $26 = tempRet0;
  __ZNSt3__26localeD2Ev($10);
  ___resumeException($25|0);
  // unreachable;
 } else {
  __ZNSt3__26localeD2Ev($10);
  $21 = HEAP32[$1>>2]|0;
  HEAP32[$11>>2] = $21;
  $22 = HEAP32[$8>>2]|0;
  $23 = HEAP32[$9>>2]|0;
  ;HEAP32[$$byval_copy>>2]=HEAP32[$11>>2]|0;
  $24 = (__ZNSt3__216__pad_and_outputIwNS_11char_traitsIwEEEENS_19ostreambuf_iteratorIT_T0_EES6_PKS4_S8_S8_RNS_8ios_baseES4_($$byval_copy,$7,$22,$23,$2,$3)|0);
  STACKTOP = sp;return ($24|0);
 }
 return (0)|0;
}
function __ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwy($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$byval_copy = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 240|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(240|0);
 $$byval_copy = sp + 204|0;
 $vararg_buffer = sp + 8|0;
 $6 = sp;
 $7 = sp + 208|0;
 $8 = sp + 32|0;
 $9 = sp + 28|0;
 $10 = sp + 24|0;
 $11 = sp + 20|0;
 $12 = sp + 16|0;
 $13 = $6;
 $14 = $13;
 HEAP32[$14>>2] = 37;
 $15 = (($13) + 4)|0;
 $16 = $15;
 HEAP32[$16>>2] = 0;
 $17 = ((($6)) + 1|0);
 $18 = ((($2)) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 __ZNSt3__214__num_put_base12__format_intEPcPKcbj($17,202865,0,$19);
 $20 = (__ZNSt3__26__clocEv()|0);
 $21 = $vararg_buffer;
 $22 = $21;
 HEAP32[$22>>2] = $4;
 $23 = (($21) + 4)|0;
 $24 = $23;
 HEAP32[$24>>2] = $5;
 $25 = (__ZNSt3__219__libcpp_snprintf_lEPcjP15__locale_structPKcz($7,23,$20,$6,$vararg_buffer)|0);
 $26 = (($7) + ($25)|0);
 $27 = (__ZNSt3__214__num_put_base18__identify_paddingEPcS1_RKNS_8ios_baseE($7,$26,$2)|0);
 __ZNKSt3__28ios_base6getlocEv($11,$2);
 __THREW__ = 0;
 invoke_viiiiiii(4695,($7|0),($27|0),($26|0),($8|0),($9|0),($10|0),($11|0));
 $28 = __THREW__; __THREW__ = 0;
 $29 = $28&1;
 if ($29) {
  $34 = ___cxa_find_matching_catch_2()|0;
  $35 = tempRet0;
  __ZNSt3__26localeD2Ev($11);
  ___resumeException($34|0);
  // unreachable;
 } else {
  __ZNSt3__26localeD2Ev($11);
  $30 = HEAP32[$1>>2]|0;
  HEAP32[$12>>2] = $30;
  $31 = HEAP32[$9>>2]|0;
  $32 = HEAP32[$10>>2]|0;
  ;HEAP32[$$byval_copy>>2]=HEAP32[$12>>2]|0;
  $33 = (__ZNSt3__216__pad_and_outputIwNS_11char_traitsIwEEEENS_19ostreambuf_iteratorIT_T0_EES6_PKS4_S8_S8_RNS_8ios_baseES4_($$byval_copy,$8,$31,$32,$2,$3)|0);
  STACKTOP = sp;return ($33|0);
 }
 return (0)|0;
}
function __ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwd($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = +$4;
 var $$0 = 0, $$046 = 0, $$047 = 0, $$050 = 0, $$1 = 0, $$148 = 0, $$151 = 0, $$2 = 0, $$24980 = 0, $$25279 = 0, $$45482 = 0, $$483 = 0, $$byval_copy = 0, $$pre = 0, $$sroa$058$0 = 0, $$sroa$069$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer2 = 0, $vararg_buffer5 = 0, $vararg_buffer9 = 0, $vararg_ptr1 = 0, $vararg_ptr8 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 352|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(352|0);
 $$byval_copy = sp + 304|0;
 $vararg_buffer9 = sp + 48|0;
 $vararg_buffer5 = sp + 32|0;
 $vararg_buffer2 = sp + 24|0;
 $vararg_buffer = sp + 8|0;
 $5 = sp;
 $6 = sp + 308|0;
 $7 = sp + 300|0;
 $8 = sp + 72|0;
 $9 = sp + 68|0;
 $10 = sp + 64|0;
 $11 = sp + 60|0;
 $12 = sp + 56|0;
 $13 = $5;
 $14 = $13;
 HEAP32[$14>>2] = 37;
 $15 = (($13) + 4)|0;
 $16 = $15;
 HEAP32[$16>>2] = 0;
 $17 = ((($5)) + 1|0);
 $18 = ((($2)) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (__ZNSt3__214__num_put_base14__format_floatEPcPKcj($17,221531,$19)|0);
 HEAP32[$7>>2] = $6;
 $21 = (__ZNSt3__26__clocEv()|0);
 if ($20) {
  $22 = ((($2)) + 8|0);
  $23 = HEAP32[$22>>2]|0;
  HEAP32[$vararg_buffer>>2] = $23;
  $vararg_ptr1 = ((($vararg_buffer)) + 8|0);
  HEAPF64[$vararg_ptr1>>3] = $4;
  $24 = (__ZNSt3__219__libcpp_snprintf_lEPcjP15__locale_structPKcz($6,30,$21,$5,$vararg_buffer)|0);
  $$0 = $24;
 } else {
  HEAPF64[$vararg_buffer2>>3] = $4;
  $25 = (__ZNSt3__219__libcpp_snprintf_lEPcjP15__locale_structPKcz($6,30,$21,$5,$vararg_buffer2)|0);
  $$0 = $25;
 }
 $26 = ($$0|0)>(29);
 L5: do {
  if ($26) {
   if ($20) {
    __THREW__ = 0;
    $27 = (invoke_i(4668)|0);
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if (!($29)) {
     $30 = ((($2)) + 8|0);
     $31 = HEAP32[$30>>2]|0;
     __THREW__ = 0;
     HEAP32[$vararg_buffer5>>2] = $31;
     $vararg_ptr8 = ((($vararg_buffer5)) + 8|0);
     HEAPF64[$vararg_ptr8>>3] = $4;
     $32 = (invoke_iiiii(4690,($7|0),($27|0),($5|0),($vararg_buffer5|0))|0);
     $33 = __THREW__; __THREW__ = 0;
     $34 = $33&1;
     if (!($34)) {
      $$1 = $32;
      label = 12;
     }
    }
   } else {
    __THREW__ = 0;
    $37 = (invoke_i(4668)|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if (!($39)) {
     __THREW__ = 0;
     HEAPF64[$vararg_buffer9>>3] = $4;
     $40 = (invoke_iiiii(4690,($7|0),($37|0),($5|0),($vararg_buffer9|0))|0);
     $41 = __THREW__; __THREW__ = 0;
     $42 = $41&1;
     if (!($42)) {
      $$1 = $40;
      label = 12;
     }
    }
   }
   do {
    if ((label|0) == 12) {
     $43 = HEAP32[$7>>2]|0;
     $44 = ($43|0)==(0|0);
     if ($44) {
      __THREW__ = 0;
      invoke_v(4685);
      $45 = __THREW__; __THREW__ = 0;
      break;
     } else {
      $46 = $43;
      $$2 = $$1;$$sroa$069$0 = $46;$48 = $43;
      label = 15;
      break L5;
     }
    }
   } while(0);
   $35 = ___cxa_find_matching_catch_2()|0;
   $36 = tempRet0;
   $$45482 = $36;$$483 = $35;
  } else {
   $$pre = HEAP32[$7>>2]|0;
   $$2 = $$0;$$sroa$069$0 = 0;$48 = $$pre;
   label = 15;
  }
 } while(0);
 if ((label|0) == 15) {
  $47 = (($48) + ($$2)|0);
  $49 = (__ZNSt3__214__num_put_base18__identify_paddingEPcS1_RKNS_8ios_baseE($48,$47,$2)|0);
  $50 = ($48|0)==($6|0);
  do {
   if ($50) {
    $$046 = $8;$$sroa$058$0 = 0;
    label = 19;
   } else {
    $51 = $$2 << 3;
    $52 = (_malloc($51)|0);
    $53 = ($52|0)==(0|0);
    if ($53) {
     __THREW__ = 0;
     invoke_v(4685);
     $54 = __THREW__; __THREW__ = 0;
     $55 = ___cxa_find_matching_catch_2()|0;
     $56 = tempRet0;
     $$24980 = $55;$$25279 = $56;
     break;
    } else {
     $57 = $52;
     $$046 = $52;$$sroa$058$0 = $57;
     label = 19;
     break;
    }
   }
  } while(0);
  if ((label|0) == 19) {
   __THREW__ = 0;
   invoke_vii(3257,($11|0),($2|0));
   $58 = __THREW__; __THREW__ = 0;
   $59 = $58&1;
   do {
    if ($59) {
     $72 = ___cxa_find_matching_catch_2()|0;
     $73 = tempRet0;
     $$047 = $72;$$050 = $73;
     label = 29;
    } else {
     __THREW__ = 0;
     invoke_viiiiiii(4696,($48|0),($49|0),($47|0),($$046|0),($9|0),($10|0),($11|0));
     $60 = __THREW__; __THREW__ = 0;
     $61 = $60&1;
     if ($61) {
      $74 = ___cxa_find_matching_catch_2()|0;
      $75 = tempRet0;
      __ZNSt3__26localeD2Ev($11);
      $$047 = $74;$$050 = $75;
      label = 29;
      break;
     }
     __ZNSt3__26localeD2Ev($11);
     $62 = HEAP32[$1>>2]|0;
     HEAP32[$12>>2] = $62;
     $63 = HEAP32[$9>>2]|0;
     $64 = HEAP32[$10>>2]|0;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy>>2]=HEAP32[$12>>2]|0;
     $65 = (invoke_iiiiiii(4697,($$byval_copy|0),($$046|0),($63|0),($64|0),($2|0),($3|0))|0);
     $66 = __THREW__; __THREW__ = 0;
     $67 = $66&1;
     if ($67) {
      $76 = ___cxa_find_matching_catch_2()|0;
      $77 = tempRet0;
      $$148 = $76;$$151 = $77;
      break;
     }
     HEAP32[$1>>2] = $65;
     $68 = ($$sroa$058$0|0)==(0);
     if (!($68)) {
      $69 = $$sroa$058$0;
      _free($69);
     }
     $70 = ($$sroa$069$0|0)==(0);
     if (!($70)) {
      $71 = $$sroa$069$0;
      _free($71);
     }
     STACKTOP = sp;return ($65|0);
    }
   } while(0);
   if ((label|0) == 29) {
    $$148 = $$047;$$151 = $$050;
   }
   $78 = ($$sroa$058$0|0)==(0);
   if ($78) {
    $$24980 = $$148;$$25279 = $$151;
   } else {
    $79 = $$sroa$058$0;
    _free($79);
    $$24980 = $$148;$$25279 = $$151;
   }
  }
  $80 = ($$sroa$069$0|0)==(0);
  if ($80) {
   $$45482 = $$25279;$$483 = $$24980;
  } else {
   $81 = $$sroa$069$0;
   _free($81);
   $$45482 = $$25279;$$483 = $$24980;
  }
 }
 ___resumeException($$483|0);
 // unreachable;
 return (0)|0;
}
function __ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwe($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = +$4;
 var $$0 = 0, $$046 = 0, $$047 = 0, $$050 = 0, $$1 = 0, $$148 = 0, $$151 = 0, $$2 = 0, $$24980 = 0, $$25279 = 0, $$45482 = 0, $$483 = 0, $$byval_copy = 0, $$pre = 0, $$sroa$058$0 = 0, $$sroa$069$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer2 = 0, $vararg_buffer5 = 0, $vararg_buffer9 = 0, $vararg_ptr1 = 0, $vararg_ptr8 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 352|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(352|0);
 $$byval_copy = sp + 304|0;
 $vararg_buffer9 = sp + 48|0;
 $vararg_buffer5 = sp + 32|0;
 $vararg_buffer2 = sp + 24|0;
 $vararg_buffer = sp + 8|0;
 $5 = sp;
 $6 = sp + 308|0;
 $7 = sp + 300|0;
 $8 = sp + 72|0;
 $9 = sp + 68|0;
 $10 = sp + 64|0;
 $11 = sp + 60|0;
 $12 = sp + 56|0;
 $13 = $5;
 $14 = $13;
 HEAP32[$14>>2] = 37;
 $15 = (($13) + 4)|0;
 $16 = $15;
 HEAP32[$16>>2] = 0;
 $17 = ((($5)) + 1|0);
 $18 = ((($2)) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (__ZNSt3__214__num_put_base14__format_floatEPcPKcj($17,202863,$19)|0);
 HEAP32[$7>>2] = $6;
 $21 = (__ZNSt3__26__clocEv()|0);
 if ($20) {
  $22 = ((($2)) + 8|0);
  $23 = HEAP32[$22>>2]|0;
  HEAP32[$vararg_buffer>>2] = $23;
  $vararg_ptr1 = ((($vararg_buffer)) + 8|0);
  HEAPF64[$vararg_ptr1>>3] = $4;
  $24 = (__ZNSt3__219__libcpp_snprintf_lEPcjP15__locale_structPKcz($6,30,$21,$5,$vararg_buffer)|0);
  $$0 = $24;
 } else {
  HEAPF64[$vararg_buffer2>>3] = $4;
  $25 = (__ZNSt3__219__libcpp_snprintf_lEPcjP15__locale_structPKcz($6,30,$21,$5,$vararg_buffer2)|0);
  $$0 = $25;
 }
 $26 = ($$0|0)>(29);
 L5: do {
  if ($26) {
   if ($20) {
    __THREW__ = 0;
    $27 = (invoke_i(4668)|0);
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if (!($29)) {
     $30 = ((($2)) + 8|0);
     $31 = HEAP32[$30>>2]|0;
     __THREW__ = 0;
     HEAP32[$vararg_buffer5>>2] = $31;
     $vararg_ptr8 = ((($vararg_buffer5)) + 8|0);
     HEAPF64[$vararg_ptr8>>3] = $4;
     $32 = (invoke_iiiii(4690,($7|0),($27|0),($5|0),($vararg_buffer5|0))|0);
     $33 = __THREW__; __THREW__ = 0;
     $34 = $33&1;
     if (!($34)) {
      $$1 = $32;
      label = 12;
     }
    }
   } else {
    __THREW__ = 0;
    $37 = (invoke_i(4668)|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if (!($39)) {
     __THREW__ = 0;
     HEAPF64[$vararg_buffer9>>3] = $4;
     $40 = (invoke_iiiii(4690,($7|0),($37|0),($5|0),($vararg_buffer9|0))|0);
     $41 = __THREW__; __THREW__ = 0;
     $42 = $41&1;
     if (!($42)) {
      $$1 = $40;
      label = 12;
     }
    }
   }
   do {
    if ((label|0) == 12) {
     $43 = HEAP32[$7>>2]|0;
     $44 = ($43|0)==(0|0);
     if ($44) {
      __THREW__ = 0;
      invoke_v(4685);
      $45 = __THREW__; __THREW__ = 0;
      break;
     } else {
      $46 = $43;
      $$2 = $$1;$$sroa$069$0 = $46;$48 = $43;
      label = 15;
      break L5;
     }
    }
   } while(0);
   $35 = ___cxa_find_matching_catch_2()|0;
   $36 = tempRet0;
   $$45482 = $36;$$483 = $35;
  } else {
   $$pre = HEAP32[$7>>2]|0;
   $$2 = $$0;$$sroa$069$0 = 0;$48 = $$pre;
   label = 15;
  }
 } while(0);
 if ((label|0) == 15) {
  $47 = (($48) + ($$2)|0);
  $49 = (__ZNSt3__214__num_put_base18__identify_paddingEPcS1_RKNS_8ios_baseE($48,$47,$2)|0);
  $50 = ($48|0)==($6|0);
  do {
   if ($50) {
    $$046 = $8;$$sroa$058$0 = 0;
    label = 19;
   } else {
    $51 = $$2 << 3;
    $52 = (_malloc($51)|0);
    $53 = ($52|0)==(0|0);
    if ($53) {
     __THREW__ = 0;
     invoke_v(4685);
     $54 = __THREW__; __THREW__ = 0;
     $55 = ___cxa_find_matching_catch_2()|0;
     $56 = tempRet0;
     $$24980 = $55;$$25279 = $56;
     break;
    } else {
     $57 = $52;
     $$046 = $52;$$sroa$058$0 = $57;
     label = 19;
     break;
    }
   }
  } while(0);
  if ((label|0) == 19) {
   __THREW__ = 0;
   invoke_vii(3257,($11|0),($2|0));
   $58 = __THREW__; __THREW__ = 0;
   $59 = $58&1;
   do {
    if ($59) {
     $72 = ___cxa_find_matching_catch_2()|0;
     $73 = tempRet0;
     $$047 = $72;$$050 = $73;
     label = 29;
    } else {
     __THREW__ = 0;
     invoke_viiiiiii(4696,($48|0),($49|0),($47|0),($$046|0),($9|0),($10|0),($11|0));
     $60 = __THREW__; __THREW__ = 0;
     $61 = $60&1;
     if ($61) {
      $74 = ___cxa_find_matching_catch_2()|0;
      $75 = tempRet0;
      __ZNSt3__26localeD2Ev($11);
      $$047 = $74;$$050 = $75;
      label = 29;
      break;
     }
     __ZNSt3__26localeD2Ev($11);
     $62 = HEAP32[$1>>2]|0;
     HEAP32[$12>>2] = $62;
     $63 = HEAP32[$9>>2]|0;
     $64 = HEAP32[$10>>2]|0;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy>>2]=HEAP32[$12>>2]|0;
     $65 = (invoke_iiiiiii(4697,($$byval_copy|0),($$046|0),($63|0),($64|0),($2|0),($3|0))|0);
     $66 = __THREW__; __THREW__ = 0;
     $67 = $66&1;
     if ($67) {
      $76 = ___cxa_find_matching_catch_2()|0;
      $77 = tempRet0;
      $$148 = $76;$$151 = $77;
      break;
     }
     HEAP32[$1>>2] = $65;
     $68 = ($$sroa$058$0|0)==(0);
     if (!($68)) {
      $69 = $$sroa$058$0;
      _free($69);
     }
     $70 = ($$sroa$069$0|0)==(0);
     if (!($70)) {
      $71 = $$sroa$069$0;
      _free($71);
     }
     STACKTOP = sp;return ($65|0);
    }
   } while(0);
   if ((label|0) == 29) {
    $$148 = $$047;$$151 = $$050;
   }
   $78 = ($$sroa$058$0|0)==(0);
   if ($78) {
    $$24980 = $$148;$$25279 = $$151;
   } else {
    $79 = $$sroa$058$0;
    _free($79);
    $$24980 = $$148;$$25279 = $$151;
   }
  }
  $80 = ($$sroa$069$0|0)==(0);
  if ($80) {
   $$45482 = $$25279;$$483 = $$24980;
  } else {
   $81 = $$sroa$069$0;
   _free($81);
   $$45482 = $$25279;$$483 = $$24980;
  }
 }
 ___resumeException($$483|0);
 // unreachable;
 return (0)|0;
}
function __ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwPKv($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0 = 0, $$byval_copy = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 192|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(192|0);
 $$byval_copy = sp + 160|0;
 $vararg_buffer = sp;
 $5 = sp + 184|0;
 $6 = sp + 164|0;
 $7 = sp + 12|0;
 $8 = sp + 8|0;
 $9 = sp + 4|0;
 ;HEAP8[$5>>0]=HEAP8[202857>>0]|0;HEAP8[$5+1>>0]=HEAP8[202857+1>>0]|0;HEAP8[$5+2>>0]=HEAP8[202857+2>>0]|0;HEAP8[$5+3>>0]=HEAP8[202857+3>>0]|0;HEAP8[$5+4>>0]=HEAP8[202857+4>>0]|0;HEAP8[$5+5>>0]=HEAP8[202857+5>>0]|0;
 $10 = (__ZNSt3__26__clocEv()|0);
 HEAP32[$vararg_buffer>>2] = $4;
 $11 = (__ZNSt3__219__libcpp_snprintf_lEPcjP15__locale_structPKcz($6,20,$10,$5,$vararg_buffer)|0);
 $12 = (($6) + ($11)|0);
 $13 = (__ZNSt3__214__num_put_base18__identify_paddingEPcS1_RKNS_8ios_baseE($6,$12,$2)|0);
 __ZNKSt3__28ios_base6getlocEv($8,$2);
 __THREW__ = 0;
 $14 = (invoke_iii(3255,($8|0),(215220|0))|0);
 $15 = __THREW__; __THREW__ = 0;
 $16 = $15&1;
 if ($16) {
  $28 = ___cxa_find_matching_catch_2()|0;
  $29 = tempRet0;
  __ZNSt3__26localeD2Ev($8);
  ___resumeException($28|0);
  // unreachable;
 } else {
  __ZNSt3__26localeD2Ev($8);
  $17 = HEAP32[$14>>2]|0;
  $18 = ((($17)) + 48|0);
  $19 = HEAP32[$18>>2]|0;
  (FUNCTION_TABLE_iiiii[$19 & 8191]($14,$6,$12,$7)|0);
  $20 = (($7) + ($11<<2)|0);
  $21 = ($13|0)==($12|0);
  $22 = $6;
  $23 = $13;
  $24 = (($23) - ($22))|0;
  $25 = (($7) + ($24<<2)|0);
  $$0 = $21 ? $20 : $25;
  $26 = HEAP32[$1>>2]|0;
  HEAP32[$9>>2] = $26;
  ;HEAP32[$$byval_copy>>2]=HEAP32[$9>>2]|0;
  $27 = (__ZNSt3__216__pad_and_outputIwNS_11char_traitsIwEEEENS_19ostreambuf_iteratorIT_T0_EES6_PKS4_S8_S8_RNS_8ios_baseES4_($$byval_copy,$7,$$0,$20,$2,$3)|0);
  STACKTOP = sp;return ($27|0);
 }
 return (0)|0;
}
function __ZNSt3__216__pad_and_outputIwNS_11char_traitsIwEEEENS_19ostreambuf_iteratorIT_T0_EES6_PKS4_S8_S8_RNS_8ios_baseES4_($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$0 = 0, $$0$i$i = 0, $$pre$phi46Z2D = 0, $$pre$phi48Z2D = 0, $$pre45 = 0, $$sroa$0$2 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $6 = sp + 12|0;
 $7 = sp;
 $8 = HEAP32[$0>>2]|0;
 $9 = ($8|0)==(0|0);
 L1: do {
  if ($9) {
   $$sroa$0$2 = 0;
  } else {
   $10 = $3;
   $11 = $1;
   $12 = (($10) - ($11))|0;
   $13 = $12 >> 2;
   $14 = ((($4)) + 12|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = ($15|0)>($13|0);
   $17 = (($15) - ($13))|0;
   $$0 = $16 ? $17 : 0;
   $18 = $2;
   $19 = (($18) - ($11))|0;
   $20 = $19 >> 2;
   $21 = ($19|0)>(0);
   if ($21) {
    $22 = HEAP32[$8>>2]|0;
    $23 = ((($22)) + 48|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = (FUNCTION_TABLE_iiii[$24 & 8191]($8,$1,$20)|0);
    $26 = ($25|0)==($20|0);
    if (!($26)) {
     HEAP32[$0>>2] = 0;
     $$sroa$0$2 = 0;
     break;
    }
   }
   $27 = ($$0|0)>(0);
   do {
    if ($27) {
     ;HEAP32[$7>>2]=0|0;HEAP32[$7+4>>2]=0|0;HEAP32[$7+8>>2]=0|0;
     $28 = ($$0>>>0)>(1073741807);
     if ($28) {
      __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv($7);
      // unreachable;
     }
     $29 = ($$0>>>0)<(2);
     do {
      if ($29) {
       $30 = $$0&255;
       $31 = ((($7)) + 8|0);
       $32 = ((($31)) + 3|0);
       HEAP8[$32>>0] = $30;
       $$0$i$i = $7;$$pre$phi46Z2D = $32;$$pre$phi48Z2D = $7;
      } else {
       $33 = (($$0) + 4)|0;
       $34 = $33 & 2147483644;
       $35 = ($34>>>0)>(1073741823);
       if (!($35)) {
        $41 = $34 << 2;
        $42 = (__Znwj($41)|0);
        HEAP32[$7>>2] = $42;
        $43 = $34 | -2147483648;
        $44 = ((($7)) + 8|0);
        HEAP32[$44>>2] = $43;
        $45 = ((($7)) + 4|0);
        HEAP32[$45>>2] = $$0;
        $$pre45 = ((($44)) + 3|0);
        $$0$i$i = $42;$$pre$phi46Z2D = $$pre45;$$pre$phi48Z2D = $7;
        break;
       }
       $36 = (___cxa_allocate_exception(8)|0);
       __THREW__ = 0;
       invoke_vii(3366,($36|0),(204840|0));
       $37 = __THREW__; __THREW__ = 0;
       $38 = $37&1;
       if ($38) {
        $39 = ___cxa_find_matching_catch_2()|0;
        $40 = tempRet0;
        ___cxa_free_exception(($36|0));
        ___resumeException($39|0);
        // unreachable;
       } else {
        HEAP32[$36>>2] = (99824);
        ___cxa_throw(($36|0),(34608|0),(3230|0));
        // unreachable;
       }
      }
     } while(0);
     (__ZNSt3__211char_traitsIwE6assignEPwjw($$0$i$i,$$0,$5)|0);
     $46 = (($$0$i$i) + ($$0<<2)|0);
     HEAP32[$6>>2] = 0;
     __ZNSt3__211char_traitsIwE6assignERwRKw($46,$6);
     $47 = HEAP8[$$pre$phi46Z2D>>0]|0;
     $48 = ($47<<24>>24)<(0);
     $49 = HEAP32[$7>>2]|0;
     $50 = $48 ? $49 : $$pre$phi48Z2D;
     $51 = HEAP32[$8>>2]|0;
     $52 = ((($51)) + 48|0);
     $53 = HEAP32[$52>>2]|0;
     __THREW__ = 0;
     $54 = (invoke_iiii($53|0,($8|0),($50|0),($$0|0))|0);
     $55 = __THREW__; __THREW__ = 0;
     $56 = $55&1;
     if ($56) {
      $58 = ___cxa_find_matching_catch_2()|0;
      $59 = tempRet0;
      __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev($7);
      ___resumeException($58|0);
      // unreachable;
     }
     $57 = ($54|0)==($$0|0);
     if ($57) {
      __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev($7);
      break;
     } else {
      HEAP32[$0>>2] = 0;
      __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev($7);
      $$sroa$0$2 = 0;
      break L1;
     }
    }
   } while(0);
   $60 = (($10) - ($18))|0;
   $61 = $60 >> 2;
   $62 = ($60|0)>(0);
   if ($62) {
    $63 = HEAP32[$8>>2]|0;
    $64 = ((($63)) + 48|0);
    $65 = HEAP32[$64>>2]|0;
    $66 = (FUNCTION_TABLE_iiii[$65 & 8191]($8,$2,$61)|0);
    $67 = ($66|0)==($61|0);
    if (!($67)) {
     HEAP32[$0>>2] = 0;
     $$sroa$0$2 = 0;
     break;
    }
   }
   HEAP32[$14>>2] = 0;
   $$sroa$0$2 = $8;
  }
 } while(0);
 STACKTOP = sp;return ($$sroa$0$2|0);
}
function __ZNSt3__211char_traitsIwE6assignEPwjw($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($1|0)==(0);
 if ($3) {
  $7 = $0;
 } else {
  __THREW__ = 0;
  $4 = (invoke_iiii(4698,($0|0),($2|0),($1|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if ($6) {
   $8 = ___cxa_find_matching_catch_3(0|0)|0;
   $9 = tempRet0;
   ___clang_call_terminate($8);
   // unreachable;
  } else {
   $7 = $0;
  }
 }
 return ($7|0);
}
function __ZNSt3__29__num_putIwE23__widen_and_group_floatEPcS2_S2_PwRS3_S4_RKNS_6localeE($0,$1,$2,$3,$4,$5,$6) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 var $$$0111 = 0, $$0 = 0, $$0$i$i = 0, $$0$i$i131 = 0, $$0111 = 0, $$0112 = 0, $$0114 = 0, $$0116 = 0, $$07$i$i = 0, $$07$i$i130 = 0, $$1 = 0, $$1113 = 0, $$1115 = 0, $$1117 = 0, $$2 = 0, $$2118 = 0, $$3 = 0, $$pre$phiZ2D = 0, $10 = 0, $100 = 0;
 var $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0;
 var $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0;
 var $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0;
 var $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0;
 var $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $storemerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $7 = sp;
 $8 = (__ZNKSt3__26locale9use_facetERNS0_2idE($6,215220)|0);
 $9 = (__ZNKSt3__26locale9use_facetERNS0_2idE($6,215228)|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ((($10)) + 20|0);
 $12 = HEAP32[$11>>2]|0;
 FUNCTION_TABLE_vii[$12 & 8191]($7,$9);
 HEAP32[$5>>2] = $3;
 $13 = HEAP8[$0>>0]|0;
 switch ($13<<24>>24) {
 case 43: case 45:  {
  $14 = HEAP32[$8>>2]|0;
  $15 = ((($14)) + 44|0);
  $16 = HEAP32[$15>>2]|0;
  __THREW__ = 0;
  $17 = (invoke_iii($16|0,($8|0),($13|0))|0);
  $18 = __THREW__; __THREW__ = 0;
  $19 = $18&1;
  if (!($19)) {
   $20 = ((($0)) + 1|0);
   $21 = HEAP32[$5>>2]|0;
   $22 = ((($21)) + 4|0);
   HEAP32[$5>>2] = $22;
   HEAP32[$21>>2] = $17;
   $$0114 = $20;
   label = 4;
  }
  break;
 }
 default: {
  $$0114 = $0;
  label = 4;
 }
 }
 L4: do {
  if ((label|0) == 4) {
   $23 = $2;
   $24 = $$0114;
   $25 = (($23) - ($24))|0;
   $26 = ($25|0)>(1);
   L6: do {
    if ($26) {
     $27 = HEAP8[$$0114>>0]|0;
     $28 = ($27<<24>>24)==(48);
     if ($28) {
      $29 = ((($$0114)) + 1|0);
      $30 = HEAP8[$29>>0]|0;
      switch ($30<<24>>24) {
      case 88: case 120:  {
       break;
      }
      default: {
       $$1117 = $$0114;
       label = 15;
       break L6;
      }
      }
      $31 = HEAP32[$8>>2]|0;
      $32 = ((($31)) + 44|0);
      $33 = HEAP32[$32>>2]|0;
      __THREW__ = 0;
      $34 = (invoke_iii($33|0,($8|0),48)|0);
      $35 = __THREW__; __THREW__ = 0;
      $36 = $35&1;
      if ($36) {
       break L4;
      }
      $37 = HEAP32[$5>>2]|0;
      $38 = ((($37)) + 4|0);
      HEAP32[$5>>2] = $38;
      HEAP32[$37>>2] = $34;
      $39 = ((($$0114)) + 2|0);
      $40 = HEAP8[$29>>0]|0;
      $41 = HEAP32[$8>>2]|0;
      $42 = ((($41)) + 44|0);
      $43 = HEAP32[$42>>2]|0;
      __THREW__ = 0;
      $44 = (invoke_iii($43|0,($8|0),($40|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       break L4;
      }
      $47 = HEAP32[$5>>2]|0;
      $48 = ((($47)) + 4|0);
      HEAP32[$5>>2] = $48;
      HEAP32[$47>>2] = $44;
      $$0116 = $39;
      while(1) {
       $49 = ($$0116>>>0)<($2>>>0);
       if (!($49)) {
        $$1115 = $39;$$2118 = $$0116;
        break L6;
       }
       $50 = HEAP8[$$0116>>0]|0;
       __THREW__ = 0;
       $51 = (invoke_i(4668)|0);
       $52 = __THREW__; __THREW__ = 0;
       $53 = $52&1;
       if ($53) {
        break L4;
       }
       $54 = $50 << 24 >> 24;
       __THREW__ = 0;
       $55 = (invoke_iii(4693,($54|0),($51|0))|0);
       $56 = __THREW__; __THREW__ = 0;
       $57 = $56&1;
       if ($57) {
        break L4;
       }
       $58 = ($55|0)==(0);
       if ($58) {
        $$1115 = $39;$$2118 = $$0116;
        break L6;
       }
       $59 = ((($$0116)) + 1|0);
       $$0116 = $59;
      }
     } else {
      $$1117 = $$0114;
      label = 15;
     }
    } else {
     $$1117 = $$0114;
     label = 15;
    }
   } while(0);
   L18: do {
    if ((label|0) == 15) {
     while(1) {
      label = 0;
      $60 = ($$1117>>>0)<($2>>>0);
      if (!($60)) {
       $$1115 = $$0114;$$2118 = $$1117;
       break L18;
      }
      $61 = HEAP8[$$1117>>0]|0;
      __THREW__ = 0;
      $62 = (invoke_i(4668)|0);
      $63 = __THREW__; __THREW__ = 0;
      $64 = $63&1;
      if ($64) {
       break L4;
      }
      $65 = $61 << 24 >> 24;
      __THREW__ = 0;
      $66 = (invoke_iii(4694,($65|0),($62|0))|0);
      $67 = __THREW__; __THREW__ = 0;
      $68 = $67&1;
      if ($68) {
       break L4;
      }
      $69 = ($66|0)==(0);
      if ($69) {
       $$1115 = $$0114;$$2118 = $$1117;
       break L18;
      }
      $70 = ((($$1117)) + 1|0);
      $$1117 = $70;
      label = 15;
     }
    }
   } while(0);
   $71 = ((($7)) + 11|0);
   $72 = HEAP8[$71>>0]|0;
   $73 = ($72<<24>>24)<(0);
   $74 = ((($7)) + 4|0);
   $75 = HEAP32[$74>>2]|0;
   $76 = $72&255;
   $77 = $73 ? $75 : $76;
   $78 = ($77|0)==(0);
   $79 = $$1115;
   $80 = $0;
   L26: do {
    if ($78) {
     $81 = HEAP32[$5>>2]|0;
     $82 = HEAP32[$8>>2]|0;
     $83 = ((($82)) + 48|0);
     $84 = HEAP32[$83>>2]|0;
     __THREW__ = 0;
     (invoke_iiiii($84|0,($8|0),($$1115|0),($$2118|0),($81|0))|0);
     $85 = __THREW__; __THREW__ = 0;
     $86 = $85&1;
     if ($86) {
      break L4;
     }
     $87 = $$2118;
     $88 = (($87) - ($79))|0;
     $89 = HEAP32[$5>>2]|0;
     $90 = (($89) + ($88<<2)|0);
     HEAP32[$5>>2] = $90;
     $$pre$phiZ2D = $8;$177 = $90;
    } else {
     $91 = ($$1115|0)==($$2118|0);
     L30: do {
      if (!($91)) {
       $$0$i$i = $$2118;$$07$i$i = $$1115;
       while(1) {
        $92 = ((($$0$i$i)) + -1|0);
        $93 = ($$07$i$i>>>0)<($92>>>0);
        if (!($93)) {
         break L30;
        }
        $94 = HEAP8[$$07$i$i>>0]|0;
        $95 = HEAP8[$92>>0]|0;
        HEAP8[$$07$i$i>>0] = $95;
        HEAP8[$92>>0] = $94;
        $96 = ((($$07$i$i)) + 1|0);
        $$0$i$i = $92;$$07$i$i = $96;
       }
      }
     } while(0);
     $97 = HEAP32[$9>>2]|0;
     $98 = ((($97)) + 16|0);
     $99 = HEAP32[$98>>2]|0;
     __THREW__ = 0;
     $100 = (invoke_ii($99|0,($9|0))|0);
     $101 = __THREW__; __THREW__ = 0;
     $102 = $101&1;
     if ($102) {
      break L4;
     }
     $$0 = $$1115;$$0111 = 0;$$0112 = 0;
     while(1) {
      $103 = ($$0>>>0)<($$2118>>>0);
      if (!($103)) {
       break;
      }
      $113 = HEAP8[$71>>0]|0;
      $114 = ($113<<24>>24)<(0);
      $115 = HEAP32[$7>>2]|0;
      $116 = $114 ? $115 : $7;
      $117 = (($116) + ($$0111)|0);
      $118 = HEAP8[$117>>0]|0;
      $119 = ($118<<24>>24)>(0);
      $120 = $118 << 24 >> 24;
      $121 = ($$0112|0)==($120|0);
      $or$cond = $119 & $121;
      if ($or$cond) {
       $122 = HEAP32[$5>>2]|0;
       $123 = ((($122)) + 4|0);
       HEAP32[$5>>2] = $123;
       HEAP32[$122>>2] = $100;
       $124 = HEAP32[$74>>2]|0;
       $125 = $113&255;
       $126 = $114 ? $124 : $125;
       $127 = (($126) + -1)|0;
       $128 = ($$0111>>>0)<($127>>>0);
       $129 = $128&1;
       $$$0111 = (($129) + ($$0111))|0;
       $$1 = $$$0111;$$1113 = 0;
      } else {
       $$1 = $$0111;$$1113 = $$0112;
      }
      $130 = HEAP8[$$0>>0]|0;
      $131 = HEAP32[$8>>2]|0;
      $132 = ((($131)) + 44|0);
      $133 = HEAP32[$132>>2]|0;
      __THREW__ = 0;
      $134 = (invoke_iii($133|0,($8|0),($130|0))|0);
      $135 = __THREW__; __THREW__ = 0;
      $136 = $135&1;
      if ($136) {
       break L4;
      }
      $137 = HEAP32[$5>>2]|0;
      $138 = ((($137)) + 4|0);
      HEAP32[$5>>2] = $138;
      HEAP32[$137>>2] = $134;
      $139 = (($$1113) + 1)|0;
      $140 = ((($$0)) + 1|0);
      $$0 = $140;$$0111 = $$1;$$0112 = $139;
     }
     $104 = (($79) - ($80))|0;
     $105 = (($3) + ($104<<2)|0);
     $106 = HEAP32[$5>>2]|0;
     $107 = ($105|0)==($106|0);
     if ($107) {
      $$pre$phiZ2D = $8;$177 = $105;
     } else {
      $$0$i$i131 = $106;$$07$i$i130 = $105;
      while(1) {
       $108 = ((($$0$i$i131)) + -4|0);
       $109 = ($$07$i$i130>>>0)<($108>>>0);
       if (!($109)) {
        $$pre$phiZ2D = $8;$177 = $106;
        break L26;
       }
       $110 = HEAP32[$$07$i$i130>>2]|0;
       $111 = HEAP32[$108>>2]|0;
       HEAP32[$$07$i$i130>>2] = $111;
       HEAP32[$108>>2] = $110;
       $112 = ((($$07$i$i130)) + 4|0);
       $$0$i$i131 = $108;$$07$i$i130 = $112;
      }
     }
    }
   } while(0);
   $$2 = $$2118;$178 = $177;
   while(1) {
    $141 = ($$2>>>0)<($2>>>0);
    if (!($141)) {
     $$3 = $$2;$164 = $178;
     break;
    }
    $142 = HEAP8[$$2>>0]|0;
    $143 = ($142<<24>>24)==(46);
    $144 = ((($$2)) + 1|0);
    if ($143) {
     label = 39;
     break;
    }
    $153 = HEAP32[$$pre$phiZ2D>>2]|0;
    $154 = ((($153)) + 44|0);
    $155 = HEAP32[$154>>2]|0;
    __THREW__ = 0;
    $156 = (invoke_iii($155|0,($8|0),($142|0))|0);
    $157 = __THREW__; __THREW__ = 0;
    $158 = $157&1;
    if ($158) {
     break L4;
    }
    $159 = HEAP32[$5>>2]|0;
    $160 = ((($159)) + 4|0);
    HEAP32[$5>>2] = $160;
    HEAP32[$159>>2] = $156;
    $$2 = $144;$178 = $160;
   }
   if ((label|0) == 39) {
    $145 = HEAP32[$9>>2]|0;
    $146 = ((($145)) + 12|0);
    $147 = HEAP32[$146>>2]|0;
    __THREW__ = 0;
    $148 = (invoke_ii($147|0,($9|0))|0);
    $149 = __THREW__; __THREW__ = 0;
    $150 = $149&1;
    if ($150) {
     break;
    }
    $151 = HEAP32[$5>>2]|0;
    $152 = ((($151)) + 4|0);
    HEAP32[$5>>2] = $152;
    HEAP32[$151>>2] = $148;
    $$3 = $144;$164 = $152;
   }
   $161 = HEAP32[$8>>2]|0;
   $162 = ((($161)) + 48|0);
   $163 = HEAP32[$162>>2]|0;
   __THREW__ = 0;
   (invoke_iiiii($163|0,($8|0),($$3|0),($2|0),($164|0))|0);
   $165 = __THREW__; __THREW__ = 0;
   $166 = $165&1;
   if (!($166)) {
    $167 = $$3;
    $168 = (($23) - ($167))|0;
    $169 = HEAP32[$5>>2]|0;
    $170 = (($169) + ($168<<2)|0);
    HEAP32[$5>>2] = $170;
    $171 = ($1|0)==($2|0);
    $172 = $1;
    $173 = (($172) - ($80))|0;
    $174 = (($3) + ($173<<2)|0);
    $storemerge = $171 ? $170 : $174;
    HEAP32[$4>>2] = $storemerge;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($7);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $175 = ___cxa_find_matching_catch_2()|0;
 $176 = tempRet0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($7);
 ___resumeException($175|0);
 // unreachable;
}
function __ZNSt3__29__num_putIwE21__widen_and_group_intEPcS2_S2_PwRS3_S4_RKNS_6localeE($0,$1,$2,$3,$4,$5,$6) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 var $$$081 = 0, $$0 = 0, $$0$i$i = 0, $$0$i$i97 = 0, $$07$i$i = 0, $$07$i$i96 = 0, $$081 = 0, $$082 = 0, $$086 = 0, $$1 = 0, $$183 = 0, $$187 = 0, $$pre = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $storemerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $7 = sp;
 $8 = (__ZNKSt3__26locale9use_facetERNS0_2idE($6,215220)|0);
 $9 = (__ZNKSt3__26locale9use_facetERNS0_2idE($6,215228)|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ((($10)) + 20|0);
 $12 = HEAP32[$11>>2]|0;
 FUNCTION_TABLE_vii[$12 & 8191]($7,$9);
 $13 = ((($7)) + 11|0);
 $14 = HEAP8[$13>>0]|0;
 $15 = ($14<<24>>24)<(0);
 $16 = ((($7)) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = $14&255;
 $19 = $15 ? $17 : $18;
 $20 = ($19|0)==(0);
 $21 = $2;
 $22 = $0;
 L1: do {
  if ($20) {
   $23 = HEAP32[$8>>2]|0;
   $24 = ((($23)) + 48|0);
   $25 = HEAP32[$24>>2]|0;
   __THREW__ = 0;
   (invoke_iiiii($25|0,($8|0),($0|0),($2|0),($3|0))|0);
   $26 = __THREW__; __THREW__ = 0;
   $27 = $26&1;
   if ($27) {
    label = 28;
   } else {
    $28 = (($21) - ($22))|0;
    $29 = (($3) + ($28<<2)|0);
    HEAP32[$5>>2] = $29;
    $120 = $29;
    label = 27;
   }
  } else {
   HEAP32[$5>>2] = $3;
   $30 = HEAP8[$0>>0]|0;
   switch ($30<<24>>24) {
   case 43: case 45:  {
    $31 = HEAP32[$8>>2]|0;
    $32 = ((($31)) + 44|0);
    $33 = HEAP32[$32>>2]|0;
    __THREW__ = 0;
    $34 = (invoke_iii($33|0,($8|0),($30|0))|0);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     label = 28;
     break L1;
    }
    $37 = ((($0)) + 1|0);
    $38 = HEAP32[$5>>2]|0;
    $39 = ((($38)) + 4|0);
    HEAP32[$5>>2] = $39;
    HEAP32[$38>>2] = $34;
    $$086 = $37;
    break;
   }
   default: {
    $$086 = $0;
   }
   }
   $40 = $$086;
   $41 = (($21) - ($40))|0;
   $42 = ($41|0)>(1);
   L9: do {
    if ($42) {
     $43 = HEAP8[$$086>>0]|0;
     $44 = ($43<<24>>24)==(48);
     if ($44) {
      $45 = ((($$086)) + 1|0);
      $46 = HEAP8[$45>>0]|0;
      switch ($46<<24>>24) {
      case 88: case 120:  {
       break;
      }
      default: {
       $$187 = $$086;
       break L9;
      }
      }
      $47 = HEAP32[$8>>2]|0;
      $48 = ((($47)) + 44|0);
      $49 = HEAP32[$48>>2]|0;
      __THREW__ = 0;
      $50 = (invoke_iii($49|0,($8|0),48)|0);
      $51 = __THREW__; __THREW__ = 0;
      $52 = $51&1;
      if ($52) {
       label = 28;
       break L1;
      }
      $53 = HEAP32[$5>>2]|0;
      $54 = ((($53)) + 4|0);
      HEAP32[$5>>2] = $54;
      HEAP32[$53>>2] = $50;
      $55 = HEAP8[$45>>0]|0;
      $56 = HEAP32[$8>>2]|0;
      $57 = ((($56)) + 44|0);
      $58 = HEAP32[$57>>2]|0;
      __THREW__ = 0;
      $59 = (invoke_iii($58|0,($8|0),($55|0))|0);
      $60 = __THREW__; __THREW__ = 0;
      $61 = $60&1;
      if ($61) {
       label = 28;
       break L1;
      }
      $62 = ((($$086)) + 2|0);
      $63 = HEAP32[$5>>2]|0;
      $64 = ((($63)) + 4|0);
      HEAP32[$5>>2] = $64;
      HEAP32[$63>>2] = $59;
      $$187 = $62;
     } else {
      $$187 = $$086;
     }
    } else {
     $$187 = $$086;
    }
   } while(0);
   $65 = ($$187|0)==($2|0);
   L16: do {
    if (!($65)) {
     $$0$i$i = $2;$$07$i$i = $$187;
     while(1) {
      $66 = ((($$0$i$i)) + -1|0);
      $67 = ($$07$i$i>>>0)<($66>>>0);
      if (!($67)) {
       break L16;
      }
      $68 = HEAP8[$$07$i$i>>0]|0;
      $69 = HEAP8[$66>>0]|0;
      HEAP8[$$07$i$i>>0] = $69;
      HEAP8[$66>>0] = $68;
      $70 = ((($$07$i$i)) + 1|0);
      $$0$i$i = $66;$$07$i$i = $70;
     }
    }
   } while(0);
   $71 = HEAP32[$9>>2]|0;
   $72 = ((($71)) + 16|0);
   $73 = HEAP32[$72>>2]|0;
   __THREW__ = 0;
   $74 = (invoke_ii($73|0,($9|0))|0);
   $75 = __THREW__; __THREW__ = 0;
   $76 = $75&1;
   if ($76) {
    label = 28;
   } else {
    $$0 = $$187;$$081 = 0;$$082 = 0;
    while(1) {
     $77 = ($$0>>>0)<($2>>>0);
     if (!($77)) {
      break;
     }
     $88 = HEAP8[$13>>0]|0;
     $89 = ($88<<24>>24)<(0);
     $90 = HEAP32[$7>>2]|0;
     $91 = $89 ? $90 : $7;
     $92 = (($91) + ($$081)|0);
     $93 = HEAP8[$92>>0]|0;
     $94 = ($93<<24>>24)!=(0);
     $95 = $93 << 24 >> 24;
     $96 = ($$082|0)==($95|0);
     $or$cond = $94 & $96;
     if ($or$cond) {
      $97 = HEAP32[$5>>2]|0;
      $98 = ((($97)) + 4|0);
      HEAP32[$5>>2] = $98;
      HEAP32[$97>>2] = $74;
      $99 = HEAP32[$16>>2]|0;
      $100 = $88&255;
      $101 = $89 ? $99 : $100;
      $102 = (($101) + -1)|0;
      $103 = ($$081>>>0)<($102>>>0);
      $104 = $103&1;
      $$$081 = (($104) + ($$081))|0;
      $$1 = $$$081;$$183 = 0;
     } else {
      $$1 = $$081;$$183 = $$082;
     }
     $105 = HEAP8[$$0>>0]|0;
     $106 = HEAP32[$8>>2]|0;
     $107 = ((($106)) + 44|0);
     $108 = HEAP32[$107>>2]|0;
     __THREW__ = 0;
     $109 = (invoke_iii($108|0,($8|0),($105|0))|0);
     $110 = __THREW__; __THREW__ = 0;
     $111 = $110&1;
     if ($111) {
      label = 28;
      break L1;
     }
     $112 = HEAP32[$5>>2]|0;
     $113 = ((($112)) + 4|0);
     HEAP32[$5>>2] = $113;
     HEAP32[$112>>2] = $109;
     $114 = (($$183) + 1)|0;
     $115 = ((($$0)) + 1|0);
     $$0 = $115;$$081 = $$1;$$082 = $114;
    }
    $78 = $$187;
    $79 = (($78) - ($22))|0;
    $80 = (($3) + ($79<<2)|0);
    $81 = HEAP32[$5>>2]|0;
    $82 = ($80|0)==($81|0);
    if ($82) {
     $120 = $80;
     label = 27;
    } else {
     $$0$i$i97 = $81;$$07$i$i96 = $80;
     while(1) {
      $83 = ((($$0$i$i97)) + -4|0);
      $84 = ($$07$i$i96>>>0)<($83>>>0);
      if (!($84)) {
       break;
      }
      $85 = HEAP32[$$07$i$i96>>2]|0;
      $86 = HEAP32[$83>>2]|0;
      HEAP32[$$07$i$i96>>2] = $86;
      HEAP32[$83>>2] = $85;
      $87 = ((($$07$i$i96)) + 4|0);
      $$0$i$i97 = $83;$$07$i$i96 = $87;
     }
     $$pre = HEAP32[$5>>2]|0;
     $120 = $$pre;
     label = 27;
    }
   }
  }
 } while(0);
 if ((label|0) == 27) {
  $116 = ($1|0)==($2|0);
  $117 = $1;
  $118 = (($117) - ($22))|0;
  $119 = (($3) + ($118<<2)|0);
  $storemerge = $116 ? $120 : $119;
  HEAP32[$4>>2] = $storemerge;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($7);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 28) {
  $121 = ___cxa_find_matching_catch_2()|0;
  $122 = tempRet0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($7);
  ___resumeException($121|0);
  // unreachable;
 }
}
function __ZNSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEED2Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__26locale5facetD2Ev($0);
 return;
}
function __ZNSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEED0Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__26locale5facetD2Ev($0);
 __ZdlPv($0);
 return;
}
function __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE13do_date_orderEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 2;
}
function __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE11do_get_timeES4_S4_RNS_8ios_baseERjP2tm($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $10 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy1 = sp + 12|0;
 $$byval_copy = sp + 8|0;
 $6 = sp + 4|0;
 $7 = sp;
 $8 = HEAP32[$1>>2]|0;
 HEAP32[$6>>2] = $8;
 $9 = HEAP32[$2>>2]|0;
 HEAP32[$7>>2] = $9;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$6>>2]|0;
 ;HEAP32[$$byval_copy1>>2]=HEAP32[$7>>2]|0;
 $10 = (__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjP2tmPKcSC_($0,$$byval_copy,$$byval_copy1,$3,$4,$5,203393,(203401))|0);
 STACKTOP = sp;return ($10|0);
}
function __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE11do_get_dateES4_S4_RNS_8ios_baseERjP2tm($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy1 = sp + 12|0;
 $$byval_copy = sp + 8|0;
 $6 = sp + 4|0;
 $7 = sp;
 $8 = ((($0)) + 8|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($9)) + 20|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (FUNCTION_TABLE_ii[$11 & 8191]($8)|0);
 $13 = HEAP32[$1>>2]|0;
 HEAP32[$6>>2] = $13;
 $14 = HEAP32[$2>>2]|0;
 HEAP32[$7>>2] = $14;
 $15 = ((($12)) + 11|0);
 $16 = HEAP8[$15>>0]|0;
 $17 = ($16<<24>>24)<(0);
 $18 = HEAP32[$12>>2]|0;
 $19 = $17 ? $18 : $12;
 $20 = ((($12)) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = $16&255;
 $23 = $17 ? $21 : $22;
 $24 = (($19) + ($23)|0);
 ;HEAP32[$$byval_copy>>2]=HEAP32[$6>>2]|0;
 ;HEAP32[$$byval_copy1>>2]=HEAP32[$7>>2]|0;
 $25 = (__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjP2tmPKcSC_($0,$$byval_copy,$$byval_copy1,$3,$4,$5,$19,$24)|0);
 STACKTOP = sp;return ($25|0);
}
function __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE14do_get_weekdayES4_S4_RNS_8ios_baseERjP2tm($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$byval_copy = 0, $$sroa$0$0$copyload = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy = sp + 8|0;
 $6 = sp + 4|0;
 $7 = sp;
 __ZNKSt3__28ios_base6getlocEv($6,$3);
 __THREW__ = 0;
 $8 = (invoke_iii(3255,($6|0),(215188|0))|0);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if ($10) {
  $13 = ___cxa_find_matching_catch_2()|0;
  $14 = tempRet0;
  __ZNSt3__26localeD2Ev($6);
  ___resumeException($13|0);
  // unreachable;
 } else {
  __ZNSt3__26localeD2Ev($6);
  $11 = ((($5)) + 24|0);
  $12 = HEAP32[$2>>2]|0;
  HEAP32[$7>>2] = $12;
  ;HEAP32[$$byval_copy>>2]=HEAP32[$7>>2]|0;
  __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE17__get_weekdaynameERiRS4_S4_RjRKNS_5ctypeIcEE($0,$11,$1,$$byval_copy,$4,$8);
  $$sroa$0$0$copyload = HEAP32[$1>>2]|0;
  STACKTOP = sp;return ($$sroa$0$0$copyload|0);
 }
 return (0)|0;
}
function __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE16do_get_monthnameES4_S4_RNS_8ios_baseERjP2tm($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$byval_copy = 0, $$sroa$0$0$copyload = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy = sp + 8|0;
 $6 = sp + 4|0;
 $7 = sp;
 __ZNKSt3__28ios_base6getlocEv($6,$3);
 __THREW__ = 0;
 $8 = (invoke_iii(3255,($6|0),(215188|0))|0);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if ($10) {
  $13 = ___cxa_find_matching_catch_2()|0;
  $14 = tempRet0;
  __ZNSt3__26localeD2Ev($6);
  ___resumeException($13|0);
  // unreachable;
 } else {
  __ZNSt3__26localeD2Ev($6);
  $11 = ((($5)) + 16|0);
  $12 = HEAP32[$2>>2]|0;
  HEAP32[$7>>2] = $12;
  ;HEAP32[$$byval_copy>>2]=HEAP32[$7>>2]|0;
  __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE15__get_monthnameERiRS4_S4_RjRKNS_5ctypeIcEE($0,$11,$1,$$byval_copy,$4,$8);
  $$sroa$0$0$copyload = HEAP32[$1>>2]|0;
  STACKTOP = sp;return ($$sroa$0$0$copyload|0);
 }
 return (0)|0;
}
function __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE11do_get_yearES4_S4_RNS_8ios_baseERjP2tm($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$byval_copy = 0, $$sroa$0$0$copyload = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy = sp + 8|0;
 $6 = sp + 4|0;
 $7 = sp;
 __ZNKSt3__28ios_base6getlocEv($6,$3);
 __THREW__ = 0;
 $8 = (invoke_iii(3255,($6|0),(215188|0))|0);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if ($10) {
  $13 = ___cxa_find_matching_catch_2()|0;
  $14 = tempRet0;
  __ZNSt3__26localeD2Ev($6);
  ___resumeException($13|0);
  // unreachable;
 } else {
  __ZNSt3__26localeD2Ev($6);
  $11 = ((($5)) + 20|0);
  $12 = HEAP32[$2>>2]|0;
  HEAP32[$7>>2] = $12;
  ;HEAP32[$$byval_copy>>2]=HEAP32[$7>>2]|0;
  __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE10__get_yearERiRS4_S4_RjRKNS_5ctypeIcEE($0,$11,$1,$$byval_copy,$4,$8);
  $$sroa$0$0$copyload = HEAP32[$1>>2]|0;
  STACKTOP = sp;return ($$sroa$0$0$copyload|0);
 }
 return (0)|0;
}
function __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjP2tmcc($0,$1,$2,$3,$4,$5,$6,$7) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $$byval_copy10 = 0, $$byval_copy11 = 0, $$byval_copy12 = 0, $$byval_copy13 = 0, $$byval_copy14 = 0, $$byval_copy15 = 0, $$byval_copy16 = 0, $$byval_copy17 = 0, $$byval_copy18 = 0, $$byval_copy19 = 0, $$byval_copy2 = 0, $$byval_copy20 = 0, $$byval_copy21 = 0, $$byval_copy22 = 0, $$byval_copy23 = 0, $$byval_copy24 = 0, $$byval_copy25 = 0, $$byval_copy26 = 0;
 var $$byval_copy27 = 0, $$byval_copy28 = 0, $$byval_copy29 = 0, $$byval_copy3 = 0, $$byval_copy30 = 0, $$byval_copy4 = 0, $$byval_copy5 = 0, $$byval_copy6 = 0, $$byval_copy7 = 0, $$byval_copy8 = 0, $$byval_copy9 = 0, $$sroa$097$0 = 0, $$sroa$097$0$copyload = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 256|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(256|0);
 $$byval_copy30 = sp + 248|0;
 $$byval_copy29 = sp + 244|0;
 $$byval_copy28 = sp + 240|0;
 $$byval_copy27 = sp + 236|0;
 $$byval_copy26 = sp + 232|0;
 $$byval_copy25 = sp + 228|0;
 $$byval_copy24 = sp + 224|0;
 $$byval_copy23 = sp + 220|0;
 $$byval_copy22 = sp + 216|0;
 $$byval_copy21 = sp + 212|0;
 $$byval_copy20 = sp + 208|0;
 $$byval_copy19 = sp + 204|0;
 $$byval_copy18 = sp + 200|0;
 $$byval_copy17 = sp + 196|0;
 $$byval_copy16 = sp + 192|0;
 $$byval_copy15 = sp + 188|0;
 $$byval_copy14 = sp + 184|0;
 $$byval_copy13 = sp + 180|0;
 $$byval_copy12 = sp + 176|0;
 $$byval_copy11 = sp + 172|0;
 $$byval_copy10 = sp + 168|0;
 $$byval_copy9 = sp + 164|0;
 $$byval_copy8 = sp + 160|0;
 $$byval_copy7 = sp + 156|0;
 $$byval_copy6 = sp + 152|0;
 $$byval_copy5 = sp + 148|0;
 $$byval_copy4 = sp + 144|0;
 $$byval_copy3 = sp + 140|0;
 $$byval_copy2 = sp + 136|0;
 $$byval_copy1 = sp + 132|0;
 $$byval_copy = sp + 128|0;
 $8 = sp + 124|0;
 $9 = sp + 120|0;
 $10 = sp + 116|0;
 $11 = sp + 112|0;
 $12 = sp + 108|0;
 $13 = sp + 104|0;
 $14 = sp + 100|0;
 $15 = sp + 96|0;
 $16 = sp + 92|0;
 $17 = sp + 88|0;
 $18 = sp + 84|0;
 $19 = sp + 80|0;
 $20 = sp + 76|0;
 $21 = sp + 72|0;
 $22 = sp + 68|0;
 $23 = sp + 64|0;
 $24 = sp + 60|0;
 $25 = sp + 56|0;
 $26 = sp + 52|0;
 $27 = sp + 48|0;
 $28 = sp + 44|0;
 $29 = sp + 40|0;
 $30 = sp + 36|0;
 $31 = sp + 32|0;
 $32 = sp + 28|0;
 $33 = sp + 24|0;
 $34 = sp + 20|0;
 $35 = sp + 16|0;
 $36 = sp + 12|0;
 $37 = sp + 8|0;
 $38 = sp + 4|0;
 $39 = sp;
 HEAP32[$4>>2] = 0;
 __ZNKSt3__28ios_base6getlocEv($8,$3);
 __THREW__ = 0;
 $40 = (invoke_iii(3255,($8|0),(215188|0))|0);
 $41 = __THREW__; __THREW__ = 0;
 $42 = $41&1;
 if ($42) {
  $49 = ___cxa_find_matching_catch_2()|0;
  $50 = tempRet0;
  __ZNSt3__26localeD2Ev($8);
  ___resumeException($49|0);
  // unreachable;
 }
 __ZNSt3__26localeD2Ev($8);
 $43 = $6 << 24 >> 24;
 $44 = ((($5)) + 16|0);
 $45 = ((($5)) + 8|0);
 $46 = ((($5)) + 20|0);
 $47 = ((($5)) + 24|0);
 $48 = ((($0)) + 8|0);
 do {
  switch ($43|0) {
  case 65: case 97:  {
   $51 = HEAP32[$2>>2]|0;
   HEAP32[$9>>2] = $51;
   ;HEAP32[$$byval_copy>>2]=HEAP32[$9>>2]|0;
   __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE17__get_weekdaynameERiRS4_S4_RjRKNS_5ctypeIcEE($0,$47,$1,$$byval_copy,$4,$40);
   label = 28;
   break;
  }
  case 104: case 66: case 98:  {
   $52 = HEAP32[$2>>2]|0;
   HEAP32[$10>>2] = $52;
   ;HEAP32[$$byval_copy1>>2]=HEAP32[$10>>2]|0;
   __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE15__get_monthnameERiRS4_S4_RjRKNS_5ctypeIcEE($0,$44,$1,$$byval_copy1,$4,$40);
   label = 28;
   break;
  }
  case 99:  {
   $53 = HEAP32[$48>>2]|0;
   $54 = ((($53)) + 12|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = (FUNCTION_TABLE_ii[$55 & 8191]($48)|0);
   $57 = HEAP32[$1>>2]|0;
   HEAP32[$11>>2] = $57;
   $58 = HEAP32[$2>>2]|0;
   HEAP32[$12>>2] = $58;
   $59 = ((($56)) + 11|0);
   $60 = HEAP8[$59>>0]|0;
   $61 = ($60<<24>>24)<(0);
   $62 = HEAP32[$56>>2]|0;
   $63 = $61 ? $62 : $56;
   $64 = ((($56)) + 4|0);
   $65 = HEAP32[$64>>2]|0;
   $66 = $60&255;
   $67 = $61 ? $65 : $66;
   $68 = (($63) + ($67)|0);
   ;HEAP32[$$byval_copy2>>2]=HEAP32[$11>>2]|0;
   ;HEAP32[$$byval_copy3>>2]=HEAP32[$12>>2]|0;
   $69 = (__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjP2tmPKcSC_($0,$$byval_copy2,$$byval_copy3,$3,$4,$5,$63,$68)|0);
   HEAP32[$1>>2] = $69;
   label = 28;
   break;
  }
  case 101: case 100:  {
   $70 = ((($5)) + 12|0);
   $71 = HEAP32[$2>>2]|0;
   HEAP32[$13>>2] = $71;
   ;HEAP32[$$byval_copy4>>2]=HEAP32[$13>>2]|0;
   __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE9__get_dayERiRS4_S4_RjRKNS_5ctypeIcEE($0,$70,$1,$$byval_copy4,$4,$40);
   label = 28;
   break;
  }
  case 68:  {
   $72 = HEAP32[$1>>2]|0;
   HEAP32[$14>>2] = $72;
   $73 = HEAP32[$2>>2]|0;
   HEAP32[$15>>2] = $73;
   ;HEAP32[$$byval_copy5>>2]=HEAP32[$14>>2]|0;
   ;HEAP32[$$byval_copy6>>2]=HEAP32[$15>>2]|0;
   $74 = (__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjP2tmPKcSC_($0,$$byval_copy5,$$byval_copy6,$3,$4,$5,203353,(203361))|0);
   HEAP32[$1>>2] = $74;
   label = 28;
   break;
  }
  case 70:  {
   $75 = HEAP32[$1>>2]|0;
   HEAP32[$16>>2] = $75;
   $76 = HEAP32[$2>>2]|0;
   HEAP32[$17>>2] = $76;
   ;HEAP32[$$byval_copy7>>2]=HEAP32[$16>>2]|0;
   ;HEAP32[$$byval_copy8>>2]=HEAP32[$17>>2]|0;
   $77 = (__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjP2tmPKcSC_($0,$$byval_copy7,$$byval_copy8,$3,$4,$5,203361,(203369))|0);
   HEAP32[$1>>2] = $77;
   label = 28;
   break;
  }
  case 72:  {
   $78 = HEAP32[$2>>2]|0;
   HEAP32[$18>>2] = $78;
   ;HEAP32[$$byval_copy9>>2]=HEAP32[$18>>2]|0;
   __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE10__get_hourERiRS4_S4_RjRKNS_5ctypeIcEE($0,$45,$1,$$byval_copy9,$4,$40);
   label = 28;
   break;
  }
  case 73:  {
   $79 = HEAP32[$2>>2]|0;
   HEAP32[$19>>2] = $79;
   ;HEAP32[$$byval_copy10>>2]=HEAP32[$19>>2]|0;
   __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE13__get_12_hourERiRS4_S4_RjRKNS_5ctypeIcEE($0,$45,$1,$$byval_copy10,$4,$40);
   label = 28;
   break;
  }
  case 106:  {
   $80 = ((($5)) + 28|0);
   $81 = HEAP32[$2>>2]|0;
   HEAP32[$20>>2] = $81;
   ;HEAP32[$$byval_copy11>>2]=HEAP32[$20>>2]|0;
   __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE18__get_day_year_numERiRS4_S4_RjRKNS_5ctypeIcEE($0,$80,$1,$$byval_copy11,$4,$40);
   label = 28;
   break;
  }
  case 109:  {
   $82 = HEAP32[$2>>2]|0;
   HEAP32[$21>>2] = $82;
   ;HEAP32[$$byval_copy12>>2]=HEAP32[$21>>2]|0;
   __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE11__get_monthERiRS4_S4_RjRKNS_5ctypeIcEE($0,$44,$1,$$byval_copy12,$4,$40);
   label = 28;
   break;
  }
  case 77:  {
   $83 = ((($5)) + 4|0);
   $84 = HEAP32[$2>>2]|0;
   HEAP32[$22>>2] = $84;
   ;HEAP32[$$byval_copy13>>2]=HEAP32[$22>>2]|0;
   __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE12__get_minuteERiRS4_S4_RjRKNS_5ctypeIcEE($0,$83,$1,$$byval_copy13,$4,$40);
   label = 28;
   break;
  }
  case 116: case 110:  {
   $85 = HEAP32[$2>>2]|0;
   HEAP32[$23>>2] = $85;
   ;HEAP32[$$byval_copy14>>2]=HEAP32[$23>>2]|0;
   __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE17__get_white_spaceERS4_S4_RjRKNS_5ctypeIcEE($0,$1,$$byval_copy14,$4,$40);
   label = 28;
   break;
  }
  case 112:  {
   $86 = HEAP32[$2>>2]|0;
   HEAP32[$24>>2] = $86;
   ;HEAP32[$$byval_copy15>>2]=HEAP32[$24>>2]|0;
   __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE11__get_am_pmERiRS4_S4_RjRKNS_5ctypeIcEE($0,$45,$1,$$byval_copy15,$4,$40);
   label = 28;
   break;
  }
  case 114:  {
   $87 = HEAP32[$1>>2]|0;
   HEAP32[$25>>2] = $87;
   $88 = HEAP32[$2>>2]|0;
   HEAP32[$26>>2] = $88;
   ;HEAP32[$$byval_copy16>>2]=HEAP32[$25>>2]|0;
   ;HEAP32[$$byval_copy17>>2]=HEAP32[$26>>2]|0;
   $89 = (__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjP2tmPKcSC_($0,$$byval_copy16,$$byval_copy17,$3,$4,$5,203369,(203380))|0);
   HEAP32[$1>>2] = $89;
   label = 28;
   break;
  }
  case 82:  {
   $90 = HEAP32[$1>>2]|0;
   HEAP32[$27>>2] = $90;
   $91 = HEAP32[$2>>2]|0;
   HEAP32[$28>>2] = $91;
   ;HEAP32[$$byval_copy18>>2]=HEAP32[$27>>2]|0;
   ;HEAP32[$$byval_copy19>>2]=HEAP32[$28>>2]|0;
   $92 = (__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjP2tmPKcSC_($0,$$byval_copy18,$$byval_copy19,$3,$4,$5,203380,(203385))|0);
   HEAP32[$1>>2] = $92;
   label = 28;
   break;
  }
  case 83:  {
   $93 = HEAP32[$2>>2]|0;
   HEAP32[$29>>2] = $93;
   ;HEAP32[$$byval_copy20>>2]=HEAP32[$29>>2]|0;
   __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE12__get_secondERiRS4_S4_RjRKNS_5ctypeIcEE($0,$5,$1,$$byval_copy20,$4,$40);
   label = 28;
   break;
  }
  case 84:  {
   $94 = HEAP32[$1>>2]|0;
   HEAP32[$30>>2] = $94;
   $95 = HEAP32[$2>>2]|0;
   HEAP32[$31>>2] = $95;
   ;HEAP32[$$byval_copy21>>2]=HEAP32[$30>>2]|0;
   ;HEAP32[$$byval_copy22>>2]=HEAP32[$31>>2]|0;
   $96 = (__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjP2tmPKcSC_($0,$$byval_copy21,$$byval_copy22,$3,$4,$5,203385,(203393))|0);
   HEAP32[$1>>2] = $96;
   label = 28;
   break;
  }
  case 119:  {
   $97 = HEAP32[$2>>2]|0;
   HEAP32[$32>>2] = $97;
   ;HEAP32[$$byval_copy23>>2]=HEAP32[$32>>2]|0;
   __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE13__get_weekdayERiRS4_S4_RjRKNS_5ctypeIcEE($0,$47,$1,$$byval_copy23,$4,$40);
   label = 28;
   break;
  }
  case 120:  {
   $98 = HEAP32[$0>>2]|0;
   $99 = ((($98)) + 20|0);
   $100 = HEAP32[$99>>2]|0;
   $101 = HEAP32[$1>>2]|0;
   HEAP32[$33>>2] = $101;
   $102 = HEAP32[$2>>2]|0;
   HEAP32[$34>>2] = $102;
   ;HEAP32[$$byval_copy24>>2]=HEAP32[$33>>2]|0;
   ;HEAP32[$$byval_copy25>>2]=HEAP32[$34>>2]|0;
   $103 = (FUNCTION_TABLE_iiiiiii[$100 & 8191]($0,$$byval_copy24,$$byval_copy25,$3,$4,$5)|0);
   $$sroa$097$0 = $103;
   break;
  }
  case 88:  {
   $104 = HEAP32[$48>>2]|0;
   $105 = ((($104)) + 24|0);
   $106 = HEAP32[$105>>2]|0;
   $107 = (FUNCTION_TABLE_ii[$106 & 8191]($48)|0);
   $108 = HEAP32[$1>>2]|0;
   HEAP32[$35>>2] = $108;
   $109 = HEAP32[$2>>2]|0;
   HEAP32[$36>>2] = $109;
   $110 = ((($107)) + 11|0);
   $111 = HEAP8[$110>>0]|0;
   $112 = ($111<<24>>24)<(0);
   $113 = HEAP32[$107>>2]|0;
   $114 = $112 ? $113 : $107;
   $115 = ((($107)) + 4|0);
   $116 = HEAP32[$115>>2]|0;
   $117 = $111&255;
   $118 = $112 ? $116 : $117;
   $119 = (($114) + ($118)|0);
   ;HEAP32[$$byval_copy26>>2]=HEAP32[$35>>2]|0;
   ;HEAP32[$$byval_copy27>>2]=HEAP32[$36>>2]|0;
   $120 = (__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjP2tmPKcSC_($0,$$byval_copy26,$$byval_copy27,$3,$4,$5,$114,$119)|0);
   HEAP32[$1>>2] = $120;
   label = 28;
   break;
  }
  case 121:  {
   $121 = HEAP32[$2>>2]|0;
   HEAP32[$37>>2] = $121;
   ;HEAP32[$$byval_copy28>>2]=HEAP32[$37>>2]|0;
   __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE10__get_yearERiRS4_S4_RjRKNS_5ctypeIcEE($0,$46,$1,$$byval_copy28,$4,$40);
   label = 28;
   break;
  }
  case 89:  {
   $122 = HEAP32[$2>>2]|0;
   HEAP32[$38>>2] = $122;
   ;HEAP32[$$byval_copy29>>2]=HEAP32[$38>>2]|0;
   __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE11__get_year4ERiRS4_S4_RjRKNS_5ctypeIcEE($0,$46,$1,$$byval_copy29,$4,$40);
   label = 28;
   break;
  }
  case 37:  {
   $123 = HEAP32[$2>>2]|0;
   HEAP32[$39>>2] = $123;
   ;HEAP32[$$byval_copy30>>2]=HEAP32[$39>>2]|0;
   __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE13__get_percentERS4_S4_RjRKNS_5ctypeIcEE($0,$1,$$byval_copy30,$4,$40);
   label = 28;
   break;
  }
  default: {
   $124 = HEAP32[$4>>2]|0;
   $125 = $124 | 4;
   HEAP32[$4>>2] = $125;
   label = 28;
  }
  }
 } while(0);
 if ((label|0) == 28) {
  $$sroa$097$0$copyload = HEAP32[$1>>2]|0;
  $$sroa$097$0 = $$sroa$097$0$copyload;
 }
 STACKTOP = sp;return ($$sroa$097$0|0);
}
function __ZNKSt3__220__time_get_c_storageIcE7__weeksEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP8[207112]|0;
 $2 = ($1<<24>>24)==(0);
 do {
  if ($2) {
   $3 = (___cxa_guard_acquire(207112)|0);
   $4 = ($3|0)==(0);
   if (!($4)) {
    __THREW__ = 0;
    invoke_v(4699);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     $8 = ___cxa_find_matching_catch_2()|0;
     $9 = tempRet0;
     ___resumeException($8|0);
     // unreachable;
    } else {
     HEAP32[54015] = 215892;
     break;
    }
   }
  }
 } while(0);
 $7 = HEAP32[54015]|0;
 return ($7|0);
}
function __ZNKSt3__220__time_get_c_storageIcE8__monthsEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP8[207096]|0;
 $2 = ($1<<24>>24)==(0);
 do {
  if ($2) {
   $3 = (___cxa_guard_acquire(207096)|0);
   $4 = ($3|0)==(0);
   if (!($4)) {
    __THREW__ = 0;
    invoke_v(4700);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     $8 = ___cxa_find_matching_catch_2()|0;
     $9 = tempRet0;
     ___resumeException($8|0);
     // unreachable;
    } else {
     HEAP32[53972] = 215600;
     break;
    }
   }
  }
 } while(0);
 $7 = HEAP32[53972]|0;
 return ($7|0);
}
function __ZNKSt3__220__time_get_c_storageIcE7__am_pmEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP8[207080]|0;
 $2 = ($1<<24>>24)==(0);
 do {
  if ($2) {
   $3 = (___cxa_guard_acquire(207080)|0);
   $4 = ($3|0)==(0);
   if (!($4)) {
    __THREW__ = 0;
    invoke_v(4701);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     $8 = ___cxa_find_matching_catch_2()|0;
     $9 = tempRet0;
     ___resumeException($8|0);
     // unreachable;
    } else {
     HEAP32[53899] = 215308;
     break;
    }
   }
  }
 } while(0);
 $7 = HEAP32[53899]|0;
 return ($7|0);
}
function __ZNKSt3__220__time_get_c_storageIcE3__cEv($0) {
 $0 = $0|0;
 var $$0$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $2 = HEAP8[207072]|0;
 $3 = ($2<<24>>24)==(0);
 L1: do {
  if ($3) {
   $4 = (___cxa_guard_acquire(207072)|0);
   $5 = ($4|0)==(0);
   if (!($5)) {
    ;HEAP32[215296>>2]=0|0;HEAP32[215296+4>>2]=0|0;HEAP32[215296+8>>2]=0|0;
    $6 = (__ZNSt3__211char_traitsIcE6lengthEPKc(203111)|0);
    $7 = ($6>>>0)>(4294967279);
    do {
     if ($7) {
      __THREW__ = 0;
      invoke_vi(3367,(215296|0));
      $8 = __THREW__; __THREW__ = 0;
     } else {
      $9 = ($6>>>0)<(11);
      if ($9) {
       $10 = $6&255;
       HEAP8[(215307)>>0] = $10;
       $$0$i$i = 215296;
      } else {
       $11 = (($6) + 16)|0;
       $12 = $11 & -16;
       __THREW__ = 0;
       $13 = (invoke_ii(3276,($12|0))|0);
       $14 = __THREW__; __THREW__ = 0;
       $15 = $14&1;
       if ($15) {
        break;
       }
       HEAP32[53824] = $13;
       $16 = $12 | -2147483648;
       HEAP32[(215304)>>2] = $16;
       HEAP32[(215300)>>2] = $6;
       $$0$i$i = $13;
      }
      (__ZNSt3__211char_traitsIcE4copyEPcPKcj($$0$i$i,203111,$6)|0);
      $17 = (($$0$i$i) + ($6)|0);
      HEAP8[$1>>0] = 0;
      __ZNSt3__211char_traitsIcE6assignERcRKc($17,$1);
      (___cxa_atexit((3252|0),(215296|0),(___dso_handle|0))|0);
      break L1;
     }
    } while(0);
    $18 = ___cxa_find_matching_catch_2()|0;
    $19 = tempRet0;
    ___resumeException($18|0);
    // unreachable;
   }
  }
 } while(0);
 STACKTOP = sp;return (215296|0);
}
function __ZNKSt3__220__time_get_c_storageIcE3__rEv($0) {
 $0 = $0|0;
 var $$0$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $2 = HEAP8[207064]|0;
 $3 = ($2<<24>>24)==(0);
 L1: do {
  if ($3) {
   $4 = (___cxa_guard_acquire(207064)|0);
   $5 = ($4|0)==(0);
   if (!($5)) {
    ;HEAP32[215284>>2]=0|0;HEAP32[215284+4>>2]=0|0;HEAP32[215284+8>>2]=0|0;
    $6 = (__ZNSt3__211char_traitsIcE6lengthEPKc(203099)|0);
    $7 = ($6>>>0)>(4294967279);
    do {
     if ($7) {
      __THREW__ = 0;
      invoke_vi(3367,(215284|0));
      $8 = __THREW__; __THREW__ = 0;
     } else {
      $9 = ($6>>>0)<(11);
      if ($9) {
       $10 = $6&255;
       HEAP8[(215295)>>0] = $10;
       $$0$i$i = 215284;
      } else {
       $11 = (($6) + 16)|0;
       $12 = $11 & -16;
       __THREW__ = 0;
       $13 = (invoke_ii(3276,($12|0))|0);
       $14 = __THREW__; __THREW__ = 0;
       $15 = $14&1;
       if ($15) {
        break;
       }
       HEAP32[53821] = $13;
       $16 = $12 | -2147483648;
       HEAP32[(215292)>>2] = $16;
       HEAP32[(215288)>>2] = $6;
       $$0$i$i = $13;
      }
      (__ZNSt3__211char_traitsIcE4copyEPcPKcj($$0$i$i,203099,$6)|0);
      $17 = (($$0$i$i) + ($6)|0);
      HEAP8[$1>>0] = 0;
      __ZNSt3__211char_traitsIcE6assignERcRKc($17,$1);
      (___cxa_atexit((3252|0),(215284|0),(___dso_handle|0))|0);
      break L1;
     }
    } while(0);
    $18 = ___cxa_find_matching_catch_2()|0;
    $19 = tempRet0;
    ___resumeException($18|0);
    // unreachable;
   }
  }
 } while(0);
 STACKTOP = sp;return (215284|0);
}
function __ZNKSt3__220__time_get_c_storageIcE3__xEv($0) {
 $0 = $0|0;
 var $$0$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $2 = HEAP8[207056]|0;
 $3 = ($2<<24>>24)==(0);
 L1: do {
  if ($3) {
   $4 = (___cxa_guard_acquire(207056)|0);
   $5 = ($4|0)==(0);
   if (!($5)) {
    ;HEAP32[215272>>2]=0|0;HEAP32[215272+4>>2]=0|0;HEAP32[215272+8>>2]=0|0;
    $6 = (__ZNSt3__211char_traitsIcE6lengthEPKc(203090)|0);
    $7 = ($6>>>0)>(4294967279);
    do {
     if ($7) {
      __THREW__ = 0;
      invoke_vi(3367,(215272|0));
      $8 = __THREW__; __THREW__ = 0;
     } else {
      $9 = ($6>>>0)<(11);
      if ($9) {
       $10 = $6&255;
       HEAP8[(215283)>>0] = $10;
       $$0$i$i = 215272;
      } else {
       $11 = (($6) + 16)|0;
       $12 = $11 & -16;
       __THREW__ = 0;
       $13 = (invoke_ii(3276,($12|0))|0);
       $14 = __THREW__; __THREW__ = 0;
       $15 = $14&1;
       if ($15) {
        break;
       }
       HEAP32[53818] = $13;
       $16 = $12 | -2147483648;
       HEAP32[(215280)>>2] = $16;
       HEAP32[(215276)>>2] = $6;
       $$0$i$i = $13;
      }
      (__ZNSt3__211char_traitsIcE4copyEPcPKcj($$0$i$i,203090,$6)|0);
      $17 = (($$0$i$i) + ($6)|0);
      HEAP8[$1>>0] = 0;
      __ZNSt3__211char_traitsIcE6assignERcRKc($17,$1);
      (___cxa_atexit((3252|0),(215272|0),(___dso_handle|0))|0);
      break L1;
     }
    } while(0);
    $18 = ___cxa_find_matching_catch_2()|0;
    $19 = tempRet0;
    ___resumeException($18|0);
    // unreachable;
   }
  }
 } while(0);
 STACKTOP = sp;return (215272|0);
}
function __ZNKSt3__220__time_get_c_storageIcE3__XEv($0) {
 $0 = $0|0;
 var $$0$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $2 = HEAP8[207048]|0;
 $3 = ($2<<24>>24)==(0);
 L1: do {
  if ($3) {
   $4 = (___cxa_guard_acquire(207048)|0);
   $5 = ($4|0)==(0);
   if (!($5)) {
    ;HEAP32[215260>>2]=0|0;HEAP32[215260+4>>2]=0|0;HEAP32[215260+8>>2]=0|0;
    $6 = (__ZNSt3__211char_traitsIcE6lengthEPKc(203081)|0);
    $7 = ($6>>>0)>(4294967279);
    do {
     if ($7) {
      __THREW__ = 0;
      invoke_vi(3367,(215260|0));
      $8 = __THREW__; __THREW__ = 0;
     } else {
      $9 = ($6>>>0)<(11);
      if ($9) {
       $10 = $6&255;
       HEAP8[(215271)>>0] = $10;
       $$0$i$i = 215260;
      } else {
       $11 = (($6) + 16)|0;
       $12 = $11 & -16;
       __THREW__ = 0;
       $13 = (invoke_ii(3276,($12|0))|0);
       $14 = __THREW__; __THREW__ = 0;
       $15 = $14&1;
       if ($15) {
        break;
       }
       HEAP32[53815] = $13;
       $16 = $12 | -2147483648;
       HEAP32[(215268)>>2] = $16;
       HEAP32[(215264)>>2] = $6;
       $$0$i$i = $13;
      }
      (__ZNSt3__211char_traitsIcE4copyEPcPKcj($$0$i$i,203081,$6)|0);
      $17 = (($$0$i$i) + ($6)|0);
      HEAP8[$1>>0] = 0;
      __ZNSt3__211char_traitsIcE6assignERcRKc($17,$1);
      (___cxa_atexit((3252|0),(215260|0),(___dso_handle|0))|0);
      break L1;
     }
    } while(0);
    $18 = ___cxa_find_matching_catch_2()|0;
    $19 = tempRet0;
    ___resumeException($18|0);
    // unreachable;
   }
  }
 } while(0);
 STACKTOP = sp;return (215260|0);
}
function __ZNSt3__2L10init_am_pmEv() {
 var $$0$i$i = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $exitcond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[207088]|0;
 $1 = ($0<<24>>24)==(0);
 if ($1) {
  $2 = (___cxa_guard_acquire(207088)|0);
  $3 = ($2|0)==(0);
  if (!($3)) {
   $4 = 215308;
   while(1) {
    ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;
    $$0$i$i = 0;
    while(1) {
     $exitcond$i$i = ($$0$i$i|0)==(3);
     if ($exitcond$i$i) {
      break;
     }
     $5 = (($4) + ($$0$i$i<<2)|0);
     HEAP32[$5>>2] = 0;
     $6 = (($$0$i$i) + 1)|0;
     $$0$i$i = $6;
    }
    $7 = ((($4)) + 12|0);
    $8 = ($7|0)==((215596)|0);
    if ($8) {
     break;
    } else {
     $4 = $7;
    }
   }
   (___cxa_atexit((4702|0),(0|0),(___dso_handle|0))|0);
  }
 }
 (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc(215308,203132)|0);
 (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc((215320),203135)|0);
 return;
}
function ___cxx_global_array_dtor_118($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (215596);
 while(1) {
  $1 = ((($2)) + -12|0);
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($1);
  $3 = ($1|0)==(215308|0);
  if ($3) {
   break;
  } else {
   $2 = $1;
  }
 }
 return;
}
function __ZNSt3__2L11init_monthsEv() {
 var $$0$i$i = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $exitcond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[207104]|0;
 $1 = ($0<<24>>24)==(0);
 if ($1) {
  $2 = (___cxa_guard_acquire(207104)|0);
  $3 = ($2|0)==(0);
  if (!($3)) {
   $4 = 215600;
   while(1) {
    ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;
    $$0$i$i = 0;
    while(1) {
     $exitcond$i$i = ($$0$i$i|0)==(3);
     if ($exitcond$i$i) {
      break;
     }
     $5 = (($4) + ($$0$i$i<<2)|0);
     HEAP32[$5>>2] = 0;
     $6 = (($$0$i$i) + 1)|0;
     $$0$i$i = $6;
    }
    $7 = ((($4)) + 12|0);
    $8 = ($7|0)==((215888)|0);
    if ($8) {
     break;
    } else {
     $4 = $7;
    }
   }
   (___cxa_atexit((4703|0),(0|0),(___dso_handle|0))|0);
  }
 }
 (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc(215600,203138)|0);
 (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc((215612),203146)|0);
 (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc((215624),203155)|0);
 (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc((215636),203161)|0);
 (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc((215648),203167)|0);
 (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc((215660),203171)|0);
 (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc((215672),203176)|0);
 (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc((215684),203181)|0);
 (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc((215696),203188)|0);
 (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc((215708),203198)|0);
 (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc((215720),203206)|0);
 (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc((215732),203215)|0);
 (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc((215744),203224)|0);
 (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc((215756),203228)|0);
 (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc((215768),203232)|0);
 (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc((215780),203236)|0);
 (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc((215792),203167)|0);
 (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc((215804),203240)|0);
 (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc((215816),203244)|0);
 (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc((215828),203248)|0);
 (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc((215840),203252)|0);
 (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc((215852),203256)|0);
 (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc((215864),203260)|0);
 (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc((215876),203264)|0);
 return;
}
function ___cxx_global_array_dtor_70($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (215888);
 while(1) {
  $1 = ((($2)) + -12|0);
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($1);
  $3 = ($1|0)==(215600|0);
  if ($3) {
   break;
  } else {
   $2 = $1;
  }
 }
 return;
}
function __ZNSt3__2L10init_weeksEv() {
 var $$0$i$i = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $exitcond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[207120]|0;
 $1 = ($0<<24>>24)==(0);
 if ($1) {
  $2 = (___cxa_guard_acquire(207120)|0);
  $3 = ($2|0)==(0);
  if (!($3)) {
   $4 = 215892;
   while(1) {
    ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;
    $$0$i$i = 0;
    while(1) {
     $exitcond$i$i = ($$0$i$i|0)==(3);
     if ($exitcond$i$i) {
      break;
     }
     $5 = (($4) + ($$0$i$i<<2)|0);
     HEAP32[$5>>2] = 0;
     $6 = (($$0$i$i) + 1)|0;
     $$0$i$i = $6;
    }
    $7 = ((($4)) + 12|0);
    $8 = ($7|0)==((216060)|0);
    if ($8) {
     break;
    } else {
     $4 = $7;
    }
   }
   (___cxa_atexit((4704|0),(0|0),(___dso_handle|0))|0);
  }
 }
 (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc(215892,203268)|0);
 (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc((215904),203275)|0);
 (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc((215916),203282)|0);
 (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc((215928),203290)|0);
 (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc((215940),203300)|0);
 (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc((215952),203309)|0);
 (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc((215964),203316)|0);
 (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc((215976),203325)|0);
 (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc((215988),203329)|0);
 (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc((216000),203333)|0);
 (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc((216012),203337)|0);
 (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc((216024),203341)|0);
 (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc((216036),203345)|0);
 (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc((216048),203349)|0);
 return;
}
function ___cxx_global_array_dtor($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (216060);
 while(1) {
  $1 = ((($2)) + -12|0);
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($1);
  $3 = ($1|0)==(215892|0);
  if ($3) {
   break;
  } else {
   $2 = $1;
  }
 }
 return;
}
function __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE17__get_weekdaynameERiRS4_S4_RjRKNS_5ctypeIcEE($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$byval_copy = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy = sp + 4|0;
 $6 = sp;
 $7 = ((($0)) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 $10 = (FUNCTION_TABLE_ii[$9 & 8191]($7)|0);
 $11 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $11;
 $12 = ((($10)) + 168|0);
 ;HEAP32[$$byval_copy>>2]=HEAP32[$6>>2]|0;
 $13 = (__ZNSt3__214__scan_keywordINS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEPKNS_12basic_stringIcS3_NS_9allocatorIcEEEENS_5ctypeIcEEEET0_RT_SE_SD_SD_RKT1_Rjb($2,$$byval_copy,$10,$12,$5,$4,0)|0);
 $14 = $13;
 $15 = $10;
 $16 = (($14) - ($15))|0;
 $17 = ($16|0)<(168);
 if ($17) {
  $18 = (($16|0) / 12)&-1;
  $19 = (($18|0) % 7)&-1;
  HEAP32[$1>>2] = $19;
 }
 STACKTOP = sp;return;
}
function __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE15__get_monthnameERiRS4_S4_RjRKNS_5ctypeIcEE($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$byval_copy = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy = sp + 4|0;
 $6 = sp;
 $7 = ((($0)) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($8)) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (FUNCTION_TABLE_ii[$10 & 8191]($7)|0);
 $12 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $12;
 $13 = ((($11)) + 288|0);
 ;HEAP32[$$byval_copy>>2]=HEAP32[$6>>2]|0;
 $14 = (__ZNSt3__214__scan_keywordINS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEPKNS_12basic_stringIcS3_NS_9allocatorIcEEEENS_5ctypeIcEEEET0_RT_SE_SD_SD_RKT1_Rjb($2,$$byval_copy,$11,$13,$5,$4,0)|0);
 $15 = $14;
 $16 = $11;
 $17 = (($15) - ($16))|0;
 $18 = ($17|0)<(288);
 if ($18) {
  $19 = (($17|0) / 12)&-1;
  $20 = (($19|0) % 12)&-1;
  HEAP32[$1>>2] = $20;
 }
 STACKTOP = sp;return;
}
function __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjP2tmPKcSC_($0,$1,$2,$3,$4,$5,$6,$7) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 var $$0$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i55 = 0, $$0$i$i$i$i71 = 0, $$0$i$i2$i$i = 0, $$0$i$i2$i$i61 = 0, $$0$i$i2$i$i77 = 0, $$0$i$i68 = 0, $$0$ph = 0, $$0$ph$be = 0, $$0$ph$sink = 0, $$051 = 0, $$052 = 0, $$byval_copy = 0, $$byval_copy1 = 0, $$lcssa = 0, $$ph = 0, $$pre = 0, $$pre$i$i$i57 = 0, $$pre$i$i$i73 = 0;
 var $$pre$i4$i$i63 = 0, $$pre$i4$i$i63100 = 0, $$pre$i4$i$i63101 = 0, $$pre$pre = 0, $$sroa$049$0$copyload = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0;
 var $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0;
 var $phitmp$i5$i$i64 = 0, $sext = 0, $tmp$i$i66 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $$byval_copy1 = sp + 16|0;
 $$byval_copy = sp + 12|0;
 $8 = sp + 8|0;
 $9 = sp + 4|0;
 $10 = sp;
 __ZNKSt3__28ios_base6getlocEv($8,$3);
 __THREW__ = 0;
 $11 = (invoke_iii(3255,($8|0),(215188|0))|0);
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $50 = ___cxa_find_matching_catch_2()|0;
  $51 = tempRet0;
  __ZNSt3__26localeD2Ev($8);
  ___resumeException($50|0);
  // unreachable;
 }
 __ZNSt3__26localeD2Ev($8);
 HEAP32[$4>>2] = 0;
 $14 = ((($11)) + 8|0);
 $$0$ph = $6;$$pre = 0;
 L4: while(1) {
  $15 = ($$0$ph|0)!=($7|0);
  $16 = $$pre;
  while(1) {
   $17 = ($16|0)==(0);
   $or$cond = $15 & $17;
   $18 = HEAP32[$1>>2]|0;
   if (!($or$cond)) {
    $$pre$i$i$i73 = $18;
    break L4;
   }
   $19 = ($18|0)==(0|0);
   $20 = $18;
   if ($19) {
    $156 = 0;$218 = 1;$75 = $20;
   } else {
    $21 = ((($18)) + 12|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = ((($18)) + 16|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = ($22|0)==($24|0);
    if ($25) {
     $26 = HEAP32[$18>>2]|0;
     $27 = ((($26)) + 36|0);
     $28 = HEAP32[$27>>2]|0;
     $29 = (FUNCTION_TABLE_ii[$28 & 8191]($18)|0);
     $$0$i$i$i$i = $29;
    } else {
     $30 = HEAP8[$22>>0]|0;
     $31 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($30)|0);
     $$0$i$i$i$i = $31;
    }
    $32 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
    $33 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i$i$i,$32)|0);
    if ($33) {
     HEAP32[$1>>2] = 0;
     $156 = 0;$218 = 1;$75 = 0;
    } else {
     $156 = $18;$218 = 0;$75 = $20;
    }
   }
   $34 = HEAP32[$2>>2]|0;
   $35 = ($34|0)==(0|0);
   $36 = $34;
   do {
    if ($35) {
     $$ph = $36;
     label = 17;
    } else {
     $37 = ((($34)) + 12|0);
     $38 = HEAP32[$37>>2]|0;
     $39 = ((($34)) + 16|0);
     $40 = HEAP32[$39>>2]|0;
     $41 = ($38|0)==($40|0);
     if ($41) {
      $42 = HEAP32[$34>>2]|0;
      $43 = ((($42)) + 36|0);
      $44 = HEAP32[$43>>2]|0;
      $45 = (FUNCTION_TABLE_ii[$44 & 8191]($34)|0);
      $$0$i$i2$i$i = $45;
     } else {
      $46 = HEAP8[$38>>0]|0;
      $47 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($46)|0);
      $$0$i$i2$i$i = $47;
     }
     $48 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
     $49 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i2$i$i,$48)|0);
     if ($49) {
      HEAP32[$2>>2] = 0;
      $$ph = 0;
      label = 17;
      break;
     } else {
      if ($218) {
       $219 = $34;$76 = $36;
       break;
      } else {
       label = 63;
       break L4;
      }
     }
    }
   } while(0);
   if ((label|0) == 17) {
    label = 0;
    if ($218) {
     label = 63;
     break L4;
    } else {
     $219 = 0;$76 = $$ph;
    }
   }
   $52 = HEAP8[$$0$ph>>0]|0;
   $53 = HEAP32[$11>>2]|0;
   $54 = ((($53)) + 36|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = (FUNCTION_TABLE_iiii[$55 & 8191]($11,$52,0)|0);
   $57 = ($56<<24>>24)==(37);
   if ($57) {
    label = 21;
    break;
   }
   $80 = HEAP8[$$0$ph>>0]|0;
   $81 = ($80<<24>>24)>(-1);
   if ($81) {
    $82 = $80 << 24 >> 24;
    $83 = HEAP32[$14>>2]|0;
    $84 = (($83) + ($82<<1)|0);
    $85 = HEAP16[$84>>1]|0;
    $86 = $85 & 8192;
    $87 = ($86<<16>>16)==(0);
    if (!($87)) {
     $$0$ph$sink = $$0$ph;
     label = 29;
     break;
    }
   }
   $155 = ((($156)) + 12|0);
   $157 = HEAP32[$155>>2]|0;
   $158 = ((($156)) + 16|0);
   $159 = HEAP32[$158>>2]|0;
   $160 = ($157|0)==($159|0);
   if ($160) {
    $161 = HEAP32[$156>>2]|0;
    $162 = ((($161)) + 36|0);
    $163 = HEAP32[$162>>2]|0;
    $164 = (FUNCTION_TABLE_ii[$163 & 8191]($156)|0);
    $$0$i$i68 = $164;
   } else {
    $165 = HEAP8[$157>>0]|0;
    $166 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($165)|0);
    $$0$i$i68 = $166;
   }
   $167 = $$0$i$i68&255;
   $168 = HEAP32[$11>>2]|0;
   $169 = ((($168)) + 12|0);
   $170 = HEAP32[$169>>2]|0;
   $171 = (FUNCTION_TABLE_iii[$170 & 8191]($11,$167)|0);
   $172 = HEAP8[$$0$ph>>0]|0;
   $173 = HEAP32[$11>>2]|0;
   $174 = ((($173)) + 12|0);
   $175 = HEAP32[$174>>2]|0;
   $176 = (FUNCTION_TABLE_iii[$175 & 8191]($11,$172)|0);
   $177 = ($171<<24>>24)==($176<<24>>24);
   if ($177) {
    label = 59;
    break;
   }
   HEAP32[$4>>2] = 4;
   $16 = 4;
  }
  L38: do {
   if ((label|0) == 21) {
    label = 0;
    $58 = ((($$0$ph)) + 1|0);
    $59 = ($58|0)==($7|0);
    if ($59) {
     label = 63;
     break L4;
    }
    $60 = HEAP8[$58>>0]|0;
    $61 = HEAP32[$11>>2]|0;
    $62 = ((($61)) + 36|0);
    $63 = HEAP32[$62>>2]|0;
    $64 = (FUNCTION_TABLE_iiii[$63 & 8191]($11,$60,0)|0);
    switch ($64<<24>>24) {
    case 48: case 69:  {
     $65 = ((($$0$ph)) + 2|0);
     $66 = ($65|0)==($7|0);
     if ($66) {
      label = 63;
      break L4;
     }
     $67 = HEAP8[$65>>0]|0;
     $68 = HEAP32[$11>>2]|0;
     $69 = ((($68)) + 36|0);
     $70 = HEAP32[$69>>2]|0;
     $71 = (FUNCTION_TABLE_iiii[$70 & 8191]($11,$67,0)|0);
     $$051 = $64;$$052 = $71;$79 = $58;
     break;
    }
    default: {
     $$051 = 0;$$052 = $64;$79 = $$0$ph;
    }
    }
    $72 = HEAP32[$0>>2]|0;
    $73 = ((($72)) + 36|0);
    $74 = HEAP32[$73>>2]|0;
    HEAP32[$9>>2] = $75;
    HEAP32[$10>>2] = $76;
    ;HEAP32[$$byval_copy>>2]=HEAP32[$9>>2]|0;
    ;HEAP32[$$byval_copy1>>2]=HEAP32[$10>>2]|0;
    $77 = (FUNCTION_TABLE_iiiiiiiii[$74 & 8191]($0,$$byval_copy,$$byval_copy1,$3,$4,$5,$$052,$$051)|0);
    HEAP32[$1>>2] = $77;
    $78 = ((($79)) + 2|0);
    $$0$ph$be = $78;
   }
   else if ((label|0) == 29) {
    while(1) {
     label = 0;
     $88 = ((($$0$ph$sink)) + 1|0);
     $89 = ($88|0)==($7|0);
     if ($89) {
      $$lcssa = $7;
      break;
     }
     $90 = HEAP8[$88>>0]|0;
     $91 = ($90<<24>>24)>(-1);
     if (!($91)) {
      $$lcssa = $88;
      break;
     }
     $92 = $90 << 24 >> 24;
     $93 = (($83) + ($92<<1)|0);
     $94 = HEAP16[$93>>1]|0;
     $95 = $94 & 8192;
     $96 = ($95<<16>>16)==(0);
     if ($96) {
      $$lcssa = $88;
      break;
     } else {
      $$0$ph$sink = $88;
      label = 29;
     }
    }
    $$pre$i$i$i57 = $156;$$pre$i4$i$i63 = $219;$111 = $219;
    while(1) {
     $97 = ($$pre$i$i$i57|0)==(0|0);
     if ($97) {
      $126 = 1;$128 = 0;
     } else {
      $98 = ((($$pre$i$i$i57)) + 12|0);
      $99 = HEAP32[$98>>2]|0;
      $100 = ((($$pre$i$i$i57)) + 16|0);
      $101 = HEAP32[$100>>2]|0;
      $102 = ($99|0)==($101|0);
      if ($102) {
       $103 = HEAP32[$$pre$i$i$i57>>2]|0;
       $104 = ((($103)) + 36|0);
       $105 = HEAP32[$104>>2]|0;
       $106 = (FUNCTION_TABLE_ii[$105 & 8191]($$pre$i$i$i57)|0);
       $$0$i$i$i$i55 = $106;
      } else {
       $107 = HEAP8[$99>>0]|0;
       $108 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($107)|0);
       $$0$i$i$i$i55 = $108;
      }
      $109 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
      $110 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i$i$i55,$109)|0);
      if ($110) {
       HEAP32[$1>>2] = 0;
       $126 = 1;$128 = 0;
      } else {
       $126 = 0;$128 = $$pre$i$i$i57;
      }
     }
     $112 = ($111|0)==(0|0);
     do {
      if ($112) {
       $$pre$i4$i$i63101 = $$pre$i4$i$i63;
       label = 45;
      } else {
       $113 = ((($111)) + 12|0);
       $114 = HEAP32[$113>>2]|0;
       $115 = ((($111)) + 16|0);
       $116 = HEAP32[$115>>2]|0;
       $117 = ($114|0)==($116|0);
       if ($117) {
        $118 = HEAP32[$111>>2]|0;
        $119 = ((($118)) + 36|0);
        $120 = HEAP32[$119>>2]|0;
        $121 = (FUNCTION_TABLE_ii[$120 & 8191]($111)|0);
        $$0$i$i2$i$i61 = $121;
       } else {
        $122 = HEAP8[$114>>0]|0;
        $123 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($122)|0);
        $$0$i$i2$i$i61 = $123;
       }
       $124 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
       $125 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i2$i$i61,$124)|0);
       if ($125) {
        HEAP32[$2>>2] = 0;
        $$pre$i4$i$i63101 = 0;
        label = 45;
        break;
       } else {
        $phitmp$i5$i$i64 = ($$pre$i4$i$i63|0)==(0|0);
        $tmp$i$i66 = $126 ^ $phitmp$i5$i$i64;
        if ($tmp$i$i66) {
         $$pre$i4$i$i63100 = $$pre$i4$i$i63;$220 = $$pre$i4$i$i63;
         break;
        } else {
         $$0$ph$be = $$lcssa;
         break L38;
        }
       }
      }
     } while(0);
     if ((label|0) == 45) {
      label = 0;
      if ($126) {
       $$0$ph$be = $$lcssa;
       break L38;
      } else {
       $$pre$i4$i$i63100 = $$pre$i4$i$i63101;$220 = 0;
      }
     }
     $127 = ((($128)) + 12|0);
     $129 = HEAP32[$127>>2]|0;
     $130 = ((($128)) + 16|0);
     $131 = HEAP32[$130>>2]|0;
     $132 = ($129|0)==($131|0);
     if ($132) {
      $133 = HEAP32[$128>>2]|0;
      $134 = ((($133)) + 36|0);
      $135 = HEAP32[$134>>2]|0;
      $136 = (FUNCTION_TABLE_ii[$135 & 8191]($128)|0);
      $$0$i$i = $136;
     } else {
      $137 = HEAP8[$129>>0]|0;
      $138 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($137)|0);
      $$0$i$i = $138;
     }
     $139 = $$0$i$i&255;
     $140 = ($139<<24>>24)>(-1);
     if (!($140)) {
      $$0$ph$be = $$lcssa;
      break L38;
     }
     $sext = $$0$i$i << 24;
     $141 = $sext >> 24;
     $142 = HEAP32[$14>>2]|0;
     $143 = (($142) + ($141<<1)|0);
     $144 = HEAP16[$143>>1]|0;
     $145 = $144 & 8192;
     $146 = ($145<<16>>16)==(0);
     if ($146) {
      $$0$ph$be = $$lcssa;
      break L38;
     }
     $147 = HEAP32[$127>>2]|0;
     $148 = HEAP32[$130>>2]|0;
     $149 = ($147|0)==($148|0);
     if ($149) {
      $150 = HEAP32[$128>>2]|0;
      $151 = ((($150)) + 40|0);
      $152 = HEAP32[$151>>2]|0;
      (FUNCTION_TABLE_ii[$152 & 8191]($128)|0);
      $$pre$i$i$i57 = $128;$$pre$i4$i$i63 = $$pre$i4$i$i63100;$111 = $220;
      continue;
     } else {
      $153 = ((($147)) + 1|0);
      HEAP32[$127>>2] = $153;
      $154 = HEAP8[$147>>0]|0;
      (__ZNSt3__211char_traitsIcE11to_int_typeEc($154)|0);
      $$pre$i$i$i57 = $128;$$pre$i4$i$i63 = $$pre$i4$i$i63100;$111 = $220;
      continue;
     }
    }
   }
   else if ((label|0) == 59) {
    label = 0;
    $178 = ((($$0$ph)) + 1|0);
    $179 = HEAP32[$155>>2]|0;
    $180 = HEAP32[$158>>2]|0;
    $181 = ($179|0)==($180|0);
    if ($181) {
     $182 = HEAP32[$156>>2]|0;
     $183 = ((($182)) + 40|0);
     $184 = HEAP32[$183>>2]|0;
     (FUNCTION_TABLE_ii[$184 & 8191]($156)|0);
     $$0$ph$be = $178;
     break;
    } else {
     $185 = ((($179)) + 1|0);
     HEAP32[$155>>2] = $185;
     $186 = HEAP8[$179>>0]|0;
     (__ZNSt3__211char_traitsIcE11to_int_typeEc($186)|0);
     $$0$ph$be = $178;
     break;
    }
   }
  } while(0);
  $$pre$pre = HEAP32[$4>>2]|0;
  $$0$ph = $$0$ph$be;$$pre = $$pre$pre;
 }
 if ((label|0) == 63) {
  HEAP32[$4>>2] = 4;
  $$pre$i$i$i73 = $156;
 }
 $187 = ($$pre$i$i$i73|0)==(0|0);
 if ($187) {
  $$sroa$049$0$copyload = 0;$221 = 1;
 } else {
  $188 = ((($$pre$i$i$i73)) + 12|0);
  $189 = HEAP32[$188>>2]|0;
  $190 = ((($$pre$i$i$i73)) + 16|0);
  $191 = HEAP32[$190>>2]|0;
  $192 = ($189|0)==($191|0);
  if ($192) {
   $193 = HEAP32[$$pre$i$i$i73>>2]|0;
   $194 = ((($193)) + 36|0);
   $195 = HEAP32[$194>>2]|0;
   $196 = (FUNCTION_TABLE_ii[$195 & 8191]($$pre$i$i$i73)|0);
   $$0$i$i$i$i71 = $196;
  } else {
   $197 = HEAP8[$189>>0]|0;
   $198 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($197)|0);
   $$0$i$i$i$i71 = $198;
  }
  $199 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
  $200 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i$i$i71,$199)|0);
  if ($200) {
   HEAP32[$1>>2] = 0;
   $$sroa$049$0$copyload = 0;$221 = 1;
  } else {
   $$sroa$049$0$copyload = $$pre$i$i$i73;$221 = 0;
  }
 }
 $201 = HEAP32[$2>>2]|0;
 $202 = ($201|0)==(0|0);
 do {
  if ($202) {
   label = 76;
  } else {
   $203 = ((($201)) + 12|0);
   $204 = HEAP32[$203>>2]|0;
   $205 = ((($201)) + 16|0);
   $206 = HEAP32[$205>>2]|0;
   $207 = ($204|0)==($206|0);
   if ($207) {
    $208 = HEAP32[$201>>2]|0;
    $209 = ((($208)) + 36|0);
    $210 = HEAP32[$209>>2]|0;
    $211 = (FUNCTION_TABLE_ii[$210 & 8191]($201)|0);
    $$0$i$i2$i$i77 = $211;
   } else {
    $212 = HEAP8[$204>>0]|0;
    $213 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($212)|0);
    $$0$i$i2$i$i77 = $213;
   }
   $214 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
   $215 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i2$i$i77,$214)|0);
   if ($215) {
    HEAP32[$2>>2] = 0;
    label = 76;
    break;
   } else {
    if ($221) {
     break;
    } else {
     label = 78;
     break;
    }
   }
  }
 } while(0);
 if ((label|0) == 76) {
  if ($221) {
   label = 78;
  }
 }
 if ((label|0) == 78) {
  $216 = HEAP32[$4>>2]|0;
  $217 = $216 | 2;
  HEAP32[$4>>2] = $217;
 }
 STACKTOP = sp;return ($$sroa$049$0$copyload|0);
}
function __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE9__get_dayERiRS4_S4_RjRKNS_5ctypeIcEE($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$byval_copy = 0, $$off = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy = sp + 4|0;
 $6 = sp;
 $7 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $7;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$6>>2]|0;
 $8 = (__ZNSt3__220__get_up_to_n_digitsIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEiRT0_S5_RjRKNS_5ctypeIT_EEi($2,$$byval_copy,$4,$5,2)|0);
 $9 = HEAP32[$4>>2]|0;
 $10 = $9 & 4;
 $11 = ($10|0)==(0);
 $$off = (($8) + -1)|0;
 $12 = ($$off>>>0)<(31);
 $13 = $12 & $11;
 if ($13) {
  HEAP32[$1>>2] = $8;
 } else {
  $14 = $9 | 4;
  HEAP32[$4>>2] = $14;
 }
 STACKTOP = sp;return;
}
function __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE10__get_hourERiRS4_S4_RjRKNS_5ctypeIcEE($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$byval_copy = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy = sp + 4|0;
 $6 = sp;
 $7 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $7;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$6>>2]|0;
 $8 = (__ZNSt3__220__get_up_to_n_digitsIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEiRT0_S5_RjRKNS_5ctypeIT_EEi($2,$$byval_copy,$4,$5,2)|0);
 $9 = HEAP32[$4>>2]|0;
 $10 = $9 & 4;
 $11 = ($10|0)==(0);
 $12 = ($8|0)<(24);
 $or$cond = $12 & $11;
 if ($or$cond) {
  HEAP32[$1>>2] = $8;
 } else {
  $13 = $9 | 4;
  HEAP32[$4>>2] = $13;
 }
 STACKTOP = sp;return;
}
function __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE13__get_12_hourERiRS4_S4_RjRKNS_5ctypeIcEE($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$byval_copy = 0, $$off = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy = sp + 4|0;
 $6 = sp;
 $7 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $7;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$6>>2]|0;
 $8 = (__ZNSt3__220__get_up_to_n_digitsIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEiRT0_S5_RjRKNS_5ctypeIT_EEi($2,$$byval_copy,$4,$5,2)|0);
 $9 = HEAP32[$4>>2]|0;
 $10 = $9 & 4;
 $11 = ($10|0)==(0);
 $$off = (($8) + -1)|0;
 $12 = ($$off>>>0)<(12);
 $13 = $12 & $11;
 if ($13) {
  HEAP32[$1>>2] = $8;
 } else {
  $14 = $9 | 4;
  HEAP32[$4>>2] = $14;
 }
 STACKTOP = sp;return;
}
function __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE18__get_day_year_numERiRS4_S4_RjRKNS_5ctypeIcEE($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$byval_copy = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy = sp + 4|0;
 $6 = sp;
 $7 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $7;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$6>>2]|0;
 $8 = (__ZNSt3__220__get_up_to_n_digitsIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEiRT0_S5_RjRKNS_5ctypeIT_EEi($2,$$byval_copy,$4,$5,3)|0);
 $9 = HEAP32[$4>>2]|0;
 $10 = $9 & 4;
 $11 = ($10|0)==(0);
 $12 = ($8|0)<(366);
 $or$cond = $12 & $11;
 if ($or$cond) {
  HEAP32[$1>>2] = $8;
 } else {
  $13 = $9 | 4;
  HEAP32[$4>>2] = $13;
 }
 STACKTOP = sp;return;
}
function __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE11__get_monthERiRS4_S4_RjRKNS_5ctypeIcEE($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$byval_copy = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy = sp + 4|0;
 $6 = sp;
 $7 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $7;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$6>>2]|0;
 $8 = (__ZNSt3__220__get_up_to_n_digitsIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEiRT0_S5_RjRKNS_5ctypeIT_EEi($2,$$byval_copy,$4,$5,2)|0);
 $9 = HEAP32[$4>>2]|0;
 $10 = $9 & 4;
 $11 = ($10|0)==(0);
 $12 = ($8|0)<(13);
 $or$cond = $12 & $11;
 if ($or$cond) {
  $13 = (($8) + -1)|0;
  HEAP32[$1>>2] = $13;
 } else {
  $14 = $9 | 4;
  HEAP32[$4>>2] = $14;
 }
 STACKTOP = sp;return;
}
function __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE12__get_minuteERiRS4_S4_RjRKNS_5ctypeIcEE($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$byval_copy = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy = sp + 4|0;
 $6 = sp;
 $7 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $7;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$6>>2]|0;
 $8 = (__ZNSt3__220__get_up_to_n_digitsIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEiRT0_S5_RjRKNS_5ctypeIT_EEi($2,$$byval_copy,$4,$5,2)|0);
 $9 = HEAP32[$4>>2]|0;
 $10 = $9 & 4;
 $11 = ($10|0)==(0);
 $12 = ($8|0)<(60);
 $or$cond = $12 & $11;
 if ($or$cond) {
  HEAP32[$1>>2] = $8;
 } else {
  $13 = $9 | 4;
  HEAP32[$4>>2] = $13;
 }
 STACKTOP = sp;return;
}
function __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE17__get_white_spaceERS4_S4_RjRKNS_5ctypeIcEE($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i7 = 0, $$0$i$i2$i$i = 0, $$0$i$i2$i$i13 = 0, $$pre$i$i$i = 0, $$pre$i$i$i9 = 0, $$pre$i4$i$i15 = 0, $10 = 0, $100 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $phitmp$i$i$i = 0, $phitmp$i$i$i10 = 0, $sext = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = ((($4)) + 8|0);
 L1: while(1) {
  $6 = HEAP32[$1>>2]|0;
  $7 = ($6|0)==(0|0);
  do {
   if ($7) {
    $98 = 1;
   } else {
    $8 = ((($6)) + 12|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = ((($6)) + 16|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($9|0)==($11|0);
    if ($12) {
     $13 = HEAP32[$6>>2]|0;
     $14 = ((($13)) + 36|0);
     $15 = HEAP32[$14>>2]|0;
     $16 = (FUNCTION_TABLE_ii[$15 & 8191]($6)|0);
     $$0$i$i$i$i = $16;
    } else {
     $17 = HEAP8[$9>>0]|0;
     $18 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($17)|0);
     $$0$i$i$i$i = $18;
    }
    $19 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
    $20 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i$i$i,$19)|0);
    if ($20) {
     HEAP32[$1>>2] = 0;
     $98 = 1;
     break;
    } else {
     $$pre$i$i$i = HEAP32[$1>>2]|0;
     $phitmp$i$i$i = ($$pre$i$i$i|0)==(0|0);
     $98 = $phitmp$i$i$i;
     break;
    }
   }
  } while(0);
  $21 = HEAP32[$2>>2]|0;
  $22 = ($21|0)==(0|0);
  do {
   if ($22) {
    label = 15;
   } else {
    $23 = ((($21)) + 12|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = ((($21)) + 16|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = ($24|0)==($26|0);
    if ($27) {
     $28 = HEAP32[$21>>2]|0;
     $29 = ((($28)) + 36|0);
     $30 = HEAP32[$29>>2]|0;
     $31 = (FUNCTION_TABLE_ii[$30 & 8191]($21)|0);
     $$0$i$i2$i$i = $31;
    } else {
     $32 = HEAP8[$24>>0]|0;
     $33 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($32)|0);
     $$0$i$i2$i$i = $33;
    }
    $34 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
    $35 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i2$i$i,$34)|0);
    if ($35) {
     HEAP32[$2>>2] = 0;
     label = 15;
     break;
    } else {
     if ($98) {
      $99 = $21;
      break;
     } else {
      $$pre$i4$i$i15 = $21;
      break L1;
     }
    }
   }
  } while(0);
  if ((label|0) == 15) {
   label = 0;
   if ($98) {
    $$pre$i4$i$i15 = 0;
    break;
   } else {
    $99 = 0;
   }
  }
  $36 = HEAP32[$1>>2]|0;
  $37 = ((($36)) + 12|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = ((($36)) + 16|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = ($38|0)==($40|0);
  if ($41) {
   $42 = HEAP32[$36>>2]|0;
   $43 = ((($42)) + 36|0);
   $44 = HEAP32[$43>>2]|0;
   $45 = (FUNCTION_TABLE_ii[$44 & 8191]($36)|0);
   $$0$i$i = $45;
  } else {
   $46 = HEAP8[$38>>0]|0;
   $47 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($46)|0);
   $$0$i$i = $47;
  }
  $48 = $$0$i$i&255;
  $49 = ($48<<24>>24)>(-1);
  if (!($49)) {
   $$pre$i4$i$i15 = $99;
   break;
  }
  $sext = $$0$i$i << 24;
  $50 = $sext >> 24;
  $51 = HEAP32[$5>>2]|0;
  $52 = (($51) + ($50<<1)|0);
  $53 = HEAP16[$52>>1]|0;
  $54 = $53 & 8192;
  $55 = ($54<<16>>16)==(0);
  if ($55) {
   $$pre$i4$i$i15 = $99;
   break;
  }
  $56 = HEAP32[$1>>2]|0;
  $57 = ((($56)) + 12|0);
  $58 = HEAP32[$57>>2]|0;
  $59 = ((($56)) + 16|0);
  $60 = HEAP32[$59>>2]|0;
  $61 = ($58|0)==($60|0);
  if ($61) {
   $62 = HEAP32[$56>>2]|0;
   $63 = ((($62)) + 40|0);
   $64 = HEAP32[$63>>2]|0;
   (FUNCTION_TABLE_ii[$64 & 8191]($56)|0);
   continue;
  } else {
   $65 = ((($58)) + 1|0);
   HEAP32[$57>>2] = $65;
   $66 = HEAP8[$58>>0]|0;
   (__ZNSt3__211char_traitsIcE11to_int_typeEc($66)|0);
   continue;
  }
 }
 $67 = HEAP32[$1>>2]|0;
 $68 = ($67|0)==(0|0);
 do {
  if ($68) {
   $100 = 1;
  } else {
   $69 = ((($67)) + 12|0);
   $70 = HEAP32[$69>>2]|0;
   $71 = ((($67)) + 16|0);
   $72 = HEAP32[$71>>2]|0;
   $73 = ($70|0)==($72|0);
   if ($73) {
    $74 = HEAP32[$67>>2]|0;
    $75 = ((($74)) + 36|0);
    $76 = HEAP32[$75>>2]|0;
    $77 = (FUNCTION_TABLE_ii[$76 & 8191]($67)|0);
    $$0$i$i$i$i7 = $77;
   } else {
    $78 = HEAP8[$70>>0]|0;
    $79 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($78)|0);
    $$0$i$i$i$i7 = $79;
   }
   $80 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
   $81 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i$i$i7,$80)|0);
   if ($81) {
    HEAP32[$1>>2] = 0;
    $100 = 1;
    break;
   } else {
    $$pre$i$i$i9 = HEAP32[$1>>2]|0;
    $phitmp$i$i$i10 = ($$pre$i$i$i9|0)==(0|0);
    $100 = $phitmp$i$i$i10;
    break;
   }
  }
 } while(0);
 $82 = ($$pre$i4$i$i15|0)==(0|0);
 do {
  if ($82) {
   label = 38;
  } else {
   $83 = ((($$pre$i4$i$i15)) + 12|0);
   $84 = HEAP32[$83>>2]|0;
   $85 = ((($$pre$i4$i$i15)) + 16|0);
   $86 = HEAP32[$85>>2]|0;
   $87 = ($84|0)==($86|0);
   if ($87) {
    $88 = HEAP32[$$pre$i4$i$i15>>2]|0;
    $89 = ((($88)) + 36|0);
    $90 = HEAP32[$89>>2]|0;
    $91 = (FUNCTION_TABLE_ii[$90 & 8191]($$pre$i4$i$i15)|0);
    $$0$i$i2$i$i13 = $91;
   } else {
    $92 = HEAP8[$84>>0]|0;
    $93 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($92)|0);
    $$0$i$i2$i$i13 = $93;
   }
   $94 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
   $95 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i2$i$i13,$94)|0);
   if ($95) {
    HEAP32[$2>>2] = 0;
    label = 38;
    break;
   } else {
    if ($100) {
     break;
    } else {
     label = 40;
     break;
    }
   }
  }
 } while(0);
 if ((label|0) == 38) {
  if ($100) {
   label = 40;
  }
 }
 if ((label|0) == 40) {
  $96 = HEAP32[$3>>2]|0;
  $97 = $96 | 2;
  HEAP32[$3>>2] = $97;
 }
 return;
}
function __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE11__get_am_pmERiRS4_S4_RjRKNS_5ctypeIcEE($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$byval_copy = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond20 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy = sp + 4|0;
 $6 = sp;
 $7 = ((($0)) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($8)) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (FUNCTION_TABLE_ii[$10 & 8191]($7)|0);
 $12 = ((($11)) + 11|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = ($13<<24>>24)<(0);
 if ($14) {
  $15 = ((($11)) + 4|0);
  $16 = HEAP32[$15>>2]|0;
  $27 = $16;
 } else {
  $17 = $13&255;
  $27 = $17;
 }
 $18 = ((($11)) + 12|0);
 $19 = ((($18)) + 11|0);
 $20 = HEAP8[$19>>0]|0;
 $21 = ($20<<24>>24)<(0);
 if ($21) {
  $22 = ((($11)) + 16|0);
  $23 = HEAP32[$22>>2]|0;
  $26 = $23;
 } else {
  $24 = $20&255;
  $26 = $24;
 }
 $25 = (0 - ($26))|0;
 $28 = ($27|0)==($25|0);
 do {
  if ($28) {
   $29 = HEAP32[$4>>2]|0;
   $30 = $29 | 4;
   HEAP32[$4>>2] = $30;
  } else {
   $31 = HEAP32[$3>>2]|0;
   HEAP32[$6>>2] = $31;
   $32 = ((($11)) + 24|0);
   ;HEAP32[$$byval_copy>>2]=HEAP32[$6>>2]|0;
   $33 = (__ZNSt3__214__scan_keywordINS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEPKNS_12basic_stringIcS3_NS_9allocatorIcEEEENS_5ctypeIcEEEET0_RT_SE_SD_SD_RKT1_Rjb($2,$$byval_copy,$11,$32,$5,$4,0)|0);
   $34 = $33;
   $35 = $11;
   $36 = (($34) - ($35))|0;
   $37 = ($36|0)==(0);
   $38 = HEAP32[$1>>2]|0;
   $39 = ($38|0)==(12);
   $or$cond = $39 & $37;
   if ($or$cond) {
    HEAP32[$1>>2] = 0;
    break;
   }
   $40 = ($36|0)==(12);
   $41 = ($38|0)<(12);
   $or$cond20 = $41 & $40;
   if ($or$cond20) {
    $42 = (($38) + 12)|0;
    HEAP32[$1>>2] = $42;
   }
  }
 } while(0);
 STACKTOP = sp;return;
}
function __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE12__get_secondERiRS4_S4_RjRKNS_5ctypeIcEE($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$byval_copy = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy = sp + 4|0;
 $6 = sp;
 $7 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $7;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$6>>2]|0;
 $8 = (__ZNSt3__220__get_up_to_n_digitsIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEiRT0_S5_RjRKNS_5ctypeIT_EEi($2,$$byval_copy,$4,$5,2)|0);
 $9 = HEAP32[$4>>2]|0;
 $10 = $9 & 4;
 $11 = ($10|0)==(0);
 $12 = ($8|0)<(61);
 $or$cond = $12 & $11;
 if ($or$cond) {
  HEAP32[$1>>2] = $8;
 } else {
  $13 = $9 | 4;
  HEAP32[$4>>2] = $13;
 }
 STACKTOP = sp;return;
}
function __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE13__get_weekdayERiRS4_S4_RjRKNS_5ctypeIcEE($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$byval_copy = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy = sp + 4|0;
 $6 = sp;
 $7 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $7;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$6>>2]|0;
 $8 = (__ZNSt3__220__get_up_to_n_digitsIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEiRT0_S5_RjRKNS_5ctypeIT_EEi($2,$$byval_copy,$4,$5,1)|0);
 $9 = HEAP32[$4>>2]|0;
 $10 = $9 & 4;
 $11 = ($10|0)==(0);
 $12 = ($8|0)<(7);
 $or$cond = $12 & $11;
 if ($or$cond) {
  HEAP32[$1>>2] = $8;
 } else {
  $13 = $9 | 4;
  HEAP32[$4>>2] = $13;
 }
 STACKTOP = sp;return;
}
function __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE10__get_yearERiRS4_S4_RjRKNS_5ctypeIcEE($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$ = 0, $$0 = 0, $$byval_copy = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy = sp + 4|0;
 $6 = sp;
 $7 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $7;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$6>>2]|0;
 $8 = (__ZNSt3__220__get_up_to_n_digitsIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEiRT0_S5_RjRKNS_5ctypeIT_EEi($2,$$byval_copy,$4,$5,4)|0);
 $9 = HEAP32[$4>>2]|0;
 $10 = $9 & 4;
 $11 = ($10|0)==(0);
 if ($11) {
  $12 = ($8|0)<(69);
  if ($12) {
   $13 = (($8) + 2000)|0;
   $$0 = $13;
  } else {
   $14 = ($8|0)<(100);
   $15 = (($8) + 1900)|0;
   $$ = $14 ? $15 : $8;
   $$0 = $$;
  }
  $16 = (($$0) + -1900)|0;
  HEAP32[$1>>2] = $16;
 }
 STACKTOP = sp;return;
}
function __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE11__get_year4ERiRS4_S4_RjRKNS_5ctypeIcEE($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$byval_copy = 0, $10 = 0, $11 = 0, $12 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy = sp + 4|0;
 $6 = sp;
 $7 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $7;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$6>>2]|0;
 $8 = (__ZNSt3__220__get_up_to_n_digitsIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEiRT0_S5_RjRKNS_5ctypeIT_EEi($2,$$byval_copy,$4,$5,4)|0);
 $9 = HEAP32[$4>>2]|0;
 $10 = $9 & 4;
 $11 = ($10|0)==(0);
 if ($11) {
  $12 = (($8) + -1900)|0;
  HEAP32[$1>>2] = $12;
 }
 STACKTOP = sp;return;
}
function __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE13__get_percentERS4_S4_RjRKNS_5ctypeIcEE($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i11 = 0, $$0$i$i2$i$i = 0, $$0$i$i2$i$i17 = 0, $$pre$i$i$i = 0, $$pre$i$i$i13 = 0, $$pre$i4$i$i1925 = 0, $$sink3 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $phitmp$i$i$i = 0, $phitmp$i$i$i14 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = HEAP32[$1>>2]|0;
 $6 = ($5|0)==(0|0);
 do {
  if ($6) {
   $95 = 1;
  } else {
   $7 = ((($5)) + 12|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ((($5)) + 16|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($8|0)==($10|0);
   if ($11) {
    $12 = HEAP32[$5>>2]|0;
    $13 = ((($12)) + 36|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = (FUNCTION_TABLE_ii[$14 & 8191]($5)|0);
    $$0$i$i$i$i = $15;
   } else {
    $16 = HEAP8[$8>>0]|0;
    $17 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($16)|0);
    $$0$i$i$i$i = $17;
   }
   $18 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
   $19 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i$i$i,$18)|0);
   if ($19) {
    HEAP32[$1>>2] = 0;
    $95 = 1;
    break;
   } else {
    $$pre$i$i$i = HEAP32[$1>>2]|0;
    $phitmp$i$i$i = ($$pre$i$i$i|0)==(0|0);
    $95 = $phitmp$i$i$i;
    break;
   }
  }
 } while(0);
 $20 = HEAP32[$2>>2]|0;
 $21 = ($20|0)==(0|0);
 do {
  if ($21) {
   label = 14;
  } else {
   $22 = ((($20)) + 12|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = ((($20)) + 16|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = ($23|0)==($25|0);
   if ($26) {
    $27 = HEAP32[$20>>2]|0;
    $28 = ((($27)) + 36|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = (FUNCTION_TABLE_ii[$29 & 8191]($20)|0);
    $$0$i$i2$i$i = $30;
   } else {
    $31 = HEAP8[$23>>0]|0;
    $32 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($31)|0);
    $$0$i$i2$i$i = $32;
   }
   $33 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
   $34 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i2$i$i,$33)|0);
   if ($34) {
    HEAP32[$2>>2] = 0;
    label = 14;
    break;
   } else {
    if ($95) {
     $$pre$i4$i$i1925 = $20;
     label = 16;
     break;
    } else {
     $$sink3 = 6;
     label = 38;
     break;
    }
   }
  }
 } while(0);
 if ((label|0) == 14) {
  if ($95) {
   $$sink3 = 6;
   label = 38;
  } else {
   $$pre$i4$i$i1925 = 0;
   label = 16;
  }
 }
 L22: do {
  if ((label|0) == 16) {
   $35 = HEAP32[$1>>2]|0;
   $36 = ((($35)) + 12|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = ((($35)) + 16|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = ($37|0)==($39|0);
   if ($40) {
    $41 = HEAP32[$35>>2]|0;
    $42 = ((($41)) + 36|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = (FUNCTION_TABLE_ii[$43 & 8191]($35)|0);
    $$0$i$i = $44;
   } else {
    $45 = HEAP8[$37>>0]|0;
    $46 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($45)|0);
    $$0$i$i = $46;
   }
   $47 = $$0$i$i&255;
   $48 = HEAP32[$4>>2]|0;
   $49 = ((($48)) + 36|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = (FUNCTION_TABLE_iiii[$50 & 8191]($4,$47,0)|0);
   $52 = ($51<<24>>24)==(37);
   if ($52) {
    $53 = HEAP32[$1>>2]|0;
    $54 = ((($53)) + 12|0);
    $55 = HEAP32[$54>>2]|0;
    $56 = ((($53)) + 16|0);
    $57 = HEAP32[$56>>2]|0;
    $58 = ($55|0)==($57|0);
    if ($58) {
     $59 = HEAP32[$53>>2]|0;
     $60 = ((($59)) + 40|0);
     $61 = HEAP32[$60>>2]|0;
     (FUNCTION_TABLE_ii[$61 & 8191]($53)|0);
    } else {
     $62 = ((($55)) + 1|0);
     HEAP32[$54>>2] = $62;
     $63 = HEAP8[$55>>0]|0;
     (__ZNSt3__211char_traitsIcE11to_int_typeEc($63)|0);
    }
    $64 = HEAP32[$1>>2]|0;
    $65 = ($64|0)==(0|0);
    do {
     if ($65) {
      $96 = 1;
     } else {
      $66 = ((($64)) + 12|0);
      $67 = HEAP32[$66>>2]|0;
      $68 = ((($64)) + 16|0);
      $69 = HEAP32[$68>>2]|0;
      $70 = ($67|0)==($69|0);
      if ($70) {
       $71 = HEAP32[$64>>2]|0;
       $72 = ((($71)) + 36|0);
       $73 = HEAP32[$72>>2]|0;
       $74 = (FUNCTION_TABLE_ii[$73 & 8191]($64)|0);
       $$0$i$i$i$i11 = $74;
      } else {
       $75 = HEAP8[$67>>0]|0;
       $76 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($75)|0);
       $$0$i$i$i$i11 = $76;
      }
      $77 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
      $78 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i$i$i11,$77)|0);
      if ($78) {
       HEAP32[$1>>2] = 0;
       $96 = 1;
       break;
      } else {
       $$pre$i$i$i13 = HEAP32[$1>>2]|0;
       $phitmp$i$i$i14 = ($$pre$i$i$i13|0)==(0|0);
       $96 = $phitmp$i$i$i14;
       break;
      }
     }
    } while(0);
    $79 = ($$pre$i4$i$i1925|0)==(0|0);
    do {
     if (!($79)) {
      $80 = ((($$pre$i4$i$i1925)) + 12|0);
      $81 = HEAP32[$80>>2]|0;
      $82 = ((($$pre$i4$i$i1925)) + 16|0);
      $83 = HEAP32[$82>>2]|0;
      $84 = ($81|0)==($83|0);
      if ($84) {
       $85 = HEAP32[$$pre$i4$i$i1925>>2]|0;
       $86 = ((($85)) + 36|0);
       $87 = HEAP32[$86>>2]|0;
       $88 = (FUNCTION_TABLE_ii[$87 & 8191]($$pre$i4$i$i1925)|0);
       $$0$i$i2$i$i17 = $88;
      } else {
       $89 = HEAP8[$81>>0]|0;
       $90 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($89)|0);
       $$0$i$i2$i$i17 = $90;
      }
      $91 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
      $92 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i2$i$i17,$91)|0);
      if ($92) {
       HEAP32[$2>>2] = 0;
       break;
      } else {
       if ($96) {
        break L22;
       } else {
        $$sink3 = 2;
        label = 38;
        break L22;
       }
      }
     }
    } while(0);
    if ($96) {
     $$sink3 = 2;
     label = 38;
    }
   } else {
    $$sink3 = 4;
    label = 38;
   }
  }
 } while(0);
 if ((label|0) == 38) {
  $93 = HEAP32[$3>>2]|0;
  $94 = $93 | $$sink3;
  HEAP32[$3>>2] = $94;
 }
 return;
}
function __ZNSt3__220__get_up_to_n_digitsIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEiRT0_S5_RjRKNS_5ctypeIT_EEi($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0 = 0, $$0$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i25 = 0, $$0$i$i$i$i41 = 0, $$0$i$i2$i$i = 0, $$0$i$i2$i$i31 = 0, $$0$i$i2$i$i47 = 0, $$0$i$i37 = 0, $$0$in = 0, $$023 = 0, $$023$in = 0, $$2 = 0, $$pre$i$i$i = 0, $$pre$i$i$i27 = 0, $$pre$i$i$i43 = 0, $$pre$i4$i$i33 = 0, $$pre$i4$i$i49 = 0, $10 = 0, $100 = 0;
 var $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0;
 var $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0;
 var $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0;
 var $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0;
 var $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $phitmp$i$i$i = 0, $phitmp$i$i$i28 = 0, $phitmp$i$i$i44 = 0, $phitmp$i5$i$i34 = 0, $sext = 0;
 var $sext54 = 0, $tmp$i$i36 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = HEAP32[$0>>2]|0;
 $6 = ($5|0)==(0|0);
 do {
  if ($6) {
   $178 = 1;
  } else {
   $7 = ((($5)) + 12|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ((($5)) + 16|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($8|0)==($10|0);
   if ($11) {
    $12 = HEAP32[$5>>2]|0;
    $13 = ((($12)) + 36|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = (FUNCTION_TABLE_ii[$14 & 8191]($5)|0);
    $$0$i$i$i$i = $15;
   } else {
    $16 = HEAP8[$8>>0]|0;
    $17 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($16)|0);
    $$0$i$i$i$i = $17;
   }
   $18 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
   $19 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i$i$i,$18)|0);
   if ($19) {
    HEAP32[$0>>2] = 0;
    $178 = 1;
    break;
   } else {
    $$pre$i$i$i = HEAP32[$0>>2]|0;
    $phitmp$i$i$i = ($$pre$i$i$i|0)==(0|0);
    $178 = $phitmp$i$i$i;
    break;
   }
  }
 } while(0);
 $20 = HEAP32[$1>>2]|0;
 $21 = ($20|0)==(0|0);
 do {
  if ($21) {
   label = 14;
  } else {
   $22 = ((($20)) + 12|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = ((($20)) + 16|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = ($23|0)==($25|0);
   if ($26) {
    $27 = HEAP32[$20>>2]|0;
    $28 = ((($27)) + 36|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = (FUNCTION_TABLE_ii[$29 & 8191]($20)|0);
    $$0$i$i2$i$i = $30;
   } else {
    $31 = HEAP8[$23>>0]|0;
    $32 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($31)|0);
    $$0$i$i2$i$i = $32;
   }
   $33 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
   $34 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i2$i$i,$33)|0);
   if ($34) {
    HEAP32[$1>>2] = 0;
    label = 14;
    break;
   } else {
    if ($178) {
     $179 = $20;
     label = 17;
     break;
    } else {
     label = 16;
     break;
    }
   }
  }
 } while(0);
 if ((label|0) == 14) {
  if ($178) {
   label = 16;
  } else {
   $179 = 0;
   label = 17;
  }
 }
 L22: do {
  if ((label|0) == 16) {
   $35 = HEAP32[$2>>2]|0;
   $36 = $35 | 6;
   HEAP32[$2>>2] = $36;
   $$2 = 0;
  }
  else if ((label|0) == 17) {
   $37 = HEAP32[$0>>2]|0;
   $38 = ((($37)) + 12|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = ((($37)) + 16|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = ($39|0)==($41|0);
   if ($42) {
    $43 = HEAP32[$37>>2]|0;
    $44 = ((($43)) + 36|0);
    $45 = HEAP32[$44>>2]|0;
    $46 = (FUNCTION_TABLE_ii[$45 & 8191]($37)|0);
    $$0$i$i = $46;
   } else {
    $47 = HEAP8[$39>>0]|0;
    $48 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($47)|0);
    $$0$i$i = $48;
   }
   $49 = $$0$i$i&255;
   $50 = ($49<<24>>24)>(-1);
   if ($50) {
    $sext = $$0$i$i << 24;
    $51 = $sext >> 24;
    $52 = ((($3)) + 8|0);
    $53 = HEAP32[$52>>2]|0;
    $54 = (($53) + ($51<<1)|0);
    $55 = HEAP16[$54>>1]|0;
    $56 = $55 & 2048;
    $57 = ($56<<16>>16)==(0);
    if (!($57)) {
     $60 = HEAP32[$3>>2]|0;
     $61 = ((($60)) + 36|0);
     $62 = HEAP32[$61>>2]|0;
     $63 = (FUNCTION_TABLE_iiii[$62 & 8191]($3,$49,0)|0);
     $64 = $63 << 24 >> 24;
     $65 = HEAP32[$0>>2]|0;
     $66 = ((($65)) + 12|0);
     $67 = HEAP32[$66>>2]|0;
     $68 = ((($65)) + 16|0);
     $69 = HEAP32[$68>>2]|0;
     $70 = ($67|0)==($69|0);
     if ($70) {
      $71 = HEAP32[$65>>2]|0;
      $72 = ((($71)) + 40|0);
      $73 = HEAP32[$72>>2]|0;
      (FUNCTION_TABLE_ii[$73 & 8191]($65)|0);
      $$0$in = $64;$$023$in = $4;$$pre$i4$i$i33 = $179;$91 = $179;
     } else {
      $74 = ((($67)) + 1|0);
      HEAP32[$66>>2] = $74;
      $75 = HEAP8[$67>>0]|0;
      (__ZNSt3__211char_traitsIcE11to_int_typeEc($75)|0);
      $$0$in = $64;$$023$in = $4;$$pre$i4$i$i33 = $179;$91 = $179;
     }
     while(1) {
      $$0 = (($$0$in) + -48)|0;
      $$023 = (($$023$in) + -1)|0;
      $76 = HEAP32[$0>>2]|0;
      $77 = ($76|0)==(0|0);
      do {
       if ($77) {
        $107 = 1;
       } else {
        $78 = ((($76)) + 12|0);
        $79 = HEAP32[$78>>2]|0;
        $80 = ((($76)) + 16|0);
        $81 = HEAP32[$80>>2]|0;
        $82 = ($79|0)==($81|0);
        if ($82) {
         $83 = HEAP32[$76>>2]|0;
         $84 = ((($83)) + 36|0);
         $85 = HEAP32[$84>>2]|0;
         $86 = (FUNCTION_TABLE_ii[$85 & 8191]($76)|0);
         $$0$i$i$i$i25 = $86;
        } else {
         $87 = HEAP8[$79>>0]|0;
         $88 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($87)|0);
         $$0$i$i$i$i25 = $88;
        }
        $89 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
        $90 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i$i$i25,$89)|0);
        if ($90) {
         HEAP32[$0>>2] = 0;
         $107 = 1;
         break;
        } else {
         $$pre$i$i$i27 = HEAP32[$0>>2]|0;
         $phitmp$i$i$i28 = ($$pre$i$i$i27|0)==(0|0);
         $107 = $phitmp$i$i$i28;
         break;
        }
       }
      } while(0);
      $92 = ($91|0)==(0|0);
      do {
       if ($92) {
        $$pre$i4$i$i49 = $$pre$i4$i$i33;$106 = 1;$180 = 0;
       } else {
        $93 = ((($91)) + 12|0);
        $94 = HEAP32[$93>>2]|0;
        $95 = ((($91)) + 16|0);
        $96 = HEAP32[$95>>2]|0;
        $97 = ($94|0)==($96|0);
        if ($97) {
         $98 = HEAP32[$91>>2]|0;
         $99 = ((($98)) + 36|0);
         $100 = HEAP32[$99>>2]|0;
         $101 = (FUNCTION_TABLE_ii[$100 & 8191]($91)|0);
         $$0$i$i2$i$i31 = $101;
        } else {
         $102 = HEAP8[$94>>0]|0;
         $103 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($102)|0);
         $$0$i$i2$i$i31 = $103;
        }
        $104 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
        $105 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i2$i$i31,$104)|0);
        if ($105) {
         HEAP32[$1>>2] = 0;
         $$pre$i4$i$i49 = 0;$106 = 1;$180 = 0;
         break;
        } else {
         $phitmp$i5$i$i34 = ($$pre$i4$i$i33|0)==(0|0);
         $$pre$i4$i$i49 = $$pre$i4$i$i33;$106 = $phitmp$i5$i$i34;$180 = $$pre$i4$i$i33;
         break;
        }
       }
      } while(0);
      $tmp$i$i36 = $107 ^ $106;
      $108 = ($$023$in|0)>(1);
      $109 = $108 & $tmp$i$i36;
      $110 = HEAP32[$0>>2]|0;
      if (!($109)) {
       break;
      }
      $111 = ((($110)) + 12|0);
      $112 = HEAP32[$111>>2]|0;
      $113 = ((($110)) + 16|0);
      $114 = HEAP32[$113>>2]|0;
      $115 = ($112|0)==($114|0);
      if ($115) {
       $116 = HEAP32[$110>>2]|0;
       $117 = ((($116)) + 36|0);
       $118 = HEAP32[$117>>2]|0;
       $119 = (FUNCTION_TABLE_ii[$118 & 8191]($110)|0);
       $$0$i$i37 = $119;
      } else {
       $120 = HEAP8[$112>>0]|0;
       $121 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($120)|0);
       $$0$i$i37 = $121;
      }
      $122 = $$0$i$i37&255;
      $123 = ($122<<24>>24)>(-1);
      if (!($123)) {
       $$2 = $$0;
       break L22;
      }
      $sext54 = $$0$i$i37 << 24;
      $124 = $sext54 >> 24;
      $125 = HEAP32[$52>>2]|0;
      $126 = (($125) + ($124<<1)|0);
      $127 = HEAP16[$126>>1]|0;
      $128 = $127 & 2048;
      $129 = ($128<<16>>16)==(0);
      if ($129) {
       $$2 = $$0;
       break L22;
      }
      $130 = ($$0*10)|0;
      $131 = HEAP32[$3>>2]|0;
      $132 = ((($131)) + 36|0);
      $133 = HEAP32[$132>>2]|0;
      $134 = (FUNCTION_TABLE_iiii[$133 & 8191]($3,$122,0)|0);
      $135 = $134 << 24 >> 24;
      $136 = (($135) + ($130))|0;
      $137 = HEAP32[$0>>2]|0;
      $138 = ((($137)) + 12|0);
      $139 = HEAP32[$138>>2]|0;
      $140 = ((($137)) + 16|0);
      $141 = HEAP32[$140>>2]|0;
      $142 = ($139|0)==($141|0);
      if ($142) {
       $143 = HEAP32[$137>>2]|0;
       $144 = ((($143)) + 40|0);
       $145 = HEAP32[$144>>2]|0;
       (FUNCTION_TABLE_ii[$145 & 8191]($137)|0);
       $$0$in = $136;$$023$in = $$023;$$pre$i4$i$i33 = $$pre$i4$i$i49;$91 = $180;
       continue;
      } else {
       $146 = ((($139)) + 1|0);
       HEAP32[$138>>2] = $146;
       $147 = HEAP8[$139>>0]|0;
       (__ZNSt3__211char_traitsIcE11to_int_typeEc($147)|0);
       $$0$in = $136;$$023$in = $$023;$$pre$i4$i$i33 = $$pre$i4$i$i49;$91 = $180;
       continue;
      }
     }
     $148 = ($110|0)==(0|0);
     do {
      if ($148) {
       $181 = 1;
      } else {
       $149 = ((($110)) + 12|0);
       $150 = HEAP32[$149>>2]|0;
       $151 = ((($110)) + 16|0);
       $152 = HEAP32[$151>>2]|0;
       $153 = ($150|0)==($152|0);
       if ($153) {
        $154 = HEAP32[$110>>2]|0;
        $155 = ((($154)) + 36|0);
        $156 = HEAP32[$155>>2]|0;
        $157 = (FUNCTION_TABLE_ii[$156 & 8191]($110)|0);
        $$0$i$i$i$i41 = $157;
       } else {
        $158 = HEAP8[$150>>0]|0;
        $159 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($158)|0);
        $$0$i$i$i$i41 = $159;
       }
       $160 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
       $161 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i$i$i41,$160)|0);
       if ($161) {
        HEAP32[$0>>2] = 0;
        $181 = 1;
        break;
       } else {
        $$pre$i$i$i43 = HEAP32[$0>>2]|0;
        $phitmp$i$i$i44 = ($$pre$i$i$i43|0)==(0|0);
        $181 = $phitmp$i$i$i44;
        break;
       }
      }
     } while(0);
     $162 = ($$pre$i4$i$i49|0)==(0|0);
     do {
      if ($162) {
       label = 62;
      } else {
       $163 = ((($$pre$i4$i$i49)) + 12|0);
       $164 = HEAP32[$163>>2]|0;
       $165 = ((($$pre$i4$i$i49)) + 16|0);
       $166 = HEAP32[$165>>2]|0;
       $167 = ($164|0)==($166|0);
       if ($167) {
        $168 = HEAP32[$$pre$i4$i$i49>>2]|0;
        $169 = ((($168)) + 36|0);
        $170 = HEAP32[$169>>2]|0;
        $171 = (FUNCTION_TABLE_ii[$170 & 8191]($$pre$i4$i$i49)|0);
        $$0$i$i2$i$i47 = $171;
       } else {
        $172 = HEAP8[$164>>0]|0;
        $173 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($172)|0);
        $$0$i$i2$i$i47 = $173;
       }
       $174 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
       $175 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i2$i$i47,$174)|0);
       if ($175) {
        HEAP32[$1>>2] = 0;
        label = 62;
        break;
       } else {
        if ($181) {
         $$2 = $$0;
         break L22;
        } else {
         break;
        }
       }
      }
     } while(0);
     if ((label|0) == 62) {
      if (!($181)) {
       $$2 = $$0;
       break;
      }
     }
     $176 = HEAP32[$2>>2]|0;
     $177 = $176 | 2;
     HEAP32[$2>>2] = $177;
     $$2 = $$0;
     break;
    }
   }
   $58 = HEAP32[$2>>2]|0;
   $59 = $58 | 4;
   HEAP32[$2>>2] = $59;
   $$2 = 0;
  }
 } while(0);
 return ($$2|0);
}
function __ZNSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEED2Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__26locale5facetD2Ev($0);
 return;
}
function __ZNSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEED0Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__26locale5facetD2Ev($0);
 __ZdlPv($0);
 return;
}
function __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE13do_date_orderEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 2;
}
function __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE11do_get_timeES4_S4_RNS_8ios_baseERjP2tm($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $10 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy1 = sp + 12|0;
 $$byval_copy = sp + 8|0;
 $6 = sp + 4|0;
 $7 = sp;
 $8 = HEAP32[$1>>2]|0;
 HEAP32[$6>>2] = $8;
 $9 = HEAP32[$2>>2]|0;
 HEAP32[$7>>2] = $9;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$6>>2]|0;
 ;HEAP32[$$byval_copy1>>2]=HEAP32[$7>>2]|0;
 $10 = (__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjP2tmPKwSC_($0,$$byval_copy,$$byval_copy1,$3,$4,$5,98484,(98516))|0);
 STACKTOP = sp;return ($10|0);
}
function __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE11do_get_dateES4_S4_RNS_8ios_baseERjP2tm($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy1 = sp + 12|0;
 $$byval_copy = sp + 8|0;
 $6 = sp + 4|0;
 $7 = sp;
 $8 = ((($0)) + 8|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($9)) + 20|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (FUNCTION_TABLE_ii[$11 & 8191]($8)|0);
 $13 = HEAP32[$1>>2]|0;
 HEAP32[$6>>2] = $13;
 $14 = HEAP32[$2>>2]|0;
 HEAP32[$7>>2] = $14;
 $15 = ((($12)) + 8|0);
 $16 = ((($15)) + 3|0);
 $17 = HEAP8[$16>>0]|0;
 $18 = ($17<<24>>24)<(0);
 $19 = HEAP32[$12>>2]|0;
 $20 = $18 ? $19 : $12;
 $21 = ((($12)) + 4|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = $17&255;
 $24 = $18 ? $22 : $23;
 $25 = (($20) + ($24<<2)|0);
 ;HEAP32[$$byval_copy>>2]=HEAP32[$6>>2]|0;
 ;HEAP32[$$byval_copy1>>2]=HEAP32[$7>>2]|0;
 $26 = (__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjP2tmPKwSC_($0,$$byval_copy,$$byval_copy1,$3,$4,$5,$20,$25)|0);
 STACKTOP = sp;return ($26|0);
}
function __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE14do_get_weekdayES4_S4_RNS_8ios_baseERjP2tm($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$byval_copy = 0, $$sroa$0$0$copyload = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy = sp + 8|0;
 $6 = sp + 4|0;
 $7 = sp;
 __ZNKSt3__28ios_base6getlocEv($6,$3);
 __THREW__ = 0;
 $8 = (invoke_iii(3255,($6|0),(215220|0))|0);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if ($10) {
  $13 = ___cxa_find_matching_catch_2()|0;
  $14 = tempRet0;
  __ZNSt3__26localeD2Ev($6);
  ___resumeException($13|0);
  // unreachable;
 } else {
  __ZNSt3__26localeD2Ev($6);
  $11 = ((($5)) + 24|0);
  $12 = HEAP32[$2>>2]|0;
  HEAP32[$7>>2] = $12;
  ;HEAP32[$$byval_copy>>2]=HEAP32[$7>>2]|0;
  __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE17__get_weekdaynameERiRS4_S4_RjRKNS_5ctypeIwEE($0,$11,$1,$$byval_copy,$4,$8);
  $$sroa$0$0$copyload = HEAP32[$1>>2]|0;
  STACKTOP = sp;return ($$sroa$0$0$copyload|0);
 }
 return (0)|0;
}
function __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE16do_get_monthnameES4_S4_RNS_8ios_baseERjP2tm($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$byval_copy = 0, $$sroa$0$0$copyload = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy = sp + 8|0;
 $6 = sp + 4|0;
 $7 = sp;
 __ZNKSt3__28ios_base6getlocEv($6,$3);
 __THREW__ = 0;
 $8 = (invoke_iii(3255,($6|0),(215220|0))|0);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if ($10) {
  $13 = ___cxa_find_matching_catch_2()|0;
  $14 = tempRet0;
  __ZNSt3__26localeD2Ev($6);
  ___resumeException($13|0);
  // unreachable;
 } else {
  __ZNSt3__26localeD2Ev($6);
  $11 = ((($5)) + 16|0);
  $12 = HEAP32[$2>>2]|0;
  HEAP32[$7>>2] = $12;
  ;HEAP32[$$byval_copy>>2]=HEAP32[$7>>2]|0;
  __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE15__get_monthnameERiRS4_S4_RjRKNS_5ctypeIwEE($0,$11,$1,$$byval_copy,$4,$8);
  $$sroa$0$0$copyload = HEAP32[$1>>2]|0;
  STACKTOP = sp;return ($$sroa$0$0$copyload|0);
 }
 return (0)|0;
}
function __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE11do_get_yearES4_S4_RNS_8ios_baseERjP2tm($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$byval_copy = 0, $$sroa$0$0$copyload = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy = sp + 8|0;
 $6 = sp + 4|0;
 $7 = sp;
 __ZNKSt3__28ios_base6getlocEv($6,$3);
 __THREW__ = 0;
 $8 = (invoke_iii(3255,($6|0),(215220|0))|0);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if ($10) {
  $13 = ___cxa_find_matching_catch_2()|0;
  $14 = tempRet0;
  __ZNSt3__26localeD2Ev($6);
  ___resumeException($13|0);
  // unreachable;
 } else {
  __ZNSt3__26localeD2Ev($6);
  $11 = ((($5)) + 20|0);
  $12 = HEAP32[$2>>2]|0;
  HEAP32[$7>>2] = $12;
  ;HEAP32[$$byval_copy>>2]=HEAP32[$7>>2]|0;
  __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE10__get_yearERiRS4_S4_RjRKNS_5ctypeIwEE($0,$11,$1,$$byval_copy,$4,$8);
  $$sroa$0$0$copyload = HEAP32[$1>>2]|0;
  STACKTOP = sp;return ($$sroa$0$0$copyload|0);
 }
 return (0)|0;
}
function __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjP2tmcc($0,$1,$2,$3,$4,$5,$6,$7) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $$byval_copy10 = 0, $$byval_copy11 = 0, $$byval_copy12 = 0, $$byval_copy13 = 0, $$byval_copy14 = 0, $$byval_copy15 = 0, $$byval_copy16 = 0, $$byval_copy17 = 0, $$byval_copy18 = 0, $$byval_copy19 = 0, $$byval_copy2 = 0, $$byval_copy20 = 0, $$byval_copy21 = 0, $$byval_copy22 = 0, $$byval_copy23 = 0, $$byval_copy24 = 0, $$byval_copy25 = 0, $$byval_copy26 = 0;
 var $$byval_copy27 = 0, $$byval_copy28 = 0, $$byval_copy29 = 0, $$byval_copy3 = 0, $$byval_copy30 = 0, $$byval_copy4 = 0, $$byval_copy5 = 0, $$byval_copy6 = 0, $$byval_copy7 = 0, $$byval_copy8 = 0, $$byval_copy9 = 0, $$sroa$097$0 = 0, $$sroa$097$0$copyload = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 256|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(256|0);
 $$byval_copy30 = sp + 248|0;
 $$byval_copy29 = sp + 244|0;
 $$byval_copy28 = sp + 240|0;
 $$byval_copy27 = sp + 236|0;
 $$byval_copy26 = sp + 232|0;
 $$byval_copy25 = sp + 228|0;
 $$byval_copy24 = sp + 224|0;
 $$byval_copy23 = sp + 220|0;
 $$byval_copy22 = sp + 216|0;
 $$byval_copy21 = sp + 212|0;
 $$byval_copy20 = sp + 208|0;
 $$byval_copy19 = sp + 204|0;
 $$byval_copy18 = sp + 200|0;
 $$byval_copy17 = sp + 196|0;
 $$byval_copy16 = sp + 192|0;
 $$byval_copy15 = sp + 188|0;
 $$byval_copy14 = sp + 184|0;
 $$byval_copy13 = sp + 180|0;
 $$byval_copy12 = sp + 176|0;
 $$byval_copy11 = sp + 172|0;
 $$byval_copy10 = sp + 168|0;
 $$byval_copy9 = sp + 164|0;
 $$byval_copy8 = sp + 160|0;
 $$byval_copy7 = sp + 156|0;
 $$byval_copy6 = sp + 152|0;
 $$byval_copy5 = sp + 148|0;
 $$byval_copy4 = sp + 144|0;
 $$byval_copy3 = sp + 140|0;
 $$byval_copy2 = sp + 136|0;
 $$byval_copy1 = sp + 132|0;
 $$byval_copy = sp + 128|0;
 $8 = sp + 124|0;
 $9 = sp + 120|0;
 $10 = sp + 116|0;
 $11 = sp + 112|0;
 $12 = sp + 108|0;
 $13 = sp + 104|0;
 $14 = sp + 100|0;
 $15 = sp + 96|0;
 $16 = sp + 92|0;
 $17 = sp + 88|0;
 $18 = sp + 84|0;
 $19 = sp + 80|0;
 $20 = sp + 76|0;
 $21 = sp + 72|0;
 $22 = sp + 68|0;
 $23 = sp + 64|0;
 $24 = sp + 60|0;
 $25 = sp + 56|0;
 $26 = sp + 52|0;
 $27 = sp + 48|0;
 $28 = sp + 44|0;
 $29 = sp + 40|0;
 $30 = sp + 36|0;
 $31 = sp + 32|0;
 $32 = sp + 28|0;
 $33 = sp + 24|0;
 $34 = sp + 20|0;
 $35 = sp + 16|0;
 $36 = sp + 12|0;
 $37 = sp + 8|0;
 $38 = sp + 4|0;
 $39 = sp;
 HEAP32[$4>>2] = 0;
 __ZNKSt3__28ios_base6getlocEv($8,$3);
 __THREW__ = 0;
 $40 = (invoke_iii(3255,($8|0),(215220|0))|0);
 $41 = __THREW__; __THREW__ = 0;
 $42 = $41&1;
 if ($42) {
  $49 = ___cxa_find_matching_catch_2()|0;
  $50 = tempRet0;
  __ZNSt3__26localeD2Ev($8);
  ___resumeException($49|0);
  // unreachable;
 }
 __ZNSt3__26localeD2Ev($8);
 $43 = $6 << 24 >> 24;
 $44 = ((($5)) + 16|0);
 $45 = ((($5)) + 8|0);
 $46 = ((($5)) + 20|0);
 $47 = ((($5)) + 24|0);
 $48 = ((($0)) + 8|0);
 do {
  switch ($43|0) {
  case 65: case 97:  {
   $51 = HEAP32[$2>>2]|0;
   HEAP32[$9>>2] = $51;
   ;HEAP32[$$byval_copy>>2]=HEAP32[$9>>2]|0;
   __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE17__get_weekdaynameERiRS4_S4_RjRKNS_5ctypeIwEE($0,$47,$1,$$byval_copy,$4,$40);
   label = 28;
   break;
  }
  case 104: case 66: case 98:  {
   $52 = HEAP32[$2>>2]|0;
   HEAP32[$10>>2] = $52;
   ;HEAP32[$$byval_copy1>>2]=HEAP32[$10>>2]|0;
   __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE15__get_monthnameERiRS4_S4_RjRKNS_5ctypeIwEE($0,$44,$1,$$byval_copy1,$4,$40);
   label = 28;
   break;
  }
  case 99:  {
   $53 = HEAP32[$48>>2]|0;
   $54 = ((($53)) + 12|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = (FUNCTION_TABLE_ii[$55 & 8191]($48)|0);
   $57 = HEAP32[$1>>2]|0;
   HEAP32[$11>>2] = $57;
   $58 = HEAP32[$2>>2]|0;
   HEAP32[$12>>2] = $58;
   $59 = ((($56)) + 8|0);
   $60 = ((($59)) + 3|0);
   $61 = HEAP8[$60>>0]|0;
   $62 = ($61<<24>>24)<(0);
   $63 = HEAP32[$56>>2]|0;
   $64 = $62 ? $63 : $56;
   $65 = ((($56)) + 4|0);
   $66 = HEAP32[$65>>2]|0;
   $67 = $61&255;
   $68 = $62 ? $66 : $67;
   $69 = (($64) + ($68<<2)|0);
   ;HEAP32[$$byval_copy2>>2]=HEAP32[$11>>2]|0;
   ;HEAP32[$$byval_copy3>>2]=HEAP32[$12>>2]|0;
   $70 = (__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjP2tmPKwSC_($0,$$byval_copy2,$$byval_copy3,$3,$4,$5,$64,$69)|0);
   HEAP32[$1>>2] = $70;
   label = 28;
   break;
  }
  case 101: case 100:  {
   $71 = ((($5)) + 12|0);
   $72 = HEAP32[$2>>2]|0;
   HEAP32[$13>>2] = $72;
   ;HEAP32[$$byval_copy4>>2]=HEAP32[$13>>2]|0;
   __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE9__get_dayERiRS4_S4_RjRKNS_5ctypeIwEE($0,$71,$1,$$byval_copy4,$4,$40);
   label = 28;
   break;
  }
  case 68:  {
   $73 = HEAP32[$1>>2]|0;
   HEAP32[$14>>2] = $73;
   $74 = HEAP32[$2>>2]|0;
   HEAP32[$15>>2] = $74;
   ;HEAP32[$$byval_copy5>>2]=HEAP32[$14>>2]|0;
   ;HEAP32[$$byval_copy6>>2]=HEAP32[$15>>2]|0;
   $75 = (__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjP2tmPKwSC_($0,$$byval_copy5,$$byval_copy6,$3,$4,$5,98324,(98356))|0);
   HEAP32[$1>>2] = $75;
   label = 28;
   break;
  }
  case 70:  {
   $76 = HEAP32[$1>>2]|0;
   HEAP32[$16>>2] = $76;
   $77 = HEAP32[$2>>2]|0;
   HEAP32[$17>>2] = $77;
   ;HEAP32[$$byval_copy7>>2]=HEAP32[$16>>2]|0;
   ;HEAP32[$$byval_copy8>>2]=HEAP32[$17>>2]|0;
   $78 = (__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjP2tmPKwSC_($0,$$byval_copy7,$$byval_copy8,$3,$4,$5,98356,(98388))|0);
   HEAP32[$1>>2] = $78;
   label = 28;
   break;
  }
  case 72:  {
   $79 = HEAP32[$2>>2]|0;
   HEAP32[$18>>2] = $79;
   ;HEAP32[$$byval_copy9>>2]=HEAP32[$18>>2]|0;
   __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE10__get_hourERiRS4_S4_RjRKNS_5ctypeIwEE($0,$45,$1,$$byval_copy9,$4,$40);
   label = 28;
   break;
  }
  case 73:  {
   $80 = HEAP32[$2>>2]|0;
   HEAP32[$19>>2] = $80;
   ;HEAP32[$$byval_copy10>>2]=HEAP32[$19>>2]|0;
   __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE13__get_12_hourERiRS4_S4_RjRKNS_5ctypeIwEE($0,$45,$1,$$byval_copy10,$4,$40);
   label = 28;
   break;
  }
  case 106:  {
   $81 = ((($5)) + 28|0);
   $82 = HEAP32[$2>>2]|0;
   HEAP32[$20>>2] = $82;
   ;HEAP32[$$byval_copy11>>2]=HEAP32[$20>>2]|0;
   __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE18__get_day_year_numERiRS4_S4_RjRKNS_5ctypeIwEE($0,$81,$1,$$byval_copy11,$4,$40);
   label = 28;
   break;
  }
  case 109:  {
   $83 = HEAP32[$2>>2]|0;
   HEAP32[$21>>2] = $83;
   ;HEAP32[$$byval_copy12>>2]=HEAP32[$21>>2]|0;
   __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE11__get_monthERiRS4_S4_RjRKNS_5ctypeIwEE($0,$44,$1,$$byval_copy12,$4,$40);
   label = 28;
   break;
  }
  case 77:  {
   $84 = ((($5)) + 4|0);
   $85 = HEAP32[$2>>2]|0;
   HEAP32[$22>>2] = $85;
   ;HEAP32[$$byval_copy13>>2]=HEAP32[$22>>2]|0;
   __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE12__get_minuteERiRS4_S4_RjRKNS_5ctypeIwEE($0,$84,$1,$$byval_copy13,$4,$40);
   label = 28;
   break;
  }
  case 116: case 110:  {
   $86 = HEAP32[$2>>2]|0;
   HEAP32[$23>>2] = $86;
   ;HEAP32[$$byval_copy14>>2]=HEAP32[$23>>2]|0;
   __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE17__get_white_spaceERS4_S4_RjRKNS_5ctypeIwEE($0,$1,$$byval_copy14,$4,$40);
   label = 28;
   break;
  }
  case 112:  {
   $87 = HEAP32[$2>>2]|0;
   HEAP32[$24>>2] = $87;
   ;HEAP32[$$byval_copy15>>2]=HEAP32[$24>>2]|0;
   __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE11__get_am_pmERiRS4_S4_RjRKNS_5ctypeIwEE($0,$45,$1,$$byval_copy15,$4,$40);
   label = 28;
   break;
  }
  case 114:  {
   $88 = HEAP32[$1>>2]|0;
   HEAP32[$25>>2] = $88;
   $89 = HEAP32[$2>>2]|0;
   HEAP32[$26>>2] = $89;
   ;HEAP32[$$byval_copy16>>2]=HEAP32[$25>>2]|0;
   ;HEAP32[$$byval_copy17>>2]=HEAP32[$26>>2]|0;
   $90 = (__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjP2tmPKwSC_($0,$$byval_copy16,$$byval_copy17,$3,$4,$5,98388,(98432))|0);
   HEAP32[$1>>2] = $90;
   label = 28;
   break;
  }
  case 82:  {
   $91 = HEAP32[$1>>2]|0;
   HEAP32[$27>>2] = $91;
   $92 = HEAP32[$2>>2]|0;
   HEAP32[$28>>2] = $92;
   ;HEAP32[$$byval_copy18>>2]=HEAP32[$27>>2]|0;
   ;HEAP32[$$byval_copy19>>2]=HEAP32[$28>>2]|0;
   $93 = (__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjP2tmPKwSC_($0,$$byval_copy18,$$byval_copy19,$3,$4,$5,98432,(98452))|0);
   HEAP32[$1>>2] = $93;
   label = 28;
   break;
  }
  case 83:  {
   $94 = HEAP32[$2>>2]|0;
   HEAP32[$29>>2] = $94;
   ;HEAP32[$$byval_copy20>>2]=HEAP32[$29>>2]|0;
   __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE12__get_secondERiRS4_S4_RjRKNS_5ctypeIwEE($0,$5,$1,$$byval_copy20,$4,$40);
   label = 28;
   break;
  }
  case 84:  {
   $95 = HEAP32[$1>>2]|0;
   HEAP32[$30>>2] = $95;
   $96 = HEAP32[$2>>2]|0;
   HEAP32[$31>>2] = $96;
   ;HEAP32[$$byval_copy21>>2]=HEAP32[$30>>2]|0;
   ;HEAP32[$$byval_copy22>>2]=HEAP32[$31>>2]|0;
   $97 = (__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjP2tmPKwSC_($0,$$byval_copy21,$$byval_copy22,$3,$4,$5,98452,(98484))|0);
   HEAP32[$1>>2] = $97;
   label = 28;
   break;
  }
  case 119:  {
   $98 = HEAP32[$2>>2]|0;
   HEAP32[$32>>2] = $98;
   ;HEAP32[$$byval_copy23>>2]=HEAP32[$32>>2]|0;
   __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE13__get_weekdayERiRS4_S4_RjRKNS_5ctypeIwEE($0,$47,$1,$$byval_copy23,$4,$40);
   label = 28;
   break;
  }
  case 120:  {
   $99 = HEAP32[$0>>2]|0;
   $100 = ((($99)) + 20|0);
   $101 = HEAP32[$100>>2]|0;
   $102 = HEAP32[$1>>2]|0;
   HEAP32[$33>>2] = $102;
   $103 = HEAP32[$2>>2]|0;
   HEAP32[$34>>2] = $103;
   ;HEAP32[$$byval_copy24>>2]=HEAP32[$33>>2]|0;
   ;HEAP32[$$byval_copy25>>2]=HEAP32[$34>>2]|0;
   $104 = (FUNCTION_TABLE_iiiiiii[$101 & 8191]($0,$$byval_copy24,$$byval_copy25,$3,$4,$5)|0);
   $$sroa$097$0 = $104;
   break;
  }
  case 88:  {
   $105 = HEAP32[$48>>2]|0;
   $106 = ((($105)) + 24|0);
   $107 = HEAP32[$106>>2]|0;
   $108 = (FUNCTION_TABLE_ii[$107 & 8191]($48)|0);
   $109 = HEAP32[$1>>2]|0;
   HEAP32[$35>>2] = $109;
   $110 = HEAP32[$2>>2]|0;
   HEAP32[$36>>2] = $110;
   $111 = ((($108)) + 8|0);
   $112 = ((($111)) + 3|0);
   $113 = HEAP8[$112>>0]|0;
   $114 = ($113<<24>>24)<(0);
   $115 = HEAP32[$108>>2]|0;
   $116 = $114 ? $115 : $108;
   $117 = ((($108)) + 4|0);
   $118 = HEAP32[$117>>2]|0;
   $119 = $113&255;
   $120 = $114 ? $118 : $119;
   $121 = (($116) + ($120<<2)|0);
   ;HEAP32[$$byval_copy26>>2]=HEAP32[$35>>2]|0;
   ;HEAP32[$$byval_copy27>>2]=HEAP32[$36>>2]|0;
   $122 = (__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjP2tmPKwSC_($0,$$byval_copy26,$$byval_copy27,$3,$4,$5,$116,$121)|0);
   HEAP32[$1>>2] = $122;
   label = 28;
   break;
  }
  case 121:  {
   $123 = HEAP32[$2>>2]|0;
   HEAP32[$37>>2] = $123;
   ;HEAP32[$$byval_copy28>>2]=HEAP32[$37>>2]|0;
   __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE10__get_yearERiRS4_S4_RjRKNS_5ctypeIwEE($0,$46,$1,$$byval_copy28,$4,$40);
   label = 28;
   break;
  }
  case 89:  {
   $124 = HEAP32[$2>>2]|0;
   HEAP32[$38>>2] = $124;
   ;HEAP32[$$byval_copy29>>2]=HEAP32[$38>>2]|0;
   __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE11__get_year4ERiRS4_S4_RjRKNS_5ctypeIwEE($0,$46,$1,$$byval_copy29,$4,$40);
   label = 28;
   break;
  }
  case 37:  {
   $125 = HEAP32[$2>>2]|0;
   HEAP32[$39>>2] = $125;
   ;HEAP32[$$byval_copy30>>2]=HEAP32[$39>>2]|0;
   __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE13__get_percentERS4_S4_RjRKNS_5ctypeIwEE($0,$1,$$byval_copy30,$4,$40);
   label = 28;
   break;
  }
  default: {
   $126 = HEAP32[$4>>2]|0;
   $127 = $126 | 4;
   HEAP32[$4>>2] = $127;
   label = 28;
  }
  }
 } while(0);
 if ((label|0) == 28) {
  $$sroa$097$0$copyload = HEAP32[$1>>2]|0;
  $$sroa$097$0 = $$sroa$097$0$copyload;
 }
 STACKTOP = sp;return ($$sroa$097$0|0);
}
function __ZNKSt3__220__time_get_c_storageIwE7__weeksEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP8[207192]|0;
 $2 = ($1<<24>>24)==(0);
 do {
  if ($2) {
   $3 = (___cxa_guard_acquire(207192)|0);
   $4 = ($3|0)==(0);
   if (!($4)) {
    __THREW__ = 0;
    invoke_v(4705);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     $8 = ___cxa_find_matching_catch_2()|0;
     $9 = tempRet0;
     ___resumeException($8|0);
     // unreachable;
    } else {
     HEAP32[54218] = 216704;
     break;
    }
   }
  }
 } while(0);
 $7 = HEAP32[54218]|0;
 return ($7|0);
}
function __ZNKSt3__220__time_get_c_storageIwE8__monthsEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP8[207176]|0;
 $2 = ($1<<24>>24)==(0);
 do {
  if ($2) {
   $3 = (___cxa_guard_acquire(207176)|0);
   $4 = ($3|0)==(0);
   if (!($4)) {
    __THREW__ = 0;
    invoke_v(4706);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     $8 = ___cxa_find_matching_catch_2()|0;
     $9 = tempRet0;
     ___resumeException($8|0);
     // unreachable;
    } else {
     HEAP32[54175] = 216412;
     break;
    }
   }
  }
 } while(0);
 $7 = HEAP32[54175]|0;
 return ($7|0);
}
function __ZNKSt3__220__time_get_c_storageIwE7__am_pmEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP8[207160]|0;
 $2 = ($1<<24>>24)==(0);
 do {
  if ($2) {
   $3 = (___cxa_guard_acquire(207160)|0);
   $4 = ($3|0)==(0);
   if (!($4)) {
    __THREW__ = 0;
    invoke_v(4707);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     $8 = ___cxa_find_matching_catch_2()|0;
     $9 = tempRet0;
     ___resumeException($8|0);
     // unreachable;
    } else {
     HEAP32[54102] = 216120;
     break;
    }
   }
  }
 } while(0);
 $7 = HEAP32[54102]|0;
 return ($7|0);
}
function __ZNKSt3__220__time_get_c_storageIwE3__cEv($0) {
 $0 = $0|0;
 var $$0$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $2 = HEAP8[207152]|0;
 $3 = ($2<<24>>24)==(0);
 L1: do {
  if ($3) {
   $4 = (___cxa_guard_acquire(207152)|0);
   $5 = ($4|0)==(0);
   if (!($5)) {
    ;HEAP32[216108>>2]=0|0;HEAP32[216108+4>>2]=0|0;HEAP32[216108+8>>2]=0|0;
    $6 = (__ZNSt3__211char_traitsIwE6lengthEPKw(97356)|0);
    $7 = ($6>>>0)>(1073741807);
    L4: do {
     if ($7) {
      __THREW__ = 0;
      invoke_vi(3367,(216108|0));
      $8 = __THREW__; __THREW__ = 0;
      label = 15;
     } else {
      $9 = ($6>>>0)<(2);
      do {
       if ($9) {
        $10 = $6&255;
        HEAP8[((((216116)) + 3|0))>>0] = $10;
        $$0$i$i = 216108;
       } else {
        $11 = (($6) + 4)|0;
        $12 = $11 & -4;
        $13 = ($12>>>0)>(1073741823);
        if (!($13)) {
         $20 = $12 << 2;
         __THREW__ = 0;
         $21 = (invoke_ii(3276,($20|0))|0);
         $22 = __THREW__; __THREW__ = 0;
         $23 = $22&1;
         if ($23) {
          label = 15;
          break L4;
         }
         HEAP32[54027] = $21;
         $24 = $12 | -2147483648;
         HEAP32[(216116)>>2] = $24;
         HEAP32[(216112)>>2] = $6;
         $$0$i$i = $21;
         break;
        }
        $14 = (___cxa_allocate_exception(8)|0);
        __THREW__ = 0;
        invoke_vii(3366,($14|0),(204840|0));
        $15 = __THREW__; __THREW__ = 0;
        $16 = $15&1;
        if ($16) {
         $18 = ___cxa_find_matching_catch_2()|0;
         $19 = tempRet0;
         ___cxa_free_exception(($14|0));
         $eh$lpad$body$index2Z2D = $19;$eh$lpad$body$indexZ2D = $18;
         break L4;
        } else {
         HEAP32[$14>>2] = (99824);
         __THREW__ = 0;
         invoke_viii(3695,($14|0),(34608|0),(3230|0));
         $17 = __THREW__; __THREW__ = 0;
         label = 15;
         break L4;
        }
       }
      } while(0);
      (__ZNSt3__211char_traitsIwE4copyEPwPKwj($$0$i$i,97356,$6)|0);
      $25 = (($$0$i$i) + ($6<<2)|0);
      HEAP32[$1>>2] = 0;
      __ZNSt3__211char_traitsIwE6assignERwRKw($25,$1);
      (___cxa_atexit((4708|0),(216108|0),(___dso_handle|0))|0);
      break L1;
     }
    } while(0);
    if ((label|0) == 15) {
     $26 = ___cxa_find_matching_catch_2()|0;
     $27 = tempRet0;
     $eh$lpad$body$index2Z2D = $27;$eh$lpad$body$indexZ2D = $26;
    }
    ___resumeException($eh$lpad$body$indexZ2D|0);
    // unreachable;
   }
  }
 } while(0);
 STACKTOP = sp;return (216108|0);
}
function __ZNKSt3__220__time_get_c_storageIwE3__rEv($0) {
 $0 = $0|0;
 var $$0$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $2 = HEAP8[207144]|0;
 $3 = ($2<<24>>24)==(0);
 L1: do {
  if ($3) {
   $4 = (___cxa_guard_acquire(207144)|0);
   $5 = ($4|0)==(0);
   if (!($5)) {
    ;HEAP32[216096>>2]=0|0;HEAP32[216096+4>>2]=0|0;HEAP32[216096+8>>2]=0|0;
    $6 = (__ZNSt3__211char_traitsIwE6lengthEPKw(97308)|0);
    $7 = ($6>>>0)>(1073741807);
    L4: do {
     if ($7) {
      __THREW__ = 0;
      invoke_vi(3367,(216096|0));
      $8 = __THREW__; __THREW__ = 0;
      label = 15;
     } else {
      $9 = ($6>>>0)<(2);
      do {
       if ($9) {
        $10 = $6&255;
        HEAP8[((((216104)) + 3|0))>>0] = $10;
        $$0$i$i = 216096;
       } else {
        $11 = (($6) + 4)|0;
        $12 = $11 & -4;
        $13 = ($12>>>0)>(1073741823);
        if (!($13)) {
         $20 = $12 << 2;
         __THREW__ = 0;
         $21 = (invoke_ii(3276,($20|0))|0);
         $22 = __THREW__; __THREW__ = 0;
         $23 = $22&1;
         if ($23) {
          label = 15;
          break L4;
         }
         HEAP32[54024] = $21;
         $24 = $12 | -2147483648;
         HEAP32[(216104)>>2] = $24;
         HEAP32[(216100)>>2] = $6;
         $$0$i$i = $21;
         break;
        }
        $14 = (___cxa_allocate_exception(8)|0);
        __THREW__ = 0;
        invoke_vii(3366,($14|0),(204840|0));
        $15 = __THREW__; __THREW__ = 0;
        $16 = $15&1;
        if ($16) {
         $18 = ___cxa_find_matching_catch_2()|0;
         $19 = tempRet0;
         ___cxa_free_exception(($14|0));
         $eh$lpad$body$index2Z2D = $19;$eh$lpad$body$indexZ2D = $18;
         break L4;
        } else {
         HEAP32[$14>>2] = (99824);
         __THREW__ = 0;
         invoke_viii(3695,($14|0),(34608|0),(3230|0));
         $17 = __THREW__; __THREW__ = 0;
         label = 15;
         break L4;
        }
       }
      } while(0);
      (__ZNSt3__211char_traitsIwE4copyEPwPKwj($$0$i$i,97308,$6)|0);
      $25 = (($$0$i$i) + ($6<<2)|0);
      HEAP32[$1>>2] = 0;
      __ZNSt3__211char_traitsIwE6assignERwRKw($25,$1);
      (___cxa_atexit((4708|0),(216096|0),(___dso_handle|0))|0);
      break L1;
     }
    } while(0);
    if ((label|0) == 15) {
     $26 = ___cxa_find_matching_catch_2()|0;
     $27 = tempRet0;
     $eh$lpad$body$index2Z2D = $27;$eh$lpad$body$indexZ2D = $26;
    }
    ___resumeException($eh$lpad$body$indexZ2D|0);
    // unreachable;
   }
  }
 } while(0);
 STACKTOP = sp;return (216096|0);
}
function __ZNKSt3__220__time_get_c_storageIwE3__xEv($0) {
 $0 = $0|0;
 var $$0$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $2 = HEAP8[207136]|0;
 $3 = ($2<<24>>24)==(0);
 L1: do {
  if ($3) {
   $4 = (___cxa_guard_acquire(207136)|0);
   $5 = ($4|0)==(0);
   if (!($5)) {
    ;HEAP32[216084>>2]=0|0;HEAP32[216084+4>>2]=0|0;HEAP32[216084+8>>2]=0|0;
    $6 = (__ZNSt3__211char_traitsIwE6lengthEPKw(97272)|0);
    $7 = ($6>>>0)>(1073741807);
    L4: do {
     if ($7) {
      __THREW__ = 0;
      invoke_vi(3367,(216084|0));
      $8 = __THREW__; __THREW__ = 0;
      label = 15;
     } else {
      $9 = ($6>>>0)<(2);
      do {
       if ($9) {
        $10 = $6&255;
        HEAP8[((((216092)) + 3|0))>>0] = $10;
        $$0$i$i = 216084;
       } else {
        $11 = (($6) + 4)|0;
        $12 = $11 & -4;
        $13 = ($12>>>0)>(1073741823);
        if (!($13)) {
         $20 = $12 << 2;
         __THREW__ = 0;
         $21 = (invoke_ii(3276,($20|0))|0);
         $22 = __THREW__; __THREW__ = 0;
         $23 = $22&1;
         if ($23) {
          label = 15;
          break L4;
         }
         HEAP32[54021] = $21;
         $24 = $12 | -2147483648;
         HEAP32[(216092)>>2] = $24;
         HEAP32[(216088)>>2] = $6;
         $$0$i$i = $21;
         break;
        }
        $14 = (___cxa_allocate_exception(8)|0);
        __THREW__ = 0;
        invoke_vii(3366,($14|0),(204840|0));
        $15 = __THREW__; __THREW__ = 0;
        $16 = $15&1;
        if ($16) {
         $18 = ___cxa_find_matching_catch_2()|0;
         $19 = tempRet0;
         ___cxa_free_exception(($14|0));
         $eh$lpad$body$index2Z2D = $19;$eh$lpad$body$indexZ2D = $18;
         break L4;
        } else {
         HEAP32[$14>>2] = (99824);
         __THREW__ = 0;
         invoke_viii(3695,($14|0),(34608|0),(3230|0));
         $17 = __THREW__; __THREW__ = 0;
         label = 15;
         break L4;
        }
       }
      } while(0);
      (__ZNSt3__211char_traitsIwE4copyEPwPKwj($$0$i$i,97272,$6)|0);
      $25 = (($$0$i$i) + ($6<<2)|0);
      HEAP32[$1>>2] = 0;
      __ZNSt3__211char_traitsIwE6assignERwRKw($25,$1);
      (___cxa_atexit((4708|0),(216084|0),(___dso_handle|0))|0);
      break L1;
     }
    } while(0);
    if ((label|0) == 15) {
     $26 = ___cxa_find_matching_catch_2()|0;
     $27 = tempRet0;
     $eh$lpad$body$index2Z2D = $27;$eh$lpad$body$indexZ2D = $26;
    }
    ___resumeException($eh$lpad$body$indexZ2D|0);
    // unreachable;
   }
  }
 } while(0);
 STACKTOP = sp;return (216084|0);
}
function __ZNKSt3__220__time_get_c_storageIwE3__XEv($0) {
 $0 = $0|0;
 var $$0$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $2 = HEAP8[207128]|0;
 $3 = ($2<<24>>24)==(0);
 L1: do {
  if ($3) {
   $4 = (___cxa_guard_acquire(207128)|0);
   $5 = ($4|0)==(0);
   if (!($5)) {
    ;HEAP32[216072>>2]=0|0;HEAP32[216072+4>>2]=0|0;HEAP32[216072+8>>2]=0|0;
    $6 = (__ZNSt3__211char_traitsIwE6lengthEPKw(97236)|0);
    $7 = ($6>>>0)>(1073741807);
    L4: do {
     if ($7) {
      __THREW__ = 0;
      invoke_vi(3367,(216072|0));
      $8 = __THREW__; __THREW__ = 0;
      label = 15;
     } else {
      $9 = ($6>>>0)<(2);
      do {
       if ($9) {
        $10 = $6&255;
        HEAP8[((((216080)) + 3|0))>>0] = $10;
        $$0$i$i = 216072;
       } else {
        $11 = (($6) + 4)|0;
        $12 = $11 & -4;
        $13 = ($12>>>0)>(1073741823);
        if (!($13)) {
         $20 = $12 << 2;
         __THREW__ = 0;
         $21 = (invoke_ii(3276,($20|0))|0);
         $22 = __THREW__; __THREW__ = 0;
         $23 = $22&1;
         if ($23) {
          label = 15;
          break L4;
         }
         HEAP32[54018] = $21;
         $24 = $12 | -2147483648;
         HEAP32[(216080)>>2] = $24;
         HEAP32[(216076)>>2] = $6;
         $$0$i$i = $21;
         break;
        }
        $14 = (___cxa_allocate_exception(8)|0);
        __THREW__ = 0;
        invoke_vii(3366,($14|0),(204840|0));
        $15 = __THREW__; __THREW__ = 0;
        $16 = $15&1;
        if ($16) {
         $18 = ___cxa_find_matching_catch_2()|0;
         $19 = tempRet0;
         ___cxa_free_exception(($14|0));
         $eh$lpad$body$index2Z2D = $19;$eh$lpad$body$indexZ2D = $18;
         break L4;
        } else {
         HEAP32[$14>>2] = (99824);
         __THREW__ = 0;
         invoke_viii(3695,($14|0),(34608|0),(3230|0));
         $17 = __THREW__; __THREW__ = 0;
         label = 15;
         break L4;
        }
       }
      } while(0);
      (__ZNSt3__211char_traitsIwE4copyEPwPKwj($$0$i$i,97236,$6)|0);
      $25 = (($$0$i$i) + ($6<<2)|0);
      HEAP32[$1>>2] = 0;
      __ZNSt3__211char_traitsIwE6assignERwRKw($25,$1);
      (___cxa_atexit((4708|0),(216072|0),(___dso_handle|0))|0);
      break L1;
     }
    } while(0);
    if ((label|0) == 15) {
     $26 = ___cxa_find_matching_catch_2()|0;
     $27 = tempRet0;
     $eh$lpad$body$index2Z2D = $27;$eh$lpad$body$indexZ2D = $26;
    }
    ___resumeException($eh$lpad$body$indexZ2D|0);
    // unreachable;
   }
  }
 } while(0);
 STACKTOP = sp;return (216072|0);
}
function __ZNSt3__211char_traitsIwE6lengthEPKw($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 $1 = (invoke_ii(4709,($0|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch_3(0|0)|0;
  $5 = tempRet0;
  ___clang_call_terminate($4);
  // unreachable;
 } else {
  return ($1|0);
 }
 return (0)|0;
}
function __ZNSt3__2L11init_wam_pmEv() {
 var $$0$i$i = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $exitcond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[207168]|0;
 $1 = ($0<<24>>24)==(0);
 if ($1) {
  $2 = (___cxa_guard_acquire(207168)|0);
  $3 = ($2|0)==(0);
  if (!($3)) {
   $4 = 216120;
   while(1) {
    ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;
    $$0$i$i = 0;
    while(1) {
     $exitcond$i$i = ($$0$i$i|0)==(3);
     if ($exitcond$i$i) {
      break;
     }
     $5 = (($4) + ($$0$i$i<<2)|0);
     HEAP32[$5>>2] = 0;
     $6 = (($$0$i$i) + 1)|0;
     $$0$i$i = $6;
    }
    $7 = ((($4)) + 12|0);
    $8 = ($7|0)==((216408)|0);
    if ($8) {
     break;
    } else {
     $4 = $7;
    }
   }
   (___cxa_atexit((4710|0),(0|0),(___dso_handle|0))|0);
  }
 }
 (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw(216120,97440)|0);
 (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw((216132),97452)|0);
 return;
}
function ___cxx_global_array_dtor_121($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (216408);
 while(1) {
  $1 = ((($2)) + -12|0);
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev($1);
  $3 = ($1|0)==(216120|0);
  if ($3) {
   break;
  } else {
   $2 = $1;
  }
 }
 return;
}
function __ZNSt3__2L12init_wmonthsEv() {
 var $$0$i$i = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $exitcond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[207184]|0;
 $1 = ($0<<24>>24)==(0);
 if ($1) {
  $2 = (___cxa_guard_acquire(207184)|0);
  $3 = ($2|0)==(0);
  if (!($3)) {
   $4 = 216412;
   while(1) {
    ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;
    $$0$i$i = 0;
    while(1) {
     $exitcond$i$i = ($$0$i$i|0)==(3);
     if ($exitcond$i$i) {
      break;
     }
     $5 = (($4) + ($$0$i$i<<2)|0);
     HEAP32[$5>>2] = 0;
     $6 = (($$0$i$i) + 1)|0;
     $$0$i$i = $6;
    }
    $7 = ((($4)) + 12|0);
    $8 = ($7|0)==((216700)|0);
    if ($8) {
     break;
    } else {
     $4 = $7;
    }
   }
   (___cxa_atexit((4711|0),(0|0),(___dso_handle|0))|0);
  }
 }
 (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw(216412,97464)|0);
 (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw((216424),97496)|0);
 (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw((216436),97532)|0);
 (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw((216448),97556)|0);
 (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw((216460),97580)|0);
 (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw((216472),97596)|0);
 (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw((216484),97616)|0);
 (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw((216496),97636)|0);
 (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw((216508),97664)|0);
 (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw((216520),97704)|0);
 (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw((216532),97736)|0);
 (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw((216544),97772)|0);
 (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw((216556),97808)|0);
 (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw((216568),97824)|0);
 (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw((216580),97840)|0);
 (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw((216592),97856)|0);
 (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw((216604),97580)|0);
 (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw((216616),97872)|0);
 (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw((216628),97888)|0);
 (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw((216640),97904)|0);
 (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw((216652),97920)|0);
 (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw((216664),97936)|0);
 (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw((216676),97952)|0);
 (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw((216688),97968)|0);
 return;
}
function ___cxx_global_array_dtor_94($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (216700);
 while(1) {
  $1 = ((($2)) + -12|0);
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev($1);
  $3 = ($1|0)==(216412|0);
  if ($3) {
   break;
  } else {
   $2 = $1;
  }
 }
 return;
}
function __ZNSt3__2L11init_wweeksEv() {
 var $$0$i$i = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $exitcond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[207200]|0;
 $1 = ($0<<24>>24)==(0);
 if ($1) {
  $2 = (___cxa_guard_acquire(207200)|0);
  $3 = ($2|0)==(0);
  if (!($3)) {
   $4 = 216704;
   while(1) {
    ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;
    $$0$i$i = 0;
    while(1) {
     $exitcond$i$i = ($$0$i$i|0)==(3);
     if ($exitcond$i$i) {
      break;
     }
     $5 = (($4) + ($$0$i$i<<2)|0);
     HEAP32[$5>>2] = 0;
     $6 = (($$0$i$i) + 1)|0;
     $$0$i$i = $6;
    }
    $7 = ((($4)) + 12|0);
    $8 = ($7|0)==((216872)|0);
    if ($8) {
     break;
    } else {
     $4 = $7;
    }
   }
   (___cxa_atexit((4712|0),(0|0),(___dso_handle|0))|0);
  }
 }
 (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw(216704,97984)|0);
 (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw((216716),98012)|0);
 (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw((216728),98040)|0);
 (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw((216740),98072)|0);
 (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw((216752),98112)|0);
 (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw((216764),98148)|0);
 (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw((216776),98176)|0);
 (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw((216788),98212)|0);
 (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw((216800),98228)|0);
 (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw((216812),98244)|0);
 (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw((216824),98260)|0);
 (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw((216836),98276)|0);
 (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw((216848),98292)|0);
 (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw((216860),98308)|0);
 return;
}
function ___cxx_global_array_dtor_55($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (216872);
 while(1) {
  $1 = ((($2)) + -12|0);
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev($1);
  $3 = ($1|0)==(216704|0);
  if ($3) {
   break;
  } else {
   $2 = $1;
  }
 }
 return;
}
function __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE17__get_weekdaynameERiRS4_S4_RjRKNS_5ctypeIwEE($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$byval_copy = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy = sp + 4|0;
 $6 = sp;
 $7 = ((($0)) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 $10 = (FUNCTION_TABLE_ii[$9 & 8191]($7)|0);
 $11 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $11;
 $12 = ((($10)) + 168|0);
 ;HEAP32[$$byval_copy>>2]=HEAP32[$6>>2]|0;
 $13 = (__ZNSt3__214__scan_keywordINS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEPKNS_12basic_stringIwS3_NS_9allocatorIwEEEENS_5ctypeIwEEEET0_RT_SE_SD_SD_RKT1_Rjb($2,$$byval_copy,$10,$12,$5,$4,0)|0);
 $14 = $13;
 $15 = $10;
 $16 = (($14) - ($15))|0;
 $17 = ($16|0)<(168);
 if ($17) {
  $18 = (($16|0) / 12)&-1;
  $19 = (($18|0) % 7)&-1;
  HEAP32[$1>>2] = $19;
 }
 STACKTOP = sp;return;
}
function __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE15__get_monthnameERiRS4_S4_RjRKNS_5ctypeIwEE($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$byval_copy = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy = sp + 4|0;
 $6 = sp;
 $7 = ((($0)) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($8)) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (FUNCTION_TABLE_ii[$10 & 8191]($7)|0);
 $12 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $12;
 $13 = ((($11)) + 288|0);
 ;HEAP32[$$byval_copy>>2]=HEAP32[$6>>2]|0;
 $14 = (__ZNSt3__214__scan_keywordINS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEPKNS_12basic_stringIwS3_NS_9allocatorIwEEEENS_5ctypeIwEEEET0_RT_SE_SD_SD_RKT1_Rjb($2,$$byval_copy,$11,$13,$5,$4,0)|0);
 $15 = $14;
 $16 = $11;
 $17 = (($15) - ($16))|0;
 $18 = ($17|0)<(288);
 if ($18) {
  $19 = (($17|0) / 12)&-1;
  $20 = (($19|0) % 12)&-1;
  HEAP32[$1>>2] = $20;
 }
 STACKTOP = sp;return;
}
function __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjP2tmPKwSC_($0,$1,$2,$3,$4,$5,$6,$7) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 var $$0$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i54 = 0, $$0$i$i$i$i69 = 0, $$0$i$i2$i$i = 0, $$0$i$i2$i$i60 = 0, $$0$i$i2$i$i75 = 0, $$0$i$i66 = 0, $$0$ph = 0, $$0$ph$be = 0, $$0$ph$sink = 0, $$051 = 0, $$052 = 0, $$byval_copy = 0, $$byval_copy1 = 0, $$lcssa = 0, $$ph = 0, $$pre = 0, $$pre$i$i$i56 = 0, $$pre$i$i$i71 = 0;
 var $$pre$i4$i$i62 = 0, $$pre$i4$i$i62100 = 0, $$pre$i4$i$i62101 = 0, $$pre$pre = 0, $$sroa$049$0$copyload = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0;
 var $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $phitmp$i5$i$i63 = 0, $tmp$i$i65 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $$byval_copy1 = sp + 16|0;
 $$byval_copy = sp + 12|0;
 $8 = sp + 8|0;
 $9 = sp + 4|0;
 $10 = sp;
 __ZNKSt3__28ios_base6getlocEv($8,$3);
 __THREW__ = 0;
 $11 = (invoke_iii(3255,($8|0),(215220|0))|0);
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $49 = ___cxa_find_matching_catch_2()|0;
  $50 = tempRet0;
  __ZNSt3__26localeD2Ev($8);
  ___resumeException($49|0);
  // unreachable;
 }
 __ZNSt3__26localeD2Ev($8);
 HEAP32[$4>>2] = 0;
 $$0$ph = $6;$$pre = 0;
 L4: while(1) {
  $14 = ($$0$ph|0)!=($7|0);
  $15 = $$pre;
  while(1) {
   $16 = ($15|0)==(0);
   $or$cond = $14 & $16;
   $17 = HEAP32[$1>>2]|0;
   if (!($or$cond)) {
    $$pre$i$i$i71 = $17;
    break L4;
   }
   $18 = ($17|0)==(0|0);
   $19 = $17;
   if ($18) {
    $146 = 0;$207 = 1;$74 = $19;
   } else {
    $20 = ((($17)) + 12|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = ((($17)) + 16|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = ($21|0)==($23|0);
    if ($24) {
     $25 = HEAP32[$17>>2]|0;
     $26 = ((($25)) + 36|0);
     $27 = HEAP32[$26>>2]|0;
     $28 = (FUNCTION_TABLE_ii[$27 & 8191]($17)|0);
     $$0$i$i$i$i = $28;
    } else {
     $29 = HEAP32[$21>>2]|0;
     $30 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($29)|0);
     $$0$i$i$i$i = $30;
    }
    $31 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
    $32 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i$i$i,$31)|0);
    if ($32) {
     HEAP32[$1>>2] = 0;
     $146 = 0;$207 = 1;$74 = 0;
    } else {
     $146 = $17;$207 = 0;$74 = $19;
    }
   }
   $33 = HEAP32[$2>>2]|0;
   $34 = ($33|0)==(0|0);
   $35 = $33;
   do {
    if ($34) {
     $$ph = $35;
     label = 17;
    } else {
     $36 = ((($33)) + 12|0);
     $37 = HEAP32[$36>>2]|0;
     $38 = ((($33)) + 16|0);
     $39 = HEAP32[$38>>2]|0;
     $40 = ($37|0)==($39|0);
     if ($40) {
      $41 = HEAP32[$33>>2]|0;
      $42 = ((($41)) + 36|0);
      $43 = HEAP32[$42>>2]|0;
      $44 = (FUNCTION_TABLE_ii[$43 & 8191]($33)|0);
      $$0$i$i2$i$i = $44;
     } else {
      $45 = HEAP32[$37>>2]|0;
      $46 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($45)|0);
      $$0$i$i2$i$i = $46;
     }
     $47 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
     $48 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i2$i$i,$47)|0);
     if ($48) {
      HEAP32[$2>>2] = 0;
      $$ph = 0;
      label = 17;
      break;
     } else {
      if ($207) {
       $208 = $33;$75 = $35;
       break;
      } else {
       label = 60;
       break L4;
      }
     }
    }
   } while(0);
   if ((label|0) == 17) {
    label = 0;
    if ($207) {
     label = 60;
     break L4;
    } else {
     $208 = 0;$75 = $$ph;
    }
   }
   $51 = HEAP32[$$0$ph>>2]|0;
   $52 = HEAP32[$11>>2]|0;
   $53 = ((($52)) + 52|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = (FUNCTION_TABLE_iiii[$54 & 8191]($11,$51,0)|0);
   $56 = ($55<<24>>24)==(37);
   if ($56) {
    label = 21;
    break;
   }
   $79 = HEAP32[$$0$ph>>2]|0;
   $80 = HEAP32[$11>>2]|0;
   $81 = ((($80)) + 12|0);
   $82 = HEAP32[$81>>2]|0;
   $83 = (FUNCTION_TABLE_iiii[$82 & 8191]($11,8192,$79)|0);
   if ($83) {
    $$0$ph$sink = $$0$ph;
    label = 28;
    break;
   }
   $145 = ((($146)) + 12|0);
   $147 = HEAP32[$145>>2]|0;
   $148 = ((($146)) + 16|0);
   $149 = HEAP32[$148>>2]|0;
   $150 = ($147|0)==($149|0);
   if ($150) {
    $151 = HEAP32[$146>>2]|0;
    $152 = ((($151)) + 36|0);
    $153 = HEAP32[$152>>2]|0;
    $154 = (FUNCTION_TABLE_ii[$153 & 8191]($146)|0);
    $$0$i$i66 = $154;
   } else {
    $155 = HEAP32[$147>>2]|0;
    $156 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($155)|0);
    $$0$i$i66 = $156;
   }
   $157 = HEAP32[$11>>2]|0;
   $158 = ((($157)) + 28|0);
   $159 = HEAP32[$158>>2]|0;
   $160 = (FUNCTION_TABLE_iii[$159 & 8191]($11,$$0$i$i66)|0);
   $161 = HEAP32[$$0$ph>>2]|0;
   $162 = HEAP32[$11>>2]|0;
   $163 = ((($162)) + 28|0);
   $164 = HEAP32[$163>>2]|0;
   $165 = (FUNCTION_TABLE_iii[$164 & 8191]($11,$161)|0);
   $166 = ($160|0)==($165|0);
   if ($166) {
    label = 56;
    break;
   }
   HEAP32[$4>>2] = 4;
   $15 = 4;
  }
  L36: do {
   if ((label|0) == 21) {
    label = 0;
    $57 = ((($$0$ph)) + 4|0);
    $58 = ($57|0)==($7|0);
    if ($58) {
     label = 60;
     break L4;
    }
    $59 = HEAP32[$57>>2]|0;
    $60 = HEAP32[$11>>2]|0;
    $61 = ((($60)) + 52|0);
    $62 = HEAP32[$61>>2]|0;
    $63 = (FUNCTION_TABLE_iiii[$62 & 8191]($11,$59,0)|0);
    switch ($63<<24>>24) {
    case 48: case 69:  {
     $64 = ((($$0$ph)) + 8|0);
     $65 = ($64|0)==($7|0);
     if ($65) {
      label = 60;
      break L4;
     }
     $66 = HEAP32[$64>>2]|0;
     $67 = HEAP32[$11>>2]|0;
     $68 = ((($67)) + 52|0);
     $69 = HEAP32[$68>>2]|0;
     $70 = (FUNCTION_TABLE_iiii[$69 & 8191]($11,$66,0)|0);
     $$051 = $63;$$052 = $70;$78 = $57;
     break;
    }
    default: {
     $$051 = 0;$$052 = $63;$78 = $$0$ph;
    }
    }
    $71 = HEAP32[$0>>2]|0;
    $72 = ((($71)) + 36|0);
    $73 = HEAP32[$72>>2]|0;
    HEAP32[$9>>2] = $74;
    HEAP32[$10>>2] = $75;
    ;HEAP32[$$byval_copy>>2]=HEAP32[$9>>2]|0;
    ;HEAP32[$$byval_copy1>>2]=HEAP32[$10>>2]|0;
    $76 = (FUNCTION_TABLE_iiiiiiiii[$73 & 8191]($0,$$byval_copy,$$byval_copy1,$3,$4,$5,$$052,$$051)|0);
    HEAP32[$1>>2] = $76;
    $77 = ((($78)) + 8|0);
    $$0$ph$be = $77;
   }
   else if ((label|0) == 28) {
    while(1) {
     label = 0;
     $84 = ((($$0$ph$sink)) + 4|0);
     $85 = ($84|0)==($7|0);
     if ($85) {
      $$lcssa = $7;
      break;
     }
     $86 = HEAP32[$84>>2]|0;
     $87 = HEAP32[$11>>2]|0;
     $88 = ((($87)) + 12|0);
     $89 = HEAP32[$88>>2]|0;
     $90 = (FUNCTION_TABLE_iiii[$89 & 8191]($11,8192,$86)|0);
     if ($90) {
      $$0$ph$sink = $84;
      label = 28;
     } else {
      $$lcssa = $84;
      break;
     }
    }
    $$pre$i$i$i56 = $146;$$pre$i4$i$i62 = $208;$105 = $208;
    while(1) {
     $91 = ($$pre$i$i$i56|0)==(0|0);
     if ($91) {
      $120 = 1;$122 = 0;
     } else {
      $92 = ((($$pre$i$i$i56)) + 12|0);
      $93 = HEAP32[$92>>2]|0;
      $94 = ((($$pre$i$i$i56)) + 16|0);
      $95 = HEAP32[$94>>2]|0;
      $96 = ($93|0)==($95|0);
      if ($96) {
       $97 = HEAP32[$$pre$i$i$i56>>2]|0;
       $98 = ((($97)) + 36|0);
       $99 = HEAP32[$98>>2]|0;
       $100 = (FUNCTION_TABLE_ii[$99 & 8191]($$pre$i$i$i56)|0);
       $$0$i$i$i$i54 = $100;
      } else {
       $101 = HEAP32[$93>>2]|0;
       $102 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($101)|0);
       $$0$i$i$i$i54 = $102;
      }
      $103 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
      $104 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i$i$i54,$103)|0);
      if ($104) {
       HEAP32[$1>>2] = 0;
       $120 = 1;$122 = 0;
      } else {
       $120 = 0;$122 = $$pre$i$i$i56;
      }
     }
     $106 = ($105|0)==(0|0);
     do {
      if ($106) {
       $$pre$i4$i$i62101 = $$pre$i4$i$i62;
       label = 43;
      } else {
       $107 = ((($105)) + 12|0);
       $108 = HEAP32[$107>>2]|0;
       $109 = ((($105)) + 16|0);
       $110 = HEAP32[$109>>2]|0;
       $111 = ($108|0)==($110|0);
       if ($111) {
        $112 = HEAP32[$105>>2]|0;
        $113 = ((($112)) + 36|0);
        $114 = HEAP32[$113>>2]|0;
        $115 = (FUNCTION_TABLE_ii[$114 & 8191]($105)|0);
        $$0$i$i2$i$i60 = $115;
       } else {
        $116 = HEAP32[$108>>2]|0;
        $117 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($116)|0);
        $$0$i$i2$i$i60 = $117;
       }
       $118 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
       $119 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i2$i$i60,$118)|0);
       if ($119) {
        HEAP32[$2>>2] = 0;
        $$pre$i4$i$i62101 = 0;
        label = 43;
        break;
       } else {
        $phitmp$i5$i$i63 = ($$pre$i4$i$i62|0)==(0|0);
        $tmp$i$i65 = $120 ^ $phitmp$i5$i$i63;
        if ($tmp$i$i65) {
         $$pre$i4$i$i62100 = $$pre$i4$i$i62;$209 = $$pre$i4$i$i62;
         break;
        } else {
         $$0$ph$be = $$lcssa;
         break L36;
        }
       }
      }
     } while(0);
     if ((label|0) == 43) {
      label = 0;
      if ($120) {
       $$0$ph$be = $$lcssa;
       break L36;
      } else {
       $$pre$i4$i$i62100 = $$pre$i4$i$i62101;$209 = 0;
      }
     }
     $121 = ((($122)) + 12|0);
     $123 = HEAP32[$121>>2]|0;
     $124 = ((($122)) + 16|0);
     $125 = HEAP32[$124>>2]|0;
     $126 = ($123|0)==($125|0);
     if ($126) {
      $127 = HEAP32[$122>>2]|0;
      $128 = ((($127)) + 36|0);
      $129 = HEAP32[$128>>2]|0;
      $130 = (FUNCTION_TABLE_ii[$129 & 8191]($122)|0);
      $$0$i$i = $130;
     } else {
      $131 = HEAP32[$123>>2]|0;
      $132 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($131)|0);
      $$0$i$i = $132;
     }
     $133 = HEAP32[$11>>2]|0;
     $134 = ((($133)) + 12|0);
     $135 = HEAP32[$134>>2]|0;
     $136 = (FUNCTION_TABLE_iiii[$135 & 8191]($11,8192,$$0$i$i)|0);
     if (!($136)) {
      $$0$ph$be = $$lcssa;
      break L36;
     }
     $137 = HEAP32[$121>>2]|0;
     $138 = HEAP32[$124>>2]|0;
     $139 = ($137|0)==($138|0);
     if ($139) {
      $140 = HEAP32[$122>>2]|0;
      $141 = ((($140)) + 40|0);
      $142 = HEAP32[$141>>2]|0;
      (FUNCTION_TABLE_ii[$142 & 8191]($122)|0);
      $$pre$i$i$i56 = $122;$$pre$i4$i$i62 = $$pre$i4$i$i62100;$105 = $209;
      continue;
     } else {
      $143 = ((($137)) + 4|0);
      HEAP32[$121>>2] = $143;
      $144 = HEAP32[$137>>2]|0;
      (__ZNSt3__211char_traitsIwE11to_int_typeEw($144)|0);
      $$pre$i$i$i56 = $122;$$pre$i4$i$i62 = $$pre$i4$i$i62100;$105 = $209;
      continue;
     }
    }
   }
   else if ((label|0) == 56) {
    label = 0;
    $167 = ((($$0$ph)) + 4|0);
    $168 = HEAP32[$145>>2]|0;
    $169 = HEAP32[$148>>2]|0;
    $170 = ($168|0)==($169|0);
    if ($170) {
     $171 = HEAP32[$146>>2]|0;
     $172 = ((($171)) + 40|0);
     $173 = HEAP32[$172>>2]|0;
     (FUNCTION_TABLE_ii[$173 & 8191]($146)|0);
     $$0$ph$be = $167;
     break;
    } else {
     $174 = ((($168)) + 4|0);
     HEAP32[$145>>2] = $174;
     $175 = HEAP32[$168>>2]|0;
     (__ZNSt3__211char_traitsIwE11to_int_typeEw($175)|0);
     $$0$ph$be = $167;
     break;
    }
   }
  } while(0);
  $$pre$pre = HEAP32[$4>>2]|0;
  $$0$ph = $$0$ph$be;$$pre = $$pre$pre;
 }
 if ((label|0) == 60) {
  HEAP32[$4>>2] = 4;
  $$pre$i$i$i71 = $146;
 }
 $176 = ($$pre$i$i$i71|0)==(0|0);
 if ($176) {
  $$sroa$049$0$copyload = 0;$210 = 1;
 } else {
  $177 = ((($$pre$i$i$i71)) + 12|0);
  $178 = HEAP32[$177>>2]|0;
  $179 = ((($$pre$i$i$i71)) + 16|0);
  $180 = HEAP32[$179>>2]|0;
  $181 = ($178|0)==($180|0);
  if ($181) {
   $182 = HEAP32[$$pre$i$i$i71>>2]|0;
   $183 = ((($182)) + 36|0);
   $184 = HEAP32[$183>>2]|0;
   $185 = (FUNCTION_TABLE_ii[$184 & 8191]($$pre$i$i$i71)|0);
   $$0$i$i$i$i69 = $185;
  } else {
   $186 = HEAP32[$178>>2]|0;
   $187 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($186)|0);
   $$0$i$i$i$i69 = $187;
  }
  $188 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
  $189 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i$i$i69,$188)|0);
  if ($189) {
   HEAP32[$1>>2] = 0;
   $$sroa$049$0$copyload = 0;$210 = 1;
  } else {
   $$sroa$049$0$copyload = $$pre$i$i$i71;$210 = 0;
  }
 }
 $190 = HEAP32[$2>>2]|0;
 $191 = ($190|0)==(0|0);
 do {
  if ($191) {
   label = 73;
  } else {
   $192 = ((($190)) + 12|0);
   $193 = HEAP32[$192>>2]|0;
   $194 = ((($190)) + 16|0);
   $195 = HEAP32[$194>>2]|0;
   $196 = ($193|0)==($195|0);
   if ($196) {
    $197 = HEAP32[$190>>2]|0;
    $198 = ((($197)) + 36|0);
    $199 = HEAP32[$198>>2]|0;
    $200 = (FUNCTION_TABLE_ii[$199 & 8191]($190)|0);
    $$0$i$i2$i$i75 = $200;
   } else {
    $201 = HEAP32[$193>>2]|0;
    $202 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($201)|0);
    $$0$i$i2$i$i75 = $202;
   }
   $203 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
   $204 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i2$i$i75,$203)|0);
   if ($204) {
    HEAP32[$2>>2] = 0;
    label = 73;
    break;
   } else {
    if ($210) {
     break;
    } else {
     label = 75;
     break;
    }
   }
  }
 } while(0);
 if ((label|0) == 73) {
  if ($210) {
   label = 75;
  }
 }
 if ((label|0) == 75) {
  $205 = HEAP32[$4>>2]|0;
  $206 = $205 | 2;
  HEAP32[$4>>2] = $206;
 }
 STACKTOP = sp;return ($$sroa$049$0$copyload|0);
}
function __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE9__get_dayERiRS4_S4_RjRKNS_5ctypeIwEE($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$byval_copy = 0, $$off = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy = sp + 4|0;
 $6 = sp;
 $7 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $7;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$6>>2]|0;
 $8 = (__ZNSt3__220__get_up_to_n_digitsIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEiRT0_S5_RjRKNS_5ctypeIT_EEi($2,$$byval_copy,$4,$5,2)|0);
 $9 = HEAP32[$4>>2]|0;
 $10 = $9 & 4;
 $11 = ($10|0)==(0);
 $$off = (($8) + -1)|0;
 $12 = ($$off>>>0)<(31);
 $13 = $12 & $11;
 if ($13) {
  HEAP32[$1>>2] = $8;
 } else {
  $14 = $9 | 4;
  HEAP32[$4>>2] = $14;
 }
 STACKTOP = sp;return;
}
function __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE10__get_hourERiRS4_S4_RjRKNS_5ctypeIwEE($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$byval_copy = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy = sp + 4|0;
 $6 = sp;
 $7 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $7;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$6>>2]|0;
 $8 = (__ZNSt3__220__get_up_to_n_digitsIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEiRT0_S5_RjRKNS_5ctypeIT_EEi($2,$$byval_copy,$4,$5,2)|0);
 $9 = HEAP32[$4>>2]|0;
 $10 = $9 & 4;
 $11 = ($10|0)==(0);
 $12 = ($8|0)<(24);
 $or$cond = $12 & $11;
 if ($or$cond) {
  HEAP32[$1>>2] = $8;
 } else {
  $13 = $9 | 4;
  HEAP32[$4>>2] = $13;
 }
 STACKTOP = sp;return;
}
function __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE13__get_12_hourERiRS4_S4_RjRKNS_5ctypeIwEE($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$byval_copy = 0, $$off = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy = sp + 4|0;
 $6 = sp;
 $7 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $7;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$6>>2]|0;
 $8 = (__ZNSt3__220__get_up_to_n_digitsIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEiRT0_S5_RjRKNS_5ctypeIT_EEi($2,$$byval_copy,$4,$5,2)|0);
 $9 = HEAP32[$4>>2]|0;
 $10 = $9 & 4;
 $11 = ($10|0)==(0);
 $$off = (($8) + -1)|0;
 $12 = ($$off>>>0)<(12);
 $13 = $12 & $11;
 if ($13) {
  HEAP32[$1>>2] = $8;
 } else {
  $14 = $9 | 4;
  HEAP32[$4>>2] = $14;
 }
 STACKTOP = sp;return;
}
function __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE18__get_day_year_numERiRS4_S4_RjRKNS_5ctypeIwEE($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$byval_copy = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy = sp + 4|0;
 $6 = sp;
 $7 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $7;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$6>>2]|0;
 $8 = (__ZNSt3__220__get_up_to_n_digitsIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEiRT0_S5_RjRKNS_5ctypeIT_EEi($2,$$byval_copy,$4,$5,3)|0);
 $9 = HEAP32[$4>>2]|0;
 $10 = $9 & 4;
 $11 = ($10|0)==(0);
 $12 = ($8|0)<(366);
 $or$cond = $12 & $11;
 if ($or$cond) {
  HEAP32[$1>>2] = $8;
 } else {
  $13 = $9 | 4;
  HEAP32[$4>>2] = $13;
 }
 STACKTOP = sp;return;
}
function __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE11__get_monthERiRS4_S4_RjRKNS_5ctypeIwEE($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$byval_copy = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy = sp + 4|0;
 $6 = sp;
 $7 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $7;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$6>>2]|0;
 $8 = (__ZNSt3__220__get_up_to_n_digitsIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEiRT0_S5_RjRKNS_5ctypeIT_EEi($2,$$byval_copy,$4,$5,2)|0);
 $9 = HEAP32[$4>>2]|0;
 $10 = $9 & 4;
 $11 = ($10|0)==(0);
 $12 = ($8|0)<(13);
 $or$cond = $12 & $11;
 if ($or$cond) {
  $13 = (($8) + -1)|0;
  HEAP32[$1>>2] = $13;
 } else {
  $14 = $9 | 4;
  HEAP32[$4>>2] = $14;
 }
 STACKTOP = sp;return;
}
function __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE12__get_minuteERiRS4_S4_RjRKNS_5ctypeIwEE($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$byval_copy = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy = sp + 4|0;
 $6 = sp;
 $7 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $7;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$6>>2]|0;
 $8 = (__ZNSt3__220__get_up_to_n_digitsIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEiRT0_S5_RjRKNS_5ctypeIT_EEi($2,$$byval_copy,$4,$5,2)|0);
 $9 = HEAP32[$4>>2]|0;
 $10 = $9 & 4;
 $11 = ($10|0)==(0);
 $12 = ($8|0)<(60);
 $or$cond = $12 & $11;
 if ($or$cond) {
  HEAP32[$1>>2] = $8;
 } else {
  $13 = $9 | 4;
  HEAP32[$4>>2] = $13;
 }
 STACKTOP = sp;return;
}
function __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE17__get_white_spaceERS4_S4_RjRKNS_5ctypeIwEE($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i7 = 0, $$0$i$i2$i$i = 0, $$0$i$i2$i$i13 = 0, $$pre$i$i$i = 0, $$pre$i$i$i9 = 0, $$pre$i4$i$i15 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $phitmp$i$i$i = 0;
 var $phitmp$i$i$i10 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 L1: while(1) {
  $5 = HEAP32[$1>>2]|0;
  $6 = ($5|0)==(0|0);
  do {
   if ($6) {
    $93 = 1;
   } else {
    $7 = ((($5)) + 12|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = ((($5)) + 16|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = ($8|0)==($10|0);
    if ($11) {
     $12 = HEAP32[$5>>2]|0;
     $13 = ((($12)) + 36|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = (FUNCTION_TABLE_ii[$14 & 8191]($5)|0);
     $$0$i$i$i$i = $15;
    } else {
     $16 = HEAP32[$8>>2]|0;
     $17 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($16)|0);
     $$0$i$i$i$i = $17;
    }
    $18 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
    $19 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i$i$i,$18)|0);
    if ($19) {
     HEAP32[$1>>2] = 0;
     $93 = 1;
     break;
    } else {
     $$pre$i$i$i = HEAP32[$1>>2]|0;
     $phitmp$i$i$i = ($$pre$i$i$i|0)==(0|0);
     $93 = $phitmp$i$i$i;
     break;
    }
   }
  } while(0);
  $20 = HEAP32[$2>>2]|0;
  $21 = ($20|0)==(0|0);
  do {
   if ($21) {
    label = 15;
   } else {
    $22 = ((($20)) + 12|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = ((($20)) + 16|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = ($23|0)==($25|0);
    if ($26) {
     $27 = HEAP32[$20>>2]|0;
     $28 = ((($27)) + 36|0);
     $29 = HEAP32[$28>>2]|0;
     $30 = (FUNCTION_TABLE_ii[$29 & 8191]($20)|0);
     $$0$i$i2$i$i = $30;
    } else {
     $31 = HEAP32[$23>>2]|0;
     $32 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($31)|0);
     $$0$i$i2$i$i = $32;
    }
    $33 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
    $34 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i2$i$i,$33)|0);
    if ($34) {
     HEAP32[$2>>2] = 0;
     label = 15;
     break;
    } else {
     if ($93) {
      $94 = $20;
      break;
     } else {
      $$pre$i4$i$i15 = $20;
      break L1;
     }
    }
   }
  } while(0);
  if ((label|0) == 15) {
   label = 0;
   if ($93) {
    $$pre$i4$i$i15 = 0;
    break;
   } else {
    $94 = 0;
   }
  }
  $35 = HEAP32[$1>>2]|0;
  $36 = ((($35)) + 12|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = ((($35)) + 16|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = ($37|0)==($39|0);
  if ($40) {
   $41 = HEAP32[$35>>2]|0;
   $42 = ((($41)) + 36|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = (FUNCTION_TABLE_ii[$43 & 8191]($35)|0);
   $$0$i$i = $44;
  } else {
   $45 = HEAP32[$37>>2]|0;
   $46 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($45)|0);
   $$0$i$i = $46;
  }
  $47 = HEAP32[$4>>2]|0;
  $48 = ((($47)) + 12|0);
  $49 = HEAP32[$48>>2]|0;
  $50 = (FUNCTION_TABLE_iiii[$49 & 8191]($4,8192,$$0$i$i)|0);
  if (!($50)) {
   $$pre$i4$i$i15 = $94;
   break;
  }
  $51 = HEAP32[$1>>2]|0;
  $52 = ((($51)) + 12|0);
  $53 = HEAP32[$52>>2]|0;
  $54 = ((($51)) + 16|0);
  $55 = HEAP32[$54>>2]|0;
  $56 = ($53|0)==($55|0);
  if ($56) {
   $57 = HEAP32[$51>>2]|0;
   $58 = ((($57)) + 40|0);
   $59 = HEAP32[$58>>2]|0;
   (FUNCTION_TABLE_ii[$59 & 8191]($51)|0);
   continue;
  } else {
   $60 = ((($53)) + 4|0);
   HEAP32[$52>>2] = $60;
   $61 = HEAP32[$53>>2]|0;
   (__ZNSt3__211char_traitsIwE11to_int_typeEw($61)|0);
   continue;
  }
 }
 $62 = HEAP32[$1>>2]|0;
 $63 = ($62|0)==(0|0);
 do {
  if ($63) {
   $95 = 1;
  } else {
   $64 = ((($62)) + 12|0);
   $65 = HEAP32[$64>>2]|0;
   $66 = ((($62)) + 16|0);
   $67 = HEAP32[$66>>2]|0;
   $68 = ($65|0)==($67|0);
   if ($68) {
    $69 = HEAP32[$62>>2]|0;
    $70 = ((($69)) + 36|0);
    $71 = HEAP32[$70>>2]|0;
    $72 = (FUNCTION_TABLE_ii[$71 & 8191]($62)|0);
    $$0$i$i$i$i7 = $72;
   } else {
    $73 = HEAP32[$65>>2]|0;
    $74 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($73)|0);
    $$0$i$i$i$i7 = $74;
   }
   $75 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
   $76 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i$i$i7,$75)|0);
   if ($76) {
    HEAP32[$1>>2] = 0;
    $95 = 1;
    break;
   } else {
    $$pre$i$i$i9 = HEAP32[$1>>2]|0;
    $phitmp$i$i$i10 = ($$pre$i$i$i9|0)==(0|0);
    $95 = $phitmp$i$i$i10;
    break;
   }
  }
 } while(0);
 $77 = ($$pre$i4$i$i15|0)==(0|0);
 do {
  if ($77) {
   label = 37;
  } else {
   $78 = ((($$pre$i4$i$i15)) + 12|0);
   $79 = HEAP32[$78>>2]|0;
   $80 = ((($$pre$i4$i$i15)) + 16|0);
   $81 = HEAP32[$80>>2]|0;
   $82 = ($79|0)==($81|0);
   if ($82) {
    $83 = HEAP32[$$pre$i4$i$i15>>2]|0;
    $84 = ((($83)) + 36|0);
    $85 = HEAP32[$84>>2]|0;
    $86 = (FUNCTION_TABLE_ii[$85 & 8191]($$pre$i4$i$i15)|0);
    $$0$i$i2$i$i13 = $86;
   } else {
    $87 = HEAP32[$79>>2]|0;
    $88 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($87)|0);
    $$0$i$i2$i$i13 = $88;
   }
   $89 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
   $90 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i2$i$i13,$89)|0);
   if ($90) {
    HEAP32[$2>>2] = 0;
    label = 37;
    break;
   } else {
    if ($95) {
     break;
    } else {
     label = 39;
     break;
    }
   }
  }
 } while(0);
 if ((label|0) == 37) {
  if ($95) {
   label = 39;
  }
 }
 if ((label|0) == 39) {
  $91 = HEAP32[$3>>2]|0;
  $92 = $91 | 2;
  HEAP32[$3>>2] = $92;
 }
 return;
}
function __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE11__get_am_pmERiRS4_S4_RjRKNS_5ctypeIwEE($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$byval_copy = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0;
 var $or$cond20 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy = sp + 4|0;
 $6 = sp;
 $7 = ((($0)) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($8)) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (FUNCTION_TABLE_ii[$10 & 8191]($7)|0);
 $12 = ((($11)) + 8|0);
 $13 = ((($12)) + 3|0);
 $14 = HEAP8[$13>>0]|0;
 $15 = ($14<<24>>24)<(0);
 if ($15) {
  $16 = ((($11)) + 4|0);
  $17 = HEAP32[$16>>2]|0;
  $28 = $17;
 } else {
  $18 = $14&255;
  $28 = $18;
 }
 $19 = ((($11)) + 20|0);
 $20 = ((($19)) + 3|0);
 $21 = HEAP8[$20>>0]|0;
 $22 = ($21<<24>>24)<(0);
 if ($22) {
  $23 = ((($11)) + 16|0);
  $24 = HEAP32[$23>>2]|0;
  $27 = $24;
 } else {
  $25 = $21&255;
  $27 = $25;
 }
 $26 = (0 - ($27))|0;
 $29 = ($28|0)==($26|0);
 do {
  if ($29) {
   $30 = HEAP32[$4>>2]|0;
   $31 = $30 | 4;
   HEAP32[$4>>2] = $31;
  } else {
   $32 = HEAP32[$3>>2]|0;
   HEAP32[$6>>2] = $32;
   $33 = ((($11)) + 24|0);
   ;HEAP32[$$byval_copy>>2]=HEAP32[$6>>2]|0;
   $34 = (__ZNSt3__214__scan_keywordINS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEPKNS_12basic_stringIwS3_NS_9allocatorIwEEEENS_5ctypeIwEEEET0_RT_SE_SD_SD_RKT1_Rjb($2,$$byval_copy,$11,$33,$5,$4,0)|0);
   $35 = $34;
   $36 = $11;
   $37 = (($35) - ($36))|0;
   $38 = ($37|0)==(0);
   $39 = HEAP32[$1>>2]|0;
   $40 = ($39|0)==(12);
   $or$cond = $40 & $38;
   if ($or$cond) {
    HEAP32[$1>>2] = 0;
    break;
   }
   $41 = ($37|0)==(12);
   $42 = ($39|0)<(12);
   $or$cond20 = $42 & $41;
   if ($or$cond20) {
    $43 = (($39) + 12)|0;
    HEAP32[$1>>2] = $43;
   }
  }
 } while(0);
 STACKTOP = sp;return;
}
function __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE12__get_secondERiRS4_S4_RjRKNS_5ctypeIwEE($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$byval_copy = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy = sp + 4|0;
 $6 = sp;
 $7 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $7;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$6>>2]|0;
 $8 = (__ZNSt3__220__get_up_to_n_digitsIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEiRT0_S5_RjRKNS_5ctypeIT_EEi($2,$$byval_copy,$4,$5,2)|0);
 $9 = HEAP32[$4>>2]|0;
 $10 = $9 & 4;
 $11 = ($10|0)==(0);
 $12 = ($8|0)<(61);
 $or$cond = $12 & $11;
 if ($or$cond) {
  HEAP32[$1>>2] = $8;
 } else {
  $13 = $9 | 4;
  HEAP32[$4>>2] = $13;
 }
 STACKTOP = sp;return;
}
function __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE13__get_weekdayERiRS4_S4_RjRKNS_5ctypeIwEE($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$byval_copy = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy = sp + 4|0;
 $6 = sp;
 $7 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $7;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$6>>2]|0;
 $8 = (__ZNSt3__220__get_up_to_n_digitsIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEiRT0_S5_RjRKNS_5ctypeIT_EEi($2,$$byval_copy,$4,$5,1)|0);
 $9 = HEAP32[$4>>2]|0;
 $10 = $9 & 4;
 $11 = ($10|0)==(0);
 $12 = ($8|0)<(7);
 $or$cond = $12 & $11;
 if ($or$cond) {
  HEAP32[$1>>2] = $8;
 } else {
  $13 = $9 | 4;
  HEAP32[$4>>2] = $13;
 }
 STACKTOP = sp;return;
}
function __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE10__get_yearERiRS4_S4_RjRKNS_5ctypeIwEE($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$ = 0, $$0 = 0, $$byval_copy = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy = sp + 4|0;
 $6 = sp;
 $7 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $7;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$6>>2]|0;
 $8 = (__ZNSt3__220__get_up_to_n_digitsIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEiRT0_S5_RjRKNS_5ctypeIT_EEi($2,$$byval_copy,$4,$5,4)|0);
 $9 = HEAP32[$4>>2]|0;
 $10 = $9 & 4;
 $11 = ($10|0)==(0);
 if ($11) {
  $12 = ($8|0)<(69);
  if ($12) {
   $13 = (($8) + 2000)|0;
   $$0 = $13;
  } else {
   $14 = ($8|0)<(100);
   $15 = (($8) + 1900)|0;
   $$ = $14 ? $15 : $8;
   $$0 = $$;
  }
  $16 = (($$0) + -1900)|0;
  HEAP32[$1>>2] = $16;
 }
 STACKTOP = sp;return;
}
function __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE11__get_year4ERiRS4_S4_RjRKNS_5ctypeIwEE($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$byval_copy = 0, $10 = 0, $11 = 0, $12 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy = sp + 4|0;
 $6 = sp;
 $7 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $7;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$6>>2]|0;
 $8 = (__ZNSt3__220__get_up_to_n_digitsIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEiRT0_S5_RjRKNS_5ctypeIT_EEi($2,$$byval_copy,$4,$5,4)|0);
 $9 = HEAP32[$4>>2]|0;
 $10 = $9 & 4;
 $11 = ($10|0)==(0);
 if ($11) {
  $12 = (($8) + -1900)|0;
  HEAP32[$1>>2] = $12;
 }
 STACKTOP = sp;return;
}
function __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE13__get_percentERS4_S4_RjRKNS_5ctypeIwEE($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i11 = 0, $$0$i$i2$i$i = 0, $$0$i$i2$i$i17 = 0, $$pre$i$i$i = 0, $$pre$i$i$i13 = 0, $$pre$i4$i$i1925 = 0, $$sink3 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $phitmp$i$i$i = 0, $phitmp$i$i$i14 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = HEAP32[$1>>2]|0;
 $6 = ($5|0)==(0|0);
 do {
  if ($6) {
   $94 = 1;
  } else {
   $7 = ((($5)) + 12|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ((($5)) + 16|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($8|0)==($10|0);
   if ($11) {
    $12 = HEAP32[$5>>2]|0;
    $13 = ((($12)) + 36|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = (FUNCTION_TABLE_ii[$14 & 8191]($5)|0);
    $$0$i$i$i$i = $15;
   } else {
    $16 = HEAP32[$8>>2]|0;
    $17 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($16)|0);
    $$0$i$i$i$i = $17;
   }
   $18 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
   $19 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i$i$i,$18)|0);
   if ($19) {
    HEAP32[$1>>2] = 0;
    $94 = 1;
    break;
   } else {
    $$pre$i$i$i = HEAP32[$1>>2]|0;
    $phitmp$i$i$i = ($$pre$i$i$i|0)==(0|0);
    $94 = $phitmp$i$i$i;
    break;
   }
  }
 } while(0);
 $20 = HEAP32[$2>>2]|0;
 $21 = ($20|0)==(0|0);
 do {
  if ($21) {
   label = 14;
  } else {
   $22 = ((($20)) + 12|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = ((($20)) + 16|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = ($23|0)==($25|0);
   if ($26) {
    $27 = HEAP32[$20>>2]|0;
    $28 = ((($27)) + 36|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = (FUNCTION_TABLE_ii[$29 & 8191]($20)|0);
    $$0$i$i2$i$i = $30;
   } else {
    $31 = HEAP32[$23>>2]|0;
    $32 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($31)|0);
    $$0$i$i2$i$i = $32;
   }
   $33 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
   $34 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i2$i$i,$33)|0);
   if ($34) {
    HEAP32[$2>>2] = 0;
    label = 14;
    break;
   } else {
    if ($94) {
     $$pre$i4$i$i1925 = $20;
     label = 16;
     break;
    } else {
     $$sink3 = 6;
     label = 38;
     break;
    }
   }
  }
 } while(0);
 if ((label|0) == 14) {
  if ($94) {
   $$sink3 = 6;
   label = 38;
  } else {
   $$pre$i4$i$i1925 = 0;
   label = 16;
  }
 }
 L22: do {
  if ((label|0) == 16) {
   $35 = HEAP32[$1>>2]|0;
   $36 = ((($35)) + 12|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = ((($35)) + 16|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = ($37|0)==($39|0);
   if ($40) {
    $41 = HEAP32[$35>>2]|0;
    $42 = ((($41)) + 36|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = (FUNCTION_TABLE_ii[$43 & 8191]($35)|0);
    $$0$i$i = $44;
   } else {
    $45 = HEAP32[$37>>2]|0;
    $46 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($45)|0);
    $$0$i$i = $46;
   }
   $47 = HEAP32[$4>>2]|0;
   $48 = ((($47)) + 52|0);
   $49 = HEAP32[$48>>2]|0;
   $50 = (FUNCTION_TABLE_iiii[$49 & 8191]($4,$$0$i$i,0)|0);
   $51 = ($50<<24>>24)==(37);
   if ($51) {
    $52 = HEAP32[$1>>2]|0;
    $53 = ((($52)) + 12|0);
    $54 = HEAP32[$53>>2]|0;
    $55 = ((($52)) + 16|0);
    $56 = HEAP32[$55>>2]|0;
    $57 = ($54|0)==($56|0);
    if ($57) {
     $58 = HEAP32[$52>>2]|0;
     $59 = ((($58)) + 40|0);
     $60 = HEAP32[$59>>2]|0;
     (FUNCTION_TABLE_ii[$60 & 8191]($52)|0);
    } else {
     $61 = ((($54)) + 4|0);
     HEAP32[$53>>2] = $61;
     $62 = HEAP32[$54>>2]|0;
     (__ZNSt3__211char_traitsIwE11to_int_typeEw($62)|0);
    }
    $63 = HEAP32[$1>>2]|0;
    $64 = ($63|0)==(0|0);
    do {
     if ($64) {
      $95 = 1;
     } else {
      $65 = ((($63)) + 12|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = ((($63)) + 16|0);
      $68 = HEAP32[$67>>2]|0;
      $69 = ($66|0)==($68|0);
      if ($69) {
       $70 = HEAP32[$63>>2]|0;
       $71 = ((($70)) + 36|0);
       $72 = HEAP32[$71>>2]|0;
       $73 = (FUNCTION_TABLE_ii[$72 & 8191]($63)|0);
       $$0$i$i$i$i11 = $73;
      } else {
       $74 = HEAP32[$66>>2]|0;
       $75 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($74)|0);
       $$0$i$i$i$i11 = $75;
      }
      $76 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
      $77 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i$i$i11,$76)|0);
      if ($77) {
       HEAP32[$1>>2] = 0;
       $95 = 1;
       break;
      } else {
       $$pre$i$i$i13 = HEAP32[$1>>2]|0;
       $phitmp$i$i$i14 = ($$pre$i$i$i13|0)==(0|0);
       $95 = $phitmp$i$i$i14;
       break;
      }
     }
    } while(0);
    $78 = ($$pre$i4$i$i1925|0)==(0|0);
    do {
     if (!($78)) {
      $79 = ((($$pre$i4$i$i1925)) + 12|0);
      $80 = HEAP32[$79>>2]|0;
      $81 = ((($$pre$i4$i$i1925)) + 16|0);
      $82 = HEAP32[$81>>2]|0;
      $83 = ($80|0)==($82|0);
      if ($83) {
       $84 = HEAP32[$$pre$i4$i$i1925>>2]|0;
       $85 = ((($84)) + 36|0);
       $86 = HEAP32[$85>>2]|0;
       $87 = (FUNCTION_TABLE_ii[$86 & 8191]($$pre$i4$i$i1925)|0);
       $$0$i$i2$i$i17 = $87;
      } else {
       $88 = HEAP32[$80>>2]|0;
       $89 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($88)|0);
       $$0$i$i2$i$i17 = $89;
      }
      $90 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
      $91 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i2$i$i17,$90)|0);
      if ($91) {
       HEAP32[$2>>2] = 0;
       break;
      } else {
       if ($95) {
        break L22;
       } else {
        $$sink3 = 2;
        label = 38;
        break L22;
       }
      }
     }
    } while(0);
    if ($95) {
     $$sink3 = 2;
     label = 38;
    }
   } else {
    $$sink3 = 4;
    label = 38;
   }
  }
 } while(0);
 if ((label|0) == 38) {
  $92 = HEAP32[$3>>2]|0;
  $93 = $92 | $$sink3;
  HEAP32[$3>>2] = $93;
 }
 return;
}
function __ZNSt3__220__get_up_to_n_digitsIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEiRT0_S5_RjRKNS_5ctypeIT_EEi($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0 = 0, $$0$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i27 = 0, $$0$i$i$i$i42 = 0, $$0$i$i2$i$i = 0, $$0$i$i2$i$i33 = 0, $$0$i$i2$i$i48 = 0, $$0$i$i39 = 0, $$0$in = 0, $$025 = 0, $$025$in = 0, $$2 = 0, $$pre$i$i$i = 0, $$pre$i$i$i29 = 0, $$pre$i$i$i44 = 0, $$pre$i4$i$i35 = 0, $$pre$i4$i$i50 = 0, $10 = 0, $100 = 0;
 var $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0;
 var $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0;
 var $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0;
 var $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $18 = 0;
 var $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $phitmp$i$i$i = 0, $phitmp$i$i$i30 = 0, $phitmp$i$i$i45 = 0, $phitmp$i5$i$i36 = 0, $tmp$i$i38 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = HEAP32[$0>>2]|0;
 $6 = ($5|0)==(0|0);
 do {
  if ($6) {
   $169 = 1;
  } else {
   $7 = ((($5)) + 12|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ((($5)) + 16|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($8|0)==($10|0);
   if ($11) {
    $12 = HEAP32[$5>>2]|0;
    $13 = ((($12)) + 36|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = (FUNCTION_TABLE_ii[$14 & 8191]($5)|0);
    $$0$i$i$i$i = $15;
   } else {
    $16 = HEAP32[$8>>2]|0;
    $17 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($16)|0);
    $$0$i$i$i$i = $17;
   }
   $18 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
   $19 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i$i$i,$18)|0);
   if ($19) {
    HEAP32[$0>>2] = 0;
    $169 = 1;
    break;
   } else {
    $$pre$i$i$i = HEAP32[$0>>2]|0;
    $phitmp$i$i$i = ($$pre$i$i$i|0)==(0|0);
    $169 = $phitmp$i$i$i;
    break;
   }
  }
 } while(0);
 $20 = HEAP32[$1>>2]|0;
 $21 = ($20|0)==(0|0);
 do {
  if ($21) {
   label = 14;
  } else {
   $22 = ((($20)) + 12|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = ((($20)) + 16|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = ($23|0)==($25|0);
   if ($26) {
    $27 = HEAP32[$20>>2]|0;
    $28 = ((($27)) + 36|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = (FUNCTION_TABLE_ii[$29 & 8191]($20)|0);
    $$0$i$i2$i$i = $30;
   } else {
    $31 = HEAP32[$23>>2]|0;
    $32 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($31)|0);
    $$0$i$i2$i$i = $32;
   }
   $33 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
   $34 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i2$i$i,$33)|0);
   if ($34) {
    HEAP32[$1>>2] = 0;
    label = 14;
    break;
   } else {
    if ($169) {
     $170 = $20;
     label = 17;
     break;
    } else {
     label = 16;
     break;
    }
   }
  }
 } while(0);
 if ((label|0) == 14) {
  if ($169) {
   label = 16;
  } else {
   $170 = 0;
   label = 17;
  }
 }
 L22: do {
  if ((label|0) == 16) {
   $35 = HEAP32[$2>>2]|0;
   $36 = $35 | 6;
   HEAP32[$2>>2] = $36;
   $$2 = 0;
  }
  else if ((label|0) == 17) {
   $37 = HEAP32[$0>>2]|0;
   $38 = ((($37)) + 12|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = ((($37)) + 16|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = ($39|0)==($41|0);
   if ($42) {
    $43 = HEAP32[$37>>2]|0;
    $44 = ((($43)) + 36|0);
    $45 = HEAP32[$44>>2]|0;
    $46 = (FUNCTION_TABLE_ii[$45 & 8191]($37)|0);
    $$0$i$i = $46;
   } else {
    $47 = HEAP32[$39>>2]|0;
    $48 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($47)|0);
    $$0$i$i = $48;
   }
   $49 = HEAP32[$3>>2]|0;
   $50 = ((($49)) + 12|0);
   $51 = HEAP32[$50>>2]|0;
   $52 = (FUNCTION_TABLE_iiii[$51 & 8191]($3,2048,$$0$i$i)|0);
   if (!($52)) {
    $53 = HEAP32[$2>>2]|0;
    $54 = $53 | 4;
    HEAP32[$2>>2] = $54;
    $$2 = 0;
    break;
   }
   $55 = HEAP32[$3>>2]|0;
   $56 = ((($55)) + 52|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = (FUNCTION_TABLE_iiii[$57 & 8191]($3,$$0$i$i,0)|0);
   $59 = $58 << 24 >> 24;
   $60 = HEAP32[$0>>2]|0;
   $61 = ((($60)) + 12|0);
   $62 = HEAP32[$61>>2]|0;
   $63 = ((($60)) + 16|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = ($62|0)==($64|0);
   if ($65) {
    $66 = HEAP32[$60>>2]|0;
    $67 = ((($66)) + 40|0);
    $68 = HEAP32[$67>>2]|0;
    (FUNCTION_TABLE_ii[$68 & 8191]($60)|0);
    $$0$in = $59;$$025$in = $4;$$pre$i4$i$i35 = $170;$86 = $170;
   } else {
    $69 = ((($62)) + 4|0);
    HEAP32[$61>>2] = $69;
    $70 = HEAP32[$62>>2]|0;
    (__ZNSt3__211char_traitsIwE11to_int_typeEw($70)|0);
    $$0$in = $59;$$025$in = $4;$$pre$i4$i$i35 = $170;$86 = $170;
   }
   while(1) {
    $$0 = (($$0$in) + -48)|0;
    $$025 = (($$025$in) + -1)|0;
    $71 = HEAP32[$0>>2]|0;
    $72 = ($71|0)==(0|0);
    do {
     if ($72) {
      $102 = 1;
     } else {
      $73 = ((($71)) + 12|0);
      $74 = HEAP32[$73>>2]|0;
      $75 = ((($71)) + 16|0);
      $76 = HEAP32[$75>>2]|0;
      $77 = ($74|0)==($76|0);
      if ($77) {
       $78 = HEAP32[$71>>2]|0;
       $79 = ((($78)) + 36|0);
       $80 = HEAP32[$79>>2]|0;
       $81 = (FUNCTION_TABLE_ii[$80 & 8191]($71)|0);
       $$0$i$i$i$i27 = $81;
      } else {
       $82 = HEAP32[$74>>2]|0;
       $83 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($82)|0);
       $$0$i$i$i$i27 = $83;
      }
      $84 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
      $85 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i$i$i27,$84)|0);
      if ($85) {
       HEAP32[$0>>2] = 0;
       $102 = 1;
       break;
      } else {
       $$pre$i$i$i29 = HEAP32[$0>>2]|0;
       $phitmp$i$i$i30 = ($$pre$i$i$i29|0)==(0|0);
       $102 = $phitmp$i$i$i30;
       break;
      }
     }
    } while(0);
    $87 = ($86|0)==(0|0);
    do {
     if ($87) {
      $$pre$i4$i$i50 = $$pre$i4$i$i35;$101 = 1;$171 = 0;
     } else {
      $88 = ((($86)) + 12|0);
      $89 = HEAP32[$88>>2]|0;
      $90 = ((($86)) + 16|0);
      $91 = HEAP32[$90>>2]|0;
      $92 = ($89|0)==($91|0);
      if ($92) {
       $93 = HEAP32[$86>>2]|0;
       $94 = ((($93)) + 36|0);
       $95 = HEAP32[$94>>2]|0;
       $96 = (FUNCTION_TABLE_ii[$95 & 8191]($86)|0);
       $$0$i$i2$i$i33 = $96;
      } else {
       $97 = HEAP32[$89>>2]|0;
       $98 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($97)|0);
       $$0$i$i2$i$i33 = $98;
      }
      $99 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
      $100 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i2$i$i33,$99)|0);
      if ($100) {
       HEAP32[$1>>2] = 0;
       $$pre$i4$i$i50 = 0;$101 = 1;$171 = 0;
       break;
      } else {
       $phitmp$i5$i$i36 = ($$pre$i4$i$i35|0)==(0|0);
       $$pre$i4$i$i50 = $$pre$i4$i$i35;$101 = $phitmp$i5$i$i36;$171 = $$pre$i4$i$i35;
       break;
      }
     }
    } while(0);
    $tmp$i$i38 = $102 ^ $101;
    $103 = ($$025$in|0)>(1);
    $104 = $103 & $tmp$i$i38;
    $105 = HEAP32[$0>>2]|0;
    if (!($104)) {
     break;
    }
    $106 = ((($105)) + 12|0);
    $107 = HEAP32[$106>>2]|0;
    $108 = ((($105)) + 16|0);
    $109 = HEAP32[$108>>2]|0;
    $110 = ($107|0)==($109|0);
    if ($110) {
     $111 = HEAP32[$105>>2]|0;
     $112 = ((($111)) + 36|0);
     $113 = HEAP32[$112>>2]|0;
     $114 = (FUNCTION_TABLE_ii[$113 & 8191]($105)|0);
     $$0$i$i39 = $114;
    } else {
     $115 = HEAP32[$107>>2]|0;
     $116 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($115)|0);
     $$0$i$i39 = $116;
    }
    $117 = HEAP32[$3>>2]|0;
    $118 = ((($117)) + 12|0);
    $119 = HEAP32[$118>>2]|0;
    $120 = (FUNCTION_TABLE_iiii[$119 & 8191]($3,2048,$$0$i$i39)|0);
    if (!($120)) {
     $$2 = $$0;
     break L22;
    }
    $121 = ($$0*10)|0;
    $122 = HEAP32[$3>>2]|0;
    $123 = ((($122)) + 52|0);
    $124 = HEAP32[$123>>2]|0;
    $125 = (FUNCTION_TABLE_iiii[$124 & 8191]($3,$$0$i$i39,0)|0);
    $126 = $125 << 24 >> 24;
    $127 = (($126) + ($121))|0;
    $128 = HEAP32[$0>>2]|0;
    $129 = ((($128)) + 12|0);
    $130 = HEAP32[$129>>2]|0;
    $131 = ((($128)) + 16|0);
    $132 = HEAP32[$131>>2]|0;
    $133 = ($130|0)==($132|0);
    if ($133) {
     $134 = HEAP32[$128>>2]|0;
     $135 = ((($134)) + 40|0);
     $136 = HEAP32[$135>>2]|0;
     (FUNCTION_TABLE_ii[$136 & 8191]($128)|0);
     $$0$in = $127;$$025$in = $$025;$$pre$i4$i$i35 = $$pre$i4$i$i50;$86 = $171;
     continue;
    } else {
     $137 = ((($130)) + 4|0);
     HEAP32[$129>>2] = $137;
     $138 = HEAP32[$130>>2]|0;
     (__ZNSt3__211char_traitsIwE11to_int_typeEw($138)|0);
     $$0$in = $127;$$025$in = $$025;$$pre$i4$i$i35 = $$pre$i4$i$i50;$86 = $171;
     continue;
    }
   }
   $139 = ($105|0)==(0|0);
   do {
    if ($139) {
     $172 = 1;
    } else {
     $140 = ((($105)) + 12|0);
     $141 = HEAP32[$140>>2]|0;
     $142 = ((($105)) + 16|0);
     $143 = HEAP32[$142>>2]|0;
     $144 = ($141|0)==($143|0);
     if ($144) {
      $145 = HEAP32[$105>>2]|0;
      $146 = ((($145)) + 36|0);
      $147 = HEAP32[$146>>2]|0;
      $148 = (FUNCTION_TABLE_ii[$147 & 8191]($105)|0);
      $$0$i$i$i$i42 = $148;
     } else {
      $149 = HEAP32[$141>>2]|0;
      $150 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($149)|0);
      $$0$i$i$i$i42 = $150;
     }
     $151 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
     $152 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i$i$i42,$151)|0);
     if ($152) {
      HEAP32[$0>>2] = 0;
      $172 = 1;
      break;
     } else {
      $$pre$i$i$i44 = HEAP32[$0>>2]|0;
      $phitmp$i$i$i45 = ($$pre$i$i$i44|0)==(0|0);
      $172 = $phitmp$i$i$i45;
      break;
     }
    }
   } while(0);
   $153 = ($$pre$i4$i$i50|0)==(0|0);
   do {
    if ($153) {
     label = 60;
    } else {
     $154 = ((($$pre$i4$i$i50)) + 12|0);
     $155 = HEAP32[$154>>2]|0;
     $156 = ((($$pre$i4$i$i50)) + 16|0);
     $157 = HEAP32[$156>>2]|0;
     $158 = ($155|0)==($157|0);
     if ($158) {
      $159 = HEAP32[$$pre$i4$i$i50>>2]|0;
      $160 = ((($159)) + 36|0);
      $161 = HEAP32[$160>>2]|0;
      $162 = (FUNCTION_TABLE_ii[$161 & 8191]($$pre$i4$i$i50)|0);
      $$0$i$i2$i$i48 = $162;
     } else {
      $163 = HEAP32[$155>>2]|0;
      $164 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($163)|0);
      $$0$i$i2$i$i48 = $164;
     }
     $165 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
     $166 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i2$i$i48,$165)|0);
     if ($166) {
      HEAP32[$1>>2] = 0;
      label = 60;
      break;
     } else {
      if ($172) {
       $$2 = $$0;
       break L22;
      } else {
       break;
      }
     }
    }
   } while(0);
   if ((label|0) == 60) {
    if (!($172)) {
     $$2 = $$0;
     break;
    }
   }
   $167 = HEAP32[$2>>2]|0;
   $168 = $167 | 2;
   HEAP32[$2>>2] = $168;
   $$2 = $$0;
  }
 } while(0);
 return ($$2|0);
}
function __ZNSt3__28time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 8|0);
 __ZNSt3__210__time_putD2Ev($1);
 __ZNSt3__26locale5facetD2Ev($0);
 return;
}
function __ZNSt3__28time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEED0Ev($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 8|0);
 __ZNSt3__210__time_putD2Ev($1);
 __ZNSt3__26locale5facetD2Ev($0);
 __ZdlPv($0);
 return;
}
function __ZNKSt3__28time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcPK2tmcc($0,$1,$2,$3,$4,$5,$6) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 var $$$sroa$04$0$i = 0, $$0$i$i = 0, $$0$i$i$i$i = 0, $$sroa$04$0$i = 0, $$sroa$04$1$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(112|0);
 $7 = sp + 4|0;
 $8 = sp;
 $9 = ((($7)) + 100|0);
 HEAP32[$8>>2] = $9;
 $10 = ((($0)) + 8|0);
 __ZNKSt3__210__time_put8__do_putEPcRS1_PK2tmcc($10,$7,$8,$4,$5,$6);
 $11 = HEAP32[$8>>2]|0;
 $12 = HEAP32[$1>>2]|0;
 $$0$i$i = $7;$$sroa$04$0$i = $12;
 while(1) {
  $13 = ($$0$i$i|0)==($11|0);
  if ($13) {
   break;
  }
  $14 = HEAP8[$$0$i$i>>0]|0;
  $15 = ($$sroa$04$0$i|0)==(0|0);
  if ($15) {
   $$sroa$04$1$i = 0;
  } else {
   $16 = ((($$sroa$04$0$i)) + 24|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = ((($$sroa$04$0$i)) + 28|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ($17|0)==($19|0);
   if ($20) {
    $21 = HEAP32[$$sroa$04$0$i>>2]|0;
    $22 = ((($21)) + 52|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($14)|0);
    $25 = (FUNCTION_TABLE_iii[$23 & 8191]($$sroa$04$0$i,$24)|0);
    $$0$i$i$i$i = $25;
   } else {
    $26 = ((($17)) + 1|0);
    HEAP32[$16>>2] = $26;
    HEAP8[$17>>0] = $14;
    $27 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($14)|0);
    $$0$i$i$i$i = $27;
   }
   $28 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
   $29 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i$i$i,$28)|0);
   $$$sroa$04$0$i = $29 ? 0 : $$sroa$04$0$i;
   $$sroa$04$1$i = $$$sroa$04$0$i;
  }
  $30 = ((($$0$i$i)) + 1|0);
  $$0$i$i = $30;$$sroa$04$0$i = $$sroa$04$1$i;
 }
 STACKTOP = sp;return ($$sroa$04$0$i|0);
}
function __ZNKSt3__210__time_put8__do_putEPcRS1_PK2tmcc($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $6 = sp;
 HEAP8[$6>>0] = 37;
 $7 = ((($6)) + 1|0);
 HEAP8[$7>>0] = $4;
 $8 = ((($6)) + 2|0);
 HEAP8[$8>>0] = $5;
 $9 = ((($6)) + 3|0);
 HEAP8[$9>>0] = 0;
 $10 = ($5<<24>>24)==(0);
 if (!($10)) {
  HEAP8[$7>>0] = $5;
  HEAP8[$8>>0] = $4;
 }
 $11 = HEAP32[$2>>2]|0;
 $12 = (__ZNSt3__212_GLOBAL__N_17countofIcEEjPKT_S4_($1,$11)|0);
 $13 = HEAP32[$0>>2]|0;
 $14 = (_strftime_l(($1|0),($12|0),($6|0),($3|0),($13|0))|0);
 $15 = (($1) + ($14)|0);
 HEAP32[$2>>2] = $15;
 STACKTOP = sp;return;
}
function __ZNSt3__212_GLOBAL__N_17countofIcEEjPKT_S4_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = $1;
 $3 = $0;
 $4 = (($2) - ($3))|0;
 return ($4|0);
}
function __ZNSt3__210__time_putD2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 $2 = (invoke_i(4668)|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 do {
  if (!($4)) {
   $5 = ($1|0)==($2|0);
   if (!($5)) {
    $6 = HEAP32[$0>>2]|0;
    __THREW__ = 0;
    invoke_vi(4713,($6|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     break;
    }
   }
   return;
  }
 } while(0);
 $9 = ___cxa_find_matching_catch_3(0|0)|0;
 $10 = tempRet0;
 ___clang_call_terminate($9);
 // unreachable;
}
function __ZNSt3__28time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 8|0);
 __ZNSt3__210__time_putD2Ev($1);
 __ZNSt3__26locale5facetD2Ev($0);
 return;
}
function __ZNSt3__28time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEED0Ev($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 8|0);
 __ZNSt3__210__time_putD2Ev($1);
 __ZNSt3__26locale5facetD2Ev($0);
 __ZdlPv($0);
 return;
}
function __ZNKSt3__28time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwPK2tmcc($0,$1,$2,$3,$4,$5,$6) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 var $$$sroa$04$0$i = 0, $$0$i$i = 0, $$0$i$i$i$i = 0, $$sroa$04$0$i = 0, $$sroa$04$1$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 416|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(416|0);
 $7 = sp + 8|0;
 $8 = sp;
 $9 = ((($7)) + 400|0);
 HEAP32[$8>>2] = $9;
 $10 = ((($0)) + 8|0);
 __ZNKSt3__210__time_put8__do_putEPwRS1_PK2tmcc($10,$7,$8,$4,$5,$6);
 $11 = HEAP32[$8>>2]|0;
 $12 = HEAP32[$1>>2]|0;
 $$0$i$i = $7;$$sroa$04$0$i = $12;
 while(1) {
  $13 = ($$0$i$i|0)==($11|0);
  if ($13) {
   break;
  }
  $14 = HEAP32[$$0$i$i>>2]|0;
  $15 = ($$sroa$04$0$i|0)==(0|0);
  if ($15) {
   $$sroa$04$1$i = 0;
  } else {
   $16 = ((($$sroa$04$0$i)) + 24|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = ((($$sroa$04$0$i)) + 28|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ($17|0)==($19|0);
   if ($20) {
    $21 = HEAP32[$$sroa$04$0$i>>2]|0;
    $22 = ((($21)) + 52|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($14)|0);
    $25 = (FUNCTION_TABLE_iii[$23 & 8191]($$sroa$04$0$i,$24)|0);
    $$0$i$i$i$i = $25;
   } else {
    $26 = ((($17)) + 4|0);
    HEAP32[$16>>2] = $26;
    HEAP32[$17>>2] = $14;
    $27 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($14)|0);
    $$0$i$i$i$i = $27;
   }
   $28 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
   $29 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i$i$i,$28)|0);
   $$$sroa$04$0$i = $29 ? 0 : $$sroa$04$0$i;
   $$sroa$04$1$i = $$$sroa$04$0$i;
  }
  $30 = ((($$0$i$i)) + 4|0);
  $$0$i$i = $30;$$sroa$04$0$i = $$sroa$04$1$i;
 }
 STACKTOP = sp;return ($$sroa$04$0$i|0);
}
function __ZNKSt3__210__time_put8__do_putEPwRS1_PK2tmcc($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(128|0);
 $6 = sp + 16|0;
 $7 = sp + 12|0;
 $8 = sp;
 $9 = sp + 8|0;
 $10 = ((($6)) + 100|0);
 HEAP32[$7>>2] = $10;
 __ZNKSt3__210__time_put8__do_putEPcRS1_PK2tmcc($0,$6,$7,$3,$4,$5);
 $11 = $8;
 $12 = $11;
 HEAP32[$12>>2] = 0;
 $13 = (($11) + 4)|0;
 $14 = $13;
 HEAP32[$14>>2] = 0;
 HEAP32[$9>>2] = $6;
 $15 = HEAP32[$2>>2]|0;
 $16 = (__ZNSt3__212_GLOBAL__N_17countofIwEEjPKT_S4_($1,$15)|0);
 $17 = HEAP32[$0>>2]|0;
 $18 = (___uselocale($17)|0);
 __THREW__ = 0;
 $19 = (invoke_iiiii(4714,($1|0),($9|0),($16|0),($8|0))|0);
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if ($21) {
  $27 = ___cxa_find_matching_catch_2()|0;
  $28 = tempRet0;
  $29 = ($18|0)==(0|0);
  if (!($29)) {
   __THREW__ = 0;
   (invoke_ii(4671,($18|0))|0);
   $30 = __THREW__; __THREW__ = 0;
   $31 = $30&1;
   if ($31) {
    $32 = ___cxa_find_matching_catch_3(0|0)|0;
    $33 = tempRet0;
    ___clang_call_terminate($32);
    // unreachable;
   }
  }
  ___resumeException($27|0);
  // unreachable;
 }
 $22 = ($18|0)==(0|0);
 if (!($22)) {
  __THREW__ = 0;
  (invoke_ii(4671,($18|0))|0);
  $23 = __THREW__; __THREW__ = 0;
  $24 = $23&1;
  if ($24) {
   $25 = ___cxa_find_matching_catch_3(0|0)|0;
   $26 = tempRet0;
   ___clang_call_terminate($25);
   // unreachable;
  }
 }
 $34 = ($19|0)==(-1);
 if ($34) {
  __ZNSt3__221__throw_runtime_errorEPKc(203716);
  // unreachable;
 } else {
  $35 = (($1) + ($19<<2)|0);
  HEAP32[$2>>2] = $35;
  STACKTOP = sp;return;
 }
}
function __ZNSt3__212_GLOBAL__N_17countofIwEEjPKT_S4_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = $1;
 $3 = $0;
 $4 = (($2) - ($3))|0;
 $5 = $4 >> 2;
 return ($5|0);
}
function __ZNSt3__221__throw_runtime_errorEPKc($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (___cxa_allocate_exception(8)|0);
 __THREW__ = 0;
 invoke_vii(4715,($1|0),($0|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch_2()|0;
  $5 = tempRet0;
  ___cxa_free_exception(($1|0));
  ___resumeException($4|0);
  // unreachable;
 } else {
  ___cxa_throw(($1|0),(34576|0),(3233|0));
  // unreachable;
 }
}
function __ZNSt3__210moneypunctIcLb0EED2Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__26locale5facetD2Ev($0);
 return;
}
function __ZNSt3__210moneypunctIcLb0EED0Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__26locale5facetD2Ev($0);
 __ZdlPv($0);
 return;
}
function __ZNKSt3__210moneypunctIcLb0EE16do_decimal_pointEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 127;
}
function __ZNKSt3__210moneypunctIcLb0EE16do_thousands_sepEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 127;
}
function __ZNKSt3__210moneypunctIcLb0EE11do_groupingEv($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i = 0, $2 = 0, $3 = 0, $exitcond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 ;HEAP32[$0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;
 $$0$i$i = 0;
 while(1) {
  $exitcond$i$i = ($$0$i$i|0)==(3);
  if ($exitcond$i$i) {
   break;
  }
  $2 = (($0) + ($$0$i$i<<2)|0);
  HEAP32[$2>>2] = 0;
  $3 = (($$0$i$i) + 1)|0;
  $$0$i$i = $3;
 }
 return;
}
function __ZNKSt3__210moneypunctIcLb0EE14do_curr_symbolEv($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i = 0, $2 = 0, $3 = 0, $exitcond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 ;HEAP32[$0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;
 $$0$i$i = 0;
 while(1) {
  $exitcond$i$i = ($$0$i$i|0)==(3);
  if ($exitcond$i$i) {
   break;
  }
  $2 = (($0) + ($$0$i$i<<2)|0);
  HEAP32[$2>>2] = 0;
  $3 = (($$0$i$i) + 1)|0;
  $$0$i$i = $3;
 }
 return;
}
function __ZNKSt3__210moneypunctIcLb0EE16do_positive_signEv($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i = 0, $2 = 0, $3 = 0, $exitcond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 ;HEAP32[$0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;
 $$0$i$i = 0;
 while(1) {
  $exitcond$i$i = ($$0$i$i|0)==(3);
  if ($exitcond$i$i) {
   break;
  }
  $2 = (($0) + ($$0$i$i<<2)|0);
  HEAP32[$2>>2] = 0;
  $3 = (($$0$i$i) + 1)|0;
  $$0$i$i = $3;
 }
 return;
}
function __ZNKSt3__210moneypunctIcLb0EE16do_negative_signEv($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 ;HEAP32[$0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;
 $3 = ((($0)) + 11|0);
 HEAP8[$3>>0] = 1;
 (__ZNSt3__211char_traitsIcE6assignEPcjc($0,1,45)|0);
 $4 = ((($0)) + 1|0);
 HEAP8[$2>>0] = 0;
 __ZNSt3__211char_traitsIcE6assignERcRKc($4,$2);
 STACKTOP = sp;return;
}
function __ZNKSt3__210moneypunctIcLb0EE14do_frac_digitsEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function __ZNKSt3__210moneypunctIcLb0EE13do_pos_formatEv($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP8[$0>>0]=67109634&255;HEAP8[$0+1>>0]=(67109634>>8)&255;HEAP8[$0+2>>0]=(67109634>>16)&255;HEAP8[$0+3>>0]=67109634>>24;
 return;
}
function __ZNKSt3__210moneypunctIcLb0EE13do_neg_formatEv($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP8[$0>>0]=67109634&255;HEAP8[$0+1>>0]=(67109634>>8)&255;HEAP8[$0+2>>0]=(67109634>>16)&255;HEAP8[$0+3>>0]=67109634>>24;
 return;
}
function __ZNSt3__210moneypunctIcLb1EED2Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__26locale5facetD2Ev($0);
 return;
}
function __ZNSt3__210moneypunctIcLb1EED0Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__26locale5facetD2Ev($0);
 __ZdlPv($0);
 return;
}
function __ZNKSt3__210moneypunctIcLb1EE16do_decimal_pointEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 127;
}
function __ZNKSt3__210moneypunctIcLb1EE16do_thousands_sepEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 127;
}
function __ZNKSt3__210moneypunctIcLb1EE11do_groupingEv($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i = 0, $2 = 0, $3 = 0, $exitcond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 ;HEAP32[$0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;
 $$0$i$i = 0;
 while(1) {
  $exitcond$i$i = ($$0$i$i|0)==(3);
  if ($exitcond$i$i) {
   break;
  }
  $2 = (($0) + ($$0$i$i<<2)|0);
  HEAP32[$2>>2] = 0;
  $3 = (($$0$i$i) + 1)|0;
  $$0$i$i = $3;
 }
 return;
}
function __ZNKSt3__210moneypunctIcLb1EE14do_curr_symbolEv($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i = 0, $2 = 0, $3 = 0, $exitcond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 ;HEAP32[$0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;
 $$0$i$i = 0;
 while(1) {
  $exitcond$i$i = ($$0$i$i|0)==(3);
  if ($exitcond$i$i) {
   break;
  }
  $2 = (($0) + ($$0$i$i<<2)|0);
  HEAP32[$2>>2] = 0;
  $3 = (($$0$i$i) + 1)|0;
  $$0$i$i = $3;
 }
 return;
}
function __ZNKSt3__210moneypunctIcLb1EE16do_positive_signEv($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i = 0, $2 = 0, $3 = 0, $exitcond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 ;HEAP32[$0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;
 $$0$i$i = 0;
 while(1) {
  $exitcond$i$i = ($$0$i$i|0)==(3);
  if ($exitcond$i$i) {
   break;
  }
  $2 = (($0) + ($$0$i$i<<2)|0);
  HEAP32[$2>>2] = 0;
  $3 = (($$0$i$i) + 1)|0;
  $$0$i$i = $3;
 }
 return;
}
function __ZNKSt3__210moneypunctIcLb1EE16do_negative_signEv($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 ;HEAP32[$0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;
 $3 = ((($0)) + 11|0);
 HEAP8[$3>>0] = 1;
 (__ZNSt3__211char_traitsIcE6assignEPcjc($0,1,45)|0);
 $4 = ((($0)) + 1|0);
 HEAP8[$2>>0] = 0;
 __ZNSt3__211char_traitsIcE6assignERcRKc($4,$2);
 STACKTOP = sp;return;
}
function __ZNKSt3__210moneypunctIcLb1EE14do_frac_digitsEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function __ZNKSt3__210moneypunctIcLb1EE13do_pos_formatEv($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP8[$0>>0]=67109634&255;HEAP8[$0+1>>0]=(67109634>>8)&255;HEAP8[$0+2>>0]=(67109634>>16)&255;HEAP8[$0+3>>0]=67109634>>24;
 return;
}
function __ZNKSt3__210moneypunctIcLb1EE13do_neg_formatEv($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP8[$0>>0]=67109634&255;HEAP8[$0+1>>0]=(67109634>>8)&255;HEAP8[$0+2>>0]=(67109634>>16)&255;HEAP8[$0+3>>0]=67109634>>24;
 return;
}
function __ZNSt3__210moneypunctIwLb0EED2Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__26locale5facetD2Ev($0);
 return;
}
function __ZNSt3__210moneypunctIwLb0EED0Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__26locale5facetD2Ev($0);
 __ZdlPv($0);
 return;
}
function __ZNKSt3__210moneypunctIwLb0EE16do_decimal_pointEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 2147483647;
}
function __ZNKSt3__210moneypunctIwLb0EE16do_thousands_sepEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 2147483647;
}
function __ZNKSt3__210moneypunctIwLb0EE11do_groupingEv($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i = 0, $2 = 0, $3 = 0, $exitcond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 ;HEAP32[$0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;
 $$0$i$i = 0;
 while(1) {
  $exitcond$i$i = ($$0$i$i|0)==(3);
  if ($exitcond$i$i) {
   break;
  }
  $2 = (($0) + ($$0$i$i<<2)|0);
  HEAP32[$2>>2] = 0;
  $3 = (($$0$i$i) + 1)|0;
  $$0$i$i = $3;
 }
 return;
}
function __ZNKSt3__210moneypunctIwLb0EE14do_curr_symbolEv($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i = 0, $2 = 0, $3 = 0, $exitcond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 ;HEAP32[$0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;
 $$0$i$i = 0;
 while(1) {
  $exitcond$i$i = ($$0$i$i|0)==(3);
  if ($exitcond$i$i) {
   break;
  }
  $2 = (($0) + ($$0$i$i<<2)|0);
  HEAP32[$2>>2] = 0;
  $3 = (($$0$i$i) + 1)|0;
  $$0$i$i = $3;
 }
 return;
}
function __ZNKSt3__210moneypunctIwLb0EE16do_positive_signEv($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i = 0, $2 = 0, $3 = 0, $exitcond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 ;HEAP32[$0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;
 $$0$i$i = 0;
 while(1) {
  $exitcond$i$i = ($$0$i$i|0)==(3);
  if ($exitcond$i$i) {
   break;
  }
  $2 = (($0) + ($$0$i$i<<2)|0);
  HEAP32[$2>>2] = 0;
  $3 = (($$0$i$i) + 1)|0;
  $$0$i$i = $3;
 }
 return;
}
function __ZNKSt3__210moneypunctIwLb0EE16do_negative_signEv($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 ;HEAP32[$0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;
 $3 = ((($0)) + 8|0);
 $4 = ((($3)) + 3|0);
 HEAP8[$4>>0] = 1;
 (__ZNSt3__211char_traitsIwE6assignEPwjw($0,1,45)|0);
 $5 = ((($0)) + 4|0);
 HEAP32[$2>>2] = 0;
 __ZNSt3__211char_traitsIwE6assignERwRKw($5,$2);
 STACKTOP = sp;return;
}
function __ZNKSt3__210moneypunctIwLb0EE14do_frac_digitsEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function __ZNKSt3__210moneypunctIwLb0EE13do_pos_formatEv($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP8[$0>>0]=67109634&255;HEAP8[$0+1>>0]=(67109634>>8)&255;HEAP8[$0+2>>0]=(67109634>>16)&255;HEAP8[$0+3>>0]=67109634>>24;
 return;
}
function __ZNKSt3__210moneypunctIwLb0EE13do_neg_formatEv($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP8[$0>>0]=67109634&255;HEAP8[$0+1>>0]=(67109634>>8)&255;HEAP8[$0+2>>0]=(67109634>>16)&255;HEAP8[$0+3>>0]=67109634>>24;
 return;
}
function __ZNSt3__210moneypunctIwLb1EED2Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__26locale5facetD2Ev($0);
 return;
}
function __ZNSt3__210moneypunctIwLb1EED0Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__26locale5facetD2Ev($0);
 __ZdlPv($0);
 return;
}
function __ZNKSt3__210moneypunctIwLb1EE16do_decimal_pointEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 2147483647;
}
function __ZNKSt3__210moneypunctIwLb1EE16do_thousands_sepEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 2147483647;
}
function __ZNKSt3__210moneypunctIwLb1EE11do_groupingEv($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i = 0, $2 = 0, $3 = 0, $exitcond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 ;HEAP32[$0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;
 $$0$i$i = 0;
 while(1) {
  $exitcond$i$i = ($$0$i$i|0)==(3);
  if ($exitcond$i$i) {
   break;
  }
  $2 = (($0) + ($$0$i$i<<2)|0);
  HEAP32[$2>>2] = 0;
  $3 = (($$0$i$i) + 1)|0;
  $$0$i$i = $3;
 }
 return;
}
function __ZNKSt3__210moneypunctIwLb1EE14do_curr_symbolEv($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i = 0, $2 = 0, $3 = 0, $exitcond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 ;HEAP32[$0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;
 $$0$i$i = 0;
 while(1) {
  $exitcond$i$i = ($$0$i$i|0)==(3);
  if ($exitcond$i$i) {
   break;
  }
  $2 = (($0) + ($$0$i$i<<2)|0);
  HEAP32[$2>>2] = 0;
  $3 = (($$0$i$i) + 1)|0;
  $$0$i$i = $3;
 }
 return;
}
function __ZNKSt3__210moneypunctIwLb1EE16do_positive_signEv($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i = 0, $2 = 0, $3 = 0, $exitcond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 ;HEAP32[$0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;
 $$0$i$i = 0;
 while(1) {
  $exitcond$i$i = ($$0$i$i|0)==(3);
  if ($exitcond$i$i) {
   break;
  }
  $2 = (($0) + ($$0$i$i<<2)|0);
  HEAP32[$2>>2] = 0;
  $3 = (($$0$i$i) + 1)|0;
  $$0$i$i = $3;
 }
 return;
}
function __ZNKSt3__210moneypunctIwLb1EE16do_negative_signEv($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 ;HEAP32[$0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;
 $3 = ((($0)) + 8|0);
 $4 = ((($3)) + 3|0);
 HEAP8[$4>>0] = 1;
 (__ZNSt3__211char_traitsIwE6assignEPwjw($0,1,45)|0);
 $5 = ((($0)) + 4|0);
 HEAP32[$2>>2] = 0;
 __ZNSt3__211char_traitsIwE6assignERwRKw($5,$2);
 STACKTOP = sp;return;
}
function __ZNKSt3__210moneypunctIwLb1EE14do_frac_digitsEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function __ZNKSt3__210moneypunctIwLb1EE13do_pos_formatEv($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP8[$0>>0]=67109634&255;HEAP8[$0+1>>0]=(67109634>>8)&255;HEAP8[$0+2>>0]=(67109634>>16)&255;HEAP8[$0+3>>0]=67109634>>24;
 return;
}
function __ZNKSt3__210moneypunctIwLb1EE13do_neg_formatEv($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP8[$0>>0]=67109634&255;HEAP8[$0+1>>0]=(67109634>>8)&255;HEAP8[$0+2>>0]=(67109634>>16)&255;HEAP8[$0+3>>0]=67109634>>24;
 return;
}
function __ZNSt3__29money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEED2Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__26locale5facetD2Ev($0);
 return;
}
function __ZNSt3__29money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEED0Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__26locale5facetD2Ev($0);
 __ZdlPv($0);
 return;
}
function __ZNKSt3__29money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_bRNS_8ios_baseERjRe($0,$1,$2,$3,$4,$5,$6) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 var $$0 = 0, $$0$i = 0, $$0$i$i$i$i = 0, $$0$i$i2$i$i = 0, $$0$lcssa$i = 0, $$031 = 0, $$032 = 0, $$035 = 0, $$1 = 0, $$133 = 0, $$136 = 0, $$2 = 0, $$234 = 0, $$237 = 0, $$33860 = 0, $$33861 = 0, $$362 = 0, $$363 = 0, $$byval_copy = 0, $$pre = 0;
 var $$pre$i$i$i = 0, $$pre57 = 0, $$pre64 = 0, $$sroa$0$0$copyload = 0, $$sroa$044$0 = 0, $$sroa$044$1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $phitmp$i$i$i = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 240|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(240|0);
 $$byval_copy = sp + 24|0;
 $vararg_buffer = sp;
 $7 = sp + 140|0;
 $8 = sp + 16|0;
 $9 = sp + 12|0;
 $10 = sp + 8|0;
 $11 = sp + 138|0;
 $12 = sp + 4|0;
 $13 = sp + 128|0;
 $14 = sp + 28|0;
 $15 = $7;
 HEAP32[$8>>2] = $15;
 $16 = ((($8)) + 4|0);
 HEAP32[$16>>2] = (4716);
 $17 = ((($7)) + 100|0);
 __THREW__ = 0;
 invoke_vii(3257,($10|0),($4|0));
 $18 = __THREW__; __THREW__ = 0;
 $19 = $18&1;
 if ($19) {
  $45 = ___cxa_find_matching_catch_2()|0;
  $46 = tempRet0;
  HEAP32[$8>>2] = 0;
  $$33860 = $46;$$362 = $45;$124 = 4716;$125 = $7;
  label = 54;
 } else {
  __THREW__ = 0;
  $20 = (invoke_iii(3255,($10|0),(215188|0))|0);
  $21 = __THREW__; __THREW__ = 0;
  $22 = $21&1;
  if ($22) {
   $47 = ___cxa_find_matching_catch_2()|0;
   $48 = tempRet0;
   $$234 = $47;$$237 = $48;
  } else {
   HEAP8[$11>>0] = 0;
   $23 = HEAP32[$2>>2]|0;
   HEAP32[$12>>2] = $23;
   $24 = ((($4)) + 4|0);
   $25 = HEAP32[$24>>2]|0;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy>>2]=HEAP32[$12>>2]|0;
   $26 = (invoke_iiiiiiiiiiii(4717,($1|0),($$byval_copy|0),($3|0),($10|0),($25|0),($5|0),($11|0),($20|0),($8|0),($9|0),($17|0))|0);
   $27 = __THREW__; __THREW__ = 0;
   $28 = $27&1;
   L7: do {
    if ($28) {
     label = 11;
    } else {
     L9: do {
      if ($26) {
       $29 = HEAP32[$20>>2]|0;
       $30 = ((($29)) + 32|0);
       $31 = HEAP32[$30>>2]|0;
       __THREW__ = 0;
       (invoke_iiiii($31|0,($20|0),(203939|0),((203949)|0),($13|0))|0);
       $32 = __THREW__; __THREW__ = 0;
       $33 = $32&1;
       if ($33) {
        $51 = ___cxa_find_matching_catch_2()|0;
        $52 = tempRet0;
        $$032 = $51;$$035 = $52;
       } else {
        $34 = HEAP32[$9>>2]|0;
        $35 = HEAP32[$8>>2]|0;
        $36 = (($34) - ($35))|0;
        $37 = ($36|0)>(98);
        $38 = $35;
        $39 = $34;
        if ($37) {
         $40 = (($36) + 2)|0;
         $41 = (_malloc($40)|0);
         $42 = $41;
         $43 = ($41|0)==(0|0);
         if ($43) {
          __THREW__ = 0;
          invoke_v(4685);
          $44 = __THREW__; __THREW__ = 0;
          $$sroa$044$0 = $42;
         } else {
          $$031 = $41;$$sroa$044$1 = $42;
          label = 16;
         }
        } else {
         $$031 = $14;$$sroa$044$1 = 0;
         label = 16;
        }
        do {
         if ((label|0) == 16) {
          $57 = HEAP8[$11>>0]|0;
          $58 = ($57<<24>>24)==(0);
          if ($58) {
           $$1 = $$031;
          } else {
           $59 = ((($$031)) + 1|0);
           HEAP8[$$031>>0] = 45;
           $$1 = $59;
          }
          $60 = ((($13)) + 10|0);
          $61 = $13;
          $$0 = $38;$$2 = $$1;$63 = $39;
          while(1) {
           $62 = ($$0>>>0)<($63>>>0);
           if (!($62)) {
            break;
           }
           $66 = HEAP8[$$0>>0]|0;
           $$0$i = $13;
           while(1) {
            $67 = ($$0$i|0)==($60|0);
            if ($67) {
             $$0$lcssa$i = $60;
             break;
            }
            $68 = HEAP8[$$0$i>>0]|0;
            $69 = ($68<<24>>24)==($66<<24>>24);
            if ($69) {
             $$0$lcssa$i = $$0$i;
             break;
            }
            $70 = ((($$0$i)) + 1|0);
            $$0$i = $70;
           }
           $71 = $$0$lcssa$i;
           $72 = (($71) - ($61))|0;
           $73 = (203939 + ($72)|0);
           $74 = HEAP8[$73>>0]|0;
           HEAP8[$$2>>0] = $74;
           $75 = ((($$0)) + 1|0);
           $76 = ((($$2)) + 1|0);
           $$pre = HEAP32[$9>>2]|0;
           $$0 = $75;$$2 = $76;$63 = $$pre;
          }
          HEAP8[$$2>>0] = 0;
          HEAP32[$vararg_buffer>>2] = $6;
          $64 = (_sscanf($14,203950,$vararg_buffer)|0);
          $65 = ($64|0)==(1);
          if (!($65)) {
           __THREW__ = 0;
           invoke_vi(4718,(203954|0));
           $77 = __THREW__; __THREW__ = 0;
           $$sroa$044$0 = $$sroa$044$1;
           break;
          }
          $78 = ($$sroa$044$1|0)==(0);
          if (!($78)) {
           $79 = $$sroa$044$1;
           _free($79);
          }
          break L9;
         }
        } while(0);
        $53 = ___cxa_find_matching_catch_2()|0;
        $54 = tempRet0;
        $55 = ($$sroa$044$0|0)==(0);
        if (!($55)) {
         $56 = $$sroa$044$0;
         _free($56);
        }
        $$032 = $53;$$035 = $54;
       }
       $$133 = $$032;$$136 = $$035;
       break L7;
      }
     } while(0);
     $80 = HEAP32[$1>>2]|0;
     $81 = ($80|0)==(0|0);
     do {
      if ($81) {
       $130 = 1;
      } else {
       $82 = ((($80)) + 12|0);
       $83 = HEAP32[$82>>2]|0;
       $84 = ((($80)) + 16|0);
       $85 = HEAP32[$84>>2]|0;
       $86 = ($83|0)==($85|0);
       if ($86) {
        $87 = HEAP32[$80>>2]|0;
        $88 = ((($87)) + 36|0);
        $89 = HEAP32[$88>>2]|0;
        __THREW__ = 0;
        $90 = (invoke_ii($89|0,($80|0))|0);
        $91 = __THREW__; __THREW__ = 0;
        $92 = $91&1;
        if ($92) {
         label = 11;
         break L7;
        } else {
         $$0$i$i$i$i = $90;
        }
       } else {
        $93 = HEAP8[$83>>0]|0;
        $94 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($93)|0);
        $$0$i$i$i$i = $94;
       }
       $95 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
       $96 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i$i$i,$95)|0);
       if ($96) {
        HEAP32[$1>>2] = 0;
        $130 = 1;
        break;
       } else {
        $$pre$i$i$i = HEAP32[$1>>2]|0;
        $phitmp$i$i$i = ($$pre$i$i$i|0)==(0|0);
        $130 = $phitmp$i$i$i;
        break;
       }
      }
     } while(0);
     $97 = HEAP32[$2>>2]|0;
     $98 = ($97|0)==(0|0);
     do {
      if ($98) {
       label = 44;
      } else {
       $99 = ((($97)) + 12|0);
       $100 = HEAP32[$99>>2]|0;
       $101 = ((($97)) + 16|0);
       $102 = HEAP32[$101>>2]|0;
       $103 = ($100|0)==($102|0);
       if ($103) {
        $104 = HEAP32[$97>>2]|0;
        $105 = ((($104)) + 36|0);
        $106 = HEAP32[$105>>2]|0;
        __THREW__ = 0;
        $107 = (invoke_ii($106|0,($97|0))|0);
        $108 = __THREW__; __THREW__ = 0;
        $109 = $108&1;
        if ($109) {
         label = 11;
         break L7;
        } else {
         $$0$i$i2$i$i = $107;
        }
       } else {
        $110 = HEAP8[$100>>0]|0;
        $111 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($110)|0);
        $$0$i$i2$i$i = $111;
       }
       $112 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
       $113 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i2$i$i,$112)|0);
       if ($113) {
        HEAP32[$2>>2] = 0;
        label = 44;
        break;
       } else {
        if ($130) {
         break;
        } else {
         label = 46;
         break;
        }
       }
      }
     } while(0);
     if ((label|0) == 44) {
      if ($130) {
       label = 46;
      }
     }
     if ((label|0) == 46) {
      $114 = HEAP32[$5>>2]|0;
      $115 = $114 | 2;
      HEAP32[$5>>2] = $115;
     }
     $$sroa$0$0$copyload = HEAP32[$1>>2]|0;
     __ZNSt3__26localeD2Ev($10);
     $116 = HEAP32[$8>>2]|0;
     HEAP32[$8>>2] = 0;
     $117 = ($116|0)==(0|0);
     if (!($117)) {
      $118 = HEAP32[$16>>2]|0;
      __THREW__ = 0;
      invoke_vi($118|0,($116|0));
      $119 = __THREW__; __THREW__ = 0;
      $120 = $119&1;
      if ($120) {
       $121 = ___cxa_find_matching_catch_3(0|0)|0;
       $122 = tempRet0;
       ___clang_call_terminate($121);
       // unreachable;
      }
     }
     STACKTOP = sp;return ($$sroa$0$0$copyload|0);
    }
   } while(0);
   if ((label|0) == 11) {
    $49 = ___cxa_find_matching_catch_2()|0;
    $50 = tempRet0;
    $$133 = $49;$$136 = $50;
   }
   $$234 = $$133;$$237 = $$136;
  }
  __ZNSt3__26localeD2Ev($10);
  $$pre57 = HEAP32[$8>>2]|0;
  HEAP32[$8>>2] = 0;
  $123 = ($$pre57|0)==(0|0);
  if ($123) {
   $$33861 = $$237;$$363 = $$234;
  } else {
   $$pre64 = HEAP32[$16>>2]|0;
   $$33860 = $$237;$$362 = $$234;$124 = $$pre64;$125 = $$pre57;
   label = 54;
  }
 }
 if ((label|0) == 54) {
  __THREW__ = 0;
  invoke_vi($124|0,($125|0));
  $126 = __THREW__; __THREW__ = 0;
  $127 = $126&1;
  if ($127) {
   $128 = ___cxa_find_matching_catch_3(0|0)|0;
   $129 = tempRet0;
   ___clang_call_terminate($128);
   // unreachable;
  } else {
   $$33861 = $$33860;$$363 = $$362;
  }
 }
 ___resumeException($$363|0);
 // unreachable;
 return (0)|0;
}
function __ZNKSt3__29money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_bRNS_8ios_baseERjRNS_12basic_stringIcS3_NS_9allocatorIcEEEE($0,$1,$2,$3,$4,$5,$6) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 var $$0 = 0, $$0$i$i$i$i = 0, $$0$i$i2$i$i = 0, $$1 = 0, $$132 = 0, $$23343 = 0, $$23344 = 0, $$245 = 0, $$246 = 0, $$byval_copy = 0, $$pre = 0, $$pre$i$i$i = 0, $$sroa$0$0$copyload = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $phitmp$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(144|0);
 $$byval_copy = sp + 24|0;
 $7 = sp + 133|0;
 $8 = sp + 132|0;
 $9 = sp + 32|0;
 $10 = sp + 16|0;
 $11 = sp + 8|0;
 $12 = sp + 4|0;
 $13 = sp + 28|0;
 $14 = sp;
 $15 = $9;
 HEAP32[$10>>2] = $15;
 $16 = ((($10)) + 4|0);
 HEAP32[$16>>2] = (4716);
 $17 = ((($9)) + 100|0);
 __THREW__ = 0;
 invoke_vii(3257,($12|0),($4|0));
 $18 = __THREW__; __THREW__ = 0;
 $19 = $18&1;
 if ($19) {
  $45 = ___cxa_find_matching_catch_2()|0;
  $46 = tempRet0;
  HEAP32[$10>>2] = 0;
  $$23343 = $46;$$245 = $45;$111 = $9;
  label = 41;
 } else {
  __THREW__ = 0;
  $20 = (invoke_iii(3255,($12|0),(215188|0))|0);
  $21 = __THREW__; __THREW__ = 0;
  $22 = $21&1;
  if ($22) {
   $47 = ___cxa_find_matching_catch_2()|0;
   $48 = tempRet0;
   $$1 = $47;$$132 = $48;
  } else {
   HEAP8[$13>>0] = 0;
   $23 = HEAP32[$2>>2]|0;
   HEAP32[$14>>2] = $23;
   $24 = ((($4)) + 4|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = $23;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy>>2]=HEAP32[$14>>2]|0;
   $27 = (invoke_iiiiiiiiiiii(4717,($1|0),($$byval_copy|0),($3|0),($12|0),($25|0),($5|0),($13|0),($20|0),($10|0),($11|0),($17|0))|0);
   $28 = __THREW__; __THREW__ = 0;
   $29 = $28&1;
   L7: do {
    if (!($29)) {
     if ($27) {
      $30 = ((($6)) + 11|0);
      $31 = HEAP8[$30>>0]|0;
      $32 = ($31<<24>>24)<(0);
      if ($32) {
       $33 = HEAP32[$6>>2]|0;
       HEAP8[$7>>0] = 0;
       __ZNSt3__211char_traitsIcE6assignERcRKc($33,$7);
       $34 = ((($6)) + 4|0);
       HEAP32[$34>>2] = 0;
      } else {
       HEAP8[$8>>0] = 0;
       __ZNSt3__211char_traitsIcE6assignERcRKc($6,$8);
       HEAP8[$30>>0] = 0;
      }
      $35 = HEAP8[$13>>0]|0;
      $36 = ($35<<24>>24)==(0);
      if (!($36)) {
       $37 = HEAP32[$20>>2]|0;
       $38 = ((($37)) + 28|0);
       $39 = HEAP32[$38>>2]|0;
       __THREW__ = 0;
       $40 = (invoke_iii($39|0,($20|0),45)|0);
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if ($42) {
        break;
       }
       __THREW__ = 0;
       invoke_vii(3433,($6|0),($40|0));
       $43 = __THREW__; __THREW__ = 0;
       $44 = $43&1;
       if ($44) {
        break;
       }
      }
      $49 = HEAP32[$20>>2]|0;
      $50 = ((($49)) + 28|0);
      $51 = HEAP32[$50>>2]|0;
      __THREW__ = 0;
      $52 = (invoke_iii($51|0,($20|0),48)|0);
      $53 = __THREW__; __THREW__ = 0;
      $54 = $53&1;
      if ($54) {
       break;
      }
      $55 = HEAP32[$10>>2]|0;
      $56 = HEAP32[$11>>2]|0;
      $57 = ((($56)) + -1|0);
      $$0 = $55;
      while(1) {
       $58 = ($$0>>>0)<($57>>>0);
       if (!($58)) {
        break;
       }
       $59 = HEAP8[$$0>>0]|0;
       $60 = ($59<<24>>24)==($52<<24>>24);
       if (!($60)) {
        break;
       }
       $61 = ((($$0)) + 1|0);
       $$0 = $61;
      }
      __THREW__ = 0;
      (invoke_iiii(4719,($6|0),($$0|0),($56|0))|0);
      $62 = __THREW__; __THREW__ = 0;
      $63 = $62&1;
      if ($63) {
       break;
      }
     }
     $64 = HEAP32[$1>>2]|0;
     $65 = ($64|0)==(0|0);
     do {
      if ($65) {
       $116 = 1;
      } else {
       $66 = ((($64)) + 12|0);
       $67 = HEAP32[$66>>2]|0;
       $68 = ((($64)) + 16|0);
       $69 = HEAP32[$68>>2]|0;
       $70 = ($67|0)==($69|0);
       if ($70) {
        $71 = HEAP32[$64>>2]|0;
        $72 = ((($71)) + 36|0);
        $73 = HEAP32[$72>>2]|0;
        __THREW__ = 0;
        $74 = (invoke_ii($73|0,($64|0))|0);
        $75 = __THREW__; __THREW__ = 0;
        $76 = $75&1;
        if ($76) {
         break L7;
        } else {
         $$0$i$i$i$i = $74;
        }
       } else {
        $77 = HEAP8[$67>>0]|0;
        $78 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($77)|0);
        $$0$i$i$i$i = $78;
       }
       $79 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
       $80 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i$i$i,$79)|0);
       if ($80) {
        HEAP32[$1>>2] = 0;
        $116 = 1;
        break;
       } else {
        $$pre$i$i$i = HEAP32[$1>>2]|0;
        $phitmp$i$i$i = ($$pre$i$i$i|0)==(0|0);
        $116 = $phitmp$i$i$i;
        break;
       }
      }
     } while(0);
     $81 = ($23|0)==(0);
     do {
      if ($81) {
       label = 32;
      } else {
       $82 = ((($26)) + 12|0);
       $83 = HEAP32[$82>>2]|0;
       $84 = ((($26)) + 16|0);
       $85 = HEAP32[$84>>2]|0;
       $86 = ($83|0)==($85|0);
       if ($86) {
        $87 = $23;
        $88 = HEAP32[$87>>2]|0;
        $89 = ((($88)) + 36|0);
        $90 = HEAP32[$89>>2]|0;
        __THREW__ = 0;
        $91 = (invoke_ii($90|0,($26|0))|0);
        $92 = __THREW__; __THREW__ = 0;
        $93 = $92&1;
        if ($93) {
         break L7;
        } else {
         $$0$i$i2$i$i = $91;
        }
       } else {
        $94 = HEAP8[$83>>0]|0;
        $95 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($94)|0);
        $$0$i$i2$i$i = $95;
       }
       $96 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
       $97 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i2$i$i,$96)|0);
       if ($97) {
        HEAP32[$2>>2] = 0;
        label = 32;
        break;
       } else {
        if ($116) {
         break;
        } else {
         label = 34;
         break;
        }
       }
      }
     } while(0);
     if ((label|0) == 32) {
      if ($116) {
       label = 34;
      }
     }
     if ((label|0) == 34) {
      $98 = HEAP32[$5>>2]|0;
      $99 = $98 | 2;
      HEAP32[$5>>2] = $99;
     }
     $$sroa$0$0$copyload = HEAP32[$1>>2]|0;
     __ZNSt3__26localeD2Ev($12);
     $100 = HEAP32[$10>>2]|0;
     HEAP32[$10>>2] = 0;
     $101 = ($100|0)==(0|0);
     if (!($101)) {
      $102 = HEAP32[$16>>2]|0;
      __THREW__ = 0;
      invoke_vi($102|0,($100|0));
      $103 = __THREW__; __THREW__ = 0;
      $104 = $103&1;
      if ($104) {
       $105 = ___cxa_find_matching_catch_3(0|0)|0;
       $106 = tempRet0;
       ___clang_call_terminate($105);
       // unreachable;
      }
     }
     STACKTOP = sp;return ($$sroa$0$0$copyload|0);
    }
   } while(0);
   $107 = ___cxa_find_matching_catch_2()|0;
   $108 = tempRet0;
   $$1 = $107;$$132 = $108;
  }
  __ZNSt3__26localeD2Ev($12);
  $$pre = HEAP32[$10>>2]|0;
  HEAP32[$10>>2] = 0;
  $109 = ($$pre|0)==(0|0);
  if ($109) {
   $$23344 = $$132;$$246 = $$1;
  } else {
   $$23343 = $$132;$$245 = $$1;$111 = $$pre;
   label = 41;
  }
 }
 if ((label|0) == 41) {
  $110 = HEAP32[$16>>2]|0;
  __THREW__ = 0;
  invoke_vi($110|0,($111|0));
  $112 = __THREW__; __THREW__ = 0;
  $113 = $112&1;
  if ($113) {
   $114 = ___cxa_find_matching_catch_3(0|0)|0;
   $115 = tempRet0;
   ___clang_call_terminate($114);
   // unreachable;
  } else {
   $$23344 = $$23343;$$246 = $$245;
  }
 }
 ___resumeException($$246|0);
 // unreachable;
 return (0)|0;
}
function __ZNSt3__212__do_nothingEPv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZNSt3__29money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE8__do_getERS4_S4_bRKNS_6localeEjRjRbRKNS_5ctypeIcEERNS_10unique_ptrIcPFvPvEEERPcSM_($0,$1,$2,$3,$4,$5,$6,$7,$8,$9,$10) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 $8 = $8|0;
 $9 = $9|0;
 $10 = $10|0;
 var $$$0149 = 0, $$$0149159 = 0, $$$0149160 = 0, $$$0149161 = 0, $$0 = 0, $$0$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i186 = 0, $$0$i$i$i$i252 = 0, $$0$i$i$i$i273 = 0, $$0$i$i$i$i295 = 0, $$0$i$i$i$i314 = 0, $$0$i$i$i$i339 = 0, $$0$i$i168 = 0, $$0$i$i171 = 0, $$0$i$i174 = 0, $$0$i$i177 = 0, $$0$i$i182 = 0, $$0$i$i184 = 0, $$0$i$i2$i$i = 0;
 var $$0$i$i2$i$i192 = 0, $$0$i$i2$i$i258 = 0, $$0$i$i2$i$i279 = 0, $$0$i$i2$i$i301 = 0, $$0$i$i2$i$i320 = 0, $$0$i$i2$i$i345 = 0, $$0$i$i201 = 0, $$0$i$i205 = 0, $$0$i$i212 = 0, $$0$i$i217 = 0, $$0$i$i224 = 0, $$0$i$i231 = 0, $$0$i$i249 = 0, $$0$i$i267 = 0, $$0$i$i288 = 0, $$0$i$i309 = 0, $$0$i$i329 = 0, $$0$i$i333 = 0, $$0132 = 0, $$0149 = 0;
 var $$0158 = 0, $$10 = 0, $$1150 = 0, $$2134$ph = 0, $$5142 = 0, $$5148 = 0, $$lcssa = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i188 = 0, $$pre$i$i$i254 = 0, $$pre$i$i$i275 = 0, $$pre$i$i$i297 = 0, $$pre$i$i$i316 = 0, $$pre$i$i$i341 = 0, $$pre$i4$i$i194 = 0, $$pre$i4$i$i194512 = 0, $$pre$i4$i$i194514 = 0, $$pre$i4$i$i260 = 0, $$pre$i4$i$i260509 = 0;
 var $$pre$i4$i$i260510 = 0, $$pre$i4$i$i281 = 0, $$pre$i4$i$i281498 = 0, $$pre$i4$i$i281500 = 0, $$pre$i4$i$i303 = 0, $$pre$i4$i$i322 = 0, $$pre$i4$i$i322505$ph = 0, $$pre$i4$i$i322505518 = 0, $$pre502 = 0, $$pre504 = 0, $$pre507 = 0, $$pre508 = 0, $$sink = 0, $$sroa$0360$0 = 0, $$sroa$0381$0 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0;
 var $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0;
 var $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0;
 var $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0;
 var $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0;
 var $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0;
 var $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0;
 var $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0;
 var $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0;
 var $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0;
 var $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0;
 var $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0;
 var $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0;
 var $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0;
 var $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0;
 var $396 = 0, $397 = 0, $398 = 0, $399 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0;
 var $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0;
 var $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0;
 var $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0;
 var $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0;
 var $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0;
 var $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0;
 var $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0;
 var $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0;
 var $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0;
 var $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0;
 var $596 = 0, $597 = 0, $598 = 0, $599 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0;
 var $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0;
 var $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0;
 var $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0;
 var $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0;
 var $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0;
 var $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0;
 var $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0;
 var $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0;
 var $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0;
 var $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0;
 var $796 = 0, $797 = 0, $798 = 0, $799 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0;
 var $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0;
 var $832 = 0, $833 = 0, $834 = 0, $835 = 0, $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0;
 var $850 = 0, $851 = 0, $852 = 0, $853 = 0, $854 = 0, $855 = 0, $856 = 0, $857 = 0, $858 = 0, $859 = 0, $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0;
 var $869 = 0, $87 = 0, $870 = 0, $871 = 0, $872 = 0, $873 = 0, $874 = 0, $875 = 0, $876 = 0, $877 = 0, $878 = 0, $879 = 0, $88 = 0, $880 = 0, $881 = 0, $882 = 0, $883 = 0, $884 = 0, $885 = 0, $886 = 0;
 var $887 = 0, $888 = 0, $889 = 0, $89 = 0, $890 = 0, $891 = 0, $892 = 0, $893 = 0, $894 = 0, $895 = 0, $896 = 0, $897 = 0, $898 = 0, $899 = 0, $90 = 0, $900 = 0, $901 = 0, $902 = 0, $903 = 0, $904 = 0;
 var $905 = 0, $906 = 0, $907 = 0, $908 = 0, $909 = 0, $91 = 0, $910 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $brmerge = 0, $exitcond$i$i = 0, $exitcond$i$i169 = 0, $exitcond$i$i172 = 0, $exitcond$i$i175 = 0;
 var $exitcond$i$i178 = 0, $or$cond = 0, $or$cond13 = 0, $or$cond15 = 0, $or$cond164 = 0, $phitmp$i$i$i = 0, $phitmp$i$i$i189 = 0, $phitmp$i$i$i255 = 0, $phitmp$i$i$i276 = 0, $phitmp$i$i$i298 = 0, $phitmp$i$i$i317 = 0, $phitmp$i$i$i342 = 0, $phitmp$i5$i$i195 = 0, $phitmp$i5$i$i261 = 0, $phitmp$i5$i$i282 = 0, $phitmp$i5$i$i323 = 0, $sext = 0, $sext421 = 0, $sext422 = 0, $sext423 = 0;
 var $switch = 0, $tmp$i$i197 = 0, $tmp$i$i263 = 0, $tmp$i$i284 = 0, $tmp$i$i325 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 512|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(512|0);
 $11 = sp + 488|0;
 $12 = sp + 88|0;
 $13 = sp + 80|0;
 $14 = sp + 72|0;
 $15 = sp + 68|0;
 $16 = sp + 496|0;
 $17 = sp + 493|0;
 $18 = sp + 492|0;
 $19 = sp + 56|0;
 $20 = sp + 44|0;
 $21 = sp + 32|0;
 $22 = sp + 20|0;
 $23 = sp + 8|0;
 $24 = sp + 4|0;
 $25 = sp;
 HEAP32[$11>>2] = $10;
 $26 = $12;
 HEAP32[$13>>2] = $26;
 $27 = ((($13)) + 4|0);
 HEAP32[$27>>2] = (4716);
 HEAP32[$14>>2] = $12;
 $28 = ((($12)) + 400|0);
 HEAP32[$15>>2] = $28;
 ;HEAP32[$19>>2]=0|0;HEAP32[$19+4>>2]=0|0;HEAP32[$19+8>>2]=0|0;
 $$0$i$i = 0;
 while(1) {
  $exitcond$i$i = ($$0$i$i|0)==(3);
  if ($exitcond$i$i) {
   break;
  }
  $29 = (($19) + ($$0$i$i<<2)|0);
  HEAP32[$29>>2] = 0;
  $30 = (($$0$i$i) + 1)|0;
  $$0$i$i = $30;
 }
 ;HEAP32[$20>>2]=0|0;HEAP32[$20+4>>2]=0|0;HEAP32[$20+8>>2]=0|0;
 $$0$i$i168 = 0;
 while(1) {
  $exitcond$i$i169 = ($$0$i$i168|0)==(3);
  if ($exitcond$i$i169) {
   break;
  }
  $31 = (($20) + ($$0$i$i168<<2)|0);
  HEAP32[$31>>2] = 0;
  $32 = (($$0$i$i168) + 1)|0;
  $$0$i$i168 = $32;
 }
 ;HEAP32[$21>>2]=0|0;HEAP32[$21+4>>2]=0|0;HEAP32[$21+8>>2]=0|0;
 $$0$i$i171 = 0;
 while(1) {
  $exitcond$i$i172 = ($$0$i$i171|0)==(3);
  if ($exitcond$i$i172) {
   break;
  }
  $33 = (($21) + ($$0$i$i171<<2)|0);
  HEAP32[$33>>2] = 0;
  $34 = (($$0$i$i171) + 1)|0;
  $$0$i$i171 = $34;
 }
 ;HEAP32[$22>>2]=0|0;HEAP32[$22+4>>2]=0|0;HEAP32[$22+8>>2]=0|0;
 $$0$i$i174 = 0;
 while(1) {
  $exitcond$i$i175 = ($$0$i$i174|0)==(3);
  if ($exitcond$i$i175) {
   break;
  }
  $35 = (($22) + ($$0$i$i174<<2)|0);
  HEAP32[$35>>2] = 0;
  $36 = (($$0$i$i174) + 1)|0;
  $$0$i$i174 = $36;
 }
 ;HEAP32[$23>>2]=0|0;HEAP32[$23+4>>2]=0|0;HEAP32[$23+8>>2]=0|0;
 $$0$i$i177 = 0;
 while(1) {
  $exitcond$i$i178 = ($$0$i$i177|0)==(3);
  if ($exitcond$i$i178) {
   break;
  }
  $37 = (($23) + ($$0$i$i177<<2)|0);
  HEAP32[$37>>2] = 0;
  $38 = (($$0$i$i177) + 1)|0;
  $$0$i$i177 = $38;
 }
 __THREW__ = 0;
 invoke_viiiiiiiiii(4720,($2|0),($3|0),($16|0),($17|0),($18|0),($19|0),($20|0),($21|0),($22|0),($24|0));
 $39 = __THREW__; __THREW__ = 0;
 $40 = $39&1;
 L21: do {
  if ($40) {
   $92 = ___cxa_find_matching_catch_2()|0;
   $93 = tempRet0;
   $$5142 = $92;$$5148 = $93;
  } else {
   $41 = HEAP32[$8>>2]|0;
   HEAP32[$9>>2] = $41;
   $42 = ((($7)) + 8|0);
   $43 = ((($21)) + 11|0);
   $44 = ((($21)) + 4|0);
   $45 = ((($22)) + 11|0);
   $46 = ((($22)) + 4|0);
   $47 = $4 & 512;
   $48 = ($47|0)!=(0);
   $49 = ((($20)) + 11|0);
   $50 = ((($20)) + 4|0);
   $51 = ((($23)) + 11|0);
   $52 = ((($23)) + 4|0);
   $53 = ((($16)) + 3|0);
   $54 = ((($19)) + 11|0);
   $55 = ((($19)) + 4|0);
   $$0149 = 0;$$0158 = 0;
   L24: while(1) {
    $56 = ($$0158>>>0)<(4);
    $57 = ($$0149|0)!=(0|0);
    if (!($56)) {
     label = 246;
     break;
    }
    $58 = HEAP32[$0>>2]|0;
    $59 = ($58|0)==(0|0);
    do {
     if ($59) {
      $902 = 1;
     } else {
      $60 = ((($58)) + 12|0);
      $61 = HEAP32[$60>>2]|0;
      $62 = ((($58)) + 16|0);
      $63 = HEAP32[$62>>2]|0;
      $64 = ($61|0)==($63|0);
      if ($64) {
       $65 = HEAP32[$58>>2]|0;
       $66 = ((($65)) + 36|0);
       $67 = HEAP32[$66>>2]|0;
       __THREW__ = 0;
       $68 = (invoke_ii($67|0,($58|0))|0);
       $69 = __THREW__; __THREW__ = 0;
       $70 = $69&1;
       if ($70) {
        label = 35;
        break L24;
       } else {
        $$0$i$i$i$i = $68;
       }
      } else {
       $71 = HEAP8[$61>>0]|0;
       $72 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($71)|0);
       $$0$i$i$i$i = $72;
      }
      $73 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
      $74 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i$i$i,$73)|0);
      if ($74) {
       HEAP32[$0>>2] = 0;
       $902 = 1;
       break;
      } else {
       $$pre$i$i$i = HEAP32[$0>>2]|0;
       $phitmp$i$i$i = ($$pre$i$i$i|0)==(0|0);
       $902 = $phitmp$i$i$i;
       break;
      }
     }
    } while(0);
    $75 = HEAP32[$1>>2]|0;
    $76 = ($75|0)==(0|0);
    do {
     if ($76) {
      label = 32;
     } else {
      $77 = ((($75)) + 12|0);
      $78 = HEAP32[$77>>2]|0;
      $79 = ((($75)) + 16|0);
      $80 = HEAP32[$79>>2]|0;
      $81 = ($78|0)==($80|0);
      if ($81) {
       $82 = HEAP32[$75>>2]|0;
       $83 = ((($82)) + 36|0);
       $84 = HEAP32[$83>>2]|0;
       __THREW__ = 0;
       $85 = (invoke_ii($84|0,($75|0))|0);
       $86 = __THREW__; __THREW__ = 0;
       $87 = $86&1;
       if ($87) {
        label = 35;
        break L24;
       } else {
        $$0$i$i2$i$i = $85;
       }
      } else {
       $88 = HEAP8[$78>>0]|0;
       $89 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($88)|0);
       $$0$i$i2$i$i = $89;
      }
      $90 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
      $91 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i2$i$i,$90)|0);
      if ($91) {
       HEAP32[$1>>2] = 0;
       label = 32;
       break;
      } else {
       if ($902) {
        $903 = $75;
        break;
       } else {
        label = 246;
        break L24;
       }
      }
     }
    } while(0);
    if ((label|0) == 32) {
     label = 0;
     if ($902) {
      label = 246;
      break;
     } else {
      $903 = 0;
     }
    }
    $96 = (($16) + ($$0158)|0);
    $97 = HEAP8[$96>>0]|0;
    $98 = $97 << 24 >> 24;
    $99 = ($$0158|0)!=(3);
    L49: do {
     switch ($98|0) {
     case 1:  {
      if ($99) {
       $100 = HEAP32[$0>>2]|0;
       $101 = ((($100)) + 12|0);
       $102 = HEAP32[$101>>2]|0;
       $103 = ((($100)) + 16|0);
       $104 = HEAP32[$103>>2]|0;
       $105 = ($102|0)==($104|0);
       if ($105) {
        $106 = HEAP32[$100>>2]|0;
        $107 = ((($106)) + 36|0);
        $108 = HEAP32[$107>>2]|0;
        __THREW__ = 0;
        $109 = (invoke_ii($108|0,($100|0))|0);
        $110 = __THREW__; __THREW__ = 0;
        $111 = $110&1;
        if ($111) {
         label = 35;
         break L24;
        } else {
         $$0$i$i182 = $109;
        }
       } else {
        $112 = HEAP8[$102>>0]|0;
        $113 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($112)|0);
        $$0$i$i182 = $113;
       }
       $114 = $$0$i$i182&255;
       $115 = ($114<<24>>24)>(-1);
       if (!($115)) {
        label = 47;
        break L24;
       }
       $sext423 = $$0$i$i182 << 24;
       $116 = $sext423 >> 24;
       $117 = HEAP32[$42>>2]|0;
       $118 = (($117) + ($116<<1)|0);
       $119 = HEAP16[$118>>1]|0;
       $120 = $119 & 8192;
       $121 = ($120<<16>>16)==(0);
       if ($121) {
        label = 47;
        break L24;
       }
       $122 = HEAP32[$0>>2]|0;
       $123 = ((($122)) + 12|0);
       $124 = HEAP32[$123>>2]|0;
       $125 = ((($122)) + 16|0);
       $126 = HEAP32[$125>>2]|0;
       $127 = ($124|0)==($126|0);
       if ($127) {
        $128 = HEAP32[$122>>2]|0;
        $129 = ((($128)) + 40|0);
        $130 = HEAP32[$129>>2]|0;
        __THREW__ = 0;
        $131 = (invoke_ii($130|0,($122|0))|0);
        $132 = __THREW__; __THREW__ = 0;
        $133 = $132&1;
        if ($133) {
         label = 35;
         break L24;
        } else {
         $$0$i$i184 = $131;
        }
       } else {
        $134 = ((($124)) + 1|0);
        HEAP32[$123>>2] = $134;
        $135 = HEAP8[$124>>0]|0;
        $136 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($135)|0);
        $$0$i$i184 = $136;
       }
       $137 = $$0$i$i184&255;
       __THREW__ = 0;
       invoke_vii(3433,($23|0),($137|0));
       $138 = __THREW__; __THREW__ = 0;
       $139 = $138&1;
       if ($139) {
        label = 35;
        break L24;
       } else {
        $$pre$i4$i$i194 = $903;$159 = $903;
        label = 49;
       }
      } else {
       $$1150 = $$0149;
      }
      break;
     }
     case 0:  {
      if ($99) {
       $$pre$i4$i$i194 = $903;$159 = $903;
       label = 49;
      } else {
       $$1150 = $$0149;
      }
      break;
     }
     case 3:  {
      $217 = HEAP8[$43>>0]|0;
      $218 = ($217<<24>>24)<(0);
      $219 = HEAP32[$44>>2]|0;
      $220 = $217&255;
      $221 = $218 ? $219 : $220;
      $222 = HEAP8[$45>>0]|0;
      $223 = ($222<<24>>24)<(0);
      $224 = HEAP32[$46>>2]|0;
      $225 = $222&255;
      $226 = $223 ? $224 : $225;
      $227 = (0 - ($226))|0;
      $228 = ($221|0)==($227|0);
      if ($228) {
       $$1150 = $$0149;
      } else {
       $229 = ($221|0)==(0);
       if ($229) {
        $271 = HEAP32[$0>>2]|0;
        $272 = ((($271)) + 12|0);
        $273 = HEAP32[$272>>2]|0;
        $274 = ((($271)) + 16|0);
        $275 = HEAP32[$274>>2]|0;
        $276 = ($273|0)==($275|0);
        if ($276) {
         $277 = HEAP32[$271>>2]|0;
         $278 = ((($277)) + 36|0);
         $279 = HEAP32[$278>>2]|0;
         __THREW__ = 0;
         $280 = (invoke_ii($279|0,($271|0))|0);
         $281 = __THREW__; __THREW__ = 0;
         $282 = $281&1;
         if ($282) {
          label = 35;
          break L24;
         } else {
          $$0$i$i217 = $280;
         }
        } else {
         $283 = HEAP8[$273>>0]|0;
         $284 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($283)|0);
         $$0$i$i217 = $284;
        }
        $285 = $$0$i$i217&255;
        $286 = HEAP8[$45>>0]|0;
        $287 = ($286<<24>>24)<(0);
        $288 = HEAP32[$22>>2]|0;
        $289 = $287 ? $288 : $22;
        $290 = HEAP8[$289>>0]|0;
        $291 = ($285<<24>>24)==($290<<24>>24);
        if (!($291)) {
         $$1150 = $$0149;
         break L49;
        }
        $292 = HEAP32[$0>>2]|0;
        $293 = ((($292)) + 12|0);
        $294 = HEAP32[$293>>2]|0;
        $295 = ((($292)) + 16|0);
        $296 = HEAP32[$295>>2]|0;
        $297 = ($294|0)==($296|0);
        if ($297) {
         $298 = HEAP32[$292>>2]|0;
         $299 = ((($298)) + 40|0);
         $300 = HEAP32[$299>>2]|0;
         __THREW__ = 0;
         (invoke_ii($300|0,($292|0))|0);
         $301 = __THREW__; __THREW__ = 0;
         $302 = $301&1;
         if ($302) {
          label = 35;
          break L24;
         }
        } else {
         $303 = ((($294)) + 1|0);
         HEAP32[$293>>2] = $303;
         $304 = HEAP8[$294>>0]|0;
         (__ZNSt3__211char_traitsIcE11to_int_typeEc($304)|0);
        }
        HEAP8[$6>>0] = 1;
        $305 = HEAP8[$45>>0]|0;
        $306 = ($305<<24>>24)<(0);
        $307 = HEAP32[$46>>2]|0;
        $308 = $305&255;
        $309 = $306 ? $307 : $308;
        $310 = ($309>>>0)>(1);
        $$$0149159 = $310 ? $22 : $$0149;
        $$1150 = $$$0149159;
        break L49;
       }
       $230 = ($226|0)==(0);
       $231 = HEAP32[$0>>2]|0;
       $232 = ((($231)) + 12|0);
       $233 = HEAP32[$232>>2]|0;
       $234 = ((($231)) + 16|0);
       $235 = HEAP32[$234>>2]|0;
       $236 = ($233|0)==($235|0);
       if ($230) {
        if ($236) {
         $237 = HEAP32[$231>>2]|0;
         $238 = ((($237)) + 36|0);
         $239 = HEAP32[$238>>2]|0;
         __THREW__ = 0;
         $240 = (invoke_ii($239|0,($231|0))|0);
         $241 = __THREW__; __THREW__ = 0;
         $242 = $241&1;
         if ($242) {
          label = 35;
          break L24;
         } else {
          $$0$i$i212 = $240;
         }
        } else {
         $243 = HEAP8[$233>>0]|0;
         $244 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($243)|0);
         $$0$i$i212 = $244;
        }
        $245 = $$0$i$i212&255;
        $246 = HEAP8[$43>>0]|0;
        $247 = ($246<<24>>24)<(0);
        $248 = HEAP32[$21>>2]|0;
        $249 = $247 ? $248 : $21;
        $250 = HEAP8[$249>>0]|0;
        $251 = ($245<<24>>24)==($250<<24>>24);
        if (!($251)) {
         HEAP8[$6>>0] = 1;
         $$1150 = $$0149;
         break L49;
        }
        $252 = HEAP32[$0>>2]|0;
        $253 = ((($252)) + 12|0);
        $254 = HEAP32[$253>>2]|0;
        $255 = ((($252)) + 16|0);
        $256 = HEAP32[$255>>2]|0;
        $257 = ($254|0)==($256|0);
        if ($257) {
         $258 = HEAP32[$252>>2]|0;
         $259 = ((($258)) + 40|0);
         $260 = HEAP32[$259>>2]|0;
         __THREW__ = 0;
         (invoke_ii($260|0,($252|0))|0);
         $261 = __THREW__; __THREW__ = 0;
         $262 = $261&1;
         if ($262) {
          label = 35;
          break L24;
         }
        } else {
         $263 = ((($254)) + 1|0);
         HEAP32[$253>>2] = $263;
         $264 = HEAP8[$254>>0]|0;
         (__ZNSt3__211char_traitsIcE11to_int_typeEc($264)|0);
        }
        $265 = HEAP8[$43>>0]|0;
        $266 = ($265<<24>>24)<(0);
        $267 = HEAP32[$44>>2]|0;
        $268 = $265&255;
        $269 = $266 ? $267 : $268;
        $270 = ($269>>>0)>(1);
        $$$0149 = $270 ? $21 : $$0149;
        $$1150 = $$$0149;
        break L49;
       }
       if ($236) {
        $311 = HEAP32[$231>>2]|0;
        $312 = ((($311)) + 36|0);
        $313 = HEAP32[$312>>2]|0;
        __THREW__ = 0;
        $314 = (invoke_ii($313|0,($231|0))|0);
        $315 = __THREW__; __THREW__ = 0;
        $316 = $315&1;
        if ($316) {
         label = 35;
         break L24;
        } else {
         $$0$i$i224 = $314;
        }
       } else {
        $317 = HEAP8[$233>>0]|0;
        $318 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($317)|0);
        $$0$i$i224 = $318;
       }
       $319 = $$0$i$i224&255;
       $320 = HEAP8[$43>>0]|0;
       $321 = ($320<<24>>24)<(0);
       $322 = HEAP32[$21>>2]|0;
       $323 = $321 ? $322 : $21;
       $324 = HEAP8[$323>>0]|0;
       $325 = ($319<<24>>24)==($324<<24>>24);
       $326 = HEAP32[$0>>2]|0;
       $327 = ((($326)) + 12|0);
       $328 = HEAP32[$327>>2]|0;
       $329 = ((($326)) + 16|0);
       $330 = HEAP32[$329>>2]|0;
       $331 = ($328|0)==($330|0);
       if ($325) {
        if ($331) {
         $332 = HEAP32[$326>>2]|0;
         $333 = ((($332)) + 40|0);
         $334 = HEAP32[$333>>2]|0;
         __THREW__ = 0;
         (invoke_ii($334|0,($326|0))|0);
         $335 = __THREW__; __THREW__ = 0;
         $336 = $335&1;
         if ($336) {
          label = 35;
          break L24;
         }
        } else {
         $337 = ((($328)) + 1|0);
         HEAP32[$327>>2] = $337;
         $338 = HEAP8[$328>>0]|0;
         (__ZNSt3__211char_traitsIcE11to_int_typeEc($338)|0);
        }
        $339 = HEAP8[$43>>0]|0;
        $340 = ($339<<24>>24)<(0);
        $341 = HEAP32[$44>>2]|0;
        $342 = $339&255;
        $343 = $340 ? $341 : $342;
        $344 = ($343>>>0)>(1);
        $$$0149160 = $344 ? $21 : $$0149;
        $$1150 = $$$0149160;
        break L49;
       }
       if ($331) {
        $345 = HEAP32[$326>>2]|0;
        $346 = ((($345)) + 36|0);
        $347 = HEAP32[$346>>2]|0;
        __THREW__ = 0;
        $348 = (invoke_ii($347|0,($326|0))|0);
        $349 = __THREW__; __THREW__ = 0;
        $350 = $349&1;
        if ($350) {
         label = 35;
         break L24;
        } else {
         $$0$i$i231 = $348;
        }
       } else {
        $351 = HEAP8[$328>>0]|0;
        $352 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($351)|0);
        $$0$i$i231 = $352;
       }
       $353 = $$0$i$i231&255;
       $354 = HEAP8[$45>>0]|0;
       $355 = ($354<<24>>24)<(0);
       $356 = HEAP32[$22>>2]|0;
       $357 = $355 ? $356 : $22;
       $358 = HEAP8[$357>>0]|0;
       $359 = ($353<<24>>24)==($358<<24>>24);
       if (!($359)) {
        label = 109;
        break L24;
       }
       $360 = HEAP32[$0>>2]|0;
       $361 = ((($360)) + 12|0);
       $362 = HEAP32[$361>>2]|0;
       $363 = ((($360)) + 16|0);
       $364 = HEAP32[$363>>2]|0;
       $365 = ($362|0)==($364|0);
       if ($365) {
        $366 = HEAP32[$360>>2]|0;
        $367 = ((($366)) + 40|0);
        $368 = HEAP32[$367>>2]|0;
        __THREW__ = 0;
        (invoke_ii($368|0,($360|0))|0);
        $369 = __THREW__; __THREW__ = 0;
        $370 = $369&1;
        if ($370) {
         label = 35;
         break L24;
        }
       } else {
        $371 = ((($362)) + 1|0);
        HEAP32[$361>>2] = $371;
        $372 = HEAP8[$362>>0]|0;
        (__ZNSt3__211char_traitsIcE11to_int_typeEc($372)|0);
       }
       HEAP8[$6>>0] = 1;
       $373 = HEAP8[$45>>0]|0;
       $374 = ($373<<24>>24)<(0);
       $375 = HEAP32[$46>>2]|0;
       $376 = $373&255;
       $377 = $374 ? $375 : $376;
       $378 = ($377>>>0)>(1);
       $$$0149161 = $378 ? $22 : $$0149;
       $$1150 = $$$0149161;
      }
      break;
     }
     case 2:  {
      $381 = ($$0158>>>0)<(2);
      $or$cond = $381 | $57;
      if (!($or$cond)) {
       $382 = ($$0158|0)==(2);
       $383 = HEAP8[$53>>0]|0;
       $384 = ($383<<24>>24)!=(0);
       $385 = $382 & $384;
       $brmerge = $48 | $385;
       if (!($brmerge)) {
        $$1150 = 0;
        break L49;
       }
      }
      $386 = HEAP8[$49>>0]|0;
      $387 = ($386<<24>>24)<(0);
      $388 = HEAP32[$20>>2]|0;
      $389 = $387 ? $388 : $20;
      $390 = $389;
      $391 = ($$0158|0)==(0);
      L115: do {
       if ($391) {
        $$pre$i4$i$i260 = $903;$$sroa$0360$0 = $390;$430 = $386;$434 = $388;$457 = $903;
       } else {
        $392 = (($$0158) + -1)|0;
        $393 = (($16) + ($392)|0);
        $394 = HEAP8[$393>>0]|0;
        $switch = ($394&255)<(2);
        if ($switch) {
         $395 = HEAP32[$50>>2]|0;
         $396 = $386&255;
         $397 = $387 ? $395 : $396;
         $398 = (($389) + ($397)|0);
         $$sroa$0381$0 = $390;
         while(1) {
          $399 = $$sroa$0381$0;
          $400 = ($399|0)==($398|0);
          if ($400) {
           break;
          }
          $401 = HEAP8[$399>>0]|0;
          $402 = ($401<<24>>24)>(-1);
          if (!($402)) {
           break;
          }
          $403 = $401 << 24 >> 24;
          $404 = HEAP32[$42>>2]|0;
          $405 = (($404) + ($403<<1)|0);
          $406 = HEAP16[$405>>1]|0;
          $407 = $406 & 8192;
          $408 = ($407<<16>>16)==(0);
          if ($408) {
           break;
          }
          $409 = ((($399)) + 1|0);
          $410 = $409;
          $$sroa$0381$0 = $410;
         }
         $411 = (($$sroa$0381$0) - ($390))|0;
         $412 = HEAP8[$51>>0]|0;
         $413 = ($412<<24>>24)<(0);
         $414 = HEAP32[$52>>2]|0;
         $415 = $412&255;
         $416 = $413 ? $414 : $415;
         $417 = ($411>>>0)>($416>>>0);
         if ($417) {
          $$pre$i4$i$i260 = $903;$$sroa$0360$0 = $390;$430 = $386;$434 = $388;$457 = $903;
         } else {
          $418 = HEAP32[$23>>2]|0;
          $419 = $413 ? $418 : $23;
          $420 = (($419) + ($416)|0);
          $421 = (0 - ($411))|0;
          $422 = (($420) + ($421)|0);
          $$sink = $389;$423 = $422;
          while(1) {
           $424 = ($423|0)==($420|0);
           if ($424) {
            $$pre$i4$i$i260 = $903;$$sroa$0360$0 = $$sroa$0381$0;$430 = $386;$434 = $388;$457 = $903;
            break L115;
           }
           $425 = HEAP8[$423>>0]|0;
           $426 = HEAP8[$$sink>>0]|0;
           $427 = ($425<<24>>24)==($426<<24>>24);
           if (!($427)) {
            $$pre$i4$i$i260 = $903;$$sroa$0360$0 = $390;$430 = $386;$434 = $388;$457 = $903;
            break L115;
           }
           $428 = ((($423)) + 1|0);
           $429 = ((($$sink)) + 1|0);
           $$sink = $429;$423 = $428;
          }
         }
        } else {
         $$pre$i4$i$i260 = $903;$$sroa$0360$0 = $390;$430 = $386;$434 = $388;$457 = $903;
        }
       }
      } while(0);
      L129: while(1) {
       $431 = ($430<<24>>24)<(0);
       $432 = HEAP32[$50>>2]|0;
       $433 = $430&255;
       $435 = $431 ? $434 : $20;
       $436 = $431 ? $432 : $433;
       $437 = (($435) + ($436)|0);
       $438 = $$sroa$0360$0;
       $439 = ($438|0)==($437|0);
       if ($439) {
        $$lcssa = $437;
        break;
       }
       $440 = HEAP32[$0>>2]|0;
       $441 = ($440|0)==(0|0);
       do {
        if ($441) {
         $474 = 1;
        } else {
         $442 = ((($440)) + 12|0);
         $443 = HEAP32[$442>>2]|0;
         $444 = ((($440)) + 16|0);
         $445 = HEAP32[$444>>2]|0;
         $446 = ($443|0)==($445|0);
         if ($446) {
          $447 = HEAP32[$440>>2]|0;
          $448 = ((($447)) + 36|0);
          $449 = HEAP32[$448>>2]|0;
          __THREW__ = 0;
          $450 = (invoke_ii($449|0,($440|0))|0);
          $451 = __THREW__; __THREW__ = 0;
          $452 = $451&1;
          if ($452) {
           label = 148;
           break L24;
          } else {
           $$0$i$i$i$i252 = $450;
          }
         } else {
          $453 = HEAP8[$443>>0]|0;
          $454 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($453)|0);
          $$0$i$i$i$i252 = $454;
         }
         $455 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
         $456 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i$i$i252,$455)|0);
         if ($456) {
          HEAP32[$0>>2] = 0;
          $474 = 1;
          break;
         } else {
          $$pre$i$i$i254 = HEAP32[$0>>2]|0;
          $phitmp$i$i$i255 = ($$pre$i$i$i254|0)==(0|0);
          $474 = $phitmp$i$i$i255;
          break;
         }
        }
       } while(0);
       $458 = ($457|0)==(0|0);
       do {
        if ($458) {
         $$pre$i4$i$i260510 = $$pre$i4$i$i260;
         label = 138;
        } else {
         $459 = ((($457)) + 12|0);
         $460 = HEAP32[$459>>2]|0;
         $461 = ((($457)) + 16|0);
         $462 = HEAP32[$461>>2]|0;
         $463 = ($460|0)==($462|0);
         if ($463) {
          $464 = HEAP32[$457>>2]|0;
          $465 = ((($464)) + 36|0);
          $466 = HEAP32[$465>>2]|0;
          __THREW__ = 0;
          $467 = (invoke_ii($466|0,($457|0))|0);
          $468 = __THREW__; __THREW__ = 0;
          $469 = $468&1;
          if ($469) {
           label = 148;
           break L24;
          } else {
           $$0$i$i2$i$i258 = $467;
          }
         } else {
          $470 = HEAP8[$460>>0]|0;
          $471 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($470)|0);
          $$0$i$i2$i$i258 = $471;
         }
         $472 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
         $473 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i2$i$i258,$472)|0);
         if ($473) {
          HEAP32[$1>>2] = 0;
          $$pre$i4$i$i260510 = 0;
          label = 138;
          break;
         } else {
          $phitmp$i5$i$i261 = ($$pre$i4$i$i260|0)==(0|0);
          $tmp$i$i263 = $474 ^ $phitmp$i5$i$i261;
          if ($tmp$i$i263) {
           $$pre$i4$i$i260509 = $$pre$i4$i$i260;$905 = $$pre$i4$i$i260;
           break;
          } else {
           $$lcssa = $438;
           break L129;
          }
         }
        }
       } while(0);
       if ((label|0) == 138) {
        label = 0;
        if ($474) {
         $$lcssa = $438;
         break;
        } else {
         $$pre$i4$i$i260509 = $$pre$i4$i$i260510;$905 = 0;
        }
       }
       $475 = HEAP32[$0>>2]|0;
       $476 = ((($475)) + 12|0);
       $477 = HEAP32[$476>>2]|0;
       $478 = ((($475)) + 16|0);
       $479 = HEAP32[$478>>2]|0;
       $480 = ($477|0)==($479|0);
       if ($480) {
        $481 = HEAP32[$475>>2]|0;
        $482 = ((($481)) + 36|0);
        $483 = HEAP32[$482>>2]|0;
        __THREW__ = 0;
        $484 = (invoke_ii($483|0,($475|0))|0);
        $485 = __THREW__; __THREW__ = 0;
        $486 = $485&1;
        if ($486) {
         label = 148;
         break L24;
        } else {
         $$0$i$i267 = $484;
        }
       } else {
        $487 = HEAP8[$477>>0]|0;
        $488 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($487)|0);
        $$0$i$i267 = $488;
       }
       $489 = $$0$i$i267&255;
       $490 = HEAP8[$438>>0]|0;
       $491 = ($489<<24>>24)==($490<<24>>24);
       if (!($491)) {
        $$lcssa = $438;
        break;
       }
       $492 = HEAP32[$0>>2]|0;
       $493 = ((($492)) + 12|0);
       $494 = HEAP32[$493>>2]|0;
       $495 = ((($492)) + 16|0);
       $496 = HEAP32[$495>>2]|0;
       $497 = ($494|0)==($496|0);
       if ($497) {
        $498 = HEAP32[$492>>2]|0;
        $499 = ((($498)) + 40|0);
        $500 = HEAP32[$499>>2]|0;
        __THREW__ = 0;
        (invoke_ii($500|0,($492|0))|0);
        $501 = __THREW__; __THREW__ = 0;
        $502 = $501&1;
        if ($502) {
         label = 149;
         break L24;
        }
       } else {
        $503 = ((($494)) + 1|0);
        HEAP32[$493>>2] = $503;
        $504 = HEAP8[$494>>0]|0;
        (__ZNSt3__211char_traitsIcE11to_int_typeEc($504)|0);
       }
       $505 = ((($438)) + 1|0);
       $506 = $505;
       $$pre507 = HEAP8[$49>>0]|0;
       $$pre508 = HEAP32[$20>>2]|0;
       $$pre$i4$i$i260 = $$pre$i4$i$i260509;$$sroa$0360$0 = $506;$430 = $$pre507;$434 = $$pre508;$457 = $905;
      }
      if ($48) {
       $511 = HEAP8[$49>>0]|0;
       $512 = ($511<<24>>24)<(0);
       $513 = HEAP32[$20>>2]|0;
       $514 = HEAP32[$50>>2]|0;
       $515 = $511&255;
       $516 = $512 ? $513 : $20;
       $517 = $512 ? $514 : $515;
       $518 = (($516) + ($517)|0);
       $519 = ($$lcssa|0)==($518|0);
       if ($519) {
        $$1150 = $$0149;
       } else {
        label = 152;
        break L24;
       }
      } else {
       $$1150 = $$0149;
      }
      break;
     }
     case 4:  {
      $$0132 = 0;$$pre$i4$i$i281 = $903;$539 = $903;
      L165: while(1) {
       $522 = HEAP32[$0>>2]|0;
       $523 = ($522|0)==(0|0);
       do {
        if ($523) {
         $556 = 1;
        } else {
         $524 = ((($522)) + 12|0);
         $525 = HEAP32[$524>>2]|0;
         $526 = ((($522)) + 16|0);
         $527 = HEAP32[$526>>2]|0;
         $528 = ($525|0)==($527|0);
         if ($528) {
          $529 = HEAP32[$522>>2]|0;
          $530 = ((($529)) + 36|0);
          $531 = HEAP32[$530>>2]|0;
          __THREW__ = 0;
          $532 = (invoke_ii($531|0,($522|0))|0);
          $533 = __THREW__; __THREW__ = 0;
          $534 = $533&1;
          if ($534) {
           label = 244;
           break L24;
          } else {
           $$0$i$i$i$i273 = $532;
          }
         } else {
          $535 = HEAP8[$525>>0]|0;
          $536 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($535)|0);
          $$0$i$i$i$i273 = $536;
         }
         $537 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
         $538 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i$i$i273,$537)|0);
         if ($538) {
          HEAP32[$0>>2] = 0;
          $556 = 1;
          break;
         } else {
          $$pre$i$i$i275 = HEAP32[$0>>2]|0;
          $phitmp$i$i$i276 = ($$pre$i$i$i275|0)==(0|0);
          $556 = $phitmp$i$i$i276;
          break;
         }
        }
       } while(0);
       $540 = ($539|0)==(0|0);
       do {
        if ($540) {
         $$pre$i4$i$i281498 = $$pre$i4$i$i281;
         label = 166;
        } else {
         $541 = ((($539)) + 12|0);
         $542 = HEAP32[$541>>2]|0;
         $543 = ((($539)) + 16|0);
         $544 = HEAP32[$543>>2]|0;
         $545 = ($542|0)==($544|0);
         if ($545) {
          $546 = HEAP32[$539>>2]|0;
          $547 = ((($546)) + 36|0);
          $548 = HEAP32[$547>>2]|0;
          __THREW__ = 0;
          $549 = (invoke_ii($548|0,($539|0))|0);
          $550 = __THREW__; __THREW__ = 0;
          $551 = $550&1;
          if ($551) {
           label = 244;
           break L24;
          } else {
           $$0$i$i2$i$i279 = $549;
          }
         } else {
          $552 = HEAP8[$542>>0]|0;
          $553 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($552)|0);
          $$0$i$i2$i$i279 = $553;
         }
         $554 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
         $555 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i2$i$i279,$554)|0);
         if ($555) {
          HEAP32[$1>>2] = 0;
          $$pre$i4$i$i281498 = 0;
          label = 166;
          break;
         } else {
          $phitmp$i5$i$i282 = ($$pre$i4$i$i281|0)==(0|0);
          $tmp$i$i284 = $556 ^ $phitmp$i5$i$i282;
          if ($tmp$i$i284) {
           $$pre$i4$i$i281500 = $$pre$i4$i$i281;$906 = $$pre$i4$i$i281;
           break;
          } else {
           $$pre$i4$i$i303 = $$pre$i4$i$i281;
           break L165;
          }
         }
        }
       } while(0);
       if ((label|0) == 166) {
        label = 0;
        if ($556) {
         $$pre$i4$i$i303 = $$pre$i4$i$i281498;
         break;
        } else {
         $$pre$i4$i$i281500 = $$pre$i4$i$i281498;$906 = 0;
        }
       }
       $557 = HEAP32[$0>>2]|0;
       $558 = ((($557)) + 12|0);
       $559 = HEAP32[$558>>2]|0;
       $560 = ((($557)) + 16|0);
       $561 = HEAP32[$560>>2]|0;
       $562 = ($559|0)==($561|0);
       if ($562) {
        $563 = HEAP32[$557>>2]|0;
        $564 = ((($563)) + 36|0);
        $565 = HEAP32[$564>>2]|0;
        __THREW__ = 0;
        $566 = (invoke_ii($565|0,($557|0))|0);
        $567 = __THREW__; __THREW__ = 0;
        $568 = $567&1;
        if ($568) {
         label = 244;
         break L24;
        } else {
         $$0$i$i288 = $566;
        }
       } else {
        $569 = HEAP8[$559>>0]|0;
        $570 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($569)|0);
        $$0$i$i288 = $570;
       }
       $571 = $$0$i$i288&255;
       $572 = ($571<<24>>24)>(-1);
       if ($572) {
        $sext421 = $$0$i$i288 << 24;
        $573 = $sext421 >> 24;
        $574 = HEAP32[$42>>2]|0;
        $575 = (($574) + ($573<<1)|0);
        $576 = HEAP16[$575>>1]|0;
        $577 = $576 & 2048;
        $578 = ($577<<16>>16)==(0);
        if ($578) {
         label = 177;
        } else {
         $579 = HEAP32[$9>>2]|0;
         $580 = HEAP32[$11>>2]|0;
         $581 = ($579|0)==($580|0);
         if ($581) {
          __THREW__ = 0;
          invoke_viii(4721,($8|0),($9|0),($11|0));
          $582 = __THREW__; __THREW__ = 0;
          $583 = $582&1;
          if ($583) {
           label = 244;
           break L24;
          }
          $$pre = HEAP32[$9>>2]|0;
          $585 = $$pre;
         } else {
          $585 = $579;
         }
         $584 = ((($585)) + 1|0);
         HEAP32[$9>>2] = $584;
         HEAP8[$585>>0] = $571;
         $586 = (($$0132) + 1)|0;
         $$2134$ph = $586;
        }
       } else {
        label = 177;
       }
       if ((label|0) == 177) {
        label = 0;
        $587 = HEAP8[$54>>0]|0;
        $588 = ($587<<24>>24)<(0);
        $589 = HEAP32[$55>>2]|0;
        $590 = $587&255;
        $591 = $588 ? $589 : $590;
        $592 = ($591|0)!=(0);
        $593 = ($$0132|0)!=(0);
        $or$cond13 = $593 & $592;
        $594 = HEAP8[$18>>0]|0;
        $595 = ($571<<24>>24)==($594<<24>>24);
        $or$cond164 = $595 & $or$cond13;
        if (!($or$cond164)) {
         $$pre$i4$i$i303 = $$pre$i4$i$i281500;
         break;
        }
        $596 = HEAP32[$14>>2]|0;
        $597 = HEAP32[$15>>2]|0;
        $598 = ($596|0)==($597|0);
        if ($598) {
         __THREW__ = 0;
         invoke_viii(4722,($13|0),($14|0),($15|0));
         $599 = __THREW__; __THREW__ = 0;
         $600 = $599&1;
         if ($600) {
          label = 244;
          break L24;
         }
         $$pre502 = HEAP32[$14>>2]|0;
         $602 = $$pre502;
        } else {
         $602 = $596;
        }
        $601 = ((($602)) + 4|0);
        HEAP32[$14>>2] = $601;
        HEAP32[$602>>2] = $$0132;
        $$2134$ph = 0;
       }
       $603 = HEAP32[$0>>2]|0;
       $604 = ((($603)) + 12|0);
       $605 = HEAP32[$604>>2]|0;
       $606 = ((($603)) + 16|0);
       $607 = HEAP32[$606>>2]|0;
       $608 = ($605|0)==($607|0);
       if ($608) {
        $609 = HEAP32[$603>>2]|0;
        $610 = ((($609)) + 40|0);
        $611 = HEAP32[$610>>2]|0;
        __THREW__ = 0;
        (invoke_ii($611|0,($603|0))|0);
        $612 = __THREW__; __THREW__ = 0;
        $613 = $612&1;
        if ($613) {
         label = 244;
         break L24;
        } else {
         $$0132 = $$2134$ph;$$pre$i4$i$i281 = $$pre$i4$i$i281500;$539 = $906;
         continue;
        }
       } else {
        $614 = ((($605)) + 1|0);
        HEAP32[$604>>2] = $614;
        $615 = HEAP8[$605>>0]|0;
        (__ZNSt3__211char_traitsIcE11to_int_typeEc($615)|0);
        $$0132 = $$2134$ph;$$pre$i4$i$i281 = $$pre$i4$i$i281500;$539 = $906;
        continue;
       }
      }
      $616 = HEAP32[$13>>2]|0;
      $617 = HEAP32[$14>>2]|0;
      $618 = ($616|0)!=($617|0);
      $619 = ($$0132|0)!=(0);
      $or$cond15 = $619 & $618;
      if ($or$cond15) {
       $620 = HEAP32[$15>>2]|0;
       $621 = ($617|0)==($620|0);
       if ($621) {
        __THREW__ = 0;
        invoke_viii(4722,($13|0),($14|0),($15|0));
        $622 = __THREW__; __THREW__ = 0;
        $623 = $622&1;
        if ($623) {
         label = 244;
         break L24;
        }
        $$pre504 = HEAP32[$14>>2]|0;
        $625 = $$pre504;
       } else {
        $625 = $617;
       }
       $624 = ((($625)) + 4|0);
       HEAP32[$14>>2] = $624;
       HEAP32[$625>>2] = $$0132;
      }
      $626 = HEAP32[$24>>2]|0;
      $627 = ($626|0)>(0);
      L219: do {
       if ($627) {
        $628 = HEAP32[$0>>2]|0;
        $629 = ($628|0)==(0|0);
        do {
         if ($629) {
          $907 = 1;
         } else {
          $630 = ((($628)) + 12|0);
          $631 = HEAP32[$630>>2]|0;
          $632 = ((($628)) + 16|0);
          $633 = HEAP32[$632>>2]|0;
          $634 = ($631|0)==($633|0);
          if ($634) {
           $635 = HEAP32[$628>>2]|0;
           $636 = ((($635)) + 36|0);
           $637 = HEAP32[$636>>2]|0;
           __THREW__ = 0;
           $638 = (invoke_ii($637|0,($628|0))|0);
           $639 = __THREW__; __THREW__ = 0;
           $640 = $639&1;
           if ($640) {
            label = 244;
            break L24;
           } else {
            $$0$i$i$i$i295 = $638;
           }
          } else {
           $641 = HEAP8[$631>>0]|0;
           $642 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($641)|0);
           $$0$i$i$i$i295 = $642;
          }
          $643 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
          $644 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i$i$i295,$643)|0);
          if ($644) {
           HEAP32[$0>>2] = 0;
           $907 = 1;
           break;
          } else {
           $$pre$i$i$i297 = HEAP32[$0>>2]|0;
           $phitmp$i$i$i298 = ($$pre$i$i$i297|0)==(0|0);
           $907 = $phitmp$i$i$i298;
           break;
          }
         }
        } while(0);
        $645 = ($$pre$i4$i$i303|0)==(0|0);
        do {
         if ($645) {
          label = 204;
         } else {
          $646 = ((($$pre$i4$i$i303)) + 12|0);
          $647 = HEAP32[$646>>2]|0;
          $648 = ((($$pre$i4$i$i303)) + 16|0);
          $649 = HEAP32[$648>>2]|0;
          $650 = ($647|0)==($649|0);
          if ($650) {
           $651 = HEAP32[$$pre$i4$i$i303>>2]|0;
           $652 = ((($651)) + 36|0);
           $653 = HEAP32[$652>>2]|0;
           __THREW__ = 0;
           $654 = (invoke_ii($653|0,($$pre$i4$i$i303|0))|0);
           $655 = __THREW__; __THREW__ = 0;
           $656 = $655&1;
           if ($656) {
            label = 244;
            break L24;
           } else {
            $$0$i$i2$i$i301 = $654;
           }
          } else {
           $657 = HEAP8[$647>>0]|0;
           $658 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($657)|0);
           $$0$i$i2$i$i301 = $658;
          }
          $659 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
          $660 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i2$i$i301,$659)|0);
          if ($660) {
           HEAP32[$1>>2] = 0;
           label = 204;
           break;
          } else {
           if ($907) {
            $908 = $$pre$i4$i$i303;
            break;
           } else {
            label = 243;
            break L24;
           }
          }
         }
        } while(0);
        if ((label|0) == 204) {
         label = 0;
         if ($907) {
          label = 243;
          break L24;
         } else {
          $908 = 0;
         }
        }
        $661 = HEAP32[$0>>2]|0;
        $662 = ((($661)) + 12|0);
        $663 = HEAP32[$662>>2]|0;
        $664 = ((($661)) + 16|0);
        $665 = HEAP32[$664>>2]|0;
        $666 = ($663|0)==($665|0);
        if ($666) {
         $667 = HEAP32[$661>>2]|0;
         $668 = ((($667)) + 36|0);
         $669 = HEAP32[$668>>2]|0;
         __THREW__ = 0;
         $670 = (invoke_ii($669|0,($661|0))|0);
         $671 = __THREW__; __THREW__ = 0;
         $672 = $671&1;
         if ($672) {
          label = 244;
          break L24;
         } else {
          $$0$i$i309 = $670;
         }
        } else {
         $673 = HEAP8[$663>>0]|0;
         $674 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($673)|0);
         $$0$i$i309 = $674;
        }
        $675 = $$0$i$i309&255;
        $676 = HEAP8[$17>>0]|0;
        $677 = ($675<<24>>24)==($676<<24>>24);
        if (!($677)) {
         label = 243;
         break L24;
        }
        $678 = HEAP32[$0>>2]|0;
        $679 = ((($678)) + 12|0);
        $680 = HEAP32[$679>>2]|0;
        $681 = ((($678)) + 16|0);
        $682 = HEAP32[$681>>2]|0;
        $683 = ($680|0)==($682|0);
        if ($683) {
         $684 = HEAP32[$678>>2]|0;
         $685 = ((($684)) + 40|0);
         $686 = HEAP32[$685>>2]|0;
         __THREW__ = 0;
         (invoke_ii($686|0,($678|0))|0);
         $687 = __THREW__; __THREW__ = 0;
         $688 = $687&1;
         if ($688) {
          label = 244;
          break L24;
         } else {
          $$pre$i4$i$i322 = $908;$710 = $908;
         }
        } else {
         $689 = ((($680)) + 1|0);
         HEAP32[$679>>2] = $689;
         $690 = HEAP8[$680>>0]|0;
         (__ZNSt3__211char_traitsIcE11to_int_typeEc($690)|0);
         $$pre$i4$i$i322 = $908;$710 = $908;
        }
        while(1) {
         $691 = HEAP32[$24>>2]|0;
         $692 = ($691|0)>(0);
         if (!($692)) {
          break L219;
         }
         $693 = HEAP32[$0>>2]|0;
         $694 = ($693|0)==(0|0);
         do {
          if ($694) {
           $727 = 1;
          } else {
           $695 = ((($693)) + 12|0);
           $696 = HEAP32[$695>>2]|0;
           $697 = ((($693)) + 16|0);
           $698 = HEAP32[$697>>2]|0;
           $699 = ($696|0)==($698|0);
           if ($699) {
            $700 = HEAP32[$693>>2]|0;
            $701 = ((($700)) + 36|0);
            $702 = HEAP32[$701>>2]|0;
            __THREW__ = 0;
            $703 = (invoke_ii($702|0,($693|0))|0);
            $704 = __THREW__; __THREW__ = 0;
            $705 = $704&1;
            if ($705) {
             label = 244;
             break L24;
            } else {
             $$0$i$i$i$i314 = $703;
            }
           } else {
            $706 = HEAP8[$696>>0]|0;
            $707 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($706)|0);
            $$0$i$i$i$i314 = $707;
           }
           $708 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
           $709 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i$i$i314,$708)|0);
           if ($709) {
            HEAP32[$0>>2] = 0;
            $727 = 1;
            break;
           } else {
            $$pre$i$i$i316 = HEAP32[$0>>2]|0;
            $phitmp$i$i$i317 = ($$pre$i$i$i316|0)==(0|0);
            $727 = $phitmp$i$i$i317;
            break;
           }
          }
         } while(0);
         $711 = ($710|0)==(0|0);
         do {
          if ($711) {
           $$pre$i4$i$i322505$ph = $$pre$i4$i$i322;
           label = 227;
          } else {
           $712 = ((($710)) + 12|0);
           $713 = HEAP32[$712>>2]|0;
           $714 = ((($710)) + 16|0);
           $715 = HEAP32[$714>>2]|0;
           $716 = ($713|0)==($715|0);
           if ($716) {
            $717 = HEAP32[$710>>2]|0;
            $718 = ((($717)) + 36|0);
            $719 = HEAP32[$718>>2]|0;
            __THREW__ = 0;
            $720 = (invoke_ii($719|0,($710|0))|0);
            $721 = __THREW__; __THREW__ = 0;
            $722 = $721&1;
            if ($722) {
             label = 244;
             break L24;
            } else {
             $$0$i$i2$i$i320 = $720;
            }
           } else {
            $723 = HEAP8[$713>>0]|0;
            $724 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($723)|0);
            $$0$i$i2$i$i320 = $724;
           }
           $725 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
           $726 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i2$i$i320,$725)|0);
           if ($726) {
            HEAP32[$1>>2] = 0;
            $$pre$i4$i$i322505$ph = 0;
            label = 227;
            break;
           } else {
            $phitmp$i5$i$i323 = ($$pre$i4$i$i322|0)==(0|0);
            $tmp$i$i325 = $727 ^ $phitmp$i5$i$i323;
            if ($tmp$i$i325) {
             $$pre$i4$i$i322505518 = $$pre$i4$i$i322;$909 = $$pre$i4$i$i322;
             break;
            } else {
             label = 243;
             break L24;
            }
           }
          }
         } while(0);
         if ((label|0) == 227) {
          label = 0;
          if ($727) {
           label = 243;
           break L24;
          } else {
           $$pre$i4$i$i322505518 = $$pre$i4$i$i322505$ph;$909 = 0;
          }
         }
         $728 = HEAP32[$0>>2]|0;
         $729 = ((($728)) + 12|0);
         $730 = HEAP32[$729>>2]|0;
         $731 = ((($728)) + 16|0);
         $732 = HEAP32[$731>>2]|0;
         $733 = ($730|0)==($732|0);
         if ($733) {
          $734 = HEAP32[$728>>2]|0;
          $735 = ((($734)) + 36|0);
          $736 = HEAP32[$735>>2]|0;
          __THREW__ = 0;
          $737 = (invoke_ii($736|0,($728|0))|0);
          $738 = __THREW__; __THREW__ = 0;
          $739 = $738&1;
          if ($739) {
           label = 244;
           break L24;
          } else {
           $$0$i$i329 = $737;
          }
         } else {
          $740 = HEAP8[$730>>0]|0;
          $741 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($740)|0);
          $$0$i$i329 = $741;
         }
         $742 = $$0$i$i329&255;
         $743 = ($742<<24>>24)>(-1);
         if (!($743)) {
          label = 243;
          break L24;
         }
         $sext = $$0$i$i329 << 24;
         $744 = $sext >> 24;
         $745 = HEAP32[$42>>2]|0;
         $746 = (($745) + ($744<<1)|0);
         $747 = HEAP16[$746>>1]|0;
         $748 = $747 & 2048;
         $749 = ($748<<16>>16)==(0);
         if ($749) {
          label = 243;
          break L24;
         }
         $750 = HEAP32[$9>>2]|0;
         $751 = HEAP32[$11>>2]|0;
         $752 = ($750|0)==($751|0);
         if ($752) {
          __THREW__ = 0;
          invoke_viii(4721,($8|0),($9|0),($11|0));
          $753 = __THREW__; __THREW__ = 0;
          $754 = $753&1;
          if ($754) {
           label = 244;
           break L24;
          }
         }
         $755 = HEAP32[$0>>2]|0;
         $756 = ((($755)) + 12|0);
         $757 = HEAP32[$756>>2]|0;
         $758 = ((($755)) + 16|0);
         $759 = HEAP32[$758>>2]|0;
         $760 = ($757|0)==($759|0);
         if ($760) {
          $761 = HEAP32[$755>>2]|0;
          $762 = ((($761)) + 36|0);
          $763 = HEAP32[$762>>2]|0;
          __THREW__ = 0;
          $764 = (invoke_ii($763|0,($755|0))|0);
          $765 = __THREW__; __THREW__ = 0;
          $766 = $765&1;
          if ($766) {
           label = 244;
           break L24;
          } else {
           $$0$i$i333 = $764;
          }
         } else {
          $767 = HEAP8[$757>>0]|0;
          $768 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($767)|0);
          $$0$i$i333 = $768;
         }
         $769 = $$0$i$i333&255;
         $770 = HEAP32[$9>>2]|0;
         $771 = ((($770)) + 1|0);
         HEAP32[$9>>2] = $771;
         HEAP8[$770>>0] = $769;
         $772 = HEAP32[$24>>2]|0;
         $773 = (($772) + -1)|0;
         HEAP32[$24>>2] = $773;
         $774 = HEAP32[$0>>2]|0;
         $775 = ((($774)) + 12|0);
         $776 = HEAP32[$775>>2]|0;
         $777 = ((($774)) + 16|0);
         $778 = HEAP32[$777>>2]|0;
         $779 = ($776|0)==($778|0);
         if ($779) {
          $780 = HEAP32[$774>>2]|0;
          $781 = ((($780)) + 40|0);
          $782 = HEAP32[$781>>2]|0;
          __THREW__ = 0;
          (invoke_ii($782|0,($774|0))|0);
          $783 = __THREW__; __THREW__ = 0;
          $784 = $783&1;
          if ($784) {
           label = 244;
           break L24;
          } else {
           $$pre$i4$i$i322 = $$pre$i4$i$i322505518;$710 = $909;
           continue;
          }
         } else {
          $785 = ((($776)) + 1|0);
          HEAP32[$775>>2] = $785;
          $786 = HEAP8[$776>>0]|0;
          (__ZNSt3__211char_traitsIcE11to_int_typeEc($786)|0);
          $$pre$i4$i$i322 = $$pre$i4$i$i322505518;$710 = $909;
          continue;
         }
        }
       }
      } while(0);
      $787 = HEAP32[$9>>2]|0;
      $788 = HEAP32[$8>>2]|0;
      $789 = ($787|0)==($788|0);
      if ($789) {
       label = 243;
       break L24;
      } else {
       $$1150 = $$0149;
      }
      break;
     }
     default: {
      $$1150 = $$0149;
     }
     }
    } while(0);
    L293: do {
     if ((label|0) == 49) {
      while(1) {
       label = 0;
       $142 = HEAP32[$0>>2]|0;
       $143 = ($142|0)==(0|0);
       do {
        if ($143) {
         $176 = 1;
        } else {
         $144 = ((($142)) + 12|0);
         $145 = HEAP32[$144>>2]|0;
         $146 = ((($142)) + 16|0);
         $147 = HEAP32[$146>>2]|0;
         $148 = ($145|0)==($147|0);
         if ($148) {
          $149 = HEAP32[$142>>2]|0;
          $150 = ((($149)) + 36|0);
          $151 = HEAP32[$150>>2]|0;
          __THREW__ = 0;
          $152 = (invoke_ii($151|0,($142|0))|0);
          $153 = __THREW__; __THREW__ = 0;
          $154 = $153&1;
          if ($154) {
           label = 35;
           break L24;
          } else {
           $$0$i$i$i$i186 = $152;
          }
         } else {
          $155 = HEAP8[$145>>0]|0;
          $156 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($155)|0);
          $$0$i$i$i$i186 = $156;
         }
         $157 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
         $158 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i$i$i186,$157)|0);
         if ($158) {
          HEAP32[$0>>2] = 0;
          $176 = 1;
          break;
         } else {
          $$pre$i$i$i188 = HEAP32[$0>>2]|0;
          $phitmp$i$i$i189 = ($$pre$i$i$i188|0)==(0|0);
          $176 = $phitmp$i$i$i189;
          break;
         }
        }
       } while(0);
       $160 = ($159|0)==(0|0);
       do {
        if ($160) {
         $$pre$i4$i$i194512 = $$pre$i4$i$i194;
         label = 62;
        } else {
         $161 = ((($159)) + 12|0);
         $162 = HEAP32[$161>>2]|0;
         $163 = ((($159)) + 16|0);
         $164 = HEAP32[$163>>2]|0;
         $165 = ($162|0)==($164|0);
         if ($165) {
          $166 = HEAP32[$159>>2]|0;
          $167 = ((($166)) + 36|0);
          $168 = HEAP32[$167>>2]|0;
          __THREW__ = 0;
          $169 = (invoke_ii($168|0,($159|0))|0);
          $170 = __THREW__; __THREW__ = 0;
          $171 = $170&1;
          if ($171) {
           label = 35;
           break L24;
          } else {
           $$0$i$i2$i$i192 = $169;
          }
         } else {
          $172 = HEAP8[$162>>0]|0;
          $173 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($172)|0);
          $$0$i$i2$i$i192 = $173;
         }
         $174 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
         $175 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i2$i$i192,$174)|0);
         if ($175) {
          HEAP32[$1>>2] = 0;
          $$pre$i4$i$i194512 = 0;
          label = 62;
          break;
         } else {
          $phitmp$i5$i$i195 = ($$pre$i4$i$i194|0)==(0|0);
          $tmp$i$i197 = $176 ^ $phitmp$i5$i$i195;
          if ($tmp$i$i197) {
           $$pre$i4$i$i194514 = $$pre$i4$i$i194;$904 = $$pre$i4$i$i194;
           break;
          } else {
           $$1150 = $$0149;
           break L293;
          }
         }
        }
       } while(0);
       if ((label|0) == 62) {
        label = 0;
        if ($176) {
         $$1150 = $$0149;
         break L293;
        } else {
         $$pre$i4$i$i194514 = $$pre$i4$i$i194512;$904 = 0;
        }
       }
       $177 = HEAP32[$0>>2]|0;
       $178 = ((($177)) + 12|0);
       $179 = HEAP32[$178>>2]|0;
       $180 = ((($177)) + 16|0);
       $181 = HEAP32[$180>>2]|0;
       $182 = ($179|0)==($181|0);
       if ($182) {
        $183 = HEAP32[$177>>2]|0;
        $184 = ((($183)) + 36|0);
        $185 = HEAP32[$184>>2]|0;
        __THREW__ = 0;
        $186 = (invoke_ii($185|0,($177|0))|0);
        $187 = __THREW__; __THREW__ = 0;
        $188 = $187&1;
        if ($188) {
         label = 35;
         break L24;
        } else {
         $$0$i$i201 = $186;
        }
       } else {
        $189 = HEAP8[$179>>0]|0;
        $190 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($189)|0);
        $$0$i$i201 = $190;
       }
       $191 = $$0$i$i201&255;
       $192 = ($191<<24>>24)>(-1);
       if (!($192)) {
        $$1150 = $$0149;
        break L293;
       }
       $sext422 = $$0$i$i201 << 24;
       $193 = $sext422 >> 24;
       $194 = HEAP32[$42>>2]|0;
       $195 = (($194) + ($193<<1)|0);
       $196 = HEAP16[$195>>1]|0;
       $197 = $196 & 8192;
       $198 = ($197<<16>>16)==(0);
       if ($198) {
        $$1150 = $$0149;
        break L293;
       }
       $199 = HEAP32[$0>>2]|0;
       $200 = ((($199)) + 12|0);
       $201 = HEAP32[$200>>2]|0;
       $202 = ((($199)) + 16|0);
       $203 = HEAP32[$202>>2]|0;
       $204 = ($201|0)==($203|0);
       if ($204) {
        $205 = HEAP32[$199>>2]|0;
        $206 = ((($205)) + 40|0);
        $207 = HEAP32[$206>>2]|0;
        __THREW__ = 0;
        $208 = (invoke_ii($207|0,($199|0))|0);
        $209 = __THREW__; __THREW__ = 0;
        $210 = $209&1;
        if ($210) {
         label = 35;
         break L24;
        } else {
         $$0$i$i205 = $208;
        }
       } else {
        $211 = ((($201)) + 1|0);
        HEAP32[$200>>2] = $211;
        $212 = HEAP8[$201>>0]|0;
        $213 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($212)|0);
        $$0$i$i205 = $213;
       }
       $214 = $$0$i$i205&255;
       __THREW__ = 0;
       invoke_vii(3433,($23|0),($214|0));
       $215 = __THREW__; __THREW__ = 0;
       $216 = $215&1;
       if ($216) {
        label = 35;
        break L24;
       } else {
        $$pre$i4$i$i194 = $$pre$i4$i$i194514;$159 = $904;
        label = 49;
       }
      }
     }
    } while(0);
    $794 = (($$0158) + 1)|0;
    $$0149 = $$1150;$$0158 = $794;
   }
   L329: do {
    if ((label|0) == 35) {
     $94 = ___cxa_find_matching_catch_2()|0;
     $95 = tempRet0;
     $$5142 = $94;$$5148 = $95;
     break L21;
    }
    else if ((label|0) == 47) {
     $140 = HEAP32[$5>>2]|0;
     $141 = $140 | 4;
     HEAP32[$5>>2] = $141;
     $$10 = 0;
    }
    else if ((label|0) == 109) {
     $379 = HEAP32[$5>>2]|0;
     $380 = $379 | 4;
     HEAP32[$5>>2] = $380;
     $$10 = 0;
    }
    else if ((label|0) == 148) {
     $507 = ___cxa_find_matching_catch_2()|0;
     $508 = tempRet0;
     $$5142 = $507;$$5148 = $508;
     break L21;
    }
    else if ((label|0) == 149) {
     $509 = ___cxa_find_matching_catch_2()|0;
     $510 = tempRet0;
     $$5142 = $509;$$5148 = $510;
     break L21;
    }
    else if ((label|0) == 152) {
     $520 = HEAP32[$5>>2]|0;
     $521 = $520 | 4;
     HEAP32[$5>>2] = $521;
     $$10 = 0;
    }
    else if ((label|0) == 243) {
     $790 = HEAP32[$5>>2]|0;
     $791 = $790 | 4;
     HEAP32[$5>>2] = $791;
     $$10 = 0;
    }
    else if ((label|0) == 244) {
     $792 = ___cxa_find_matching_catch_2()|0;
     $793 = tempRet0;
     $$5142 = $792;$$5148 = $793;
     break L21;
    }
    else if ((label|0) == 246) {
     L331: do {
      if ($57) {
       $795 = ((($$0149)) + 11|0);
       $796 = ((($$0149)) + 4|0);
       $$0 = 1;
       L333: while(1) {
        $797 = HEAP8[$795>>0]|0;
        $798 = ($797<<24>>24)<(0);
        if ($798) {
         $799 = HEAP32[$796>>2]|0;
         $802 = $799;
        } else {
         $800 = $797&255;
         $802 = $800;
        }
        $801 = ($$0>>>0)<($802>>>0);
        if (!($801)) {
         break L331;
        }
        $803 = HEAP32[$0>>2]|0;
        $804 = ($803|0)==(0|0);
        do {
         if ($804) {
          $910 = 1;
         } else {
          $805 = ((($803)) + 12|0);
          $806 = HEAP32[$805>>2]|0;
          $807 = ((($803)) + 16|0);
          $808 = HEAP32[$807>>2]|0;
          $809 = ($806|0)==($808|0);
          if ($809) {
           $810 = HEAP32[$803>>2]|0;
           $811 = ((($810)) + 36|0);
           $812 = HEAP32[$811>>2]|0;
           __THREW__ = 0;
           $813 = (invoke_ii($812|0,($803|0))|0);
           $814 = __THREW__; __THREW__ = 0;
           $815 = $814&1;
           if ($815) {
            label = 274;
            break L333;
           } else {
            $$0$i$i$i$i339 = $813;
           }
          } else {
           $816 = HEAP8[$806>>0]|0;
           $817 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($816)|0);
           $$0$i$i$i$i339 = $817;
          }
          $818 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
          $819 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i$i$i339,$818)|0);
          if ($819) {
           HEAP32[$0>>2] = 0;
           $910 = 1;
           break;
          } else {
           $$pre$i$i$i341 = HEAP32[$0>>2]|0;
           $phitmp$i$i$i342 = ($$pre$i$i$i341|0)==(0|0);
           $910 = $phitmp$i$i$i342;
           break;
          }
         }
        } while(0);
        $820 = HEAP32[$1>>2]|0;
        $821 = ($820|0)==(0|0);
        do {
         if ($821) {
          label = 265;
         } else {
          $822 = ((($820)) + 12|0);
          $823 = HEAP32[$822>>2]|0;
          $824 = ((($820)) + 16|0);
          $825 = HEAP32[$824>>2]|0;
          $826 = ($823|0)==($825|0);
          if ($826) {
           $827 = HEAP32[$820>>2]|0;
           $828 = ((($827)) + 36|0);
           $829 = HEAP32[$828>>2]|0;
           __THREW__ = 0;
           $830 = (invoke_ii($829|0,($820|0))|0);
           $831 = __THREW__; __THREW__ = 0;
           $832 = $831&1;
           if ($832) {
            label = 274;
            break L333;
           } else {
            $$0$i$i2$i$i345 = $830;
           }
          } else {
           $833 = HEAP8[$823>>0]|0;
           $834 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($833)|0);
           $$0$i$i2$i$i345 = $834;
          }
          $835 = (__ZNSt3__211char_traitsIcE3eofEv()|0);
          $836 = (__ZNSt3__211char_traitsIcE11eq_int_typeEii($$0$i$i2$i$i345,$835)|0);
          if ($836) {
           HEAP32[$1>>2] = 0;
           label = 265;
           break;
          } else {
           if ($910) {
            break;
           } else {
            label = 273;
            break L333;
           }
          }
         }
        } while(0);
        if ((label|0) == 265) {
         label = 0;
         if ($910) {
          label = 273;
          break;
         }
        }
        $837 = HEAP32[$0>>2]|0;
        $838 = ((($837)) + 12|0);
        $839 = HEAP32[$838>>2]|0;
        $840 = ((($837)) + 16|0);
        $841 = HEAP32[$840>>2]|0;
        $842 = ($839|0)==($841|0);
        if ($842) {
         $843 = HEAP32[$837>>2]|0;
         $844 = ((($843)) + 36|0);
         $845 = HEAP32[$844>>2]|0;
         __THREW__ = 0;
         $846 = (invoke_ii($845|0,($837|0))|0);
         $847 = __THREW__; __THREW__ = 0;
         $848 = $847&1;
         if ($848) {
          label = 274;
          break;
         } else {
          $$0$i$i249 = $846;
         }
        } else {
         $849 = HEAP8[$839>>0]|0;
         $850 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($849)|0);
         $$0$i$i249 = $850;
        }
        $851 = $$0$i$i249&255;
        $852 = HEAP8[$795>>0]|0;
        $853 = ($852<<24>>24)<(0);
        if ($853) {
         $854 = HEAP32[$$0149>>2]|0;
         $856 = $854;
        } else {
         $856 = $$0149;
        }
        $855 = (($856) + ($$0)|0);
        $857 = HEAP8[$855>>0]|0;
        $858 = ($851<<24>>24)==($857<<24>>24);
        if (!($858)) {
         label = 273;
         break;
        }
        $863 = (($$0) + 1)|0;
        $864 = HEAP32[$0>>2]|0;
        $865 = ((($864)) + 12|0);
        $866 = HEAP32[$865>>2]|0;
        $867 = ((($864)) + 16|0);
        $868 = HEAP32[$867>>2]|0;
        $869 = ($866|0)==($868|0);
        if ($869) {
         $870 = HEAP32[$864>>2]|0;
         $871 = ((($870)) + 40|0);
         $872 = HEAP32[$871>>2]|0;
         __THREW__ = 0;
         (invoke_ii($872|0,($864|0))|0);
         $873 = __THREW__; __THREW__ = 0;
         $874 = $873&1;
         if ($874) {
          label = 274;
          break;
         } else {
          $$0 = $863;
          continue;
         }
        } else {
         $875 = ((($866)) + 1|0);
         HEAP32[$865>>2] = $875;
         $876 = HEAP8[$866>>0]|0;
         (__ZNSt3__211char_traitsIcE11to_int_typeEc($876)|0);
         $$0 = $863;
         continue;
        }
       }
       if ((label|0) == 273) {
        $859 = HEAP32[$5>>2]|0;
        $860 = $859 | 4;
        HEAP32[$5>>2] = $860;
        $$10 = 0;
        break L329;
       }
       else if ((label|0) == 274) {
        $861 = ___cxa_find_matching_catch_2()|0;
        $862 = tempRet0;
        $$5142 = $861;$$5148 = $862;
        break L21;
       }
      }
     } while(0);
     $877 = HEAP32[$13>>2]|0;
     $878 = HEAP32[$14>>2]|0;
     $879 = ($877|0)==($878|0);
     if ($879) {
      $$10 = 1;
     } else {
      HEAP32[$25>>2] = 0;
      __THREW__ = 0;
      invoke_viiii(4676,($19|0),($877|0),($878|0),($25|0));
      $880 = __THREW__; __THREW__ = 0;
      $881 = $880&1;
      if ($881) {
       $886 = ___cxa_find_matching_catch_2()|0;
       $887 = tempRet0;
       $$5142 = $886;$$5148 = $887;
       break L21;
      }
      $882 = HEAP32[$25>>2]|0;
      $883 = ($882|0)==(0);
      if ($883) {
       $$10 = 1;
       break;
      } else {
       $884 = HEAP32[$5>>2]|0;
       $885 = $884 | 4;
       HEAP32[$5>>2] = $885;
       $$10 = 0;
       break;
      }
     }
    }
   } while(0);
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($23);
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($22);
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($21);
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($20);
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($19);
   $888 = HEAP32[$13>>2]|0;
   HEAP32[$13>>2] = 0;
   $889 = ($888|0)==(0|0);
   if (!($889)) {
    $890 = HEAP32[$27>>2]|0;
    __THREW__ = 0;
    invoke_vi($890|0,($888|0));
    $891 = __THREW__; __THREW__ = 0;
    $892 = $891&1;
    if ($892) {
     $893 = ___cxa_find_matching_catch_3(0|0)|0;
     $894 = tempRet0;
     ___clang_call_terminate($893);
     // unreachable;
    }
   }
   STACKTOP = sp;return ($$10|0);
  }
 } while(0);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($23);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($22);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($21);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($20);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($19);
 $895 = HEAP32[$13>>2]|0;
 HEAP32[$13>>2] = 0;
 $896 = ($895|0)==(0|0);
 if (!($896)) {
  $897 = HEAP32[$27>>2]|0;
  __THREW__ = 0;
  invoke_vi($897|0,($895|0));
  $898 = __THREW__; __THREW__ = 0;
  $899 = $898&1;
  if ($899) {
   $900 = ___cxa_find_matching_catch_3(0|0)|0;
   $901 = tempRet0;
   ___clang_call_terminate($900);
   // unreachable;
  }
 }
 ___resumeException($$5142|0);
 // unreachable;
 return (0)|0;
}
function __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE23__append_forward_unsafeIPcEERS5_T_S9_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$0$i$i = 0, $$021$i$i = 0, $$021$ph$i$i = 0, $$040 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $8 = 0, $9 = 0, $phitmp$i = 0, $scevgep = 0, $scevgep23$i$i = 0, $scevgep45 = 0, $scevgep46 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = $1;
 $4 = sp + 13|0;
 $5 = sp;
 $6 = sp + 12|0;
 $7 = ((($0)) + 11|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = ($8<<24>>24)<(0);
 if ($9) {
  $11 = ((($0)) + 4|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ((($0)) + 8|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = $14 & 2147483647;
  $phitmp$i = (($15) + -1)|0;
  $55 = $12;$56 = $phitmp$i;
 } else {
  $10 = $8&255;
  $55 = $10;$56 = 10;
 }
 $16 = $2;
 $17 = (($16) - ($3))|0;
 $18 = ($17|0)==(0);
 do {
  if (!($18)) {
   if ($9) {
    $19 = HEAP32[$0>>2]|0;
    $20 = ((($0)) + 4|0);
    $21 = HEAP32[$20>>2]|0;
    $24 = $19;$25 = $21;$26 = $19;
   } else {
    $22 = $8&255;
    $24 = $0;$25 = $22;$26 = $0;
   }
   $23 = (($24) + ($25)|0);
   $27 = (__ZNSt3__214__ptr_in_rangeIcEEbPKT_S3_S3_($1,$26,$23)|0);
   if ($27) {
    ;HEAP32[$5>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;
    $28 = ($17>>>0)>(4294967279);
    if ($28) {
     __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv($5);
     // unreachable;
    }
    $29 = ($17>>>0)<(11);
    if ($29) {
     $30 = $17&255;
     $31 = ((($5)) + 11|0);
     HEAP8[$31>>0] = $30;
     $$021$ph$i$i = $5;
    } else {
     $32 = (($17) + 16)|0;
     $33 = $32 & -16;
     $34 = (__Znwj($33)|0);
     HEAP32[$5>>2] = $34;
     $35 = $33 | -2147483648;
     $36 = ((($5)) + 8|0);
     HEAP32[$36>>2] = $35;
     $37 = ((($5)) + 4|0);
     HEAP32[$37>>2] = $17;
     $$021$ph$i$i = $34;
    }
    $$0$i$i = $1;$$021$i$i = $$021$ph$i$i;
    while(1) {
     $38 = ($$0$i$i|0)==($2|0);
     if ($38) {
      break;
     }
     __ZNSt3__211char_traitsIcE6assignERcRKc($$021$i$i,$$0$i$i);
     $39 = ((($$0$i$i)) + 1|0);
     $40 = ((($$021$i$i)) + 1|0);
     $$0$i$i = $39;$$021$i$i = $40;
    }
    $scevgep23$i$i = (($$021$ph$i$i) + ($17)|0);
    HEAP8[$4>>0] = 0;
    __ZNSt3__211char_traitsIcE6assignERcRKc($scevgep23$i$i,$4);
    $41 = ((($5)) + 11|0);
    $42 = HEAP8[$41>>0]|0;
    $43 = ($42<<24>>24)<(0);
    $44 = HEAP32[$5>>2]|0;
    $45 = ((($5)) + 4|0);
    $46 = HEAP32[$45>>2]|0;
    $47 = $42&255;
    $48 = $43 ? $44 : $5;
    $49 = $43 ? $46 : $47;
    __THREW__ = 0;
    (invoke_iiii(3544,($0|0),($48|0),($49|0))|0);
    $50 = __THREW__; __THREW__ = 0;
    $51 = $50&1;
    if ($51) {
     $52 = ___cxa_find_matching_catch_2()|0;
     $53 = tempRet0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($5);
     ___resumeException($52|0);
     // unreachable;
    } else {
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($5);
     break;
    }
   } else {
    $54 = (($56) - ($55))|0;
    $57 = ($54>>>0)<($17>>>0);
    $58 = (($55) + ($17))|0;
    if ($57) {
     $59 = (($58) - ($56))|0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE9__grow_byEjjjjjj($0,$56,$59,$55,$55,0,0);
    }
    $60 = HEAP8[$7>>0]|0;
    $61 = ($60<<24>>24)<(0);
    if ($61) {
     $62 = HEAP32[$0>>2]|0;
     $64 = $62;
    } else {
     $64 = $0;
    }
    $63 = (($64) + ($55)|0);
    $65 = (($55) - ($3))|0;
    $scevgep = (($2) + ($65)|0);
    $scevgep45 = $scevgep;
    $$0 = $63;$$040 = $1;
    while(1) {
     $66 = ($$040|0)==($2|0);
     if ($66) {
      break;
     }
     __ZNSt3__211char_traitsIcE6assignERcRKc($$0,$$040);
     $67 = ((($$0)) + 1|0);
     $68 = ((($$040)) + 1|0);
     $$0 = $67;$$040 = $68;
    }
    $scevgep46 = (($64) + ($scevgep45)|0);
    HEAP8[$6>>0] = 0;
    __ZNSt3__211char_traitsIcE6assignERcRKc($scevgep46,$6);
    $69 = HEAP8[$7>>0]|0;
    $70 = ($69<<24>>24)<(0);
    if ($70) {
     $71 = ((($0)) + 4|0);
     HEAP32[$71>>2] = $58;
     break;
    } else {
     $72 = $58&255;
     HEAP8[$7>>0] = $72;
     break;
    }
   }
  }
 } while(0);
 STACKTOP = sp;return ($0|0);
}
function __ZNSt3__214__ptr_in_rangeIcEEbPKT_S3_S3_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$ = 0, $3 = 0, $not$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($0>>>0)<($2>>>0);
 $not$ = ($1>>>0)<=($0>>>0);
 $$ = $not$ & $3;
 return ($$|0);
}
function __ZNSt3__211__money_getIcE13__gather_infoEbRKNS_6localeERNS_10money_base7patternERcS8_RNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEESF_SF_SF_Ri($0,$1,$2,$3,$4,$5,$6,$7,$8,$9) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 $8 = $8|0;
 $9 = $9|0;
 var $$0$i$i$i = 0, $$0$i$i$i40 = 0, $$0$i$i$i45 = 0, $$0$i$i$i50 = 0, $$0$i$i$i55 = 0, $$0$i$i$i60 = 0, $$0$i$i$i65 = 0, $$0$i$i$i70 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0;
 var $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $19 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $exitcond$i$i$i = 0, $exitcond$i$i$i41 = 0, $exitcond$i$i$i46 = 0, $exitcond$i$i$i51 = 0, $exitcond$i$i$i56 = 0, $exitcond$i$i$i61 = 0, $exitcond$i$i$i66 = 0, $exitcond$i$i$i71 = 0, $storemerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(128|0);
 $10 = sp + 119|0;
 $11 = sp + 118|0;
 $12 = sp + 117|0;
 $13 = sp + 116|0;
 $14 = sp + 115|0;
 $15 = sp + 114|0;
 $16 = sp + 113|0;
 $17 = sp + 112|0;
 $18 = sp + 111|0;
 $19 = sp + 110|0;
 $20 = sp + 109|0;
 $21 = sp + 108|0;
 $22 = sp + 107|0;
 $23 = sp + 106|0;
 $24 = sp + 105|0;
 $25 = sp + 104|0;
 $26 = sp + 100|0;
 $27 = sp + 88|0;
 $28 = sp + 76|0;
 $29 = sp + 64|0;
 $30 = sp + 52|0;
 $31 = sp + 48|0;
 $32 = sp + 36|0;
 $33 = sp + 24|0;
 $34 = sp + 12|0;
 $35 = sp;
 if ($0) {
  $36 = (__ZNKSt3__26locale9use_facetERNS0_2idE($1,216908)|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = ((($37)) + 44|0);
  $39 = HEAP32[$38>>2]|0;
  FUNCTION_TABLE_vii[$39 & 8191]($26,$36);
  $40 = HEAP32[$26>>2]|0;
  HEAP8[$2>>0]=$40&255;HEAP8[$2+1>>0]=($40>>8)&255;HEAP8[$2+2>>0]=($40>>16)&255;HEAP8[$2+3>>0]=$40>>24;
  $41 = HEAP32[$36>>2]|0;
  $42 = ((($41)) + 32|0);
  $43 = HEAP32[$42>>2]|0;
  FUNCTION_TABLE_vii[$43 & 8191]($27,$36);
  $44 = ((($8)) + 11|0);
  $45 = HEAP8[$44>>0]|0;
  $46 = ($45<<24>>24)<(0);
  if ($46) {
   $47 = HEAP32[$8>>2]|0;
   HEAP8[$24>>0] = 0;
   __ZNSt3__211char_traitsIcE6assignERcRKc($47,$24);
   $48 = ((($8)) + 4|0);
   HEAP32[$48>>2] = 0;
  } else {
   HEAP8[$25>>0] = 0;
   __ZNSt3__211char_traitsIcE6assignERcRKc($8,$25);
   HEAP8[$44>>0] = 0;
  }
  __THREW__ = 0;
  invoke_vii(4723,($8|0),0);
  $49 = __THREW__; __THREW__ = 0;
  $50 = $49&1;
  if ($50) {
   $51 = ___cxa_find_matching_catch_3(0|0)|0;
   $52 = tempRet0;
   ___clang_call_terminate($51);
   // unreachable;
  }
  ;HEAP32[$8>>2]=HEAP32[$27>>2]|0;HEAP32[$8+4>>2]=HEAP32[$27+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$27+8>>2]|0;
  $$0$i$i$i = 0;
  while(1) {
   $exitcond$i$i$i = ($$0$i$i$i|0)==(3);
   if ($exitcond$i$i$i) {
    break;
   }
   $53 = (($27) + ($$0$i$i$i<<2)|0);
   HEAP32[$53>>2] = 0;
   $54 = (($$0$i$i$i) + 1)|0;
   $$0$i$i$i = $54;
  }
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($27);
  $55 = HEAP32[$36>>2]|0;
  $56 = ((($55)) + 28|0);
  $57 = HEAP32[$56>>2]|0;
  FUNCTION_TABLE_vii[$57 & 8191]($28,$36);
  $58 = ((($7)) + 11|0);
  $59 = HEAP8[$58>>0]|0;
  $60 = ($59<<24>>24)<(0);
  if ($60) {
   $61 = HEAP32[$7>>2]|0;
   HEAP8[$22>>0] = 0;
   __ZNSt3__211char_traitsIcE6assignERcRKc($61,$22);
   $62 = ((($7)) + 4|0);
   HEAP32[$62>>2] = 0;
  } else {
   HEAP8[$23>>0] = 0;
   __ZNSt3__211char_traitsIcE6assignERcRKc($7,$23);
   HEAP8[$58>>0] = 0;
  }
  __THREW__ = 0;
  invoke_vii(4723,($7|0),0);
  $63 = __THREW__; __THREW__ = 0;
  $64 = $63&1;
  if ($64) {
   $65 = ___cxa_find_matching_catch_3(0|0)|0;
   $66 = tempRet0;
   ___clang_call_terminate($65);
   // unreachable;
  }
  ;HEAP32[$7>>2]=HEAP32[$28>>2]|0;HEAP32[$7+4>>2]=HEAP32[$28+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[$28+8>>2]|0;
  $$0$i$i$i40 = 0;
  while(1) {
   $exitcond$i$i$i41 = ($$0$i$i$i40|0)==(3);
   if ($exitcond$i$i$i41) {
    break;
   }
   $67 = (($28) + ($$0$i$i$i40<<2)|0);
   HEAP32[$67>>2] = 0;
   $68 = (($$0$i$i$i40) + 1)|0;
   $$0$i$i$i40 = $68;
  }
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($28);
  $69 = HEAP32[$36>>2]|0;
  $70 = ((($69)) + 12|0);
  $71 = HEAP32[$70>>2]|0;
  $72 = (FUNCTION_TABLE_ii[$71 & 8191]($36)|0);
  HEAP8[$3>>0] = $72;
  $73 = HEAP32[$36>>2]|0;
  $74 = ((($73)) + 16|0);
  $75 = HEAP32[$74>>2]|0;
  $76 = (FUNCTION_TABLE_ii[$75 & 8191]($36)|0);
  HEAP8[$4>>0] = $76;
  $77 = HEAP32[$36>>2]|0;
  $78 = ((($77)) + 20|0);
  $79 = HEAP32[$78>>2]|0;
  FUNCTION_TABLE_vii[$79 & 8191]($29,$36);
  $80 = ((($5)) + 11|0);
  $81 = HEAP8[$80>>0]|0;
  $82 = ($81<<24>>24)<(0);
  if ($82) {
   $83 = HEAP32[$5>>2]|0;
   HEAP8[$20>>0] = 0;
   __ZNSt3__211char_traitsIcE6assignERcRKc($83,$20);
   $84 = ((($5)) + 4|0);
   HEAP32[$84>>2] = 0;
  } else {
   HEAP8[$21>>0] = 0;
   __ZNSt3__211char_traitsIcE6assignERcRKc($5,$21);
   HEAP8[$80>>0] = 0;
  }
  __THREW__ = 0;
  invoke_vii(4723,($5|0),0);
  $85 = __THREW__; __THREW__ = 0;
  $86 = $85&1;
  if ($86) {
   $87 = ___cxa_find_matching_catch_3(0|0)|0;
   $88 = tempRet0;
   ___clang_call_terminate($87);
   // unreachable;
  }
  ;HEAP32[$5>>2]=HEAP32[$29>>2]|0;HEAP32[$5+4>>2]=HEAP32[$29+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$29+8>>2]|0;
  $$0$i$i$i45 = 0;
  while(1) {
   $exitcond$i$i$i46 = ($$0$i$i$i45|0)==(3);
   if ($exitcond$i$i$i46) {
    break;
   }
   $89 = (($29) + ($$0$i$i$i45<<2)|0);
   HEAP32[$89>>2] = 0;
   $90 = (($$0$i$i$i45) + 1)|0;
   $$0$i$i$i45 = $90;
  }
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($29);
  $91 = HEAP32[$36>>2]|0;
  $92 = ((($91)) + 24|0);
  $93 = HEAP32[$92>>2]|0;
  FUNCTION_TABLE_vii[$93 & 8191]($30,$36);
  $94 = ((($6)) + 11|0);
  $95 = HEAP8[$94>>0]|0;
  $96 = ($95<<24>>24)<(0);
  if ($96) {
   $97 = HEAP32[$6>>2]|0;
   HEAP8[$18>>0] = 0;
   __ZNSt3__211char_traitsIcE6assignERcRKc($97,$18);
   $98 = ((($6)) + 4|0);
   HEAP32[$98>>2] = 0;
  } else {
   HEAP8[$19>>0] = 0;
   __ZNSt3__211char_traitsIcE6assignERcRKc($6,$19);
   HEAP8[$94>>0] = 0;
  }
  __THREW__ = 0;
  invoke_vii(4723,($6|0),0);
  $99 = __THREW__; __THREW__ = 0;
  $100 = $99&1;
  if ($100) {
   $101 = ___cxa_find_matching_catch_3(0|0)|0;
   $102 = tempRet0;
   ___clang_call_terminate($101);
   // unreachable;
  }
  ;HEAP32[$6>>2]=HEAP32[$30>>2]|0;HEAP32[$6+4>>2]=HEAP32[$30+4>>2]|0;HEAP32[$6+8>>2]=HEAP32[$30+8>>2]|0;
  $$0$i$i$i50 = 0;
  while(1) {
   $exitcond$i$i$i51 = ($$0$i$i$i50|0)==(3);
   if ($exitcond$i$i$i51) {
    break;
   }
   $103 = (($30) + ($$0$i$i$i50<<2)|0);
   HEAP32[$103>>2] = 0;
   $104 = (($$0$i$i$i50) + 1)|0;
   $$0$i$i$i50 = $104;
  }
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($30);
  $105 = HEAP32[$36>>2]|0;
  $106 = ((($105)) + 36|0);
  $107 = HEAP32[$106>>2]|0;
  $108 = (FUNCTION_TABLE_ii[$107 & 8191]($36)|0);
  $storemerge = $108;
 } else {
  $109 = (__ZNKSt3__26locale9use_facetERNS0_2idE($1,216900)|0);
  $110 = HEAP32[$109>>2]|0;
  $111 = ((($110)) + 44|0);
  $112 = HEAP32[$111>>2]|0;
  FUNCTION_TABLE_vii[$112 & 8191]($31,$109);
  $113 = HEAP32[$31>>2]|0;
  HEAP8[$2>>0]=$113&255;HEAP8[$2+1>>0]=($113>>8)&255;HEAP8[$2+2>>0]=($113>>16)&255;HEAP8[$2+3>>0]=$113>>24;
  $114 = HEAP32[$109>>2]|0;
  $115 = ((($114)) + 32|0);
  $116 = HEAP32[$115>>2]|0;
  FUNCTION_TABLE_vii[$116 & 8191]($32,$109);
  $117 = ((($8)) + 11|0);
  $118 = HEAP8[$117>>0]|0;
  $119 = ($118<<24>>24)<(0);
  if ($119) {
   $120 = HEAP32[$8>>2]|0;
   HEAP8[$16>>0] = 0;
   __ZNSt3__211char_traitsIcE6assignERcRKc($120,$16);
   $121 = ((($8)) + 4|0);
   HEAP32[$121>>2] = 0;
  } else {
   HEAP8[$17>>0] = 0;
   __ZNSt3__211char_traitsIcE6assignERcRKc($8,$17);
   HEAP8[$117>>0] = 0;
  }
  __THREW__ = 0;
  invoke_vii(4723,($8|0),0);
  $122 = __THREW__; __THREW__ = 0;
  $123 = $122&1;
  if ($123) {
   $124 = ___cxa_find_matching_catch_3(0|0)|0;
   $125 = tempRet0;
   ___clang_call_terminate($124);
   // unreachable;
  }
  ;HEAP32[$8>>2]=HEAP32[$32>>2]|0;HEAP32[$8+4>>2]=HEAP32[$32+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$32+8>>2]|0;
  $$0$i$i$i55 = 0;
  while(1) {
   $exitcond$i$i$i56 = ($$0$i$i$i55|0)==(3);
   if ($exitcond$i$i$i56) {
    break;
   }
   $126 = (($32) + ($$0$i$i$i55<<2)|0);
   HEAP32[$126>>2] = 0;
   $127 = (($$0$i$i$i55) + 1)|0;
   $$0$i$i$i55 = $127;
  }
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($32);
  $128 = HEAP32[$109>>2]|0;
  $129 = ((($128)) + 28|0);
  $130 = HEAP32[$129>>2]|0;
  FUNCTION_TABLE_vii[$130 & 8191]($33,$109);
  $131 = ((($7)) + 11|0);
  $132 = HEAP8[$131>>0]|0;
  $133 = ($132<<24>>24)<(0);
  if ($133) {
   $134 = HEAP32[$7>>2]|0;
   HEAP8[$14>>0] = 0;
   __ZNSt3__211char_traitsIcE6assignERcRKc($134,$14);
   $135 = ((($7)) + 4|0);
   HEAP32[$135>>2] = 0;
  } else {
   HEAP8[$15>>0] = 0;
   __ZNSt3__211char_traitsIcE6assignERcRKc($7,$15);
   HEAP8[$131>>0] = 0;
  }
  __THREW__ = 0;
  invoke_vii(4723,($7|0),0);
  $136 = __THREW__; __THREW__ = 0;
  $137 = $136&1;
  if ($137) {
   $138 = ___cxa_find_matching_catch_3(0|0)|0;
   $139 = tempRet0;
   ___clang_call_terminate($138);
   // unreachable;
  }
  ;HEAP32[$7>>2]=HEAP32[$33>>2]|0;HEAP32[$7+4>>2]=HEAP32[$33+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[$33+8>>2]|0;
  $$0$i$i$i60 = 0;
  while(1) {
   $exitcond$i$i$i61 = ($$0$i$i$i60|0)==(3);
   if ($exitcond$i$i$i61) {
    break;
   }
   $140 = (($33) + ($$0$i$i$i60<<2)|0);
   HEAP32[$140>>2] = 0;
   $141 = (($$0$i$i$i60) + 1)|0;
   $$0$i$i$i60 = $141;
  }
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($33);
  $142 = HEAP32[$109>>2]|0;
  $143 = ((($142)) + 12|0);
  $144 = HEAP32[$143>>2]|0;
  $145 = (FUNCTION_TABLE_ii[$144 & 8191]($109)|0);
  HEAP8[$3>>0] = $145;
  $146 = HEAP32[$109>>2]|0;
  $147 = ((($146)) + 16|0);
  $148 = HEAP32[$147>>2]|0;
  $149 = (FUNCTION_TABLE_ii[$148 & 8191]($109)|0);
  HEAP8[$4>>0] = $149;
  $150 = HEAP32[$109>>2]|0;
  $151 = ((($150)) + 20|0);
  $152 = HEAP32[$151>>2]|0;
  FUNCTION_TABLE_vii[$152 & 8191]($34,$109);
  $153 = ((($5)) + 11|0);
  $154 = HEAP8[$153>>0]|0;
  $155 = ($154<<24>>24)<(0);
  if ($155) {
   $156 = HEAP32[$5>>2]|0;
   HEAP8[$12>>0] = 0;
   __ZNSt3__211char_traitsIcE6assignERcRKc($156,$12);
   $157 = ((($5)) + 4|0);
   HEAP32[$157>>2] = 0;
  } else {
   HEAP8[$13>>0] = 0;
   __ZNSt3__211char_traitsIcE6assignERcRKc($5,$13);
   HEAP8[$153>>0] = 0;
  }
  __THREW__ = 0;
  invoke_vii(4723,($5|0),0);
  $158 = __THREW__; __THREW__ = 0;
  $159 = $158&1;
  if ($159) {
   $160 = ___cxa_find_matching_catch_3(0|0)|0;
   $161 = tempRet0;
   ___clang_call_terminate($160);
   // unreachable;
  }
  ;HEAP32[$5>>2]=HEAP32[$34>>2]|0;HEAP32[$5+4>>2]=HEAP32[$34+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$34+8>>2]|0;
  $$0$i$i$i65 = 0;
  while(1) {
   $exitcond$i$i$i66 = ($$0$i$i$i65|0)==(3);
   if ($exitcond$i$i$i66) {
    break;
   }
   $162 = (($34) + ($$0$i$i$i65<<2)|0);
   HEAP32[$162>>2] = 0;
   $163 = (($$0$i$i$i65) + 1)|0;
   $$0$i$i$i65 = $163;
  }
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($34);
  $164 = HEAP32[$109>>2]|0;
  $165 = ((($164)) + 24|0);
  $166 = HEAP32[$165>>2]|0;
  FUNCTION_TABLE_vii[$166 & 8191]($35,$109);
  $167 = ((($6)) + 11|0);
  $168 = HEAP8[$167>>0]|0;
  $169 = ($168<<24>>24)<(0);
  if ($169) {
   $170 = HEAP32[$6>>2]|0;
   HEAP8[$10>>0] = 0;
   __ZNSt3__211char_traitsIcE6assignERcRKc($170,$10);
   $171 = ((($6)) + 4|0);
   HEAP32[$171>>2] = 0;
  } else {
   HEAP8[$11>>0] = 0;
   __ZNSt3__211char_traitsIcE6assignERcRKc($6,$11);
   HEAP8[$167>>0] = 0;
  }
  __THREW__ = 0;
  invoke_vii(4723,($6|0),0);
  $172 = __THREW__; __THREW__ = 0;
  $173 = $172&1;
  if ($173) {
   $174 = ___cxa_find_matching_catch_3(0|0)|0;
   $175 = tempRet0;
   ___clang_call_terminate($174);
   // unreachable;
  }
  ;HEAP32[$6>>2]=HEAP32[$35>>2]|0;HEAP32[$6+4>>2]=HEAP32[$35+4>>2]|0;HEAP32[$6+8>>2]=HEAP32[$35+8>>2]|0;
  $$0$i$i$i70 = 0;
  while(1) {
   $exitcond$i$i$i71 = ($$0$i$i$i70|0)==(3);
   if ($exitcond$i$i$i71) {
    break;
   }
   $176 = (($35) + ($$0$i$i$i70<<2)|0);
   HEAP32[$176>>2] = 0;
   $177 = (($$0$i$i$i70) + 1)|0;
   $$0$i$i$i70 = $177;
  }
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($35);
  $178 = HEAP32[$109>>2]|0;
  $179 = ((($178)) + 36|0);
  $180 = HEAP32[$179>>2]|0;
  $181 = (FUNCTION_TABLE_ii[$180 & 8191]($109)|0);
  $storemerge = $181;
 }
 HEAP32[$9>>2] = $storemerge;
 STACKTOP = sp;return;
}
function __ZNSt3__219__double_or_nothingIcEEvRNS_10unique_ptrIT_PFvPvEEERPS2_S9_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$ = 0, $$34 = 0, $$pr = 0, $$pre = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)!=(4716|0);
 $6 = HEAP32[$2>>2]|0;
 $7 = HEAP32[$0>>2]|0;
 $8 = (($6) - ($7))|0;
 $9 = ($8>>>0)<(2147483647);
 $10 = $8 << 1;
 $$34 = $9 ? $10 : -1;
 $11 = ($$34|0)==(0);
 $$ = $11 ? 1 : $$34;
 $12 = HEAP32[$1>>2]|0;
 $13 = $7;
 $14 = (($12) - ($7))|0;
 $15 = $5 ? $13 : 0;
 $16 = (_realloc($15,$$)|0);
 $17 = ($16|0)==(0|0);
 if ($17) {
  __ZSt17__throw_bad_allocv();
  // unreachable;
 }
 do {
  if ($5) {
   $18 = $16;
   HEAP32[$0>>2] = $18;
   $27 = $16;
  } else {
   $$pr = HEAP32[$0>>2]|0;
   $19 = $16;
   HEAP32[$0>>2] = $19;
   $20 = ($$pr|0)==(0|0);
   if ($20) {
    $27 = $16;
   } else {
    $21 = HEAP32[$3>>2]|0;
    __THREW__ = 0;
    invoke_vi($21|0,($$pr|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     $24 = ___cxa_find_matching_catch_3(0|0)|0;
     $25 = tempRet0;
     ___clang_call_terminate($24);
     // unreachable;
    } else {
     $$pre = HEAP32[$0>>2]|0;
     $27 = $$pre;
     break;
    }
   }
  }
 } while(0);
 HEAP32[$3>>2] = (4724);
 $26 = (($27) + ($14)|0);
 HEAP32[$1>>2] = $26;
 $28 = HEAP32[$0>>2]|0;
 $29 = (($28) + ($$)|0);
 HEAP32[$2>>2] = $29;
 return;
}
function __ZNSt3__219__double_or_nothingIjEEvRNS_10unique_ptrIT_PFvPvEEERPS2_S9_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$ = 0, $$34 = 0, $$pr = 0, $$pre = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)!=(4716|0);
 $6 = HEAP32[$2>>2]|0;
 $7 = HEAP32[$0>>2]|0;
 $8 = (($6) - ($7))|0;
 $9 = ($8>>>0)<(2147483647);
 $10 = $8 << 1;
 $$34 = $9 ? $10 : -1;
 $11 = ($$34|0)==(0);
 $$ = $11 ? 4 : $$34;
 $12 = HEAP32[$1>>2]|0;
 $13 = (($12) - ($7))|0;
 $14 = $13 >> 2;
 $phitmp = $7;
 $15 = $5 ? $phitmp : 0;
 $16 = (_realloc($15,$$)|0);
 $17 = ($16|0)==(0|0);
 if ($17) {
  __ZSt17__throw_bad_allocv();
  // unreachable;
 }
 do {
  if ($5) {
   $18 = $16;
   HEAP32[$0>>2] = $18;
   $28 = $16;
  } else {
   $$pr = HEAP32[$0>>2]|0;
   $19 = $16;
   HEAP32[$0>>2] = $19;
   $20 = ($$pr|0)==(0|0);
   if ($20) {
    $28 = $16;
   } else {
    $21 = HEAP32[$3>>2]|0;
    __THREW__ = 0;
    invoke_vi($21|0,($$pr|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     $24 = ___cxa_find_matching_catch_3(0|0)|0;
     $25 = tempRet0;
     ___clang_call_terminate($24);
     // unreachable;
    } else {
     $$pre = HEAP32[$0>>2]|0;
     $28 = $$pre;
     break;
    }
   }
  }
 } while(0);
 HEAP32[$3>>2] = (4724);
 $26 = $$ >>> 2;
 $27 = (($28) + ($14<<2)|0);
 HEAP32[$1>>2] = $27;
 $29 = HEAP32[$0>>2]|0;
 $30 = (($29) + ($26<<2)|0);
 HEAP32[$2>>2] = $30;
 return;
}
function __ZNSt3__29money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEED2Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__26locale5facetD2Ev($0);
 return;
}
function __ZNSt3__29money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEED0Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__26locale5facetD2Ev($0);
 __ZdlPv($0);
 return;
}
function __ZNKSt3__29money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_bRNS_8ios_baseERjRe($0,$1,$2,$3,$4,$5,$6) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 var $$0 = 0, $$0$i = 0, $$0$i$i$i$i = 0, $$0$i$i2$i$i = 0, $$0$lcssa$i = 0, $$031 = 0, $$032 = 0, $$035 = 0, $$1 = 0, $$133 = 0, $$136 = 0, $$2 = 0, $$234 = 0, $$237 = 0, $$33859 = 0, $$33860 = 0, $$361 = 0, $$362 = 0, $$byval_copy = 0, $$pre = 0;
 var $$pre$i$i$i = 0, $$pre56 = 0, $$pre63 = 0, $$sroa$0$0$copyload = 0, $$sroa$043$0 = 0, $$sroa$043$1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $phitmp$i$i$i = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 592|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(592|0);
 $$byval_copy = sp + 472|0;
 $vararg_buffer = sp;
 $7 = sp + 72|0;
 $8 = sp + 64|0;
 $9 = sp + 56|0;
 $10 = sp + 52|0;
 $11 = sp + 576|0;
 $12 = sp + 48|0;
 $13 = sp + 8|0;
 $14 = sp + 476|0;
 $15 = $7;
 HEAP32[$8>>2] = $15;
 $16 = ((($8)) + 4|0);
 HEAP32[$16>>2] = (4716);
 $17 = ((($7)) + 400|0);
 __THREW__ = 0;
 invoke_vii(3257,($10|0),($4|0));
 $18 = __THREW__; __THREW__ = 0;
 $19 = $18&1;
 if ($19) {
  $46 = ___cxa_find_matching_catch_2()|0;
  $47 = tempRet0;
  HEAP32[$8>>2] = 0;
  $$33859 = $47;$$361 = $46;$126 = 4716;$127 = $7;
  label = 54;
 } else {
  __THREW__ = 0;
  $20 = (invoke_iii(3255,($10|0),(215220|0))|0);
  $21 = __THREW__; __THREW__ = 0;
  $22 = $21&1;
  if ($22) {
   $48 = ___cxa_find_matching_catch_2()|0;
   $49 = tempRet0;
   $$234 = $48;$$237 = $49;
  } else {
   HEAP8[$11>>0] = 0;
   $23 = HEAP32[$2>>2]|0;
   HEAP32[$12>>2] = $23;
   $24 = ((($4)) + 4|0);
   $25 = HEAP32[$24>>2]|0;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy>>2]=HEAP32[$12>>2]|0;
   $26 = (invoke_iiiiiiiiiiii(4725,($1|0),($$byval_copy|0),($3|0),($10|0),($25|0),($5|0),($11|0),($20|0),($8|0),($9|0),($17|0))|0);
   $27 = __THREW__; __THREW__ = 0;
   $28 = $27&1;
   L7: do {
    if ($28) {
     label = 11;
    } else {
     L9: do {
      if ($26) {
       $29 = HEAP32[$20>>2]|0;
       $30 = ((($29)) + 48|0);
       $31 = HEAP32[$30>>2]|0;
       __THREW__ = 0;
       (invoke_iiiii($31|0,($20|0),(204065|0),((204075)|0),($13|0))|0);
       $32 = __THREW__; __THREW__ = 0;
       $33 = $32&1;
       if ($33) {
        $52 = ___cxa_find_matching_catch_2()|0;
        $53 = tempRet0;
        $$032 = $52;$$035 = $53;
       } else {
        $34 = HEAP32[$9>>2]|0;
        $35 = HEAP32[$8>>2]|0;
        $36 = (($34) - ($35))|0;
        $37 = ($36|0)>(392);
        $38 = $35;
        $39 = $34;
        if ($37) {
         $40 = $36 >>> 2;
         $41 = (($40) + 2)|0;
         $42 = (_malloc($41)|0);
         $43 = $42;
         $44 = ($42|0)==(0|0);
         if ($44) {
          __THREW__ = 0;
          invoke_v(4685);
          $45 = __THREW__; __THREW__ = 0;
          $$sroa$043$0 = $43;
         } else {
          $$031 = $42;$$sroa$043$1 = $43;
          label = 16;
         }
        } else {
         $$031 = $14;$$sroa$043$1 = 0;
         label = 16;
        }
        do {
         if ((label|0) == 16) {
          $58 = HEAP8[$11>>0]|0;
          $59 = ($58<<24>>24)==(0);
          if ($59) {
           $$1 = $$031;
          } else {
           $60 = ((($$031)) + 1|0);
           HEAP8[$$031>>0] = 45;
           $$1 = $60;
          }
          $61 = ((($13)) + 40|0);
          $62 = $13;
          $$0 = $38;$$2 = $$1;$64 = $39;
          while(1) {
           $63 = ($$0>>>0)<($64>>>0);
           if (!($63)) {
            break;
           }
           $67 = HEAP32[$$0>>2]|0;
           $$0$i = $13;
           while(1) {
            $68 = ($$0$i|0)==($61|0);
            if ($68) {
             $$0$lcssa$i = $61;
             break;
            }
            $69 = HEAP32[$$0$i>>2]|0;
            $70 = ($69|0)==($67|0);
            if ($70) {
             $$0$lcssa$i = $$0$i;
             break;
            }
            $71 = ((($$0$i)) + 4|0);
            $$0$i = $71;
           }
           $72 = $$0$lcssa$i;
           $73 = (($72) - ($62))|0;
           $74 = $73 >> 2;
           $75 = (204065 + ($74)|0);
           $76 = HEAP8[$75>>0]|0;
           HEAP8[$$2>>0] = $76;
           $77 = ((($$0)) + 4|0);
           $78 = ((($$2)) + 1|0);
           $$pre = HEAP32[$9>>2]|0;
           $$0 = $77;$$2 = $78;$64 = $$pre;
          }
          HEAP8[$$2>>0] = 0;
          HEAP32[$vararg_buffer>>2] = $6;
          $65 = (_sscanf($14,203950,$vararg_buffer)|0);
          $66 = ($65|0)==(1);
          if (!($66)) {
           __THREW__ = 0;
           invoke_vi(4718,(203954|0));
           $79 = __THREW__; __THREW__ = 0;
           $$sroa$043$0 = $$sroa$043$1;
           break;
          }
          $80 = ($$sroa$043$1|0)==(0);
          if (!($80)) {
           $81 = $$sroa$043$1;
           _free($81);
          }
          break L9;
         }
        } while(0);
        $54 = ___cxa_find_matching_catch_2()|0;
        $55 = tempRet0;
        $56 = ($$sroa$043$0|0)==(0);
        if (!($56)) {
         $57 = $$sroa$043$0;
         _free($57);
        }
        $$032 = $54;$$035 = $55;
       }
       $$133 = $$032;$$136 = $$035;
       break L7;
      }
     } while(0);
     $82 = HEAP32[$1>>2]|0;
     $83 = ($82|0)==(0|0);
     do {
      if ($83) {
       $132 = 1;
      } else {
       $84 = ((($82)) + 12|0);
       $85 = HEAP32[$84>>2]|0;
       $86 = ((($82)) + 16|0);
       $87 = HEAP32[$86>>2]|0;
       $88 = ($85|0)==($87|0);
       if ($88) {
        $89 = HEAP32[$82>>2]|0;
        $90 = ((($89)) + 36|0);
        $91 = HEAP32[$90>>2]|0;
        __THREW__ = 0;
        $92 = (invoke_ii($91|0,($82|0))|0);
        $93 = __THREW__; __THREW__ = 0;
        $94 = $93&1;
        if ($94) {
         label = 11;
         break L7;
        } else {
         $$0$i$i$i$i = $92;
        }
       } else {
        $95 = HEAP32[$85>>2]|0;
        $96 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($95)|0);
        $$0$i$i$i$i = $96;
       }
       $97 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
       $98 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i$i$i,$97)|0);
       if ($98) {
        HEAP32[$1>>2] = 0;
        $132 = 1;
        break;
       } else {
        $$pre$i$i$i = HEAP32[$1>>2]|0;
        $phitmp$i$i$i = ($$pre$i$i$i|0)==(0|0);
        $132 = $phitmp$i$i$i;
        break;
       }
      }
     } while(0);
     $99 = HEAP32[$2>>2]|0;
     $100 = ($99|0)==(0|0);
     do {
      if ($100) {
       label = 44;
      } else {
       $101 = ((($99)) + 12|0);
       $102 = HEAP32[$101>>2]|0;
       $103 = ((($99)) + 16|0);
       $104 = HEAP32[$103>>2]|0;
       $105 = ($102|0)==($104|0);
       if ($105) {
        $106 = HEAP32[$99>>2]|0;
        $107 = ((($106)) + 36|0);
        $108 = HEAP32[$107>>2]|0;
        __THREW__ = 0;
        $109 = (invoke_ii($108|0,($99|0))|0);
        $110 = __THREW__; __THREW__ = 0;
        $111 = $110&1;
        if ($111) {
         label = 11;
         break L7;
        } else {
         $$0$i$i2$i$i = $109;
        }
       } else {
        $112 = HEAP32[$102>>2]|0;
        $113 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($112)|0);
        $$0$i$i2$i$i = $113;
       }
       $114 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
       $115 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i2$i$i,$114)|0);
       if ($115) {
        HEAP32[$2>>2] = 0;
        label = 44;
        break;
       } else {
        if ($132) {
         break;
        } else {
         label = 46;
         break;
        }
       }
      }
     } while(0);
     if ((label|0) == 44) {
      if ($132) {
       label = 46;
      }
     }
     if ((label|0) == 46) {
      $116 = HEAP32[$5>>2]|0;
      $117 = $116 | 2;
      HEAP32[$5>>2] = $117;
     }
     $$sroa$0$0$copyload = HEAP32[$1>>2]|0;
     __ZNSt3__26localeD2Ev($10);
     $118 = HEAP32[$8>>2]|0;
     HEAP32[$8>>2] = 0;
     $119 = ($118|0)==(0|0);
     if (!($119)) {
      $120 = HEAP32[$16>>2]|0;
      __THREW__ = 0;
      invoke_vi($120|0,($118|0));
      $121 = __THREW__; __THREW__ = 0;
      $122 = $121&1;
      if ($122) {
       $123 = ___cxa_find_matching_catch_3(0|0)|0;
       $124 = tempRet0;
       ___clang_call_terminate($123);
       // unreachable;
      }
     }
     STACKTOP = sp;return ($$sroa$0$0$copyload|0);
    }
   } while(0);
   if ((label|0) == 11) {
    $50 = ___cxa_find_matching_catch_2()|0;
    $51 = tempRet0;
    $$133 = $50;$$136 = $51;
   }
   $$234 = $$133;$$237 = $$136;
  }
  __ZNSt3__26localeD2Ev($10);
  $$pre56 = HEAP32[$8>>2]|0;
  HEAP32[$8>>2] = 0;
  $125 = ($$pre56|0)==(0|0);
  if ($125) {
   $$33860 = $$237;$$362 = $$234;
  } else {
   $$pre63 = HEAP32[$16>>2]|0;
   $$33859 = $$237;$$361 = $$234;$126 = $$pre63;$127 = $$pre56;
   label = 54;
  }
 }
 if ((label|0) == 54) {
  __THREW__ = 0;
  invoke_vi($126|0,($127|0));
  $128 = __THREW__; __THREW__ = 0;
  $129 = $128&1;
  if ($129) {
   $130 = ___cxa_find_matching_catch_3(0|0)|0;
   $131 = tempRet0;
   ___clang_call_terminate($130);
   // unreachable;
  } else {
   $$33860 = $$33859;$$362 = $$361;
  }
 }
 ___resumeException($$362|0);
 // unreachable;
 return (0)|0;
}
function __ZNKSt3__29money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_bRNS_8ios_baseERjRNS_12basic_stringIwS3_NS_9allocatorIwEEEE($0,$1,$2,$3,$4,$5,$6) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 var $$0 = 0, $$0$i$i$i$i = 0, $$0$i$i2$i$i = 0, $$1 = 0, $$135 = 0, $$23646 = 0, $$23647 = 0, $$248 = 0, $$249 = 0, $$byval_copy = 0, $$pre = 0, $$pre$i$i$i = 0, $$sroa$0$0$copyload = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $phitmp$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 448|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(448|0);
 $$byval_copy = sp + 432|0;
 $7 = sp + 428|0;
 $8 = sp + 424|0;
 $9 = sp + 24|0;
 $10 = sp + 16|0;
 $11 = sp + 8|0;
 $12 = sp + 4|0;
 $13 = sp + 436|0;
 $14 = sp;
 $15 = $9;
 HEAP32[$10>>2] = $15;
 $16 = ((($10)) + 4|0);
 HEAP32[$16>>2] = (4716);
 $17 = ((($9)) + 400|0);
 __THREW__ = 0;
 invoke_vii(3257,($12|0),($4|0));
 $18 = __THREW__; __THREW__ = 0;
 $19 = $18&1;
 if ($19) {
  $46 = ___cxa_find_matching_catch_2()|0;
  $47 = tempRet0;
  HEAP32[$10>>2] = 0;
  $$23646 = $47;$$248 = $46;$112 = $9;
  label = 41;
 } else {
  __THREW__ = 0;
  $20 = (invoke_iii(3255,($12|0),(215220|0))|0);
  $21 = __THREW__; __THREW__ = 0;
  $22 = $21&1;
  if ($22) {
   $48 = ___cxa_find_matching_catch_2()|0;
   $49 = tempRet0;
   $$1 = $48;$$135 = $49;
  } else {
   HEAP8[$13>>0] = 0;
   $23 = HEAP32[$2>>2]|0;
   HEAP32[$14>>2] = $23;
   $24 = ((($4)) + 4|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = $23;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy>>2]=HEAP32[$14>>2]|0;
   $27 = (invoke_iiiiiiiiiiii(4725,($1|0),($$byval_copy|0),($3|0),($12|0),($25|0),($5|0),($13|0),($20|0),($10|0),($11|0),($17|0))|0);
   $28 = __THREW__; __THREW__ = 0;
   $29 = $28&1;
   L7: do {
    if (!($29)) {
     if ($27) {
      $30 = ((($6)) + 8|0);
      $31 = ((($30)) + 3|0);
      $32 = HEAP8[$31>>0]|0;
      $33 = ($32<<24>>24)<(0);
      if ($33) {
       $34 = HEAP32[$6>>2]|0;
       HEAP32[$7>>2] = 0;
       __ZNSt3__211char_traitsIwE6assignERwRKw($34,$7);
       $35 = ((($6)) + 4|0);
       HEAP32[$35>>2] = 0;
      } else {
       HEAP32[$8>>2] = 0;
       __ZNSt3__211char_traitsIwE6assignERwRKw($6,$8);
       HEAP8[$31>>0] = 0;
      }
      $36 = HEAP8[$13>>0]|0;
      $37 = ($36<<24>>24)==(0);
      if (!($37)) {
       $38 = HEAP32[$20>>2]|0;
       $39 = ((($38)) + 44|0);
       $40 = HEAP32[$39>>2]|0;
       __THREW__ = 0;
       $41 = (invoke_iii($40|0,($20|0),45)|0);
       $42 = __THREW__; __THREW__ = 0;
       $43 = $42&1;
       if ($43) {
        break;
       }
       __THREW__ = 0;
       invoke_vii(4726,($6|0),($41|0));
       $44 = __THREW__; __THREW__ = 0;
       $45 = $44&1;
       if ($45) {
        break;
       }
      }
      $50 = HEAP32[$20>>2]|0;
      $51 = ((($50)) + 44|0);
      $52 = HEAP32[$51>>2]|0;
      __THREW__ = 0;
      $53 = (invoke_iii($52|0,($20|0),48)|0);
      $54 = __THREW__; __THREW__ = 0;
      $55 = $54&1;
      if ($55) {
       break;
      }
      $56 = HEAP32[$10>>2]|0;
      $57 = HEAP32[$11>>2]|0;
      $58 = ((($57)) + -4|0);
      $$0 = $56;
      while(1) {
       $59 = ($$0>>>0)<($58>>>0);
       if (!($59)) {
        break;
       }
       $60 = HEAP32[$$0>>2]|0;
       $61 = ($60|0)==($53|0);
       if (!($61)) {
        break;
       }
       $62 = ((($$0)) + 4|0);
       $$0 = $62;
      }
      __THREW__ = 0;
      (invoke_iiii(4727,($6|0),($$0|0),($57|0))|0);
      $63 = __THREW__; __THREW__ = 0;
      $64 = $63&1;
      if ($64) {
       break;
      }
     }
     $65 = HEAP32[$1>>2]|0;
     $66 = ($65|0)==(0|0);
     do {
      if ($66) {
       $117 = 1;
      } else {
       $67 = ((($65)) + 12|0);
       $68 = HEAP32[$67>>2]|0;
       $69 = ((($65)) + 16|0);
       $70 = HEAP32[$69>>2]|0;
       $71 = ($68|0)==($70|0);
       if ($71) {
        $72 = HEAP32[$65>>2]|0;
        $73 = ((($72)) + 36|0);
        $74 = HEAP32[$73>>2]|0;
        __THREW__ = 0;
        $75 = (invoke_ii($74|0,($65|0))|0);
        $76 = __THREW__; __THREW__ = 0;
        $77 = $76&1;
        if ($77) {
         break L7;
        } else {
         $$0$i$i$i$i = $75;
        }
       } else {
        $78 = HEAP32[$68>>2]|0;
        $79 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($78)|0);
        $$0$i$i$i$i = $79;
       }
       $80 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
       $81 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i$i$i,$80)|0);
       if ($81) {
        HEAP32[$1>>2] = 0;
        $117 = 1;
        break;
       } else {
        $$pre$i$i$i = HEAP32[$1>>2]|0;
        $phitmp$i$i$i = ($$pre$i$i$i|0)==(0|0);
        $117 = $phitmp$i$i$i;
        break;
       }
      }
     } while(0);
     $82 = ($23|0)==(0);
     do {
      if ($82) {
       label = 32;
      } else {
       $83 = ((($26)) + 12|0);
       $84 = HEAP32[$83>>2]|0;
       $85 = ((($26)) + 16|0);
       $86 = HEAP32[$85>>2]|0;
       $87 = ($84|0)==($86|0);
       if ($87) {
        $88 = $23;
        $89 = HEAP32[$88>>2]|0;
        $90 = ((($89)) + 36|0);
        $91 = HEAP32[$90>>2]|0;
        __THREW__ = 0;
        $92 = (invoke_ii($91|0,($26|0))|0);
        $93 = __THREW__; __THREW__ = 0;
        $94 = $93&1;
        if ($94) {
         break L7;
        } else {
         $$0$i$i2$i$i = $92;
        }
       } else {
        $95 = HEAP32[$84>>2]|0;
        $96 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($95)|0);
        $$0$i$i2$i$i = $96;
       }
       $97 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
       $98 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i2$i$i,$97)|0);
       if ($98) {
        HEAP32[$2>>2] = 0;
        label = 32;
        break;
       } else {
        if ($117) {
         break;
        } else {
         label = 34;
         break;
        }
       }
      }
     } while(0);
     if ((label|0) == 32) {
      if ($117) {
       label = 34;
      }
     }
     if ((label|0) == 34) {
      $99 = HEAP32[$5>>2]|0;
      $100 = $99 | 2;
      HEAP32[$5>>2] = $100;
     }
     $$sroa$0$0$copyload = HEAP32[$1>>2]|0;
     __ZNSt3__26localeD2Ev($12);
     $101 = HEAP32[$10>>2]|0;
     HEAP32[$10>>2] = 0;
     $102 = ($101|0)==(0|0);
     if (!($102)) {
      $103 = HEAP32[$16>>2]|0;
      __THREW__ = 0;
      invoke_vi($103|0,($101|0));
      $104 = __THREW__; __THREW__ = 0;
      $105 = $104&1;
      if ($105) {
       $106 = ___cxa_find_matching_catch_3(0|0)|0;
       $107 = tempRet0;
       ___clang_call_terminate($106);
       // unreachable;
      }
     }
     STACKTOP = sp;return ($$sroa$0$0$copyload|0);
    }
   } while(0);
   $108 = ___cxa_find_matching_catch_2()|0;
   $109 = tempRet0;
   $$1 = $108;$$135 = $109;
  }
  __ZNSt3__26localeD2Ev($12);
  $$pre = HEAP32[$10>>2]|0;
  HEAP32[$10>>2] = 0;
  $110 = ($$pre|0)==(0|0);
  if ($110) {
   $$23647 = $$135;$$249 = $$1;
  } else {
   $$23646 = $$135;$$248 = $$1;$112 = $$pre;
   label = 41;
  }
 }
 if ((label|0) == 41) {
  $111 = HEAP32[$16>>2]|0;
  __THREW__ = 0;
  invoke_vi($111|0,($112|0));
  $113 = __THREW__; __THREW__ = 0;
  $114 = $113&1;
  if ($114) {
   $115 = ___cxa_find_matching_catch_3(0|0)|0;
   $116 = tempRet0;
   ___clang_call_terminate($115);
   // unreachable;
  } else {
   $$23647 = $$23646;$$249 = $$248;
  }
 }
 ___resumeException($$249|0);
 // unreachable;
 return (0)|0;
}
function __ZNSt3__29money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE8__do_getERS4_S4_bRKNS_6localeEjRjRbRKNS_5ctypeIwEERNS_10unique_ptrIwPFvPvEEERPwSM_($0,$1,$2,$3,$4,$5,$6,$7,$8,$9,$10) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 $8 = $8|0;
 $9 = $9|0;
 $10 = $10|0;
 var $$$0152 = 0, $$$0152162 = 0, $$$0152163 = 0, $$$0152164 = 0, $$0 = 0, $$0$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i189 = 0, $$0$i$i$i$i252 = 0, $$0$i$i$i$i273 = 0, $$0$i$i$i$i295 = 0, $$0$i$i$i$i314 = 0, $$0$i$i$i$i340 = 0, $$0$i$i171 = 0, $$0$i$i173 = 0, $$0$i$i176 = 0, $$0$i$i179 = 0, $$0$i$i184 = 0, $$0$i$i187 = 0, $$0$i$i2$i$i = 0;
 var $$0$i$i2$i$i195 = 0, $$0$i$i2$i$i258 = 0, $$0$i$i2$i$i279 = 0, $$0$i$i2$i$i301 = 0, $$0$i$i2$i$i320 = 0, $$0$i$i2$i$i346 = 0, $$0$i$i204 = 0, $$0$i$i209 = 0, $$0$i$i216 = 0, $$0$i$i221 = 0, $$0$i$i228 = 0, $$0$i$i235 = 0, $$0$i$i267 = 0, $$0$i$i288 = 0, $$0$i$i309 = 0, $$0$i$i329 = 0, $$0$i$i334 = 0, $$0$i$i355 = 0, $$0135 = 0, $$0152 = 0;
 var $$0161 = 0, $$10 = 0, $$1153 = 0, $$2137$ph = 0, $$5145 = 0, $$5151 = 0, $$lcssa = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i191 = 0, $$pre$i$i$i254 = 0, $$pre$i$i$i275 = 0, $$pre$i$i$i297 = 0, $$pre$i$i$i316 = 0, $$pre$i$i$i342 = 0, $$pre$i4$i$i197 = 0, $$pre$i4$i$i197527 = 0, $$pre$i4$i$i197529 = 0, $$pre$i4$i$i260 = 0, $$pre$i4$i$i260524 = 0;
 var $$pre$i4$i$i260525 = 0, $$pre$i4$i$i281 = 0, $$pre$i4$i$i281509 = 0, $$pre$i4$i$i281511 = 0, $$pre$i4$i$i303 = 0, $$pre$i4$i$i322 = 0, $$pre$i4$i$i322516$ph = 0, $$pre$i4$i$i322516533 = 0, $$pre513 = 0, $$pre515 = 0, $$pre518 = 0, $$pre519 = 0, $$pre520 = 0, $$pre521 = 0, $$pre522 = 0, $$pre523 = 0, $$sink = 0, $$sroa$0366$0 = 0, $$sroa$0388$0 = 0, $100 = 0;
 var $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0;
 var $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0;
 var $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0;
 var $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0;
 var $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0;
 var $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0;
 var $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0;
 var $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0;
 var $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0;
 var $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0;
 var $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $30 = 0, $300 = 0;
 var $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0;
 var $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0;
 var $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0;
 var $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0;
 var $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0;
 var $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0;
 var $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0;
 var $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0;
 var $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0;
 var $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0;
 var $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $50 = 0, $500 = 0;
 var $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0;
 var $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0;
 var $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0;
 var $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0;
 var $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0;
 var $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0;
 var $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0;
 var $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0;
 var $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0;
 var $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0;
 var $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $70 = 0, $700 = 0;
 var $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0;
 var $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0;
 var $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0;
 var $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0;
 var $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0;
 var $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0;
 var $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0;
 var $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = 0, $834 = 0, $835 = 0, $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0;
 var $847 = 0, $848 = 0, $849 = 0, $85 = 0, $850 = 0, $851 = 0, $852 = 0, $853 = 0, $854 = 0, $855 = 0, $856 = 0, $857 = 0, $858 = 0, $859 = 0, $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0;
 var $865 = 0, $866 = 0, $867 = 0, $868 = 0, $869 = 0, $87 = 0, $870 = 0, $871 = 0, $872 = 0, $873 = 0, $874 = 0, $875 = 0, $876 = 0, $877 = 0, $878 = 0, $879 = 0, $88 = 0, $880 = 0, $881 = 0, $882 = 0;
 var $883 = 0, $884 = 0, $885 = 0, $886 = 0, $887 = 0, $888 = 0, $889 = 0, $89 = 0, $890 = 0, $891 = 0, $892 = 0, $893 = 0, $894 = 0, $895 = 0, $896 = 0, $897 = 0, $898 = 0, $899 = 0, $90 = 0, $900 = 0;
 var $901 = 0, $902 = 0, $903 = 0, $904 = 0, $905 = 0, $906 = 0, $907 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $brmerge = 0, $exitcond$i$i = 0, $exitcond$i$i172 = 0, $exitcond$i$i174 = 0;
 var $exitcond$i$i177 = 0, $exitcond$i$i180 = 0, $or$cond = 0, $or$cond13 = 0, $or$cond15 = 0, $or$cond167 = 0, $phitmp$i$i$i = 0, $phitmp$i$i$i192 = 0, $phitmp$i$i$i255 = 0, $phitmp$i$i$i276 = 0, $phitmp$i$i$i298 = 0, $phitmp$i$i$i317 = 0, $phitmp$i$i$i343 = 0, $phitmp$i5$i$i198 = 0, $phitmp$i5$i$i261 = 0, $phitmp$i5$i$i282 = 0, $phitmp$i5$i$i323 = 0, $switch = 0, $tmp$i$i200 = 0, $tmp$i$i263 = 0;
 var $tmp$i$i284 = 0, $tmp$i$i325 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 512|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(512|0);
 $11 = sp + 496|0;
 $12 = sp + 96|0;
 $13 = sp + 88|0;
 $14 = sp + 80|0;
 $15 = sp + 76|0;
 $16 = sp + 500|0;
 $17 = sp + 72|0;
 $18 = sp + 68|0;
 $19 = sp + 56|0;
 $20 = sp + 44|0;
 $21 = sp + 32|0;
 $22 = sp + 20|0;
 $23 = sp + 8|0;
 $24 = sp + 4|0;
 $25 = sp;
 HEAP32[$11>>2] = $10;
 $26 = $12;
 HEAP32[$13>>2] = $26;
 $27 = ((($13)) + 4|0);
 HEAP32[$27>>2] = (4716);
 HEAP32[$14>>2] = $12;
 $28 = ((($12)) + 400|0);
 HEAP32[$15>>2] = $28;
 ;HEAP32[$19>>2]=0|0;HEAP32[$19+4>>2]=0|0;HEAP32[$19+8>>2]=0|0;
 $$0$i$i = 0;
 while(1) {
  $exitcond$i$i = ($$0$i$i|0)==(3);
  if ($exitcond$i$i) {
   break;
  }
  $29 = (($19) + ($$0$i$i<<2)|0);
  HEAP32[$29>>2] = 0;
  $30 = (($$0$i$i) + 1)|0;
  $$0$i$i = $30;
 }
 ;HEAP32[$20>>2]=0|0;HEAP32[$20+4>>2]=0|0;HEAP32[$20+8>>2]=0|0;
 $$0$i$i171 = 0;
 while(1) {
  $exitcond$i$i172 = ($$0$i$i171|0)==(3);
  if ($exitcond$i$i172) {
   break;
  }
  $31 = (($20) + ($$0$i$i171<<2)|0);
  HEAP32[$31>>2] = 0;
  $32 = (($$0$i$i171) + 1)|0;
  $$0$i$i171 = $32;
 }
 ;HEAP32[$21>>2]=0|0;HEAP32[$21+4>>2]=0|0;HEAP32[$21+8>>2]=0|0;
 $$0$i$i173 = 0;
 while(1) {
  $exitcond$i$i174 = ($$0$i$i173|0)==(3);
  if ($exitcond$i$i174) {
   break;
  }
  $33 = (($21) + ($$0$i$i173<<2)|0);
  HEAP32[$33>>2] = 0;
  $34 = (($$0$i$i173) + 1)|0;
  $$0$i$i173 = $34;
 }
 ;HEAP32[$22>>2]=0|0;HEAP32[$22+4>>2]=0|0;HEAP32[$22+8>>2]=0|0;
 $$0$i$i176 = 0;
 while(1) {
  $exitcond$i$i177 = ($$0$i$i176|0)==(3);
  if ($exitcond$i$i177) {
   break;
  }
  $35 = (($22) + ($$0$i$i176<<2)|0);
  HEAP32[$35>>2] = 0;
  $36 = (($$0$i$i176) + 1)|0;
  $$0$i$i176 = $36;
 }
 ;HEAP32[$23>>2]=0|0;HEAP32[$23+4>>2]=0|0;HEAP32[$23+8>>2]=0|0;
 $$0$i$i179 = 0;
 while(1) {
  $exitcond$i$i180 = ($$0$i$i179|0)==(3);
  if ($exitcond$i$i180) {
   break;
  }
  $37 = (($23) + ($$0$i$i179<<2)|0);
  HEAP32[$37>>2] = 0;
  $38 = (($$0$i$i179) + 1)|0;
  $$0$i$i179 = $38;
 }
 __THREW__ = 0;
 invoke_viiiiiiiiii(4728,($2|0),($3|0),($16|0),($17|0),($18|0),($19|0),($20|0),($21|0),($22|0),($24|0));
 $39 = __THREW__; __THREW__ = 0;
 $40 = $39&1;
 L21: do {
  if ($40) {
   $95 = ___cxa_find_matching_catch_2()|0;
   $96 = tempRet0;
   $$5145 = $95;$$5151 = $96;
  } else {
   $41 = HEAP32[$8>>2]|0;
   HEAP32[$9>>2] = $41;
   $42 = ((($21)) + 8|0);
   $43 = ((($42)) + 3|0);
   $44 = ((($21)) + 4|0);
   $45 = ((($22)) + 8|0);
   $46 = ((($45)) + 3|0);
   $47 = ((($22)) + 4|0);
   $48 = $4 & 512;
   $49 = ($48|0)!=(0);
   $50 = ((($20)) + 8|0);
   $51 = ((($50)) + 3|0);
   $52 = ((($20)) + 4|0);
   $53 = ((($23)) + 8|0);
   $54 = ((($53)) + 3|0);
   $55 = ((($23)) + 4|0);
   $56 = ((($16)) + 3|0);
   $57 = ((($19)) + 11|0);
   $58 = ((($19)) + 4|0);
   $$0152 = 0;$$0161 = 0;
   L24: while(1) {
    $59 = ($$0161>>>0)<(4);
    $60 = ($$0152|0)!=(0|0);
    if (!($59)) {
     label = 247;
     break;
    }
    $61 = HEAP32[$0>>2]|0;
    $62 = ($61|0)==(0|0);
    do {
     if ($62) {
      $899 = 1;
     } else {
      $63 = ((($61)) + 12|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = ((($61)) + 16|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = ($64|0)==($66|0);
      if ($67) {
       $68 = HEAP32[$61>>2]|0;
       $69 = ((($68)) + 36|0);
       $70 = HEAP32[$69>>2]|0;
       __THREW__ = 0;
       $71 = (invoke_ii($70|0,($61|0))|0);
       $72 = __THREW__; __THREW__ = 0;
       $73 = $72&1;
       if ($73) {
        label = 35;
        break L24;
       } else {
        $$0$i$i$i$i = $71;
       }
      } else {
       $74 = HEAP32[$64>>2]|0;
       $75 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($74)|0);
       $$0$i$i$i$i = $75;
      }
      $76 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
      $77 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i$i$i,$76)|0);
      if ($77) {
       HEAP32[$0>>2] = 0;
       $899 = 1;
       break;
      } else {
       $$pre$i$i$i = HEAP32[$0>>2]|0;
       $phitmp$i$i$i = ($$pre$i$i$i|0)==(0|0);
       $899 = $phitmp$i$i$i;
       break;
      }
     }
    } while(0);
    $78 = HEAP32[$1>>2]|0;
    $79 = ($78|0)==(0|0);
    do {
     if ($79) {
      label = 32;
     } else {
      $80 = ((($78)) + 12|0);
      $81 = HEAP32[$80>>2]|0;
      $82 = ((($78)) + 16|0);
      $83 = HEAP32[$82>>2]|0;
      $84 = ($81|0)==($83|0);
      if ($84) {
       $85 = HEAP32[$78>>2]|0;
       $86 = ((($85)) + 36|0);
       $87 = HEAP32[$86>>2]|0;
       __THREW__ = 0;
       $88 = (invoke_ii($87|0,($78|0))|0);
       $89 = __THREW__; __THREW__ = 0;
       $90 = $89&1;
       if ($90) {
        label = 35;
        break L24;
       } else {
        $$0$i$i2$i$i = $88;
       }
      } else {
       $91 = HEAP32[$81>>2]|0;
       $92 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($91)|0);
       $$0$i$i2$i$i = $92;
      }
      $93 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
      $94 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i2$i$i,$93)|0);
      if ($94) {
       HEAP32[$1>>2] = 0;
       label = 32;
       break;
      } else {
       if ($899) {
        $900 = $78;
        break;
       } else {
        label = 247;
        break L24;
       }
      }
     }
    } while(0);
    if ((label|0) == 32) {
     label = 0;
     if ($899) {
      label = 247;
      break;
     } else {
      $900 = 0;
     }
    }
    $99 = (($16) + ($$0161)|0);
    $100 = HEAP8[$99>>0]|0;
    $101 = $100 << 24 >> 24;
    $102 = ($$0161|0)!=(3);
    L49: do {
     switch ($101|0) {
     case 1:  {
      if ($102) {
       $103 = HEAP32[$0>>2]|0;
       $104 = ((($103)) + 12|0);
       $105 = HEAP32[$104>>2]|0;
       $106 = ((($103)) + 16|0);
       $107 = HEAP32[$106>>2]|0;
       $108 = ($105|0)==($107|0);
       if ($108) {
        $109 = HEAP32[$103>>2]|0;
        $110 = ((($109)) + 36|0);
        $111 = HEAP32[$110>>2]|0;
        __THREW__ = 0;
        $112 = (invoke_ii($111|0,($103|0))|0);
        $113 = __THREW__; __THREW__ = 0;
        $114 = $113&1;
        if ($114) {
         label = 35;
         break L24;
        } else {
         $$0$i$i184 = $112;
        }
       } else {
        $115 = HEAP32[$105>>2]|0;
        $116 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($115)|0);
        $$0$i$i184 = $116;
       }
       $117 = HEAP32[$7>>2]|0;
       $118 = ((($117)) + 12|0);
       $119 = HEAP32[$118>>2]|0;
       __THREW__ = 0;
       $120 = (invoke_iiii($119|0,($7|0),8192,($$0$i$i184|0))|0);
       $121 = __THREW__; __THREW__ = 0;
       $122 = $121&1;
       if ($122) {
        label = 35;
        break L24;
       }
       if (!($120)) {
        label = 47;
        break L24;
       }
       $123 = HEAP32[$0>>2]|0;
       $124 = ((($123)) + 12|0);
       $125 = HEAP32[$124>>2]|0;
       $126 = ((($123)) + 16|0);
       $127 = HEAP32[$126>>2]|0;
       $128 = ($125|0)==($127|0);
       if ($128) {
        $129 = HEAP32[$123>>2]|0;
        $130 = ((($129)) + 40|0);
        $131 = HEAP32[$130>>2]|0;
        __THREW__ = 0;
        $132 = (invoke_ii($131|0,($123|0))|0);
        $133 = __THREW__; __THREW__ = 0;
        $134 = $133&1;
        if ($134) {
         label = 35;
         break L24;
        } else {
         $$0$i$i187 = $132;
        }
       } else {
        $135 = ((($125)) + 4|0);
        HEAP32[$124>>2] = $135;
        $136 = HEAP32[$125>>2]|0;
        $137 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($136)|0);
        $$0$i$i187 = $137;
       }
       __THREW__ = 0;
       invoke_vii(4726,($23|0),($$0$i$i187|0));
       $138 = __THREW__; __THREW__ = 0;
       $139 = $138&1;
       if ($139) {
        label = 35;
        break L24;
       } else {
        $$pre$i4$i$i197 = $900;$159 = $900;
        label = 49;
       }
      } else {
       $$1153 = $$0152;
      }
      break;
     }
     case 0:  {
      if ($102) {
       $$pre$i4$i$i197 = $900;$159 = $900;
       label = 49;
      } else {
       $$1153 = $$0152;
      }
      break;
     }
     case 3:  {
      $214 = HEAP8[$43>>0]|0;
      $215 = ($214<<24>>24)<(0);
      $216 = HEAP32[$44>>2]|0;
      $217 = $214&255;
      $218 = $215 ? $216 : $217;
      $219 = HEAP8[$46>>0]|0;
      $220 = ($219<<24>>24)<(0);
      $221 = HEAP32[$47>>2]|0;
      $222 = $219&255;
      $223 = $220 ? $221 : $222;
      $224 = (0 - ($223))|0;
      $225 = ($218|0)==($224|0);
      if ($225) {
       $$1153 = $$0152;
      } else {
       $226 = ($218|0)==(0);
       if ($226) {
        $267 = HEAP32[$0>>2]|0;
        $268 = ((($267)) + 12|0);
        $269 = HEAP32[$268>>2]|0;
        $270 = ((($267)) + 16|0);
        $271 = HEAP32[$270>>2]|0;
        $272 = ($269|0)==($271|0);
        if ($272) {
         $273 = HEAP32[$267>>2]|0;
         $274 = ((($273)) + 36|0);
         $275 = HEAP32[$274>>2]|0;
         __THREW__ = 0;
         $276 = (invoke_ii($275|0,($267|0))|0);
         $277 = __THREW__; __THREW__ = 0;
         $278 = $277&1;
         if ($278) {
          label = 35;
          break L24;
         } else {
          $$0$i$i221 = $276;
         }
        } else {
         $279 = HEAP32[$269>>2]|0;
         $280 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($279)|0);
         $$0$i$i221 = $280;
        }
        $281 = HEAP8[$46>>0]|0;
        $282 = ($281<<24>>24)<(0);
        $283 = HEAP32[$22>>2]|0;
        $284 = $282 ? $283 : $22;
        $285 = HEAP32[$284>>2]|0;
        $286 = ($$0$i$i221|0)==($285|0);
        if (!($286)) {
         $$1153 = $$0152;
         break L49;
        }
        $287 = HEAP32[$0>>2]|0;
        $288 = ((($287)) + 12|0);
        $289 = HEAP32[$288>>2]|0;
        $290 = ((($287)) + 16|0);
        $291 = HEAP32[$290>>2]|0;
        $292 = ($289|0)==($291|0);
        if ($292) {
         $293 = HEAP32[$287>>2]|0;
         $294 = ((($293)) + 40|0);
         $295 = HEAP32[$294>>2]|0;
         __THREW__ = 0;
         (invoke_ii($295|0,($287|0))|0);
         $296 = __THREW__; __THREW__ = 0;
         $297 = $296&1;
         if ($297) {
          label = 35;
          break L24;
         }
        } else {
         $298 = ((($289)) + 4|0);
         HEAP32[$288>>2] = $298;
         $299 = HEAP32[$289>>2]|0;
         (__ZNSt3__211char_traitsIwE11to_int_typeEw($299)|0);
        }
        HEAP8[$6>>0] = 1;
        $300 = HEAP8[$46>>0]|0;
        $301 = ($300<<24>>24)<(0);
        $302 = HEAP32[$47>>2]|0;
        $303 = $300&255;
        $304 = $301 ? $302 : $303;
        $305 = ($304>>>0)>(1);
        $$$0152162 = $305 ? $22 : $$0152;
        $$1153 = $$$0152162;
        break L49;
       }
       $227 = ($223|0)==(0);
       $228 = HEAP32[$0>>2]|0;
       $229 = ((($228)) + 12|0);
       $230 = HEAP32[$229>>2]|0;
       $231 = ((($228)) + 16|0);
       $232 = HEAP32[$231>>2]|0;
       $233 = ($230|0)==($232|0);
       if ($227) {
        if ($233) {
         $234 = HEAP32[$228>>2]|0;
         $235 = ((($234)) + 36|0);
         $236 = HEAP32[$235>>2]|0;
         __THREW__ = 0;
         $237 = (invoke_ii($236|0,($228|0))|0);
         $238 = __THREW__; __THREW__ = 0;
         $239 = $238&1;
         if ($239) {
          label = 35;
          break L24;
         } else {
          $$0$i$i216 = $237;
         }
        } else {
         $240 = HEAP32[$230>>2]|0;
         $241 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($240)|0);
         $$0$i$i216 = $241;
        }
        $242 = HEAP8[$43>>0]|0;
        $243 = ($242<<24>>24)<(0);
        $244 = HEAP32[$21>>2]|0;
        $245 = $243 ? $244 : $21;
        $246 = HEAP32[$245>>2]|0;
        $247 = ($$0$i$i216|0)==($246|0);
        if (!($247)) {
         HEAP8[$6>>0] = 1;
         $$1153 = $$0152;
         break L49;
        }
        $248 = HEAP32[$0>>2]|0;
        $249 = ((($248)) + 12|0);
        $250 = HEAP32[$249>>2]|0;
        $251 = ((($248)) + 16|0);
        $252 = HEAP32[$251>>2]|0;
        $253 = ($250|0)==($252|0);
        if ($253) {
         $254 = HEAP32[$248>>2]|0;
         $255 = ((($254)) + 40|0);
         $256 = HEAP32[$255>>2]|0;
         __THREW__ = 0;
         (invoke_ii($256|0,($248|0))|0);
         $257 = __THREW__; __THREW__ = 0;
         $258 = $257&1;
         if ($258) {
          label = 35;
          break L24;
         }
        } else {
         $259 = ((($250)) + 4|0);
         HEAP32[$249>>2] = $259;
         $260 = HEAP32[$250>>2]|0;
         (__ZNSt3__211char_traitsIwE11to_int_typeEw($260)|0);
        }
        $261 = HEAP8[$43>>0]|0;
        $262 = ($261<<24>>24)<(0);
        $263 = HEAP32[$44>>2]|0;
        $264 = $261&255;
        $265 = $262 ? $263 : $264;
        $266 = ($265>>>0)>(1);
        $$$0152 = $266 ? $21 : $$0152;
        $$1153 = $$$0152;
        break L49;
       }
       if ($233) {
        $306 = HEAP32[$228>>2]|0;
        $307 = ((($306)) + 36|0);
        $308 = HEAP32[$307>>2]|0;
        __THREW__ = 0;
        $309 = (invoke_ii($308|0,($228|0))|0);
        $310 = __THREW__; __THREW__ = 0;
        $311 = $310&1;
        if ($311) {
         label = 35;
         break L24;
        } else {
         $$0$i$i228 = $309;
        }
       } else {
        $312 = HEAP32[$230>>2]|0;
        $313 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($312)|0);
        $$0$i$i228 = $313;
       }
       $314 = HEAP8[$43>>0]|0;
       $315 = ($314<<24>>24)<(0);
       $316 = HEAP32[$21>>2]|0;
       $317 = $315 ? $316 : $21;
       $318 = HEAP32[$317>>2]|0;
       $319 = ($$0$i$i228|0)==($318|0);
       $320 = HEAP32[$0>>2]|0;
       $321 = ((($320)) + 12|0);
       $322 = HEAP32[$321>>2]|0;
       $323 = ((($320)) + 16|0);
       $324 = HEAP32[$323>>2]|0;
       $325 = ($322|0)==($324|0);
       if ($319) {
        if ($325) {
         $326 = HEAP32[$320>>2]|0;
         $327 = ((($326)) + 40|0);
         $328 = HEAP32[$327>>2]|0;
         __THREW__ = 0;
         (invoke_ii($328|0,($320|0))|0);
         $329 = __THREW__; __THREW__ = 0;
         $330 = $329&1;
         if ($330) {
          label = 35;
          break L24;
         }
        } else {
         $331 = ((($322)) + 4|0);
         HEAP32[$321>>2] = $331;
         $332 = HEAP32[$322>>2]|0;
         (__ZNSt3__211char_traitsIwE11to_int_typeEw($332)|0);
        }
        $333 = HEAP8[$43>>0]|0;
        $334 = ($333<<24>>24)<(0);
        $335 = HEAP32[$44>>2]|0;
        $336 = $333&255;
        $337 = $334 ? $335 : $336;
        $338 = ($337>>>0)>(1);
        $$$0152163 = $338 ? $21 : $$0152;
        $$1153 = $$$0152163;
        break L49;
       }
       if ($325) {
        $339 = HEAP32[$320>>2]|0;
        $340 = ((($339)) + 36|0);
        $341 = HEAP32[$340>>2]|0;
        __THREW__ = 0;
        $342 = (invoke_ii($341|0,($320|0))|0);
        $343 = __THREW__; __THREW__ = 0;
        $344 = $343&1;
        if ($344) {
         label = 35;
         break L24;
        } else {
         $$0$i$i235 = $342;
        }
       } else {
        $345 = HEAP32[$322>>2]|0;
        $346 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($345)|0);
        $$0$i$i235 = $346;
       }
       $347 = HEAP8[$46>>0]|0;
       $348 = ($347<<24>>24)<(0);
       $349 = HEAP32[$22>>2]|0;
       $350 = $348 ? $349 : $22;
       $351 = HEAP32[$350>>2]|0;
       $352 = ($$0$i$i235|0)==($351|0);
       if (!($352)) {
        label = 109;
        break L24;
       }
       $353 = HEAP32[$0>>2]|0;
       $354 = ((($353)) + 12|0);
       $355 = HEAP32[$354>>2]|0;
       $356 = ((($353)) + 16|0);
       $357 = HEAP32[$356>>2]|0;
       $358 = ($355|0)==($357|0);
       if ($358) {
        $359 = HEAP32[$353>>2]|0;
        $360 = ((($359)) + 40|0);
        $361 = HEAP32[$360>>2]|0;
        __THREW__ = 0;
        (invoke_ii($361|0,($353|0))|0);
        $362 = __THREW__; __THREW__ = 0;
        $363 = $362&1;
        if ($363) {
         label = 35;
         break L24;
        }
       } else {
        $364 = ((($355)) + 4|0);
        HEAP32[$354>>2] = $364;
        $365 = HEAP32[$355>>2]|0;
        (__ZNSt3__211char_traitsIwE11to_int_typeEw($365)|0);
       }
       HEAP8[$6>>0] = 1;
       $366 = HEAP8[$46>>0]|0;
       $367 = ($366<<24>>24)<(0);
       $368 = HEAP32[$47>>2]|0;
       $369 = $366&255;
       $370 = $367 ? $368 : $369;
       $371 = ($370>>>0)>(1);
       $$$0152164 = $371 ? $22 : $$0152;
       $$1153 = $$$0152164;
      }
      break;
     }
     case 2:  {
      $374 = ($$0161>>>0)<(2);
      $or$cond = $374 | $60;
      if (!($or$cond)) {
       $375 = ($$0161|0)==(2);
       $376 = HEAP8[$56>>0]|0;
       $377 = ($376<<24>>24)!=(0);
       $378 = $375 & $377;
       $brmerge = $49 | $378;
       if (!($brmerge)) {
        $$1153 = 0;
        break L49;
       }
      }
      $379 = HEAP8[$51>>0]|0;
      $380 = ($379<<24>>24)<(0);
      $381 = HEAP32[$20>>2]|0;
      $382 = $380 ? $381 : $20;
      $383 = $382;
      $384 = ($$0161|0)==(0);
      L115: do {
       if ($384) {
        $$pre$i4$i$i260 = $900;$$sroa$0366$0 = $383;$434 = $379;$438 = $381;$461 = $900;
       } else {
        $385 = (($$0161) + -1)|0;
        $386 = (($16) + ($385)|0);
        $387 = HEAP8[$386>>0]|0;
        $switch = ($387&255)<(2);
        if ($switch) {
         $$sroa$0388$0 = $383;$388 = $379;$392 = $381;
         while(1) {
          $389 = ($388<<24>>24)<(0);
          $390 = HEAP32[$52>>2]|0;
          $391 = $388&255;
          $393 = $389 ? $392 : $20;
          $394 = $389 ? $390 : $391;
          $395 = (($393) + ($394<<2)|0);
          $396 = $$sroa$0388$0;
          $397 = ($396|0)==($395|0);
          if ($397) {
           $409 = $388;$411 = $392;
           break;
          }
          $398 = HEAP32[$396>>2]|0;
          $399 = HEAP32[$7>>2]|0;
          $400 = ((($399)) + 12|0);
          $401 = HEAP32[$400>>2]|0;
          __THREW__ = 0;
          $402 = (invoke_iiii($401|0,($7|0),8192,($398|0))|0);
          $403 = __THREW__; __THREW__ = 0;
          $404 = $403&1;
          if ($404) {
           label = 119;
           break L24;
          }
          if (!($402)) {
           label = 117;
           break;
          }
          $405 = ((($396)) + 4|0);
          $406 = $405;
          $$pre518 = HEAP8[$51>>0]|0;
          $$pre519 = HEAP32[$20>>2]|0;
          $$sroa$0388$0 = $406;$388 = $$pre518;$392 = $$pre519;
         }
         if ((label|0) == 117) {
          label = 0;
          $$pre520 = HEAP8[$51>>0]|0;
          $$pre521 = HEAP32[$20>>2]|0;
          $409 = $$pre520;$411 = $$pre521;
         }
         $410 = ($409<<24>>24)<(0);
         $412 = $410 ? $411 : $20;
         $413 = $412;
         $414 = (($$sroa$0388$0) - ($413))|0;
         $415 = $414 >> 2;
         $416 = HEAP8[$54>>0]|0;
         $417 = ($416<<24>>24)<(0);
         $418 = HEAP32[$55>>2]|0;
         $419 = $416&255;
         $420 = $417 ? $418 : $419;
         $421 = ($415>>>0)>($420>>>0);
         if ($421) {
          $$pre$i4$i$i260 = $900;$$sroa$0366$0 = $413;$434 = $409;$438 = $411;$461 = $900;
         } else {
          $422 = HEAP32[$23>>2]|0;
          $423 = $417 ? $422 : $23;
          $424 = (($423) + ($420<<2)|0);
          $425 = (0 - ($415))|0;
          $426 = (($424) + ($425<<2)|0);
          $$sink = $412;$427 = $426;
          while(1) {
           $428 = ($427|0)==($424|0);
           if ($428) {
            $$pre$i4$i$i260 = $900;$$sroa$0366$0 = $$sroa$0388$0;$434 = $409;$438 = $411;$461 = $900;
            break L115;
           }
           $429 = HEAP32[$427>>2]|0;
           $430 = HEAP32[$$sink>>2]|0;
           $431 = ($429|0)==($430|0);
           if (!($431)) {
            $$pre$i4$i$i260 = $900;$$sroa$0366$0 = $413;$434 = $409;$438 = $411;$461 = $900;
            break L115;
           }
           $432 = ((($427)) + 4|0);
           $433 = ((($$sink)) + 4|0);
           $$sink = $433;$427 = $432;
          }
         }
        } else {
         $$pre$i4$i$i260 = $900;$$sroa$0366$0 = $383;$434 = $379;$438 = $381;$461 = $900;
        }
       }
      } while(0);
      L130: while(1) {
       $435 = ($434<<24>>24)<(0);
       $436 = HEAP32[$52>>2]|0;
       $437 = $434&255;
       $439 = $435 ? $438 : $20;
       $440 = $435 ? $436 : $437;
       $441 = (($439) + ($440<<2)|0);
       $442 = $$sroa$0366$0;
       $443 = ($442|0)==($441|0);
       if ($443) {
        $$lcssa = $441;
        break;
       }
       $444 = HEAP32[$0>>2]|0;
       $445 = ($444|0)==(0|0);
       do {
        if ($445) {
         $478 = 1;
        } else {
         $446 = ((($444)) + 12|0);
         $447 = HEAP32[$446>>2]|0;
         $448 = ((($444)) + 16|0);
         $449 = HEAP32[$448>>2]|0;
         $450 = ($447|0)==($449|0);
         if ($450) {
          $451 = HEAP32[$444>>2]|0;
          $452 = ((($451)) + 36|0);
          $453 = HEAP32[$452>>2]|0;
          __THREW__ = 0;
          $454 = (invoke_ii($453|0,($444|0))|0);
          $455 = __THREW__; __THREW__ = 0;
          $456 = $455&1;
          if ($456) {
           label = 149;
           break L24;
          } else {
           $$0$i$i$i$i252 = $454;
          }
         } else {
          $457 = HEAP32[$447>>2]|0;
          $458 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($457)|0);
          $$0$i$i$i$i252 = $458;
         }
         $459 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
         $460 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i$i$i252,$459)|0);
         if ($460) {
          HEAP32[$0>>2] = 0;
          $478 = 1;
          break;
         } else {
          $$pre$i$i$i254 = HEAP32[$0>>2]|0;
          $phitmp$i$i$i255 = ($$pre$i$i$i254|0)==(0|0);
          $478 = $phitmp$i$i$i255;
          break;
         }
        }
       } while(0);
       $462 = ($461|0)==(0|0);
       do {
        if ($462) {
         $$pre$i4$i$i260525 = $$pre$i4$i$i260;
         label = 139;
        } else {
         $463 = ((($461)) + 12|0);
         $464 = HEAP32[$463>>2]|0;
         $465 = ((($461)) + 16|0);
         $466 = HEAP32[$465>>2]|0;
         $467 = ($464|0)==($466|0);
         if ($467) {
          $468 = HEAP32[$461>>2]|0;
          $469 = ((($468)) + 36|0);
          $470 = HEAP32[$469>>2]|0;
          __THREW__ = 0;
          $471 = (invoke_ii($470|0,($461|0))|0);
          $472 = __THREW__; __THREW__ = 0;
          $473 = $472&1;
          if ($473) {
           label = 149;
           break L24;
          } else {
           $$0$i$i2$i$i258 = $471;
          }
         } else {
          $474 = HEAP32[$464>>2]|0;
          $475 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($474)|0);
          $$0$i$i2$i$i258 = $475;
         }
         $476 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
         $477 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i2$i$i258,$476)|0);
         if ($477) {
          HEAP32[$1>>2] = 0;
          $$pre$i4$i$i260525 = 0;
          label = 139;
          break;
         } else {
          $phitmp$i5$i$i261 = ($$pre$i4$i$i260|0)==(0|0);
          $tmp$i$i263 = $478 ^ $phitmp$i5$i$i261;
          if ($tmp$i$i263) {
           $$pre$i4$i$i260524 = $$pre$i4$i$i260;$902 = $$pre$i4$i$i260;
           break;
          } else {
           $$lcssa = $442;
           break L130;
          }
         }
        }
       } while(0);
       if ((label|0) == 139) {
        label = 0;
        if ($478) {
         $$lcssa = $442;
         break;
        } else {
         $$pre$i4$i$i260524 = $$pre$i4$i$i260525;$902 = 0;
        }
       }
       $479 = HEAP32[$0>>2]|0;
       $480 = ((($479)) + 12|0);
       $481 = HEAP32[$480>>2]|0;
       $482 = ((($479)) + 16|0);
       $483 = HEAP32[$482>>2]|0;
       $484 = ($481|0)==($483|0);
       if ($484) {
        $485 = HEAP32[$479>>2]|0;
        $486 = ((($485)) + 36|0);
        $487 = HEAP32[$486>>2]|0;
        __THREW__ = 0;
        $488 = (invoke_ii($487|0,($479|0))|0);
        $489 = __THREW__; __THREW__ = 0;
        $490 = $489&1;
        if ($490) {
         label = 149;
         break L24;
        } else {
         $$0$i$i267 = $488;
        }
       } else {
        $491 = HEAP32[$481>>2]|0;
        $492 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($491)|0);
        $$0$i$i267 = $492;
       }
       $493 = HEAP32[$442>>2]|0;
       $494 = ($$0$i$i267|0)==($493|0);
       if (!($494)) {
        $$lcssa = $442;
        break;
       }
       $495 = HEAP32[$0>>2]|0;
       $496 = ((($495)) + 12|0);
       $497 = HEAP32[$496>>2]|0;
       $498 = ((($495)) + 16|0);
       $499 = HEAP32[$498>>2]|0;
       $500 = ($497|0)==($499|0);
       if ($500) {
        $501 = HEAP32[$495>>2]|0;
        $502 = ((($501)) + 40|0);
        $503 = HEAP32[$502>>2]|0;
        __THREW__ = 0;
        (invoke_ii($503|0,($495|0))|0);
        $504 = __THREW__; __THREW__ = 0;
        $505 = $504&1;
        if ($505) {
         label = 150;
         break L24;
        }
       } else {
        $506 = ((($497)) + 4|0);
        HEAP32[$496>>2] = $506;
        $507 = HEAP32[$497>>2]|0;
        (__ZNSt3__211char_traitsIwE11to_int_typeEw($507)|0);
       }
       $508 = ((($442)) + 4|0);
       $509 = $508;
       $$pre522 = HEAP8[$51>>0]|0;
       $$pre523 = HEAP32[$20>>2]|0;
       $$pre$i4$i$i260 = $$pre$i4$i$i260524;$$sroa$0366$0 = $509;$434 = $$pre522;$438 = $$pre523;$461 = $902;
      }
      if ($49) {
       $514 = HEAP8[$51>>0]|0;
       $515 = ($514<<24>>24)<(0);
       $516 = HEAP32[$20>>2]|0;
       $517 = HEAP32[$52>>2]|0;
       $518 = $514&255;
       $519 = $515 ? $516 : $20;
       $520 = $515 ? $517 : $518;
       $521 = (($519) + ($520<<2)|0);
       $522 = ($$lcssa|0)==($521|0);
       if ($522) {
        $$1153 = $$0152;
       } else {
        label = 153;
        break L24;
       }
      } else {
       $$1153 = $$0152;
      }
      break;
     }
     case 4:  {
      $$0135 = 0;$$pre$i4$i$i281 = $900;$542 = $900;
      L166: while(1) {
       $525 = HEAP32[$0>>2]|0;
       $526 = ($525|0)==(0|0);
       do {
        if ($526) {
         $559 = 1;
        } else {
         $527 = ((($525)) + 12|0);
         $528 = HEAP32[$527>>2]|0;
         $529 = ((($525)) + 16|0);
         $530 = HEAP32[$529>>2]|0;
         $531 = ($528|0)==($530|0);
         if ($531) {
          $532 = HEAP32[$525>>2]|0;
          $533 = ((($532)) + 36|0);
          $534 = HEAP32[$533>>2]|0;
          __THREW__ = 0;
          $535 = (invoke_ii($534|0,($525|0))|0);
          $536 = __THREW__; __THREW__ = 0;
          $537 = $536&1;
          if ($537) {
           label = 245;
           break L24;
          } else {
           $$0$i$i$i$i273 = $535;
          }
         } else {
          $538 = HEAP32[$528>>2]|0;
          $539 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($538)|0);
          $$0$i$i$i$i273 = $539;
         }
         $540 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
         $541 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i$i$i273,$540)|0);
         if ($541) {
          HEAP32[$0>>2] = 0;
          $559 = 1;
          break;
         } else {
          $$pre$i$i$i275 = HEAP32[$0>>2]|0;
          $phitmp$i$i$i276 = ($$pre$i$i$i275|0)==(0|0);
          $559 = $phitmp$i$i$i276;
          break;
         }
        }
       } while(0);
       $543 = ($542|0)==(0|0);
       do {
        if ($543) {
         $$pre$i4$i$i281509 = $$pre$i4$i$i281;
         label = 167;
        } else {
         $544 = ((($542)) + 12|0);
         $545 = HEAP32[$544>>2]|0;
         $546 = ((($542)) + 16|0);
         $547 = HEAP32[$546>>2]|0;
         $548 = ($545|0)==($547|0);
         if ($548) {
          $549 = HEAP32[$542>>2]|0;
          $550 = ((($549)) + 36|0);
          $551 = HEAP32[$550>>2]|0;
          __THREW__ = 0;
          $552 = (invoke_ii($551|0,($542|0))|0);
          $553 = __THREW__; __THREW__ = 0;
          $554 = $553&1;
          if ($554) {
           label = 245;
           break L24;
          } else {
           $$0$i$i2$i$i279 = $552;
          }
         } else {
          $555 = HEAP32[$545>>2]|0;
          $556 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($555)|0);
          $$0$i$i2$i$i279 = $556;
         }
         $557 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
         $558 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i2$i$i279,$557)|0);
         if ($558) {
          HEAP32[$1>>2] = 0;
          $$pre$i4$i$i281509 = 0;
          label = 167;
          break;
         } else {
          $phitmp$i5$i$i282 = ($$pre$i4$i$i281|0)==(0|0);
          $tmp$i$i284 = $559 ^ $phitmp$i5$i$i282;
          if ($tmp$i$i284) {
           $$pre$i4$i$i281511 = $$pre$i4$i$i281;$903 = $$pre$i4$i$i281;
           break;
          } else {
           $$pre$i4$i$i303 = $$pre$i4$i$i281;
           break L166;
          }
         }
        }
       } while(0);
       if ((label|0) == 167) {
        label = 0;
        if ($559) {
         $$pre$i4$i$i303 = $$pre$i4$i$i281509;
         break;
        } else {
         $$pre$i4$i$i281511 = $$pre$i4$i$i281509;$903 = 0;
        }
       }
       $560 = HEAP32[$0>>2]|0;
       $561 = ((($560)) + 12|0);
       $562 = HEAP32[$561>>2]|0;
       $563 = ((($560)) + 16|0);
       $564 = HEAP32[$563>>2]|0;
       $565 = ($562|0)==($564|0);
       if ($565) {
        $566 = HEAP32[$560>>2]|0;
        $567 = ((($566)) + 36|0);
        $568 = HEAP32[$567>>2]|0;
        __THREW__ = 0;
        $569 = (invoke_ii($568|0,($560|0))|0);
        $570 = __THREW__; __THREW__ = 0;
        $571 = $570&1;
        if ($571) {
         label = 245;
         break L24;
        } else {
         $$0$i$i288 = $569;
        }
       } else {
        $572 = HEAP32[$562>>2]|0;
        $573 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($572)|0);
        $$0$i$i288 = $573;
       }
       $574 = HEAP32[$7>>2]|0;
       $575 = ((($574)) + 12|0);
       $576 = HEAP32[$575>>2]|0;
       __THREW__ = 0;
       $577 = (invoke_iiii($576|0,($7|0),2048,($$0$i$i288|0))|0);
       $578 = __THREW__; __THREW__ = 0;
       $579 = $578&1;
       if ($579) {
        label = 245;
        break L24;
       }
       if ($577) {
        $580 = HEAP32[$9>>2]|0;
        $581 = HEAP32[$11>>2]|0;
        $582 = ($580|0)==($581|0);
        if ($582) {
         __THREW__ = 0;
         invoke_viii(4729,($8|0),($9|0),($11|0));
         $583 = __THREW__; __THREW__ = 0;
         $584 = $583&1;
         if ($584) {
          label = 245;
          break L24;
         }
         $$pre513 = HEAP32[$9>>2]|0;
         $586 = $$pre513;
        } else {
         $586 = $580;
        }
        $585 = ((($586)) + 4|0);
        HEAP32[$9>>2] = $585;
        HEAP32[$586>>2] = $$0$i$i288;
        $587 = (($$0135) + 1)|0;
        $$2137$ph = $587;
       } else {
        $588 = HEAP8[$57>>0]|0;
        $589 = ($588<<24>>24)<(0);
        $590 = HEAP32[$58>>2]|0;
        $591 = $588&255;
        $592 = $589 ? $590 : $591;
        $593 = ($592|0)!=(0);
        $594 = ($$0135|0)!=(0);
        $or$cond13 = $594 & $593;
        $595 = HEAP32[$18>>2]|0;
        $596 = ($$0$i$i288|0)==($595|0);
        $or$cond167 = $596 & $or$cond13;
        if (!($or$cond167)) {
         $$pre$i4$i$i303 = $$pre$i4$i$i281511;
         break;
        }
        $597 = HEAP32[$14>>2]|0;
        $598 = HEAP32[$15>>2]|0;
        $599 = ($597|0)==($598|0);
        if ($599) {
         __THREW__ = 0;
         invoke_viii(4722,($13|0),($14|0),($15|0));
         $600 = __THREW__; __THREW__ = 0;
         $601 = $600&1;
         if ($601) {
          label = 245;
          break L24;
         }
         $$pre = HEAP32[$14>>2]|0;
         $603 = $$pre;
        } else {
         $603 = $597;
        }
        $602 = ((($603)) + 4|0);
        HEAP32[$14>>2] = $602;
        HEAP32[$603>>2] = $$0135;
        $$2137$ph = 0;
       }
       $604 = HEAP32[$0>>2]|0;
       $605 = ((($604)) + 12|0);
       $606 = HEAP32[$605>>2]|0;
       $607 = ((($604)) + 16|0);
       $608 = HEAP32[$607>>2]|0;
       $609 = ($606|0)==($608|0);
       if ($609) {
        $610 = HEAP32[$604>>2]|0;
        $611 = ((($610)) + 40|0);
        $612 = HEAP32[$611>>2]|0;
        __THREW__ = 0;
        (invoke_ii($612|0,($604|0))|0);
        $613 = __THREW__; __THREW__ = 0;
        $614 = $613&1;
        if ($614) {
         label = 245;
         break L24;
        } else {
         $$0135 = $$2137$ph;$$pre$i4$i$i281 = $$pre$i4$i$i281511;$542 = $903;
         continue;
        }
       } else {
        $615 = ((($606)) + 4|0);
        HEAP32[$605>>2] = $615;
        $616 = HEAP32[$606>>2]|0;
        (__ZNSt3__211char_traitsIwE11to_int_typeEw($616)|0);
        $$0135 = $$2137$ph;$$pre$i4$i$i281 = $$pre$i4$i$i281511;$542 = $903;
        continue;
       }
      }
      $617 = HEAP32[$13>>2]|0;
      $618 = HEAP32[$14>>2]|0;
      $619 = ($617|0)!=($618|0);
      $620 = ($$0135|0)!=(0);
      $or$cond15 = $620 & $619;
      if ($or$cond15) {
       $621 = HEAP32[$15>>2]|0;
       $622 = ($618|0)==($621|0);
       if ($622) {
        __THREW__ = 0;
        invoke_viii(4722,($13|0),($14|0),($15|0));
        $623 = __THREW__; __THREW__ = 0;
        $624 = $623&1;
        if ($624) {
         label = 245;
         break L24;
        }
        $$pre515 = HEAP32[$14>>2]|0;
        $626 = $$pre515;
       } else {
        $626 = $618;
       }
       $625 = ((($626)) + 4|0);
       HEAP32[$14>>2] = $625;
       HEAP32[$626>>2] = $$0135;
      }
      $627 = HEAP32[$24>>2]|0;
      $628 = ($627|0)>(0);
      L219: do {
       if ($628) {
        $629 = HEAP32[$0>>2]|0;
        $630 = ($629|0)==(0|0);
        do {
         if ($630) {
          $904 = 1;
         } else {
          $631 = ((($629)) + 12|0);
          $632 = HEAP32[$631>>2]|0;
          $633 = ((($629)) + 16|0);
          $634 = HEAP32[$633>>2]|0;
          $635 = ($632|0)==($634|0);
          if ($635) {
           $636 = HEAP32[$629>>2]|0;
           $637 = ((($636)) + 36|0);
           $638 = HEAP32[$637>>2]|0;
           __THREW__ = 0;
           $639 = (invoke_ii($638|0,($629|0))|0);
           $640 = __THREW__; __THREW__ = 0;
           $641 = $640&1;
           if ($641) {
            label = 245;
            break L24;
           } else {
            $$0$i$i$i$i295 = $639;
           }
          } else {
           $642 = HEAP32[$632>>2]|0;
           $643 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($642)|0);
           $$0$i$i$i$i295 = $643;
          }
          $644 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
          $645 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i$i$i295,$644)|0);
          if ($645) {
           HEAP32[$0>>2] = 0;
           $904 = 1;
           break;
          } else {
           $$pre$i$i$i297 = HEAP32[$0>>2]|0;
           $phitmp$i$i$i298 = ($$pre$i$i$i297|0)==(0|0);
           $904 = $phitmp$i$i$i298;
           break;
          }
         }
        } while(0);
        $646 = ($$pre$i4$i$i303|0)==(0|0);
        do {
         if ($646) {
          label = 205;
         } else {
          $647 = ((($$pre$i4$i$i303)) + 12|0);
          $648 = HEAP32[$647>>2]|0;
          $649 = ((($$pre$i4$i$i303)) + 16|0);
          $650 = HEAP32[$649>>2]|0;
          $651 = ($648|0)==($650|0);
          if ($651) {
           $652 = HEAP32[$$pre$i4$i$i303>>2]|0;
           $653 = ((($652)) + 36|0);
           $654 = HEAP32[$653>>2]|0;
           __THREW__ = 0;
           $655 = (invoke_ii($654|0,($$pre$i4$i$i303|0))|0);
           $656 = __THREW__; __THREW__ = 0;
           $657 = $656&1;
           if ($657) {
            label = 245;
            break L24;
           } else {
            $$0$i$i2$i$i301 = $655;
           }
          } else {
           $658 = HEAP32[$648>>2]|0;
           $659 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($658)|0);
           $$0$i$i2$i$i301 = $659;
          }
          $660 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
          $661 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i2$i$i301,$660)|0);
          if ($661) {
           HEAP32[$1>>2] = 0;
           label = 205;
           break;
          } else {
           if ($904) {
            $905 = $$pre$i4$i$i303;
            break;
           } else {
            label = 244;
            break L24;
           }
          }
         }
        } while(0);
        if ((label|0) == 205) {
         label = 0;
         if ($904) {
          label = 244;
          break L24;
         } else {
          $905 = 0;
         }
        }
        $662 = HEAP32[$0>>2]|0;
        $663 = ((($662)) + 12|0);
        $664 = HEAP32[$663>>2]|0;
        $665 = ((($662)) + 16|0);
        $666 = HEAP32[$665>>2]|0;
        $667 = ($664|0)==($666|0);
        if ($667) {
         $668 = HEAP32[$662>>2]|0;
         $669 = ((($668)) + 36|0);
         $670 = HEAP32[$669>>2]|0;
         __THREW__ = 0;
         $671 = (invoke_ii($670|0,($662|0))|0);
         $672 = __THREW__; __THREW__ = 0;
         $673 = $672&1;
         if ($673) {
          label = 245;
          break L24;
         } else {
          $$0$i$i309 = $671;
         }
        } else {
         $674 = HEAP32[$664>>2]|0;
         $675 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($674)|0);
         $$0$i$i309 = $675;
        }
        $676 = HEAP32[$17>>2]|0;
        $677 = ($$0$i$i309|0)==($676|0);
        if (!($677)) {
         label = 244;
         break L24;
        }
        $678 = HEAP32[$0>>2]|0;
        $679 = ((($678)) + 12|0);
        $680 = HEAP32[$679>>2]|0;
        $681 = ((($678)) + 16|0);
        $682 = HEAP32[$681>>2]|0;
        $683 = ($680|0)==($682|0);
        if ($683) {
         $684 = HEAP32[$678>>2]|0;
         $685 = ((($684)) + 40|0);
         $686 = HEAP32[$685>>2]|0;
         __THREW__ = 0;
         (invoke_ii($686|0,($678|0))|0);
         $687 = __THREW__; __THREW__ = 0;
         $688 = $687&1;
         if ($688) {
          label = 245;
          break L24;
         } else {
          $$pre$i4$i$i322 = $905;$710 = $905;
         }
        } else {
         $689 = ((($680)) + 4|0);
         HEAP32[$679>>2] = $689;
         $690 = HEAP32[$680>>2]|0;
         (__ZNSt3__211char_traitsIwE11to_int_typeEw($690)|0);
         $$pre$i4$i$i322 = $905;$710 = $905;
        }
        while(1) {
         $691 = HEAP32[$24>>2]|0;
         $692 = ($691|0)>(0);
         if (!($692)) {
          break L219;
         }
         $693 = HEAP32[$0>>2]|0;
         $694 = ($693|0)==(0|0);
         do {
          if ($694) {
           $727 = 1;
          } else {
           $695 = ((($693)) + 12|0);
           $696 = HEAP32[$695>>2]|0;
           $697 = ((($693)) + 16|0);
           $698 = HEAP32[$697>>2]|0;
           $699 = ($696|0)==($698|0);
           if ($699) {
            $700 = HEAP32[$693>>2]|0;
            $701 = ((($700)) + 36|0);
            $702 = HEAP32[$701>>2]|0;
            __THREW__ = 0;
            $703 = (invoke_ii($702|0,($693|0))|0);
            $704 = __THREW__; __THREW__ = 0;
            $705 = $704&1;
            if ($705) {
             label = 245;
             break L24;
            } else {
             $$0$i$i$i$i314 = $703;
            }
           } else {
            $706 = HEAP32[$696>>2]|0;
            $707 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($706)|0);
            $$0$i$i$i$i314 = $707;
           }
           $708 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
           $709 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i$i$i314,$708)|0);
           if ($709) {
            HEAP32[$0>>2] = 0;
            $727 = 1;
            break;
           } else {
            $$pre$i$i$i316 = HEAP32[$0>>2]|0;
            $phitmp$i$i$i317 = ($$pre$i$i$i316|0)==(0|0);
            $727 = $phitmp$i$i$i317;
            break;
           }
          }
         } while(0);
         $711 = ($710|0)==(0|0);
         do {
          if ($711) {
           $$pre$i4$i$i322516$ph = $$pre$i4$i$i322;
           label = 228;
          } else {
           $712 = ((($710)) + 12|0);
           $713 = HEAP32[$712>>2]|0;
           $714 = ((($710)) + 16|0);
           $715 = HEAP32[$714>>2]|0;
           $716 = ($713|0)==($715|0);
           if ($716) {
            $717 = HEAP32[$710>>2]|0;
            $718 = ((($717)) + 36|0);
            $719 = HEAP32[$718>>2]|0;
            __THREW__ = 0;
            $720 = (invoke_ii($719|0,($710|0))|0);
            $721 = __THREW__; __THREW__ = 0;
            $722 = $721&1;
            if ($722) {
             label = 245;
             break L24;
            } else {
             $$0$i$i2$i$i320 = $720;
            }
           } else {
            $723 = HEAP32[$713>>2]|0;
            $724 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($723)|0);
            $$0$i$i2$i$i320 = $724;
           }
           $725 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
           $726 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i2$i$i320,$725)|0);
           if ($726) {
            HEAP32[$1>>2] = 0;
            $$pre$i4$i$i322516$ph = 0;
            label = 228;
            break;
           } else {
            $phitmp$i5$i$i323 = ($$pre$i4$i$i322|0)==(0|0);
            $tmp$i$i325 = $727 ^ $phitmp$i5$i$i323;
            if ($tmp$i$i325) {
             $$pre$i4$i$i322516533 = $$pre$i4$i$i322;$906 = $$pre$i4$i$i322;
             break;
            } else {
             label = 244;
             break L24;
            }
           }
          }
         } while(0);
         if ((label|0) == 228) {
          label = 0;
          if ($727) {
           label = 244;
           break L24;
          } else {
           $$pre$i4$i$i322516533 = $$pre$i4$i$i322516$ph;$906 = 0;
          }
         }
         $728 = HEAP32[$0>>2]|0;
         $729 = ((($728)) + 12|0);
         $730 = HEAP32[$729>>2]|0;
         $731 = ((($728)) + 16|0);
         $732 = HEAP32[$731>>2]|0;
         $733 = ($730|0)==($732|0);
         if ($733) {
          $734 = HEAP32[$728>>2]|0;
          $735 = ((($734)) + 36|0);
          $736 = HEAP32[$735>>2]|0;
          __THREW__ = 0;
          $737 = (invoke_ii($736|0,($728|0))|0);
          $738 = __THREW__; __THREW__ = 0;
          $739 = $738&1;
          if ($739) {
           label = 245;
           break L24;
          } else {
           $$0$i$i329 = $737;
          }
         } else {
          $740 = HEAP32[$730>>2]|0;
          $741 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($740)|0);
          $$0$i$i329 = $741;
         }
         $742 = HEAP32[$7>>2]|0;
         $743 = ((($742)) + 12|0);
         $744 = HEAP32[$743>>2]|0;
         __THREW__ = 0;
         $745 = (invoke_iiii($744|0,($7|0),2048,($$0$i$i329|0))|0);
         $746 = __THREW__; __THREW__ = 0;
         $747 = $746&1;
         if ($747) {
          label = 245;
          break L24;
         }
         if (!($745)) {
          label = 244;
          break L24;
         }
         $748 = HEAP32[$9>>2]|0;
         $749 = HEAP32[$11>>2]|0;
         $750 = ($748|0)==($749|0);
         if ($750) {
          __THREW__ = 0;
          invoke_viii(4729,($8|0),($9|0),($11|0));
          $751 = __THREW__; __THREW__ = 0;
          $752 = $751&1;
          if ($752) {
           label = 245;
           break L24;
          }
         }
         $753 = HEAP32[$0>>2]|0;
         $754 = ((($753)) + 12|0);
         $755 = HEAP32[$754>>2]|0;
         $756 = ((($753)) + 16|0);
         $757 = HEAP32[$756>>2]|0;
         $758 = ($755|0)==($757|0);
         if ($758) {
          $759 = HEAP32[$753>>2]|0;
          $760 = ((($759)) + 36|0);
          $761 = HEAP32[$760>>2]|0;
          __THREW__ = 0;
          $762 = (invoke_ii($761|0,($753|0))|0);
          $763 = __THREW__; __THREW__ = 0;
          $764 = $763&1;
          if ($764) {
           label = 245;
           break L24;
          } else {
           $$0$i$i334 = $762;
          }
         } else {
          $765 = HEAP32[$755>>2]|0;
          $766 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($765)|0);
          $$0$i$i334 = $766;
         }
         $767 = HEAP32[$9>>2]|0;
         $768 = ((($767)) + 4|0);
         HEAP32[$9>>2] = $768;
         HEAP32[$767>>2] = $$0$i$i334;
         $769 = HEAP32[$24>>2]|0;
         $770 = (($769) + -1)|0;
         HEAP32[$24>>2] = $770;
         $771 = HEAP32[$0>>2]|0;
         $772 = ((($771)) + 12|0);
         $773 = HEAP32[$772>>2]|0;
         $774 = ((($771)) + 16|0);
         $775 = HEAP32[$774>>2]|0;
         $776 = ($773|0)==($775|0);
         if ($776) {
          $777 = HEAP32[$771>>2]|0;
          $778 = ((($777)) + 40|0);
          $779 = HEAP32[$778>>2]|0;
          __THREW__ = 0;
          (invoke_ii($779|0,($771|0))|0);
          $780 = __THREW__; __THREW__ = 0;
          $781 = $780&1;
          if ($781) {
           label = 245;
           break L24;
          } else {
           $$pre$i4$i$i322 = $$pre$i4$i$i322516533;$710 = $906;
           continue;
          }
         } else {
          $782 = ((($773)) + 4|0);
          HEAP32[$772>>2] = $782;
          $783 = HEAP32[$773>>2]|0;
          (__ZNSt3__211char_traitsIwE11to_int_typeEw($783)|0);
          $$pre$i4$i$i322 = $$pre$i4$i$i322516533;$710 = $906;
          continue;
         }
        }
       }
      } while(0);
      $784 = HEAP32[$9>>2]|0;
      $785 = HEAP32[$8>>2]|0;
      $786 = ($784|0)==($785|0);
      if ($786) {
       label = 244;
       break L24;
      } else {
       $$1153 = $$0152;
      }
      break;
     }
     default: {
      $$1153 = $$0152;
     }
     }
    } while(0);
    L293: do {
     if ((label|0) == 49) {
      while(1) {
       label = 0;
       $142 = HEAP32[$0>>2]|0;
       $143 = ($142|0)==(0|0);
       do {
        if ($143) {
         $176 = 1;
        } else {
         $144 = ((($142)) + 12|0);
         $145 = HEAP32[$144>>2]|0;
         $146 = ((($142)) + 16|0);
         $147 = HEAP32[$146>>2]|0;
         $148 = ($145|0)==($147|0);
         if ($148) {
          $149 = HEAP32[$142>>2]|0;
          $150 = ((($149)) + 36|0);
          $151 = HEAP32[$150>>2]|0;
          __THREW__ = 0;
          $152 = (invoke_ii($151|0,($142|0))|0);
          $153 = __THREW__; __THREW__ = 0;
          $154 = $153&1;
          if ($154) {
           label = 35;
           break L24;
          } else {
           $$0$i$i$i$i189 = $152;
          }
         } else {
          $155 = HEAP32[$145>>2]|0;
          $156 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($155)|0);
          $$0$i$i$i$i189 = $156;
         }
         $157 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
         $158 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i$i$i189,$157)|0);
         if ($158) {
          HEAP32[$0>>2] = 0;
          $176 = 1;
          break;
         } else {
          $$pre$i$i$i191 = HEAP32[$0>>2]|0;
          $phitmp$i$i$i192 = ($$pre$i$i$i191|0)==(0|0);
          $176 = $phitmp$i$i$i192;
          break;
         }
        }
       } while(0);
       $160 = ($159|0)==(0|0);
       do {
        if ($160) {
         $$pre$i4$i$i197527 = $$pre$i4$i$i197;
         label = 62;
        } else {
         $161 = ((($159)) + 12|0);
         $162 = HEAP32[$161>>2]|0;
         $163 = ((($159)) + 16|0);
         $164 = HEAP32[$163>>2]|0;
         $165 = ($162|0)==($164|0);
         if ($165) {
          $166 = HEAP32[$159>>2]|0;
          $167 = ((($166)) + 36|0);
          $168 = HEAP32[$167>>2]|0;
          __THREW__ = 0;
          $169 = (invoke_ii($168|0,($159|0))|0);
          $170 = __THREW__; __THREW__ = 0;
          $171 = $170&1;
          if ($171) {
           label = 35;
           break L24;
          } else {
           $$0$i$i2$i$i195 = $169;
          }
         } else {
          $172 = HEAP32[$162>>2]|0;
          $173 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($172)|0);
          $$0$i$i2$i$i195 = $173;
         }
         $174 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
         $175 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i2$i$i195,$174)|0);
         if ($175) {
          HEAP32[$1>>2] = 0;
          $$pre$i4$i$i197527 = 0;
          label = 62;
          break;
         } else {
          $phitmp$i5$i$i198 = ($$pre$i4$i$i197|0)==(0|0);
          $tmp$i$i200 = $176 ^ $phitmp$i5$i$i198;
          if ($tmp$i$i200) {
           $$pre$i4$i$i197529 = $$pre$i4$i$i197;$901 = $$pre$i4$i$i197;
           break;
          } else {
           $$1153 = $$0152;
           break L293;
          }
         }
        }
       } while(0);
       if ((label|0) == 62) {
        label = 0;
        if ($176) {
         $$1153 = $$0152;
         break L293;
        } else {
         $$pre$i4$i$i197529 = $$pre$i4$i$i197527;$901 = 0;
        }
       }
       $177 = HEAP32[$0>>2]|0;
       $178 = ((($177)) + 12|0);
       $179 = HEAP32[$178>>2]|0;
       $180 = ((($177)) + 16|0);
       $181 = HEAP32[$180>>2]|0;
       $182 = ($179|0)==($181|0);
       if ($182) {
        $183 = HEAP32[$177>>2]|0;
        $184 = ((($183)) + 36|0);
        $185 = HEAP32[$184>>2]|0;
        __THREW__ = 0;
        $186 = (invoke_ii($185|0,($177|0))|0);
        $187 = __THREW__; __THREW__ = 0;
        $188 = $187&1;
        if ($188) {
         label = 35;
         break L24;
        } else {
         $$0$i$i204 = $186;
        }
       } else {
        $189 = HEAP32[$179>>2]|0;
        $190 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($189)|0);
        $$0$i$i204 = $190;
       }
       $191 = HEAP32[$7>>2]|0;
       $192 = ((($191)) + 12|0);
       $193 = HEAP32[$192>>2]|0;
       __THREW__ = 0;
       $194 = (invoke_iiii($193|0,($7|0),8192,($$0$i$i204|0))|0);
       $195 = __THREW__; __THREW__ = 0;
       $196 = $195&1;
       if ($196) {
        label = 35;
        break L24;
       }
       if (!($194)) {
        $$1153 = $$0152;
        break L293;
       }
       $197 = HEAP32[$0>>2]|0;
       $198 = ((($197)) + 12|0);
       $199 = HEAP32[$198>>2]|0;
       $200 = ((($197)) + 16|0);
       $201 = HEAP32[$200>>2]|0;
       $202 = ($199|0)==($201|0);
       if ($202) {
        $203 = HEAP32[$197>>2]|0;
        $204 = ((($203)) + 40|0);
        $205 = HEAP32[$204>>2]|0;
        __THREW__ = 0;
        $206 = (invoke_ii($205|0,($197|0))|0);
        $207 = __THREW__; __THREW__ = 0;
        $208 = $207&1;
        if ($208) {
         label = 35;
         break L24;
        } else {
         $$0$i$i209 = $206;
        }
       } else {
        $209 = ((($199)) + 4|0);
        HEAP32[$198>>2] = $209;
        $210 = HEAP32[$199>>2]|0;
        $211 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($210)|0);
        $$0$i$i209 = $211;
       }
       __THREW__ = 0;
       invoke_vii(4726,($23|0),($$0$i$i209|0));
       $212 = __THREW__; __THREW__ = 0;
       $213 = $212&1;
       if ($213) {
        label = 35;
        break L24;
       } else {
        $$pre$i4$i$i197 = $$pre$i4$i$i197529;$159 = $901;
        label = 49;
       }
      }
     }
    } while(0);
    $791 = (($$0161) + 1)|0;
    $$0152 = $$1153;$$0161 = $791;
   }
   L329:    switch (label|0) {
    case 35: {
     $97 = ___cxa_find_matching_catch_2()|0;
     $98 = tempRet0;
     $$5145 = $97;$$5151 = $98;
     break L21;
     break;
    }
    case 47: {
     $140 = HEAP32[$5>>2]|0;
     $141 = $140 | 4;
     HEAP32[$5>>2] = $141;
     $$10 = 0;
     break;
    }
    case 109: {
     $372 = HEAP32[$5>>2]|0;
     $373 = $372 | 4;
     HEAP32[$5>>2] = $373;
     $$10 = 0;
     break;
    }
    case 119: {
     $407 = ___cxa_find_matching_catch_2()|0;
     $408 = tempRet0;
     $$5145 = $407;$$5151 = $408;
     break L21;
     break;
    }
    case 149: {
     $510 = ___cxa_find_matching_catch_2()|0;
     $511 = tempRet0;
     $$5145 = $510;$$5151 = $511;
     break L21;
     break;
    }
    case 150: {
     $512 = ___cxa_find_matching_catch_2()|0;
     $513 = tempRet0;
     $$5145 = $512;$$5151 = $513;
     break L21;
     break;
    }
    case 153: {
     $523 = HEAP32[$5>>2]|0;
     $524 = $523 | 4;
     HEAP32[$5>>2] = $524;
     $$10 = 0;
     break;
    }
    case 244: {
     $787 = HEAP32[$5>>2]|0;
     $788 = $787 | 4;
     HEAP32[$5>>2] = $788;
     $$10 = 0;
     break;
    }
    case 245: {
     $789 = ___cxa_find_matching_catch_2()|0;
     $790 = tempRet0;
     $$5145 = $789;$$5151 = $790;
     break L21;
     break;
    }
    case 247: {
     L331: do {
      if ($60) {
       $792 = ((($$0152)) + 8|0);
       $793 = ((($792)) + 3|0);
       $794 = ((($$0152)) + 4|0);
       $$0 = 1;
       L333: while(1) {
        $795 = HEAP8[$793>>0]|0;
        $796 = ($795<<24>>24)<(0);
        if ($796) {
         $797 = HEAP32[$794>>2]|0;
         $800 = $797;
        } else {
         $798 = $795&255;
         $800 = $798;
        }
        $799 = ($$0>>>0)<($800>>>0);
        if (!($799)) {
         break L331;
        }
        $801 = HEAP32[$0>>2]|0;
        $802 = ($801|0)==(0|0);
        do {
         if ($802) {
          $907 = 1;
         } else {
          $803 = ((($801)) + 12|0);
          $804 = HEAP32[$803>>2]|0;
          $805 = ((($801)) + 16|0);
          $806 = HEAP32[$805>>2]|0;
          $807 = ($804|0)==($806|0);
          if ($807) {
           $808 = HEAP32[$801>>2]|0;
           $809 = ((($808)) + 36|0);
           $810 = HEAP32[$809>>2]|0;
           __THREW__ = 0;
           $811 = (invoke_ii($810|0,($801|0))|0);
           $812 = __THREW__; __THREW__ = 0;
           $813 = $812&1;
           if ($813) {
            label = 275;
            break L333;
           } else {
            $$0$i$i$i$i340 = $811;
           }
          } else {
           $814 = HEAP32[$804>>2]|0;
           $815 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($814)|0);
           $$0$i$i$i$i340 = $815;
          }
          $816 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
          $817 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i$i$i340,$816)|0);
          if ($817) {
           HEAP32[$0>>2] = 0;
           $907 = 1;
           break;
          } else {
           $$pre$i$i$i342 = HEAP32[$0>>2]|0;
           $phitmp$i$i$i343 = ($$pre$i$i$i342|0)==(0|0);
           $907 = $phitmp$i$i$i343;
           break;
          }
         }
        } while(0);
        $818 = HEAP32[$1>>2]|0;
        $819 = ($818|0)==(0|0);
        do {
         if ($819) {
          label = 266;
         } else {
          $820 = ((($818)) + 12|0);
          $821 = HEAP32[$820>>2]|0;
          $822 = ((($818)) + 16|0);
          $823 = HEAP32[$822>>2]|0;
          $824 = ($821|0)==($823|0);
          if ($824) {
           $825 = HEAP32[$818>>2]|0;
           $826 = ((($825)) + 36|0);
           $827 = HEAP32[$826>>2]|0;
           __THREW__ = 0;
           $828 = (invoke_ii($827|0,($818|0))|0);
           $829 = __THREW__; __THREW__ = 0;
           $830 = $829&1;
           if ($830) {
            label = 275;
            break L333;
           } else {
            $$0$i$i2$i$i346 = $828;
           }
          } else {
           $831 = HEAP32[$821>>2]|0;
           $832 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($831)|0);
           $$0$i$i2$i$i346 = $832;
          }
          $833 = (__ZNSt3__211char_traitsIwE3eofEv()|0);
          $834 = (__ZNSt3__211char_traitsIwE11eq_int_typeEjj($$0$i$i2$i$i346,$833)|0);
          if ($834) {
           HEAP32[$1>>2] = 0;
           label = 266;
           break;
          } else {
           if ($907) {
            break;
           } else {
            label = 274;
            break L333;
           }
          }
         }
        } while(0);
        if ((label|0) == 266) {
         label = 0;
         if ($907) {
          label = 274;
          break;
         }
        }
        $835 = HEAP32[$0>>2]|0;
        $836 = ((($835)) + 12|0);
        $837 = HEAP32[$836>>2]|0;
        $838 = ((($835)) + 16|0);
        $839 = HEAP32[$838>>2]|0;
        $840 = ($837|0)==($839|0);
        if ($840) {
         $841 = HEAP32[$835>>2]|0;
         $842 = ((($841)) + 36|0);
         $843 = HEAP32[$842>>2]|0;
         __THREW__ = 0;
         $844 = (invoke_ii($843|0,($835|0))|0);
         $845 = __THREW__; __THREW__ = 0;
         $846 = $845&1;
         if ($846) {
          label = 275;
          break;
         } else {
          $$0$i$i355 = $844;
         }
        } else {
         $847 = HEAP32[$837>>2]|0;
         $848 = (__ZNSt3__211char_traitsIwE11to_int_typeEw($847)|0);
         $$0$i$i355 = $848;
        }
        $849 = HEAP8[$793>>0]|0;
        $850 = ($849<<24>>24)<(0);
        if ($850) {
         $851 = HEAP32[$$0152>>2]|0;
         $853 = $851;
        } else {
         $853 = $$0152;
        }
        $852 = (($853) + ($$0<<2)|0);
        $854 = HEAP32[$852>>2]|0;
        $855 = ($$0$i$i355|0)==($854|0);
        if (!($855)) {
         label = 274;
         break;
        }
        $860 = (($$0) + 1)|0;
        $861 = HEAP32[$0>>2]|0;
        $862 = ((($861)) + 12|0);
        $863 = HEAP32[$862>>2]|0;
        $864 = ((($861)) + 16|0);
        $865 = HEAP32[$864>>2]|0;
        $866 = ($863|0)==($865|0);
        if ($866) {
         $867 = HEAP32[$861>>2]|0;
         $868 = ((($867)) + 40|0);
         $869 = HEAP32[$868>>2]|0;
         __THREW__ = 0;
         (invoke_ii($869|0,($861|0))|0);
         $870 = __THREW__; __THREW__ = 0;
         $871 = $870&1;
         if ($871) {
          label = 275;
          break;
         } else {
          $$0 = $860;
          continue;
         }
        } else {
         $872 = ((($863)) + 4|0);
         HEAP32[$862>>2] = $872;
         $873 = HEAP32[$863>>2]|0;
         (__ZNSt3__211char_traitsIwE11to_int_typeEw($873)|0);
         $$0 = $860;
         continue;
        }
       }
       if ((label|0) == 274) {
        $856 = HEAP32[$5>>2]|0;
        $857 = $856 | 4;
        HEAP32[$5>>2] = $857;
        $$10 = 0;
        break L329;
       }
       else if ((label|0) == 275) {
        $858 = ___cxa_find_matching_catch_2()|0;
        $859 = tempRet0;
        $$5145 = $858;$$5151 = $859;
        break L21;
       }
      }
     } while(0);
     $874 = HEAP32[$13>>2]|0;
     $875 = HEAP32[$14>>2]|0;
     $876 = ($874|0)==($875|0);
     if ($876) {
      $$10 = 1;
     } else {
      HEAP32[$25>>2] = 0;
      __THREW__ = 0;
      invoke_viiii(4676,($19|0),($874|0),($875|0),($25|0));
      $877 = __THREW__; __THREW__ = 0;
      $878 = $877&1;
      if ($878) {
       $883 = ___cxa_find_matching_catch_2()|0;
       $884 = tempRet0;
       $$5145 = $883;$$5151 = $884;
       break L21;
      }
      $879 = HEAP32[$25>>2]|0;
      $880 = ($879|0)==(0);
      if ($880) {
       $$10 = 1;
       break;
      } else {
       $881 = HEAP32[$5>>2]|0;
       $882 = $881 | 4;
       HEAP32[$5>>2] = $882;
       $$10 = 0;
       break;
      }
     }
     break;
    }
   }
   __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev($23);
   __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev($22);
   __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev($21);
   __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev($20);
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($19);
   $885 = HEAP32[$13>>2]|0;
   HEAP32[$13>>2] = 0;
   $886 = ($885|0)==(0|0);
   if (!($886)) {
    $887 = HEAP32[$27>>2]|0;
    __THREW__ = 0;
    invoke_vi($887|0,($885|0));
    $888 = __THREW__; __THREW__ = 0;
    $889 = $888&1;
    if ($889) {
     $890 = ___cxa_find_matching_catch_3(0|0)|0;
     $891 = tempRet0;
     ___clang_call_terminate($890);
     // unreachable;
    }
   }
   STACKTOP = sp;return ($$10|0);
  }
 } while(0);
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev($23);
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev($22);
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev($21);
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev($20);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($19);
 $892 = HEAP32[$13>>2]|0;
 HEAP32[$13>>2] = 0;
 $893 = ($892|0)==(0|0);
 if (!($893)) {
  $894 = HEAP32[$27>>2]|0;
  __THREW__ = 0;
  invoke_vi($894|0,($892|0));
  $895 = __THREW__; __THREW__ = 0;
  $896 = $895&1;
  if ($896) {
   $897 = ___cxa_find_matching_catch_3(0|0)|0;
   $898 = tempRet0;
   ___clang_call_terminate($897);
   // unreachable;
  }
 }
 ___resumeException($$5145|0);
 // unreachable;
 return (0)|0;
}
function __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE23__append_forward_unsafeIPwEERS5_T_S9_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$0$i$i = 0, $$021$i$i = 0, $$040 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $9 = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $3 = sp + 16|0;
 $4 = sp + 4|0;
 $5 = sp;
 $6 = ((($0)) + 8|0);
 $7 = ((($6)) + 3|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = ($8<<24>>24)<(0);
 if ($9) {
  $11 = ((($0)) + 4|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = HEAP32[$6>>2]|0;
  $14 = $13 & 2147483647;
  $phitmp$i = (($14) + -1)|0;
  $65 = $12;$66 = $phitmp$i;
 } else {
  $10 = $8&255;
  $65 = $10;$66 = 1;
 }
 $15 = $2;
 $16 = $1;
 $17 = (($15) - ($16))|0;
 $18 = $17 >> 2;
 $19 = ($18|0)==(0);
 do {
  if (!($19)) {
   if ($9) {
    $20 = HEAP32[$0>>2]|0;
    $21 = ((($0)) + 4|0);
    $22 = HEAP32[$21>>2]|0;
    $25 = $20;$26 = $22;$27 = $20;
   } else {
    $23 = $8&255;
    $25 = $0;$26 = $23;$27 = $0;
   }
   $24 = (($25) + ($26<<2)|0);
   $28 = (__ZNSt3__214__ptr_in_rangeIwEEbPKT_S3_S3_($1,$27,$24)|0);
   if (!($28)) {
    $64 = (($66) - ($65))|0;
    $67 = ($64>>>0)<($18>>>0);
    $68 = (($65) + ($18))|0;
    if ($67) {
     $69 = (($68) - ($66))|0;
     __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE9__grow_byEjjjjjj($0,$66,$69,$65,$65,0,0);
    }
    $70 = HEAP8[$7>>0]|0;
    $71 = ($70<<24>>24)<(0);
    if ($71) {
     $72 = HEAP32[$0>>2]|0;
     $74 = $72;
    } else {
     $74 = $0;
    }
    $73 = (($74) + ($65<<2)|0);
    $$0 = $73;$$040 = $1;
    while(1) {
     $75 = ($$040|0)==($2|0);
     if ($75) {
      break;
     }
     __ZNSt3__211char_traitsIwE6assignERwRKw($$0,$$040);
     $76 = ((($$0)) + 4|0);
     $77 = ((($$040)) + 4|0);
     $$0 = $76;$$040 = $77;
    }
    HEAP32[$5>>2] = 0;
    __ZNSt3__211char_traitsIwE6assignERwRKw($$0,$5);
    $78 = HEAP8[$7>>0]|0;
    $79 = ($78<<24>>24)<(0);
    if ($79) {
     $80 = ((($0)) + 4|0);
     HEAP32[$80>>2] = $68;
     break;
    } else {
     $81 = $68&255;
     HEAP8[$7>>0] = $81;
     break;
    }
   }
   ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;
   $29 = ($18>>>0)>(1073741807);
   if ($29) {
    __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv($4);
    // unreachable;
   }
   $30 = ($18>>>0)<(2);
   do {
    if ($30) {
     $31 = $18&255;
     $32 = ((($4)) + 8|0);
     $33 = ((($32)) + 3|0);
     HEAP8[$33>>0] = $31;
     $$0$i$i = $1;$$021$i$i = $4;
    } else {
     $34 = (($18) + 4)|0;
     $35 = $34 & -4;
     $36 = ($35>>>0)>(1073741823);
     if (!($36)) {
      $42 = $35 << 2;
      $43 = (__Znwj($42)|0);
      HEAP32[$4>>2] = $43;
      $44 = $35 | -2147483648;
      $45 = ((($4)) + 8|0);
      HEAP32[$45>>2] = $44;
      $46 = ((($4)) + 4|0);
      HEAP32[$46>>2] = $18;
      $$0$i$i = $1;$$021$i$i = $43;
      break;
     }
     $37 = (___cxa_allocate_exception(8)|0);
     __THREW__ = 0;
     invoke_vii(3366,($37|0),(204840|0));
     $38 = __THREW__; __THREW__ = 0;
     $39 = $38&1;
     if ($39) {
      $40 = ___cxa_find_matching_catch_2()|0;
      $41 = tempRet0;
      ___cxa_free_exception(($37|0));
      ___resumeException($40|0);
      // unreachable;
     } else {
      HEAP32[$37>>2] = (99824);
      ___cxa_throw(($37|0),(34608|0),(3230|0));
      // unreachable;
     }
    }
   } while(0);
   while(1) {
    $47 = ($$0$i$i|0)==($2|0);
    if ($47) {
     break;
    }
    __ZNSt3__211char_traitsIwE6assignERwRKw($$021$i$i,$$0$i$i);
    $48 = ((($$0$i$i)) + 4|0);
    $49 = ((($$021$i$i)) + 4|0);
    $$0$i$i = $48;$$021$i$i = $49;
   }
   HEAP32[$3>>2] = 0;
   __ZNSt3__211char_traitsIwE6assignERwRKw($$021$i$i,$3);
   $50 = ((($4)) + 8|0);
   $51 = ((($50)) + 3|0);
   $52 = HEAP8[$51>>0]|0;
   $53 = ($52<<24>>24)<(0);
   $54 = HEAP32[$4>>2]|0;
   $55 = $53 ? $54 : $4;
   $56 = ((($4)) + 4|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = $52&255;
   $59 = $53 ? $57 : $58;
   __THREW__ = 0;
   (invoke_iiii(4730,($0|0),($55|0),($59|0))|0);
   $60 = __THREW__; __THREW__ = 0;
   $61 = $60&1;
   if ($61) {
    $62 = ___cxa_find_matching_catch_2()|0;
    $63 = tempRet0;
    __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev($4);
    ___resumeException($62|0);
    // unreachable;
   } else {
    __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev($4);
    break;
   }
  }
 } while(0);
 STACKTOP = sp;return ($0|0);
}
function __ZNSt3__214__ptr_in_rangeIwEEbPKT_S3_S3_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$ = 0, $3 = 0, $not$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($0>>>0)<($2>>>0);
 $not$ = ($1>>>0)<=($0>>>0);
 $$ = $not$ & $3;
 return ($$|0);
}
function __ZNSt3__211__money_getIwE13__gather_infoEbRKNS_6localeERNS_10money_base7patternERwS8_RNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERNS9_IwNSA_IwEENSC_IwEEEESJ_SJ_Ri($0,$1,$2,$3,$4,$5,$6,$7,$8,$9) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 $8 = $8|0;
 $9 = $9|0;
 var $$0$i$i$i = 0, $$0$i$i$i40 = 0, $$0$i$i$i43 = 0, $$0$i$i$i47 = 0, $$0$i$i$i52 = 0, $$0$i$i$i57 = 0, $$0$i$i$i62 = 0, $$0$i$i$i67 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0;
 var $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0;
 var $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i$i$i = 0, $exitcond$i$i$i41 = 0, $exitcond$i$i$i44 = 0, $exitcond$i$i$i48 = 0, $exitcond$i$i$i53 = 0, $exitcond$i$i$i58 = 0, $exitcond$i$i$i63 = 0, $exitcond$i$i$i68 = 0, $storemerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(160|0);
 $10 = sp + 148|0;
 $11 = sp + 144|0;
 $12 = sp + 155|0;
 $13 = sp + 154|0;
 $14 = sp + 140|0;
 $15 = sp + 136|0;
 $16 = sp + 132|0;
 $17 = sp + 128|0;
 $18 = sp + 124|0;
 $19 = sp + 120|0;
 $20 = sp + 153|0;
 $21 = sp + 152|0;
 $22 = sp + 116|0;
 $23 = sp + 112|0;
 $24 = sp + 108|0;
 $25 = sp + 104|0;
 $26 = sp + 100|0;
 $27 = sp + 88|0;
 $28 = sp + 76|0;
 $29 = sp + 64|0;
 $30 = sp + 52|0;
 $31 = sp + 48|0;
 $32 = sp + 36|0;
 $33 = sp + 24|0;
 $34 = sp + 12|0;
 $35 = sp;
 if ($0) {
  $36 = (__ZNKSt3__26locale9use_facetERNS0_2idE($1,216924)|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = ((($37)) + 44|0);
  $39 = HEAP32[$38>>2]|0;
  FUNCTION_TABLE_vii[$39 & 8191]($26,$36);
  $40 = HEAP32[$26>>2]|0;
  HEAP8[$2>>0]=$40&255;HEAP8[$2+1>>0]=($40>>8)&255;HEAP8[$2+2>>0]=($40>>16)&255;HEAP8[$2+3>>0]=$40>>24;
  $41 = HEAP32[$36>>2]|0;
  $42 = ((($41)) + 32|0);
  $43 = HEAP32[$42>>2]|0;
  FUNCTION_TABLE_vii[$43 & 8191]($27,$36);
  $44 = ((($8)) + 8|0);
  $45 = ((($44)) + 3|0);
  $46 = HEAP8[$45>>0]|0;
  $47 = ($46<<24>>24)<(0);
  if ($47) {
   $48 = HEAP32[$8>>2]|0;
   HEAP32[$24>>2] = 0;
   __ZNSt3__211char_traitsIwE6assignERwRKw($48,$24);
   $49 = ((($8)) + 4|0);
   HEAP32[$49>>2] = 0;
  } else {
   HEAP32[$25>>2] = 0;
   __ZNSt3__211char_traitsIwE6assignERwRKw($8,$25);
   HEAP8[$45>>0] = 0;
  }
  __THREW__ = 0;
  invoke_vii(4731,($8|0),0);
  $50 = __THREW__; __THREW__ = 0;
  $51 = $50&1;
  if ($51) {
   $52 = ___cxa_find_matching_catch_3(0|0)|0;
   $53 = tempRet0;
   ___clang_call_terminate($52);
   // unreachable;
  }
  ;HEAP32[$8>>2]=HEAP32[$27>>2]|0;HEAP32[$8+4>>2]=HEAP32[$27+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$27+8>>2]|0;
  $$0$i$i$i = 0;
  while(1) {
   $exitcond$i$i$i = ($$0$i$i$i|0)==(3);
   if ($exitcond$i$i$i) {
    break;
   }
   $54 = (($27) + ($$0$i$i$i<<2)|0);
   HEAP32[$54>>2] = 0;
   $55 = (($$0$i$i$i) + 1)|0;
   $$0$i$i$i = $55;
  }
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev($27);
  $56 = HEAP32[$36>>2]|0;
  $57 = ((($56)) + 28|0);
  $58 = HEAP32[$57>>2]|0;
  FUNCTION_TABLE_vii[$58 & 8191]($28,$36);
  $59 = ((($7)) + 8|0);
  $60 = ((($59)) + 3|0);
  $61 = HEAP8[$60>>0]|0;
  $62 = ($61<<24>>24)<(0);
  if ($62) {
   $63 = HEAP32[$7>>2]|0;
   HEAP32[$22>>2] = 0;
   __ZNSt3__211char_traitsIwE6assignERwRKw($63,$22);
   $64 = ((($7)) + 4|0);
   HEAP32[$64>>2] = 0;
  } else {
   HEAP32[$23>>2] = 0;
   __ZNSt3__211char_traitsIwE6assignERwRKw($7,$23);
   HEAP8[$60>>0] = 0;
  }
  __THREW__ = 0;
  invoke_vii(4731,($7|0),0);
  $65 = __THREW__; __THREW__ = 0;
  $66 = $65&1;
  if ($66) {
   $67 = ___cxa_find_matching_catch_3(0|0)|0;
   $68 = tempRet0;
   ___clang_call_terminate($67);
   // unreachable;
  }
  ;HEAP32[$7>>2]=HEAP32[$28>>2]|0;HEAP32[$7+4>>2]=HEAP32[$28+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[$28+8>>2]|0;
  $$0$i$i$i40 = 0;
  while(1) {
   $exitcond$i$i$i41 = ($$0$i$i$i40|0)==(3);
   if ($exitcond$i$i$i41) {
    break;
   }
   $69 = (($28) + ($$0$i$i$i40<<2)|0);
   HEAP32[$69>>2] = 0;
   $70 = (($$0$i$i$i40) + 1)|0;
   $$0$i$i$i40 = $70;
  }
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev($28);
  $71 = HEAP32[$36>>2]|0;
  $72 = ((($71)) + 12|0);
  $73 = HEAP32[$72>>2]|0;
  $74 = (FUNCTION_TABLE_ii[$73 & 8191]($36)|0);
  HEAP32[$3>>2] = $74;
  $75 = HEAP32[$36>>2]|0;
  $76 = ((($75)) + 16|0);
  $77 = HEAP32[$76>>2]|0;
  $78 = (FUNCTION_TABLE_ii[$77 & 8191]($36)|0);
  HEAP32[$4>>2] = $78;
  $79 = HEAP32[$36>>2]|0;
  $80 = ((($79)) + 20|0);
  $81 = HEAP32[$80>>2]|0;
  FUNCTION_TABLE_vii[$81 & 8191]($29,$36);
  $82 = ((($5)) + 11|0);
  $83 = HEAP8[$82>>0]|0;
  $84 = ($83<<24>>24)<(0);
  if ($84) {
   $85 = HEAP32[$5>>2]|0;
   HEAP8[$20>>0] = 0;
   __ZNSt3__211char_traitsIcE6assignERcRKc($85,$20);
   $86 = ((($5)) + 4|0);
   HEAP32[$86>>2] = 0;
  } else {
   HEAP8[$21>>0] = 0;
   __ZNSt3__211char_traitsIcE6assignERcRKc($5,$21);
   HEAP8[$82>>0] = 0;
  }
  __THREW__ = 0;
  invoke_vii(4723,($5|0),0);
  $87 = __THREW__; __THREW__ = 0;
  $88 = $87&1;
  if ($88) {
   $89 = ___cxa_find_matching_catch_3(0|0)|0;
   $90 = tempRet0;
   ___clang_call_terminate($89);
   // unreachable;
  }
  ;HEAP32[$5>>2]=HEAP32[$29>>2]|0;HEAP32[$5+4>>2]=HEAP32[$29+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$29+8>>2]|0;
  $$0$i$i$i43 = 0;
  while(1) {
   $exitcond$i$i$i44 = ($$0$i$i$i43|0)==(3);
   if ($exitcond$i$i$i44) {
    break;
   }
   $91 = (($29) + ($$0$i$i$i43<<2)|0);
   HEAP32[$91>>2] = 0;
   $92 = (($$0$i$i$i43) + 1)|0;
   $$0$i$i$i43 = $92;
  }
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($29);
  $93 = HEAP32[$36>>2]|0;
  $94 = ((($93)) + 24|0);
  $95 = HEAP32[$94>>2]|0;
  FUNCTION_TABLE_vii[$95 & 8191]($30,$36);
  $96 = ((($6)) + 8|0);
  $97 = ((($96)) + 3|0);
  $98 = HEAP8[$97>>0]|0;
  $99 = ($98<<24>>24)<(0);
  if ($99) {
   $100 = HEAP32[$6>>2]|0;
   HEAP32[$18>>2] = 0;
   __ZNSt3__211char_traitsIwE6assignERwRKw($100,$18);
   $101 = ((($6)) + 4|0);
   HEAP32[$101>>2] = 0;
  } else {
   HEAP32[$19>>2] = 0;
   __ZNSt3__211char_traitsIwE6assignERwRKw($6,$19);
   HEAP8[$97>>0] = 0;
  }
  __THREW__ = 0;
  invoke_vii(4731,($6|0),0);
  $102 = __THREW__; __THREW__ = 0;
  $103 = $102&1;
  if ($103) {
   $104 = ___cxa_find_matching_catch_3(0|0)|0;
   $105 = tempRet0;
   ___clang_call_terminate($104);
   // unreachable;
  }
  ;HEAP32[$6>>2]=HEAP32[$30>>2]|0;HEAP32[$6+4>>2]=HEAP32[$30+4>>2]|0;HEAP32[$6+8>>2]=HEAP32[$30+8>>2]|0;
  $$0$i$i$i47 = 0;
  while(1) {
   $exitcond$i$i$i48 = ($$0$i$i$i47|0)==(3);
   if ($exitcond$i$i$i48) {
    break;
   }
   $106 = (($30) + ($$0$i$i$i47<<2)|0);
   HEAP32[$106>>2] = 0;
   $107 = (($$0$i$i$i47) + 1)|0;
   $$0$i$i$i47 = $107;
  }
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev($30);
  $108 = HEAP32[$36>>2]|0;
  $109 = ((($108)) + 36|0);
  $110 = HEAP32[$109>>2]|0;
  $111 = (FUNCTION_TABLE_ii[$110 & 8191]($36)|0);
  $storemerge = $111;
 } else {
  $112 = (__ZNKSt3__26locale9use_facetERNS0_2idE($1,216916)|0);
  $113 = HEAP32[$112>>2]|0;
  $114 = ((($113)) + 44|0);
  $115 = HEAP32[$114>>2]|0;
  FUNCTION_TABLE_vii[$115 & 8191]($31,$112);
  $116 = HEAP32[$31>>2]|0;
  HEAP8[$2>>0]=$116&255;HEAP8[$2+1>>0]=($116>>8)&255;HEAP8[$2+2>>0]=($116>>16)&255;HEAP8[$2+3>>0]=$116>>24;
  $117 = HEAP32[$112>>2]|0;
  $118 = ((($117)) + 32|0);
  $119 = HEAP32[$118>>2]|0;
  FUNCTION_TABLE_vii[$119 & 8191]($32,$112);
  $120 = ((($8)) + 8|0);
  $121 = ((($120)) + 3|0);
  $122 = HEAP8[$121>>0]|0;
  $123 = ($122<<24>>24)<(0);
  if ($123) {
   $124 = HEAP32[$8>>2]|0;
   HEAP32[$16>>2] = 0;
   __ZNSt3__211char_traitsIwE6assignERwRKw($124,$16);
   $125 = ((($8)) + 4|0);
   HEAP32[$125>>2] = 0;
  } else {
   HEAP32[$17>>2] = 0;
   __ZNSt3__211char_traitsIwE6assignERwRKw($8,$17);
   HEAP8[$121>>0] = 0;
  }
  __THREW__ = 0;
  invoke_vii(4731,($8|0),0);
  $126 = __THREW__; __THREW__ = 0;
  $127 = $126&1;
  if ($127) {
   $128 = ___cxa_find_matching_catch_3(0|0)|0;
   $129 = tempRet0;
   ___clang_call_terminate($128);
   // unreachable;
  }
  ;HEAP32[$8>>2]=HEAP32[$32>>2]|0;HEAP32[$8+4>>2]=HEAP32[$32+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$32+8>>2]|0;
  $$0$i$i$i52 = 0;
  while(1) {
   $exitcond$i$i$i53 = ($$0$i$i$i52|0)==(3);
   if ($exitcond$i$i$i53) {
    break;
   }
   $130 = (($32) + ($$0$i$i$i52<<2)|0);
   HEAP32[$130>>2] = 0;
   $131 = (($$0$i$i$i52) + 1)|0;
   $$0$i$i$i52 = $131;
  }
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev($32);
  $132 = HEAP32[$112>>2]|0;
  $133 = ((($132)) + 28|0);
  $134 = HEAP32[$133>>2]|0;
  FUNCTION_TABLE_vii[$134 & 8191]($33,$112);
  $135 = ((($7)) + 8|0);
  $136 = ((($135)) + 3|0);
  $137 = HEAP8[$136>>0]|0;
  $138 = ($137<<24>>24)<(0);
  if ($138) {
   $139 = HEAP32[$7>>2]|0;
   HEAP32[$14>>2] = 0;
   __ZNSt3__211char_traitsIwE6assignERwRKw($139,$14);
   $140 = ((($7)) + 4|0);
   HEAP32[$140>>2] = 0;
  } else {
   HEAP32[$15>>2] = 0;
   __ZNSt3__211char_traitsIwE6assignERwRKw($7,$15);
   HEAP8[$136>>0] = 0;
  }
  __THREW__ = 0;
  invoke_vii(4731,($7|0),0);
  $141 = __THREW__; __THREW__ = 0;
  $142 = $141&1;
  if ($142) {
   $143 = ___cxa_find_matching_catch_3(0|0)|0;
   $144 = tempRet0;
   ___clang_call_terminate($143);
   // unreachable;
  }
  ;HEAP32[$7>>2]=HEAP32[$33>>2]|0;HEAP32[$7+4>>2]=HEAP32[$33+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[$33+8>>2]|0;
  $$0$i$i$i57 = 0;
  while(1) {
   $exitcond$i$i$i58 = ($$0$i$i$i57|0)==(3);
   if ($exitcond$i$i$i58) {
    break;
   }
   $145 = (($33) + ($$0$i$i$i57<<2)|0);
   HEAP32[$145>>2] = 0;
   $146 = (($$0$i$i$i57) + 1)|0;
   $$0$i$i$i57 = $146;
  }
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev($33);
  $147 = HEAP32[$112>>2]|0;
  $148 = ((($147)) + 12|0);
  $149 = HEAP32[$148>>2]|0;
  $150 = (FUNCTION_TABLE_ii[$149 & 8191]($112)|0);
  HEAP32[$3>>2] = $150;
  $151 = HEAP32[$112>>2]|0;
  $152 = ((($151)) + 16|0);
  $153 = HEAP32[$152>>2]|0;
  $154 = (FUNCTION_TABLE_ii[$153 & 8191]($112)|0);
  HEAP32[$4>>2] = $154;
  $155 = HEAP32[$112>>2]|0;
  $156 = ((($155)) + 20|0);
  $157 = HEAP32[$156>>2]|0;
  FUNCTION_TABLE_vii[$157 & 8191]($34,$112);
  $158 = ((($5)) + 11|0);
  $159 = HEAP8[$158>>0]|0;
  $160 = ($159<<24>>24)<(0);
  if ($160) {
   $161 = HEAP32[$5>>2]|0;
   HEAP8[$12>>0] = 0;
   __ZNSt3__211char_traitsIcE6assignERcRKc($161,$12);
   $162 = ((($5)) + 4|0);
   HEAP32[$162>>2] = 0;
  } else {
   HEAP8[$13>>0] = 0;
   __ZNSt3__211char_traitsIcE6assignERcRKc($5,$13);
   HEAP8[$158>>0] = 0;
  }
  __THREW__ = 0;
  invoke_vii(4723,($5|0),0);
  $163 = __THREW__; __THREW__ = 0;
  $164 = $163&1;
  if ($164) {
   $165 = ___cxa_find_matching_catch_3(0|0)|0;
   $166 = tempRet0;
   ___clang_call_terminate($165);
   // unreachable;
  }
  ;HEAP32[$5>>2]=HEAP32[$34>>2]|0;HEAP32[$5+4>>2]=HEAP32[$34+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$34+8>>2]|0;
  $$0$i$i$i62 = 0;
  while(1) {
   $exitcond$i$i$i63 = ($$0$i$i$i62|0)==(3);
   if ($exitcond$i$i$i63) {
    break;
   }
   $167 = (($34) + ($$0$i$i$i62<<2)|0);
   HEAP32[$167>>2] = 0;
   $168 = (($$0$i$i$i62) + 1)|0;
   $$0$i$i$i62 = $168;
  }
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($34);
  $169 = HEAP32[$112>>2]|0;
  $170 = ((($169)) + 24|0);
  $171 = HEAP32[$170>>2]|0;
  FUNCTION_TABLE_vii[$171 & 8191]($35,$112);
  $172 = ((($6)) + 8|0);
  $173 = ((($172)) + 3|0);
  $174 = HEAP8[$173>>0]|0;
  $175 = ($174<<24>>24)<(0);
  if ($175) {
   $176 = HEAP32[$6>>2]|0;
   HEAP32[$10>>2] = 0;
   __ZNSt3__211char_traitsIwE6assignERwRKw($176,$10);
   $177 = ((($6)) + 4|0);
   HEAP32[$177>>2] = 0;
  } else {
   HEAP32[$11>>2] = 0;
   __ZNSt3__211char_traitsIwE6assignERwRKw($6,$11);
   HEAP8[$173>>0] = 0;
  }
  __THREW__ = 0;
  invoke_vii(4731,($6|0),0);
  $178 = __THREW__; __THREW__ = 0;
  $179 = $178&1;
  if ($179) {
   $180 = ___cxa_find_matching_catch_3(0|0)|0;
   $181 = tempRet0;
   ___clang_call_terminate($180);
   // unreachable;
  }
  ;HEAP32[$6>>2]=HEAP32[$35>>2]|0;HEAP32[$6+4>>2]=HEAP32[$35+4>>2]|0;HEAP32[$6+8>>2]=HEAP32[$35+8>>2]|0;
  $$0$i$i$i67 = 0;
  while(1) {
   $exitcond$i$i$i68 = ($$0$i$i$i67|0)==(3);
   if ($exitcond$i$i$i68) {
    break;
   }
   $182 = (($35) + ($$0$i$i$i67<<2)|0);
   HEAP32[$182>>2] = 0;
   $183 = (($$0$i$i$i67) + 1)|0;
   $$0$i$i$i67 = $183;
  }
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev($35);
  $184 = HEAP32[$112>>2]|0;
  $185 = ((($184)) + 36|0);
  $186 = HEAP32[$185>>2]|0;
  $187 = (FUNCTION_TABLE_ii[$186 & 8191]($112)|0);
  $storemerge = $187;
 }
 HEAP32[$9>>2] = $storemerge;
 STACKTOP = sp;return;
}
function __ZNSt3__219__double_or_nothingIwEEvRNS_10unique_ptrIT_PFvPvEEERPS2_S9_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$ = 0, $$34 = 0, $$pr = 0, $$pre = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)!=(4716|0);
 $6 = HEAP32[$2>>2]|0;
 $7 = HEAP32[$0>>2]|0;
 $8 = (($6) - ($7))|0;
 $9 = ($8>>>0)<(2147483647);
 $10 = $8 << 1;
 $$34 = $9 ? $10 : -1;
 $11 = ($$34|0)==(0);
 $$ = $11 ? 4 : $$34;
 $12 = HEAP32[$1>>2]|0;
 $13 = (($12) - ($7))|0;
 $14 = $13 >> 2;
 $phitmp = $7;
 $15 = $5 ? $phitmp : 0;
 $16 = (_realloc($15,$$)|0);
 $17 = ($16|0)==(0|0);
 if ($17) {
  __ZSt17__throw_bad_allocv();
  // unreachable;
 }
 do {
  if ($5) {
   $18 = $16;
   HEAP32[$0>>2] = $18;
   $28 = $16;
  } else {
   $$pr = HEAP32[$0>>2]|0;
   $19 = $16;
   HEAP32[$0>>2] = $19;
   $20 = ($$pr|0)==(0|0);
   if ($20) {
    $28 = $16;
   } else {
    $21 = HEAP32[$3>>2]|0;
    __THREW__ = 0;
    invoke_vi($21|0,($$pr|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     $24 = ___cxa_find_matching_catch_3(0|0)|0;
     $25 = tempRet0;
     ___clang_call_terminate($24);
     // unreachable;
    } else {
     $$pre = HEAP32[$0>>2]|0;
     $28 = $$pre;
     break;
    }
   }
  }
 } while(0);
 HEAP32[$3>>2] = (4724);
 $26 = $$ >>> 2;
 $27 = (($28) + ($14<<2)|0);
 HEAP32[$1>>2] = $27;
 $29 = HEAP32[$0>>2]|0;
 $30 = (($29) + ($26<<2)|0);
 HEAP32[$2>>2] = $30;
 return;
}
function __ZNSt3__29money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEED2Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__26locale5facetD2Ev($0);
 return;
}
function __ZNSt3__29money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEED0Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__26locale5facetD2Ev($0);
 __ZdlPv($0);
 return;
}
function __ZNKSt3__29money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_bRNS_8ios_baseEce($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = +$5;
 var $$0 = 0, $$0$i$i = 0, $$0$i$i56 = 0, $$0$i$i59 = 0, $$046 = 0, $$047 = 0, $$048 = 0, $$049 = 0, $$1 = 0, $$150 = 0, $$3 = 0, $$352 = 0, $$4 = 0, $$453 = 0, $$byval_copy = 0, $$sink = 0, $$sink1 = 0, $$sink105 = 0, $$sink106 = 0, $$sroa$071$0 = 0;
 var $$sroa$071$1 = 0, $$sroa$083$0 = 0, $$sroa$083$1 = 0, $$sroa$083$2 = 0, $$sroa$096$0 = 0, $$sroa$096$1 = 0, $$sroa$096$2 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $exitcond$i$i = 0, $exitcond$i$i57 = 0, $exitcond$i$i60 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 400|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(400|0);
 $$byval_copy = sp + 76|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $6 = sp + 288|0;
 $7 = sp + 72|0;
 $8 = sp + 188|0;
 $9 = sp + 68|0;
 $10 = sp + 184|0;
 $11 = sp + 181|0;
 $12 = sp + 180|0;
 $13 = sp + 56|0;
 $14 = sp + 44|0;
 $15 = sp + 32|0;
 $16 = sp + 28|0;
 $17 = sp + 80|0;
 $18 = sp + 24|0;
 $19 = sp + 20|0;
 $20 = sp + 16|0;
 HEAP32[$7>>2] = $6;
 HEAPF64[$vararg_buffer>>3] = $5;
 $21 = (_snprintf($6,100,204171,$vararg_buffer)|0);
 $22 = ($21>>>0)>(99);
 do {
  if ($22) {
   __THREW__ = 0;
   $23 = (invoke_i(4668)|0);
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   if ($25) {
    $$sroa$083$0 = 0;$$sroa$096$0 = 0;
    label = 6;
   } else {
    __THREW__ = 0;
    HEAPF64[$vararg_buffer1>>3] = $5;
    $26 = (invoke_iiiii(4690,($7|0),($23|0),(204171|0),($vararg_buffer1|0))|0);
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     $$sroa$083$0 = 0;$$sroa$096$0 = 0;
     label = 6;
    } else {
     $29 = HEAP32[$7>>2]|0;
     $30 = ($29|0)==(0|0);
     if ($30) {
      __THREW__ = 0;
      invoke_v(4685);
      $31 = __THREW__; __THREW__ = 0;
      $$sroa$083$0 = 0;$$sroa$096$0 = 0;
      label = 6;
      break;
     }
     $34 = $29;
     $35 = (_malloc($26)|0);
     $36 = $35;
     $37 = ($35|0)==(0|0);
     if ($37) {
      __THREW__ = 0;
      invoke_v(4685);
      $38 = __THREW__; __THREW__ = 0;
      $$sroa$083$0 = $36;$$sroa$096$0 = $34;
      label = 6;
     } else {
      $$0 = $35;$$047 = $26;$$sroa$083$1 = $36;$$sroa$096$1 = $34;
      label = 9;
     }
    }
   }
  } else {
   $$0 = $8;$$047 = $21;$$sroa$083$1 = 0;$$sroa$096$1 = 0;
   label = 9;
  }
 } while(0);
 if ((label|0) == 9) {
  __THREW__ = 0;
  invoke_vii(3257,($9|0),($3|0));
  $39 = __THREW__; __THREW__ = 0;
  $40 = $39&1;
  if ($40) {
   $$sroa$083$0 = $$sroa$083$1;$$sroa$096$0 = $$sroa$096$1;
   label = 6;
  } else {
   __THREW__ = 0;
   $41 = (invoke_iii(3255,($9|0),(215188|0))|0);
   $42 = __THREW__; __THREW__ = 0;
   $43 = $42&1;
   do {
    if ($43) {
     $106 = ___cxa_find_matching_catch_2()|0;
     $107 = tempRet0;
     $$3 = $106;$$352 = $107;
    } else {
     $44 = HEAP32[$7>>2]|0;
     $45 = (($44) + ($$047)|0);
     $46 = HEAP32[$41>>2]|0;
     $47 = ((($46)) + 32|0);
     $48 = HEAP32[$47>>2]|0;
     __THREW__ = 0;
     (invoke_iiiii($48|0,($41|0),($44|0),($45|0),($$0|0))|0);
     $49 = __THREW__; __THREW__ = 0;
     $50 = $49&1;
     if ($50) {
      $108 = ___cxa_find_matching_catch_2()|0;
      $109 = tempRet0;
      $$3 = $108;$$352 = $109;
      break;
     }
     $51 = ($$047|0)==(0);
     if ($51) {
      $61 = 0;
     } else {
      $52 = HEAP32[$7>>2]|0;
      $53 = HEAP8[$52>>0]|0;
      $54 = ($53<<24>>24)==(45);
      $61 = $54;
     }
     ;HEAP32[$13>>2]=0|0;HEAP32[$13+4>>2]=0|0;HEAP32[$13+8>>2]=0|0;
     $$0$i$i = 0;
     while(1) {
      $exitcond$i$i = ($$0$i$i|0)==(3);
      if ($exitcond$i$i) {
       break;
      }
      $55 = (($13) + ($$0$i$i<<2)|0);
      HEAP32[$55>>2] = 0;
      $56 = (($$0$i$i) + 1)|0;
      $$0$i$i = $56;
     }
     ;HEAP32[$14>>2]=0|0;HEAP32[$14+4>>2]=0|0;HEAP32[$14+8>>2]=0|0;
     $$0$i$i56 = 0;
     while(1) {
      $exitcond$i$i57 = ($$0$i$i56|0)==(3);
      if ($exitcond$i$i57) {
       break;
      }
      $57 = (($14) + ($$0$i$i56<<2)|0);
      HEAP32[$57>>2] = 0;
      $58 = (($$0$i$i56) + 1)|0;
      $$0$i$i56 = $58;
     }
     ;HEAP32[$15>>2]=0|0;HEAP32[$15+4>>2]=0|0;HEAP32[$15+8>>2]=0|0;
     $$0$i$i59 = 0;
     while(1) {
      $exitcond$i$i60 = ($$0$i$i59|0)==(3);
      if ($exitcond$i$i60) {
       break;
      }
      $59 = (($15) + ($$0$i$i59<<2)|0);
      HEAP32[$59>>2] = 0;
      $60 = (($$0$i$i59) + 1)|0;
      $$0$i$i59 = $60;
     }
     __THREW__ = 0;
     invoke_viiiiiiiiii(4732,($2|0),($61|0),($9|0),($10|0),($11|0),($12|0),($13|0),($14|0),($15|0),($16|0));
     $62 = __THREW__; __THREW__ = 0;
     $63 = $62&1;
     if ($63) {
      $110 = ___cxa_find_matching_catch_2()|0;
      $111 = tempRet0;
      $$1 = $110;$$150 = $111;
     } else {
      $64 = HEAP32[$16>>2]|0;
      $65 = ($$047|0)>($64|0);
      if ($65) {
       $66 = (($$047) - ($64))|0;
       $67 = $66 << 1;
       $68 = ((($15)) + 11|0);
       $69 = HEAP8[$68>>0]|0;
       $70 = ($69<<24>>24)<(0);
       $71 = ((($15)) + 4|0);
       $72 = HEAP32[$71>>2]|0;
       $73 = $69&255;
       $74 = $70 ? $72 : $73;
       $75 = (($74) + ($67))|0;
       $76 = ((($14)) + 11|0);
       $77 = HEAP8[$76>>0]|0;
       $78 = ($77<<24>>24)<(0);
       $79 = ((($14)) + 4|0);
       $80 = HEAP32[$79>>2]|0;
       $81 = $77&255;
       $82 = $78 ? $80 : $81;
       $$sink1 = 1;$$sink105 = $75;$$sink106 = $82;
      } else {
       $83 = ((($15)) + 11|0);
       $84 = HEAP8[$83>>0]|0;
       $85 = ($84<<24>>24)<(0);
       $86 = ((($15)) + 4|0);
       $87 = HEAP32[$86>>2]|0;
       $88 = $84&255;
       $89 = $85 ? $87 : $88;
       $90 = ((($14)) + 11|0);
       $91 = HEAP8[$90>>0]|0;
       $92 = ($91<<24>>24)<(0);
       $93 = ((($14)) + 4|0);
       $94 = HEAP32[$93>>2]|0;
       $95 = $91&255;
       $96 = $92 ? $94 : $95;
       $$sink1 = 2;$$sink105 = $96;$$sink106 = $89;
      }
      $97 = (($$sink106) + ($64))|0;
      $$sink = (($97) + ($$sink105))|0;
      $98 = (($$sink) + ($$sink1))|0;
      $99 = ($98>>>0)>(100);
      if ($99) {
       $100 = (_malloc($98)|0);
       $101 = $100;
       $102 = ($100|0)==(0|0);
       if ($102) {
        __THREW__ = 0;
        invoke_v(4685);
        $103 = __THREW__; __THREW__ = 0;
        $104 = ___cxa_find_matching_catch_2()|0;
        $105 = tempRet0;
        $$048 = $104;$$049 = $105;$$sroa$071$1 = $101;
       } else {
        $$046 = $100;$$sroa$071$0 = $101;
        label = 33;
       }
      } else {
       $$046 = $17;$$sroa$071$0 = 0;
       label = 33;
      }
      if ((label|0) == 33) {
       $112 = ((($3)) + 4|0);
       $113 = HEAP32[$112>>2]|0;
       $114 = (($$0) + ($$047)|0);
       $115 = HEAP8[$11>>0]|0;
       $116 = HEAP8[$12>>0]|0;
       __THREW__ = 0;
       invoke_viiiiiiiiiiiiiii(4733,($$046|0),($18|0),($19|0),($113|0),($$0|0),($114|0),($41|0),($61|0),($10|0),($115|0),($116|0),($13|0),($14|0),($15|0),($64|0));
       $117 = __THREW__; __THREW__ = 0;
       $118 = $117&1;
       if (!($118)) {
        $119 = HEAP32[$1>>2]|0;
        HEAP32[$20>>2] = $119;
        $120 = HEAP32[$18>>2]|0;
        $121 = HEAP32[$19>>2]|0;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy>>2]=HEAP32[$20>>2]|0;
        $122 = (invoke_iiiiiii(3258,($$byval_copy|0),($$046|0),($120|0),($121|0),($3|0),($4|0))|0);
        $123 = __THREW__; __THREW__ = 0;
        $124 = $123&1;
        if (!($124)) {
         $125 = ($$sroa$071$0|0)==(0);
         if (!($125)) {
          $126 = $$sroa$071$0;
          _free($126);
         }
         __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($15);
         __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($14);
         __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($13);
         __ZNSt3__26localeD2Ev($9);
         $127 = ($$sroa$083$1|0)==(0);
         if (!($127)) {
          $128 = $$sroa$083$1;
          _free($128);
         }
         $129 = ($$sroa$096$1|0)==(0);
         if (!($129)) {
          $130 = $$sroa$096$1;
          _free($130);
         }
         STACKTOP = sp;return ($122|0);
        }
       }
       $131 = ___cxa_find_matching_catch_2()|0;
       $132 = tempRet0;
       $$048 = $131;$$049 = $132;$$sroa$071$1 = $$sroa$071$0;
      }
      $133 = ($$sroa$071$1|0)==(0);
      if (!($133)) {
       $134 = $$sroa$071$1;
       _free($134);
      }
      $$1 = $$048;$$150 = $$049;
     }
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($15);
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($14);
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($13);
     $$3 = $$1;$$352 = $$150;
    }
   } while(0);
   __ZNSt3__26localeD2Ev($9);
   $$4 = $$3;$$453 = $$352;$$sroa$083$2 = $$sroa$083$1;$$sroa$096$2 = $$sroa$096$1;
  }
 }
 if ((label|0) == 6) {
  $32 = ___cxa_find_matching_catch_2()|0;
  $33 = tempRet0;
  $$4 = $32;$$453 = $33;$$sroa$083$2 = $$sroa$083$0;$$sroa$096$2 = $$sroa$096$0;
 }
 $135 = ($$sroa$083$2|0)==(0);
 if (!($135)) {
  $136 = $$sroa$083$2;
  _free($136);
 }
 $137 = ($$sroa$096$2|0)==(0);
 if (!($137)) {
  $138 = $$sroa$096$2;
  _free($138);
 }
 ___resumeException($$4|0);
 // unreachable;
 return (0)|0;
}
function __ZNKSt3__29money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_bRNS_8ios_baseEcRKNS_12basic_stringIcS3_NS_9allocatorIcEEEE($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$0 = 0, $$0$i$i = 0, $$0$i$i37 = 0, $$0$i$i40 = 0, $$032 = 0, $$033 = 0, $$1 = 0, $$134 = 0, $$3 = 0, $$336 = 0, $$byval_copy = 0, $$sink = 0, $$sink1 = 0, $$sink63 = 0, $$sink64 = 0, $$sroa$053$0 = 0, $$sroa$053$1 = 0, $10 = 0, $100 = 0, $101 = 0;
 var $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0;
 var $120 = 0, $121 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i$i = 0, $exitcond$i$i38 = 0, $exitcond$i$i41 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(176|0);
 $$byval_copy = sp + 56|0;
 $6 = sp + 52|0;
 $7 = sp + 164|0;
 $8 = sp + 161|0;
 $9 = sp + 160|0;
 $10 = sp + 40|0;
 $11 = sp + 28|0;
 $12 = sp + 16|0;
 $13 = sp + 12|0;
 $14 = sp + 60|0;
 $15 = sp + 8|0;
 $16 = sp + 4|0;
 $17 = sp;
 __ZNKSt3__28ios_base6getlocEv($6,$3);
 __THREW__ = 0;
 $18 = (invoke_iii(3255,($6|0),(215188|0))|0);
 $19 = __THREW__; __THREW__ = 0;
 $20 = $19&1;
 L1: do {
  if ($20) {
   $95 = ___cxa_find_matching_catch_2()|0;
   $96 = tempRet0;
   $$3 = $95;$$336 = $96;
  } else {
   $21 = ((($5)) + 11|0);
   $22 = HEAP8[$21>>0]|0;
   $23 = ($22<<24>>24)<(0);
   $24 = ((($5)) + 4|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = $22&255;
   $27 = $23 ? $25 : $26;
   $28 = ($27|0)==(0);
   do {
    if ($28) {
     $45 = 0;
    } else {
     $29 = HEAP32[$5>>2]|0;
     $30 = $23 ? $29 : $5;
     $31 = HEAP8[$30>>0]|0;
     $32 = HEAP32[$18>>2]|0;
     $33 = ((($32)) + 28|0);
     $34 = HEAP32[$33>>2]|0;
     __THREW__ = 0;
     $35 = (invoke_iii($34|0,($18|0),45)|0);
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if ($37) {
      $97 = ___cxa_find_matching_catch_2()|0;
      $98 = tempRet0;
      $$3 = $97;$$336 = $98;
      break L1;
     } else {
      $38 = ($31<<24>>24)==($35<<24>>24);
      $45 = $38;
      break;
     }
    }
   } while(0);
   ;HEAP32[$10>>2]=0|0;HEAP32[$10+4>>2]=0|0;HEAP32[$10+8>>2]=0|0;
   $$0$i$i = 0;
   while(1) {
    $exitcond$i$i = ($$0$i$i|0)==(3);
    if ($exitcond$i$i) {
     break;
    }
    $39 = (($10) + ($$0$i$i<<2)|0);
    HEAP32[$39>>2] = 0;
    $40 = (($$0$i$i) + 1)|0;
    $$0$i$i = $40;
   }
   ;HEAP32[$11>>2]=0|0;HEAP32[$11+4>>2]=0|0;HEAP32[$11+8>>2]=0|0;
   $$0$i$i37 = 0;
   while(1) {
    $exitcond$i$i38 = ($$0$i$i37|0)==(3);
    if ($exitcond$i$i38) {
     break;
    }
    $41 = (($11) + ($$0$i$i37<<2)|0);
    HEAP32[$41>>2] = 0;
    $42 = (($$0$i$i37) + 1)|0;
    $$0$i$i37 = $42;
   }
   ;HEAP32[$12>>2]=0|0;HEAP32[$12+4>>2]=0|0;HEAP32[$12+8>>2]=0|0;
   $$0$i$i40 = 0;
   while(1) {
    $exitcond$i$i41 = ($$0$i$i40|0)==(3);
    if ($exitcond$i$i41) {
     break;
    }
    $43 = (($12) + ($$0$i$i40<<2)|0);
    HEAP32[$43>>2] = 0;
    $44 = (($$0$i$i40) + 1)|0;
    $$0$i$i40 = $44;
   }
   __THREW__ = 0;
   invoke_viiiiiiiiii(4732,($2|0),($45|0),($6|0),($7|0),($8|0),($9|0),($10|0),($11|0),($12|0),($13|0));
   $46 = __THREW__; __THREW__ = 0;
   $47 = $46&1;
   if ($47) {
    $99 = ___cxa_find_matching_catch_2()|0;
    $100 = tempRet0;
    $$1 = $99;$$134 = $100;
   } else {
    $48 = HEAP8[$21>>0]|0;
    $49 = ($48<<24>>24)<(0);
    $50 = HEAP32[$24>>2]|0;
    $51 = $48&255;
    $52 = $49 ? $50 : $51;
    $53 = HEAP32[$13>>2]|0;
    $54 = ($52|0)>($53|0);
    if ($54) {
     $55 = (($52) - ($53))|0;
     $56 = $55 << 1;
     $57 = ((($12)) + 11|0);
     $58 = HEAP8[$57>>0]|0;
     $59 = ($58<<24>>24)<(0);
     $60 = ((($12)) + 4|0);
     $61 = HEAP32[$60>>2]|0;
     $62 = $58&255;
     $63 = $59 ? $61 : $62;
     $64 = (($63) + ($56))|0;
     $65 = ((($11)) + 11|0);
     $66 = HEAP8[$65>>0]|0;
     $67 = ($66<<24>>24)<(0);
     $68 = ((($11)) + 4|0);
     $69 = HEAP32[$68>>2]|0;
     $70 = $66&255;
     $71 = $67 ? $69 : $70;
     $$sink1 = 1;$$sink63 = $64;$$sink64 = $71;
    } else {
     $72 = ((($12)) + 11|0);
     $73 = HEAP8[$72>>0]|0;
     $74 = ($73<<24>>24)<(0);
     $75 = ((($12)) + 4|0);
     $76 = HEAP32[$75>>2]|0;
     $77 = $73&255;
     $78 = $74 ? $76 : $77;
     $79 = ((($11)) + 11|0);
     $80 = HEAP8[$79>>0]|0;
     $81 = ($80<<24>>24)<(0);
     $82 = ((($11)) + 4|0);
     $83 = HEAP32[$82>>2]|0;
     $84 = $80&255;
     $85 = $81 ? $83 : $84;
     $$sink1 = 2;$$sink63 = $85;$$sink64 = $78;
    }
    $86 = (($$sink64) + ($53))|0;
    $$sink = (($86) + ($$sink63))|0;
    $87 = (($$sink) + ($$sink1))|0;
    $88 = ($87>>>0)>(100);
    if ($88) {
     $89 = (_malloc($87)|0);
     $90 = $89;
     $91 = ($89|0)==(0|0);
     if ($91) {
      __THREW__ = 0;
      invoke_v(4685);
      $92 = __THREW__; __THREW__ = 0;
      $93 = ___cxa_find_matching_catch_2()|0;
      $94 = tempRet0;
      $$0 = $93;$$033 = $94;$$sroa$053$1 = $90;
     } else {
      $$032 = $89;$$sroa$053$0 = $90;
      label = 24;
     }
    } else {
     $$032 = $14;$$sroa$053$0 = 0;
     label = 24;
    }
    if ((label|0) == 24) {
     $101 = ((($3)) + 4|0);
     $102 = HEAP32[$101>>2]|0;
     $103 = HEAP32[$5>>2]|0;
     $104 = $49 ? $103 : $5;
     $105 = (($104) + ($52)|0);
     $106 = HEAP8[$8>>0]|0;
     $107 = HEAP8[$9>>0]|0;
     __THREW__ = 0;
     invoke_viiiiiiiiiiiiiii(4733,($$032|0),($15|0),($16|0),($102|0),($104|0),($105|0),($18|0),($45|0),($7|0),($106|0),($107|0),($10|0),($11|0),($12|0),($53|0));
     $108 = __THREW__; __THREW__ = 0;
     $109 = $108&1;
     if (!($109)) {
      $110 = HEAP32[$1>>2]|0;
      HEAP32[$17>>2] = $110;
      $111 = HEAP32[$15>>2]|0;
      $112 = HEAP32[$16>>2]|0;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy>>2]=HEAP32[$17>>2]|0;
      $113 = (invoke_iiiiiii(3258,($$byval_copy|0),($$032|0),($111|0),($112|0),($3|0),($4|0))|0);
      $114 = __THREW__; __THREW__ = 0;
      $115 = $114&1;
      if (!($115)) {
       $116 = ($$sroa$053$0|0)==(0);
       if (!($116)) {
        $117 = $$sroa$053$0;
        _free($117);
       }
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($12);
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($11);
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($10);
       __ZNSt3__26localeD2Ev($6);
       STACKTOP = sp;return ($113|0);
      }
     }
     $118 = ___cxa_find_matching_catch_2()|0;
     $119 = tempRet0;
     $$0 = $118;$$033 = $119;$$sroa$053$1 = $$sroa$053$0;
    }
    $120 = ($$sroa$053$1|0)==(0);
    if (!($120)) {
     $121 = $$sroa$053$1;
     _free($121);
    }
    $$1 = $$0;$$134 = $$033;
   }
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($12);
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($11);
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($10);
   $$3 = $$1;$$336 = $$134;
  }
 } while(0);
 __ZNSt3__26localeD2Ev($6);
 ___resumeException($$3|0);
 // unreachable;
 return (0)|0;
}
function __ZNSt3__211__money_putIcE13__gather_infoEbbRKNS_6localeERNS_10money_base7patternERcS8_RNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEESF_SF_Ri($0,$1,$2,$3,$4,$5,$6,$7,$8,$9) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 $8 = $8|0;
 $9 = $9|0;
 var $$0$i$i$i = 0, $$0$i$i$i48 = 0, $$0$i$i$i53 = 0, $$0$i$i$i58 = 0, $$0$i$i$i63 = 0, $$0$i$i$i68 = 0, $$0$i$i$i73 = 0, $$0$i$i$i78 = 0, $$pre$phi81Z2D = 0, $$pre$phiZ2D = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0;
 var $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0;
 var $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i$i$i = 0, $exitcond$i$i$i49 = 0, $exitcond$i$i$i54 = 0, $exitcond$i$i$i59 = 0, $exitcond$i$i$i64 = 0, $exitcond$i$i$i69 = 0, $exitcond$i$i$i74 = 0, $exitcond$i$i$i79 = 0;
 var $storemerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(128|0);
 $10 = sp + 127|0;
 $11 = sp + 126|0;
 $12 = sp + 125|0;
 $13 = sp + 124|0;
 $14 = sp + 123|0;
 $15 = sp + 122|0;
 $16 = sp + 121|0;
 $17 = sp + 120|0;
 $18 = sp + 119|0;
 $19 = sp + 118|0;
 $20 = sp + 117|0;
 $21 = sp + 116|0;
 $22 = sp + 115|0;
 $23 = sp + 114|0;
 $24 = sp + 113|0;
 $25 = sp + 112|0;
 $26 = sp + 108|0;
 $27 = sp + 96|0;
 $28 = sp + 92|0;
 $29 = sp + 80|0;
 $30 = sp + 68|0;
 $31 = sp + 56|0;
 $32 = sp + 52|0;
 $33 = sp + 40|0;
 $34 = sp + 36|0;
 $35 = sp + 24|0;
 $36 = sp + 12|0;
 $37 = sp;
 if ($0) {
  $38 = (__ZNKSt3__26locale9use_facetERNS0_2idE($2,216908)|0);
  if ($1) {
   $39 = HEAP32[$38>>2]|0;
   $40 = ((($39)) + 44|0);
   $41 = HEAP32[$40>>2]|0;
   FUNCTION_TABLE_vii[$41 & 8191]($26,$38);
   $42 = HEAP32[$26>>2]|0;
   HEAP8[$3>>0]=$42&255;HEAP8[$3+1>>0]=($42>>8)&255;HEAP8[$3+2>>0]=($42>>16)&255;HEAP8[$3+3>>0]=$42>>24;
   $43 = HEAP32[$38>>2]|0;
   $44 = ((($43)) + 32|0);
   $45 = HEAP32[$44>>2]|0;
   FUNCTION_TABLE_vii[$45 & 8191]($27,$38);
   $46 = ((($8)) + 11|0);
   $47 = HEAP8[$46>>0]|0;
   $48 = ($47<<24>>24)<(0);
   if ($48) {
    $49 = HEAP32[$8>>2]|0;
    HEAP8[$24>>0] = 0;
    __ZNSt3__211char_traitsIcE6assignERcRKc($49,$24);
    $50 = ((($8)) + 4|0);
    HEAP32[$50>>2] = 0;
   } else {
    HEAP8[$25>>0] = 0;
    __ZNSt3__211char_traitsIcE6assignERcRKc($8,$25);
    HEAP8[$46>>0] = 0;
   }
   __THREW__ = 0;
   invoke_vii(4723,($8|0),0);
   $51 = __THREW__; __THREW__ = 0;
   $52 = $51&1;
   if ($52) {
    $53 = ___cxa_find_matching_catch_3(0|0)|0;
    $54 = tempRet0;
    ___clang_call_terminate($53);
    // unreachable;
   }
   ;HEAP32[$8>>2]=HEAP32[$27>>2]|0;HEAP32[$8+4>>2]=HEAP32[$27+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$27+8>>2]|0;
   $$0$i$i$i = 0;
   while(1) {
    $exitcond$i$i$i = ($$0$i$i$i|0)==(3);
    if ($exitcond$i$i$i) {
     break;
    }
    $55 = (($27) + ($$0$i$i$i<<2)|0);
    HEAP32[$55>>2] = 0;
    $56 = (($$0$i$i$i) + 1)|0;
    $$0$i$i$i = $56;
   }
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($27);
   $$pre$phiZ2D = $38;
  } else {
   $57 = HEAP32[$38>>2]|0;
   $58 = ((($57)) + 40|0);
   $59 = HEAP32[$58>>2]|0;
   FUNCTION_TABLE_vii[$59 & 8191]($28,$38);
   $60 = HEAP32[$28>>2]|0;
   HEAP8[$3>>0]=$60&255;HEAP8[$3+1>>0]=($60>>8)&255;HEAP8[$3+2>>0]=($60>>16)&255;HEAP8[$3+3>>0]=$60>>24;
   $61 = HEAP32[$38>>2]|0;
   $62 = ((($61)) + 28|0);
   $63 = HEAP32[$62>>2]|0;
   FUNCTION_TABLE_vii[$63 & 8191]($29,$38);
   $64 = ((($8)) + 11|0);
   $65 = HEAP8[$64>>0]|0;
   $66 = ($65<<24>>24)<(0);
   if ($66) {
    $67 = HEAP32[$8>>2]|0;
    HEAP8[$22>>0] = 0;
    __ZNSt3__211char_traitsIcE6assignERcRKc($67,$22);
    $68 = ((($8)) + 4|0);
    HEAP32[$68>>2] = 0;
   } else {
    HEAP8[$23>>0] = 0;
    __ZNSt3__211char_traitsIcE6assignERcRKc($8,$23);
    HEAP8[$64>>0] = 0;
   }
   __THREW__ = 0;
   invoke_vii(4723,($8|0),0);
   $69 = __THREW__; __THREW__ = 0;
   $70 = $69&1;
   if ($70) {
    $71 = ___cxa_find_matching_catch_3(0|0)|0;
    $72 = tempRet0;
    ___clang_call_terminate($71);
    // unreachable;
   }
   ;HEAP32[$8>>2]=HEAP32[$29>>2]|0;HEAP32[$8+4>>2]=HEAP32[$29+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$29+8>>2]|0;
   $$0$i$i$i48 = 0;
   while(1) {
    $exitcond$i$i$i49 = ($$0$i$i$i48|0)==(3);
    if ($exitcond$i$i$i49) {
     break;
    }
    $73 = (($29) + ($$0$i$i$i48<<2)|0);
    HEAP32[$73>>2] = 0;
    $74 = (($$0$i$i$i48) + 1)|0;
    $$0$i$i$i48 = $74;
   }
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($29);
   $$pre$phiZ2D = $38;
  }
  $75 = HEAP32[$38>>2]|0;
  $76 = ((($75)) + 12|0);
  $77 = HEAP32[$76>>2]|0;
  $78 = (FUNCTION_TABLE_ii[$77 & 8191]($38)|0);
  HEAP8[$4>>0] = $78;
  $79 = HEAP32[$38>>2]|0;
  $80 = ((($79)) + 16|0);
  $81 = HEAP32[$80>>2]|0;
  $82 = (FUNCTION_TABLE_ii[$81 & 8191]($38)|0);
  HEAP8[$5>>0] = $82;
  $83 = HEAP32[$$pre$phiZ2D>>2]|0;
  $84 = ((($83)) + 20|0);
  $85 = HEAP32[$84>>2]|0;
  FUNCTION_TABLE_vii[$85 & 8191]($30,$38);
  $86 = ((($6)) + 11|0);
  $87 = HEAP8[$86>>0]|0;
  $88 = ($87<<24>>24)<(0);
  if ($88) {
   $89 = HEAP32[$6>>2]|0;
   HEAP8[$20>>0] = 0;
   __ZNSt3__211char_traitsIcE6assignERcRKc($89,$20);
   $90 = ((($6)) + 4|0);
   HEAP32[$90>>2] = 0;
  } else {
   HEAP8[$21>>0] = 0;
   __ZNSt3__211char_traitsIcE6assignERcRKc($6,$21);
   HEAP8[$86>>0] = 0;
  }
  __THREW__ = 0;
  invoke_vii(4723,($6|0),0);
  $91 = __THREW__; __THREW__ = 0;
  $92 = $91&1;
  if ($92) {
   $93 = ___cxa_find_matching_catch_3(0|0)|0;
   $94 = tempRet0;
   ___clang_call_terminate($93);
   // unreachable;
  }
  ;HEAP32[$6>>2]=HEAP32[$30>>2]|0;HEAP32[$6+4>>2]=HEAP32[$30+4>>2]|0;HEAP32[$6+8>>2]=HEAP32[$30+8>>2]|0;
  $$0$i$i$i53 = 0;
  while(1) {
   $exitcond$i$i$i54 = ($$0$i$i$i53|0)==(3);
   if ($exitcond$i$i$i54) {
    break;
   }
   $95 = (($30) + ($$0$i$i$i53<<2)|0);
   HEAP32[$95>>2] = 0;
   $96 = (($$0$i$i$i53) + 1)|0;
   $$0$i$i$i53 = $96;
  }
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($30);
  $97 = HEAP32[$$pre$phiZ2D>>2]|0;
  $98 = ((($97)) + 24|0);
  $99 = HEAP32[$98>>2]|0;
  FUNCTION_TABLE_vii[$99 & 8191]($31,$38);
  $100 = ((($7)) + 11|0);
  $101 = HEAP8[$100>>0]|0;
  $102 = ($101<<24>>24)<(0);
  if ($102) {
   $103 = HEAP32[$7>>2]|0;
   HEAP8[$18>>0] = 0;
   __ZNSt3__211char_traitsIcE6assignERcRKc($103,$18);
   $104 = ((($7)) + 4|0);
   HEAP32[$104>>2] = 0;
  } else {
   HEAP8[$19>>0] = 0;
   __ZNSt3__211char_traitsIcE6assignERcRKc($7,$19);
   HEAP8[$100>>0] = 0;
  }
  __THREW__ = 0;
  invoke_vii(4723,($7|0),0);
  $105 = __THREW__; __THREW__ = 0;
  $106 = $105&1;
  if ($106) {
   $107 = ___cxa_find_matching_catch_3(0|0)|0;
   $108 = tempRet0;
   ___clang_call_terminate($107);
   // unreachable;
  }
  ;HEAP32[$7>>2]=HEAP32[$31>>2]|0;HEAP32[$7+4>>2]=HEAP32[$31+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[$31+8>>2]|0;
  $$0$i$i$i58 = 0;
  while(1) {
   $exitcond$i$i$i59 = ($$0$i$i$i58|0)==(3);
   if ($exitcond$i$i$i59) {
    break;
   }
   $109 = (($31) + ($$0$i$i$i58<<2)|0);
   HEAP32[$109>>2] = 0;
   $110 = (($$0$i$i$i58) + 1)|0;
   $$0$i$i$i58 = $110;
  }
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($31);
  $111 = HEAP32[$38>>2]|0;
  $112 = ((($111)) + 36|0);
  $113 = HEAP32[$112>>2]|0;
  $114 = (FUNCTION_TABLE_ii[$113 & 8191]($38)|0);
  $storemerge = $114;
 } else {
  $115 = (__ZNKSt3__26locale9use_facetERNS0_2idE($2,216900)|0);
  if ($1) {
   $116 = HEAP32[$115>>2]|0;
   $117 = ((($116)) + 44|0);
   $118 = HEAP32[$117>>2]|0;
   FUNCTION_TABLE_vii[$118 & 8191]($32,$115);
   $119 = HEAP32[$32>>2]|0;
   HEAP8[$3>>0]=$119&255;HEAP8[$3+1>>0]=($119>>8)&255;HEAP8[$3+2>>0]=($119>>16)&255;HEAP8[$3+3>>0]=$119>>24;
   $120 = HEAP32[$115>>2]|0;
   $121 = ((($120)) + 32|0);
   $122 = HEAP32[$121>>2]|0;
   FUNCTION_TABLE_vii[$122 & 8191]($33,$115);
   $123 = ((($8)) + 11|0);
   $124 = HEAP8[$123>>0]|0;
   $125 = ($124<<24>>24)<(0);
   if ($125) {
    $126 = HEAP32[$8>>2]|0;
    HEAP8[$16>>0] = 0;
    __ZNSt3__211char_traitsIcE6assignERcRKc($126,$16);
    $127 = ((($8)) + 4|0);
    HEAP32[$127>>2] = 0;
   } else {
    HEAP8[$17>>0] = 0;
    __ZNSt3__211char_traitsIcE6assignERcRKc($8,$17);
    HEAP8[$123>>0] = 0;
   }
   __THREW__ = 0;
   invoke_vii(4723,($8|0),0);
   $128 = __THREW__; __THREW__ = 0;
   $129 = $128&1;
   if ($129) {
    $130 = ___cxa_find_matching_catch_3(0|0)|0;
    $131 = tempRet0;
    ___clang_call_terminate($130);
    // unreachable;
   }
   ;HEAP32[$8>>2]=HEAP32[$33>>2]|0;HEAP32[$8+4>>2]=HEAP32[$33+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$33+8>>2]|0;
   $$0$i$i$i63 = 0;
   while(1) {
    $exitcond$i$i$i64 = ($$0$i$i$i63|0)==(3);
    if ($exitcond$i$i$i64) {
     break;
    }
    $132 = (($33) + ($$0$i$i$i63<<2)|0);
    HEAP32[$132>>2] = 0;
    $133 = (($$0$i$i$i63) + 1)|0;
    $$0$i$i$i63 = $133;
   }
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($33);
   $$pre$phi81Z2D = $115;
  } else {
   $134 = HEAP32[$115>>2]|0;
   $135 = ((($134)) + 40|0);
   $136 = HEAP32[$135>>2]|0;
   FUNCTION_TABLE_vii[$136 & 8191]($34,$115);
   $137 = HEAP32[$34>>2]|0;
   HEAP8[$3>>0]=$137&255;HEAP8[$3+1>>0]=($137>>8)&255;HEAP8[$3+2>>0]=($137>>16)&255;HEAP8[$3+3>>0]=$137>>24;
   $138 = HEAP32[$115>>2]|0;
   $139 = ((($138)) + 28|0);
   $140 = HEAP32[$139>>2]|0;
   FUNCTION_TABLE_vii[$140 & 8191]($35,$115);
   $141 = ((($8)) + 11|0);
   $142 = HEAP8[$141>>0]|0;
   $143 = ($142<<24>>24)<(0);
   if ($143) {
    $144 = HEAP32[$8>>2]|0;
    HEAP8[$14>>0] = 0;
    __ZNSt3__211char_traitsIcE6assignERcRKc($144,$14);
    $145 = ((($8)) + 4|0);
    HEAP32[$145>>2] = 0;
   } else {
    HEAP8[$15>>0] = 0;
    __ZNSt3__211char_traitsIcE6assignERcRKc($8,$15);
    HEAP8[$141>>0] = 0;
   }
   __THREW__ = 0;
   invoke_vii(4723,($8|0),0);
   $146 = __THREW__; __THREW__ = 0;
   $147 = $146&1;
   if ($147) {
    $148 = ___cxa_find_matching_catch_3(0|0)|0;
    $149 = tempRet0;
    ___clang_call_terminate($148);
    // unreachable;
   }
   ;HEAP32[$8>>2]=HEAP32[$35>>2]|0;HEAP32[$8+4>>2]=HEAP32[$35+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$35+8>>2]|0;
   $$0$i$i$i68 = 0;
   while(1) {
    $exitcond$i$i$i69 = ($$0$i$i$i68|0)==(3);
    if ($exitcond$i$i$i69) {
     break;
    }
    $150 = (($35) + ($$0$i$i$i68<<2)|0);
    HEAP32[$150>>2] = 0;
    $151 = (($$0$i$i$i68) + 1)|0;
    $$0$i$i$i68 = $151;
   }
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($35);
   $$pre$phi81Z2D = $115;
  }
  $152 = HEAP32[$115>>2]|0;
  $153 = ((($152)) + 12|0);
  $154 = HEAP32[$153>>2]|0;
  $155 = (FUNCTION_TABLE_ii[$154 & 8191]($115)|0);
  HEAP8[$4>>0] = $155;
  $156 = HEAP32[$115>>2]|0;
  $157 = ((($156)) + 16|0);
  $158 = HEAP32[$157>>2]|0;
  $159 = (FUNCTION_TABLE_ii[$158 & 8191]($115)|0);
  HEAP8[$5>>0] = $159;
  $160 = HEAP32[$$pre$phi81Z2D>>2]|0;
  $161 = ((($160)) + 20|0);
  $162 = HEAP32[$161>>2]|0;
  FUNCTION_TABLE_vii[$162 & 8191]($36,$115);
  $163 = ((($6)) + 11|0);
  $164 = HEAP8[$163>>0]|0;
  $165 = ($164<<24>>24)<(0);
  if ($165) {
   $166 = HEAP32[$6>>2]|0;
   HEAP8[$12>>0] = 0;
   __ZNSt3__211char_traitsIcE6assignERcRKc($166,$12);
   $167 = ((($6)) + 4|0);
   HEAP32[$167>>2] = 0;
  } else {
   HEAP8[$13>>0] = 0;
   __ZNSt3__211char_traitsIcE6assignERcRKc($6,$13);
   HEAP8[$163>>0] = 0;
  }
  __THREW__ = 0;
  invoke_vii(4723,($6|0),0);
  $168 = __THREW__; __THREW__ = 0;
  $169 = $168&1;
  if ($169) {
   $170 = ___cxa_find_matching_catch_3(0|0)|0;
   $171 = tempRet0;
   ___clang_call_terminate($170);
   // unreachable;
  }
  ;HEAP32[$6>>2]=HEAP32[$36>>2]|0;HEAP32[$6+4>>2]=HEAP32[$36+4>>2]|0;HEAP32[$6+8>>2]=HEAP32[$36+8>>2]|0;
  $$0$i$i$i73 = 0;
  while(1) {
   $exitcond$i$i$i74 = ($$0$i$i$i73|0)==(3);
   if ($exitcond$i$i$i74) {
    break;
   }
   $172 = (($36) + ($$0$i$i$i73<<2)|0);
   HEAP32[$172>>2] = 0;
   $173 = (($$0$i$i$i73) + 1)|0;
   $$0$i$i$i73 = $173;
  }
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($36);
  $174 = HEAP32[$$pre$phi81Z2D>>2]|0;
  $175 = ((($174)) + 24|0);
  $176 = HEAP32[$175>>2]|0;
  FUNCTION_TABLE_vii[$176 & 8191]($37,$115);
  $177 = ((($7)) + 11|0);
  $178 = HEAP8[$177>>0]|0;
  $179 = ($178<<24>>24)<(0);
  if ($179) {
   $180 = HEAP32[$7>>2]|0;
   HEAP8[$10>>0] = 0;
   __ZNSt3__211char_traitsIcE6assignERcRKc($180,$10);
   $181 = ((($7)) + 4|0);
   HEAP32[$181>>2] = 0;
  } else {
   HEAP8[$11>>0] = 0;
   __ZNSt3__211char_traitsIcE6assignERcRKc($7,$11);
   HEAP8[$177>>0] = 0;
  }
  __THREW__ = 0;
  invoke_vii(4723,($7|0),0);
  $182 = __THREW__; __THREW__ = 0;
  $183 = $182&1;
  if ($183) {
   $184 = ___cxa_find_matching_catch_3(0|0)|0;
   $185 = tempRet0;
   ___clang_call_terminate($184);
   // unreachable;
  }
  ;HEAP32[$7>>2]=HEAP32[$37>>2]|0;HEAP32[$7+4>>2]=HEAP32[$37+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[$37+8>>2]|0;
  $$0$i$i$i78 = 0;
  while(1) {
   $exitcond$i$i$i79 = ($$0$i$i$i78|0)==(3);
   if ($exitcond$i$i$i79) {
    break;
   }
   $186 = (($37) + ($$0$i$i$i78<<2)|0);
   HEAP32[$186>>2] = 0;
   $187 = (($$0$i$i$i78) + 1)|0;
   $$0$i$i$i78 = $187;
  }
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($37);
  $188 = HEAP32[$115>>2]|0;
  $189 = ((($188)) + 36|0);
  $190 = HEAP32[$189>>2]|0;
  $191 = (FUNCTION_TABLE_ii[$190 & 8191]($115)|0);
  $storemerge = $191;
 }
 HEAP32[$9>>2] = $storemerge;
 STACKTOP = sp;return;
}
function __ZNSt3__211__money_putIcE8__formatEPcRS2_S3_jPKcS5_RKNS_5ctypeIcEEbRKNS_10money_base7patternEccRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEESL_SL_i($0,$1,$2,$3,$4,$5,$6,$7,$8,$9,$10,$11,$12,$13,$14) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 $8 = $8|0;
 $9 = $9|0;
 $10 = $10|0;
 $11 = $11|0;
 $12 = $12|0;
 $13 = $13|0;
 $14 = $14|0;
 var $$ = 0, $$$097 = 0, $$0 = 0, $$0$i$i = 0, $$0$i$i106 = 0, $$0$i$i113 = 0, $$0101 = 0, $$0104 = 0, $$07$i$i = 0, $$093 = 0, $$095 = 0, $$097 = 0, $$099 = 0, $$1 = 0, $$1100 = 0, $$1102 = 0, $$194 = 0, $$196 = 0, $$2 = 0, $$2103 = 0;
 var $$3 = 0, $$pn = 0, $$sroa$08$0$i = 0, $$sroa$08$0$i112 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0;
 var $136 = 0, $137 = 0, $138 = 0, $139 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $exitcond = 0, $or$cond = 0, $trunc = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$2>>2] = $0;
 $15 = ((($13)) + 11|0);
 $16 = ((($13)) + 4|0);
 $17 = ((($12)) + 11|0);
 $18 = ((($12)) + 4|0);
 $19 = $3 & 512;
 $20 = ($19|0)==(0);
 $21 = ((($6)) + 8|0);
 $22 = ($14|0)>(0);
 $23 = ((($11)) + 11|0);
 $24 = ((($11)) + 4|0);
 $$0104 = 0;$$097 = $4;
 while(1) {
  $exitcond = ($$0104|0)==(4);
  if ($exitcond) {
   break;
  }
  $31 = (($8) + ($$0104)|0);
  $32 = HEAP8[$31>>0]|0;
  $33 = $32 << 24 >> 24;
  L4: do {
   switch ($33|0) {
   case 0:  {
    $34 = HEAP32[$2>>2]|0;
    HEAP32[$1>>2] = $34;
    $$2 = $$097;
    break;
   }
   case 1:  {
    $35 = HEAP32[$2>>2]|0;
    HEAP32[$1>>2] = $35;
    $36 = HEAP32[$6>>2]|0;
    $37 = ((($36)) + 28|0);
    $38 = HEAP32[$37>>2]|0;
    $39 = (FUNCTION_TABLE_iii[$38 & 8191]($6,32)|0);
    $40 = HEAP32[$2>>2]|0;
    $41 = ((($40)) + 1|0);
    HEAP32[$2>>2] = $41;
    HEAP8[$40>>0] = $39;
    $$2 = $$097;
    break;
   }
   case 3:  {
    $42 = HEAP8[$15>>0]|0;
    $43 = ($42<<24>>24)<(0);
    $44 = HEAP32[$16>>2]|0;
    $45 = $42&255;
    $46 = $43 ? $44 : $45;
    $47 = ($46|0)==(0);
    if ($47) {
     $$2 = $$097;
    } else {
     $48 = HEAP32[$13>>2]|0;
     $49 = $43 ? $48 : $13;
     $50 = HEAP8[$49>>0]|0;
     $51 = HEAP32[$2>>2]|0;
     $52 = ((($51)) + 1|0);
     HEAP32[$2>>2] = $52;
     HEAP8[$51>>0] = $50;
     $$2 = $$097;
    }
    break;
   }
   case 2:  {
    $53 = HEAP8[$17>>0]|0;
    $54 = ($53<<24>>24)<(0);
    $55 = HEAP32[$18>>2]|0;
    $56 = $53&255;
    $57 = $54 ? $55 : $56;
    $58 = ($57|0)==(0);
    $or$cond = $20 | $58;
    if ($or$cond) {
     $$2 = $$097;
    } else {
     $59 = HEAP32[$12>>2]|0;
     $60 = $54 ? $59 : $12;
     $61 = (($60) + ($57)|0);
     $62 = HEAP32[$2>>2]|0;
     $$0$i$i113 = $62;$$sroa$08$0$i112 = $60;
     while(1) {
      $63 = ($$sroa$08$0$i112|0)==($61|0);
      if ($63) {
       break;
      }
      $64 = HEAP8[$$sroa$08$0$i112>>0]|0;
      HEAP8[$$0$i$i113>>0] = $64;
      $65 = ((($$sroa$08$0$i112)) + 1|0);
      $66 = ((($$0$i$i113)) + 1|0);
      $$0$i$i113 = $66;$$sroa$08$0$i112 = $65;
     }
     HEAP32[$2>>2] = $$0$i$i113;
     $$2 = $$097;
    }
    break;
   }
   case 4:  {
    $67 = HEAP32[$2>>2]|0;
    $68 = ((($$097)) + 1|0);
    $$$097 = $7 ? $68 : $$097;
    $$0101 = $$$097;
    while(1) {
     $69 = ($$0101>>>0)<($5>>>0);
     if (!($69)) {
      break;
     }
     $70 = HEAP8[$$0101>>0]|0;
     $71 = ($70<<24>>24)>(-1);
     if (!($71)) {
      break;
     }
     $72 = $70 << 24 >> 24;
     $73 = HEAP32[$21>>2]|0;
     $74 = (($73) + ($72<<1)|0);
     $75 = HEAP16[$74>>1]|0;
     $76 = $75 & 2048;
     $77 = ($76<<16>>16)==(0);
     if ($77) {
      break;
     }
     $78 = ((($$0101)) + 1|0);
     $$0101 = $78;
    }
    if ($22) {
     $$099 = $14;$$1102 = $$0101;
     while(1) {
      $79 = ($$1102>>>0)>($$$097>>>0);
      $80 = ($$099|0)>(0);
      $81 = $79 & $80;
      if (!($81)) {
       break;
      }
      $82 = ((($$1102)) + -1|0);
      $83 = HEAP8[$82>>0]|0;
      $84 = HEAP32[$2>>2]|0;
      $85 = ((($84)) + 1|0);
      HEAP32[$2>>2] = $85;
      HEAP8[$84>>0] = $83;
      $86 = (($$099) + -1)|0;
      $$099 = $86;$$1102 = $82;
     }
     if ($80) {
      $87 = HEAP32[$6>>2]|0;
      $88 = ((($87)) + 28|0);
      $89 = HEAP32[$88>>2]|0;
      $90 = (FUNCTION_TABLE_iii[$89 & 8191]($6,48)|0);
      $94 = $90;
     } else {
      $94 = 0;
     }
     $$1100 = $$099;
     while(1) {
      $91 = ($$1100|0)>(0);
      $92 = HEAP32[$2>>2]|0;
      $93 = ((($92)) + 1|0);
      HEAP32[$2>>2] = $93;
      if (!($91)) {
       break;
      }
      HEAP8[$92>>0] = $94;
      $95 = (($$1100) + -1)|0;
      $$1100 = $95;
     }
     HEAP8[$92>>0] = $9;
     $$2103 = $$1102;
    } else {
     $$2103 = $$0101;
    }
    $96 = ($$2103|0)==($$$097|0);
    L35: do {
     if ($96) {
      $97 = HEAP32[$6>>2]|0;
      $98 = ((($97)) + 28|0);
      $99 = HEAP32[$98>>2]|0;
      $100 = (FUNCTION_TABLE_iii[$99 & 8191]($6,48)|0);
      $101 = HEAP32[$2>>2]|0;
      $102 = ((($101)) + 1|0);
      HEAP32[$2>>2] = $102;
      HEAP8[$101>>0] = $100;
     } else {
      $103 = HEAP8[$23>>0]|0;
      $104 = ($103<<24>>24)<(0);
      $105 = HEAP32[$24>>2]|0;
      $106 = $103&255;
      $107 = $104 ? $105 : $106;
      $108 = ($107|0)==(0);
      if ($108) {
       $$0 = -1;$$093 = 0;$$095 = 0;$$3 = $$2103;
      } else {
       $109 = HEAP32[$11>>2]|0;
       $110 = $104 ? $109 : $11;
       $111 = HEAP8[$110>>0]|0;
       $112 = $111 << 24 >> 24;
       $$0 = $112;$$093 = 0;$$095 = 0;$$3 = $$2103;
      }
      while(1) {
       $113 = ($$3|0)==($$$097|0);
       if ($113) {
        break L35;
       }
       $114 = ($$095|0)==($$0|0);
       if ($114) {
        $115 = HEAP32[$2>>2]|0;
        $116 = ((($115)) + 1|0);
        HEAP32[$2>>2] = $116;
        HEAP8[$115>>0] = $10;
        $117 = (($$093) + 1)|0;
        $118 = HEAP8[$23>>0]|0;
        $119 = ($118<<24>>24)<(0);
        $120 = HEAP32[$24>>2]|0;
        $121 = $118&255;
        $122 = $119 ? $120 : $121;
        $123 = ($117>>>0)<($122>>>0);
        if ($123) {
         $124 = HEAP32[$11>>2]|0;
         $125 = $119 ? $124 : $11;
         $126 = (($125) + ($117)|0);
         $127 = HEAP8[$126>>0]|0;
         $128 = ($127<<24>>24)==(127);
         $129 = $127 << 24 >> 24;
         $$ = $128 ? -1 : $129;
         $$1 = $$;$$194 = $117;$$196 = 0;
        } else {
         $$1 = $$095;$$194 = $117;$$196 = 0;
        }
       } else {
        $$1 = $$0;$$194 = $$093;$$196 = $$095;
       }
       $130 = ((($$3)) + -1|0);
       $131 = HEAP8[$130>>0]|0;
       $132 = HEAP32[$2>>2]|0;
       $133 = ((($132)) + 1|0);
       HEAP32[$2>>2] = $133;
       HEAP8[$132>>0] = $131;
       $134 = (($$196) + 1)|0;
       $$0 = $$1;$$093 = $$194;$$095 = $134;$$3 = $130;
      }
     }
    } while(0);
    $135 = HEAP32[$2>>2]|0;
    $136 = ($67|0)==($135|0);
    if ($136) {
     $$2 = $$$097;
    } else {
     $$0$i$i106 = $135;$$07$i$i = $67;
     while(1) {
      $137 = ((($$0$i$i106)) + -1|0);
      $138 = ($$07$i$i>>>0)<($137>>>0);
      if (!($138)) {
       $$2 = $$$097;
       break L4;
      }
      $139 = HEAP8[$$07$i$i>>0]|0;
      $140 = HEAP8[$137>>0]|0;
      HEAP8[$$07$i$i>>0] = $140;
      HEAP8[$137>>0] = $139;
      $141 = ((($$07$i$i)) + 1|0);
      $$0$i$i106 = $137;$$07$i$i = $141;
     }
    }
    break;
   }
   default: {
    $$2 = $$097;
   }
   }
  } while(0);
  $142 = (($$0104) + 1)|0;
  $$0104 = $142;$$097 = $$2;
 }
 $25 = HEAP8[$15>>0]|0;
 $26 = ($25<<24>>24)<(0);
 $27 = HEAP32[$16>>2]|0;
 $28 = $25&255;
 $29 = $26 ? $27 : $28;
 $30 = ($29>>>0)>(1);
 if ($30) {
  $143 = HEAP32[$13>>2]|0;
  $144 = $26 ? $143 : $13;
  $145 = (($144) + ($29)|0);
  $146 = HEAP32[$2>>2]|0;
  $$0$i$i = $146;$$pn = $144;
  while(1) {
   $$sroa$08$0$i = ((($$pn)) + 1|0);
   $147 = ($$sroa$08$0$i|0)==($145|0);
   if ($147) {
    break;
   }
   $148 = HEAP8[$$sroa$08$0$i>>0]|0;
   HEAP8[$$0$i$i>>0] = $148;
   $149 = ((($$0$i$i)) + 1|0);
   $$0$i$i = $149;$$pn = $$sroa$08$0$i;
  }
  HEAP32[$2>>2] = $$0$i$i;
 }
 $150 = $3 & 176;
 $trunc = $150&255;
 switch ($trunc<<24>>24) {
 case 32:  {
  $151 = HEAP32[$2>>2]|0;
  HEAP32[$1>>2] = $151;
  break;
 }
 case 16:  {
  break;
 }
 default: {
  HEAP32[$1>>2] = $0;
 }
 }
 return;
}
function __ZNSt3__29money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEED2Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__26locale5facetD2Ev($0);
 return;
}
function __ZNSt3__29money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEED0Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__26locale5facetD2Ev($0);
 __ZdlPv($0);
 return;
}
function __ZNKSt3__29money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_bRNS_8ios_baseEwe($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = +$5;
 var $$0 = 0, $$0$i$i = 0, $$0$i$i54 = 0, $$0$i$i56 = 0, $$046 = 0, $$047 = 0, $$048 = 0, $$049 = 0, $$1 = 0, $$150 = 0, $$3 = 0, $$352 = 0, $$4 = 0, $$453 = 0, $$byval_copy = 0, $$sink = 0, $$sink1 = 0, $$sink102 = 0, $$sink103 = 0, $$sroa$068$0 = 0;
 var $$sroa$068$1 = 0, $$sroa$080$0 = 0, $$sroa$080$1 = 0, $$sroa$080$2 = 0, $$sroa$093$0 = 0, $$sroa$093$1 = 0, $$sroa$093$2 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i$i = 0, $exitcond$i$i55 = 0, $exitcond$i$i57 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1008|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(1008|0);
 $$byval_copy = sp + 892|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $6 = sp + 900|0;
 $7 = sp + 888|0;
 $8 = sp + 488|0;
 $9 = sp + 480|0;
 $10 = sp + 896|0;
 $11 = sp + 476|0;
 $12 = sp + 472|0;
 $13 = sp + 460|0;
 $14 = sp + 448|0;
 $15 = sp + 436|0;
 $16 = sp + 432|0;
 $17 = sp + 32|0;
 $18 = sp + 24|0;
 $19 = sp + 20|0;
 $20 = sp + 16|0;
 HEAP32[$7>>2] = $6;
 HEAPF64[$vararg_buffer>>3] = $5;
 $21 = (_snprintf($6,100,204171,$vararg_buffer)|0);
 $22 = ($21>>>0)>(99);
 do {
  if ($22) {
   __THREW__ = 0;
   $23 = (invoke_i(4668)|0);
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   if ($25) {
    $$sroa$080$0 = 0;$$sroa$093$0 = 0;
    label = 6;
   } else {
    __THREW__ = 0;
    HEAPF64[$vararg_buffer1>>3] = $5;
    $26 = (invoke_iiiii(4690,($7|0),($23|0),(204171|0),($vararg_buffer1|0))|0);
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     $$sroa$080$0 = 0;$$sroa$093$0 = 0;
     label = 6;
    } else {
     $29 = HEAP32[$7>>2]|0;
     $30 = ($29|0)==(0|0);
     if ($30) {
      __THREW__ = 0;
      invoke_v(4685);
      $31 = __THREW__; __THREW__ = 0;
      $$sroa$080$0 = 0;$$sroa$093$0 = 0;
      label = 6;
      break;
     }
     $34 = $29;
     $35 = $26 << 2;
     $36 = (_malloc($35)|0);
     $37 = $36;
     $38 = ($36|0)==(0|0);
     if ($38) {
      __THREW__ = 0;
      invoke_v(4685);
      $39 = __THREW__; __THREW__ = 0;
      $$sroa$080$0 = $37;$$sroa$093$0 = $34;
      label = 6;
     } else {
      $$0 = $36;$$047 = $26;$$sroa$080$1 = $37;$$sroa$093$1 = $34;
      label = 9;
     }
    }
   }
  } else {
   $$0 = $8;$$047 = $21;$$sroa$080$1 = 0;$$sroa$093$1 = 0;
   label = 9;
  }
 } while(0);
 if ((label|0) == 9) {
  __THREW__ = 0;
  invoke_vii(3257,($9|0),($3|0));
  $40 = __THREW__; __THREW__ = 0;
  $41 = $40&1;
  if ($41) {
   $$sroa$080$0 = $$sroa$080$1;$$sroa$093$0 = $$sroa$093$1;
   label = 6;
  } else {
   __THREW__ = 0;
   $42 = (invoke_iii(3255,($9|0),(215220|0))|0);
   $43 = __THREW__; __THREW__ = 0;
   $44 = $43&1;
   do {
    if ($44) {
     $112 = ___cxa_find_matching_catch_2()|0;
     $113 = tempRet0;
     $$3 = $112;$$352 = $113;
    } else {
     $45 = HEAP32[$7>>2]|0;
     $46 = (($45) + ($$047)|0);
     $47 = HEAP32[$42>>2]|0;
     $48 = ((($47)) + 48|0);
     $49 = HEAP32[$48>>2]|0;
     __THREW__ = 0;
     (invoke_iiiii($49|0,($42|0),($45|0),($46|0),($$0|0))|0);
     $50 = __THREW__; __THREW__ = 0;
     $51 = $50&1;
     if ($51) {
      $114 = ___cxa_find_matching_catch_2()|0;
      $115 = tempRet0;
      $$3 = $114;$$352 = $115;
      break;
     }
     $52 = ($$047|0)==(0);
     if ($52) {
      $62 = 0;
     } else {
      $53 = HEAP32[$7>>2]|0;
      $54 = HEAP8[$53>>0]|0;
      $55 = ($54<<24>>24)==(45);
      $62 = $55;
     }
     ;HEAP32[$13>>2]=0|0;HEAP32[$13+4>>2]=0|0;HEAP32[$13+8>>2]=0|0;
     $$0$i$i = 0;
     while(1) {
      $exitcond$i$i = ($$0$i$i|0)==(3);
      if ($exitcond$i$i) {
       break;
      }
      $56 = (($13) + ($$0$i$i<<2)|0);
      HEAP32[$56>>2] = 0;
      $57 = (($$0$i$i) + 1)|0;
      $$0$i$i = $57;
     }
     ;HEAP32[$14>>2]=0|0;HEAP32[$14+4>>2]=0|0;HEAP32[$14+8>>2]=0|0;
     $$0$i$i54 = 0;
     while(1) {
      $exitcond$i$i55 = ($$0$i$i54|0)==(3);
      if ($exitcond$i$i55) {
       break;
      }
      $58 = (($14) + ($$0$i$i54<<2)|0);
      HEAP32[$58>>2] = 0;
      $59 = (($$0$i$i54) + 1)|0;
      $$0$i$i54 = $59;
     }
     ;HEAP32[$15>>2]=0|0;HEAP32[$15+4>>2]=0|0;HEAP32[$15+8>>2]=0|0;
     $$0$i$i56 = 0;
     while(1) {
      $exitcond$i$i57 = ($$0$i$i56|0)==(3);
      if ($exitcond$i$i57) {
       break;
      }
      $60 = (($15) + ($$0$i$i56<<2)|0);
      HEAP32[$60>>2] = 0;
      $61 = (($$0$i$i56) + 1)|0;
      $$0$i$i56 = $61;
     }
     __THREW__ = 0;
     invoke_viiiiiiiiii(4734,($2|0),($62|0),($9|0),($10|0),($11|0),($12|0),($13|0),($14|0),($15|0),($16|0));
     $63 = __THREW__; __THREW__ = 0;
     $64 = $63&1;
     if ($64) {
      $116 = ___cxa_find_matching_catch_2()|0;
      $117 = tempRet0;
      $$1 = $116;$$150 = $117;
     } else {
      $65 = HEAP32[$16>>2]|0;
      $66 = ($$047|0)>($65|0);
      if ($66) {
       $67 = (($$047) - ($65))|0;
       $68 = $67 << 1;
       $69 = ((($15)) + 8|0);
       $70 = ((($69)) + 3|0);
       $71 = HEAP8[$70>>0]|0;
       $72 = ($71<<24>>24)<(0);
       $73 = ((($15)) + 4|0);
       $74 = HEAP32[$73>>2]|0;
       $75 = $71&255;
       $76 = $72 ? $74 : $75;
       $77 = (($76) + ($68))|0;
       $78 = ((($14)) + 8|0);
       $79 = ((($78)) + 3|0);
       $80 = HEAP8[$79>>0]|0;
       $81 = ($80<<24>>24)<(0);
       $82 = ((($14)) + 4|0);
       $83 = HEAP32[$82>>2]|0;
       $84 = $80&255;
       $85 = $81 ? $83 : $84;
       $$sink1 = 1;$$sink102 = $77;$$sink103 = $85;
      } else {
       $86 = ((($15)) + 8|0);
       $87 = ((($86)) + 3|0);
       $88 = HEAP8[$87>>0]|0;
       $89 = ($88<<24>>24)<(0);
       $90 = ((($15)) + 4|0);
       $91 = HEAP32[$90>>2]|0;
       $92 = $88&255;
       $93 = $89 ? $91 : $92;
       $94 = ((($14)) + 8|0);
       $95 = ((($94)) + 3|0);
       $96 = HEAP8[$95>>0]|0;
       $97 = ($96<<24>>24)<(0);
       $98 = ((($14)) + 4|0);
       $99 = HEAP32[$98>>2]|0;
       $100 = $96&255;
       $101 = $97 ? $99 : $100;
       $$sink1 = 2;$$sink102 = $101;$$sink103 = $93;
      }
      $102 = (($$sink103) + ($65))|0;
      $$sink = (($102) + ($$sink102))|0;
      $103 = (($$sink) + ($$sink1))|0;
      $104 = ($103>>>0)>(100);
      if ($104) {
       $105 = $103 << 2;
       $106 = (_malloc($105)|0);
       $107 = $106;
       $108 = ($106|0)==(0|0);
       if ($108) {
        __THREW__ = 0;
        invoke_v(4685);
        $109 = __THREW__; __THREW__ = 0;
        $110 = ___cxa_find_matching_catch_2()|0;
        $111 = tempRet0;
        $$048 = $110;$$049 = $111;$$sroa$068$1 = $107;
       } else {
        $$046 = $106;$$sroa$068$0 = $107;
        label = 33;
       }
      } else {
       $$046 = $17;$$sroa$068$0 = 0;
       label = 33;
      }
      if ((label|0) == 33) {
       $118 = ((($3)) + 4|0);
       $119 = HEAP32[$118>>2]|0;
       $120 = (($$0) + ($$047<<2)|0);
       $121 = HEAP32[$11>>2]|0;
       $122 = HEAP32[$12>>2]|0;
       __THREW__ = 0;
       invoke_viiiiiiiiiiiiiii(4735,($$046|0),($18|0),($19|0),($119|0),($$0|0),($120|0),($42|0),($62|0),($10|0),($121|0),($122|0),($13|0),($14|0),($15|0),($65|0));
       $123 = __THREW__; __THREW__ = 0;
       $124 = $123&1;
       if (!($124)) {
        $125 = HEAP32[$1>>2]|0;
        HEAP32[$20>>2] = $125;
        $126 = HEAP32[$18>>2]|0;
        $127 = HEAP32[$19>>2]|0;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy>>2]=HEAP32[$20>>2]|0;
        $128 = (invoke_iiiiiii(4697,($$byval_copy|0),($$046|0),($126|0),($127|0),($3|0),($4|0))|0);
        $129 = __THREW__; __THREW__ = 0;
        $130 = $129&1;
        if (!($130)) {
         $131 = ($$sroa$068$0|0)==(0);
         if (!($131)) {
          $132 = $$sroa$068$0;
          _free($132);
         }
         __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev($15);
         __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev($14);
         __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($13);
         __ZNSt3__26localeD2Ev($9);
         $133 = ($$sroa$080$1|0)==(0);
         if (!($133)) {
          $134 = $$sroa$080$1;
          _free($134);
         }
         $135 = ($$sroa$093$1|0)==(0);
         if (!($135)) {
          $136 = $$sroa$093$1;
          _free($136);
         }
         STACKTOP = sp;return ($128|0);
        }
       }
       $137 = ___cxa_find_matching_catch_2()|0;
       $138 = tempRet0;
       $$048 = $137;$$049 = $138;$$sroa$068$1 = $$sroa$068$0;
      }
      $139 = ($$sroa$068$1|0)==(0);
      if (!($139)) {
       $140 = $$sroa$068$1;
       _free($140);
      }
      $$1 = $$048;$$150 = $$049;
     }
     __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev($15);
     __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev($14);
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($13);
     $$3 = $$1;$$352 = $$150;
    }
   } while(0);
   __ZNSt3__26localeD2Ev($9);
   $$4 = $$3;$$453 = $$352;$$sroa$080$2 = $$sroa$080$1;$$sroa$093$2 = $$sroa$093$1;
  }
 }
 if ((label|0) == 6) {
  $32 = ___cxa_find_matching_catch_2()|0;
  $33 = tempRet0;
  $$4 = $32;$$453 = $33;$$sroa$080$2 = $$sroa$080$0;$$sroa$093$2 = $$sroa$093$0;
 }
 $141 = ($$sroa$080$2|0)==(0);
 if (!($141)) {
  $142 = $$sroa$080$2;
  _free($142);
 }
 $143 = ($$sroa$093$2|0)==(0);
 if (!($143)) {
  $144 = $$sroa$093$2;
  _free($144);
 }
 ___resumeException($$4|0);
 // unreachable;
 return (0)|0;
}
function __ZNKSt3__29money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_bRNS_8ios_baseEwRKNS_12basic_stringIwS3_NS_9allocatorIwEEEE($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$0 = 0, $$0$i$i = 0, $$0$i$i37 = 0, $$0$i$i39 = 0, $$032 = 0, $$033 = 0, $$1 = 0, $$134 = 0, $$3 = 0, $$336 = 0, $$byval_copy = 0, $$sink = 0, $$sink1 = 0, $$sink62 = 0, $$sink63 = 0, $$sroa$052$0 = 0, $$sroa$052$1 = 0, $10 = 0, $100 = 0, $101 = 0;
 var $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0;
 var $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i$i = 0;
 var $exitcond$i$i38 = 0, $exitcond$i$i40 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 480|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(480|0);
 $$byval_copy = sp + 468|0;
 $6 = sp + 464|0;
 $7 = sp + 472|0;
 $8 = sp + 460|0;
 $9 = sp + 456|0;
 $10 = sp + 444|0;
 $11 = sp + 432|0;
 $12 = sp + 420|0;
 $13 = sp + 416|0;
 $14 = sp + 16|0;
 $15 = sp + 8|0;
 $16 = sp + 4|0;
 $17 = sp;
 __ZNKSt3__28ios_base6getlocEv($6,$3);
 __THREW__ = 0;
 $18 = (invoke_iii(3255,($6|0),(215220|0))|0);
 $19 = __THREW__; __THREW__ = 0;
 $20 = $19&1;
 L1: do {
  if ($20) {
   $101 = ___cxa_find_matching_catch_2()|0;
   $102 = tempRet0;
   $$3 = $101;$$336 = $102;
  } else {
   $21 = ((($5)) + 8|0);
   $22 = ((($21)) + 3|0);
   $23 = HEAP8[$22>>0]|0;
   $24 = ($23<<24>>24)<(0);
   $25 = ((($5)) + 4|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = $23&255;
   $28 = $24 ? $26 : $27;
   $29 = ($28|0)==(0);
   do {
    if ($29) {
     $46 = 0;
    } else {
     $30 = HEAP32[$5>>2]|0;
     $31 = $24 ? $30 : $5;
     $32 = HEAP32[$31>>2]|0;
     $33 = HEAP32[$18>>2]|0;
     $34 = ((($33)) + 44|0);
     $35 = HEAP32[$34>>2]|0;
     __THREW__ = 0;
     $36 = (invoke_iii($35|0,($18|0),45)|0);
     $37 = __THREW__; __THREW__ = 0;
     $38 = $37&1;
     if ($38) {
      $103 = ___cxa_find_matching_catch_2()|0;
      $104 = tempRet0;
      $$3 = $103;$$336 = $104;
      break L1;
     } else {
      $39 = ($32|0)==($36|0);
      $46 = $39;
      break;
     }
    }
   } while(0);
   ;HEAP32[$10>>2]=0|0;HEAP32[$10+4>>2]=0|0;HEAP32[$10+8>>2]=0|0;
   $$0$i$i = 0;
   while(1) {
    $exitcond$i$i = ($$0$i$i|0)==(3);
    if ($exitcond$i$i) {
     break;
    }
    $40 = (($10) + ($$0$i$i<<2)|0);
    HEAP32[$40>>2] = 0;
    $41 = (($$0$i$i) + 1)|0;
    $$0$i$i = $41;
   }
   ;HEAP32[$11>>2]=0|0;HEAP32[$11+4>>2]=0|0;HEAP32[$11+8>>2]=0|0;
   $$0$i$i37 = 0;
   while(1) {
    $exitcond$i$i38 = ($$0$i$i37|0)==(3);
    if ($exitcond$i$i38) {
     break;
    }
    $42 = (($11) + ($$0$i$i37<<2)|0);
    HEAP32[$42>>2] = 0;
    $43 = (($$0$i$i37) + 1)|0;
    $$0$i$i37 = $43;
   }
   ;HEAP32[$12>>2]=0|0;HEAP32[$12+4>>2]=0|0;HEAP32[$12+8>>2]=0|0;
   $$0$i$i39 = 0;
   while(1) {
    $exitcond$i$i40 = ($$0$i$i39|0)==(3);
    if ($exitcond$i$i40) {
     break;
    }
    $44 = (($12) + ($$0$i$i39<<2)|0);
    HEAP32[$44>>2] = 0;
    $45 = (($$0$i$i39) + 1)|0;
    $$0$i$i39 = $45;
   }
   __THREW__ = 0;
   invoke_viiiiiiiiii(4734,($2|0),($46|0),($6|0),($7|0),($8|0),($9|0),($10|0),($11|0),($12|0),($13|0));
   $47 = __THREW__; __THREW__ = 0;
   $48 = $47&1;
   if ($48) {
    $105 = ___cxa_find_matching_catch_2()|0;
    $106 = tempRet0;
    $$1 = $105;$$134 = $106;
   } else {
    $49 = HEAP8[$22>>0]|0;
    $50 = ($49<<24>>24)<(0);
    $51 = HEAP32[$25>>2]|0;
    $52 = $49&255;
    $53 = $50 ? $51 : $52;
    $54 = HEAP32[$13>>2]|0;
    $55 = ($53|0)>($54|0);
    if ($55) {
     $56 = (($53) - ($54))|0;
     $57 = $56 << 1;
     $58 = ((($12)) + 8|0);
     $59 = ((($58)) + 3|0);
     $60 = HEAP8[$59>>0]|0;
     $61 = ($60<<24>>24)<(0);
     $62 = ((($12)) + 4|0);
     $63 = HEAP32[$62>>2]|0;
     $64 = $60&255;
     $65 = $61 ? $63 : $64;
     $66 = (($65) + ($57))|0;
     $67 = ((($11)) + 8|0);
     $68 = ((($67)) + 3|0);
     $69 = HEAP8[$68>>0]|0;
     $70 = ($69<<24>>24)<(0);
     $71 = ((($11)) + 4|0);
     $72 = HEAP32[$71>>2]|0;
     $73 = $69&255;
     $74 = $70 ? $72 : $73;
     $$sink1 = 1;$$sink62 = $66;$$sink63 = $74;
    } else {
     $75 = ((($12)) + 8|0);
     $76 = ((($75)) + 3|0);
     $77 = HEAP8[$76>>0]|0;
     $78 = ($77<<24>>24)<(0);
     $79 = ((($12)) + 4|0);
     $80 = HEAP32[$79>>2]|0;
     $81 = $77&255;
     $82 = $78 ? $80 : $81;
     $83 = ((($11)) + 8|0);
     $84 = ((($83)) + 3|0);
     $85 = HEAP8[$84>>0]|0;
     $86 = ($85<<24>>24)<(0);
     $87 = ((($11)) + 4|0);
     $88 = HEAP32[$87>>2]|0;
     $89 = $85&255;
     $90 = $86 ? $88 : $89;
     $$sink1 = 2;$$sink62 = $90;$$sink63 = $82;
    }
    $91 = (($$sink63) + ($54))|0;
    $$sink = (($91) + ($$sink62))|0;
    $92 = (($$sink) + ($$sink1))|0;
    $93 = ($92>>>0)>(100);
    if ($93) {
     $94 = $92 << 2;
     $95 = (_malloc($94)|0);
     $96 = $95;
     $97 = ($95|0)==(0|0);
     if ($97) {
      __THREW__ = 0;
      invoke_v(4685);
      $98 = __THREW__; __THREW__ = 0;
      $99 = ___cxa_find_matching_catch_2()|0;
      $100 = tempRet0;
      $$0 = $99;$$033 = $100;$$sroa$052$1 = $96;
     } else {
      $$032 = $95;$$sroa$052$0 = $96;
      label = 24;
     }
    } else {
     $$032 = $14;$$sroa$052$0 = 0;
     label = 24;
    }
    if ((label|0) == 24) {
     $107 = ((($3)) + 4|0);
     $108 = HEAP32[$107>>2]|0;
     $109 = HEAP32[$5>>2]|0;
     $110 = $50 ? $109 : $5;
     $111 = (($110) + ($53<<2)|0);
     $112 = HEAP32[$8>>2]|0;
     $113 = HEAP32[$9>>2]|0;
     __THREW__ = 0;
     invoke_viiiiiiiiiiiiiii(4735,($$032|0),($15|0),($16|0),($108|0),($110|0),($111|0),($18|0),($46|0),($7|0),($112|0),($113|0),($10|0),($11|0),($12|0),($54|0));
     $114 = __THREW__; __THREW__ = 0;
     $115 = $114&1;
     if (!($115)) {
      $116 = HEAP32[$1>>2]|0;
      HEAP32[$17>>2] = $116;
      $117 = HEAP32[$15>>2]|0;
      $118 = HEAP32[$16>>2]|0;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy>>2]=HEAP32[$17>>2]|0;
      $119 = (invoke_iiiiiii(4697,($$byval_copy|0),($$032|0),($117|0),($118|0),($3|0),($4|0))|0);
      $120 = __THREW__; __THREW__ = 0;
      $121 = $120&1;
      if (!($121)) {
       $122 = ($$sroa$052$0|0)==(0);
       if (!($122)) {
        $123 = $$sroa$052$0;
        _free($123);
       }
       __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev($12);
       __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev($11);
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($10);
       __ZNSt3__26localeD2Ev($6);
       STACKTOP = sp;return ($119|0);
      }
     }
     $124 = ___cxa_find_matching_catch_2()|0;
     $125 = tempRet0;
     $$0 = $124;$$033 = $125;$$sroa$052$1 = $$sroa$052$0;
    }
    $126 = ($$sroa$052$1|0)==(0);
    if (!($126)) {
     $127 = $$sroa$052$1;
     _free($127);
    }
    $$1 = $$0;$$134 = $$033;
   }
   __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev($12);
   __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev($11);
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($10);
   $$3 = $$1;$$336 = $$134;
  }
 } while(0);
 __ZNSt3__26localeD2Ev($6);
 ___resumeException($$3|0);
 // unreachable;
 return (0)|0;
}
function __ZNSt3__211__money_putIwE13__gather_infoEbbRKNS_6localeERNS_10money_base7patternERwS8_RNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERNS9_IwNSA_IwEENSC_IwEEEESJ_Ri($0,$1,$2,$3,$4,$5,$6,$7,$8,$9) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 $8 = $8|0;
 $9 = $9|0;
 var $$0$i$i$i = 0, $$0$i$i$i48 = 0, $$0$i$i$i51 = 0, $$0$i$i$i55 = 0, $$0$i$i$i60 = 0, $$0$i$i$i65 = 0, $$0$i$i$i70 = 0, $$0$i$i$i75 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0;
 var $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0;
 var $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i$i$i = 0, $exitcond$i$i$i49 = 0, $exitcond$i$i$i52 = 0, $exitcond$i$i$i56 = 0;
 var $exitcond$i$i$i61 = 0, $exitcond$i$i$i66 = 0, $exitcond$i$i$i71 = 0, $exitcond$i$i$i76 = 0, $storemerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(176|0);
 $10 = sp + 156|0;
 $11 = sp + 152|0;
 $12 = sp + 163|0;
 $13 = sp + 162|0;
 $14 = sp + 148|0;
 $15 = sp + 144|0;
 $16 = sp + 140|0;
 $17 = sp + 136|0;
 $18 = sp + 132|0;
 $19 = sp + 128|0;
 $20 = sp + 161|0;
 $21 = sp + 160|0;
 $22 = sp + 124|0;
 $23 = sp + 120|0;
 $24 = sp + 116|0;
 $25 = sp + 112|0;
 $26 = sp + 108|0;
 $27 = sp + 96|0;
 $28 = sp + 92|0;
 $29 = sp + 80|0;
 $30 = sp + 68|0;
 $31 = sp + 56|0;
 $32 = sp + 52|0;
 $33 = sp + 40|0;
 $34 = sp + 36|0;
 $35 = sp + 24|0;
 $36 = sp + 12|0;
 $37 = sp;
 if ($0) {
  $38 = (__ZNKSt3__26locale9use_facetERNS0_2idE($2,216924)|0);
  if ($1) {
   $39 = HEAP32[$38>>2]|0;
   $40 = ((($39)) + 44|0);
   $41 = HEAP32[$40>>2]|0;
   FUNCTION_TABLE_vii[$41 & 8191]($26,$38);
   $42 = HEAP32[$26>>2]|0;
   HEAP8[$3>>0]=$42&255;HEAP8[$3+1>>0]=($42>>8)&255;HEAP8[$3+2>>0]=($42>>16)&255;HEAP8[$3+3>>0]=$42>>24;
   $43 = HEAP32[$38>>2]|0;
   $44 = ((($43)) + 32|0);
   $45 = HEAP32[$44>>2]|0;
   FUNCTION_TABLE_vii[$45 & 8191]($27,$38);
   $46 = ((($8)) + 8|0);
   $47 = ((($46)) + 3|0);
   $48 = HEAP8[$47>>0]|0;
   $49 = ($48<<24>>24)<(0);
   if ($49) {
    $50 = HEAP32[$8>>2]|0;
    HEAP32[$24>>2] = 0;
    __ZNSt3__211char_traitsIwE6assignERwRKw($50,$24);
    $51 = ((($8)) + 4|0);
    HEAP32[$51>>2] = 0;
   } else {
    HEAP32[$25>>2] = 0;
    __ZNSt3__211char_traitsIwE6assignERwRKw($8,$25);
    HEAP8[$47>>0] = 0;
   }
   __THREW__ = 0;
   invoke_vii(4731,($8|0),0);
   $52 = __THREW__; __THREW__ = 0;
   $53 = $52&1;
   if ($53) {
    $54 = ___cxa_find_matching_catch_3(0|0)|0;
    $55 = tempRet0;
    ___clang_call_terminate($54);
    // unreachable;
   }
   ;HEAP32[$8>>2]=HEAP32[$27>>2]|0;HEAP32[$8+4>>2]=HEAP32[$27+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$27+8>>2]|0;
   $$0$i$i$i = 0;
   while(1) {
    $exitcond$i$i$i = ($$0$i$i$i|0)==(3);
    if ($exitcond$i$i$i) {
     break;
    }
    $56 = (($27) + ($$0$i$i$i<<2)|0);
    HEAP32[$56>>2] = 0;
    $57 = (($$0$i$i$i) + 1)|0;
    $$0$i$i$i = $57;
   }
   __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev($27);
  } else {
   $58 = HEAP32[$38>>2]|0;
   $59 = ((($58)) + 40|0);
   $60 = HEAP32[$59>>2]|0;
   FUNCTION_TABLE_vii[$60 & 8191]($28,$38);
   $61 = HEAP32[$28>>2]|0;
   HEAP8[$3>>0]=$61&255;HEAP8[$3+1>>0]=($61>>8)&255;HEAP8[$3+2>>0]=($61>>16)&255;HEAP8[$3+3>>0]=$61>>24;
   $62 = HEAP32[$38>>2]|0;
   $63 = ((($62)) + 28|0);
   $64 = HEAP32[$63>>2]|0;
   FUNCTION_TABLE_vii[$64 & 8191]($29,$38);
   $65 = ((($8)) + 8|0);
   $66 = ((($65)) + 3|0);
   $67 = HEAP8[$66>>0]|0;
   $68 = ($67<<24>>24)<(0);
   if ($68) {
    $69 = HEAP32[$8>>2]|0;
    HEAP32[$22>>2] = 0;
    __ZNSt3__211char_traitsIwE6assignERwRKw($69,$22);
    $70 = ((($8)) + 4|0);
    HEAP32[$70>>2] = 0;
   } else {
    HEAP32[$23>>2] = 0;
    __ZNSt3__211char_traitsIwE6assignERwRKw($8,$23);
    HEAP8[$66>>0] = 0;
   }
   __THREW__ = 0;
   invoke_vii(4731,($8|0),0);
   $71 = __THREW__; __THREW__ = 0;
   $72 = $71&1;
   if ($72) {
    $73 = ___cxa_find_matching_catch_3(0|0)|0;
    $74 = tempRet0;
    ___clang_call_terminate($73);
    // unreachable;
   }
   ;HEAP32[$8>>2]=HEAP32[$29>>2]|0;HEAP32[$8+4>>2]=HEAP32[$29+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$29+8>>2]|0;
   $$0$i$i$i48 = 0;
   while(1) {
    $exitcond$i$i$i49 = ($$0$i$i$i48|0)==(3);
    if ($exitcond$i$i$i49) {
     break;
    }
    $75 = (($29) + ($$0$i$i$i48<<2)|0);
    HEAP32[$75>>2] = 0;
    $76 = (($$0$i$i$i48) + 1)|0;
    $$0$i$i$i48 = $76;
   }
   __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev($29);
  }
  $77 = HEAP32[$38>>2]|0;
  $78 = ((($77)) + 12|0);
  $79 = HEAP32[$78>>2]|0;
  $80 = (FUNCTION_TABLE_ii[$79 & 8191]($38)|0);
  HEAP32[$4>>2] = $80;
  $81 = HEAP32[$38>>2]|0;
  $82 = ((($81)) + 16|0);
  $83 = HEAP32[$82>>2]|0;
  $84 = (FUNCTION_TABLE_ii[$83 & 8191]($38)|0);
  HEAP32[$5>>2] = $84;
  $85 = HEAP32[$38>>2]|0;
  $86 = ((($85)) + 20|0);
  $87 = HEAP32[$86>>2]|0;
  FUNCTION_TABLE_vii[$87 & 8191]($30,$38);
  $88 = ((($6)) + 11|0);
  $89 = HEAP8[$88>>0]|0;
  $90 = ($89<<24>>24)<(0);
  if ($90) {
   $91 = HEAP32[$6>>2]|0;
   HEAP8[$20>>0] = 0;
   __ZNSt3__211char_traitsIcE6assignERcRKc($91,$20);
   $92 = ((($6)) + 4|0);
   HEAP32[$92>>2] = 0;
  } else {
   HEAP8[$21>>0] = 0;
   __ZNSt3__211char_traitsIcE6assignERcRKc($6,$21);
   HEAP8[$88>>0] = 0;
  }
  __THREW__ = 0;
  invoke_vii(4723,($6|0),0);
  $93 = __THREW__; __THREW__ = 0;
  $94 = $93&1;
  if ($94) {
   $95 = ___cxa_find_matching_catch_3(0|0)|0;
   $96 = tempRet0;
   ___clang_call_terminate($95);
   // unreachable;
  }
  ;HEAP32[$6>>2]=HEAP32[$30>>2]|0;HEAP32[$6+4>>2]=HEAP32[$30+4>>2]|0;HEAP32[$6+8>>2]=HEAP32[$30+8>>2]|0;
  $$0$i$i$i51 = 0;
  while(1) {
   $exitcond$i$i$i52 = ($$0$i$i$i51|0)==(3);
   if ($exitcond$i$i$i52) {
    break;
   }
   $97 = (($30) + ($$0$i$i$i51<<2)|0);
   HEAP32[$97>>2] = 0;
   $98 = (($$0$i$i$i51) + 1)|0;
   $$0$i$i$i51 = $98;
  }
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($30);
  $99 = HEAP32[$38>>2]|0;
  $100 = ((($99)) + 24|0);
  $101 = HEAP32[$100>>2]|0;
  FUNCTION_TABLE_vii[$101 & 8191]($31,$38);
  $102 = ((($7)) + 8|0);
  $103 = ((($102)) + 3|0);
  $104 = HEAP8[$103>>0]|0;
  $105 = ($104<<24>>24)<(0);
  if ($105) {
   $106 = HEAP32[$7>>2]|0;
   HEAP32[$18>>2] = 0;
   __ZNSt3__211char_traitsIwE6assignERwRKw($106,$18);
   $107 = ((($7)) + 4|0);
   HEAP32[$107>>2] = 0;
  } else {
   HEAP32[$19>>2] = 0;
   __ZNSt3__211char_traitsIwE6assignERwRKw($7,$19);
   HEAP8[$103>>0] = 0;
  }
  __THREW__ = 0;
  invoke_vii(4731,($7|0),0);
  $108 = __THREW__; __THREW__ = 0;
  $109 = $108&1;
  if ($109) {
   $110 = ___cxa_find_matching_catch_3(0|0)|0;
   $111 = tempRet0;
   ___clang_call_terminate($110);
   // unreachable;
  }
  ;HEAP32[$7>>2]=HEAP32[$31>>2]|0;HEAP32[$7+4>>2]=HEAP32[$31+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[$31+8>>2]|0;
  $$0$i$i$i55 = 0;
  while(1) {
   $exitcond$i$i$i56 = ($$0$i$i$i55|0)==(3);
   if ($exitcond$i$i$i56) {
    break;
   }
   $112 = (($31) + ($$0$i$i$i55<<2)|0);
   HEAP32[$112>>2] = 0;
   $113 = (($$0$i$i$i55) + 1)|0;
   $$0$i$i$i55 = $113;
  }
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev($31);
  $114 = HEAP32[$38>>2]|0;
  $115 = ((($114)) + 36|0);
  $116 = HEAP32[$115>>2]|0;
  $117 = (FUNCTION_TABLE_ii[$116 & 8191]($38)|0);
  $storemerge = $117;
 } else {
  $118 = (__ZNKSt3__26locale9use_facetERNS0_2idE($2,216916)|0);
  if ($1) {
   $119 = HEAP32[$118>>2]|0;
   $120 = ((($119)) + 44|0);
   $121 = HEAP32[$120>>2]|0;
   FUNCTION_TABLE_vii[$121 & 8191]($32,$118);
   $122 = HEAP32[$32>>2]|0;
   HEAP8[$3>>0]=$122&255;HEAP8[$3+1>>0]=($122>>8)&255;HEAP8[$3+2>>0]=($122>>16)&255;HEAP8[$3+3>>0]=$122>>24;
   $123 = HEAP32[$118>>2]|0;
   $124 = ((($123)) + 32|0);
   $125 = HEAP32[$124>>2]|0;
   FUNCTION_TABLE_vii[$125 & 8191]($33,$118);
   $126 = ((($8)) + 8|0);
   $127 = ((($126)) + 3|0);
   $128 = HEAP8[$127>>0]|0;
   $129 = ($128<<24>>24)<(0);
   if ($129) {
    $130 = HEAP32[$8>>2]|0;
    HEAP32[$16>>2] = 0;
    __ZNSt3__211char_traitsIwE6assignERwRKw($130,$16);
    $131 = ((($8)) + 4|0);
    HEAP32[$131>>2] = 0;
   } else {
    HEAP32[$17>>2] = 0;
    __ZNSt3__211char_traitsIwE6assignERwRKw($8,$17);
    HEAP8[$127>>0] = 0;
   }
   __THREW__ = 0;
   invoke_vii(4731,($8|0),0);
   $132 = __THREW__; __THREW__ = 0;
   $133 = $132&1;
   if ($133) {
    $134 = ___cxa_find_matching_catch_3(0|0)|0;
    $135 = tempRet0;
    ___clang_call_terminate($134);
    // unreachable;
   }
   ;HEAP32[$8>>2]=HEAP32[$33>>2]|0;HEAP32[$8+4>>2]=HEAP32[$33+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$33+8>>2]|0;
   $$0$i$i$i60 = 0;
   while(1) {
    $exitcond$i$i$i61 = ($$0$i$i$i60|0)==(3);
    if ($exitcond$i$i$i61) {
     break;
    }
    $136 = (($33) + ($$0$i$i$i60<<2)|0);
    HEAP32[$136>>2] = 0;
    $137 = (($$0$i$i$i60) + 1)|0;
    $$0$i$i$i60 = $137;
   }
   __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev($33);
  } else {
   $138 = HEAP32[$118>>2]|0;
   $139 = ((($138)) + 40|0);
   $140 = HEAP32[$139>>2]|0;
   FUNCTION_TABLE_vii[$140 & 8191]($34,$118);
   $141 = HEAP32[$34>>2]|0;
   HEAP8[$3>>0]=$141&255;HEAP8[$3+1>>0]=($141>>8)&255;HEAP8[$3+2>>0]=($141>>16)&255;HEAP8[$3+3>>0]=$141>>24;
   $142 = HEAP32[$118>>2]|0;
   $143 = ((($142)) + 28|0);
   $144 = HEAP32[$143>>2]|0;
   FUNCTION_TABLE_vii[$144 & 8191]($35,$118);
   $145 = ((($8)) + 8|0);
   $146 = ((($145)) + 3|0);
   $147 = HEAP8[$146>>0]|0;
   $148 = ($147<<24>>24)<(0);
   if ($148) {
    $149 = HEAP32[$8>>2]|0;
    HEAP32[$14>>2] = 0;
    __ZNSt3__211char_traitsIwE6assignERwRKw($149,$14);
    $150 = ((($8)) + 4|0);
    HEAP32[$150>>2] = 0;
   } else {
    HEAP32[$15>>2] = 0;
    __ZNSt3__211char_traitsIwE6assignERwRKw($8,$15);
    HEAP8[$146>>0] = 0;
   }
   __THREW__ = 0;
   invoke_vii(4731,($8|0),0);
   $151 = __THREW__; __THREW__ = 0;
   $152 = $151&1;
   if ($152) {
    $153 = ___cxa_find_matching_catch_3(0|0)|0;
    $154 = tempRet0;
    ___clang_call_terminate($153);
    // unreachable;
   }
   ;HEAP32[$8>>2]=HEAP32[$35>>2]|0;HEAP32[$8+4>>2]=HEAP32[$35+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$35+8>>2]|0;
   $$0$i$i$i65 = 0;
   while(1) {
    $exitcond$i$i$i66 = ($$0$i$i$i65|0)==(3);
    if ($exitcond$i$i$i66) {
     break;
    }
    $155 = (($35) + ($$0$i$i$i65<<2)|0);
    HEAP32[$155>>2] = 0;
    $156 = (($$0$i$i$i65) + 1)|0;
    $$0$i$i$i65 = $156;
   }
   __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev($35);
  }
  $157 = HEAP32[$118>>2]|0;
  $158 = ((($157)) + 12|0);
  $159 = HEAP32[$158>>2]|0;
  $160 = (FUNCTION_TABLE_ii[$159 & 8191]($118)|0);
  HEAP32[$4>>2] = $160;
  $161 = HEAP32[$118>>2]|0;
  $162 = ((($161)) + 16|0);
  $163 = HEAP32[$162>>2]|0;
  $164 = (FUNCTION_TABLE_ii[$163 & 8191]($118)|0);
  HEAP32[$5>>2] = $164;
  $165 = HEAP32[$118>>2]|0;
  $166 = ((($165)) + 20|0);
  $167 = HEAP32[$166>>2]|0;
  FUNCTION_TABLE_vii[$167 & 8191]($36,$118);
  $168 = ((($6)) + 11|0);
  $169 = HEAP8[$168>>0]|0;
  $170 = ($169<<24>>24)<(0);
  if ($170) {
   $171 = HEAP32[$6>>2]|0;
   HEAP8[$12>>0] = 0;
   __ZNSt3__211char_traitsIcE6assignERcRKc($171,$12);
   $172 = ((($6)) + 4|0);
   HEAP32[$172>>2] = 0;
  } else {
   HEAP8[$13>>0] = 0;
   __ZNSt3__211char_traitsIcE6assignERcRKc($6,$13);
   HEAP8[$168>>0] = 0;
  }
  __THREW__ = 0;
  invoke_vii(4723,($6|0),0);
  $173 = __THREW__; __THREW__ = 0;
  $174 = $173&1;
  if ($174) {
   $175 = ___cxa_find_matching_catch_3(0|0)|0;
   $176 = tempRet0;
   ___clang_call_terminate($175);
   // unreachable;
  }
  ;HEAP32[$6>>2]=HEAP32[$36>>2]|0;HEAP32[$6+4>>2]=HEAP32[$36+4>>2]|0;HEAP32[$6+8>>2]=HEAP32[$36+8>>2]|0;
  $$0$i$i$i70 = 0;
  while(1) {
   $exitcond$i$i$i71 = ($$0$i$i$i70|0)==(3);
   if ($exitcond$i$i$i71) {
    break;
   }
   $177 = (($36) + ($$0$i$i$i70<<2)|0);
   HEAP32[$177>>2] = 0;
   $178 = (($$0$i$i$i70) + 1)|0;
   $$0$i$i$i70 = $178;
  }
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($36);
  $179 = HEAP32[$118>>2]|0;
  $180 = ((($179)) + 24|0);
  $181 = HEAP32[$180>>2]|0;
  FUNCTION_TABLE_vii[$181 & 8191]($37,$118);
  $182 = ((($7)) + 8|0);
  $183 = ((($182)) + 3|0);
  $184 = HEAP8[$183>>0]|0;
  $185 = ($184<<24>>24)<(0);
  if ($185) {
   $186 = HEAP32[$7>>2]|0;
   HEAP32[$10>>2] = 0;
   __ZNSt3__211char_traitsIwE6assignERwRKw($186,$10);
   $187 = ((($7)) + 4|0);
   HEAP32[$187>>2] = 0;
  } else {
   HEAP32[$11>>2] = 0;
   __ZNSt3__211char_traitsIwE6assignERwRKw($7,$11);
   HEAP8[$183>>0] = 0;
  }
  __THREW__ = 0;
  invoke_vii(4731,($7|0),0);
  $188 = __THREW__; __THREW__ = 0;
  $189 = $188&1;
  if ($189) {
   $190 = ___cxa_find_matching_catch_3(0|0)|0;
   $191 = tempRet0;
   ___clang_call_terminate($190);
   // unreachable;
  }
  ;HEAP32[$7>>2]=HEAP32[$37>>2]|0;HEAP32[$7+4>>2]=HEAP32[$37+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[$37+8>>2]|0;
  $$0$i$i$i75 = 0;
  while(1) {
   $exitcond$i$i$i76 = ($$0$i$i$i75|0)==(3);
   if ($exitcond$i$i$i76) {
    break;
   }
   $192 = (($37) + ($$0$i$i$i75<<2)|0);
   HEAP32[$192>>2] = 0;
   $193 = (($$0$i$i$i75) + 1)|0;
   $$0$i$i$i75 = $193;
  }
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev($37);
  $194 = HEAP32[$118>>2]|0;
  $195 = ((($194)) + 36|0);
  $196 = HEAP32[$195>>2]|0;
  $197 = (FUNCTION_TABLE_ii[$196 & 8191]($118)|0);
  $storemerge = $197;
 }
 HEAP32[$9>>2] = $storemerge;
 STACKTOP = sp;return;
}
function __ZNSt3__211__money_putIwE8__formatEPwRS2_S3_jPKwS5_RKNS_5ctypeIwEEbRKNS_10money_base7patternEwwRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKNSE_IwNSF_IwEENSH_IwEEEESQ_i($0,$1,$2,$3,$4,$5,$6,$7,$8,$9,$10,$11,$12,$13,$14) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 $8 = $8|0;
 $9 = $9|0;
 $10 = $10|0;
 $11 = $11|0;
 $12 = $12|0;
 $13 = $13|0;
 $14 = $14|0;
 var $$ = 0, $$$099 = 0, $$0 = 0, $$0$i$i = 0, $$0$i$i108 = 0, $$0$i$i112 = 0, $$0101 = 0, $$0103 = 0, $$0106 = 0, $$07$i$i = 0, $$095 = 0, $$097 = 0, $$099 = 0, $$1 = 0, $$1102 = 0, $$1104 = 0, $$196 = 0, $$198 = 0, $$2 = 0, $$2105 = 0;
 var $$3 = 0, $$pre137 = 0, $$promoted = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0;
 var $117 = 0, $118 = 0, $119 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0;
 var $137 = 0, $138 = 0, $139 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $or$cond = 0, $scevgep$i = 0, $scevgep$i113 = 0, $trunc = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$2>>2] = $0;
 $15 = ((($13)) + 8|0);
 $16 = ((($15)) + 3|0);
 $17 = ((($13)) + 4|0);
 $18 = ((($12)) + 8|0);
 $19 = ((($18)) + 3|0);
 $20 = ((($12)) + 4|0);
 $21 = $3 & 512;
 $22 = ($21|0)==(0);
 $23 = ($14|0)>(0);
 $24 = ((($11)) + 11|0);
 $25 = ((($11)) + 4|0);
 $$0106 = 0;$$099 = $4;
 while(1) {
  $exitcond = ($$0106|0)==(4);
  if ($exitcond) {
   break;
  }
  $32 = (($8) + ($$0106)|0);
  $33 = HEAP8[$32>>0]|0;
  $34 = $33 << 24 >> 24;
  L4: do {
   switch ($34|0) {
   case 0:  {
    $35 = HEAP32[$2>>2]|0;
    HEAP32[$1>>2] = $35;
    $$2 = $$099;
    break;
   }
   case 1:  {
    $36 = HEAP32[$2>>2]|0;
    HEAP32[$1>>2] = $36;
    $37 = HEAP32[$6>>2]|0;
    $38 = ((($37)) + 44|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = (FUNCTION_TABLE_iii[$39 & 8191]($6,32)|0);
    $41 = HEAP32[$2>>2]|0;
    $42 = ((($41)) + 4|0);
    HEAP32[$2>>2] = $42;
    HEAP32[$41>>2] = $40;
    $$2 = $$099;
    break;
   }
   case 3:  {
    $43 = HEAP8[$16>>0]|0;
    $44 = ($43<<24>>24)<(0);
    $45 = HEAP32[$17>>2]|0;
    $46 = $43&255;
    $47 = $44 ? $45 : $46;
    $48 = ($47|0)==(0);
    if ($48) {
     $$2 = $$099;
    } else {
     $49 = HEAP32[$13>>2]|0;
     $50 = $44 ? $49 : $13;
     $51 = HEAP32[$50>>2]|0;
     $52 = HEAP32[$2>>2]|0;
     $53 = ((($52)) + 4|0);
     HEAP32[$2>>2] = $53;
     HEAP32[$52>>2] = $51;
     $$2 = $$099;
    }
    break;
   }
   case 2:  {
    $54 = HEAP8[$19>>0]|0;
    $55 = ($54<<24>>24)<(0);
    $56 = HEAP32[$20>>2]|0;
    $57 = $54&255;
    $58 = $55 ? $56 : $57;
    $59 = ($58|0)==(0);
    $or$cond = $22 | $59;
    if ($or$cond) {
     $$2 = $$099;
    } else {
     $60 = HEAP32[$12>>2]|0;
     $61 = $55 ? $60 : $12;
     $62 = (($61) + ($58<<2)|0);
     $63 = HEAP32[$2>>2]|0;
     $$0$i$i112 = $63;$64 = $61;
     while(1) {
      $65 = ($64|0)==($62|0);
      if ($65) {
       break;
      }
      $66 = HEAP32[$64>>2]|0;
      HEAP32[$$0$i$i112>>2] = $66;
      $67 = ((($64)) + 4|0);
      $68 = ((($$0$i$i112)) + 4|0);
      $$0$i$i112 = $68;$64 = $67;
     }
     $scevgep$i113 = (($63) + ($58<<2)|0);
     HEAP32[$2>>2] = $scevgep$i113;
     $$2 = $$099;
    }
    break;
   }
   case 4:  {
    $69 = HEAP32[$2>>2]|0;
    $70 = ((($$099)) + 4|0);
    $$$099 = $7 ? $70 : $$099;
    $$0103 = $$$099;
    while(1) {
     $71 = ($$0103>>>0)<($5>>>0);
     if (!($71)) {
      break;
     }
     $72 = HEAP32[$$0103>>2]|0;
     $73 = HEAP32[$6>>2]|0;
     $74 = ((($73)) + 12|0);
     $75 = HEAP32[$74>>2]|0;
     $76 = (FUNCTION_TABLE_iiii[$75 & 8191]($6,2048,$72)|0);
     if (!($76)) {
      break;
     }
     $77 = ((($$0103)) + 4|0);
     $$0103 = $77;
    }
    if ($23) {
     $$0101 = $14;$$1104 = $$0103;
     while(1) {
      $78 = ($$1104>>>0)>($$$099>>>0);
      $79 = ($$0101|0)>(0);
      $80 = $78 & $79;
      if (!($80)) {
       break;
      }
      $81 = ((($$1104)) + -4|0);
      $82 = HEAP32[$81>>2]|0;
      $83 = HEAP32[$2>>2]|0;
      $84 = ((($83)) + 4|0);
      HEAP32[$2>>2] = $84;
      HEAP32[$83>>2] = $82;
      $85 = (($$0101) + -1)|0;
      $$0101 = $85;$$1104 = $81;
     }
     if ($79) {
      $86 = HEAP32[$6>>2]|0;
      $87 = ((($86)) + 44|0);
      $88 = HEAP32[$87>>2]|0;
      $89 = (FUNCTION_TABLE_iii[$88 & 8191]($6,48)|0);
      $93 = $89;
     } else {
      $93 = 0;
     }
     $$promoted = HEAP32[$2>>2]|0;
     $$1102 = $$0101;$92 = $$promoted;
     while(1) {
      $90 = ($$1102|0)>(0);
      $91 = ((($92)) + 4|0);
      if (!($90)) {
       break;
      }
      HEAP32[$92>>2] = $93;
      $94 = (($$1102) + -1)|0;
      $$1102 = $94;$92 = $91;
     }
     HEAP32[$2>>2] = $91;
     HEAP32[$92>>2] = $9;
     $$2105 = $$1104;
    } else {
     $$2105 = $$0103;
    }
    $95 = ($$2105|0)==($$$099|0);
    if ($95) {
     $96 = HEAP32[$6>>2]|0;
     $97 = ((($96)) + 44|0);
     $98 = HEAP32[$97>>2]|0;
     $99 = (FUNCTION_TABLE_iii[$98 & 8191]($6,48)|0);
     $100 = HEAP32[$2>>2]|0;
     $101 = ((($100)) + 4|0);
     HEAP32[$2>>2] = $101;
     HEAP32[$100>>2] = $99;
     $132 = $101;
    } else {
     $102 = HEAP8[$24>>0]|0;
     $103 = ($102<<24>>24)<(0);
     $104 = HEAP32[$25>>2]|0;
     $105 = $102&255;
     $106 = $103 ? $104 : $105;
     $107 = ($106|0)==(0);
     if ($107) {
      $$0 = -1;$$095 = 0;$$097 = 0;$$3 = $$2105;
     } else {
      $108 = HEAP32[$11>>2]|0;
      $109 = $103 ? $108 : $11;
      $110 = HEAP8[$109>>0]|0;
      $111 = $110 << 24 >> 24;
      $$0 = $111;$$095 = 0;$$097 = 0;$$3 = $$2105;
     }
     while(1) {
      $112 = ($$3|0)==($$$099|0);
      if ($112) {
       break;
      }
      $113 = ($$097|0)==($$0|0);
      $114 = HEAP32[$2>>2]|0;
      if ($113) {
       $115 = ((($114)) + 4|0);
       HEAP32[$2>>2] = $115;
       HEAP32[$114>>2] = $10;
       $116 = (($$095) + 1)|0;
       $117 = HEAP32[$25>>2]|0;
       $118 = $103 ? $117 : $105;
       $119 = ($116>>>0)<($118>>>0);
       if ($119) {
        $120 = HEAP32[$11>>2]|0;
        $121 = $103 ? $120 : $11;
        $122 = (($121) + ($116)|0);
        $123 = HEAP8[$122>>0]|0;
        $124 = ($123<<24>>24)==(127);
        $125 = $123 << 24 >> 24;
        $$ = $124 ? -1 : $125;
        $$1 = $$;$$196 = $116;$$198 = 0;$129 = $115;
       } else {
        $$1 = $$097;$$196 = $116;$$198 = 0;$129 = $115;
       }
      } else {
       $$1 = $$0;$$196 = $$095;$$198 = $$097;$129 = $114;
      }
      $126 = ((($$3)) + -4|0);
      $127 = HEAP32[$126>>2]|0;
      $128 = ((($129)) + 4|0);
      HEAP32[$2>>2] = $128;
      HEAP32[$129>>2] = $127;
      $130 = (($$198) + 1)|0;
      $$0 = $$1;$$095 = $$196;$$097 = $130;$$3 = $126;
     }
     $$pre137 = HEAP32[$2>>2]|0;
     $132 = $$pre137;
    }
    $131 = ($69|0)==($132|0);
    if ($131) {
     $$2 = $$$099;
    } else {
     $$0$i$i108 = $132;$$07$i$i = $69;
     while(1) {
      $133 = ((($$0$i$i108)) + -4|0);
      $134 = ($$07$i$i>>>0)<($133>>>0);
      if (!($134)) {
       $$2 = $$$099;
       break L4;
      }
      $135 = HEAP32[$$07$i$i>>2]|0;
      $136 = HEAP32[$133>>2]|0;
      HEAP32[$$07$i$i>>2] = $136;
      HEAP32[$133>>2] = $135;
      $137 = ((($$07$i$i)) + 4|0);
      $$0$i$i108 = $133;$$07$i$i = $137;
     }
    }
    break;
   }
   default: {
    $$2 = $$099;
   }
   }
  } while(0);
  $138 = (($$0106) + 1)|0;
  $$0106 = $138;$$099 = $$2;
 }
 $26 = HEAP8[$16>>0]|0;
 $27 = ($26<<24>>24)<(0);
 $28 = HEAP32[$17>>2]|0;
 $29 = $26&255;
 $30 = $27 ? $28 : $29;
 $31 = ($30>>>0)>(1);
 if ($31) {
  $139 = HEAP32[$13>>2]|0;
  $140 = $27 ? $139 : $13;
  $141 = ((($140)) + 4|0);
  $142 = (($140) + ($30<<2)|0);
  $143 = HEAP32[$2>>2]|0;
  $144 = $141;
  $145 = $142;
  $146 = (($145) - ($144))|0;
  $$0$i$i = $143;$147 = $141;
  while(1) {
   $148 = ($147|0)==($142|0);
   if ($148) {
    break;
   }
   $149 = HEAP32[$147>>2]|0;
   HEAP32[$$0$i$i>>2] = $149;
   $150 = ((($147)) + 4|0);
   $151 = ((($$0$i$i)) + 4|0);
   $$0$i$i = $151;$147 = $150;
  }
  $152 = $146 >>> 2;
  $scevgep$i = (($143) + ($152<<2)|0);
  HEAP32[$2>>2] = $scevgep$i;
 }
 $153 = $3 & 176;
 $trunc = $153&255;
 switch ($trunc<<24>>24) {
 case 32:  {
  $154 = HEAP32[$2>>2]|0;
  HEAP32[$1>>2] = $154;
  break;
 }
 case 16:  {
  break;
 }
 default: {
  HEAP32[$1>>2] = $0;
 }
 }
 return;
}
function __ZNSt3__28messagesIcED2Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__26locale5facetD2Ev($0);
 return;
}
function __ZNSt3__28messagesIcED0Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__26locale5facetD2Ev($0);
 __ZdlPv($0);
 return;
}
function __ZNKSt3__28messagesIcE7do_openERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKNS_6localeE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$ = 0, $10 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $not$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($1)) + 11|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)<(0);
 $6 = HEAP32[$1>>2]|0;
 $7 = $5 ? $6 : $1;
 $8 = (_catopen($7,1)|0);
 $9 = $8;
 $not$ = ($8|0)!=((-1)|0);
 $10 = $not$&1;
 $$ = $9 >>> $10;
 return ($$|0);
}
function __ZNKSt3__28messagesIcE6do_getEiiiRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$0$i = 0, $$0$i$i = 0, $$0$i$i25 = 0, $$0$i30 = 0, $$1 = 0, $$123 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i$i = 0, $exitcond$i$i26 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $6 = sp;
 ;HEAP32[$6>>2]=0|0;HEAP32[$6+4>>2]=0|0;HEAP32[$6+8>>2]=0|0;
 $$0$i$i = 0;
 while(1) {
  $exitcond$i$i = ($$0$i$i|0)==(3);
  if ($exitcond$i$i) {
   break;
  }
  $7 = (($6) + ($$0$i$i<<2)|0);
  HEAP32[$7>>2] = 0;
  $8 = (($$0$i$i) + 1)|0;
  $$0$i$i = $8;
 }
 $9 = ((($5)) + 11|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = ($10<<24>>24)<(0);
 $12 = HEAP32[$5>>2]|0;
 $13 = $11 ? $12 : $5;
 $14 = ((($5)) + 4|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = $10&255;
 $17 = $11 ? $15 : $16;
 $18 = (($13) + ($17)|0);
 $$0$i30 = $13;
 while(1) {
  $19 = ($$0$i30>>>0)<($18>>>0);
  if (!($19)) {
   label = 8;
   break;
  }
  $20 = HEAP8[$$0$i30>>0]|0;
  __THREW__ = 0;
  invoke_vii(3433,($6|0),($20|0));
  $21 = __THREW__; __THREW__ = 0;
  $22 = $21&1;
  if ($22) {
   label = 9;
   break;
  }
  $23 = ((($$0$i30)) + 1|0);
  $$0$i30 = $23;
 }
 do {
  if ((label|0) == 8) {
   $24 = ($2|0)==(-1);
   $25 = $2 << 1;
   $26 = $25;
   $27 = $24 ? (-1) : $26;
   $28 = ((($6)) + 11|0);
   $29 = HEAP8[$28>>0]|0;
   $30 = ($29<<24>>24)<(0);
   $31 = HEAP32[$6>>2]|0;
   $32 = $30 ? $31 : $6;
   __THREW__ = 0;
   $33 = (invoke_iiiii(4736,($27|0),($3|0),($4|0),($32|0))|0);
   $34 = __THREW__; __THREW__ = 0;
   $35 = $34&1;
   if ($35) {
    $47 = ___cxa_find_matching_catch_2()|0;
    $48 = tempRet0;
    $$1 = $47;$$123 = $48;
    break;
   }
   ;HEAP32[$0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;
   $$0$i$i25 = 0;
   while(1) {
    $exitcond$i$i26 = ($$0$i$i25|0)==(3);
    if ($exitcond$i$i26) {
     break;
    }
    $38 = (($0) + ($$0$i$i25<<2)|0);
    HEAP32[$38>>2] = 0;
    $39 = (($$0$i$i25) + 1)|0;
    $$0$i$i25 = $39;
   }
   $40 = (_strlen($33)|0);
   $41 = (($32) + ($40)|0);
   $$0$i = $32;
   while(1) {
    $42 = ($$0$i>>>0)<($41>>>0);
    if (!($42)) {
     label = 19;
     break;
    }
    $43 = HEAP8[$$0$i>>0]|0;
    __THREW__ = 0;
    invoke_vii(3433,($0|0),($43|0));
    $44 = __THREW__; __THREW__ = 0;
    $45 = $44&1;
    if ($45) {
     label = 18;
     break;
    }
    $46 = ((($$0$i)) + 1|0);
    $$0$i = $46;
   }
   if ((label|0) == 18) {
    $49 = ___cxa_find_matching_catch_2()|0;
    $50 = tempRet0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($0);
    $$1 = $49;$$123 = $50;
    break;
   }
   else if ((label|0) == 19) {
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($6);
    STACKTOP = sp;return;
   }
  }
  else if ((label|0) == 9) {
   $36 = ___cxa_find_matching_catch_2()|0;
   $37 = tempRet0;
   $$1 = $36;$$123 = $37;
  }
 } while(0);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($6);
 ___resumeException($$1|0);
 // unreachable;
}
function __ZNKSt3__28messagesIcE8do_closeEi($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZNSt3__28messagesIwED2Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__26locale5facetD2Ev($0);
 return;
}
function __ZNSt3__28messagesIwED0Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__26locale5facetD2Ev($0);
 __ZdlPv($0);
 return;
}
function __ZNKSt3__28messagesIwE7do_openERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKNS_6localeE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$ = 0, $10 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $not$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($1)) + 11|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)<(0);
 $6 = HEAP32[$1>>2]|0;
 $7 = $5 ? $6 : $1;
 $8 = (_catopen($7,1)|0);
 $9 = $8;
 $not$ = ($8|0)!=((-1)|0);
 $10 = $not$&1;
 $$ = $9 >>> $10;
 return ($$|0);
}
function __ZNKSt3__28messagesIwE6do_getEiiiRKNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEE($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$0$i = 0, $$0$i$i = 0, $$0$i$i34 = 0, $$0$i29 = 0, $$016$i = 0, $$017$i = 0, $$019$i = 0, $$020$i = 0, $$2 = 0, $$224 = 0, $10 = 0, $100 = 0, $101 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i$i = 0, $exitcond$i$i35 = 0, $or$cond$i = 0, $or$cond$i28 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(224|0);
 $6 = sp + 184|0;
 $7 = sp + 192|0;
 $8 = sp + 180|0;
 $9 = sp + 176|0;
 $10 = sp + 168|0;
 $11 = sp + 40|0;
 $12 = sp + 32|0;
 $13 = sp + 28|0;
 $14 = sp + 16|0;
 $15 = sp + 8|0;
 $16 = sp;
 ;HEAP32[$14>>2]=0|0;HEAP32[$14+4>>2]=0|0;HEAP32[$14+8>>2]=0|0;
 $$0$i$i = 0;
 while(1) {
  $exitcond$i$i = ($$0$i$i|0)==(3);
  if ($exitcond$i$i) {
   break;
  }
  $17 = (($14) + ($$0$i$i<<2)|0);
  HEAP32[$17>>2] = 0;
  $18 = (($$0$i$i) + 1)|0;
  $$0$i$i = $18;
 }
 $19 = ((($15)) + 4|0);
 HEAP32[$19>>2] = 0;
 HEAP32[$15>>2] = (98972);
 $20 = ((($5)) + 8|0);
 $21 = ((($20)) + 3|0);
 $22 = HEAP8[$21>>0]|0;
 $23 = ($22<<24>>24)<(0);
 $24 = HEAP32[$5>>2]|0;
 $25 = $23 ? $24 : $5;
 $26 = ((($5)) + 4|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = $22&255;
 $29 = $23 ? $27 : $28;
 $30 = (($25) + ($29<<2)|0);
 $31 = ((($7)) + 32|0);
 $$016$i = $25;$$017$i = 0;
 L5: while(1) {
  $32 = ($$016$i>>>0)<($30>>>0);
  $33 = ($$017$i|0)!=(2);
  $34 = $33 & $32;
  if (!($34)) {
   label = 13;
   break;
  }
  HEAP32[$9>>2] = $$016$i;
  $35 = HEAP32[$15>>2]|0;
  $36 = ((($35)) + 12|0);
  $37 = HEAP32[$36>>2]|0;
  __THREW__ = 0;
  $38 = (invoke_iiiiiiiii($37|0,($15|0),($6|0),($$016$i|0),($30|0),($9|0),($7|0),($31|0),($8|0))|0);
  $39 = __THREW__; __THREW__ = 0;
  $40 = $39&1;
  if ($40) {
   label = 14;
   break;
  }
  $41 = ($38|0)==(2);
  $42 = HEAP32[$9>>2]|0;
  $43 = ($42|0)==($$016$i|0);
  $or$cond$i28 = $41 | $43;
  if ($or$cond$i28) {
   label = 8;
   break;
  } else {
   $$0$i29 = $7;
  }
  while(1) {
   $45 = HEAP32[$8>>2]|0;
   $46 = ($$0$i29>>>0)<($45>>>0);
   if (!($46)) {
    break;
   }
   $48 = HEAP8[$$0$i29>>0]|0;
   __THREW__ = 0;
   invoke_vii(3433,($14|0),($48|0));
   $49 = __THREW__; __THREW__ = 0;
   $50 = $49&1;
   if ($50) {
    label = 14;
    break L5;
   }
   $51 = ((($$0$i29)) + 1|0);
   $$0$i29 = $51;
  }
  $47 = HEAP32[$9>>2]|0;
  $$016$i = $47;$$017$i = $38;
 }
 do {
  if ((label|0) == 8) {
   __THREW__ = 0;
   invoke_vi(4718,(203716|0));
   $44 = __THREW__; __THREW__ = 0;
   label = 14;
  }
  else if ((label|0) == 13) {
   __ZNSt3__26locale5facetD2Ev($15);
   $52 = ($2|0)==(-1);
   $53 = $2 << 1;
   $54 = $53;
   $55 = $52 ? (-1) : $54;
   $56 = ((($14)) + 11|0);
   $57 = HEAP8[$56>>0]|0;
   $58 = ($57<<24>>24)<(0);
   $59 = HEAP32[$14>>2]|0;
   $60 = $58 ? $59 : $14;
   __THREW__ = 0;
   $61 = (invoke_iiiii(4736,($55|0),($3|0),($4|0),($60|0))|0);
   $62 = __THREW__; __THREW__ = 0;
   $63 = $62&1;
   if ($63) {
    $98 = ___cxa_find_matching_catch_2()|0;
    $99 = tempRet0;
    $$2 = $98;$$224 = $99;
    break;
   }
   ;HEAP32[$0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;
   $$0$i$i34 = 0;
   while(1) {
    $exitcond$i$i35 = ($$0$i$i34|0)==(3);
    if ($exitcond$i$i35) {
     break;
    }
    $66 = (($0) + ($$0$i$i34<<2)|0);
    HEAP32[$66>>2] = 0;
    $67 = (($$0$i$i34) + 1)|0;
    $$0$i$i34 = $67;
   }
   $68 = ((($16)) + 4|0);
   HEAP32[$68>>2] = 0;
   HEAP32[$16>>2] = (99020);
   $69 = (_strlen($61)|0);
   $70 = (($60) + ($69)|0);
   $71 = $70;
   $72 = ((($11)) + 128|0);
   $$019$i = $60;$$020$i = 0;
   L23: while(1) {
    $73 = ($$019$i>>>0)<($70>>>0);
    $74 = ($$020$i|0)!=(2);
    $75 = $74 & $73;
    if (!($75)) {
     label = 27;
     break;
    }
    HEAP32[$13>>2] = $$019$i;
    $76 = HEAP32[$16>>2]|0;
    $77 = ((($76)) + 16|0);
    $78 = HEAP32[$77>>2]|0;
    $79 = $$019$i;
    $80 = (($71) - ($79))|0;
    $81 = ($80|0)>(32);
    $82 = ((($$019$i)) + 32|0);
    $83 = $81 ? $82 : $70;
    __THREW__ = 0;
    $84 = (invoke_iiiiiiiii($78|0,($16|0),($10|0),($$019$i|0),($83|0),($13|0),($11|0),($72|0),($12|0))|0);
    $85 = __THREW__; __THREW__ = 0;
    $86 = $85&1;
    if ($86) {
     break;
    }
    $87 = ($84|0)==(2);
    $88 = HEAP32[$13>>2]|0;
    $89 = ($88|0)==($$019$i|0);
    $or$cond$i = $87 | $89;
    if ($or$cond$i) {
     label = 22;
     break;
    } else {
     $$0$i = $11;
    }
    while(1) {
     $91 = HEAP32[$12>>2]|0;
     $92 = ($$0$i>>>0)<($91>>>0);
     if (!($92)) {
      break;
     }
     $94 = HEAP32[$$0$i>>2]|0;
     __THREW__ = 0;
     invoke_vii(4726,($0|0),($94|0));
     $95 = __THREW__; __THREW__ = 0;
     $96 = $95&1;
     if ($96) {
      break L23;
     }
     $97 = ((($$0$i)) + 4|0);
     $$0$i = $97;
    }
    $93 = HEAP32[$13>>2]|0;
    $$019$i = $93;$$020$i = $84;
   }
   if ((label|0) == 22) {
    __THREW__ = 0;
    invoke_vi(4718,(203716|0));
    $90 = __THREW__; __THREW__ = 0;
   }
   else if ((label|0) == 27) {
    __ZNSt3__26locale5facetD2Ev($16);
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($14);
    STACKTOP = sp;return;
   }
   $100 = ___cxa_find_matching_catch_2()|0;
   $101 = tempRet0;
   __ZNSt3__26locale5facetD2Ev($16);
   __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev($0);
   $$2 = $100;$$224 = $101;
  }
 } while(0);
 if ((label|0) == 14) {
  $64 = ___cxa_find_matching_catch_2()|0;
  $65 = tempRet0;
  __ZNSt3__26locale5facetD2Ev($15);
  $$2 = $64;$$224 = $65;
 }
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($14);
 ___resumeException($$2|0);
 // unreachable;
}
function __ZNKSt3__28messagesIwE8do_closeEi($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZNSt3__217__widen_from_utf8ILj32EED0Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__26locale5facetD2Ev($0);
 __ZdlPv($0);
 return;
}
function __ZNKSt3__27codecvtIDic11__mbstate_tE6do_outERS1_PKDiS5_RS5_PcS7_RS7_($0,$1,$2,$3,$4,$5,$6,$7) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 var $10 = 0, $11 = 0, $12 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $8 = sp + 4|0;
 $9 = sp;
 HEAP32[$8>>2] = $2;
 HEAP32[$9>>2] = $5;
 $10 = (__ZNSt3__2L12ucs4_to_utf8EPKjS1_RS1_PhS3_RS3_mNS_12codecvt_modeE($2,$3,$8,$5,$6,$9,1114111,0)|0);
 $11 = HEAP32[$8>>2]|0;
 HEAP32[$4>>2] = $11;
 $12 = HEAP32[$9>>2]|0;
 HEAP32[$7>>2] = $12;
 STACKTOP = sp;return ($10|0);
}
function __ZNKSt3__27codecvtIDic11__mbstate_tE5do_inERS1_PKcS5_RS5_PDiS7_RS7_($0,$1,$2,$3,$4,$5,$6,$7) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 var $10 = 0, $11 = 0, $12 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $8 = sp + 4|0;
 $9 = sp;
 HEAP32[$8>>2] = $2;
 HEAP32[$9>>2] = $5;
 $10 = (__ZNSt3__2L12utf8_to_ucs4EPKhS1_RS1_PjS3_RS3_mNS_12codecvt_modeE($2,$3,$8,$5,$6,$9,1114111,0)|0);
 $11 = HEAP32[$8>>2]|0;
 HEAP32[$4>>2] = $11;
 $12 = HEAP32[$9>>2]|0;
 HEAP32[$7>>2] = $12;
 STACKTOP = sp;return ($10|0);
}
function __ZNKSt3__27codecvtIDic11__mbstate_tE10do_unshiftERS1_PcS4_RS4_($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$4>>2] = $2;
 return 3;
}
function __ZNKSt3__27codecvtIDic11__mbstate_tE11do_encodingEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function __ZNKSt3__27codecvtIDic11__mbstate_tE16do_always_noconvEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function __ZNKSt3__27codecvtIDic11__mbstate_tE9do_lengthERS1_PKcS5_j($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = (__ZNSt3__2L19utf8_to_ucs4_lengthEPKhS1_jmNS_12codecvt_modeE($2,$3,$4,1114111,0)|0);
 return ($5|0);
}
function __ZNKSt3__27codecvtIDic11__mbstate_tE13do_max_lengthEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 4;
}
function __ZNSt3__2L19utf8_to_ucs4_lengthEPKhS1_jmNS_12codecvt_modeE($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$ = 0, $$091 = 0, $$185 = 0, $$488 = 0, $$lcssa112$sink = 0, $$off = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $or$cond = 0, $or$cond100 = 0, $or$cond97 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $5 = $4 & 4;
 $6 = ($5|0)!=(0);
 $7 = $1;
 $8 = $0;
 $9 = (($7) - ($8))|0;
 $10 = ($9|0)>(2);
 $or$cond = $10 & $6;
 if ($or$cond) {
  $11 = HEAP8[$0>>0]|0;
  $12 = ($11<<24>>24)==(-17);
  if ($12) {
   $13 = ((($0)) + 1|0);
   $14 = HEAP8[$13>>0]|0;
   $15 = ($14<<24>>24)==(-69);
   if ($15) {
    $16 = ((($0)) + 2|0);
    $17 = HEAP8[$16>>0]|0;
    $18 = ($17<<24>>24)==(-65);
    $19 = ((($0)) + 3|0);
    $$ = $18 ? $19 : $0;
    $$091 = 0;$$185 = $$;
   } else {
    $$091 = 0;$$185 = $0;
   }
  } else {
   $$091 = 0;$$185 = $0;
  }
 } else {
  $$091 = 0;$$185 = $0;
 }
 L5: while(1) {
  $20 = ($$185>>>0)<($1>>>0);
  $21 = ($$091>>>0)<($2>>>0);
  $or$cond97 = $21 & $20;
  if (!($or$cond97)) {
   label = 30;
   break;
  }
  $22 = HEAP8[$$185>>0]|0;
  $23 = $22&255;
  $24 = ($22<<24>>24)>(-1);
  $25 = ((($$185)) + 1|0);
  do {
   if ($24) {
    $26 = ($23>>>0)>($3>>>0);
    if ($26) {
     label = 30;
     break L5;
    } else {
     $$488 = $25;
    }
   } else {
    $27 = ($22&255)<(194);
    if ($27) {
     label = 30;
     break L5;
    }
    $28 = ($22&255)<(224);
    $29 = ((($$185)) + 2|0);
    $30 = $$185;
    $31 = (($7) - ($30))|0;
    if ($28) {
     $32 = ($31|0)<(2);
     if ($32) {
      label = 30;
      break L5;
     }
     $33 = HEAP8[$25>>0]|0;
     $34 = $33&255;
     $35 = $34 & 192;
     $36 = ($35|0)==(128);
     if (!($36)) {
      label = 30;
      break L5;
     }
     $37 = $23 << 6;
     $38 = $37 & 1984;
     $39 = $34 & 63;
     $40 = $39 | $38;
     $41 = ($40>>>0)>($3>>>0);
     if ($41) {
      label = 30;
      break L5;
     } else {
      $$488 = $29;
      break;
     }
    }
    $42 = ($22&255)<(240);
    $43 = ((($$185)) + 3|0);
    if ($42) {
     $44 = ($31|0)<(3);
     if ($44) {
      label = 30;
      break L5;
     }
     $45 = HEAP8[$25>>0]|0;
     $46 = HEAP8[$29>>0]|0;
     $47 = $45&255;
     $48 = $47 & 224;
     switch ($22<<24>>24) {
     case -32:  {
      $49 = ($48|0)==(160);
      if (!($49)) {
       $$lcssa112$sink = $30;
       break L5;
      }
      break;
     }
     case -19:  {
      $50 = ($48|0)==(128);
      if (!($50)) {
       $$lcssa112$sink = $30;
       break L5;
      }
      break;
     }
     default: {
      $51 = $47 & 192;
      $52 = ($51|0)==(128);
      if (!($52)) {
       $$lcssa112$sink = $30;
       break L5;
      }
     }
     }
     $53 = $46&255;
     $54 = $53 & 192;
     $55 = ($54|0)==(128);
     if (!($55)) {
      label = 30;
      break L5;
     }
     $56 = $23 << 12;
     $57 = $56 & 61440;
     $58 = $47 << 6;
     $59 = $58 & 4032;
     $60 = $59 | $57;
     $61 = $53 & 63;
     $62 = $60 | $61;
     $63 = ($62>>>0)>($3>>>0);
     if ($63) {
      label = 30;
      break L5;
     } else {
      $$488 = $43;
      break;
     }
    }
    $64 = ($22&255)>(244);
    $65 = ($31|0)<(4);
    $or$cond100 = $65 | $64;
    if ($or$cond100) {
     label = 30;
     break L5;
    }
    $66 = HEAP8[$25>>0]|0;
    $67 = HEAP8[$29>>0]|0;
    $68 = HEAP8[$43>>0]|0;
    $69 = $66&255;
    switch ($22<<24>>24) {
    case -16:  {
     $$off = (($66) + 112)<<24>>24;
     $70 = ($$off&255)<(48);
     if (!($70)) {
      $$lcssa112$sink = $30;
      break L5;
     }
     break;
    }
    case -12:  {
     $71 = $69 & 240;
     $72 = ($71|0)==(128);
     if (!($72)) {
      $$lcssa112$sink = $30;
      break L5;
     }
     break;
    }
    default: {
     $73 = $69 & 192;
     $74 = ($73|0)==(128);
     if (!($74)) {
      $$lcssa112$sink = $30;
      break L5;
     }
    }
    }
    $75 = $67&255;
    $76 = $75 & 192;
    $77 = ($76|0)==(128);
    if (!($77)) {
     label = 30;
     break L5;
    }
    $78 = $68&255;
    $79 = $78 & 192;
    $80 = ($79|0)==(128);
    if (!($80)) {
     label = 30;
     break L5;
    }
    $81 = $23 << 18;
    $82 = $81 & 1835008;
    $83 = $69 << 12;
    $84 = $83 & 258048;
    $85 = $84 | $82;
    $86 = $75 << 6;
    $87 = $86 & 4032;
    $88 = $85 | $87;
    $89 = $78 & 63;
    $90 = $88 | $89;
    $91 = ($90>>>0)>($3>>>0);
    $92 = ((($$185)) + 4|0);
    if ($91) {
     label = 30;
     break L5;
    } else {
     $$488 = $92;
    }
   }
  } while(0);
  $93 = (($$091) + 1)|0;
  $$091 = $93;$$185 = $$488;
 }
 if ((label|0) == 30) {
  $94 = $$185;
  $$lcssa112$sink = $94;
 }
 $95 = (($$lcssa112$sink) - ($8))|0;
 return ($95|0);
}
function __ZNSt3__2L12utf8_to_ucs4EPKhS1_RS1_PjS3_RS3_mNS_12codecvt_modeE($0,$1,$2,$3,$4,$5,$6,$7) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 var $$9 = 0, $$off = 0, $$sink = 0, $10 = 0, $100 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$2>>2] = $0;
 HEAP32[$5>>2] = $3;
 $8 = $7 & 4;
 $9 = ($8|0)==(0);
 $10 = $1;
 if (!($9)) {
  $11 = HEAP32[$2>>2]|0;
  $12 = $11;
  $13 = (($10) - ($12))|0;
  $14 = ($13|0)>(2);
  if ($14) {
   $15 = HEAP8[$11>>0]|0;
   $16 = ($15<<24>>24)==(-17);
   if ($16) {
    $17 = ((($11)) + 1|0);
    $18 = HEAP8[$17>>0]|0;
    $19 = ($18<<24>>24)==(-69);
    if ($19) {
     $20 = ((($11)) + 2|0);
     $21 = HEAP8[$20>>0]|0;
     $22 = ($21<<24>>24)==(-65);
     if ($22) {
      $23 = ((($11)) + 3|0);
      HEAP32[$2>>2] = $23;
     }
    }
   }
  }
 }
 L7: while(1) {
  $24 = HEAP32[$2>>2]|0;
  $25 = ($24>>>0)<($1>>>0);
  if (!($25)) {
   $$9 = 0;
   break;
  }
  $26 = HEAP32[$5>>2]|0;
  $27 = ($26>>>0)<($4>>>0);
  if (!($27)) {
   $$9 = 1;
   break;
  }
  $28 = HEAP8[$24>>0]|0;
  $29 = $28&255;
  $30 = ($28<<24>>24)>(-1);
  $31 = ((($24)) + 1|0);
  do {
   if ($30) {
    $32 = ($29>>>0)>($6>>>0);
    if ($32) {
     $$9 = 2;
     break L7;
    }
    HEAP32[$26>>2] = $29;
    $$sink = $31;
   } else {
    $33 = ($28&255)<(194);
    if ($33) {
     $$9 = 2;
     break L7;
    }
    $34 = ($28&255)<(224);
    $35 = $24;
    $36 = ((($24)) + 2|0);
    $37 = (($10) - ($35))|0;
    if ($34) {
     $38 = ($37|0)<(2);
     if ($38) {
      $$9 = 1;
      break L7;
     }
     $39 = HEAP8[$31>>0]|0;
     $40 = $39&255;
     $41 = $40 & 192;
     $42 = ($41|0)==(128);
     if (!($42)) {
      $$9 = 2;
      break L7;
     }
     $43 = $29 << 6;
     $44 = $43 & 1984;
     $45 = $40 & 63;
     $46 = $45 | $44;
     $47 = ($46>>>0)>($6>>>0);
     if ($47) {
      $$9 = 2;
      break L7;
     }
     HEAP32[$26>>2] = $46;
     $$sink = $36;
     break;
    }
    $48 = ($28&255)<(240);
    $49 = ((($24)) + 3|0);
    if ($48) {
     $50 = ($37|0)<(3);
     if ($50) {
      $$9 = 1;
      break L7;
     }
     $51 = HEAP8[$31>>0]|0;
     $52 = HEAP8[$36>>0]|0;
     $53 = $51&255;
     $54 = $53 & 224;
     switch ($28<<24>>24) {
     case -32:  {
      $55 = ($54|0)==(160);
      if (!($55)) {
       $$9 = 2;
       break L7;
      }
      break;
     }
     case -19:  {
      $56 = ($54|0)==(128);
      if (!($56)) {
       $$9 = 2;
       break L7;
      }
      break;
     }
     default: {
      $57 = $53 & 192;
      $58 = ($57|0)==(128);
      if (!($58)) {
       $$9 = 2;
       break L7;
      }
     }
     }
     $59 = $52&255;
     $60 = $59 & 192;
     $61 = ($60|0)==(128);
     if (!($61)) {
      $$9 = 2;
      break L7;
     }
     $62 = $29 << 12;
     $63 = $62 & 61440;
     $64 = $53 << 6;
     $65 = $64 & 4032;
     $66 = $65 | $63;
     $67 = $59 & 63;
     $68 = $66 | $67;
     $69 = ($68>>>0)>($6>>>0);
     if ($69) {
      $$9 = 2;
      break L7;
     }
     HEAP32[$26>>2] = $68;
     $$sink = $49;
     break;
    }
    $70 = ($28&255)<(245);
    if (!($70)) {
     $$9 = 2;
     break L7;
    }
    $71 = ($37|0)<(4);
    if ($71) {
     $$9 = 1;
     break L7;
    }
    $72 = HEAP8[$31>>0]|0;
    $73 = HEAP8[$36>>0]|0;
    $74 = HEAP8[$49>>0]|0;
    $75 = $72&255;
    switch ($28<<24>>24) {
    case -16:  {
     $$off = (($72) + 112)<<24>>24;
     $76 = ($$off&255)<(48);
     if (!($76)) {
      $$9 = 2;
      break L7;
     }
     break;
    }
    case -12:  {
     $77 = $75 & 240;
     $78 = ($77|0)==(128);
     if (!($78)) {
      $$9 = 2;
      break L7;
     }
     break;
    }
    default: {
     $79 = $75 & 192;
     $80 = ($79|0)==(128);
     if (!($80)) {
      $$9 = 2;
      break L7;
     }
    }
    }
    $81 = $73&255;
    $82 = $81 & 192;
    $83 = ($82|0)==(128);
    if (!($83)) {
     $$9 = 2;
     break L7;
    }
    $84 = $74&255;
    $85 = $84 & 192;
    $86 = ($85|0)==(128);
    if (!($86)) {
     $$9 = 2;
     break L7;
    }
    $87 = $29 << 18;
    $88 = $87 & 1835008;
    $89 = $75 << 12;
    $90 = $89 & 258048;
    $91 = $90 | $88;
    $92 = $81 << 6;
    $93 = $92 & 4032;
    $94 = $91 | $93;
    $95 = $84 & 63;
    $96 = $94 | $95;
    $97 = ($96>>>0)>($6>>>0);
    if ($97) {
     $$9 = 2;
     break L7;
    }
    HEAP32[$26>>2] = $96;
    $98 = ((($24)) + 4|0);
    $$sink = $98;
   }
  } while(0);
  HEAP32[$2>>2] = $$sink;
  $99 = HEAP32[$5>>2]|0;
  $100 = ((($99)) + 4|0);
  HEAP32[$5>>2] = $100;
 }
 return ($$9|0);
}
function __ZNSt3__2L12ucs4_to_utf8EPKjS1_RS1_PhS3_RS3_mNS_12codecvt_modeE($0,$1,$2,$3,$4,$5,$6,$7) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 var $$2 = 0, $$pre = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$2>>2] = $0;
 HEAP32[$5>>2] = $3;
 $8 = $7 & 2;
 $9 = ($8|0)==(0);
 $10 = $4;
 if ($9) {
  label = 4;
 } else {
  $11 = $3;
  $12 = (($10) - ($11))|0;
  $13 = ($12|0)<(3);
  if ($13) {
   $$2 = 1;
  } else {
   $14 = ((($3)) + 1|0);
   HEAP32[$5>>2] = $14;
   HEAP8[$3>>0] = -17;
   $15 = HEAP32[$5>>2]|0;
   $16 = ((($15)) + 1|0);
   HEAP32[$5>>2] = $16;
   HEAP8[$15>>0] = -69;
   $17 = HEAP32[$5>>2]|0;
   $18 = ((($17)) + 1|0);
   HEAP32[$5>>2] = $18;
   HEAP8[$17>>0] = -65;
   label = 4;
  }
 }
 L4: do {
  if ((label|0) == 4) {
   $$pre = HEAP32[$2>>2]|0;
   $19 = $$pre;
   while(1) {
    $20 = ($19>>>0)<($1>>>0);
    if (!($20)) {
     $$2 = 0;
     break L4;
    }
    $21 = HEAP32[$19>>2]|0;
    $22 = $21 & -2048;
    $23 = ($22|0)==(55296);
    $24 = ($21>>>0)>($6>>>0);
    $or$cond = $24 | $23;
    if ($or$cond) {
     $$2 = 2;
     break L4;
    }
    $25 = ($21>>>0)<(128);
    do {
     if ($25) {
      $26 = HEAP32[$5>>2]|0;
      $27 = $26;
      $28 = (($10) - ($27))|0;
      $29 = ($28|0)<(1);
      if ($29) {
       $$2 = 1;
       break L4;
      }
      $30 = $21&255;
      $31 = ((($26)) + 1|0);
      HEAP32[$5>>2] = $31;
      HEAP8[$26>>0] = $30;
     } else {
      $32 = ($21>>>0)<(2048);
      $33 = $21 & 63;
      $34 = $33 | 128;
      $35 = $34&255;
      if ($32) {
       $36 = HEAP32[$5>>2]|0;
       $37 = $36;
       $38 = (($10) - ($37))|0;
       $39 = ($38|0)<(2);
       if ($39) {
        $$2 = 1;
        break L4;
       }
       $40 = $21 >>> 6;
       $41 = $40 | 192;
       $42 = $41&255;
       $43 = ((($36)) + 1|0);
       HEAP32[$5>>2] = $43;
       HEAP8[$36>>0] = $42;
       $44 = HEAP32[$5>>2]|0;
       $45 = ((($44)) + 1|0);
       HEAP32[$5>>2] = $45;
       HEAP8[$44>>0] = $35;
       break;
      }
      $46 = ($21>>>0)<(65536);
      $47 = HEAP32[$5>>2]|0;
      $48 = $47;
      $49 = (($10) - ($48))|0;
      $50 = $21 >>> 6;
      $51 = $50 & 63;
      $52 = $51 | 128;
      $53 = ((($47)) + 1|0);
      $54 = $52&255;
      if ($46) {
       $55 = ($49|0)<(3);
       if ($55) {
        $$2 = 1;
        break L4;
       }
       $56 = $21 >>> 12;
       $57 = $56 | 224;
       $58 = $57&255;
       HEAP32[$5>>2] = $53;
       HEAP8[$47>>0] = $58;
       $59 = HEAP32[$5>>2]|0;
       $60 = ((($59)) + 1|0);
       HEAP32[$5>>2] = $60;
       HEAP8[$59>>0] = $54;
       $61 = HEAP32[$5>>2]|0;
       $62 = ((($61)) + 1|0);
       HEAP32[$5>>2] = $62;
       HEAP8[$61>>0] = $35;
       break;
      } else {
       $63 = ($49|0)<(4);
       if ($63) {
        $$2 = 1;
        break L4;
       }
       $64 = $21 >>> 18;
       $65 = $64 | 240;
       $66 = $65&255;
       HEAP32[$5>>2] = $53;
       HEAP8[$47>>0] = $66;
       $67 = $21 >>> 12;
       $68 = $67 & 63;
       $69 = $68 | 128;
       $70 = $69&255;
       $71 = HEAP32[$5>>2]|0;
       $72 = ((($71)) + 1|0);
       HEAP32[$5>>2] = $72;
       HEAP8[$71>>0] = $70;
       $73 = HEAP32[$5>>2]|0;
       $74 = ((($73)) + 1|0);
       HEAP32[$5>>2] = $74;
       HEAP8[$73>>0] = $54;
       $75 = HEAP32[$5>>2]|0;
       $76 = ((($75)) + 1|0);
       HEAP32[$5>>2] = $76;
       HEAP8[$75>>0] = $35;
       break;
      }
     }
    } while(0);
    $77 = HEAP32[$2>>2]|0;
    $78 = ((($77)) + 4|0);
    HEAP32[$2>>2] = $78;
    $19 = $78;
   }
  }
 } while(0);
 return ($$2|0);
}
function __ZNSt3__216__narrow_to_utf8ILj32EED0Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__26locale5facetD2Ev($0);
 __ZdlPv($0);
 return;
}
function __ZNKSt3__27codecvtIcc11__mbstate_tE6do_outERS1_PKcS5_RS5_PcS7_RS7_($0,$1,$2,$3,$4,$5,$6,$7) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$4>>2] = $2;
 HEAP32[$7>>2] = $5;
 return 3;
}
function __ZNKSt3__27codecvtIcc11__mbstate_tE5do_inERS1_PKcS5_RS5_PcS7_RS7_($0,$1,$2,$3,$4,$5,$6,$7) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$4>>2] = $2;
 HEAP32[$7>>2] = $5;
 return 3;
}
function __ZNKSt3__27codecvtIcc11__mbstate_tE10do_unshiftERS1_PcS4_RS4_($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$4>>2] = $2;
 return 3;
}
function __ZNKSt3__27codecvtIcc11__mbstate_tE11do_encodingEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 1;
}
function __ZNKSt3__27codecvtIcc11__mbstate_tE16do_always_noconvEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 1;
}
function __ZNKSt3__27codecvtIcc11__mbstate_tE9do_lengthERS1_PKcS5_j($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$sroa$speculated = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = $3;
 $6 = $2;
 $7 = (($5) - ($6))|0;
 $8 = ($7>>>0)<($4>>>0);
 $$sroa$speculated = $8 ? $7 : $4;
 return ($$sroa$speculated|0);
}
function __ZNKSt3__27codecvtIcc11__mbstate_tE13do_max_lengthEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 1;
}
function __ZNKSt3__27codecvtIwc11__mbstate_tE6do_outERS1_PKwS5_RS5_PcS7_RS7_($0,$1,$2,$3,$4,$5,$6,$7) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 var $$0 = 0, $$069 = 0, $$070 = 0, $$070$lcssa = 0, $$077 = 0, $$079 = 0, $$171 = 0, $$173 = 0, $$178 = 0, $$2 = 0, $$2$lcssa = 0, $$375$ph = 0, $$476 = 0, $$5$ph87 = 0, $$pre = 0, $$pre170 = 0, $$pre171 = 0, $10 = 0, $100 = 0, $101 = 0;
 var $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $not$ = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $8 = sp;
 $9 = sp + 8|0;
 $$070 = $2;
 while(1) {
  $10 = ($$070|0)==($3|0);
  if ($10) {
   $$070$lcssa = $3;
   break;
  }
  $11 = HEAP32[$$070>>2]|0;
  $12 = ($11|0)==(0);
  if ($12) {
   $$070$lcssa = $$070;
   break;
  }
  $13 = ((($$070)) + 4|0);
  $$070 = $13;
 }
 HEAP32[$7>>2] = $5;
 HEAP32[$4>>2] = $2;
 $14 = $6;
 $15 = ((($0)) + 8|0);
 $$077 = $2;$$079 = $5;$$171 = $$070$lcssa;
 L6: while(1) {
  $16 = ($$077|0)==($3|0);
  $17 = ($$079|0)==($6|0);
  $or$cond = $17 | $16;
  if ($or$cond) {
   $113 = $$077;
   label = 53;
   break;
  }
  $18 = $1;
  $19 = $18;
  $20 = HEAP32[$19>>2]|0;
  $21 = (($18) + 4)|0;
  $22 = $21;
  $23 = HEAP32[$22>>2]|0;
  $24 = $8;
  $25 = $24;
  HEAP32[$25>>2] = $20;
  $26 = (($24) + 4)|0;
  $27 = $26;
  HEAP32[$27>>2] = $23;
  $28 = $$171;
  $29 = $$077;
  $30 = (($28) - ($29))|0;
  $31 = $30 >> 2;
  $32 = $$079;
  $33 = (($14) - ($32))|0;
  $34 = HEAP32[$15>>2]|0;
  $35 = (___uselocale($34)|0);
  __THREW__ = 0;
  $36 = (invoke_iiiiii(4737,($$079|0),($4|0),($31|0),($33|0),($1|0))|0);
  $37 = __THREW__; __THREW__ = 0;
  $38 = $37&1;
  if ($38) {
   label = 11;
   break;
  }
  $39 = ($35|0)==(0|0);
  if (!($39)) {
   __THREW__ = 0;
   (invoke_ii(4671,($35|0))|0);
   $40 = __THREW__; __THREW__ = 0;
   $41 = $40&1;
   if ($41) {
    label = 10;
    break;
   }
  }
  switch ($36|0) {
  case -1:  {
   label = 16;
   break L6;
   break;
  }
  case 0:  {
   $$375$ph = 1;
   label = 50;
   break L6;
   break;
  }
  default: {
  }
  }
  $76 = HEAP32[$7>>2]|0;
  $77 = (($76) + ($36)|0);
  HEAP32[$7>>2] = $77;
  $78 = ($77|0)==($6|0);
  if ($78) {
   label = 51;
   break;
  }
  $79 = ($$171|0)==($3|0);
  if ($79) {
   $$pre = HEAP32[$4>>2]|0;
   $$5$ph87 = $3;$115 = $77;$116 = $$pre;
  } else {
   $80 = HEAP32[$15>>2]|0;
   $81 = (___uselocale($80)|0);
   __THREW__ = 0;
   $82 = (invoke_iiii(4738,($9|0),0,($1|0))|0);
   $83 = __THREW__; __THREW__ = 0;
   $84 = $83&1;
   if ($84) {
    label = 36;
    break;
   }
   $85 = ($81|0)==(0|0);
   if (!($85)) {
    __THREW__ = 0;
    (invoke_ii(4671,($81|0))|0);
    $86 = __THREW__; __THREW__ = 0;
    $87 = $86&1;
    if ($87) {
     label = 35;
     break;
    }
   }
   $97 = ($82|0)==(-1);
   if ($97) {
    $$173 = 2;
    label = 49;
    break;
   }
   $98 = HEAP32[$7>>2]|0;
   $99 = (($14) - ($98))|0;
   $100 = ($82>>>0)>($99>>>0);
   if ($100) {
    $$173 = 1;
    label = 49;
    break;
   } else {
    $$0 = $9;$$069 = $82;
   }
   while(1) {
    $101 = ($$069|0)==(0);
    if ($101) {
     break;
    }
    $104 = ((($$0)) + 1|0);
    $105 = HEAP8[$$0>>0]|0;
    $106 = HEAP32[$7>>2]|0;
    $107 = ((($106)) + 1|0);
    HEAP32[$7>>2] = $107;
    HEAP8[$106>>0] = $105;
    $108 = (($$069) + -1)|0;
    $$0 = $104;$$069 = $108;
   }
   $102 = HEAP32[$4>>2]|0;
   $103 = ((($102)) + 4|0);
   HEAP32[$4>>2] = $103;
   $$2 = $103;
   while(1) {
    $109 = ($$2|0)==($3|0);
    if ($109) {
     $$2$lcssa = $3;
     break;
    }
    $110 = HEAP32[$$2>>2]|0;
    $111 = ($110|0)==(0);
    if ($111) {
     $$2$lcssa = $$2;
     break;
    }
    $112 = ((($$2)) + 4|0);
    $$2 = $112;
   }
   $$pre170 = HEAP32[$7>>2]|0;
   $$5$ph87 = $$2$lcssa;$115 = $$pre170;$116 = $103;
  }
  $$077 = $116;$$079 = $115;$$171 = $$5$ph87;
 }
 do {
  if ((label|0) == 10) {
   $42 = ___cxa_find_matching_catch_3(0|0)|0;
   $43 = tempRet0;
   ___clang_call_terminate($42);
   // unreachable;
  }
  else if ((label|0) == 11) {
   $44 = ___cxa_find_matching_catch_2()|0;
   $45 = tempRet0;
   $46 = ($35|0)==(0|0);
   if (!($46)) {
    __THREW__ = 0;
    (invoke_ii(4671,($35|0))|0);
    $47 = __THREW__; __THREW__ = 0;
    $48 = $47&1;
    if ($48) {
     $49 = ___cxa_find_matching_catch_3(0|0)|0;
     $50 = tempRet0;
     ___clang_call_terminate($49);
     // unreachable;
    }
   }
   ___resumeException($44|0);
   // unreachable;
  }
  else if ((label|0) == 16) {
   HEAP32[$7>>2] = $$079;
   $$178 = $$077;$56 = $$079;
   while(1) {
    $51 = HEAP32[$4>>2]|0;
    $52 = ($$178|0)==($51|0);
    if ($52) {
     label = 28;
     break;
    }
    $53 = HEAP32[$$178>>2]|0;
    $54 = HEAP32[$15>>2]|0;
    $55 = (___uselocale($54)|0);
    __THREW__ = 0;
    $57 = (invoke_iiii(4738,($56|0),($53|0),($8|0))|0);
    $58 = __THREW__; __THREW__ = 0;
    $59 = $58&1;
    if ($59) {
     label = 22;
     break;
    }
    $60 = ($55|0)==(0|0);
    if (!($60)) {
     __THREW__ = 0;
     (invoke_ii(4671,($55|0))|0);
     $61 = __THREW__; __THREW__ = 0;
     $62 = $61&1;
     if ($62) {
      label = 21;
      break;
     }
    }
    $72 = ($57|0)==(-1);
    if ($72) {
     label = 28;
     break;
    }
    $73 = HEAP32[$7>>2]|0;
    $74 = (($73) + ($57)|0);
    HEAP32[$7>>2] = $74;
    $75 = ((($$178)) + 4|0);
    $$178 = $75;$56 = $74;
   }
   if ((label|0) == 21) {
    $63 = ___cxa_find_matching_catch_3(0|0)|0;
    $64 = tempRet0;
    ___clang_call_terminate($63);
    // unreachable;
   }
   else if ((label|0) == 22) {
    $65 = ___cxa_find_matching_catch_2()|0;
    $66 = tempRet0;
    $67 = ($55|0)==(0|0);
    if (!($67)) {
     __THREW__ = 0;
     (invoke_ii(4671,($55|0))|0);
     $68 = __THREW__; __THREW__ = 0;
     $69 = $68&1;
     if ($69) {
      $70 = ___cxa_find_matching_catch_3(0|0)|0;
      $71 = tempRet0;
      ___clang_call_terminate($70);
      // unreachable;
     }
    }
    ___resumeException($65|0);
    // unreachable;
   }
   else if ((label|0) == 28) {
    HEAP32[$4>>2] = $$178;
    $$375$ph = 2;
    label = 50;
    break;
   }
  }
  else if ((label|0) == 35) {
   $88 = ___cxa_find_matching_catch_3(0|0)|0;
   $89 = tempRet0;
   ___clang_call_terminate($88);
   // unreachable;
  }
  else if ((label|0) == 36) {
   $90 = ___cxa_find_matching_catch_2()|0;
   $91 = tempRet0;
   $92 = ($81|0)==(0|0);
   if (!($92)) {
    __THREW__ = 0;
    (invoke_ii(4671,($81|0))|0);
    $93 = __THREW__; __THREW__ = 0;
    $94 = $93&1;
    if ($94) {
     $95 = ___cxa_find_matching_catch_3(0|0)|0;
     $96 = tempRet0;
     ___clang_call_terminate($95);
     // unreachable;
    }
   }
   ___resumeException($90|0);
   // unreachable;
  }
  else if ((label|0) == 49) {
   $$375$ph = $$173;
   label = 50;
  }
  else if ((label|0) == 51) {
   $$pre171 = HEAP32[$4>>2]|0;
   $113 = $$pre171;
   label = 53;
  }
 } while(0);
 if ((label|0) == 50) {
  $$476 = $$375$ph;
 }
 else if ((label|0) == 53) {
  $not$ = ($113|0)!=($3|0);
  $114 = $not$&1;
  $$476 = $114;
 }
 STACKTOP = sp;return ($$476|0);
}
function __ZNKSt3__27codecvtIwc11__mbstate_tE5do_inERS1_PKcS5_RS5_PwS7_RS7_($0,$1,$2,$3,$4,$5,$6,$7) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 var $$070 = 0, $$070$lcssa = 0, $$074 = 0, $$077 = 0, $$1 = 0, $$172$ph = 0, $$175 = 0, $$2 = 0, $$2$lcssa = 0, $$273 = 0, $$4$ph = 0, $$pre = 0, $$pre176 = 0, $$pre177 = 0, $$sink = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0;
 var $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $not$ = 0, $not$78 = 0, $or$cond = 0;
 var $storemerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $8 = sp;
 $$070 = $2;
 while(1) {
  $9 = ($$070|0)==($3|0);
  if ($9) {
   $$070$lcssa = $3;
   break;
  }
  $10 = HEAP8[$$070>>0]|0;
  $11 = ($10<<24>>24)==(0);
  if ($11) {
   $$070$lcssa = $$070;
   break;
  }
  $12 = ((($$070)) + 1|0);
  $$070 = $12;
 }
 HEAP32[$7>>2] = $5;
 HEAP32[$4>>2] = $2;
 $13 = $6;
 $14 = ((($0)) + 8|0);
 $$074 = $2;$$077 = $5;$$1 = $$070$lcssa;
 while(1) {
  $15 = ($$074|0)==($3|0);
  $16 = ($$077|0)==($6|0);
  $or$cond = $16 | $15;
  if ($or$cond) {
   $106 = $$074;
   label = 50;
   break;
  }
  $17 = $1;
  $18 = $17;
  $19 = HEAP32[$18>>2]|0;
  $20 = (($17) + 4)|0;
  $21 = $20;
  $22 = HEAP32[$21>>2]|0;
  $23 = $8;
  $24 = $23;
  HEAP32[$24>>2] = $19;
  $25 = (($23) + 4)|0;
  $26 = $25;
  HEAP32[$26>>2] = $22;
  $27 = $$1;
  $28 = $$074;
  $29 = (($27) - ($28))|0;
  $30 = $$077;
  $31 = (($13) - ($30))|0;
  $32 = $31 >> 2;
  $33 = HEAP32[$14>>2]|0;
  $34 = (___uselocale($33)|0);
  __THREW__ = 0;
  $35 = (invoke_iiiiii(4739,($$077|0),($4|0),($29|0),($32|0),($1|0))|0);
  $36 = __THREW__; __THREW__ = 0;
  $37 = $36&1;
  if ($37) {
   label = 11;
   break;
  }
  $38 = ($34|0)==(0|0);
  if (!($38)) {
   __THREW__ = 0;
   (invoke_ii(4671,($34|0))|0);
   $39 = __THREW__; __THREW__ = 0;
   $40 = $39&1;
   if ($40) {
    label = 10;
    break;
   }
  }
  $50 = ($35|0)==(-1);
  if ($50) {
   $$175 = $$074;$storemerge = $$077;
   label = 16;
   break;
  }
  $76 = HEAP32[$7>>2]|0;
  $77 = (($76) + ($35<<2)|0);
  HEAP32[$7>>2] = $77;
  $78 = ($77|0)==($6|0);
  if ($78) {
   label = 47;
   break;
  }
  $79 = ($$1|0)==($3|0);
  $$pre = HEAP32[$4>>2]|0;
  if ($79) {
   $$4$ph = $3;$108 = $77;$109 = $$pre;
  } else {
   $80 = HEAP32[$14>>2]|0;
   $81 = (___uselocale($80)|0);
   __THREW__ = 0;
   $82 = (invoke_iiiii(4740,($77|0),($$pre|0),1,($1|0))|0);
   $83 = __THREW__; __THREW__ = 0;
   $84 = $83&1;
   if ($84) {
    label = 37;
    break;
   }
   $85 = ($81|0)==(0|0);
   if (!($85)) {
    __THREW__ = 0;
    (invoke_ii(4671,($81|0))|0);
    $86 = __THREW__; __THREW__ = 0;
    $87 = $86&1;
    if ($87) {
     label = 36;
     break;
    }
   }
   $97 = ($82|0)==(0);
   if (!($97)) {
    $$172$ph = 2;
    label = 46;
    break;
   }
   $98 = HEAP32[$7>>2]|0;
   $99 = ((($98)) + 4|0);
   HEAP32[$7>>2] = $99;
   $100 = HEAP32[$4>>2]|0;
   $101 = ((($100)) + 1|0);
   HEAP32[$4>>2] = $101;
   $$2 = $101;
   while(1) {
    $102 = ($$2|0)==($3|0);
    if ($102) {
     $$2$lcssa = $3;
     break;
    }
    $103 = HEAP8[$$2>>0]|0;
    $104 = ($103<<24>>24)==(0);
    if ($104) {
     $$2$lcssa = $$2;
     break;
    }
    $105 = ((($$2)) + 1|0);
    $$2 = $105;
   }
   $$pre176 = HEAP32[$7>>2]|0;
   $$4$ph = $$2$lcssa;$108 = $$pre176;$109 = $101;
  }
  $$074 = $109;$$077 = $108;$$1 = $$4$ph;
 }
 do {
  if ((label|0) == 10) {
   $41 = ___cxa_find_matching_catch_3(0|0)|0;
   $42 = tempRet0;
   ___clang_call_terminate($41);
   // unreachable;
  }
  else if ((label|0) == 11) {
   $43 = ___cxa_find_matching_catch_2()|0;
   $44 = tempRet0;
   $45 = ($34|0)==(0|0);
   if (!($45)) {
    __THREW__ = 0;
    (invoke_ii(4671,($34|0))|0);
    $46 = __THREW__; __THREW__ = 0;
    $47 = $46&1;
    if ($47) {
     $48 = ___cxa_find_matching_catch_3(0|0)|0;
     $49 = tempRet0;
     ___clang_call_terminate($48);
     // unreachable;
    }
   }
   ___resumeException($43|0);
   // unreachable;
  }
  else if ((label|0) == 16) {
   L30: while(1) {
    label = 0;
    HEAP32[$7>>2] = $storemerge;
    $51 = HEAP32[$4>>2]|0;
    $52 = ($$175|0)==($51|0);
    if ($52) {
     label = 30;
     break;
    }
    $53 = $$175;
    $54 = (($27) - ($53))|0;
    $55 = HEAP32[$14>>2]|0;
    $56 = (___uselocale($55)|0);
    __THREW__ = 0;
    $57 = (invoke_iiiii(4740,($storemerge|0),($$175|0),($54|0),($8|0))|0);
    $58 = __THREW__; __THREW__ = 0;
    $59 = $58&1;
    if ($59) {
     label = 21;
     break;
    }
    $60 = ($56|0)==(0|0);
    if (!($60)) {
     __THREW__ = 0;
     (invoke_ii(4671,($56|0))|0);
     $61 = __THREW__; __THREW__ = 0;
     $62 = $61&1;
     if ($62) {
      label = 20;
      break;
     }
    }
    switch ($57|0) {
    case -1:  {
     label = 27;
     break L30;
     break;
    }
    case -2:  {
     label = 28;
     break L30;
     break;
    }
    case 0:  {
     $$sink = 1;
     break;
    }
    default: {
     $$sink = $57;
    }
    }
    $72 = (($$175) + ($$sink)|0);
    $73 = HEAP32[$7>>2]|0;
    $74 = ((($73)) + 4|0);
    $$175 = $72;$storemerge = $74;
    label = 16;
   }
   if ((label|0) == 20) {
    $63 = ___cxa_find_matching_catch_3(0|0)|0;
    $64 = tempRet0;
    ___clang_call_terminate($63);
    // unreachable;
   }
   else if ((label|0) == 21) {
    $65 = ___cxa_find_matching_catch_2()|0;
    $66 = tempRet0;
    $67 = ($56|0)==(0|0);
    if (!($67)) {
     __THREW__ = 0;
     (invoke_ii(4671,($56|0))|0);
     $68 = __THREW__; __THREW__ = 0;
     $69 = $68&1;
     if ($69) {
      $70 = ___cxa_find_matching_catch_3(0|0)|0;
      $71 = tempRet0;
      ___clang_call_terminate($70);
      // unreachable;
     }
    }
    ___resumeException($65|0);
    // unreachable;
   }
   else if ((label|0) == 27) {
    HEAP32[$4>>2] = $$175;
    $$172$ph = 2;
    label = 46;
    break;
   }
   else if ((label|0) == 28) {
    HEAP32[$4>>2] = $$175;
    $$172$ph = 1;
    label = 46;
    break;
   }
   else if ((label|0) == 30) {
    HEAP32[$4>>2] = $$175;
    $not$78 = ($$175|0)!=($3|0);
    $75 = $not$78&1;
    $$172$ph = $75;
    label = 46;
    break;
   }
  }
  else if ((label|0) == 36) {
   $88 = ___cxa_find_matching_catch_3(0|0)|0;
   $89 = tempRet0;
   ___clang_call_terminate($88);
   // unreachable;
  }
  else if ((label|0) == 37) {
   $90 = ___cxa_find_matching_catch_2()|0;
   $91 = tempRet0;
   $92 = ($81|0)==(0|0);
   if (!($92)) {
    __THREW__ = 0;
    (invoke_ii(4671,($81|0))|0);
    $93 = __THREW__; __THREW__ = 0;
    $94 = $93&1;
    if ($94) {
     $95 = ___cxa_find_matching_catch_3(0|0)|0;
     $96 = tempRet0;
     ___clang_call_terminate($95);
     // unreachable;
    }
   }
   ___resumeException($90|0);
   // unreachable;
  }
  else if ((label|0) == 47) {
   $$pre177 = HEAP32[$4>>2]|0;
   $106 = $$pre177;
   label = 50;
  }
 } while(0);
 if ((label|0) == 46) {
  $$273 = $$172$ph;
 }
 else if ((label|0) == 50) {
  $not$ = ($106|0)!=($3|0);
  $107 = $not$&1;
  $$273 = $107;
 }
 STACKTOP = sp;return ($$273|0);
}
function __ZNKSt3__27codecvtIwc11__mbstate_tE10do_unshiftERS1_PcS4_RS4_($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0 = 0, $$018 = 0, $$019 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $5 = sp;
 HEAP32[$4>>2] = $2;
 $6 = ((($0)) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (___uselocale($7)|0);
 __THREW__ = 0;
 $9 = (invoke_iiii(4738,($5|0),0,($1|0))|0);
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if ($11) {
  $17 = ___cxa_find_matching_catch_2()|0;
  $18 = tempRet0;
  $19 = ($8|0)==(0|0);
  if (!($19)) {
   __THREW__ = 0;
   (invoke_ii(4671,($8|0))|0);
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if ($21) {
    $22 = ___cxa_find_matching_catch_3(0|0)|0;
    $23 = tempRet0;
    ___clang_call_terminate($22);
    // unreachable;
   }
  }
  ___resumeException($17|0);
  // unreachable;
 }
 $12 = ($8|0)==(0|0);
 if (!($12)) {
  __THREW__ = 0;
  (invoke_ii(4671,($8|0))|0);
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if ($14) {
   $15 = ___cxa_find_matching_catch_3(0|0)|0;
   $16 = tempRet0;
   ___clang_call_terminate($15);
   // unreachable;
  }
 }
 L12: do {
  switch ($9|0) {
  case 0: case -1:  {
   $$019 = 2;
   break;
  }
  default: {
   $24 = (($9) + -1)|0;
   $25 = HEAP32[$4>>2]|0;
   $26 = $3;
   $27 = (($26) - ($25))|0;
   $28 = ($24>>>0)>($27>>>0);
   if ($28) {
    $$019 = 1;
   } else {
    $$0 = $5;$$018 = $24;
    while(1) {
     $29 = ($$018|0)==(0);
     if ($29) {
      $$019 = 0;
      break L12;
     }
     $30 = ((($$0)) + 1|0);
     $31 = HEAP8[$$0>>0]|0;
     $32 = HEAP32[$4>>2]|0;
     $33 = ((($32)) + 1|0);
     HEAP32[$4>>2] = $33;
     HEAP8[$32>>0] = $31;
     $34 = (($$018) + -1)|0;
     $$0 = $30;$$018 = $34;
    }
   }
  }
  }
 } while(0);
 STACKTOP = sp;return ($$019|0);
}
function __ZNKSt3__27codecvtIwc11__mbstate_tE11do_encodingEv($0) {
 $0 = $0|0;
 var $$ = 0, $$0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 __THREW__ = 0;
 $3 = (invoke_ii(4671,($2|0))|0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 do {
  if ($5) {
   label = 21;
  } else {
   __THREW__ = 0;
   $6 = (invoke_iiii(4741,(0|0),(0|0),4)|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $14 = ___cxa_find_matching_catch_3(0|0)|0;
    $15 = tempRet0;
    $16 = ($3|0)==(0|0);
    if ($16) {
     $eh$lpad$body$indexZ2D = $14;
     break;
    }
    __THREW__ = 0;
    (invoke_ii(4671,($3|0))|0);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if (!($18)) {
     $eh$lpad$body$indexZ2D = $14;
     break;
    }
    $19 = ___cxa_find_matching_catch_3(0|0)|0;
    $20 = tempRet0;
    ___clang_call_terminate($19);
    // unreachable;
   }
   $9 = ($3|0)==(0|0);
   if (!($9)) {
    __THREW__ = 0;
    (invoke_ii(4671,($3|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     $12 = ___cxa_find_matching_catch_3(0|0)|0;
     $13 = tempRet0;
     ___clang_call_terminate($12);
     // unreachable;
    }
   }
   $21 = ($6|0)==(0);
   if ($21) {
    $22 = HEAP32[$1>>2]|0;
    $23 = ($22|0)==(0|0);
    if ($23) {
     $$0 = 1;
    } else {
     __THREW__ = 0;
     $24 = (invoke_ii(4671,($22|0))|0);
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if ($26) {
      label = 21;
      break;
     }
     __THREW__ = 0;
     $27 = (invoke_i(4742)|0);
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      $35 = ___cxa_find_matching_catch_3(0|0)|0;
      $36 = tempRet0;
      $37 = ($24|0)==(0|0);
      if ($37) {
       $eh$lpad$body$indexZ2D = $35;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(4671,($24|0))|0);
      $38 = __THREW__; __THREW__ = 0;
      $39 = $38&1;
      if (!($39)) {
       $eh$lpad$body$indexZ2D = $35;
       break;
      }
      $40 = ___cxa_find_matching_catch_3(0|0)|0;
      $41 = tempRet0;
      ___clang_call_terminate($40);
      // unreachable;
     }
     $30 = ($24|0)==(0|0);
     if (!($30)) {
      __THREW__ = 0;
      (invoke_ii(4671,($24|0))|0);
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if ($32) {
       $33 = ___cxa_find_matching_catch_3(0|0)|0;
       $34 = tempRet0;
       ___clang_call_terminate($33);
       // unreachable;
      }
     }
     $42 = ($27|0)==(1);
     $$ = $42&1;
     return ($$|0);
    }
   } else {
    $$0 = -1;
   }
   return ($$0|0);
  }
 } while(0);
 if ((label|0) == 21) {
  $43 = ___cxa_find_matching_catch_3(0|0)|0;
  $44 = tempRet0;
  $eh$lpad$body$indexZ2D = $43;
 }
 ___clang_call_terminate($eh$lpad$body$indexZ2D);
 // unreachable;
 return (0)|0;
}
function __ZNKSt3__27codecvtIwc11__mbstate_tE16do_always_noconvEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function __ZNKSt3__27codecvtIwc11__mbstate_tE9do_lengthERS1_PKcS5_j($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$029 = 0, $$030 = 0, $$034 = 0, $$131 = 0, $$sink = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = $3;
 $6 = ((($0)) + 8|0);
 $$029 = 0;$$030 = 0;$$034 = $2;
 L1: while(1) {
  $7 = ($$029>>>0)>=($4>>>0);
  $8 = ($$034|0)==($3|0);
  $or$cond = $8 | $7;
  if ($or$cond) {
   label = 14;
   break;
  }
  $9 = $$034;
  $10 = (($5) - ($9))|0;
  $11 = HEAP32[$6>>2]|0;
  $12 = (___uselocale($11)|0);
  __THREW__ = 0;
  $13 = (invoke_iiii(4743,($$034|0),($10|0),($1|0))|0);
  $14 = __THREW__; __THREW__ = 0;
  $15 = $14&1;
  if ($15) {
   label = 7;
   break;
  }
  $16 = ($12|0)==(0|0);
  if (!($16)) {
   __THREW__ = 0;
   (invoke_ii(4671,($12|0))|0);
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if ($18) {
    label = 6;
    break;
   }
  }
  switch ($13|0) {
  case -2: case -1:  {
   label = 14;
   break L1;
   break;
  }
  case 0:  {
   $$sink = 1;
   break;
  }
  default: {
   $$sink = $13;
  }
  }
  $28 = (($$034) + ($$sink)|0);
  $$131 = (($$sink) + ($$030))|0;
  $29 = (($$029) + 1)|0;
  $$029 = $29;$$030 = $$131;$$034 = $28;
 }
 if ((label|0) == 6) {
  $19 = ___cxa_find_matching_catch_3(0|0)|0;
  $20 = tempRet0;
  ___clang_call_terminate($19);
  // unreachable;
 }
 else if ((label|0) == 7) {
  $21 = ___cxa_find_matching_catch_2()|0;
  $22 = tempRet0;
  $23 = ($12|0)==(0|0);
  if (!($23)) {
   __THREW__ = 0;
   (invoke_ii(4671,($12|0))|0);
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   if ($25) {
    $26 = ___cxa_find_matching_catch_3(0|0)|0;
    $27 = tempRet0;
    ___clang_call_terminate($26);
    // unreachable;
   }
  }
  ___resumeException($21|0);
  // unreachable;
 }
 else if ((label|0) == 14) {
  return ($$030|0);
 }
 return (0)|0;
}
function __ZNKSt3__27codecvtIwc11__mbstate_tE13do_max_lengthEv($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 L1: do {
  if ($3) {
   $22 = 1;
  } else {
   __THREW__ = 0;
   $4 = (invoke_ii(4671,($2|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   do {
    if ($6) {
     $23 = ___cxa_find_matching_catch_3(0|0)|0;
     $24 = tempRet0;
     $eh$lpad$body$indexZ2D = $23;
    } else {
     __THREW__ = 0;
     $7 = (invoke_i(4742)|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if ($9) {
      $15 = ___cxa_find_matching_catch_3(0|0)|0;
      $16 = tempRet0;
      $17 = ($4|0)==(0|0);
      if ($17) {
       $eh$lpad$body$indexZ2D = $15;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(4671,($4|0))|0);
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if (!($19)) {
       $eh$lpad$body$indexZ2D = $15;
       break;
      }
      $20 = ___cxa_find_matching_catch_3(0|0)|0;
      $21 = tempRet0;
      ___clang_call_terminate($20);
      // unreachable;
     } else {
      $10 = ($4|0)==(0|0);
      if ($10) {
       $22 = $7;
       break L1;
      }
      __THREW__ = 0;
      (invoke_ii(4671,($4|0))|0);
      $11 = __THREW__; __THREW__ = 0;
      $12 = $11&1;
      if (!($12)) {
       $22 = $7;
       break L1;
      }
      $13 = ___cxa_find_matching_catch_3(0|0)|0;
      $14 = tempRet0;
      ___clang_call_terminate($13);
      // unreachable;
     }
    }
   } while(0);
   ___clang_call_terminate($eh$lpad$body$indexZ2D);
   // unreachable;
  }
 } while(0);
 return ($22|0);
}
function __ZNSt3__27codecvtIwc11__mbstate_tED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (99068);
 $1 = ((($0)) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 __THREW__ = 0;
 $3 = (invoke_i(4668)|0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 do {
  if (!($5)) {
   $6 = ($2|0)==($3|0);
   if (!($6)) {
    $7 = HEAP32[$1>>2]|0;
    __THREW__ = 0;
    invoke_vi(4713,($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __ZNSt3__26locale5facetD2Ev($0);
   return;
  }
 } while(0);
 $10 = ___cxa_find_matching_catch_3(0|0)|0;
 $11 = tempRet0;
 __ZNSt3__26locale5facetD2Ev($0);
 ___clang_call_terminate($10);
 // unreachable;
}
function __ZNSt3__27codecvtIwc11__mbstate_tED0Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__27codecvtIwc11__mbstate_tED2Ev($0);
 __ZdlPv($0);
 return;
}
function __ZNKSt3__27codecvtIDsc11__mbstate_tE6do_outERS1_PKDsS5_RS5_PcS7_RS7_($0,$1,$2,$3,$4,$5,$6,$7) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 var $10 = 0, $11 = 0, $12 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $8 = sp + 4|0;
 $9 = sp;
 HEAP32[$8>>2] = $2;
 HEAP32[$9>>2] = $5;
 $10 = (__ZNSt3__2L13utf16_to_utf8EPKtS1_RS1_PhS3_RS3_mNS_12codecvt_modeE($2,$3,$8,$5,$6,$9,1114111,0)|0);
 $11 = HEAP32[$8>>2]|0;
 HEAP32[$4>>2] = $11;
 $12 = HEAP32[$9>>2]|0;
 HEAP32[$7>>2] = $12;
 STACKTOP = sp;return ($10|0);
}
function __ZNKSt3__27codecvtIDsc11__mbstate_tE5do_inERS1_PKcS5_RS5_PDsS7_RS7_($0,$1,$2,$3,$4,$5,$6,$7) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 var $10 = 0, $11 = 0, $12 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $8 = sp + 4|0;
 $9 = sp;
 HEAP32[$8>>2] = $2;
 HEAP32[$9>>2] = $5;
 $10 = (__ZNSt3__2L13utf8_to_utf16EPKhS1_RS1_PtS3_RS3_mNS_12codecvt_modeE($2,$3,$8,$5,$6,$9,1114111,0)|0);
 $11 = HEAP32[$8>>2]|0;
 HEAP32[$4>>2] = $11;
 $12 = HEAP32[$9>>2]|0;
 HEAP32[$7>>2] = $12;
 STACKTOP = sp;return ($10|0);
}
function __ZNKSt3__27codecvtIDsc11__mbstate_tE10do_unshiftERS1_PcS4_RS4_($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$4>>2] = $2;
 return 3;
}
function __ZNKSt3__27codecvtIDsc11__mbstate_tE11do_encodingEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function __ZNKSt3__27codecvtIDsc11__mbstate_tE16do_always_noconvEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function __ZNKSt3__27codecvtIDsc11__mbstate_tE9do_lengthERS1_PKcS5_j($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = (__ZNSt3__2L20utf8_to_utf16_lengthEPKhS1_jmNS_12codecvt_modeE($2,$3,$4,1114111,0)|0);
 return ($5|0);
}
function __ZNKSt3__27codecvtIDsc11__mbstate_tE13do_max_lengthEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 4;
}
function __ZNSt3__2L20utf8_to_utf16_lengthEPKhS1_jmNS_12codecvt_modeE($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$ = 0, $$0100 = 0, $$194 = 0, $$2102 = 0, $$598 = 0, $$lcssa125$sink = 0, $$off = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $or$cond = 0, $or$cond110 = 0, $or$cond115 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = $4 & 4;
 $6 = ($5|0)!=(0);
 $7 = $1;
 $8 = $0;
 $9 = (($7) - ($8))|0;
 $10 = ($9|0)>(2);
 $or$cond = $10 & $6;
 if ($or$cond) {
  $11 = HEAP8[$0>>0]|0;
  $12 = ($11<<24>>24)==(-17);
  if ($12) {
   $13 = ((($0)) + 1|0);
   $14 = HEAP8[$13>>0]|0;
   $15 = ($14<<24>>24)==(-69);
   if ($15) {
    $16 = ((($0)) + 2|0);
    $17 = HEAP8[$16>>0]|0;
    $18 = ($17<<24>>24)==(-65);
    $19 = ((($0)) + 3|0);
    $$ = $18 ? $19 : $0;
    $$0100 = 0;$$194 = $$;
   } else {
    $$0100 = 0;$$194 = $0;
   }
  } else {
   $$0100 = 0;$$194 = $0;
  }
 } else {
  $$0100 = 0;$$194 = $0;
 }
 L5: while(1) {
  $20 = ($$194>>>0)<($1>>>0);
  $21 = ($$0100>>>0)<($2>>>0);
  $or$cond110 = $21 & $20;
  if (!($or$cond110)) {
   label = 31;
   break;
  }
  $22 = HEAP8[$$194>>0]|0;
  $23 = $22&255;
  $24 = ($23>>>0)>($3>>>0);
  if ($24) {
   label = 31;
   break;
  }
  $25 = ($22<<24>>24)>(-1);
  $26 = ((($$194)) + 1|0);
  do {
   if ($25) {
    $$2102 = $$0100;$$598 = $26;
   } else {
    $27 = ($22&255)<(194);
    if ($27) {
     label = 31;
     break L5;
    }
    $28 = ($22&255)<(224);
    $29 = ((($$194)) + 2|0);
    $30 = $$194;
    $31 = (($7) - ($30))|0;
    if ($28) {
     $32 = ($31|0)<(2);
     if ($32) {
      label = 31;
      break L5;
     }
     $33 = HEAP8[$26>>0]|0;
     $34 = $33&255;
     $35 = $34 & 192;
     $36 = ($35|0)==(128);
     if (!($36)) {
      label = 31;
      break L5;
     }
     $37 = $23 << 6;
     $38 = $37 & 1984;
     $39 = $34 & 63;
     $40 = $39 | $38;
     $41 = ($40>>>0)>($3>>>0);
     if ($41) {
      label = 31;
      break L5;
     } else {
      $$2102 = $$0100;$$598 = $29;
      break;
     }
    }
    $42 = ($22&255)<(240);
    $43 = ((($$194)) + 3|0);
    if ($42) {
     $44 = ($31|0)<(3);
     if ($44) {
      label = 31;
      break L5;
     }
     $45 = HEAP8[$26>>0]|0;
     $46 = HEAP8[$29>>0]|0;
     $47 = $45&255;
     $48 = $47 & 224;
     switch ($22<<24>>24) {
     case -32:  {
      $49 = ($48|0)==(160);
      if (!($49)) {
       $$lcssa125$sink = $30;
       break L5;
      }
      break;
     }
     case -19:  {
      $50 = ($48|0)==(128);
      if (!($50)) {
       $$lcssa125$sink = $30;
       break L5;
      }
      break;
     }
     default: {
      $51 = $47 & 192;
      $52 = ($51|0)==(128);
      if (!($52)) {
       $$lcssa125$sink = $30;
       break L5;
      }
     }
     }
     $53 = $46&255;
     $54 = $53 & 192;
     $55 = ($54|0)==(128);
     if (!($55)) {
      label = 31;
      break L5;
     }
     $56 = $23 << 12;
     $57 = $56 & 61440;
     $58 = $47 << 6;
     $59 = $58 & 4032;
     $60 = $59 | $57;
     $61 = $53 & 63;
     $62 = $60 | $61;
     $63 = ($62>>>0)>($3>>>0);
     if ($63) {
      label = 31;
      break L5;
     } else {
      $$2102 = $$0100;$$598 = $43;
      break;
     }
    }
    $64 = ($22&255)<(245);
    if (!($64)) {
     label = 31;
     break L5;
    }
    $65 = ($31|0)<(4);
    $66 = (($2) - ($$0100))|0;
    $67 = ($66>>>0)<(2);
    $or$cond115 = $67 | $65;
    if ($or$cond115) {
     label = 31;
     break L5;
    }
    $68 = HEAP8[$26>>0]|0;
    $69 = HEAP8[$29>>0]|0;
    $70 = HEAP8[$43>>0]|0;
    $71 = $68&255;
    switch ($22<<24>>24) {
    case -16:  {
     $$off = (($68) + 112)<<24>>24;
     $72 = ($$off&255)<(48);
     if (!($72)) {
      $$lcssa125$sink = $30;
      break L5;
     }
     break;
    }
    case -12:  {
     $73 = $71 & 240;
     $74 = ($73|0)==(128);
     if (!($74)) {
      $$lcssa125$sink = $30;
      break L5;
     }
     break;
    }
    default: {
     $75 = $71 & 192;
     $76 = ($75|0)==(128);
     if (!($76)) {
      $$lcssa125$sink = $30;
      break L5;
     }
    }
    }
    $77 = $69&255;
    $78 = $77 & 192;
    $79 = ($78|0)==(128);
    if (!($79)) {
     label = 31;
     break L5;
    }
    $80 = $70&255;
    $81 = $80 & 192;
    $82 = ($81|0)==(128);
    if (!($82)) {
     label = 31;
     break L5;
    }
    $83 = $23 << 18;
    $84 = $83 & 1835008;
    $85 = $71 << 12;
    $86 = $85 & 258048;
    $87 = $86 | $84;
    $88 = $77 << 6;
    $89 = $88 & 4032;
    $90 = $87 | $89;
    $91 = $80 & 63;
    $92 = $90 | $91;
    $93 = ($92>>>0)>($3>>>0);
    $94 = (($$0100) + 1)|0;
    $95 = ((($$194)) + 4|0);
    if ($93) {
     label = 31;
     break L5;
    } else {
     $$2102 = $94;$$598 = $95;
    }
   }
  } while(0);
  $96 = (($$2102) + 1)|0;
  $$0100 = $96;$$194 = $$598;
 }
 if ((label|0) == 31) {
  $97 = $$194;
  $$lcssa125$sink = $97;
 }
 $98 = (($$lcssa125$sink) - ($8))|0;
 return ($98|0);
}
function __ZNSt3__2L13utf8_to_utf16EPKhS1_RS1_PtS3_RS3_mNS_12codecvt_modeE($0,$1,$2,$3,$4,$5,$6,$7) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 var $$8 = 0, $$off = 0, $$sink = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$2>>2] = $0;
 HEAP32[$5>>2] = $3;
 $8 = $7 & 4;
 $9 = ($8|0)==(0);
 $10 = $1;
 if (!($9)) {
  $11 = HEAP32[$2>>2]|0;
  $12 = $11;
  $13 = (($10) - ($12))|0;
  $14 = ($13|0)>(2);
  if ($14) {
   $15 = HEAP8[$11>>0]|0;
   $16 = ($15<<24>>24)==(-17);
   if ($16) {
    $17 = ((($11)) + 1|0);
    $18 = HEAP8[$17>>0]|0;
    $19 = ($18<<24>>24)==(-69);
    if ($19) {
     $20 = ((($11)) + 2|0);
     $21 = HEAP8[$20>>0]|0;
     $22 = ($21<<24>>24)==(-65);
     if ($22) {
      $23 = ((($11)) + 3|0);
      HEAP32[$2>>2] = $23;
     }
    }
   }
  }
 }
 $24 = $4;
 L8: while(1) {
  $25 = HEAP32[$2>>2]|0;
  $26 = ($25>>>0)<($1>>>0);
  if (!($26)) {
   label = 40;
   break;
  }
  $27 = HEAP32[$5>>2]|0;
  $28 = ($27>>>0)<($4>>>0);
  if (!($28)) {
   label = 40;
   break;
  }
  $29 = HEAP8[$25>>0]|0;
  $30 = $29&255;
  $31 = ($30>>>0)>($6>>>0);
  if ($31) {
   $$8 = 2;
   break;
  }
  $32 = ($29<<24>>24)>(-1);
  $33 = ((($25)) + 1|0);
  do {
   if ($32) {
    $34 = $29&255;
    HEAP16[$27>>1] = $34;
    $$sink = $33;
   } else {
    $35 = ($29&255)<(194);
    if ($35) {
     $$8 = 2;
     break L8;
    }
    $36 = ($29&255)<(224);
    $37 = $25;
    $38 = (($10) - ($37))|0;
    $39 = ((($25)) + 2|0);
    if ($36) {
     $40 = ($38|0)<(2);
     if ($40) {
      $$8 = 1;
      break L8;
     }
     $41 = HEAP8[$33>>0]|0;
     $42 = $41&255;
     $43 = $42 & 192;
     $44 = ($43|0)==(128);
     if (!($44)) {
      $$8 = 2;
      break L8;
     }
     $45 = $30 << 6;
     $46 = $45 & 1984;
     $47 = $42 & 63;
     $48 = $47 | $46;
     $49 = ($48>>>0)>($6>>>0);
     if ($49) {
      $$8 = 2;
      break L8;
     }
     $50 = $48&65535;
     HEAP16[$27>>1] = $50;
     $$sink = $39;
     break;
    }
    $51 = ($29&255)<(240);
    $52 = ((($25)) + 3|0);
    if ($51) {
     $53 = ($38|0)<(3);
     if ($53) {
      $$8 = 1;
      break L8;
     }
     $54 = HEAP8[$33>>0]|0;
     $55 = HEAP8[$39>>0]|0;
     $56 = $54&255;
     $57 = $56 & 224;
     switch ($29<<24>>24) {
     case -32:  {
      $58 = ($57|0)==(160);
      if (!($58)) {
       $$8 = 2;
       break L8;
      }
      break;
     }
     case -19:  {
      $59 = ($57|0)==(128);
      if (!($59)) {
       $$8 = 2;
       break L8;
      }
      break;
     }
     default: {
      $60 = $56 & 192;
      $61 = ($60|0)==(128);
      if (!($61)) {
       $$8 = 2;
       break L8;
      }
     }
     }
     $62 = $55&255;
     $63 = $62 & 192;
     $64 = ($63|0)==(128);
     if (!($64)) {
      $$8 = 2;
      break L8;
     }
     $65 = $30 << 12;
     $66 = $56 << 6;
     $67 = $66 & 4032;
     $68 = $67 | $65;
     $69 = $62 & 63;
     $70 = $68 | $69;
     $71 = $70 & 65535;
     $72 = ($71>>>0)>($6>>>0);
     if ($72) {
      $$8 = 2;
      break L8;
     }
     $73 = $70&65535;
     HEAP16[$27>>1] = $73;
     $$sink = $52;
     break;
    }
    $74 = ($29&255)<(245);
    if (!($74)) {
     $$8 = 2;
     break L8;
    }
    $75 = ($38|0)<(4);
    if ($75) {
     $$8 = 1;
     break L8;
    }
    $76 = HEAP8[$33>>0]|0;
    $77 = HEAP8[$39>>0]|0;
    $78 = HEAP8[$52>>0]|0;
    $79 = $76&255;
    switch ($29<<24>>24) {
    case -16:  {
     $$off = (($76) + 112)<<24>>24;
     $80 = ($$off&255)<(48);
     if (!($80)) {
      $$8 = 2;
      break L8;
     }
     break;
    }
    case -12:  {
     $81 = $79 & 240;
     $82 = ($81|0)==(128);
     if (!($82)) {
      $$8 = 2;
      break L8;
     }
     break;
    }
    default: {
     $83 = $79 & 192;
     $84 = ($83|0)==(128);
     if (!($84)) {
      $$8 = 2;
      break L8;
     }
    }
    }
    $85 = $77&255;
    $86 = $85 & 192;
    $87 = ($86|0)==(128);
    if (!($87)) {
     $$8 = 2;
     break L8;
    }
    $88 = $78&255;
    $89 = $88 & 192;
    $90 = ($89|0)==(128);
    if (!($90)) {
     $$8 = 2;
     break L8;
    }
    $91 = $27;
    $92 = (($24) - ($91))|0;
    $93 = ($92|0)<(4);
    if ($93) {
     $$8 = 1;
     break L8;
    }
    $94 = $30 & 7;
    $95 = $94 << 18;
    $96 = $79 << 12;
    $97 = $96 & 258048;
    $98 = $97 | $95;
    $99 = $85 << 6;
    $100 = $99 & 4032;
    $101 = $98 | $100;
    $102 = $88 & 63;
    $103 = $101 | $102;
    $104 = ($103>>>0)>($6>>>0);
    if ($104) {
     $$8 = 2;
     break L8;
    }
    $105 = $94 << 2;
    $106 = $79 >>> 4;
    $107 = $106 & 3;
    $108 = $107 | $105;
    $109 = $108 << 6;
    $110 = (($109) + 16320)|0;
    $111 = $79 << 2;
    $112 = $111 & 60;
    $113 = $85 >>> 4;
    $114 = $113 & 3;
    $115 = $112 | $114;
    $116 = $115 | $110;
    $117 = $116 | 55296;
    $118 = $117&65535;
    HEAP16[$27>>1] = $118;
    $119 = $99 & 960;
    $120 = $102 | $119;
    $121 = $120 | 56320;
    $122 = $121&65535;
    $123 = ((($27)) + 2|0);
    HEAP32[$5>>2] = $123;
    HEAP16[$123>>1] = $122;
    $124 = HEAP32[$2>>2]|0;
    $125 = ((($124)) + 4|0);
    $$sink = $125;
   }
  } while(0);
  HEAP32[$2>>2] = $$sink;
  $126 = HEAP32[$5>>2]|0;
  $127 = ((($126)) + 2|0);
  HEAP32[$5>>2] = $127;
 }
 if ((label|0) == 40) {
  $128 = $26&1;
  $$8 = $128;
 }
 return ($$8|0);
}
function __ZNSt3__2L13utf16_to_utf8EPKtS1_RS1_PhS3_RS3_mNS_12codecvt_modeE($0,$1,$2,$3,$4,$5,$6,$7) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 var $$4 = 0, $$pre = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 HEAP32[$2>>2] = $0;
 HEAP32[$5>>2] = $3;
 $8 = $7 & 2;
 $9 = ($8|0)==(0);
 $10 = $4;
 if ($9) {
  label = 4;
 } else {
  $11 = $3;
  $12 = (($10) - ($11))|0;
  $13 = ($12|0)<(3);
  if ($13) {
   $$4 = 1;
  } else {
   $14 = ((($3)) + 1|0);
   HEAP32[$5>>2] = $14;
   HEAP8[$3>>0] = -17;
   $15 = HEAP32[$5>>2]|0;
   $16 = ((($15)) + 1|0);
   HEAP32[$5>>2] = $16;
   HEAP8[$15>>0] = -69;
   $17 = HEAP32[$5>>2]|0;
   $18 = ((($17)) + 1|0);
   HEAP32[$5>>2] = $18;
   HEAP8[$17>>0] = -65;
   label = 4;
  }
 }
 L4: do {
  if ((label|0) == 4) {
   $19 = $1;
   $$pre = HEAP32[$2>>2]|0;
   $20 = $$pre;
   while(1) {
    $21 = ($20>>>0)<($1>>>0);
    if (!($21)) {
     $$4 = 0;
     break L4;
    }
    $22 = HEAP16[$20>>1]|0;
    $23 = $22&65535;
    $24 = ($23>>>0)>($6>>>0);
    if ($24) {
     $$4 = 2;
     break L4;
    }
    $25 = ($22&65535)<(128);
    do {
     if ($25) {
      $26 = HEAP32[$5>>2]|0;
      $27 = $26;
      $28 = (($10) - ($27))|0;
      $29 = ($28|0)<(1);
      if ($29) {
       $$4 = 1;
       break L4;
      }
      $30 = $22&255;
      $31 = ((($26)) + 1|0);
      HEAP32[$5>>2] = $31;
      HEAP8[$26>>0] = $30;
     } else {
      $32 = ($22&65535)<(2048);
      $33 = $23 & 63;
      $34 = $33 | 128;
      $35 = $34&255;
      if ($32) {
       $36 = HEAP32[$5>>2]|0;
       $37 = $36;
       $38 = (($10) - ($37))|0;
       $39 = ($38|0)<(2);
       if ($39) {
        $$4 = 1;
        break L4;
       }
       $40 = $23 >>> 6;
       $41 = $40 | 192;
       $42 = $41&255;
       $43 = ((($36)) + 1|0);
       HEAP32[$5>>2] = $43;
       HEAP8[$36>>0] = $42;
       $44 = HEAP32[$5>>2]|0;
       $45 = ((($44)) + 1|0);
       HEAP32[$5>>2] = $45;
       HEAP8[$44>>0] = $35;
       break;
      }
      $46 = ($22&65535)<(55296);
      $47 = $23 >>> 12;
      $48 = $47 | 224;
      $49 = $48&255;
      $50 = $23 >>> 6;
      $51 = $50 & 63;
      $52 = $51 | 128;
      $53 = $52&255;
      if ($46) {
       $54 = HEAP32[$5>>2]|0;
       $55 = $54;
       $56 = (($10) - ($55))|0;
       $57 = ($56|0)<(3);
       if ($57) {
        $$4 = 1;
        break L4;
       }
       $58 = ((($54)) + 1|0);
       HEAP32[$5>>2] = $58;
       HEAP8[$54>>0] = $49;
       $59 = HEAP32[$5>>2]|0;
       $60 = ((($59)) + 1|0);
       HEAP32[$5>>2] = $60;
       HEAP8[$59>>0] = $53;
       $61 = HEAP32[$5>>2]|0;
       $62 = ((($61)) + 1|0);
       HEAP32[$5>>2] = $62;
       HEAP8[$61>>0] = $35;
       break;
      }
      $63 = ($22&65535)<(56320);
      if (!($63)) {
       $113 = ($22&65535)<(57344);
       if ($113) {
        $$4 = 2;
        break L4;
       }
       $114 = HEAP32[$5>>2]|0;
       $115 = $114;
       $116 = (($10) - ($115))|0;
       $117 = ($116|0)<(3);
       if ($117) {
        $$4 = 1;
        break L4;
       }
       $118 = ((($114)) + 1|0);
       HEAP32[$5>>2] = $118;
       HEAP8[$114>>0] = $49;
       $119 = HEAP32[$5>>2]|0;
       $120 = ((($119)) + 1|0);
       HEAP32[$5>>2] = $120;
       HEAP8[$119>>0] = $53;
       $121 = HEAP32[$5>>2]|0;
       $122 = ((($121)) + 1|0);
       HEAP32[$5>>2] = $122;
       HEAP8[$121>>0] = $35;
       break;
      }
      $64 = $20;
      $65 = (($19) - ($64))|0;
      $66 = ($65|0)<(4);
      if ($66) {
       $$4 = 1;
       break L4;
      }
      $67 = ((($20)) + 2|0);
      $68 = HEAP16[$67>>1]|0;
      $69 = $68&65535;
      $70 = $69 & 64512;
      $71 = ($70|0)==(56320);
      if (!($71)) {
       $$4 = 2;
       break L4;
      }
      $72 = HEAP32[$5>>2]|0;
      $73 = (($10) - ($72))|0;
      $74 = ($73|0)<(4);
      if ($74) {
       $$4 = 1;
       break L4;
      }
      $75 = $23 & 960;
      $76 = $75 << 10;
      $77 = (($76) + 65536)|0;
      $78 = $33 << 10;
      $79 = $77 | $78;
      $80 = $69 & 1023;
      $81 = $79 | $80;
      $82 = ($81>>>0)>($6>>>0);
      if ($82) {
       $$4 = 2;
       break L4;
      }
      HEAP32[$2>>2] = $67;
      $83 = $75 >>> 6;
      $84 = (($83) + 1)|0;
      $85 = $84 >>> 2;
      $86 = $85 | 240;
      $87 = $86&255;
      $88 = HEAP32[$5>>2]|0;
      $89 = ((($88)) + 1|0);
      HEAP32[$5>>2] = $89;
      HEAP8[$88>>0] = $87;
      $90 = $84 << 4;
      $91 = $90 & 48;
      $92 = $23 >>> 2;
      $93 = $92 & 15;
      $94 = $93 | $91;
      $95 = $94 | 128;
      $96 = $95&255;
      $97 = HEAP32[$5>>2]|0;
      $98 = ((($97)) + 1|0);
      HEAP32[$5>>2] = $98;
      HEAP8[$97>>0] = $96;
      $99 = $23 << 4;
      $100 = $99 & 48;
      $101 = $69 >>> 6;
      $102 = $101 & 15;
      $103 = $100 | $102;
      $104 = $103 | 128;
      $105 = $104&255;
      $106 = HEAP32[$5>>2]|0;
      $107 = ((($106)) + 1|0);
      HEAP32[$5>>2] = $107;
      HEAP8[$106>>0] = $105;
      $108 = $69 & 63;
      $109 = $108 | 128;
      $110 = $109&255;
      $111 = HEAP32[$5>>2]|0;
      $112 = ((($111)) + 1|0);
      HEAP32[$5>>2] = $112;
      HEAP8[$111>>0] = $110;
     }
    } while(0);
    $123 = HEAP32[$2>>2]|0;
    $124 = ((($123)) + 2|0);
    HEAP32[$2>>2] = $124;
    $20 = $124;
   }
  }
 } while(0);
 return ($$4|0);
}
function __ZNSt3__26locale5__impD2Ev($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (99116);
 $1 = ((($0)) + 8|0);
 $2 = ((($0)) + 12|0);
 $$0 = 0;
 while(1) {
  $3 = HEAP32[$2>>2]|0;
  $4 = HEAP32[$1>>2]|0;
  $5 = (($3) - ($4))|0;
  $6 = $5 >> 2;
  $7 = ($$0>>>0)<($6>>>0);
  if (!($7)) {
   break;
  }
  $9 = $4;
  $10 = (($9) + ($$0<<2)|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($11|0)==(0|0);
  if (!($12)) {
   (__ZNSt3__214__shared_count16__release_sharedEv($11)|0);
  }
  $13 = (($$0) + 1)|0;
  $$0 = $13;
 }
 $8 = ((($0)) + 144|0);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($8);
 __ZNSt3__213__vector_baseIPNS_6locale5facetENS_15__sso_allocatorIS3_Lj28EEEED2Ev($1);
 __ZNSt3__26locale5facetD2Ev($0);
 return;
}
function __ZNSt3__26locale5__impD0Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__26locale5__impD2Ev($0);
 __ZdlPv($0);
 return;
}
function __ZNSt3__213__vector_baseIPNS_6locale5facetENS_15__sso_allocatorIS3_Lj28EEEED2Ev($0) {
 $0 = $0|0;
 var $$pre$i$i = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if (!($2)) {
   $3 = ((($0)) + 4|0);
   $$pre$i$i = HEAP32[$3>>2]|0;
   $4 = $$pre$i$i;
   while(1) {
    $5 = ($4|0)==($1|0);
    if ($5) {
     break;
    }
    $6 = ((($4)) + -4|0);
    HEAP32[$3>>2] = $6;
    $4 = $6;
   }
   $7 = ((($0)) + 16|0);
   $8 = ($7|0)==($1|0);
   if ($8) {
    $9 = ((($0)) + 128|0);
    HEAP8[$9>>0] = 0;
    break;
   } else {
    __ZdlPv($1);
    break;
   }
  }
 } while(0);
 return;
}
function __ZNSt3__25ctypeIcED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (99136);
 $1 = ((($0)) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = ((($0)) + 12|0);
  $5 = HEAP8[$4>>0]|0;
  $6 = ($5<<24>>24)==(0);
  if (!($6)) {
   __ZdaPv($2);
  }
 }
 __ZNSt3__26locale5facetD2Ev($0);
 return;
}
function __ZNSt3__25ctypeIcED0Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__25ctypeIcED2Ev($0);
 __ZdlPv($0);
 return;
}
function __ZNKSt3__25ctypeIcE10do_toupperEc($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1<<24>>24)>(-1);
 if ($2) {
  $3 = $1&255;
  $4 = (__ZNSt3__25ctypeIcE21__classic_upper_tableEv()|0);
  $5 = (($4) + ($3<<2)|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = $6&255;
  $8 = $7;
 } else {
  $8 = $1;
 }
 return ($8|0);
}
function __ZNKSt3__25ctypeIcE10do_toupperEPcPKc($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$0 = $1;
 while(1) {
  $3 = ($$0|0)==($2|0);
  if ($3) {
   break;
  }
  $4 = HEAP8[$$0>>0]|0;
  $5 = ($4<<24>>24)>(-1);
  if ($5) {
   $6 = (__ZNSt3__25ctypeIcE21__classic_upper_tableEv()|0);
   $7 = HEAP8[$$0>>0]|0;
   $8 = $7 << 24 >> 24;
   $9 = (($6) + ($8<<2)|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = $10&255;
   $12 = $11;
  } else {
   $12 = $4;
  }
  HEAP8[$$0>>0] = $12;
  $13 = ((($$0)) + 1|0);
  $$0 = $13;
 }
 return ($2|0);
}
function __ZNKSt3__25ctypeIcE10do_tolowerEc($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1<<24>>24)>(-1);
 if ($2) {
  $3 = $1 << 24 >> 24;
  $4 = (__ZNSt3__25ctypeIcE21__classic_lower_tableEv()|0);
  $5 = (($4) + ($3<<2)|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = $6&255;
  $8 = $7;
 } else {
  $8 = $1;
 }
 return ($8|0);
}
function __ZNKSt3__25ctypeIcE10do_tolowerEPcPKc($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$0 = $1;
 while(1) {
  $3 = ($$0|0)==($2|0);
  if ($3) {
   break;
  }
  $4 = HEAP8[$$0>>0]|0;
  $5 = ($4<<24>>24)>(-1);
  if ($5) {
   $6 = (__ZNSt3__25ctypeIcE21__classic_lower_tableEv()|0);
   $7 = HEAP8[$$0>>0]|0;
   $8 = $7 << 24 >> 24;
   $9 = (($6) + ($8<<2)|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = $10&255;
   $12 = $11;
  } else {
   $12 = $4;
  }
  HEAP8[$$0>>0] = $12;
  $13 = ((($$0)) + 1|0);
  $$0 = $13;
 }
 return ($2|0);
}
function __ZNKSt3__25ctypeIcE8do_widenEc($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ($1|0);
}
function __ZNKSt3__25ctypeIcE8do_widenEPKcS3_Pc($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $$07 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$0 = $3;$$07 = $1;
 while(1) {
  $4 = ($$07|0)==($2|0);
  if ($4) {
   break;
  }
  $5 = HEAP8[$$07>>0]|0;
  HEAP8[$$0>>0] = $5;
  $6 = ((($$07)) + 1|0);
  $7 = ((($$0)) + 1|0);
  $$0 = $7;$$07 = $6;
 }
 return ($2|0);
}
function __ZNKSt3__25ctypeIcE9do_narrowEcc($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$ = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($1<<24>>24)>(-1);
 $$ = $3 ? $1 : $2;
 return ($$|0);
}
function __ZNKSt3__25ctypeIcE9do_narrowEPKcS3_cPc($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$ = 0, $$0 = 0, $$09 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$0 = $4;$$09 = $1;
 while(1) {
  $5 = ($$09|0)==($2|0);
  if ($5) {
   break;
  }
  $6 = HEAP8[$$09>>0]|0;
  $7 = ($6<<24>>24)>(-1);
  $$ = $7 ? $6 : $3;
  HEAP8[$$0>>0] = $$;
  $8 = ((($$09)) + 1|0);
  $9 = ((($$0)) + 1|0);
  $$0 = $9;$$09 = $8;
 }
 return ($2|0);
}
function __ZNSt3__25ctypeIcE21__classic_lower_tableEv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 $0 = (invoke_i(4744)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $4 = ___cxa_find_matching_catch_3(0|0)|0;
  $5 = tempRet0;
  ___clang_call_terminate($4);
  // unreachable;
 } else {
  $3 = HEAP32[$0>>2]|0;
  return ($3|0);
 }
 return (0)|0;
}
function __ZNSt3__25ctypeIcE21__classic_upper_tableEv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 $0 = (invoke_i(4745)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $4 = ___cxa_find_matching_catch_3(0|0)|0;
  $5 = tempRet0;
  ___clang_call_terminate($4);
  // unreachable;
 } else {
  $3 = HEAP32[$0>>2]|0;
  return ($3|0);
 }
 return (0)|0;
}
function __ZNSt3__25ctypeIcE13classic_tableEv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 $0 = (invoke_i(4746)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $4 = ___cxa_find_matching_catch_3(0|0)|0;
  $5 = tempRet0;
  ___clang_call_terminate($4);
  // unreachable;
 } else {
  $3 = HEAP32[$0>>2]|0;
  return ($3|0);
 }
 return (0)|0;
}
function __ZNSt3__28numpunctIcED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (99188);
 $1 = ((($0)) + 12|0);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($1);
 __ZNSt3__26locale5facetD2Ev($0);
 return;
}
function __ZNSt3__28numpunctIcED0Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__28numpunctIcED2Ev($0);
 __ZdlPv($0);
 return;
}
function __ZNKSt3__28numpunctIcE16do_decimal_pointEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 8|0);
 $2 = HEAP8[$1>>0]|0;
 return ($2|0);
}
function __ZNKSt3__28numpunctIcE16do_thousands_sepEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 9|0);
 $2 = HEAP8[$1>>0]|0;
 return ($2|0);
}
function __ZNKSt3__28numpunctIcE11do_groupingEv($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 12|0);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_($0,$2);
 return;
}
function __ZNKSt3__28numpunctIcE11do_truenameEv($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 ;HEAP32[$0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;
 $3 = (__ZNSt3__211char_traitsIcE6lengthEPKc(204748)|0);
 $4 = ($3>>>0)>(4294967279);
 if ($4) {
  __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $5 = ($3>>>0)<(11);
 if ($5) {
  $6 = $3&255;
  $7 = ((($0)) + 11|0);
  HEAP8[$7>>0] = $6;
  $$0$i$i = $0;
 } else {
  $8 = (($3) + 16)|0;
  $9 = $8 & -16;
  $10 = (__Znwj($9)|0);
  HEAP32[$0>>2] = $10;
  $11 = $9 | -2147483648;
  $12 = ((($0)) + 8|0);
  HEAP32[$12>>2] = $11;
  $13 = ((($0)) + 4|0);
  HEAP32[$13>>2] = $3;
  $$0$i$i = $10;
 }
 (__ZNSt3__211char_traitsIcE4copyEPcPKcj($$0$i$i,204748,$3)|0);
 $14 = (($$0$i$i) + ($3)|0);
 HEAP8[$2>>0] = 0;
 __ZNSt3__211char_traitsIcE6assignERcRKc($14,$2);
 STACKTOP = sp;return;
}
function __ZNKSt3__28numpunctIcE12do_falsenameEv($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 ;HEAP32[$0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;
 $3 = (__ZNSt3__211char_traitsIcE6lengthEPKc(204742)|0);
 $4 = ($3>>>0)>(4294967279);
 if ($4) {
  __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $5 = ($3>>>0)<(11);
 if ($5) {
  $6 = $3&255;
  $7 = ((($0)) + 11|0);
  HEAP8[$7>>0] = $6;
  $$0$i$i = $0;
 } else {
  $8 = (($3) + 16)|0;
  $9 = $8 & -16;
  $10 = (__Znwj($9)|0);
  HEAP32[$0>>2] = $10;
  $11 = $9 | -2147483648;
  $12 = ((($0)) + 8|0);
  HEAP32[$12>>2] = $11;
  $13 = ((($0)) + 4|0);
  HEAP32[$13>>2] = $3;
  $$0$i$i = $10;
 }
 (__ZNSt3__211char_traitsIcE4copyEPcPKcj($$0$i$i,204742,$3)|0);
 $14 = (($$0$i$i) + ($3)|0);
 HEAP8[$2>>0] = 0;
 __ZNSt3__211char_traitsIcE6assignERcRKc($14,$2);
 STACKTOP = sp;return;
}
function __ZNSt3__28numpunctIwED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (99228);
 $1 = ((($0)) + 16|0);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($1);
 __ZNSt3__26locale5facetD2Ev($0);
 return;
}
function __ZNSt3__28numpunctIwED0Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__28numpunctIwED2Ev($0);
 __ZdlPv($0);
 return;
}
function __ZNKSt3__28numpunctIwE16do_decimal_pointEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 return ($2|0);
}
function __ZNKSt3__28numpunctIwE16do_thousands_sepEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 return ($2|0);
}
function __ZNKSt3__28numpunctIwE11do_groupingEv($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 16|0);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_($0,$2);
 return;
}
function __ZNKSt3__28numpunctIwE11do_truenameEv($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 ;HEAP32[$0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;
 $3 = (__ZNSt3__211char_traitsIwE6lengthEPKw(99284)|0);
 $4 = ($3>>>0)>(1073741807);
 if ($4) {
  __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $5 = ($3>>>0)<(2);
 do {
  if ($5) {
   $6 = $3&255;
   $7 = ((($0)) + 8|0);
   $8 = ((($7)) + 3|0);
   HEAP8[$8>>0] = $6;
   $$0$i$i = $0;
  } else {
   $9 = (($3) + 4)|0;
   $10 = $9 & -4;
   $11 = ($10>>>0)>(1073741823);
   if (!($11)) {
    $17 = $10 << 2;
    $18 = (__Znwj($17)|0);
    HEAP32[$0>>2] = $18;
    $19 = $10 | -2147483648;
    $20 = ((($0)) + 8|0);
    HEAP32[$20>>2] = $19;
    $21 = ((($0)) + 4|0);
    HEAP32[$21>>2] = $3;
    $$0$i$i = $18;
    break;
   }
   $12 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($12|0),(204840|0));
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if ($14) {
    $15 = ___cxa_find_matching_catch_2()|0;
    $16 = tempRet0;
    ___cxa_free_exception(($12|0));
    ___resumeException($15|0);
    // unreachable;
   } else {
    HEAP32[$12>>2] = (99824);
    ___cxa_throw(($12|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 (__ZNSt3__211char_traitsIwE4copyEPwPKwj($$0$i$i,99284,$3)|0);
 $22 = (($$0$i$i) + ($3<<2)|0);
 HEAP32[$2>>2] = 0;
 __ZNSt3__211char_traitsIwE6assignERwRKw($22,$2);
 STACKTOP = sp;return;
}
function __ZNKSt3__28numpunctIwE12do_falsenameEv($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 ;HEAP32[$0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;
 $3 = (__ZNSt3__211char_traitsIwE6lengthEPKw(99260)|0);
 $4 = ($3>>>0)>(1073741807);
 if ($4) {
  __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $5 = ($3>>>0)<(2);
 do {
  if ($5) {
   $6 = $3&255;
   $7 = ((($0)) + 8|0);
   $8 = ((($7)) + 3|0);
   HEAP8[$8>>0] = $6;
   $$0$i$i = $0;
  } else {
   $9 = (($3) + 4)|0;
   $10 = $9 & -4;
   $11 = ($10>>>0)>(1073741823);
   if (!($11)) {
    $17 = $10 << 2;
    $18 = (__Znwj($17)|0);
    HEAP32[$0>>2] = $18;
    $19 = $10 | -2147483648;
    $20 = ((($0)) + 8|0);
    HEAP32[$20>>2] = $19;
    $21 = ((($0)) + 4|0);
    HEAP32[$21>>2] = $3;
    $$0$i$i = $18;
    break;
   }
   $12 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($12|0),(204840|0));
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if ($14) {
    $15 = ___cxa_find_matching_catch_2()|0;
    $16 = tempRet0;
    ___cxa_free_exception(($12|0));
    ___resumeException($15|0);
    // unreachable;
   } else {
    HEAP32[$12>>2] = (99824);
    ___cxa_throw(($12|0),(34608|0),(3230|0));
    // unreachable;
   }
  }
 } while(0);
 (__ZNSt3__211char_traitsIwE4copyEPwPKwj($$0$i$i,99260,$3)|0);
 $22 = (($$0$i$i) + ($3<<2)|0);
 HEAP32[$2>>2] = 0;
 __ZNSt3__211char_traitsIwE6assignERwRKw($22,$2);
 STACKTOP = sp;return;
}
function __ZNSt3__26locale5facetD0Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__26locale5facetD2Ev($0);
 __ZdlPv($0);
 return;
}
function __ZNSt3__25ctypeIwED0Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__26locale5facetD2Ev($0);
 __ZdlPv($0);
 return;
}
function __ZNKSt3__25ctypeIwE5do_isEtw($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($2>>>0)<(128);
 if ($3) {
  $4 = (__ZNSt3__25ctypeIcE13classic_tableEv()|0);
  $5 = (($4) + ($2<<1)|0);
  $6 = HEAP16[$5>>1]|0;
  $7 = $6 & $1;
  $8 = ($7<<16>>16)!=(0);
  $9 = $8;
 } else {
  $9 = 0;
 }
 return ($9|0);
}
function __ZNKSt3__25ctypeIwE5do_isEPKwS3_Pt($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $$08 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$0 = $3;$$08 = $1;
 while(1) {
  $4 = ($$08|0)==($2|0);
  if ($4) {
   break;
  }
  $5 = HEAP32[$$08>>2]|0;
  $6 = ($5>>>0)<(128);
  if ($6) {
   $7 = (__ZNSt3__25ctypeIcE13classic_tableEv()|0);
   $8 = HEAP32[$$08>>2]|0;
   $9 = (($7) + ($8<<1)|0);
   $10 = HEAP16[$9>>1]|0;
   $11 = $10&65535;
   $13 = $11;
  } else {
   $13 = 0;
  }
  $12 = $13&65535;
  HEAP16[$$0>>1] = $12;
  $14 = ((($$08)) + 4|0);
  $15 = ((($$0)) + 2|0);
  $$0 = $15;$$08 = $14;
 }
 return ($2|0);
}
function __ZNKSt3__25ctypeIwE10do_scan_isEtPKwS3_($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $$0$lcssa = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$0 = $2;
 while(1) {
  $4 = ($$0|0)==($3|0);
  if ($4) {
   $$0$lcssa = $3;
   break;
  }
  $5 = HEAP32[$$0>>2]|0;
  $6 = ($5>>>0)<(128);
  if ($6) {
   $7 = (__ZNSt3__25ctypeIcE13classic_tableEv()|0);
   $8 = HEAP32[$$0>>2]|0;
   $9 = (($7) + ($8<<1)|0);
   $10 = HEAP16[$9>>1]|0;
   $11 = $10 & $1;
   $12 = ($11<<16>>16)==(0);
   if (!($12)) {
    $$0$lcssa = $$0;
    break;
   }
  }
  $13 = ((($$0)) + 4|0);
  $$0 = $13;
 }
 return ($$0$lcssa|0);
}
function __ZNKSt3__25ctypeIwE11do_scan_notEtPKwS3_($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $$0$lcssa = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$0 = $2;
 while(1) {
  $4 = ($$0|0)==($3|0);
  if ($4) {
   $$0$lcssa = $3;
   break;
  }
  $5 = HEAP32[$$0>>2]|0;
  $6 = ($5>>>0)<(128);
  if (!($6)) {
   $$0$lcssa = $$0;
   break;
  }
  $7 = (__ZNSt3__25ctypeIcE13classic_tableEv()|0);
  $8 = HEAP32[$$0>>2]|0;
  $9 = (($7) + ($8<<1)|0);
  $10 = HEAP16[$9>>1]|0;
  $11 = $10 & $1;
  $12 = ($11<<16>>16)==(0);
  if ($12) {
   $$0$lcssa = $$0;
   break;
  }
  $13 = ((($$0)) + 4|0);
  $$0 = $13;
 }
 return ($$0$lcssa|0);
}
function __ZNKSt3__25ctypeIwE10do_toupperEw($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1>>>0)<(128);
 if ($2) {
  $3 = (__ZNSt3__25ctypeIcE21__classic_upper_tableEv()|0);
  $4 = (($3) + ($1<<2)|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = $5;
 } else {
  $6 = $1;
 }
 return ($6|0);
}
function __ZNKSt3__25ctypeIwE10do_toupperEPwPKw($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$pre = 0, $10 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$0 = $1;
 while(1) {
  $3 = ($$0|0)==($2|0);
  if ($3) {
   break;
  }
  $4 = HEAP32[$$0>>2]|0;
  $5 = ($4>>>0)<(128);
  if ($5) {
   $6 = (__ZNSt3__25ctypeIcE21__classic_upper_tableEv()|0);
   $7 = HEAP32[$$0>>2]|0;
   $8 = (($6) + ($7<<2)|0);
   $$pre = HEAP32[$8>>2]|0;
   $9 = $$pre;
  } else {
   $9 = $4;
  }
  HEAP32[$$0>>2] = $9;
  $10 = ((($$0)) + 4|0);
  $$0 = $10;
 }
 return ($2|0);
}
function __ZNKSt3__25ctypeIwE10do_tolowerEw($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1>>>0)<(128);
 if ($2) {
  $3 = (__ZNSt3__25ctypeIcE21__classic_lower_tableEv()|0);
  $4 = (($3) + ($1<<2)|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = $5;
 } else {
  $6 = $1;
 }
 return ($6|0);
}
function __ZNKSt3__25ctypeIwE10do_tolowerEPwPKw($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$pre = 0, $10 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$0 = $1;
 while(1) {
  $3 = ($$0|0)==($2|0);
  if ($3) {
   break;
  }
  $4 = HEAP32[$$0>>2]|0;
  $5 = ($4>>>0)<(128);
  if ($5) {
   $6 = (__ZNSt3__25ctypeIcE21__classic_lower_tableEv()|0);
   $7 = HEAP32[$$0>>2]|0;
   $8 = (($6) + ($7<<2)|0);
   $$pre = HEAP32[$8>>2]|0;
   $9 = $$pre;
  } else {
   $9 = $4;
  }
  HEAP32[$$0>>2] = $9;
  $10 = ((($$0)) + 4|0);
  $$0 = $10;
 }
 return ($2|0);
}
function __ZNKSt3__25ctypeIwE8do_widenEc($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = $1 << 24 >> 24;
 return ($2|0);
}
function __ZNKSt3__25ctypeIwE8do_widenEPKcS3_Pw($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $$07 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$0 = $3;$$07 = $1;
 while(1) {
  $4 = ($$07|0)==($2|0);
  if ($4) {
   break;
  }
  $5 = HEAP8[$$07>>0]|0;
  $6 = $5 << 24 >> 24;
  HEAP32[$$0>>2] = $6;
  $7 = ((($$07)) + 1|0);
  $8 = ((($$0)) + 4|0);
  $$0 = $8;$$07 = $7;
 }
 return ($2|0);
}
function __ZNKSt3__25ctypeIwE9do_narrowEwc($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($1>>>0)<(128);
 $4 = $1&255;
 $$0 = $3 ? $4 : $2;
 return ($$0|0);
}
function __ZNKSt3__25ctypeIwE9do_narrowEPKwS3_cPc($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0 = 0, $$09 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep = 0, $storemerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = $1;
 $6 = $2;
 $7 = (($6) - ($5))|0;
 $8 = $7 >>> 2;
 $$0 = $4;$$09 = $1;
 while(1) {
  $9 = ($$09|0)==($2|0);
  if ($9) {
   break;
  }
  $10 = HEAP32[$$09>>2]|0;
  $11 = ($10>>>0)<(128);
  $12 = $10&255;
  $storemerge = $11 ? $12 : $3;
  HEAP8[$$0>>0] = $storemerge;
  $13 = ((($$09)) + 4|0);
  $14 = ((($$0)) + 1|0);
  $$0 = $14;$$09 = $13;
 }
 $scevgep = (($1) + ($8<<2)|0);
 return ($scevgep|0);
}
function __ZNSt3__27codecvtIcc11__mbstate_tED0Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__26locale5facetD2Ev($0);
 __ZdlPv($0);
 return;
}
function __ZNSt3__27codecvtIDsc11__mbstate_tED0Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__26locale5facetD2Ev($0);
 __ZdlPv($0);
 return;
}
function __ZNSt3__27codecvtIDic11__mbstate_tED0Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__26locale5facetD2Ev($0);
 __ZdlPv($0);
 return;
}
function __ZNSt3__220__time_get_c_storageIcEC2Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (99544);
 return;
}
function __ZNSt3__220__time_get_c_storageIwEC2Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (99580);
 return;
}
function __ZNSt3__25ctypeIcEC2EPKtbj($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $10 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = $2&1;
 $5 = (($3) + -1)|0;
 $6 = ((($0)) + 4|0);
 HEAP32[$6>>2] = $5;
 HEAP32[$0>>2] = (99136);
 $7 = ((($0)) + 8|0);
 HEAP32[$7>>2] = $1;
 $8 = ((($0)) + 12|0);
 HEAP8[$8>>0] = $4;
 $9 = ($1|0)==(0|0);
 if ($9) {
  $10 = (__ZNSt3__25ctypeIcE13classic_tableEv()|0);
  HEAP32[$7>>2] = $10;
 }
 return;
}
function __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (___cxa_allocate_exception(8)|0);
 __THREW__ = 0;
 invoke_vii(3366,($1|0),(204795|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch_2()|0;
  $5 = tempRet0;
  ___cxa_free_exception(($1|0));
  ___resumeException($4|0);
  // unreachable;
 } else {
  HEAP32[$1>>2] = (99824);
  ___cxa_throw(($1|0),(34608|0),(3230|0));
  // unreachable;
 }
}
function __ZNSt3__26locale5__impC2Ej($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$0$i$i = 0, $$03 = 0, $$1 = 0, $$14 = 0, $$pre$i$i$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = (($1) + -1)|0;
 $4 = ((($0)) + 4|0);
 HEAP32[$4>>2] = $3;
 HEAP32[$0>>2] = (99116);
 $5 = ((($0)) + 8|0);
 __THREW__ = 0;
 invoke_vii(4747,($5|0),28);
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if ($7) {
  $135 = ___cxa_find_matching_catch_2()|0;
  $136 = tempRet0;
  $$1 = $136;$$14 = $135;
 } else {
  $8 = ((($0)) + 144|0);
  ;HEAP32[$8>>2]=0|0;HEAP32[$8+4>>2]=0|0;HEAP32[$8+8>>2]=0|0;
  $9 = (__ZNSt3__211char_traitsIcE6lengthEPKc(202650)|0);
  $10 = ($9>>>0)>(4294967279);
  do {
   if ($10) {
    __THREW__ = 0;
    invoke_vi(3367,($8|0));
    $11 = __THREW__; __THREW__ = 0;
    label = 66;
   } else {
    $12 = ($9>>>0)<(11);
    if ($12) {
     $13 = $9&255;
     $14 = ((($8)) + 11|0);
     HEAP8[$14>>0] = $13;
     $$0$i$i = $8;
    } else {
     $15 = (($9) + 16)|0;
     $16 = $15 & -16;
     __THREW__ = 0;
     $17 = (invoke_ii(3276,($16|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      label = 66;
      break;
     }
     HEAP32[$8>>2] = $17;
     $20 = $16 | -2147483648;
     $21 = ((($0)) + 152|0);
     HEAP32[$21>>2] = $20;
     $22 = ((($0)) + 148|0);
     HEAP32[$22>>2] = $9;
     $$0$i$i = $17;
    }
    (__ZNSt3__211char_traitsIcE4copyEPcPKcj($$0$i$i,202650,$9)|0);
    $23 = (($$0$i$i) + ($9)|0);
    HEAP8[$2>>0] = 0;
    __ZNSt3__211char_traitsIcE6assignERcRKc($23,$2);
    $24 = HEAP32[$5>>2]|0;
    $25 = ((($0)) + 12|0);
    $$pre$i$i$i = HEAP32[$25>>2]|0;
    $26 = $$pre$i$i$i;
    while(1) {
     $27 = ($26|0)==($24|0);
     if ($27) {
      break;
     }
     $28 = ((($26)) + -4|0);
     HEAP32[$25>>2] = $28;
     $26 = $28;
    }
    __THREW__ = 0;
    invoke_v(4748);
    $29 = __THREW__; __THREW__ = 0;
    $30 = $29&1;
    do {
     if (!($30)) {
      __THREW__ = 0;
      invoke_vii(4749,($0|0),(207208|0));
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if (!($32)) {
       __THREW__ = 0;
       invoke_v(4750);
       $33 = __THREW__; __THREW__ = 0;
       $34 = $33&1;
       if (!($34)) {
        __THREW__ = 0;
        invoke_vii(4751,($0|0),(207216|0));
        $35 = __THREW__; __THREW__ = 0;
        $36 = $35&1;
        if (!($36)) {
         __ZNSt3__212_GLOBAL__N_14makeINS_5ctypeIcEEDnbjEERT_T0_T1_T2_();
         __THREW__ = 0;
         invoke_vii(4752,($0|0),(207224|0));
         $37 = __THREW__; __THREW__ = 0;
         $38 = $37&1;
         if (!($38)) {
          __THREW__ = 0;
          invoke_v(4753);
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if (!($40)) {
           __THREW__ = 0;
           invoke_vii(4754,($0|0),(207240|0));
           $41 = __THREW__; __THREW__ = 0;
           $42 = $41&1;
           if (!($42)) {
            __THREW__ = 0;
            invoke_v(4755);
            $43 = __THREW__; __THREW__ = 0;
            $44 = $43&1;
            if (!($44)) {
             __THREW__ = 0;
             invoke_vii(4756,($0|0),(207248|0));
             $45 = __THREW__; __THREW__ = 0;
             $46 = $45&1;
             if (!($46)) {
              __THREW__ = 0;
              invoke_v(4757);
              $47 = __THREW__; __THREW__ = 0;
              $48 = $47&1;
              if (!($48)) {
               __THREW__ = 0;
               invoke_vii(4758,($0|0),(207256|0));
               $49 = __THREW__; __THREW__ = 0;
               $50 = $49&1;
               if (!($50)) {
                __THREW__ = 0;
                invoke_v(4759);
                $51 = __THREW__; __THREW__ = 0;
                $52 = $51&1;
                if (!($52)) {
                 __THREW__ = 0;
                 invoke_vii(4760,($0|0),(207272|0));
                 $53 = __THREW__; __THREW__ = 0;
                 $54 = $53&1;
                 if (!($54)) {
                  __THREW__ = 0;
                  invoke_v(4761);
                  $55 = __THREW__; __THREW__ = 0;
                  $56 = $55&1;
                  if (!($56)) {
                   __THREW__ = 0;
                   invoke_vii(4762,($0|0),(207280|0));
                   $57 = __THREW__; __THREW__ = 0;
                   $58 = $57&1;
                   if ($58) {
                    break;
                   }
                   __ZNSt3__212_GLOBAL__N_14makeINS_8numpunctIcEEjEERT_T0_();
                   __THREW__ = 0;
                   invoke_vii(4763,($0|0),(207288|0));
                   $59 = __THREW__; __THREW__ = 0;
                   $60 = $59&1;
                   if ($60) {
                    break;
                   }
                   __ZNSt3__212_GLOBAL__N_14makeINS_8numpunctIwEEjEERT_T0_();
                   __THREW__ = 0;
                   invoke_vii(4764,($0|0),(207312|0));
                   $61 = __THREW__; __THREW__ = 0;
                   $62 = $61&1;
                   if ($62) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_v(4765);
                   $63 = __THREW__; __THREW__ = 0;
                   $64 = $63&1;
                   if ($64) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(4766,($0|0),(207344|0));
                   $65 = __THREW__; __THREW__ = 0;
                   $66 = $65&1;
                   if ($66) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_v(4767);
                   $67 = __THREW__; __THREW__ = 0;
                   $68 = $67&1;
                   if ($68) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(4768,($0|0),(207352|0));
                   $69 = __THREW__; __THREW__ = 0;
                   $70 = $69&1;
                   if ($70) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_v(4769);
                   $71 = __THREW__; __THREW__ = 0;
                   $72 = $71&1;
                   if ($72) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(4770,($0|0),(207360|0));
                   $73 = __THREW__; __THREW__ = 0;
                   $74 = $73&1;
                   if ($74) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_v(4771);
                   $75 = __THREW__; __THREW__ = 0;
                   $76 = $75&1;
                   if ($76) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(4772,($0|0),(207368|0));
                   $77 = __THREW__; __THREW__ = 0;
                   $78 = $77&1;
                   if ($78) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_v(4773);
                   $79 = __THREW__; __THREW__ = 0;
                   $80 = $79&1;
                   if ($80) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(4774,($0|0),(207376|0));
                   $81 = __THREW__; __THREW__ = 0;
                   $82 = $81&1;
                   if ($82) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_v(4775);
                   $83 = __THREW__; __THREW__ = 0;
                   $84 = $83&1;
                   if ($84) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(4776,($0|0),(207384|0));
                   $85 = __THREW__; __THREW__ = 0;
                   $86 = $85&1;
                   if ($86) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_v(4777);
                   $87 = __THREW__; __THREW__ = 0;
                   $88 = $87&1;
                   if ($88) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(4778,($0|0),(207392|0));
                   $89 = __THREW__; __THREW__ = 0;
                   $90 = $89&1;
                   if ($90) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_v(4779);
                   $91 = __THREW__; __THREW__ = 0;
                   $92 = $91&1;
                   if ($92) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(4780,($0|0),(207400|0));
                   $93 = __THREW__; __THREW__ = 0;
                   $94 = $93&1;
                   if ($94) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_v(4781);
                   $95 = __THREW__; __THREW__ = 0;
                   $96 = $95&1;
                   if ($96) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(4782,($0|0),(207408|0));
                   $97 = __THREW__; __THREW__ = 0;
                   $98 = $97&1;
                   if ($98) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_v(4783);
                   $99 = __THREW__; __THREW__ = 0;
                   $100 = $99&1;
                   if ($100) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(4784,($0|0),(207416|0));
                   $101 = __THREW__; __THREW__ = 0;
                   $102 = $101&1;
                   if ($102) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_v(4785);
                   $103 = __THREW__; __THREW__ = 0;
                   $104 = $103&1;
                   if ($104) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(4786,($0|0),(207424|0));
                   $105 = __THREW__; __THREW__ = 0;
                   $106 = $105&1;
                   if ($106) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_v(4787);
                   $107 = __THREW__; __THREW__ = 0;
                   $108 = $107&1;
                   if ($108) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(4788,($0|0),(207432|0));
                   $109 = __THREW__; __THREW__ = 0;
                   $110 = $109&1;
                   if ($110) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_v(4789);
                   $111 = __THREW__; __THREW__ = 0;
                   $112 = $111&1;
                   if ($112) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(4790,($0|0),(207440|0));
                   $113 = __THREW__; __THREW__ = 0;
                   $114 = $113&1;
                   if ($114) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_v(4791);
                   $115 = __THREW__; __THREW__ = 0;
                   $116 = $115&1;
                   if ($116) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(4792,($0|0),(207456|0));
                   $117 = __THREW__; __THREW__ = 0;
                   $118 = $117&1;
                   if ($118) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_v(4793);
                   $119 = __THREW__; __THREW__ = 0;
                   $120 = $119&1;
                   if ($120) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(4794,($0|0),(207472|0));
                   $121 = __THREW__; __THREW__ = 0;
                   $122 = $121&1;
                   if ($122) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_v(4795);
                   $123 = __THREW__; __THREW__ = 0;
                   $124 = $123&1;
                   if ($124) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(4796,($0|0),(207488|0));
                   $125 = __THREW__; __THREW__ = 0;
                   $126 = $125&1;
                   if ($126) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_v(4797);
                   $127 = __THREW__; __THREW__ = 0;
                   $128 = $127&1;
                   if ($128) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(4798,($0|0),(207504|0));
                   $129 = __THREW__; __THREW__ = 0;
                   $130 = $129&1;
                   if ($130) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_v(4799);
                   $131 = __THREW__; __THREW__ = 0;
                   $132 = $131&1;
                   if ($132) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(4800,($0|0),(207512|0));
                   $133 = __THREW__; __THREW__ = 0;
                   $134 = $133&1;
                   if ($134) {
                    break;
                   }
                   STACKTOP = sp;return;
                  }
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    } while(0);
    $139 = ___cxa_find_matching_catch_2()|0;
    $140 = tempRet0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($8);
    $$0 = $140;$$03 = $139;
   }
  } while(0);
  if ((label|0) == 66) {
   $137 = ___cxa_find_matching_catch_2()|0;
   $138 = tempRet0;
   $$0 = $138;$$03 = $137;
  }
  __ZNSt3__213__vector_baseIPNS_6locale5facetENS_15__sso_allocatorIS3_Lj28EEEED2Ev($5);
  $$1 = $$0;$$14 = $$03;
 }
 __ZNSt3__26locale5facetD2Ev($0);
 ___resumeException($$14|0);
 // unreachable;
}
function __ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lj28EEEEC2Ej($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = 0;
 $2 = ((($0)) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = ((($0)) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = ((($0)) + 128|0);
 HEAP8[$4>>0] = 0;
 $5 = ($1|0)==(0);
 do {
  if (!($5)) {
   __THREW__ = 0;
   invoke_vii(4801,($0|0),($1|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    invoke_vii(4802,($0|0),($1|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     break;
    }
   }
   $10 = ___cxa_find_matching_catch_2()|0;
   $11 = tempRet0;
   __ZNSt3__213__vector_baseIPNS_6locale5facetENS_15__sso_allocatorIS3_Lj28EEEED2Ev($0);
   ___resumeException($10|0);
   // unreachable;
  }
 } while(0);
 return;
}
function __ZNSt3__212_GLOBAL__N_14makeINS_7collateIcEEjEERT_T0_() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[(207212)>>2] = 0;
 HEAP32[51802] = (96780);
 return;
}
function __ZNSt3__26locale5__imp7installINS_7collateIcEEEEvPT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__ZNSt3__26locale2id5__getEv(215172)|0);
 __ZNSt3__26locale5__imp7installEPNS0_5facetEl($0,$1,$2);
 return;
}
function __ZNSt3__212_GLOBAL__N_14makeINS_7collateIwEEjEERT_T0_() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[(207220)>>2] = 0;
 HEAP32[51804] = (96812);
 return;
}
function __ZNSt3__26locale5__imp7installINS_7collateIwEEEEvPT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__ZNSt3__26locale2id5__getEv(215180)|0);
 __ZNSt3__26locale5__imp7installEPNS0_5facetEl($0,$1,$2);
 return;
}
function __ZNSt3__212_GLOBAL__N_14makeINS_5ctypeIcEEDnbjEERT_T0_T1_T2_() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__25ctypeIcEC2EPKtbj(207224,0,0,1);
 return;
}
function __ZNSt3__26locale5__imp7installINS_5ctypeIcEEEEvPT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__ZNSt3__26locale2id5__getEv(215188)|0);
 __ZNSt3__26locale5__imp7installEPNS0_5facetEl($0,$1,$2);
 return;
}
function __ZNSt3__212_GLOBAL__N_14makeINS_5ctypeIwEEjEERT_T0_() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[(207244)>>2] = 0;
 HEAP32[51810] = (99332);
 return;
}
function __ZNSt3__26locale5__imp7installINS_5ctypeIwEEEEvPT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__ZNSt3__26locale2id5__getEv(215220)|0);
 __ZNSt3__26locale5__imp7installEPNS0_5facetEl($0,$1,$2);
 return;
}
function __ZNSt3__212_GLOBAL__N_14makeINS_7codecvtIcc11__mbstate_tEEjEERT_T0_() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[(207252)>>2] = 0;
 HEAP32[51812] = (99400);
 return;
}
function __ZNSt3__26locale5__imp7installINS_7codecvtIcc11__mbstate_tEEEEvPT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__ZNSt3__26locale2id5__getEv(216980)|0);
 __ZNSt3__26locale5__imp7installEPNS0_5facetEl($0,$1,$2);
 return;
}
function __ZNSt3__212_GLOBAL__N_14makeINS_7codecvtIwc11__mbstate_tEEjEERT_T0_() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__27codecvtIwc11__mbstate_tEC2Ej(207256,1);
 return;
}
function __ZNSt3__26locale5__imp7installINS_7codecvtIwc11__mbstate_tEEEEvPT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__ZNSt3__26locale2id5__getEv(216988)|0);
 __ZNSt3__26locale5__imp7installEPNS0_5facetEl($0,$1,$2);
 return;
}
function __ZNSt3__212_GLOBAL__N_14makeINS_7codecvtIDsc11__mbstate_tEEjEERT_T0_() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[(207276)>>2] = 0;
 HEAP32[51818] = (99448);
 return;
}
function __ZNSt3__26locale5__imp7installINS_7codecvtIDsc11__mbstate_tEEEEvPT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__ZNSt3__26locale2id5__getEv(216996)|0);
 __ZNSt3__26locale5__imp7installEPNS0_5facetEl($0,$1,$2);
 return;
}
function __ZNSt3__212_GLOBAL__N_14makeINS_7codecvtIDic11__mbstate_tEEjEERT_T0_() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[(207284)>>2] = 0;
 HEAP32[51820] = (99496);
 return;
}
function __ZNSt3__26locale5__imp7installINS_7codecvtIDic11__mbstate_tEEEEvPT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__ZNSt3__26locale2id5__getEv(217004)|0);
 __ZNSt3__26locale5__imp7installEPNS0_5facetEl($0,$1,$2);
 return;
}
function __ZNSt3__212_GLOBAL__N_14makeINS_8numpunctIcEEjEERT_T0_() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__28numpunctIcEC2Ej(207288,1);
 return;
}
function __ZNSt3__26locale5__imp7installINS_8numpunctIcEEEEvPT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__ZNSt3__26locale2id5__getEv(215204)|0);
 __ZNSt3__26locale5__imp7installEPNS0_5facetEl($0,$1,$2);
 return;
}
function __ZNSt3__212_GLOBAL__N_14makeINS_8numpunctIwEEjEERT_T0_() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__28numpunctIwEC2Ej(207312,1);
 return;
}
function __ZNSt3__26locale5__imp7installINS_8numpunctIwEEEEvPT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__ZNSt3__26locale2id5__getEv(215228)|0);
 __ZNSt3__26locale5__imp7installEPNS0_5facetEl($0,$1,$2);
 return;
}
function __ZNSt3__212_GLOBAL__N_14makeINS_7num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEjEERT_T0_() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[(207348)>>2] = 0;
 HEAP32[51836] = (96844);
 return;
}
function __ZNSt3__26locale5__imp7installINS_7num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvPT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__ZNSt3__26locale2id5__getEv(215212)|0);
 __ZNSt3__26locale5__imp7installEPNS0_5facetEl($0,$1,$2);
 return;
}
function __ZNSt3__212_GLOBAL__N_14makeINS_7num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEjEERT_T0_() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[(207356)>>2] = 0;
 HEAP32[51838] = (96908);
 return;
}
function __ZNSt3__26locale5__imp7installINS_7num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvPT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__ZNSt3__26locale2id5__getEv(215236)|0);
 __ZNSt3__26locale5__imp7installEPNS0_5facetEl($0,$1,$2);
 return;
}
function __ZNSt3__212_GLOBAL__N_14makeINS_7num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEEjEERT_T0_() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[(207364)>>2] = 0;
 HEAP32[51840] = (96972);
 return;
}
function __ZNSt3__26locale5__imp7installINS_7num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvPT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__ZNSt3__26locale2id5__getEv(215244)|0);
 __ZNSt3__26locale5__imp7installEPNS0_5facetEl($0,$1,$2);
 return;
}
function __ZNSt3__212_GLOBAL__N_14makeINS_7num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEEjEERT_T0_() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[(207372)>>2] = 0;
 HEAP32[51842] = (97024);
 return;
}
function __ZNSt3__26locale5__imp7installINS_7num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvPT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__ZNSt3__26locale2id5__getEv(215252)|0);
 __ZNSt3__26locale5__imp7installEPNS0_5facetEl($0,$1,$2);
 return;
}
function __ZNSt3__212_GLOBAL__N_14makeINS_10moneypunctIcLb0EEEjEERT_T0_() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[(207380)>>2] = 0;
 HEAP32[51844] = (98572);
 return;
}
function __ZNSt3__26locale5__imp7installINS_10moneypunctIcLb0EEEEEvPT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__ZNSt3__26locale2id5__getEv(216900)|0);
 __ZNSt3__26locale5__imp7installEPNS0_5facetEl($0,$1,$2);
 return;
}
function __ZNSt3__212_GLOBAL__N_14makeINS_10moneypunctIcLb1EEEjEERT_T0_() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[(207388)>>2] = 0;
 HEAP32[51846] = (98628);
 return;
}
function __ZNSt3__26locale5__imp7installINS_10moneypunctIcLb1EEEEEvPT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__ZNSt3__26locale2id5__getEv(216908)|0);
 __ZNSt3__26locale5__imp7installEPNS0_5facetEl($0,$1,$2);
 return;
}
function __ZNSt3__212_GLOBAL__N_14makeINS_10moneypunctIwLb0EEEjEERT_T0_() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[(207396)>>2] = 0;
 HEAP32[51848] = (98684);
 return;
}
function __ZNSt3__26locale5__imp7installINS_10moneypunctIwLb0EEEEEvPT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__ZNSt3__26locale2id5__getEv(216916)|0);
 __ZNSt3__26locale5__imp7installEPNS0_5facetEl($0,$1,$2);
 return;
}
function __ZNSt3__212_GLOBAL__N_14makeINS_10moneypunctIwLb1EEEjEERT_T0_() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[(207404)>>2] = 0;
 HEAP32[51850] = (98740);
 return;
}
function __ZNSt3__26locale5__imp7installINS_10moneypunctIwLb1EEEEEvPT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__ZNSt3__26locale2id5__getEv(216924)|0);
 __ZNSt3__26locale5__imp7installEPNS0_5facetEl($0,$1,$2);
 return;
}
function __ZNSt3__212_GLOBAL__N_14makeINS_9money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEjEERT_T0_() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[(207412)>>2] = 0;
 HEAP32[51852] = (98796);
 return;
}
function __ZNSt3__26locale5__imp7installINS_9money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvPT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__ZNSt3__26locale2id5__getEv(216932)|0);
 __ZNSt3__26locale5__imp7installEPNS0_5facetEl($0,$1,$2);
 return;
}
function __ZNSt3__212_GLOBAL__N_14makeINS_9money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEjEERT_T0_() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[(207420)>>2] = 0;
 HEAP32[51854] = (98824);
 return;
}
function __ZNSt3__26locale5__imp7installINS_9money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvPT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__ZNSt3__26locale2id5__getEv(216940)|0);
 __ZNSt3__26locale5__imp7installEPNS0_5facetEl($0,$1,$2);
 return;
}
function __ZNSt3__212_GLOBAL__N_14makeINS_9money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEEjEERT_T0_() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[(207428)>>2] = 0;
 HEAP32[51856] = (98852);
 return;
}
function __ZNSt3__26locale5__imp7installINS_9money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvPT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__ZNSt3__26locale2id5__getEv(216948)|0);
 __ZNSt3__26locale5__imp7installEPNS0_5facetEl($0,$1,$2);
 return;
}
function __ZNSt3__212_GLOBAL__N_14makeINS_9money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEEjEERT_T0_() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[(207436)>>2] = 0;
 HEAP32[51858] = (98880);
 return;
}
function __ZNSt3__26locale5__imp7installINS_9money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvPT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__ZNSt3__26locale2id5__getEv(216956)|0);
 __ZNSt3__26locale5__imp7installEPNS0_5facetEl($0,$1,$2);
 return;
}
function __ZNSt3__212_GLOBAL__N_14makeINS_8time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEjEERT_T0_() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[(207444)>>2] = 0;
 HEAP32[51860] = (99312);
 __ZNSt3__220__time_get_c_storageIcEC2Ev((207448));
 HEAP32[51860] = (97076);
 HEAP32[(207448)>>2] = (97124);
 return;
}
function __ZNSt3__26locale5__imp7installINS_8time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvPT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__ZNSt3__26locale2id5__getEv(216064)|0);
 __ZNSt3__26locale5__imp7installEPNS0_5facetEl($0,$1,$2);
 return;
}
function __ZNSt3__212_GLOBAL__N_14makeINS_8time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEjEERT_T0_() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[(207460)>>2] = 0;
 HEAP32[51864] = (99312);
 __ZNSt3__220__time_get_c_storageIwEC2Ev((207464));
 HEAP32[51864] = (97160);
 HEAP32[(207464)>>2] = (97208);
 return;
}
function __ZNSt3__26locale5__imp7installINS_8time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvPT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__ZNSt3__26locale2id5__getEv(216876)|0);
 __ZNSt3__26locale5__imp7installEPNS0_5facetEl($0,$1,$2);
 return;
}
function __ZNSt3__212_GLOBAL__N_14makeINS_8time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEEjEERT_T0_() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[(207476)>>2] = 0;
 HEAP32[51868] = (99312);
 __THREW__ = 0;
 $0 = (invoke_i(4668)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZNSt3__26locale5facetD2Ev(207472);
  ___resumeException($3|0);
  // unreachable;
 } else {
  HEAP32[(207480)>>2] = $0;
  HEAP32[51868] = (98524);
  return;
 }
}
function __ZNSt3__26locale5__imp7installINS_8time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvPT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__ZNSt3__26locale2id5__getEv(216884)|0);
 __ZNSt3__26locale5__imp7installEPNS0_5facetEl($0,$1,$2);
 return;
}
function __ZNSt3__212_GLOBAL__N_14makeINS_8time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEEjEERT_T0_() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[(207492)>>2] = 0;
 HEAP32[51872] = (99312);
 __THREW__ = 0;
 $0 = (invoke_i(4668)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch_2()|0;
  $4 = tempRet0;
  __ZNSt3__26locale5facetD2Ev(207488);
  ___resumeException($3|0);
  // unreachable;
 } else {
  HEAP32[(207496)>>2] = $0;
  HEAP32[51872] = (98548);
  return;
 }
}
function __ZNSt3__26locale5__imp7installINS_8time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvPT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__ZNSt3__26locale2id5__getEv(216892)|0);
 __ZNSt3__26locale5__imp7installEPNS0_5facetEl($0,$1,$2);
 return;
}
function __ZNSt3__212_GLOBAL__N_14makeINS_8messagesIcEEjEERT_T0_() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[(207508)>>2] = 0;
 HEAP32[51876] = (98908);
 return;
}
function __ZNSt3__26locale5__imp7installINS_8messagesIcEEEEvPT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__ZNSt3__26locale2id5__getEv(216964)|0);
 __ZNSt3__26locale5__imp7installEPNS0_5facetEl($0,$1,$2);
 return;
}
function __ZNSt3__212_GLOBAL__N_14makeINS_8messagesIwEEjEERT_T0_() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[(207516)>>2] = 0;
 HEAP32[51878] = (98940);
 return;
}
function __ZNSt3__26locale5__imp7installINS_8messagesIwEEEEvPT_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__ZNSt3__26locale2id5__getEv(216972)|0);
 __ZNSt3__26locale5__imp7installEPNS0_5facetEl($0,$1,$2);
 return;
}
function __ZNSt3__26locale5__imp7installEPNS0_5facetEl($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$pre = 0, $$pre$phiZ2D = 0, $$pre14 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__214__shared_count12__add_sharedEv($1);
 $3 = ((($0)) + 8|0);
 $4 = ((($0)) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$3>>2]|0;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 2;
 $9 = ($8>>>0)>($2>>>0);
 do {
  if ($9) {
   $10 = $6;
   $$pre$phiZ2D = $3;$18 = $10;
  } else {
   $11 = (($2) + 1)|0;
   __THREW__ = 0;
   invoke_vii(4803,($3|0),($11|0));
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $$pre = HEAP32[$3>>2]|0;
    $$pre$phiZ2D = $3;$18 = $$pre;
    break;
   }
   $14 = ___cxa_find_matching_catch_2()|0;
   $15 = tempRet0;
   $16 = ($1|0)==(0|0);
   if (!($16)) {
    __ZNSt3__212_GLOBAL__N_17releaseclEPNS_6locale5facetE($1);
   }
   ___resumeException($14|0);
   // unreachable;
  }
 } while(0);
 $17 = (($18) + ($2<<2)|0);
 $19 = HEAP32[$17>>2]|0;
 $20 = ($19|0)==(0|0);
 if ($20) {
  $22 = $18;
 } else {
  (__ZNSt3__214__shared_count16__release_sharedEv($19)|0);
  $$pre14 = HEAP32[$$pre$phiZ2D>>2]|0;
  $22 = $$pre14;
 }
 $21 = (($22) + ($2<<2)|0);
 HEAP32[$21>>2] = $1;
 return;
}
function __ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lj28EEEE6resizeEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 $7 = ($6>>>0)<($1>>>0);
 $8 = $4;
 $9 = $3;
 L1: do {
  if ($7) {
   $10 = (($1) - ($6))|0;
   __ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lj28EEEE8__appendEj($0,$10);
  } else {
   $11 = ($6>>>0)>($1>>>0);
   if ($11) {
    $12 = (($8) + ($1<<2)|0);
    $13 = $9;
    while(1) {
     $14 = ($13|0)==($12|0);
     if ($14) {
      break L1;
     }
     $15 = ((($13)) + -4|0);
     HEAP32[$2>>2] = $15;
     $13 = $15;
    }
   }
  }
 } while(0);
 return;
}
function __ZNSt3__212_GLOBAL__N_17releaseclEPNS_6locale5facetE($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (__ZNSt3__214__shared_count16__release_sharedEv($0)|0);
 return;
}
function __ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lj28EEEE8__appendEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$sroa$speculated$$i = 0, $$sroa$speculated$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $2 = sp;
 $3 = ((($0)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) - ($6))|0;
 $8 = $7 >> 2;
 $9 = ($8>>>0)<($1>>>0);
 do {
  if ($9) {
   $10 = HEAP32[$0>>2]|0;
   $11 = (($6) - ($10))|0;
   $12 = $11 >> 2;
   $13 = (($12) + ($1))|0;
   $14 = (__ZNKSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lj28EEEE8max_sizeEv($0)|0);
   $15 = ($14>>>0)<($13>>>0);
   if ($15) {
    __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
    // unreachable;
   }
   $16 = ((($0)) + 16|0);
   $17 = HEAP32[$3>>2]|0;
   $18 = HEAP32[$0>>2]|0;
   $19 = (($17) - ($18))|0;
   $20 = $19 >> 2;
   $21 = $14 >>> 1;
   $22 = ($20>>>0)<($21>>>0);
   $23 = $19 >> 1;
   $24 = ($23>>>0)<($13>>>0);
   $$sroa$speculated$i = $24 ? $13 : $23;
   $$sroa$speculated$$i = $22 ? $$sroa$speculated$i : $14;
   $25 = HEAP32[$5>>2]|0;
   $26 = (($25) - ($18))|0;
   $27 = $26 >> 2;
   __ZNSt3__214__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lj28EEEEC2EjjS6_($2,$$sroa$speculated$$i,$27,$16);
   __THREW__ = 0;
   invoke_vii(4804,($2|0),($1|0));
   $28 = __THREW__; __THREW__ = 0;
   $29 = $28&1;
   if (!($29)) {
    __THREW__ = 0;
    invoke_vii(4805,($0|0),($2|0));
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if (!($31)) {
     __ZNSt3__214__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lj28EEEED2Ev($2);
     break;
    }
   }
   $32 = ___cxa_find_matching_catch_2()|0;
   $33 = tempRet0;
   __ZNSt3__214__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lj28EEEED2Ev($2);
   ___resumeException($32|0);
   // unreachable;
  } else {
   __ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lj28EEEE18__construct_at_endEj($0,$1);
  }
 } while(0);
 STACKTOP = sp;return;
}
function __ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lj28EEEE18__construct_at_endEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$pre = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $$pre = HEAP32[$2>>2]|0;
 $$0 = $1;$3 = $$pre;
 while(1) {
  HEAP32[$3>>2] = 0;
  $4 = HEAP32[$2>>2]|0;
  $5 = ((($4)) + 4|0);
  HEAP32[$2>>2] = $5;
  $6 = (($$0) + -1)|0;
  $7 = ($6|0)==(0);
  if ($7) {
   break;
  } else {
   $$0 = $6;$3 = $5;
  }
 }
 return;
}
function __ZNKSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lj28EEEE8max_sizeEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 1073741823;
}
function __ZNSt3__214__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lj28EEEEC2EjjS6_($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$not$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ((($0)) + 12|0);
 HEAP32[$4>>2] = 0;
 $5 = ((($0)) + 16|0);
 HEAP32[$5>>2] = $3;
 $6 = ($1|0)==(0);
 do {
  if ($6) {
   $12 = 0;
  } else {
   $7 = ((($3)) + 112|0);
   $8 = HEAP8[$7>>0]|0;
   $$not$i$i = ($8<<24>>24)==(0);
   $9 = ($1>>>0)<(29);
   $or$cond$i$i = $9 & $$not$i$i;
   if ($or$cond$i$i) {
    HEAP8[$7>>0] = 1;
    $12 = $3;
    break;
   } else {
    $10 = $1 << 2;
    $11 = (__Znwj($10)|0);
    $12 = $11;
    break;
   }
  }
 } while(0);
 HEAP32[$0>>2] = $12;
 $13 = (($12) + ($2<<2)|0);
 $14 = ((($0)) + 8|0);
 HEAP32[$14>>2] = $13;
 $15 = ((($0)) + 4|0);
 HEAP32[$15>>2] = $13;
 $16 = (($12) + ($1<<2)|0);
 $17 = ((($0)) + 12|0);
 HEAP32[$17>>2] = $16;
 return;
}
function __ZNSt3__214__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lj28EEEE18__construct_at_endEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$pre = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 8|0);
 $$pre = HEAP32[$2>>2]|0;
 $$0 = $1;$3 = $$pre;
 while(1) {
  HEAP32[$3>>2] = 0;
  $4 = HEAP32[$2>>2]|0;
  $5 = ((($4)) + 4|0);
  HEAP32[$2>>2] = $5;
  $6 = (($$0) + -1)|0;
  $7 = ($6|0)==(0);
  if ($7) {
   break;
  } else {
   $$0 = $6;$3 = $5;
  }
 }
 return;
}
function __ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lj28EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$pre = 0, $$pre$phiZ2D = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $3 = ((($0)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($1)) + 4|0);
 $6 = $2;
 $7 = (($4) - ($6))|0;
 $8 = $7 >> 2;
 $9 = HEAP32[$5>>2]|0;
 $10 = (0 - ($8))|0;
 $11 = (($9) + ($10<<2)|0);
 HEAP32[$5>>2] = $11;
 $12 = ($7|0)>(0);
 if ($12) {
  _memcpy(($11|0),($2|0),($7|0))|0;
  $$pre = HEAP32[$5>>2]|0;
  $$pre$phiZ2D = $5;$15 = $$pre;
 } else {
  $13 = $11;
  $$pre$phiZ2D = $5;$15 = $13;
 }
 $14 = HEAP32[$0>>2]|0;
 HEAP32[$0>>2] = $15;
 HEAP32[$$pre$phiZ2D>>2] = $14;
 $16 = ((($1)) + 8|0);
 $17 = HEAP32[$3>>2]|0;
 $18 = HEAP32[$16>>2]|0;
 HEAP32[$3>>2] = $18;
 HEAP32[$16>>2] = $17;
 $19 = ((($0)) + 8|0);
 $20 = ((($1)) + 12|0);
 $21 = HEAP32[$19>>2]|0;
 $22 = HEAP32[$20>>2]|0;
 HEAP32[$19>>2] = $22;
 HEAP32[$20>>2] = $21;
 $23 = HEAP32[$$pre$phiZ2D>>2]|0;
 HEAP32[$1>>2] = $23;
 return;
}
function __ZNSt3__214__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lj28EEEED2Ev($0) {
 $0 = $0|0;
 var $$pre$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 8|0);
 $$pre$i$i$i = HEAP32[$3>>2]|0;
 $4 = $$pre$i$i$i;
 while(1) {
  $5 = ($4|0)==($2|0);
  if ($5) {
   break;
  }
  $6 = ((($4)) + -4|0);
  HEAP32[$3>>2] = $6;
  $4 = $6;
 }
 $7 = HEAP32[$0>>2]|0;
 $8 = ($7|0)==(0|0);
 do {
  if (!($8)) {
   $9 = ((($0)) + 16|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($10|0)==($7|0);
   if ($11) {
    $12 = ((($10)) + 112|0);
    HEAP8[$12>>0] = 0;
    break;
   } else {
    __ZdlPv($7);
    break;
   }
  }
 } while(0);
 return;
}
function __ZNSt3__28numpunctIwEC2Ej($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $exitcond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (($1) + -1)|0;
 $3 = ((($0)) + 4|0);
 HEAP32[$3>>2] = $2;
 HEAP32[$0>>2] = (99228);
 $4 = ((($0)) + 8|0);
 HEAP32[$4>>2] = 46;
 $5 = ((($0)) + 12|0);
 HEAP32[$5>>2] = 44;
 $6 = ((($0)) + 16|0);
 ;HEAP32[$6>>2]=0|0;HEAP32[$6+4>>2]=0|0;HEAP32[$6+8>>2]=0|0;
 $$0$i$i = 0;
 while(1) {
  $exitcond$i$i = ($$0$i$i|0)==(3);
  if ($exitcond$i$i) {
   break;
  }
  $7 = (($6) + ($$0$i$i<<2)|0);
  HEAP32[$7>>2] = 0;
  $8 = (($$0$i$i) + 1)|0;
  $$0$i$i = $8;
 }
 return;
}
function __ZNSt3__28numpunctIcEC2Ej($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $exitcond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (($1) + -1)|0;
 $3 = ((($0)) + 4|0);
 HEAP32[$3>>2] = $2;
 HEAP32[$0>>2] = (99188);
 $4 = ((($0)) + 8|0);
 HEAP8[$4>>0] = 46;
 $5 = ((($0)) + 9|0);
 HEAP8[$5>>0] = 44;
 $6 = ((($0)) + 12|0);
 ;HEAP32[$6>>2]=0|0;HEAP32[$6+4>>2]=0|0;HEAP32[$6+8>>2]=0|0;
 $$0$i$i = 0;
 while(1) {
  $exitcond$i$i = ($$0$i$i|0)==(3);
  if ($exitcond$i$i) {
   break;
  }
  $7 = (($6) + ($$0$i$i<<2)|0);
  HEAP32[$7>>2] = 0;
  $8 = (($$0$i$i) + 1)|0;
  $$0$i$i = $8;
 }
 return;
}
function __ZNSt3__27codecvtIwc11__mbstate_tEC2Ej($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (($1) + -1)|0;
 $3 = ((($0)) + 4|0);
 HEAP32[$3>>2] = $2;
 HEAP32[$0>>2] = (99068);
 __THREW__ = 0;
 $4 = (invoke_i(4668)|0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $8 = ___cxa_find_matching_catch_2()|0;
  $9 = tempRet0;
  __ZNSt3__26locale5facetD2Ev($0);
  ___resumeException($8|0);
  // unreachable;
 } else {
  $7 = ((($0)) + 8|0);
  HEAP32[$7>>2] = $4;
  return;
 }
}
function __ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lj28EEEE8allocateEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i = 0, $$not$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__ZNKSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lj28EEEE8max_sizeEv($0)|0);
 $3 = ($2>>>0)<($1>>>0);
 if ($3) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $4 = ((($0)) + 128|0);
 $5 = HEAP8[$4>>0]|0;
 $$not$i$i = ($5<<24>>24)==(0);
 $6 = ($1>>>0)<(29);
 $or$cond$i$i = $6 & $$not$i$i;
 if ($or$cond$i$i) {
  $7 = ((($0)) + 16|0);
  HEAP8[$4>>0] = 1;
  $$0$i$i = $7;
 } else {
  $8 = $1 << 2;
  $9 = (__Znwj($8)|0);
  $$0$i$i = $9;
 }
 $10 = ((($0)) + 4|0);
 HEAP32[$10>>2] = $$0$i$i;
 HEAP32[$0>>2] = $$0$i$i;
 $11 = (($$0$i$i) + ($1<<2)|0);
 $12 = ((($0)) + 8|0);
 HEAP32[$12>>2] = $11;
 return;
}
function __ZNSt3__26locale7classicEv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[207520]|0;
 $1 = ($0<<24>>24)==(0);
 do {
  if ($1) {
   $2 = (___cxa_guard_acquire(207520)|0);
   $3 = ($2|0)==(0);
   if (!($3)) {
    __THREW__ = 0;
    (invoke_i(4806)|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     $7 = ___cxa_find_matching_catch_2()|0;
     $8 = tempRet0;
     ___resumeException($7|0);
     // unreachable;
    } else {
     HEAP32[54254] = 217012;
     break;
    }
   }
  }
 } while(0);
 $6 = HEAP32[54254]|0;
 return ($6|0);
}
function __ZNSt3__26locale5__imp12make_classicEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__212_GLOBAL__N_14makeINS_6locale5__impEjEERT_T0_();
 HEAP32[54253] = 207528;
 return (217012|0);
}
function __ZNSt3__212_GLOBAL__N_14makeINS_6locale5__impEjEERT_T0_() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__26locale5__impC2Ej(207528,1);
 return;
}
function __ZNSt3__26locale5__imp11make_globalEv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNSt3__26locale7classicEv()|0);
 __ZNSt3__26localeC2ERKS0_(217020,$0);
 return (217020|0);
}
function __ZNSt3__26localeC2ERKS0_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $2;
 __ZNSt3__214__shared_count12__add_sharedEv($2);
 return;
}
function __ZNSt3__26locale8__globalEv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[207688]|0;
 $1 = ($0<<24>>24)==(0);
 do {
  if ($1) {
   $2 = (___cxa_guard_acquire(207688)|0);
   $3 = ($2|0)==(0);
   if (!($3)) {
    __THREW__ = 0;
    (invoke_i(4807)|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     $7 = ___cxa_find_matching_catch_2()|0;
     $8 = tempRet0;
     ___resumeException($7|0);
     // unreachable;
    } else {
     HEAP32[54256] = 217020;
     break;
    }
   }
  }
 } while(0);
 $6 = HEAP32[54256]|0;
 return ($6|0);
}
function __ZNSt3__26localeC2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 $1 = (invoke_i(4808)|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $5 = ___cxa_find_matching_catch_3(0|0)|0;
  $6 = tempRet0;
  ___clang_call_terminate($5);
  // unreachable;
 } else {
  $4 = HEAP32[$1>>2]|0;
  HEAP32[$0>>2] = $4;
  __ZNSt3__214__shared_count12__add_sharedEv($4);
  return;
 }
}
function __ZNSt3__211char_traitsIcE7compareEPKcS3_j($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($2|0)==(0);
 if ($3) {
  $$0 = 0;
 } else {
  $4 = (_memcmp($0,$1,$2)|0);
  $$0 = $4;
 }
 return ($$0|0);
}
function __ZNSt3__214__shared_countD2Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZNSt3__214__shared_count12__add_sharedEv($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 4|0);
 __ZNSt3__212_GLOBAL__N_19incrementIlEET_RS2_($1);
 return;
}
function __ZNSt3__212_GLOBAL__N_19incrementIlEET_RS2_($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;HEAP32[$0>>2] = (($1+1)|0);
 return;
}
function __ZNSt3__214__shared_count16__release_sharedEv($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 4|0);
 $2 = (__ZNSt3__212_GLOBAL__N_19decrementIlEET_RS2_($1)|0);
 $3 = ($2|0)==(-1);
 if ($3) {
  $4 = HEAP32[$0>>2]|0;
  $5 = ((($4)) + 8|0);
  $6 = HEAP32[$5>>2]|0;
  FUNCTION_TABLE_vi[$6 & 8191]($0);
  $$0 = 1;
 } else {
  $$0 = 0;
 }
 return ($$0|0);
}
function __ZNSt3__212_GLOBAL__N_19decrementIlEET_RS2_($0) {
 $0 = $0|0;
 var $$0$i = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;HEAP32[$0>>2] = (($1+-1)|0);
 $$0$i = (($1) + -1)|0;
 return ($$0$i|0);
}
function __ZNSt3__211__call_onceERVmPvPFvS2_E($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (_pthread_mutex_lock((217028|0))|0);
 while(1) {
  $3 = HEAP32[$0>>2]|0;
  $4 = ($3|0)==(1);
  if (!($4)) {
   break;
  }
  (_pthread_cond_wait((217056|0),(217028|0))|0);
 }
 $5 = HEAP32[$0>>2]|0;
 $6 = ($5|0)==(0);
 do {
  if ($6) {
   HEAP32[$0>>2] = 1;
   __THREW__ = 0;
   (invoke_ii(4809,(217028|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    __THREW__ = 0;
    invoke_vi($2|0,($1|0));
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     __THREW__ = 0;
     (invoke_ii(4810,(217028|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      HEAP32[$0>>2] = -1;
      __THREW__ = 0;
      (invoke_ii(4809,(217028|0))|0);
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       __THREW__ = 0;
       (invoke_ii(4811,(217056|0))|0);
       $15 = __THREW__; __THREW__ = 0;
       $16 = $15&1;
       if (!($16)) {
        break;
       }
      }
     }
    }
   }
   $17 = ___cxa_find_matching_catch_3(0|0)|0;
   $18 = tempRet0;
   (___cxa_begin_catch(($17|0))|0);
   __THREW__ = 0;
   (invoke_ii(4810,(217028|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    HEAP32[$0>>2] = 0;
    __THREW__ = 0;
    (invoke_ii(4809,(217028|0))|0);
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if (!($22)) {
     __THREW__ = 0;
     (invoke_ii(4811,(217056|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if (!($24)) {
      __THREW__ = 0;
      invoke_v(3314);
      $25 = __THREW__; __THREW__ = 0;
     }
    }
   }
   $26 = ___cxa_find_matching_catch_2()|0;
   $27 = tempRet0;
   __THREW__ = 0;
   invoke_v(3261);
   $28 = __THREW__; __THREW__ = 0;
   $29 = $28&1;
   if ($29) {
    $30 = ___cxa_find_matching_catch_3(0|0)|0;
    $31 = tempRet0;
    ___clang_call_terminate($30);
    // unreachable;
   } else {
    ___resumeException($26|0);
    // unreachable;
   }
  } else {
   (_pthread_mutex_unlock((217028|0))|0);
  }
 } while(0);
 return;
}
function __Znwj($0) {
 $0 = $0|0;
 var $$ = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ($0|0)==(0);
 $$ = $1 ? 1 : $0;
 while(1) {
  $2 = (_malloc($$)|0);
  $3 = ($2|0)==(0|0);
  if (!($3)) {
   label = 6;
   break;
  }
  $4 = (__ZSt15get_new_handlerv()|0);
  $5 = ($4|0)==(0|0);
  if ($5) {
   label = 5;
   break;
  }
  FUNCTION_TABLE_v[$4 & 8191]();
 }
 if ((label|0) == 5) {
  $6 = (___cxa_allocate_exception(4)|0);
  __ZNSt9bad_allocC2Ev($6);
  ___cxa_throw(($6|0),(34544|0),(3225|0));
  // unreachable;
 }
 else if ((label|0) == 6) {
  return ($2|0);
 }
 return (0)|0;
}
function __Znaj($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj($0)|0);
 return ($1|0);
}
function __ZdlPv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 _free($0);
 return;
}
function __ZdaPv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($0);
 return;
}
function __ZSt17__throw_bad_allocv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (___cxa_allocate_exception(4)|0);
 __ZNSt9bad_allocC2Ev($0);
 ___cxa_throw(($0|0),(34544|0),(3225|0));
 // unreachable;
}
function __ZNSt11logic_errorC2ERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (99764);
 $2 = ((($0)) + 4|0);
 $3 = ((($1)) + 11|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)<(0);
 $6 = HEAP32[$1>>2]|0;
 $7 = $5 ? $6 : $1;
 __THREW__ = 0;
 invoke_vii(4812,($2|0),($7|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $10 = ___cxa_find_matching_catch_2()|0;
  $11 = tempRet0;
  ___resumeException($10|0);
  // unreachable;
 } else {
  return;
 }
}
function __ZNSt3__218__libcpp_refstringC2EPKc($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_strlen($1)|0);
 $3 = (($2) + 13)|0;
 $4 = (__Znwj($3)|0);
 HEAP32[$4>>2] = $2;
 $5 = ((($4)) + 4|0);
 HEAP32[$5>>2] = $2;
 $6 = ((($4)) + 8|0);
 HEAP32[$6>>2] = 0;
 $7 = (__ZNSt3__215__refstring_imp12_GLOBAL__N_113data_from_repEPNS1_9_Rep_baseE($4)|0);
 $8 = (($2) + 1)|0;
 _memcpy(($7|0),($1|0),($8|0))|0;
 HEAP32[$0>>2] = $7;
 return;
}
function __ZNSt3__215__refstring_imp12_GLOBAL__N_113data_from_repEPNS1_9_Rep_baseE($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 12|0);
 return ($1|0);
}
function __ZNSt11logic_errorC2EPKc($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (99764);
 $2 = ((($0)) + 4|0);
 __THREW__ = 0;
 invoke_vii(4812,($2|0),($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch_2()|0;
  $6 = tempRet0;
  ___resumeException($5|0);
  // unreachable;
 } else {
  return;
 }
}
function __ZNKSt3__218__libcpp_refstring15__uses_refcountEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 1;
}
function __ZNSt13runtime_errorC2ERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (99784);
 $2 = ((($0)) + 4|0);
 $3 = ((($1)) + 11|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)<(0);
 $6 = HEAP32[$1>>2]|0;
 $7 = $5 ? $6 : $1;
 __THREW__ = 0;
 invoke_vii(4812,($2|0),($7|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $10 = ___cxa_find_matching_catch_2()|0;
  $11 = tempRet0;
  ___resumeException($10|0);
  // unreachable;
 } else {
  return;
 }
}
function __ZNSt13runtime_errorC2EPKc($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (99784);
 $2 = ((($0)) + 4|0);
 __THREW__ = 0;
 invoke_vii(4812,($2|0),($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch_2()|0;
  $6 = tempRet0;
  ___resumeException($5|0);
  // unreachable;
 } else {
  return;
 }
}
function __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (___cxa_allocate_exception(8)|0);
 __THREW__ = 0;
 invoke_vii(3366,($1|0),(204827|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch_2()|0;
  $5 = tempRet0;
  ___cxa_free_exception(($1|0));
  ___resumeException($4|0);
  // unreachable;
 } else {
  HEAP32[$1>>2] = (99824);
  ___cxa_throw(($1|0),(34608|0),(3230|0));
  // unreachable;
 }
}
function __ZNKSt3__221__basic_string_commonILb1EE20__throw_out_of_rangeEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (___cxa_allocate_exception(8)|0);
 __THREW__ = 0;
 invoke_vii(3366,($1|0),(204827|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch_2()|0;
  $5 = tempRet0;
  ___cxa_free_exception(($1|0));
  ___resumeException($4|0);
  // unreachable;
 } else {
  HEAP32[$1>>2] = (99844);
  ___cxa_throw(($1|0),(34624|0),(3230|0));
  // unreachable;
 }
}
function __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 ;HEAP32[$0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;
 $3 = ((($1)) + 11|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)<(0);
 if ($5) {
  $6 = HEAP32[$1>>2]|0;
  $7 = ((($1)) + 4|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8>>>0)>(4294967279);
  if ($9) {
   __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv($0);
   // unreachable;
  }
  $10 = ($8>>>0)<(11);
  if ($10) {
   $11 = $8&255;
   $12 = ((($0)) + 11|0);
   HEAP8[$12>>0] = $11;
   $$0$i = $0;
  } else {
   $13 = (($8) + 16)|0;
   $14 = $13 & -16;
   $15 = (__Znwj($14)|0);
   HEAP32[$0>>2] = $15;
   $16 = $14 | -2147483648;
   $17 = ((($0)) + 8|0);
   HEAP32[$17>>2] = $16;
   $18 = ((($0)) + 4|0);
   HEAP32[$18>>2] = $8;
   $$0$i = $15;
  }
  (__ZNSt3__211char_traitsIcE4copyEPcPKcj($$0$i,$6,$8)|0);
  $19 = (($$0$i) + ($8)|0);
  HEAP8[$2>>0] = 0;
  __ZNSt3__211char_traitsIcE6assignERcRKc($19,$2);
 } else {
  ;HEAP32[$0>>2]=HEAP32[$1>>2]|0;HEAP32[$0+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$1+8>>2]|0;
 }
 STACKTOP = sp;return;
}
function __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_jjRKS4_($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0$i = 0, $$sroa$speculated = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $5 = sp;
 ;HEAP32[$0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;
 $6 = ((($1)) + 11|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = ($7<<24>>24)<(0);
 $9 = ((($1)) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $7&255;
 $12 = $8 ? $10 : $11;
 $13 = ($12>>>0)<($2>>>0);
 if ($13) {
  __ZNKSt3__221__basic_string_commonILb1EE20__throw_out_of_rangeEv($0);
  // unreachable;
 }
 $14 = HEAP32[$1>>2]|0;
 $15 = $8 ? $14 : $1;
 $16 = (($15) + ($2)|0);
 $17 = (($12) - ($2))|0;
 $18 = ($17>>>0)<($3>>>0);
 $$sroa$speculated = $18 ? $17 : $3;
 $19 = ($$sroa$speculated>>>0)>(4294967279);
 if ($19) {
  __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $20 = ($$sroa$speculated>>>0)<(11);
 if ($20) {
  $21 = $$sroa$speculated&255;
  $22 = ((($0)) + 11|0);
  HEAP8[$22>>0] = $21;
  $$0$i = $0;
 } else {
  $23 = (($$sroa$speculated) + 16)|0;
  $24 = $23 & -16;
  $25 = (__Znwj($24)|0);
  HEAP32[$0>>2] = $25;
  $26 = $24 | -2147483648;
  $27 = ((($0)) + 8|0);
  HEAP32[$27>>2] = $26;
  $28 = ((($0)) + 4|0);
  HEAP32[$28>>2] = $$sroa$speculated;
  $$0$i = $25;
 }
 (__ZNSt3__211char_traitsIcE4copyEPcPKcj($$0$i,$16,$$sroa$speculated)|0);
 $29 = (($$0$i) + ($$sroa$speculated)|0);
 HEAP8[$5>>0] = 0;
 __ZNSt3__211char_traitsIcE6assignERcRKc($29,$5);
 STACKTOP = sp;return;
}
function __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 11|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)<(0);
 if ($3) {
  $4 = HEAP32[$0>>2]|0;
  __ZdlPv($4);
 }
 return;
}
function __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEaSERKS5_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($0|0)==($1|0);
 if (!($2)) {
  $3 = ((($1)) + 11|0);
  $4 = HEAP8[$3>>0]|0;
  $5 = ($4<<24>>24)<(0);
  $6 = HEAP32[$1>>2]|0;
  $7 = $5 ? $6 : $1;
  $8 = ((($1)) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = $4&255;
  $11 = $5 ? $9 : $10;
  (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKcj($0,$7,$11)|0);
 }
 return ($0|0);
}
function __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKcj($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = ((($0)) + 11|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)<(0);
 if ($6) {
  $7 = ((($0)) + 8|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = $8 & 2147483647;
  $phitmp$i = (($9) + -1)|0;
  $10 = $phitmp$i;
 } else {
  $10 = 10;
 }
 $11 = ($10>>>0)<($2>>>0);
 do {
  if ($11) {
   if ($6) {
    $19 = ((($0)) + 4|0);
    $20 = HEAP32[$19>>2]|0;
    $23 = $20;
   } else {
    $21 = $5&255;
    $23 = $21;
   }
   $22 = (($2) - ($10))|0;
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE21__grow_by_and_replaceEjjjjjjPKc($0,$10,$22,$23,0,$23,$2,$1);
  } else {
   if ($6) {
    $12 = HEAP32[$0>>2]|0;
    $13 = $12;
   } else {
    $13 = $0;
   }
   (__ZNSt3__211char_traitsIcE4moveEPcPKcj($13,$1,$2)|0);
   $14 = (($13) + ($2)|0);
   HEAP8[$3>>0] = 0;
   __ZNSt3__211char_traitsIcE6assignERcRKc($14,$3);
   $15 = HEAP8[$4>>0]|0;
   $16 = ($15<<24>>24)<(0);
   if ($16) {
    $17 = ((($0)) + 4|0);
    HEAP32[$17>>2] = $2;
    break;
   } else {
    $18 = $2&255;
    HEAP8[$4>>0] = $18;
    break;
   }
  }
 } while(0);
 STACKTOP = sp;return ($0|0);
}
function __ZNSt3__211char_traitsIcE4moveEPcPKcj($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($2|0)==(0);
 if (!($3)) {
  _memmove(($0|0),($1|0),($2|0))|0;
 }
 return ($0|0);
}
function __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE21__grow_by_and_replaceEjjjjjjPKc($0,$1,$2,$3,$4,$5,$6,$7) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 var $$sroa$speculated = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $8 = 0, $9 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $8 = sp;
 $9 = (-18 - ($1))|0;
 $10 = ($9>>>0)<($2>>>0);
 if ($10) {
  __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $11 = ((($0)) + 11|0);
 $12 = HEAP8[$11>>0]|0;
 $13 = ($12<<24>>24)<(0);
 if ($13) {
  $14 = HEAP32[$0>>2]|0;
  $25 = $14;
 } else {
  $25 = $0;
 }
 $15 = ($1>>>0)<(2147483623);
 if ($15) {
  $16 = (($2) + ($1))|0;
  $17 = $1 << 1;
  $18 = ($16>>>0)<($17>>>0);
  $$sroa$speculated = $18 ? $17 : $16;
  $19 = ($$sroa$speculated>>>0)<(11);
  $20 = (($$sroa$speculated) + 16)|0;
  $21 = $20 & -16;
  $phitmp = $19 ? 11 : $21;
  $22 = $phitmp;
 } else {
  $22 = -17;
 }
 $23 = (__Znwj($22)|0);
 $24 = ($4|0)==(0);
 if (!($24)) {
  (__ZNSt3__211char_traitsIcE4copyEPcPKcj($23,$25,$4)|0);
 }
 $26 = ($6|0)==(0);
 if (!($26)) {
  $27 = (($23) + ($4)|0);
  (__ZNSt3__211char_traitsIcE4copyEPcPKcj($27,$7,$6)|0);
 }
 $28 = (($3) - ($5))|0;
 $29 = (($28) - ($4))|0;
 $30 = ($29|0)==(0);
 if (!($30)) {
  $31 = (($23) + ($4)|0);
  $32 = (($31) + ($6)|0);
  $33 = (($25) + ($4)|0);
  $34 = (($33) + ($5)|0);
  (__ZNSt3__211char_traitsIcE4copyEPcPKcj($32,$34,$29)|0);
 }
 $35 = ($1|0)==(10);
 if (!($35)) {
  __ZdlPv($25);
 }
 HEAP32[$0>>2] = $23;
 $36 = $22 | -2147483648;
 $37 = ((($0)) + 8|0);
 HEAP32[$37>>2] = $36;
 $38 = (($28) + ($6))|0;
 $39 = ((($0)) + 4|0);
 HEAP32[$39>>2] = $38;
 $40 = (($23) + ($38)|0);
 HEAP8[$8>>0] = 0;
 __ZNSt3__211char_traitsIcE6assignERcRKc($40,$8);
 STACKTOP = sp;return;
}
function __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7reserveEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$016 = 0, $$01739 = 0, $$018$off037 = 0, $$1404753 = 0, $$141 = 0, $$phitmp$i = 0, $$sroa$speculated = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp$i = 0, $phitmp$i21 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1>>>0)>(4294967279);
 if ($2) {
  __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $3 = ((($0)) + 11|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)<(0);
 if ($5) {
  $6 = ((($0)) + 8|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = $7 & 2147483647;
  $phitmp$i = (($8) + -1)|0;
  $9 = ((($0)) + 4|0);
  $10 = HEAP32[$9>>2]|0;
  $12 = $10;$18 = $phitmp$i;
 } else {
  $11 = $4&255;
  $12 = $11;$18 = 10;
 }
 $13 = ($12>>>0)>($1>>>0);
 $$sroa$speculated = $13 ? $12 : $1;
 $14 = ($$sroa$speculated>>>0)<(11);
 $15 = (($$sroa$speculated) + 16)|0;
 $16 = $15 & -16;
 $phitmp$i21 = (($16) + -1)|0;
 $$phitmp$i = $14 ? 10 : $phitmp$i21;
 $17 = ($$phitmp$i|0)==($18|0);
 L8: do {
  if (!($17)) {
   do {
    if ($14) {
     $28 = HEAP32[$0>>2]|0;
     if ($5) {
      $$01739 = $28;$$018$off037 = 0;$$141 = $0;
      label = 17;
     } else {
      $29 = $4&255;
      $30 = (($29) + 1)|0;
      (__ZNSt3__211char_traitsIcE4copyEPcPKcj($0,$28,$30)|0);
      __ZdlPv($28);
      label = 19;
     }
    } else {
     $19 = ($$phitmp$i>>>0)>($18>>>0);
     $20 = (($$phitmp$i) + 1)|0;
     if ($19) {
      $21 = (__Znwj($20)|0);
      $$016 = $21;
     } else {
      __THREW__ = 0;
      $22 = (invoke_ii(3276,($20|0))|0);
      $23 = __THREW__; __THREW__ = 0;
      $24 = $23&1;
      if ($24) {
       $25 = ___cxa_find_matching_catch_3(0|0)|0;
       $26 = tempRet0;
       (___cxa_begin_catch(($25|0))|0);
       ___cxa_end_catch();
       break L8;
      } else {
       $$016 = $22;
      }
     }
     if ($5) {
      $27 = HEAP32[$0>>2]|0;
      $$01739 = $27;$$018$off037 = 1;$$141 = $$016;
      label = 17;
      break;
     } else {
      $31 = $4&255;
      $32 = (($31) + 1)|0;
      (__ZNSt3__211char_traitsIcE4copyEPcPKcj($$016,$0,$32)|0);
      $$1404753 = $$016;
      label = 18;
      break;
     }
    }
   } while(0);
   if ((label|0) == 17) {
    $33 = ((($0)) + 4|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = (($34) + 1)|0;
    (__ZNSt3__211char_traitsIcE4copyEPcPKcj($$141,$$01739,$35)|0);
    __ZdlPv($$01739);
    if ($$018$off037) {
     $$1404753 = $$141;
     label = 18;
    } else {
     label = 19;
    }
   }
   if ((label|0) == 18) {
    $36 = (($$phitmp$i) + 1)|0;
    $37 = $36 | -2147483648;
    $38 = ((($0)) + 8|0);
    HEAP32[$38>>2] = $37;
    $39 = ((($0)) + 4|0);
    HEAP32[$39>>2] = $12;
    HEAP32[$0>>2] = $$1404753;
    break;
   }
   else if ((label|0) == 19) {
    $40 = $12&255;
    HEAP8[$3>>0] = $40;
    break;
   }
  }
 } while(0);
 return;
}
function __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__ZNSt3__211char_traitsIcE6lengthEPKc($1)|0);
 $3 = (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKcj($0,$1,$2)|0);
 return ($3|0);
}
function __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEjc($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp + 1|0;
 $4 = sp;
 $5 = ((($0)) + 11|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = ($6<<24>>24)<(0);
 if ($7) {
  $8 = ((($0)) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $11 = $9;
 } else {
  $10 = $6&255;
  $11 = $10;
 }
 $12 = ($11>>>0)<($1>>>0);
 do {
  if ($12) {
   $13 = (($1) - ($11))|0;
   (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEjc($0,$13,$2)|0);
  } else {
   if ($7) {
    $14 = HEAP32[$0>>2]|0;
    $15 = (($14) + ($1)|0);
    HEAP8[$3>>0] = 0;
    __ZNSt3__211char_traitsIcE6assignERcRKc($15,$3);
    $16 = ((($0)) + 4|0);
    HEAP32[$16>>2] = $1;
    break;
   } else {
    $17 = (($0) + ($1)|0);
    HEAP8[$4>>0] = 0;
    __ZNSt3__211char_traitsIcE6assignERcRKc($17,$4);
    $18 = $1&255;
    HEAP8[$5>>0] = $18;
    break;
   }
  }
 } while(0);
 STACKTOP = sp;return;
}
function __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEjc($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$pre = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = ($1|0)==(0);
 if (!($4)) {
  $5 = ((($0)) + 11|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)<(0);
  if ($7) {
   $8 = ((($0)) + 8|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = $9 & 2147483647;
   $phitmp$i = (($10) + -1)|0;
   $11 = ((($0)) + 4|0);
   $12 = HEAP32[$11>>2]|0;
   $15 = $12;$16 = $phitmp$i;
  } else {
   $13 = $6&255;
   $15 = $13;$16 = 10;
  }
  $14 = (($16) - ($15))|0;
  $17 = ($14>>>0)<($1>>>0);
  $18 = (($15) + ($1))|0;
  if ($17) {
   $19 = (($18) - ($16))|0;
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE9__grow_byEjjjjjj($0,$16,$19,$15,$15,0,0);
   $$pre = HEAP8[$5>>0]|0;
   $20 = $$pre;
  } else {
   $20 = $6;
  }
  $21 = ($20<<24>>24)<(0);
  if ($21) {
   $22 = HEAP32[$0>>2]|0;
   $24 = $22;
  } else {
   $24 = $0;
  }
  $23 = (($24) + ($15)|0);
  (__ZNSt3__211char_traitsIcE6assignEPcjc($23,$1,$2)|0);
  $25 = HEAP8[$5>>0]|0;
  $26 = ($25<<24>>24)<(0);
  if ($26) {
   $27 = ((($0)) + 4|0);
   HEAP32[$27>>2] = $18;
  } else {
   $28 = $18&255;
   HEAP8[$5>>0] = $28;
  }
  $29 = (($24) + ($18)|0);
  HEAP8[$3>>0] = 0;
  __ZNSt3__211char_traitsIcE6assignERcRKc($29,$3);
 }
 STACKTOP = sp;return ($0|0);
}
function __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE9__grow_byEjjjjjj($0,$1,$2,$3,$4,$5,$6) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 var $$sroa$speculated = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $7 = (-17 - ($1))|0;
 $8 = ($7>>>0)<($2>>>0);
 if ($8) {
  __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $9 = ((($0)) + 11|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = ($10<<24>>24)<(0);
 if ($11) {
  $12 = HEAP32[$0>>2]|0;
  $23 = $12;
 } else {
  $23 = $0;
 }
 $13 = ($1>>>0)<(2147483623);
 if ($13) {
  $14 = (($2) + ($1))|0;
  $15 = $1 << 1;
  $16 = ($14>>>0)<($15>>>0);
  $$sroa$speculated = $16 ? $15 : $14;
  $17 = ($$sroa$speculated>>>0)<(11);
  $18 = (($$sroa$speculated) + 16)|0;
  $19 = $18 & -16;
  $phitmp = $17 ? 11 : $19;
  $20 = $phitmp;
 } else {
  $20 = -17;
 }
 $21 = (__Znwj($20)|0);
 $22 = ($4|0)==(0);
 if (!($22)) {
  (__ZNSt3__211char_traitsIcE4copyEPcPKcj($21,$23,$4)|0);
 }
 $24 = (($3) - ($5))|0;
 $25 = (($24) - ($4))|0;
 $26 = ($25|0)==(0);
 if (!($26)) {
  $27 = (($21) + ($4)|0);
  $28 = (($27) + ($6)|0);
  $29 = (($23) + ($4)|0);
  $30 = (($29) + ($5)|0);
  (__ZNSt3__211char_traitsIcE4copyEPcPKcj($28,$30,$25)|0);
 }
 $31 = ($1|0)==(10);
 if (!($31)) {
  __ZdlPv($23);
 }
 HEAP32[$0>>2] = $21;
 $32 = $20 | -2147483648;
 $33 = ((($0)) + 8|0);
 HEAP32[$33>>2] = $32;
 return;
}
function __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKcj($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = ((($0)) + 11|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)<(0);
 if ($6) {
  $7 = ((($0)) + 8|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = $8 & 2147483647;
  $phitmp$i = (($9) + -1)|0;
  $10 = ((($0)) + 4|0);
  $11 = HEAP32[$10>>2]|0;
  $14 = $11;$15 = $phitmp$i;
 } else {
  $12 = $5&255;
  $14 = $12;$15 = 10;
 }
 $13 = (($15) - ($14))|0;
 $16 = ($13>>>0)<($2>>>0);
 $17 = (($14) + ($2))|0;
 if ($16) {
  $27 = (($17) - ($15))|0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE21__grow_by_and_replaceEjjjjjjPKc($0,$15,$27,$14,$14,0,$2,$1);
 } else {
  $18 = ($2|0)==(0);
  if (!($18)) {
   if ($6) {
    $19 = HEAP32[$0>>2]|0;
    $21 = $19;
   } else {
    $21 = $0;
   }
   $20 = (($21) + ($14)|0);
   (__ZNSt3__211char_traitsIcE4copyEPcPKcj($20,$1,$2)|0);
   $22 = HEAP8[$4>>0]|0;
   $23 = ($22<<24>>24)<(0);
   if ($23) {
    $24 = ((($0)) + 4|0);
    HEAP32[$24>>2] = $17;
   } else {
    $25 = $17&255;
    HEAP8[$4>>0] = $25;
   }
   $26 = (($21) + ($17)|0);
   HEAP8[$3>>0] = 0;
   __ZNSt3__211char_traitsIcE6assignERcRKc($26,$3);
  }
 }
 STACKTOP = sp;return ($0|0);
}
function __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKc($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__ZNSt3__211char_traitsIcE6lengthEPKc($1)|0);
 $3 = (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKcj($0,$1,$2)|0);
 return ($3|0);
}
function __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE9push_backEc($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$018 = 0, $$019 = 0, $$pn = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp + 1|0;
 $3 = sp;
 HEAP8[$2>>0] = $1;
 $4 = ((($0)) + 11|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)<(0);
 if ($6) {
  $8 = ((($0)) + 8|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = $9 & 2147483647;
  $11 = (($10) + -1)|0;
  $12 = ((($0)) + 4|0);
  $13 = HEAP32[$12>>2]|0;
  $$018 = $13;$$019 = $11;
 } else {
  $7 = $5&255;
  $$018 = $7;$$019 = 10;
 }
 $14 = ($$018|0)==($$019|0);
 if ($14) {
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE9__grow_byEjjjjjj($0,$$019,1,$$019,$$019,0,0);
  $15 = HEAP8[$4>>0]|0;
  $16 = ($15<<24>>24)<(0);
  $17 = (($$019) + 1)|0;
  if ($16) {
   $23 = $17;
   label = 8;
  } else {
   $20 = $17;
   label = 7;
  }
 } else {
  $18 = (($$018) + 1)|0;
  if ($6) {
   $23 = $18;
   label = 8;
  } else {
   $20 = $18;
   label = 7;
  }
 }
 if ((label|0) == 7) {
  $19 = $20&255;
  HEAP8[$4>>0] = $19;
  $$pn = $0;
 }
 else if ((label|0) == 8) {
  $21 = HEAP32[$0>>2]|0;
  $22 = ((($0)) + 4|0);
  HEAP32[$22>>2] = $23;
  $$pn = $21;
 }
 $$0 = (($$pn) + ($$018)|0);
 __ZNSt3__211char_traitsIcE6assignERcRKc($$0,$2);
 $24 = ((($$0)) + 1|0);
 HEAP8[$3>>0] = 0;
 __ZNSt3__211char_traitsIcE6assignERcRKc($24,$3);
 STACKTOP = sp;return;
}
function __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6insertEjPKcj($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $$1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $4 = sp;
 $5 = ((($0)) + 11|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = ($6<<24>>24)<(0);
 if ($7) {
  $8 = ((($0)) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $11 = $9;
 } else {
  $10 = $6&255;
  $11 = $10;
 }
 $12 = ($11>>>0)<($1>>>0);
 if ($12) {
  __ZNKSt3__221__basic_string_commonILb1EE20__throw_out_of_rangeEv($0);
  // unreachable;
 }
 if ($7) {
  $13 = ((($0)) + 8|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = $14 & 2147483647;
  $phitmp$i = (($15) + -1)|0;
  $17 = $phitmp$i;
 } else {
  $17 = 10;
 }
 $16 = (($17) - ($11))|0;
 $18 = ($16>>>0)<($3>>>0);
 $19 = (($11) + ($3))|0;
 if ($18) {
  $36 = (($19) - ($17))|0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE21__grow_by_and_replaceEjjjjjjPKc($0,$17,$36,$11,$1,0,$3,$2);
 } else {
  $20 = ($3|0)==(0);
  if (!($20)) {
   if ($7) {
    $21 = HEAP32[$0>>2]|0;
    $25 = $21;
   } else {
    $25 = $0;
   }
   $22 = (($11) - ($1))|0;
   $23 = ($22|0)==(0);
   $24 = (($25) + ($1)|0);
   if ($23) {
    $$1 = $2;
   } else {
    $26 = (($24) + ($3)|0);
    $27 = ($24>>>0)<=($2>>>0);
    $28 = (($25) + ($11)|0);
    $29 = ($28>>>0)>($2>>>0);
    $or$cond = $27 & $29;
    $30 = (($2) + ($3)|0);
    $$0 = $or$cond ? $30 : $2;
    (__ZNSt3__211char_traitsIcE4moveEPcPKcj($26,$24,$22)|0);
    $$1 = $$0;
   }
   (__ZNSt3__211char_traitsIcE4moveEPcPKcj($24,$$1,$3)|0);
   $31 = HEAP8[$5>>0]|0;
   $32 = ($31<<24>>24)<(0);
   if ($32) {
    $33 = ((($0)) + 4|0);
    HEAP32[$33>>2] = $19;
   } else {
    $34 = $19&255;
    HEAP8[$5>>0] = $34;
   }
   $35 = (($25) + ($19)|0);
   HEAP8[$4>>0] = 0;
   __ZNSt3__211char_traitsIcE6assignERcRKc($35,$4);
  }
 }
 STACKTOP = sp;return ($0|0);
}
function __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6insertEjPKc($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (__ZNSt3__211char_traitsIcE6lengthEPKc($2)|0);
 $4 = (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6insertEjPKcj($0,$1,$2,$3)|0);
 return ($4|0);
}
function __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5eraseEjj($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$pre = 0, $$sroa$speculated = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = ((($0)) + 11|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)<(0);
 if ($6) {
  $7 = ((($0)) + 4|0);
  $8 = HEAP32[$7>>2]|0;
  $10 = $8;
 } else {
  $9 = $5&255;
  $10 = $9;
 }
 $11 = ($10>>>0)<($1>>>0);
 if ($11) {
  __ZNKSt3__221__basic_string_commonILb1EE20__throw_out_of_rangeEv($0);
  // unreachable;
 }
 $12 = ($2|0)==(0);
 if (!($12)) {
  if ($6) {
   $13 = HEAP32[$0>>2]|0;
   $19 = $13;
  } else {
   $19 = $0;
  }
  $14 = (($10) - ($1))|0;
  $15 = ($14>>>0)<($2>>>0);
  $$sroa$speculated = $15 ? $14 : $2;
  $16 = (($14) - ($$sroa$speculated))|0;
  $17 = ($16|0)==(0);
  if ($17) {
   $22 = $5;
  } else {
   $18 = (($19) + ($1)|0);
   $20 = (($18) + ($$sroa$speculated)|0);
   (__ZNSt3__211char_traitsIcE4moveEPcPKcj($18,$20,$16)|0);
   $$pre = HEAP8[$4>>0]|0;
   $22 = $$pre;
  }
  $21 = (($10) - ($$sroa$speculated))|0;
  $23 = ($22<<24>>24)<(0);
  if ($23) {
   $24 = ((($0)) + 4|0);
   HEAP32[$24>>2] = $21;
  } else {
   $25 = $21&255;
   HEAP8[$4>>0] = $25;
  }
  $26 = (($19) + ($21)|0);
  HEAP8[$3>>0] = 0;
  __ZNSt3__211char_traitsIcE6assignERcRKc($26,$3);
 }
 STACKTOP = sp;return ($0|0);
}
function __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7replaceEjjPKcj($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$069 = 0, $$070 = 0, $$074 = 0, $$091 = 0, $$292 = 0, $$3 = 0, $$373 = 0, $$377 = 0, $$393 = 0, $$4 = 0, $$sroa$speculated = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $or$cond = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $5 = sp;
 $6 = ((($0)) + 11|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = ($7<<24>>24)<(0);
 if ($8) {
  $9 = ((($0)) + 4|0);
  $10 = HEAP32[$9>>2]|0;
  $12 = $10;
 } else {
  $11 = $7&255;
  $12 = $11;
 }
 $13 = ($12>>>0)<($1>>>0);
 if ($13) {
  __ZNKSt3__221__basic_string_commonILb1EE20__throw_out_of_rangeEv($0);
  // unreachable;
 }
 $14 = (($12) - ($1))|0;
 $15 = ($14>>>0)<($2>>>0);
 $$sroa$speculated = $15 ? $14 : $2;
 if ($8) {
  $16 = ((($0)) + 8|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = $17 & 2147483647;
  $phitmp$i = (($18) + -1)|0;
  $21 = $phitmp$i;
 } else {
  $21 = 10;
 }
 $19 = (($$sroa$speculated) - ($12))|0;
 $20 = (($19) + ($21))|0;
 $22 = ($20>>>0)<($4>>>0);
 if ($22) {
  $53 = (($12) + ($4))|0;
  $54 = (($53) - ($$sroa$speculated))|0;
  $55 = (($54) - ($21))|0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE21__grow_by_and_replaceEjjjjjjPKc($0,$21,$55,$12,$1,$$sroa$speculated,$4,$3);
 } else {
  if ($8) {
   $23 = HEAP32[$0>>2]|0;
   $29 = $23;
  } else {
   $29 = $0;
  }
  $24 = ($$sroa$speculated|0)==($4|0);
  do {
   if ($24) {
    $$292 = $4;$$3 = $1;$$373 = $3;$$377 = $4;
    label = 21;
   } else {
    $25 = (($14) - ($$sroa$speculated))|0;
    $26 = ($25|0)==(0);
    if ($26) {
     $$292 = $$sroa$speculated;$$3 = $1;$$373 = $3;$$377 = $4;
     label = 21;
    } else {
     $27 = ($$sroa$speculated>>>0)>($4>>>0);
     $28 = (($29) + ($1)|0);
     if ($27) {
      (__ZNSt3__211char_traitsIcE4moveEPcPKcj($28,$3,$4)|0);
      $43 = (($28) + ($4)|0);
      $44 = (($28) + ($$sroa$speculated)|0);
      (__ZNSt3__211char_traitsIcE4moveEPcPKcj($43,$44,$25)|0);
      $$393 = $$sroa$speculated;$$4 = $4;
      break;
     }
     $30 = ($28>>>0)<($3>>>0);
     $31 = (($29) + ($12)|0);
     $32 = ($31>>>0)>($3>>>0);
     $or$cond = $30 & $32;
     do {
      if ($or$cond) {
       $33 = (($28) + ($$sroa$speculated)|0);
       $34 = ($33>>>0)>($3>>>0);
       if ($34) {
        (__ZNSt3__211char_traitsIcE4moveEPcPKcj($28,$3,$$sroa$speculated)|0);
        $37 = (($$sroa$speculated) + ($1))|0;
        $38 = (($3) + ($4)|0);
        $39 = (($4) - ($$sroa$speculated))|0;
        $$069 = $37;$$070 = $38;$$074 = $39;$$091 = 0;
        break;
       } else {
        $35 = (($4) - ($$sroa$speculated))|0;
        $36 = (($3) + ($35)|0);
        $$069 = $1;$$070 = $36;$$074 = $4;$$091 = $$sroa$speculated;
        break;
       }
      } else {
       $$069 = $1;$$070 = $3;$$074 = $4;$$091 = $$sroa$speculated;
      }
     } while(0);
     $40 = (($29) + ($$069)|0);
     $41 = (($40) + ($$074)|0);
     $42 = (($40) + ($$091)|0);
     (__ZNSt3__211char_traitsIcE4moveEPcPKcj($41,$42,$25)|0);
     $$292 = $$091;$$3 = $$069;$$373 = $$070;$$377 = $$074;
     label = 21;
    }
   }
  } while(0);
  if ((label|0) == 21) {
   $45 = (($29) + ($$3)|0);
   (__ZNSt3__211char_traitsIcE4moveEPcPKcj($45,$$373,$$377)|0);
   $$393 = $$292;$$4 = $$377;
  }
  $46 = (($$4) - ($$393))|0;
  $47 = (($46) + ($12))|0;
  $48 = HEAP8[$6>>0]|0;
  $49 = ($48<<24>>24)<(0);
  if ($49) {
   $50 = ((($0)) + 4|0);
   HEAP32[$50>>2] = $47;
  } else {
   $51 = $47&255;
   HEAP8[$6>>0] = $51;
  }
  $52 = (($29) + ($47)|0);
  HEAP8[$5>>0] = 0;
  __ZNSt3__211char_traitsIcE6assignERcRKc($52,$5);
 }
 STACKTOP = sp;return ($0|0);
}
function __ZNSt3__211char_traitsIcE4findEPKcjRS2_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($1|0)==(0);
 if ($3) {
  $$0 = 0;
 } else {
  $4 = HEAP8[$2>>0]|0;
  $5 = (__ZNSt3__211char_traitsIcE11to_int_typeEc($4)|0);
  $6 = (_memchr($0,$5,$1)|0);
  $$0 = $6;
 }
 return ($$0|0);
}
function __ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE4findEcj($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$i = 0, $$1$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = ((($0)) + 11|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)<(0);
 if ($6) {
  $7 = HEAP32[$0>>2]|0;
  $8 = ((($0)) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $11 = $9;$14 = $7;
 } else {
  $10 = $5&255;
  $11 = $10;$14 = $0;
 }
 HEAP8[$3>>0] = $1;
 $12 = ($11>>>0)>($2>>>0);
 if ($12) {
  $13 = (($14) + ($2)|0);
  $15 = (($11) - ($2))|0;
  $16 = (__ZNSt3__211char_traitsIcE4findEPKcjRS2_($13,$15,$3)|0);
  $17 = ($16|0)==(0|0);
  $18 = $16;
  $19 = $14;
  $20 = (($18) - ($19))|0;
  $$0$i = $17 ? -1 : $20;
  $$1$i = $$0$i;
 } else {
  $$1$i = -1;
 }
 STACKTOP = sp;return ($$1$i|0);
}
function __ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5rfindEcj($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$015$i = 0, $$016$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 11|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)<(0);
 if ($5) {
  $6 = HEAP32[$0>>2]|0;
  $7 = ((($0)) + 4|0);
  $8 = HEAP32[$7>>2]|0;
  $10 = $8;$15 = $6;
 } else {
  $9 = $4&255;
  $10 = $9;$15 = $0;
 }
 $11 = ($10|0)==(0);
 L5: do {
  if ($11) {
   $23 = -1;
  } else {
   $12 = ($10>>>0)>($2>>>0);
   $13 = (($2) + 1)|0;
   $$016$i = $12 ? $13 : $10;
   $14 = (($15) + ($$016$i)|0);
   $$015$i = $14;
   while(1) {
    $16 = ($$015$i|0)==($15|0);
    if ($16) {
     $23 = -1;
     break L5;
    }
    $17 = ((($$015$i)) + -1|0);
    $18 = HEAP8[$17>>0]|0;
    $19 = (__ZNSt3__211char_traitsIcE2eqEcc($18,$1)|0);
    if ($19) {
     break;
    } else {
     $$015$i = $17;
    }
   }
   $20 = $17;
   $21 = $15;
   $22 = (($20) - ($21))|0;
   $23 = $22;
  }
 } while(0);
 return ($23|0);
}
function __ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7compareEjjPKcj($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$ = 0, $$$ = 0, $$sroa$speculated = 0, $$sroa$speculated19 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = ((($0)) + 11|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = ($6<<24>>24)<(0);
 if ($7) {
  $8 = ((($0)) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $11 = $9;
 } else {
  $10 = $6&255;
  $11 = $10;
 }
 $12 = ($11>>>0)<($1>>>0);
 $13 = ($4|0)==(-1);
 $or$cond = $13 | $12;
 if ($or$cond) {
  __ZNKSt3__221__basic_string_commonILb1EE20__throw_out_of_rangeEv($0);
  // unreachable;
 }
 $14 = (($11) - ($1))|0;
 $15 = ($14>>>0)<($2>>>0);
 $$sroa$speculated = $15 ? $14 : $2;
 if ($7) {
  $16 = HEAP32[$0>>2]|0;
  $18 = $16;
 } else {
  $18 = $0;
 }
 $17 = (($18) + ($1)|0);
 $19 = ($$sroa$speculated>>>0)>($4>>>0);
 $$sroa$speculated19 = $19 ? $4 : $$sroa$speculated;
 $20 = (__ZNSt3__211char_traitsIcE7compareEPKcS3_j($17,$3,$$sroa$speculated19)|0);
 $21 = ($20|0)==(0);
 if ($21) {
  $22 = ($$sroa$speculated>>>0)<($4>>>0);
  $$ = $19&1;
  $$$ = $22 ? -1 : $$;
  return ($$$|0);
 } else {
  return ($20|0);
 }
 return (0)|0;
}
function __ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7compareEjjPKc($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = (__ZNSt3__211char_traitsIcE6lengthEPKc($3)|0);
 $5 = (__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7compareEjjPKcj($0,$1,$2,$3,$4)|0);
 return ($5|0);
}
function __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 8|0);
 $2 = ((($1)) + 3|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)<(0);
 if ($4) {
  $5 = HEAP32[$0>>2]|0;
  __ZdlPv($5);
 }
 return;
}
function __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKwj($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = ((($0)) + 8|0);
 $5 = ((($4)) + 3|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = ($6<<24>>24)<(0);
 if ($7) {
  $8 = HEAP32[$4>>2]|0;
  $9 = $8 & 2147483647;
  $phitmp$i = (($9) + -1)|0;
  $10 = $phitmp$i;
 } else {
  $10 = 1;
 }
 $11 = ($10>>>0)<($2>>>0);
 do {
  if ($11) {
   if ($7) {
    $19 = ((($0)) + 4|0);
    $20 = HEAP32[$19>>2]|0;
    $23 = $20;
   } else {
    $21 = $6&255;
    $23 = $21;
   }
   $22 = (($2) - ($10))|0;
   __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE21__grow_by_and_replaceEjjjjjjPKw($0,$10,$22,$23,0,$23,$2,$1);
  } else {
   if ($7) {
    $12 = HEAP32[$0>>2]|0;
    $13 = $12;
   } else {
    $13 = $0;
   }
   (__ZNSt3__211char_traitsIwE4moveEPwPKwj($13,$1,$2)|0);
   $14 = (($13) + ($2<<2)|0);
   HEAP32[$3>>2] = 0;
   __ZNSt3__211char_traitsIwE6assignERwRKw($14,$3);
   $15 = HEAP8[$5>>0]|0;
   $16 = ($15<<24>>24)<(0);
   if ($16) {
    $17 = ((($0)) + 4|0);
    HEAP32[$17>>2] = $2;
    break;
   } else {
    $18 = $2&255;
    HEAP8[$5>>0] = $18;
    break;
   }
  }
 } while(0);
 STACKTOP = sp;return ($0|0);
}
function __ZNSt3__211char_traitsIwE4moveEPwPKwj($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($2|0)==(0);
 if ($3) {
  $7 = $0;
 } else {
  __THREW__ = 0;
  $4 = (invoke_iiii(4813,($0|0),($1|0),($2|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if ($6) {
   $8 = ___cxa_find_matching_catch_3(0|0)|0;
   $9 = tempRet0;
   ___clang_call_terminate($8);
   // unreachable;
  } else {
   $7 = $0;
  }
 }
 return ($7|0);
}
function __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE21__grow_by_and_replaceEjjjjjjPKw($0,$1,$2,$3,$4,$5,$6,$7) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 var $$sroa$speculated = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $8 = sp;
 $9 = (1073741806 - ($1))|0;
 $10 = ($9>>>0)<($2>>>0);
 if ($10) {
  __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $11 = ((($0)) + 8|0);
 $12 = ((($11)) + 3|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = ($13<<24>>24)<(0);
 if ($14) {
  $15 = HEAP32[$0>>2]|0;
  $34 = $15;
 } else {
  $34 = $0;
 }
 $16 = ($1>>>0)<(536870887);
 if ($16) {
  $17 = (($2) + ($1))|0;
  $18 = $1 << 1;
  $19 = ($17>>>0)<($18>>>0);
  $$sroa$speculated = $19 ? $18 : $17;
  $20 = ($$sroa$speculated>>>0)<(2);
  $21 = (($$sroa$speculated) + 4)|0;
  $22 = $21 & -4;
  $23 = $20 ? 2 : $22;
  $24 = ($23>>>0)>(1073741823);
  if ($24) {
   $25 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($25|0),(204840|0));
   $26 = __THREW__; __THREW__ = 0;
   $27 = $26&1;
   if ($27) {
    $28 = ___cxa_find_matching_catch_2()|0;
    $29 = tempRet0;
    ___cxa_free_exception(($25|0));
    ___resumeException($28|0);
    // unreachable;
   } else {
    HEAP32[$25>>2] = (99824);
    ___cxa_throw(($25|0),(34608|0),(3230|0));
    // unreachable;
   }
  } else {
   $31 = $23;
  }
 } else {
  $31 = 1073741807;
 }
 $30 = $31 << 2;
 $32 = (__Znwj($30)|0);
 $33 = ($4|0)==(0);
 if (!($33)) {
  (__ZNSt3__211char_traitsIwE4copyEPwPKwj($32,$34,$4)|0);
 }
 $35 = ($6|0)==(0);
 if (!($35)) {
  $36 = (($32) + ($4<<2)|0);
  (__ZNSt3__211char_traitsIwE4copyEPwPKwj($36,$7,$6)|0);
 }
 $37 = (($3) - ($5))|0;
 $38 = (($37) - ($4))|0;
 $39 = ($38|0)==(0);
 if (!($39)) {
  $40 = (($34) + ($4<<2)|0);
  $41 = (($40) + ($5<<2)|0);
  $42 = (($32) + ($4<<2)|0);
  $43 = (($42) + ($6<<2)|0);
  (__ZNSt3__211char_traitsIwE4copyEPwPKwj($43,$41,$38)|0);
 }
 $44 = ($1|0)==(1);
 if (!($44)) {
  __ZdlPv($34);
 }
 HEAP32[$0>>2] = $32;
 $45 = $31 | -2147483648;
 HEAP32[$11>>2] = $45;
 $46 = (($37) + ($6))|0;
 $47 = ((($0)) + 4|0);
 HEAP32[$47>>2] = $46;
 $48 = (($32) + ($46<<2)|0);
 HEAP32[$8>>2] = 0;
 __ZNSt3__211char_traitsIwE6assignERwRKw($48,$8);
 STACKTOP = sp;return;
}
function __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7reserveEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$01742 = 0, $$018$off040 = 0, $$1435056 = 0, $$144 = 0, $$phitmp$i = 0, $$sink = 0, $$sroa$speculated = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$indexZ2D = 0;
 var $phitmp$i = 0, $phitmp$i22 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1>>>0)>(1073741807);
 if ($2) {
  __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $3 = ((($0)) + 8|0);
 $4 = ((($3)) + 3|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)<(0);
 if ($6) {
  $7 = HEAP32[$3>>2]|0;
  $8 = $7 & 2147483647;
  $phitmp$i = (($8) + -1)|0;
  $9 = ((($0)) + 4|0);
  $10 = HEAP32[$9>>2]|0;
  $12 = $10;$18 = $phitmp$i;
 } else {
  $11 = $5&255;
  $12 = $11;$18 = 1;
 }
 $13 = ($12>>>0)>($1>>>0);
 $$sroa$speculated = $13 ? $12 : $1;
 $14 = ($$sroa$speculated>>>0)<(2);
 $15 = (($$sroa$speculated) + 4)|0;
 $16 = $15 & -4;
 $phitmp$i22 = (($16) + -1)|0;
 $$phitmp$i = $14 ? 1 : $phitmp$i22;
 $17 = ($$phitmp$i|0)==($18|0);
 L8: do {
  if (!($17)) {
   do {
    if ($14) {
     $42 = HEAP32[$0>>2]|0;
     if ($6) {
      $$01742 = $42;$$018$off040 = 0;$$144 = $0;
      label = 26;
     } else {
      $43 = $5&255;
      $44 = (($43) + 1)|0;
      (__ZNSt3__211char_traitsIwE4copyEPwPKwj($0,$42,$44)|0);
      __ZdlPv($42);
      label = 28;
     }
    } else {
     $19 = ($$phitmp$i>>>0)>($18>>>0);
     $20 = (($$phitmp$i) + 1)|0;
     $21 = ($20>>>0)>(1073741823);
     L14: do {
      if ($19) {
       if (!($21)) {
        $27 = $20 << 2;
        $28 = (__Znwj($27)|0);
        $$sink = $28;
        break;
       }
       $22 = (___cxa_allocate_exception(8)|0);
       __THREW__ = 0;
       invoke_vii(3366,($22|0),(204840|0));
       $23 = __THREW__; __THREW__ = 0;
       $24 = $23&1;
       if ($24) {
        $25 = ___cxa_find_matching_catch_2()|0;
        $26 = tempRet0;
        ___cxa_free_exception(($22|0));
        ___resumeException($25|0);
        // unreachable;
       } else {
        HEAP32[$22>>2] = (99824);
        ___cxa_throw(($22|0),(34608|0),(3230|0));
        // unreachable;
       }
      } else {
       do {
        if ($21) {
         $29 = (___cxa_allocate_exception(8)|0);
         __THREW__ = 0;
         invoke_vii(3366,($29|0),(204840|0));
         $30 = __THREW__; __THREW__ = 0;
         $31 = $30&1;
         if ($31) {
          $33 = ___cxa_find_matching_catch_3(0|0)|0;
          $34 = tempRet0;
          ___cxa_free_exception(($29|0));
          $eh$lpad$body$indexZ2D = $33;
          break;
         } else {
          HEAP32[$29>>2] = (99824);
          __THREW__ = 0;
          invoke_viii(3695,($29|0),(34608|0),(3230|0));
          $32 = __THREW__; __THREW__ = 0;
          label = 19;
          break;
         }
        } else {
         $35 = $20 << 2;
         __THREW__ = 0;
         $36 = (invoke_ii(3276,($35|0))|0);
         $37 = __THREW__; __THREW__ = 0;
         $38 = $37&1;
         if ($38) {
          label = 19;
         } else {
          $$sink = $36;
          break L14;
         }
        }
       } while(0);
       if ((label|0) == 19) {
        $39 = ___cxa_find_matching_catch_3(0|0)|0;
        $40 = tempRet0;
        $eh$lpad$body$indexZ2D = $39;
       }
       (___cxa_begin_catch(($eh$lpad$body$indexZ2D|0))|0);
       ___cxa_end_catch();
       break L8;
      }
     } while(0);
     if ($6) {
      $41 = HEAP32[$0>>2]|0;
      $$01742 = $41;$$018$off040 = 1;$$144 = $$sink;
      label = 26;
      break;
     } else {
      $45 = $5&255;
      $46 = (($45) + 1)|0;
      (__ZNSt3__211char_traitsIwE4copyEPwPKwj($$sink,$0,$46)|0);
      $$1435056 = $$sink;
      label = 27;
      break;
     }
    }
   } while(0);
   if ((label|0) == 26) {
    $47 = ((($0)) + 4|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = (($48) + 1)|0;
    (__ZNSt3__211char_traitsIwE4copyEPwPKwj($$144,$$01742,$49)|0);
    __ZdlPv($$01742);
    if ($$018$off040) {
     $$1435056 = $$144;
     label = 27;
    } else {
     label = 28;
    }
   }
   if ((label|0) == 27) {
    $50 = (($$phitmp$i) + 1)|0;
    $51 = $50 | -2147483648;
    HEAP32[$3>>2] = $51;
    $52 = ((($0)) + 4|0);
    HEAP32[$52>>2] = $12;
    HEAP32[$0>>2] = $$1435056;
    break;
   }
   else if ((label|0) == 28) {
    $53 = $12&255;
    HEAP8[$4>>0] = $53;
    break;
   }
  }
 } while(0);
 return;
}
function __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__ZNSt3__211char_traitsIwE6lengthEPKw($1)|0);
 $3 = (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKwj($0,$1,$2)|0);
 return ($3|0);
}
function __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE9__grow_byEjjjjjj($0,$1,$2,$3,$4,$5,$6) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 var $$sroa$speculated = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $7 = (1073741807 - ($1))|0;
 $8 = ($7>>>0)<($2>>>0);
 if ($8) {
  __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv($0);
  // unreachable;
 }
 $9 = ((($0)) + 8|0);
 $10 = ((($9)) + 3|0);
 $11 = HEAP8[$10>>0]|0;
 $12 = ($11<<24>>24)<(0);
 if ($12) {
  $13 = HEAP32[$0>>2]|0;
  $32 = $13;
 } else {
  $32 = $0;
 }
 $14 = ($1>>>0)<(536870887);
 if ($14) {
  $15 = (($2) + ($1))|0;
  $16 = $1 << 1;
  $17 = ($15>>>0)<($16>>>0);
  $$sroa$speculated = $17 ? $16 : $15;
  $18 = ($$sroa$speculated>>>0)<(2);
  $19 = (($$sroa$speculated) + 4)|0;
  $20 = $19 & -4;
  $21 = $18 ? 2 : $20;
  $22 = ($21>>>0)>(1073741823);
  if ($22) {
   $23 = (___cxa_allocate_exception(8)|0);
   __THREW__ = 0;
   invoke_vii(3366,($23|0),(204840|0));
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   if ($25) {
    $26 = ___cxa_find_matching_catch_2()|0;
    $27 = tempRet0;
    ___cxa_free_exception(($23|0));
    ___resumeException($26|0);
    // unreachable;
   } else {
    HEAP32[$23>>2] = (99824);
    ___cxa_throw(($23|0),(34608|0),(3230|0));
    // unreachable;
   }
  } else {
   $29 = $21;
  }
 } else {
  $29 = 1073741807;
 }
 $28 = $29 << 2;
 $30 = (__Znwj($28)|0);
 $31 = ($4|0)==(0);
 if (!($31)) {
  (__ZNSt3__211char_traitsIwE4copyEPwPKwj($30,$32,$4)|0);
 }
 $33 = (($3) - ($5))|0;
 $34 = (($33) - ($4))|0;
 $35 = ($34|0)==(0);
 if (!($35)) {
  $36 = (($32) + ($4<<2)|0);
  $37 = (($36) + ($5<<2)|0);
  $38 = (($30) + ($4<<2)|0);
  $39 = (($38) + ($6<<2)|0);
  (__ZNSt3__211char_traitsIwE4copyEPwPKwj($39,$37,$34)|0);
 }
 $40 = ($1|0)==(1);
 if (!($40)) {
  __ZdlPv($32);
 }
 HEAP32[$0>>2] = $30;
 $41 = $29 | -2147483648;
 HEAP32[$9>>2] = $41;
 return;
}
function __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6appendEPKwj($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = ((($0)) + 8|0);
 $5 = ((($4)) + 3|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = ($6<<24>>24)<(0);
 if ($7) {
  $8 = HEAP32[$4>>2]|0;
  $9 = $8 & 2147483647;
  $phitmp$i = (($9) + -1)|0;
  $10 = ((($0)) + 4|0);
  $11 = HEAP32[$10>>2]|0;
  $14 = $11;$15 = $phitmp$i;
 } else {
  $12 = $6&255;
  $14 = $12;$15 = 1;
 }
 $13 = (($15) - ($14))|0;
 $16 = ($13>>>0)<($2>>>0);
 $17 = (($14) + ($2))|0;
 if ($16) {
  $27 = (($17) - ($15))|0;
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE21__grow_by_and_replaceEjjjjjjPKw($0,$15,$27,$14,$14,0,$2,$1);
 } else {
  $18 = ($2|0)==(0);
  if (!($18)) {
   if ($7) {
    $19 = HEAP32[$0>>2]|0;
    $21 = $19;
   } else {
    $21 = $0;
   }
   $20 = (($21) + ($14<<2)|0);
   (__ZNSt3__211char_traitsIwE4copyEPwPKwj($20,$1,$2)|0);
   $22 = HEAP8[$5>>0]|0;
   $23 = ($22<<24>>24)<(0);
   if ($23) {
    $24 = ((($0)) + 4|0);
    HEAP32[$24>>2] = $17;
   } else {
    $25 = $17&255;
    HEAP8[$5>>0] = $25;
   }
   $26 = (($21) + ($17<<2)|0);
   HEAP32[$3>>2] = 0;
   __ZNSt3__211char_traitsIwE6assignERwRKw($26,$3);
  }
 }
 STACKTOP = sp;return ($0|0);
}
function __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE9push_backEw($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$018 = 0, $$019 = 0, $$pn = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp + 4|0;
 $3 = sp;
 HEAP32[$2>>2] = $1;
 $4 = ((($0)) + 8|0);
 $5 = ((($4)) + 3|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = ($6<<24>>24)<(0);
 if ($7) {
  $9 = HEAP32[$4>>2]|0;
  $10 = $9 & 2147483647;
  $11 = (($10) + -1)|0;
  $12 = ((($0)) + 4|0);
  $13 = HEAP32[$12>>2]|0;
  $$018 = $13;$$019 = $11;
 } else {
  $8 = $6&255;
  $$018 = $8;$$019 = 1;
 }
 $14 = ($$018|0)==($$019|0);
 if ($14) {
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE9__grow_byEjjjjjj($0,$$019,1,$$019,$$019,0,0);
  $15 = HEAP8[$5>>0]|0;
  $16 = ($15<<24>>24)<(0);
  $17 = (($$019) + 1)|0;
  if ($16) {
   $23 = $17;
   label = 8;
  } else {
   $20 = $17;
   label = 7;
  }
 } else {
  $18 = (($$018) + 1)|0;
  if ($7) {
   $23 = $18;
   label = 8;
  } else {
   $20 = $18;
   label = 7;
  }
 }
 if ((label|0) == 7) {
  $19 = $20&255;
  HEAP8[$5>>0] = $19;
  $$pn = $0;
 }
 else if ((label|0) == 8) {
  $21 = HEAP32[$0>>2]|0;
  $22 = ((($0)) + 4|0);
  HEAP32[$22>>2] = $23;
  $$pn = $21;
 }
 $$0 = (($$pn) + ($$018<<2)|0);
 __ZNSt3__211char_traitsIwE6assignERwRKw($$0,$2);
 $24 = ((($$0)) + 4|0);
 HEAP32[$3>>2] = 0;
 __ZNSt3__211char_traitsIwE6assignERwRKw($24,$3);
 STACKTOP = sp;return;
}
function __ZNSt3__24stoiERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPji($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp + 12|0;
 $4 = sp;
 ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;
 $5 = (__ZNSt3__211char_traitsIcE6lengthEPKc(204908)|0);
 $6 = ($5>>>0)>(4294967279);
 if ($6) {
  __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv($4);
  // unreachable;
 }
 $7 = ($5>>>0)<(11);
 if ($7) {
  $8 = $5&255;
  $9 = ((($4)) + 11|0);
  HEAP8[$9>>0] = $8;
  $$0$i$i = $4;
 } else {
  $10 = (($5) + 16)|0;
  $11 = $10 & -16;
  $12 = (__Znwj($11)|0);
  HEAP32[$4>>2] = $12;
  $13 = $11 | -2147483648;
  $14 = ((($4)) + 8|0);
  HEAP32[$14>>2] = $13;
  $15 = ((($4)) + 4|0);
  HEAP32[$15>>2] = $5;
  $$0$i$i = $12;
 }
 (__ZNSt3__211char_traitsIcE4copyEPcPKcj($$0$i$i,204908,$5)|0);
 $16 = (($$0$i$i) + ($5)|0);
 HEAP8[$3>>0] = 0;
 __ZNSt3__211char_traitsIcE6assignERcRKc($16,$3);
 __THREW__ = 0;
 $17 = (invoke_iiiii(4814,($4|0),($0|0),($1|0),($2|0))|0);
 $18 = __THREW__; __THREW__ = 0;
 $19 = $18&1;
 if ($19) {
  $20 = ___cxa_find_matching_catch_2()|0;
  $21 = tempRet0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($4);
  ___resumeException($20|0);
  // unreachable;
 } else {
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($4);
  STACKTOP = sp;return ($17|0);
 }
 return (0)|0;
}
function __ZNSt3__212_GLOBAL__N_110as_integerIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEEET_RKS7_RKT0_Pji($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = (__ZNSt3__212_GLOBAL__N_117as_integer_helperIlNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPFlPKcPPciEEET_RKS7_RKT0_PjiT1_($0,$1,$2,$3)|0);
 return ($4|0);
}
function __ZNSt3__212_GLOBAL__N_117as_integer_helperIlNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPFlPKcPPciEEET_RKS7_RKT0_PjiT1_($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $4 = sp;
 HEAP32[$4>>2] = 0;
 $5 = ((($1)) + 11|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = ($6<<24>>24)<(0);
 $8 = HEAP32[$1>>2]|0;
 $9 = $7 ? $8 : $1;
 $10 = (___errno_location()|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (___errno_location()|0);
 HEAP32[$12>>2] = 0;
 $13 = (_strtol($9,$4,$3)|0);
 $14 = (___errno_location()|0);
 $15 = HEAP32[$14>>2]|0;
 HEAP32[$14>>2] = $11;
 $16 = ($15|0)==(34);
 if ($16) {
  __ZNSt3__212_GLOBAL__N_130throw_from_string_out_of_rangeERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE($0);
 }
 $17 = HEAP32[$4>>2]|0;
 $18 = ($17|0)==($9|0);
 $19 = $17;
 if ($18) {
  __ZNSt3__212_GLOBAL__N_129throw_from_string_invalid_argERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE($0);
 }
 $20 = ($2|0)==(0|0);
 if (!($20)) {
  $21 = $9;
  $22 = (($19) - ($21))|0;
  HEAP32[$2>>2] = $22;
 }
 STACKTOP = sp;return ($13|0);
}
function __ZNSt3__212_GLOBAL__N_130throw_from_string_out_of_rangeERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 __ZNSt3__2plIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_12basic_stringIT_T0_T1_EERKS9_PKS6_($1,$0,204929);
 __THREW__ = 0;
 invoke_vi(4815,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch_2()|0;
  $5 = tempRet0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($1);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($1);
  STACKTOP = sp;return;
 }
}
function __ZNSt3__212_GLOBAL__N_129throw_from_string_invalid_argERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 __ZNSt3__2plIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_12basic_stringIT_T0_T1_EERKS9_PKS6_($1,$0,204913);
 __THREW__ = 0;
 invoke_vi(4816,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch_2()|0;
  $5 = tempRet0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($1);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($1);
  STACKTOP = sp;return;
 }
}
function __ZNSt3__212_GLOBAL__N_112throw_helperISt16invalid_argumentEEvRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (___cxa_allocate_exception(8)|0);
 __THREW__ = 0;
 invoke_vii(4817,($1|0),($0|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch_2()|0;
  $5 = tempRet0;
  ___cxa_free_exception(($1|0));
  ___resumeException($4|0);
  // unreachable;
 } else {
  HEAP32[$1>>2] = (99804);
  ___cxa_throw(($1|0),(34592|0),(3230|0));
  // unreachable;
 }
}
function __ZNSt3__212_GLOBAL__N_112throw_helperISt12out_of_rangeEEvRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (___cxa_allocate_exception(8)|0);
 __THREW__ = 0;
 invoke_vii(4817,($1|0),($0|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch_2()|0;
  $5 = tempRet0;
  ___cxa_free_exception(($1|0));
  ___resumeException($4|0);
  // unreachable;
 } else {
  HEAP32[$1>>2] = (99844);
  ___cxa_throw(($1|0),(34624|0),(3230|0));
  // unreachable;
 }
}
function __ZNSt3__29to_stringEj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 __ZNKSt3__212_GLOBAL__N_114initial_stringINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEjLb0EEclEv($2);
 __THREW__ = 0;
 invoke_viii(4818,($0|0),($2|0),($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch_2()|0;
  $6 = tempRet0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($2);
  ___resumeException($5|0);
  // unreachable;
 } else {
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($2);
  STACKTOP = sp;return;
 }
}
function __ZNKSt3__212_GLOBAL__N_114initial_stringINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEjLb0EEclEv($0) {
 $0 = $0|0;
 var $$0$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i$i = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 ;HEAP32[$0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;
 $$0$i$i = 0;
 while(1) {
  $exitcond$i$i = ($$0$i$i|0)==(3);
  if ($exitcond$i$i) {
   break;
  }
  $1 = (($0) + ($$0$i$i<<2)|0);
  HEAP32[$1>>2] = 0;
  $2 = (($$0$i$i) + 1)|0;
  $$0$i$i = $2;
 }
 $3 = ((($0)) + 11|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)<(0);
 if ($5) {
  $6 = ((($0)) + 8|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = $7 & 2147483647;
  $phitmp$i = (($8) + -1)|0;
  $9 = $phitmp$i;
 } else {
  $9 = 10;
 }
 __THREW__ = 0;
 invoke_viii(3434,($0|0),($9|0),0);
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if ($11) {
  $12 = ___cxa_find_matching_catch_2()|0;
  $13 = tempRet0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($0);
  ___resumeException($12|0);
  // unreachable;
 } else {
  return;
 }
}
function __ZNSt3__212_GLOBAL__N_19as_stringINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPFiPcjPKczEjEET_T0_SD_PKNSD_10value_typeET1_($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$i$i = 0, $$017 = 0, $$017$ph = 0, $$2 = 0, $$pre = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $exitcond$i$i = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $3 = ((($1)) + 11|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)<(0);
 if ($5) {
  $6 = ((($1)) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  $$017$ph = $7;
 } else {
  $8 = $4&255;
  $$017$ph = $8;
 }
 $$017 = $$017$ph;$9 = $4;
 while(1) {
  $10 = ($9<<24>>24)<(0);
  if ($10) {
   $11 = HEAP32[$1>>2]|0;
   $13 = $11;
  } else {
   $13 = $1;
  }
  $12 = (($$017) + 1)|0;
  HEAP32[$vararg_buffer>>2] = $2;
  $14 = (_snprintf($13,$12,204944,$vararg_buffer)|0);
  $15 = ($14|0)>(-1);
  if ($15) {
   $16 = ($14>>>0)>($$017>>>0);
   if ($16) {
    $$2 = $14;
   } else {
    break;
   }
  } else {
   $17 = $$017 << 1;
   $18 = $17 | 1;
   $$2 = $18;
  }
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEjc($1,$$2,0);
  $$pre = HEAP8[$3>>0]|0;
  $$017 = $$2;$9 = $$pre;
 }
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEjc($1,$14,0);
 ;HEAP32[$0>>2]=HEAP32[$1>>2]|0;HEAP32[$0+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$1+8>>2]|0;
 $$0$i$i = 0;
 while(1) {
  $exitcond$i$i = ($$0$i$i|0)==(3);
  if ($exitcond$i$i) {
   break;
  }
  $19 = (($1) + ($$0$i$i<<2)|0);
  HEAP32[$19>>2] = 0;
  $20 = (($$0$i$i) + 1)|0;
  $$0$i$i = $20;
 }
 STACKTOP = sp;return;
}
function __ZNSt3__214error_categoryD2Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZNKSt3__214error_category23default_error_conditionEi($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = $2;
 $3 = ((($0)) + 4|0);
 HEAP32[$3>>2] = $1;
 return;
}
function __ZNKSt3__214error_category10equivalentEiRKNS_15error_conditionE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = HEAP32[$0>>2]|0;
 $5 = ((($4)) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 FUNCTION_TABLE_viii[$6 & 8191]($3,$0,$1);
 $7 = ((($3)) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($2)) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8|0)==($10|0);
 if ($11) {
  $12 = HEAP32[$3>>2]|0;
  $13 = HEAP32[$2>>2]|0;
  $14 = ($12|0)==($13|0);
  $15 = $14;
 } else {
  $15 = 0;
 }
 STACKTOP = sp;return ($15|0);
}
function __ZNKSt3__214error_category10equivalentERKNS_10error_codeEi($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($1)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==($0|0);
 $6 = HEAP32[$1>>2]|0;
 $7 = ($6|0)==($2|0);
 $8 = $5 & $7;
 return ($8|0);
}
function __ZNKSt3__212__do_message7messageEi($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__212_GLOBAL__N_113do_strerror_rEi($0,$2);
 return;
}
function __ZNSt3__212_GLOBAL__N_113do_strerror_rEi($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i$i = 0, $$0$i$i12 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1040|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(1040|0);
 $vararg_buffer = sp;
 $2 = sp + 1033|0;
 $3 = sp + 1032|0;
 $4 = sp + 8|0;
 $5 = (___errno_location()|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (_strerror_r($1,$4,1024)|0);
 switch ($7|0) {
 case 0:  {
  ;HEAP32[$0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;
  $24 = (__ZNSt3__211char_traitsIcE6lengthEPKc($4)|0);
  $25 = ($24>>>0)>(4294967279);
  if ($25) {
   __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv($0);
   // unreachable;
  }
  $26 = ($24>>>0)<(11);
  if ($26) {
   $27 = $24&255;
   $28 = ((($0)) + 11|0);
   HEAP8[$28>>0] = $27;
   $$0$i$i12 = $0;
  } else {
   $29 = (($24) + 16)|0;
   $30 = $29 & -16;
   $31 = (__Znwj($30)|0);
   HEAP32[$0>>2] = $31;
   $32 = $30 | -2147483648;
   $33 = ((($0)) + 8|0);
   HEAP32[$33>>2] = $32;
   $34 = ((($0)) + 4|0);
   HEAP32[$34>>2] = $24;
   $$0$i$i12 = $31;
  }
  (__ZNSt3__211char_traitsIcE4copyEPcPKcj($$0$i$i12,$4,$24)|0);
  $35 = (($$0$i$i12) + ($24)|0);
  HEAP8[$2>>0] = 0;
  __ZNSt3__211char_traitsIcE6assignERcRKc($35,$2);
  break;
 }
 case -1:  {
  $8 = (___errno_location()|0);
  $9 = HEAP32[$8>>2]|0;
  $11 = $9;
  label = 3;
  break;
 }
 default: {
  $11 = $7;
  label = 3;
 }
 }
 L11: do {
  if ((label|0) == 3) {
   $10 = (___errno_location()|0);
   HEAP32[$10>>2] = $6;
   switch ($11|0) {
   case 22:  {
    HEAP32[$vararg_buffer>>2] = $1;
    (_snprintf($4,1024,204947,$vararg_buffer)|0);
    ;HEAP32[$0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;
    $12 = (__ZNSt3__211char_traitsIcE6lengthEPKc($4)|0);
    $13 = ($12>>>0)>(4294967279);
    if ($13) {
     __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv($0);
     // unreachable;
    }
    $14 = ($12>>>0)<(11);
    if ($14) {
     $15 = $12&255;
     $16 = ((($0)) + 11|0);
     HEAP8[$16>>0] = $15;
     $$0$i$i = $0;
    } else {
     $17 = (($12) + 16)|0;
     $18 = $17 & -16;
     $19 = (__Znwj($18)|0);
     HEAP32[$0>>2] = $19;
     $20 = $18 | -2147483648;
     $21 = ((($0)) + 8|0);
     HEAP32[$21>>2] = $20;
     $22 = ((($0)) + 4|0);
     HEAP32[$22>>2] = $12;
     $$0$i$i = $19;
    }
    (__ZNSt3__211char_traitsIcE4copyEPcPKcj($$0$i$i,$4,$12)|0);
    $23 = (($$0$i$i) + ($12)|0);
    HEAP8[$3>>0] = 0;
    __ZNSt3__211char_traitsIcE6assignERcRKc($23,$3);
    break L11;
    break;
   }
   case 34:  {
    _abort();
    // unreachable;
    break;
   }
   default: {
    ___assert_fail((204964|0),(204984|0),99,(205067|0));
    // unreachable;
   }
   }
  }
 } while(0);
 STACKTOP = sp;return;
}
function __ZNSt3__212system_errorD2Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt13runtime_errorD2Ev($0);
 return;
}
function __ZNSt3__212system_errorD0Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__212system_errorD2Ev($0);
 __ZdlPv($0);
 return;
}
function __ZNKSt3__210error_code7messageEv($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($4)) + 24|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_viii[$6 & 8191]($0,$3,$7);
 return;
}
function __ZNSt3__212system_error6__initERKNS_10error_codeENS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = HEAP32[$1>>2]|0;
 $5 = ($4|0)==(0);
 do {
  if (!($5)) {
   $6 = ((($2)) + 11|0);
   $7 = HEAP8[$6>>0]|0;
   $8 = ($7<<24>>24)<(0);
   if ($8) {
    $9 = ((($2)) + 4|0);
    $10 = HEAP32[$9>>2]|0;
    $12 = $10;
   } else {
    $11 = $7&255;
    $12 = $11;
   }
   $13 = ($12|0)==(0);
   if (!($13)) {
    (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKc($2,205152)|0);
   }
   __ZNKSt3__210error_code7messageEv($3,$1);
   $14 = ((($3)) + 11|0);
   $15 = HEAP8[$14>>0]|0;
   $16 = ($15<<24>>24)<(0);
   $17 = HEAP32[$3>>2]|0;
   $18 = $16 ? $17 : $3;
   $19 = ((($3)) + 4|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = $15&255;
   $22 = $16 ? $20 : $21;
   __THREW__ = 0;
   (invoke_iiii(3544,($2|0),($18|0),($22|0))|0);
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if ($24) {
    $25 = ___cxa_find_matching_catch_2()|0;
    $26 = tempRet0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($3);
    ___resumeException($25|0);
    // unreachable;
   } else {
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($3);
    break;
   }
  }
 } while(0);
 ;HEAP32[$0>>2]=HEAP32[$2>>2]|0;HEAP32[$0+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$2+8>>2]|0;
 $$0$i$i = 0;
 while(1) {
  $exitcond$i$i = ($$0$i$i|0)==(3);
  if ($exitcond$i$i) {
   break;
  }
  $27 = (($2) + ($$0$i$i<<2)|0);
  HEAP32[$27>>2] = 0;
  $28 = (($$0$i$i) + 1)|0;
  $$0$i$i = $28;
 }
 STACKTOP = sp;return;
}
function __ZNSt3__212system_errorC2ENS_10error_codeEPKc($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$0$i$i = 0, $$03 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $3 = sp + 24|0;
 $4 = sp + 12|0;
 $5 = sp;
 ;HEAP32[$5>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;
 $6 = (__ZNSt3__211char_traitsIcE6lengthEPKc($2)|0);
 $7 = ($6>>>0)>(4294967279);
 if ($7) {
  __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv($5);
  // unreachable;
 }
 $8 = ($6>>>0)<(11);
 if ($8) {
  $9 = $6&255;
  $10 = ((($5)) + 11|0);
  HEAP8[$10>>0] = $9;
  $$0$i$i = $5;
 } else {
  $11 = (($6) + 16)|0;
  $12 = $11 & -16;
  $13 = (__Znwj($12)|0);
  HEAP32[$5>>2] = $13;
  $14 = $12 | -2147483648;
  $15 = ((($5)) + 8|0);
  HEAP32[$15>>2] = $14;
  $16 = ((($5)) + 4|0);
  HEAP32[$16>>2] = $6;
  $$0$i$i = $13;
 }
 (__ZNSt3__211char_traitsIcE4copyEPcPKcj($$0$i$i,$2,$6)|0);
 $17 = (($$0$i$i) + ($6)|0);
 HEAP8[$3>>0] = 0;
 __ZNSt3__211char_traitsIcE6assignERcRKc($17,$3);
 __THREW__ = 0;
 invoke_viii(4819,($4|0),($1|0),($5|0));
 $18 = __THREW__; __THREW__ = 0;
 $19 = $18&1;
 do {
  if ($19) {
   $33 = ___cxa_find_matching_catch_2()|0;
   $34 = tempRet0;
   $$0 = $34;$$03 = $33;
  } else {
   __THREW__ = 0;
   invoke_vii(4820,($0|0),($4|0));
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if ($21) {
    $35 = ___cxa_find_matching_catch_2()|0;
    $36 = tempRet0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($4);
    $$0 = $36;$$03 = $35;
    break;
   } else {
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($4);
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($5);
    HEAP32[$0>>2] = (99616);
    $22 = ((($0)) + 8|0);
    $23 = $1;
    $24 = $23;
    $25 = HEAP32[$24>>2]|0;
    $26 = (($23) + 4)|0;
    $27 = $26;
    $28 = HEAP32[$27>>2]|0;
    $29 = $22;
    $30 = $29;
    HEAP32[$30>>2] = $25;
    $31 = (($29) + 4)|0;
    $32 = $31;
    HEAP32[$32>>2] = $28;
    STACKTOP = sp;return;
   }
  }
 } while(0);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($5);
 ___resumeException($$03|0);
 // unreachable;
}
function __ZL25default_terminate_handlerv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer10 = 0, $vararg_buffer3 = 0;
 var $vararg_buffer7 = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, $vararg_ptr6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $vararg_buffer10 = sp + 32|0;
 $vararg_buffer7 = sp + 24|0;
 $vararg_buffer3 = sp + 16|0;
 $vararg_buffer = sp;
 $0 = sp + 36|0;
 $1 = (___cxa_get_globals_fast()|0);
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = HEAP32[$1>>2]|0;
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = ((($3)) + 80|0);
   $6 = ((($3)) + 48|0);
   $7 = $6;
   $8 = $7;
   $9 = HEAP32[$8>>2]|0;
   $10 = (($7) + 4)|0;
   $11 = $10;
   $12 = HEAP32[$11>>2]|0;
   $13 = $9 & -256;
   $14 = ($13|0)==(1126902528);
   $15 = ($12|0)==(1129074247);
   $16 = $14 & $15;
   if (!($16)) {
    $36 = HEAP32[24908]|0;
    HEAP32[$vararg_buffer7>>2] = $36;
    _abort_message(205241,$vararg_buffer7);
    // unreachable;
   }
   $17 = ($9|0)==(1126902529);
   $18 = ($12|0)==(1129074247);
   $19 = $17 & $18;
   if ($19) {
    $20 = ((($3)) + 44|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = $21;
   } else {
    $22 = $5;
   }
   HEAP32[$0>>2] = $22;
   $23 = HEAP32[$3>>2]|0;
   $24 = ((($23)) + 4|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = HEAP32[8620]|0;
   $27 = ((($26)) + 16|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = (FUNCTION_TABLE_iiii[$28 & 8191](34480,$23,$0)|0);
   $30 = HEAP32[24908]|0;
   if ($29) {
    $31 = HEAP32[$0>>2]|0;
    $32 = HEAP32[$31>>2]|0;
    $33 = ((($32)) + 8|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = (FUNCTION_TABLE_ii[$34 & 8191]($31)|0);
    HEAP32[$vararg_buffer>>2] = $30;
    $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
    HEAP32[$vararg_ptr1>>2] = $25;
    $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
    HEAP32[$vararg_ptr2>>2] = $35;
    _abort_message(205155,$vararg_buffer);
    // unreachable;
   } else {
    HEAP32[$vararg_buffer3>>2] = $30;
    $vararg_ptr6 = ((($vararg_buffer3)) + 4|0);
    HEAP32[$vararg_ptr6>>2] = $25;
    _abort_message(205200,$vararg_buffer3);
    // unreachable;
   }
  }
 }
 _abort_message(205279,$vararg_buffer10);
 // unreachable;
}
function ___cxa_get_globals_fast() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $0 = (_pthread_once((217104|0),(4821|0))|0);
 $1 = ($0|0)==(0);
 if ($1) {
  $2 = HEAP32[54277]|0;
  $3 = (_pthread_getspecific(($2|0))|0);
  STACKTOP = sp;return ($3|0);
 } else {
  _abort_message(205430,$vararg_buffer);
  // unreachable;
 }
 return (0)|0;
}
function _abort_message($0,$varargs) {
 $0 = $0|0;
 $varargs = $varargs|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 HEAP32[$1>>2] = $varargs;
 $2 = HEAP32[23152]|0;
 (_vfprintf($2,$0,$1)|0);
 (_fputc(10,$2)|0);
 _abort();
 // unreachable;
}
function __ZN10__cxxabiv116__shim_type_infoD2Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN10__cxxabiv117__class_type_infoD0Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN10__cxxabiv116__shim_type_infoD2Ev($0);
 __ZdlPv($0);
 return;
}
function __ZNK10__cxxabiv116__shim_type_info5noop1Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZNK10__cxxabiv116__shim_type_info5noop2Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZNK10__cxxabiv117__class_type_info9can_catchEPKNS_16__shim_type_infoERPv($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$2 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(64|0);
 $3 = sp;
 $4 = (__ZN10__cxxabiv18is_equalEPKSt9type_infoS2_b($0,$1,0)|0);
 if ($4) {
  $$2 = 1;
 } else {
  $5 = ($1|0)==(0|0);
  if ($5) {
   $$2 = 0;
  } else {
   $6 = (___dynamic_cast($1,34504,34488,0)|0);
   $7 = ($6|0)==(0|0);
   if ($7) {
    $$2 = 0;
   } else {
    $8 = ((($3)) + 4|0);
    dest=$8; stop=dest+52|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
    HEAP32[$3>>2] = $6;
    $9 = ((($3)) + 8|0);
    HEAP32[$9>>2] = $0;
    $10 = ((($3)) + 12|0);
    HEAP32[$10>>2] = -1;
    $11 = ((($3)) + 48|0);
    HEAP32[$11>>2] = 1;
    $12 = HEAP32[$6>>2]|0;
    $13 = ((($12)) + 28|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = HEAP32[$2>>2]|0;
    FUNCTION_TABLE_viiii[$14 & 8191]($6,$3,$15,1);
    $16 = ((($3)) + 24|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = ($17|0)==(1);
    if ($18) {
     $19 = ((($3)) + 16|0);
     $20 = HEAP32[$19>>2]|0;
     HEAP32[$2>>2] = $20;
     $$0 = 1;
    } else {
     $$0 = 0;
    }
    $$2 = $$0;
   }
  }
 }
 STACKTOP = sp;return ($$2|0);
}
function __ZNK10__cxxabiv117__class_type_info16search_above_dstEPNS_19__dynamic_cast_infoEPKvS4_ib($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $6 = ((($1)) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (__ZN10__cxxabiv18is_equalEPKSt9type_infoS2_b($0,$7,$5)|0);
 if ($8) {
  __ZNK10__cxxabiv117__class_type_info29process_static_type_above_dstEPNS_19__dynamic_cast_infoEPKvS4_i(0,$1,$2,$3,$4);
 }
 return;
}
function __ZNK10__cxxabiv117__class_type_info16search_below_dstEPNS_19__dynamic_cast_infoEPKvib($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = ((($1)) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (__ZN10__cxxabiv18is_equalEPKSt9type_infoS2_b($0,$6,$4)|0);
 do {
  if ($7) {
   __ZNK10__cxxabiv117__class_type_info29process_static_type_below_dstEPNS_19__dynamic_cast_infoEPKvi(0,$1,$2,$3);
  } else {
   $8 = HEAP32[$1>>2]|0;
   $9 = (__ZN10__cxxabiv18is_equalEPKSt9type_infoS2_b($0,$8,$4)|0);
   if ($9) {
    $10 = ((($1)) + 16|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)==($2|0);
    $13 = ((($1)) + 32|0);
    if (!($12)) {
     $14 = ((($1)) + 20|0);
     $15 = HEAP32[$14>>2]|0;
     $16 = ($15|0)==($2|0);
     if (!($16)) {
      HEAP32[$13>>2] = $3;
      HEAP32[$14>>2] = $2;
      $18 = ((($1)) + 40|0);
      $19 = HEAP32[$18>>2]|0;
      $20 = (($19) + 1)|0;
      HEAP32[$18>>2] = $20;
      $21 = ((($1)) + 36|0);
      $22 = HEAP32[$21>>2]|0;
      $23 = ($22|0)==(1);
      if ($23) {
       $24 = ((($1)) + 24|0);
       $25 = HEAP32[$24>>2]|0;
       $26 = ($25|0)==(2);
       if ($26) {
        $27 = ((($1)) + 54|0);
        HEAP8[$27>>0] = 1;
       }
      }
      $28 = ((($1)) + 44|0);
      HEAP32[$28>>2] = 4;
      break;
     }
    }
    $17 = ($3|0)==(1);
    if ($17) {
     HEAP32[$13>>2] = 1;
    }
   }
  }
 } while(0);
 return;
}
function __ZNK10__cxxabiv117__class_type_info27has_unambiguous_public_baseEPNS_19__dynamic_cast_infoEPvi($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ((($1)) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (__ZN10__cxxabiv18is_equalEPKSt9type_infoS2_b($0,$5,0)|0);
 if ($6) {
  __ZNK10__cxxabiv117__class_type_info24process_found_base_classEPNS_19__dynamic_cast_infoEPvi(0,$1,$2,$3);
 }
 return;
}
function __ZN10__cxxabiv18is_equalEPKSt9type_infoS2_b($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($0|0)==($1|0);
 return ($3|0);
}
function __ZNK10__cxxabiv117__class_type_info24process_found_base_classEPNS_19__dynamic_cast_infoEPvi($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ((($1)) + 16|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 $7 = ((($1)) + 36|0);
 $8 = ((($1)) + 24|0);
 do {
  if ($6) {
   HEAP32[$4>>2] = $2;
   HEAP32[$8>>2] = $3;
   HEAP32[$7>>2] = 1;
  } else {
   $9 = ($5|0)==($2|0);
   if (!($9)) {
    $12 = HEAP32[$7>>2]|0;
    $13 = (($12) + 1)|0;
    HEAP32[$7>>2] = $13;
    HEAP32[$8>>2] = 2;
    $14 = ((($1)) + 54|0);
    HEAP8[$14>>0] = 1;
    break;
   }
   $10 = HEAP32[$8>>2]|0;
   $11 = ($10|0)==(2);
   if ($11) {
    HEAP32[$8>>2] = $3;
   }
  }
 } while(0);
 return;
}
function __ZNK10__cxxabiv117__class_type_info29process_static_type_below_dstEPNS_19__dynamic_cast_infoEPKvi($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==($2|0);
 if ($6) {
  $7 = ((($1)) + 28|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)==(1);
  if (!($9)) {
   HEAP32[$7>>2] = $3;
  }
 }
 return;
}
function __ZNK10__cxxabiv117__class_type_info29process_static_type_above_dstEPNS_19__dynamic_cast_infoEPKvS4_i($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond22 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = ((($1)) + 53|0);
 HEAP8[$5>>0] = 1;
 $6 = ((($1)) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==($3|0);
 do {
  if ($8) {
   $9 = ((($1)) + 52|0);
   HEAP8[$9>>0] = 1;
   $10 = ((($1)) + 16|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = ($11|0)==(0|0);
   $13 = ((($1)) + 54|0);
   $14 = ((($1)) + 48|0);
   $15 = ((($1)) + 24|0);
   $16 = ((($1)) + 36|0);
   if ($12) {
    HEAP32[$10>>2] = $2;
    HEAP32[$15>>2] = $4;
    HEAP32[$16>>2] = 1;
    $17 = HEAP32[$14>>2]|0;
    $18 = ($17|0)==(1);
    $19 = ($4|0)==(1);
    $or$cond = $18 & $19;
    if (!($or$cond)) {
     break;
    }
    HEAP8[$13>>0] = 1;
    break;
   }
   $20 = ($11|0)==($2|0);
   if (!($20)) {
    $27 = HEAP32[$16>>2]|0;
    $28 = (($27) + 1)|0;
    HEAP32[$16>>2] = $28;
    HEAP8[$13>>0] = 1;
    break;
   }
   $21 = HEAP32[$15>>2]|0;
   $22 = ($21|0)==(2);
   if ($22) {
    HEAP32[$15>>2] = $4;
    $25 = $4;
   } else {
    $25 = $21;
   }
   $23 = HEAP32[$14>>2]|0;
   $24 = ($23|0)==(1);
   $26 = ($25|0)==(1);
   $or$cond22 = $24 & $26;
   if ($or$cond22) {
    HEAP8[$13>>0] = 1;
   }
  }
 } while(0);
 return;
}
function ___dynamic_cast($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$ = 0, $$0 = 0, $$33 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond28 = 0, $or$cond30 = 0, $or$cond32 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(64|0);
 $4 = sp;
 $5 = HEAP32[$0>>2]|0;
 $6 = ((($5)) + -8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($0) + ($7)|0);
 $9 = ((($5)) + -4|0);
 $10 = HEAP32[$9>>2]|0;
 HEAP32[$4>>2] = $2;
 $11 = ((($4)) + 4|0);
 HEAP32[$11>>2] = $0;
 $12 = ((($4)) + 8|0);
 HEAP32[$12>>2] = $1;
 $13 = ((($4)) + 12|0);
 HEAP32[$13>>2] = $3;
 $14 = ((($4)) + 16|0);
 $15 = ((($4)) + 20|0);
 $16 = ((($4)) + 24|0);
 $17 = ((($4)) + 28|0);
 $18 = ((($4)) + 32|0);
 $19 = ((($4)) + 40|0);
 dest=$14; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));HEAP16[$14+36>>1]=0|0;HEAP8[$14+38>>0]=0|0;
 $20 = (__ZN10__cxxabiv18is_equalEPKSt9type_infoS2_b($10,$2,0)|0);
 L1: do {
  if ($20) {
   $21 = ((($4)) + 48|0);
   HEAP32[$21>>2] = 1;
   $22 = HEAP32[$10>>2]|0;
   $23 = ((($22)) + 20|0);
   $24 = HEAP32[$23>>2]|0;
   FUNCTION_TABLE_viiiiii[$24 & 8191]($10,$4,$8,$8,1,0);
   $25 = HEAP32[$16>>2]|0;
   $26 = ($25|0)==(1);
   $$ = $26 ? $8 : 0;
   $$0 = $$;
  } else {
   $27 = ((($4)) + 36|0);
   $28 = HEAP32[$10>>2]|0;
   $29 = ((($28)) + 24|0);
   $30 = HEAP32[$29>>2]|0;
   FUNCTION_TABLE_viiiii[$30 & 8191]($10,$4,$8,1,0);
   $31 = HEAP32[$27>>2]|0;
   switch ($31|0) {
   case 0:  {
    $32 = HEAP32[$19>>2]|0;
    $33 = ($32|0)==(1);
    $34 = HEAP32[$17>>2]|0;
    $35 = ($34|0)==(1);
    $or$cond = $33 & $35;
    $36 = HEAP32[$18>>2]|0;
    $37 = ($36|0)==(1);
    $or$cond28 = $or$cond & $37;
    $38 = HEAP32[$15>>2]|0;
    $$33 = $or$cond28 ? $38 : 0;
    $$0 = $$33;
    break L1;
    break;
   }
   case 1:  {
    break;
   }
   default: {
    $$0 = 0;
    break L1;
   }
   }
   $39 = HEAP32[$16>>2]|0;
   $40 = ($39|0)==(1);
   if (!($40)) {
    $41 = HEAP32[$19>>2]|0;
    $42 = ($41|0)==(0);
    $43 = HEAP32[$17>>2]|0;
    $44 = ($43|0)==(1);
    $or$cond30 = $42 & $44;
    $45 = HEAP32[$18>>2]|0;
    $46 = ($45|0)==(1);
    $or$cond32 = $or$cond30 & $46;
    if (!($or$cond32)) {
     $$0 = 0;
     break;
    }
   }
   $47 = HEAP32[$14>>2]|0;
   $$0 = $47;
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function __ZN10__cxxabiv120__si_class_type_infoD0Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN10__cxxabiv116__shim_type_infoD2Ev($0);
 __ZdlPv($0);
 return;
}
function __ZNK10__cxxabiv120__si_class_type_info16search_above_dstEPNS_19__dynamic_cast_infoEPKvS4_ib($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $6 = ((($1)) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (__ZN10__cxxabiv18is_equalEPKSt9type_infoS2_b($0,$7,$5)|0);
 if ($8) {
  __ZNK10__cxxabiv117__class_type_info29process_static_type_above_dstEPNS_19__dynamic_cast_infoEPKvS4_i(0,$1,$2,$3,$4);
 } else {
  $9 = ((($0)) + 8|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = HEAP32[$10>>2]|0;
  $12 = ((($11)) + 20|0);
  $13 = HEAP32[$12>>2]|0;
  FUNCTION_TABLE_viiiiii[$13 & 8191]($10,$1,$2,$3,$4,$5);
 }
 return;
}
function __ZNK10__cxxabiv120__si_class_type_info16search_below_dstEPNS_19__dynamic_cast_infoEPKvib($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$037$off038 = 0, $$037$off039 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $not$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = ((($1)) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (__ZN10__cxxabiv18is_equalEPKSt9type_infoS2_b($0,$6,$4)|0);
 do {
  if ($7) {
   __ZNK10__cxxabiv117__class_type_info29process_static_type_below_dstEPNS_19__dynamic_cast_infoEPKvi(0,$1,$2,$3);
  } else {
   $8 = HEAP32[$1>>2]|0;
   $9 = (__ZN10__cxxabiv18is_equalEPKSt9type_infoS2_b($0,$8,$4)|0);
   $10 = ((($0)) + 8|0);
   if (!($9)) {
    $41 = HEAP32[$10>>2]|0;
    $42 = HEAP32[$41>>2]|0;
    $43 = ((($42)) + 24|0);
    $44 = HEAP32[$43>>2]|0;
    FUNCTION_TABLE_viiiii[$44 & 8191]($41,$1,$2,$3,$4);
    break;
   }
   $11 = ((($1)) + 16|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = ($12|0)==($2|0);
   $14 = ((($1)) + 32|0);
   if (!($13)) {
    $15 = ((($1)) + 20|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = ($16|0)==($2|0);
    if (!($17)) {
     HEAP32[$14>>2] = $3;
     $19 = ((($1)) + 44|0);
     $20 = HEAP32[$19>>2]|0;
     $21 = ($20|0)==(4);
     if ($21) {
      break;
     }
     $22 = ((($1)) + 52|0);
     HEAP8[$22>>0] = 0;
     $23 = ((($1)) + 53|0);
     HEAP8[$23>>0] = 0;
     $24 = HEAP32[$10>>2]|0;
     $25 = HEAP32[$24>>2]|0;
     $26 = ((($25)) + 20|0);
     $27 = HEAP32[$26>>2]|0;
     FUNCTION_TABLE_viiiiii[$27 & 8191]($24,$1,$2,$2,1,$4);
     $28 = HEAP8[$23>>0]|0;
     $29 = ($28<<24>>24)==(0);
     if ($29) {
      $$037$off038 = 4;
      label = 11;
     } else {
      $30 = HEAP8[$22>>0]|0;
      $not$ = ($30<<24>>24)==(0);
      if ($not$) {
       $$037$off038 = 3;
       label = 11;
      } else {
       $$037$off039 = 3;
      }
     }
     if ((label|0) == 11) {
      HEAP32[$15>>2] = $2;
      $31 = ((($1)) + 40|0);
      $32 = HEAP32[$31>>2]|0;
      $33 = (($32) + 1)|0;
      HEAP32[$31>>2] = $33;
      $34 = ((($1)) + 36|0);
      $35 = HEAP32[$34>>2]|0;
      $36 = ($35|0)==(1);
      if ($36) {
       $37 = ((($1)) + 24|0);
       $38 = HEAP32[$37>>2]|0;
       $39 = ($38|0)==(2);
       if ($39) {
        $40 = ((($1)) + 54|0);
        HEAP8[$40>>0] = 1;
        $$037$off039 = $$037$off038;
       } else {
        $$037$off039 = $$037$off038;
       }
      } else {
       $$037$off039 = $$037$off038;
      }
     }
     HEAP32[$19>>2] = $$037$off039;
     break;
    }
   }
   $18 = ($3|0)==(1);
   if ($18) {
    HEAP32[$14>>2] = 1;
   }
  }
 } while(0);
 return;
}
function __ZNK10__cxxabiv120__si_class_type_info27has_unambiguous_public_baseEPNS_19__dynamic_cast_infoEPvi($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $10 = 0, $11 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ((($1)) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (__ZN10__cxxabiv18is_equalEPKSt9type_infoS2_b($0,$5,0)|0);
 if ($6) {
  __ZNK10__cxxabiv117__class_type_info24process_found_base_classEPNS_19__dynamic_cast_infoEPvi(0,$1,$2,$3);
 } else {
  $7 = ((($0)) + 8|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = HEAP32[$8>>2]|0;
  $10 = ((($9)) + 28|0);
  $11 = HEAP32[$10>>2]|0;
  FUNCTION_TABLE_viiii[$11 & 8191]($8,$1,$2,$3);
 }
 return;
}
function __ZNSt9type_infoD2Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZN10__cxxabiv112_GLOBAL__N_110construct_Ev() {
 var $0 = 0, $1 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $0 = (_pthread_key_create((217108|0),(4822|0))|0);
 $1 = ($0|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 } else {
  _abort_message(205479,$vararg_buffer);
  // unreachable;
 }
}
function __ZN10__cxxabiv112_GLOBAL__N_19destruct_EPv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 _free($0);
 $1 = HEAP32[54277]|0;
 $2 = (_pthread_setspecific(($1|0),(0|0))|0);
 $3 = ($2|0)==(0);
 if ($3) {
  STACKTOP = sp;return;
 } else {
  _abort_message(205529,$vararg_buffer);
  // unreachable;
 }
}
function __ZSt9terminatev() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 $0 = (invoke_i(4823)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $20 = ___cxa_find_matching_catch_3(0|0)|0;
  $21 = tempRet0;
  ___clang_call_terminate($20);
  // unreachable;
 }
 $3 = ($0|0)==(0|0);
 if (!($3)) {
  $4 = HEAP32[$0>>2]|0;
  $5 = ($4|0)==(0|0);
  if (!($5)) {
   $6 = ((($4)) + 48|0);
   $7 = $6;
   $8 = $7;
   $9 = HEAP32[$8>>2]|0;
   $10 = (($7) + 4)|0;
   $11 = $10;
   $12 = HEAP32[$11>>2]|0;
   $13 = $9 & -256;
   $14 = ($13|0)==(1126902528);
   $15 = ($12|0)==(1129074247);
   $16 = $14 & $15;
   if ($16) {
    $17 = ((($4)) + 12|0);
    $18 = HEAP32[$17>>2]|0;
    __ZSt11__terminatePFvvE($18);
    // unreachable;
   }
  }
 }
 $19 = (__ZSt13get_terminatev()|0);
 __ZSt11__terminatePFvvE($19);
 // unreachable;
}
function __ZSt11__terminatePFvvE($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 __THREW__ = 0;
 invoke_v($0|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_vii(4824,(205582|0),($vararg_buffer|0));
  $3 = __THREW__; __THREW__ = 0;
 }
 $4 = ___cxa_find_matching_catch_3(0|0)|0;
 $5 = tempRet0;
 (___cxa_begin_catch(($4|0))|0);
 __THREW__ = 0;
 invoke_vii(4824,(205622|0),($vararg_buffer1|0));
 $6 = __THREW__; __THREW__ = 0;
 $7 = ___cxa_find_matching_catch_3(0|0)|0;
 $8 = tempRet0;
 __THREW__ = 0;
 invoke_v(3261);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if ($10) {
  $11 = ___cxa_find_matching_catch_3(0|0)|0;
  $12 = tempRet0;
  ___clang_call_terminate($11);
  // unreachable;
 } else {
  ___clang_call_terminate($7);
  // unreachable;
 }
}
function __ZSt13get_terminatev() {
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[24907]|0;HEAP32[24907] = (($0+0)|0);
 $1 = $0;
 return ($1|0);
}
function __ZNSt9bad_allocD2Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZNSt9bad_allocD0Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt9bad_allocD2Ev($0);
 __ZdlPv($0);
 return;
}
function __ZNKSt9bad_alloc4whatEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (205672|0);
}
function __ZNSt9exceptionD2Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZNSt9exceptionD0Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($0);
 return;
}
function __ZNKSt9exception4whatEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (205700|0);
}
function __ZNSt11logic_errorD2Ev($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (99764);
 $1 = ((($0)) + 4|0);
 __ZNSt3__218__libcpp_refstringD2Ev($1);
 return;
}
function __ZNSt11logic_errorD0Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt11logic_errorD2Ev($0);
 __ZdlPv($0);
 return;
}
function __ZNKSt11logic_error4whatEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 4|0);
 $2 = (__ZNKSt3__218__libcpp_refstring5c_strEv($1)|0);
 return ($2|0);
}
function __ZNKSt3__218__libcpp_refstring5c_strEv($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 return ($1|0);
}
function __ZNSt3__218__libcpp_refstringD2Ev($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__ZNKSt3__218__libcpp_refstring15__uses_refcountEv($0)|0);
 if ($1) {
  $2 = HEAP32[$0>>2]|0;
  $3 = (__ZNSt3__215__refstring_imp12_GLOBAL__N_113rep_from_dataEPKc_6759($2)|0);
  $4 = ((($3)) + 8|0);
  $5 = HEAP32[$4>>2]|0;HEAP32[$4>>2] = (($5+-1)|0);
  $6 = (($5) + -1)|0;
  $7 = ($6|0)<(0);
  if ($7) {
   __ZdlPv($3);
  }
 }
 return;
}
function __ZNSt3__215__refstring_imp12_GLOBAL__N_113rep_from_dataEPKc_6759($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + -12|0);
 return ($1|0);
}
function __ZNSt13runtime_errorD2Ev($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (99784);
 $1 = ((($0)) + 4|0);
 __ZNSt3__218__libcpp_refstringD2Ev($1);
 return;
}
function __ZNSt13runtime_errorD0Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt13runtime_errorD2Ev($0);
 __ZdlPv($0);
 return;
}
function __ZNKSt13runtime_error4whatEv($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 4|0);
 $2 = (__ZNKSt3__218__libcpp_refstring5c_strEv($1)|0);
 return ($2|0);
}
function __ZNSt16invalid_argumentD0Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt11logic_errorD2Ev($0);
 __ZdlPv($0);
 return;
}
function __ZNSt12length_errorD0Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt11logic_errorD2Ev($0);
 __ZdlPv($0);
 return;
}
function __ZNSt12out_of_rangeD0Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt11logic_errorD2Ev($0);
 __ZdlPv($0);
 return;
}
function __ZNSt8bad_castD2Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZNSt8bad_castD0Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt8bad_castD2Ev($0);
 __ZdlPv($0);
 return;
}
function __ZNKSt8bad_cast4whatEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (205804|0);
}
function __ZNSt10bad_typeidD2Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZNSt10bad_typeidD0Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt10bad_typeidD2Ev($0);
 __ZdlPv($0);
 return;
}
function __ZNKSt10bad_typeid4whatEv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (205830|0);
}
function __ZN10__cxxabiv121__vmi_class_type_infoD0Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN10__cxxabiv116__shim_type_infoD2Ev($0);
 __ZdlPv($0);
 return;
}
function __ZNK10__cxxabiv121__vmi_class_type_info16search_above_dstEPNS_19__dynamic_cast_infoEPKvS4_ib($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $6 = ((($1)) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (__ZN10__cxxabiv18is_equalEPKSt9type_infoS2_b($0,$7,$5)|0);
 if ($8) {
  __ZNK10__cxxabiv117__class_type_info29process_static_type_above_dstEPNS_19__dynamic_cast_infoEPKvS4_i(0,$1,$2,$3,$4);
 } else {
  $9 = ((($1)) + 52|0);
  $10 = HEAP8[$9>>0]|0;
  $11 = ((($1)) + 53|0);
  $12 = HEAP8[$11>>0]|0;
  $13 = ((($0)) + 16|0);
  $14 = ((($0)) + 12|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (((($0)) + 16|0) + ($15<<3)|0);
  HEAP8[$9>>0] = 0;
  HEAP8[$11>>0] = 0;
  __ZNK10__cxxabiv122__base_class_type_info16search_above_dstEPNS_19__dynamic_cast_infoEPKvS4_ib($13,$1,$2,$3,$4,$5);
  $17 = ($15|0)>(1);
  L4: do {
   if ($17) {
    $18 = ((($0)) + 24|0);
    $19 = ((($1)) + 24|0);
    $20 = ((($1)) + 54|0);
    $21 = ((($0)) + 8|0);
    $$0 = $18;
    while(1) {
     $22 = HEAP8[$20>>0]|0;
     $23 = ($22<<24>>24)==(0);
     if (!($23)) {
      break L4;
     }
     $24 = HEAP8[$9>>0]|0;
     $25 = ($24<<24>>24)==(0);
     if ($25) {
      $31 = HEAP8[$11>>0]|0;
      $32 = ($31<<24>>24)==(0);
      if (!($32)) {
       $33 = HEAP32[$21>>2]|0;
       $34 = $33 & 1;
       $35 = ($34|0)==(0);
       if ($35) {
        break L4;
       }
      }
     } else {
      $26 = HEAP32[$19>>2]|0;
      $27 = ($26|0)==(1);
      if ($27) {
       break L4;
      }
      $28 = HEAP32[$21>>2]|0;
      $29 = $28 & 2;
      $30 = ($29|0)==(0);
      if ($30) {
       break L4;
      }
     }
     HEAP8[$9>>0] = 0;
     HEAP8[$11>>0] = 0;
     __ZNK10__cxxabiv122__base_class_type_info16search_above_dstEPNS_19__dynamic_cast_infoEPKvS4_ib($$0,$1,$2,$3,$4,$5);
     $36 = ((($$0)) + 8|0);
     $37 = ($36>>>0)<($16>>>0);
     if ($37) {
      $$0 = $36;
     } else {
      break;
     }
    }
   }
  } while(0);
  HEAP8[$9>>0] = $10;
  HEAP8[$11>>0] = $12;
 }
 return;
}
function __ZNK10__cxxabiv121__vmi_class_type_info16search_below_dstEPNS_19__dynamic_cast_infoEPKvib($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0 = 0, $$081$off0 = 0, $$084 = 0, $$085$off0 = 0, $$1 = 0, $$182$off0 = 0, $$186$off0 = 0, $$2 = 0, $$283$off0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = ((($1)) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (__ZN10__cxxabiv18is_equalEPKSt9type_infoS2_b($0,$6,$4)|0);
 L1: do {
  if ($7) {
   __ZNK10__cxxabiv117__class_type_info29process_static_type_below_dstEPNS_19__dynamic_cast_infoEPKvi(0,$1,$2,$3);
  } else {
   $8 = HEAP32[$1>>2]|0;
   $9 = (__ZN10__cxxabiv18is_equalEPKSt9type_infoS2_b($0,$8,$4)|0);
   $10 = ((($0)) + 12|0);
   $11 = ((($1)) + 24|0);
   $12 = ((($1)) + 36|0);
   $13 = ((($1)) + 54|0);
   $14 = ((($0)) + 8|0);
   $15 = ((($0)) + 16|0);
   if (!($9)) {
    $55 = HEAP32[$10>>2]|0;
    $56 = (((($0)) + 16|0) + ($55<<3)|0);
    __ZNK10__cxxabiv122__base_class_type_info16search_below_dstEPNS_19__dynamic_cast_infoEPKvib($15,$1,$2,$3,$4);
    $57 = ((($0)) + 24|0);
    $58 = ($55|0)>(1);
    if (!($58)) {
     break;
    }
    $59 = HEAP32[$14>>2]|0;
    $60 = $59 & 2;
    $61 = ($60|0)==(0);
    if ($61) {
     $62 = HEAP32[$12>>2]|0;
     $63 = ($62|0)==(1);
     if ($63) {
      $$0 = $57;
     } else {
      $68 = $59 & 1;
      $69 = ($68|0)==(0);
      if ($69) {
       $$2 = $57;
       while(1) {
        $78 = HEAP8[$13>>0]|0;
        $79 = ($78<<24>>24)==(0);
        if (!($79)) {
         break L1;
        }
        $80 = HEAP32[$12>>2]|0;
        $81 = ($80|0)==(1);
        if ($81) {
         break L1;
        }
        __ZNK10__cxxabiv122__base_class_type_info16search_below_dstEPNS_19__dynamic_cast_infoEPKvib($$2,$1,$2,$3,$4);
        $82 = ((($$2)) + 8|0);
        $83 = ($82>>>0)<($56>>>0);
        if ($83) {
         $$2 = $82;
        } else {
         break L1;
        }
       }
      } else {
       $$1 = $57;
      }
      while(1) {
       $70 = HEAP8[$13>>0]|0;
       $71 = ($70<<24>>24)==(0);
       if (!($71)) {
        break L1;
       }
       $72 = HEAP32[$12>>2]|0;
       $73 = ($72|0)==(1);
       if ($73) {
        $74 = HEAP32[$11>>2]|0;
        $75 = ($74|0)==(1);
        if ($75) {
         break L1;
        }
       }
       __ZNK10__cxxabiv122__base_class_type_info16search_below_dstEPNS_19__dynamic_cast_infoEPKvib($$1,$1,$2,$3,$4);
       $76 = ((($$1)) + 8|0);
       $77 = ($76>>>0)<($56>>>0);
       if ($77) {
        $$1 = $76;
       } else {
        break L1;
       }
      }
     }
    } else {
     $$0 = $57;
    }
    while(1) {
     $64 = HEAP8[$13>>0]|0;
     $65 = ($64<<24>>24)==(0);
     if (!($65)) {
      break L1;
     }
     __ZNK10__cxxabiv122__base_class_type_info16search_below_dstEPNS_19__dynamic_cast_infoEPKvib($$0,$1,$2,$3,$4);
     $66 = ((($$0)) + 8|0);
     $67 = ($66>>>0)<($56>>>0);
     if ($67) {
      $$0 = $66;
     } else {
      break L1;
     }
    }
   }
   $16 = ((($1)) + 16|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = ($17|0)==($2|0);
   $19 = ((($1)) + 32|0);
   if (!($18)) {
    $20 = ((($1)) + 20|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = ($21|0)==($2|0);
    if (!($22)) {
     HEAP32[$19>>2] = $3;
     $24 = ((($1)) + 44|0);
     $25 = HEAP32[$24>>2]|0;
     $26 = ($25|0)==(4);
     if ($26) {
      break;
     }
     $27 = HEAP32[$10>>2]|0;
     $28 = (((($0)) + 16|0) + ($27<<3)|0);
     $29 = ((($1)) + 52|0);
     $30 = ((($1)) + 53|0);
     $$081$off0 = 0;$$084 = $15;$$085$off0 = 0;
     L29: while(1) {
      $31 = ($$084>>>0)<($28>>>0);
      if (!($31)) {
       $$283$off0 = $$081$off0;
       label = 18;
       break;
      }
      HEAP8[$29>>0] = 0;
      HEAP8[$30>>0] = 0;
      __ZNK10__cxxabiv122__base_class_type_info16search_above_dstEPNS_19__dynamic_cast_infoEPKvS4_ib($$084,$1,$2,$2,1,$4);
      $32 = HEAP8[$13>>0]|0;
      $33 = ($32<<24>>24)==(0);
      if (!($33)) {
       $$283$off0 = $$081$off0;
       label = 18;
       break;
      }
      $34 = HEAP8[$30>>0]|0;
      $35 = ($34<<24>>24)==(0);
      do {
       if ($35) {
        $$182$off0 = $$081$off0;$$186$off0 = $$085$off0;
       } else {
        $36 = HEAP8[$29>>0]|0;
        $37 = ($36<<24>>24)==(0);
        if ($37) {
         $43 = HEAP32[$14>>2]|0;
         $44 = $43 & 1;
         $45 = ($44|0)==(0);
         if ($45) {
          $$283$off0 = 1;
          label = 18;
          break L29;
         } else {
          $$182$off0 = 1;$$186$off0 = $$085$off0;
          break;
         }
        }
        $38 = HEAP32[$11>>2]|0;
        $39 = ($38|0)==(1);
        if ($39) {
         label = 23;
         break L29;
        }
        $40 = HEAP32[$14>>2]|0;
        $41 = $40 & 2;
        $42 = ($41|0)==(0);
        if ($42) {
         label = 23;
         break L29;
        } else {
         $$182$off0 = 1;$$186$off0 = 1;
        }
       }
      } while(0);
      $46 = ((($$084)) + 8|0);
      $$081$off0 = $$182$off0;$$084 = $46;$$085$off0 = $$186$off0;
     }
     do {
      if ((label|0) == 18) {
       if (!($$085$off0)) {
        HEAP32[$20>>2] = $2;
        $47 = ((($1)) + 40|0);
        $48 = HEAP32[$47>>2]|0;
        $49 = (($48) + 1)|0;
        HEAP32[$47>>2] = $49;
        $50 = HEAP32[$12>>2]|0;
        $51 = ($50|0)==(1);
        if ($51) {
         $52 = HEAP32[$11>>2]|0;
         $53 = ($52|0)==(2);
         if ($53) {
          HEAP8[$13>>0] = 1;
          if ($$283$off0) {
           label = 23;
           break;
          } else {
           $54 = 4;
           break;
          }
         }
        }
       }
       if ($$283$off0) {
        label = 23;
       } else {
        $54 = 4;
       }
      }
     } while(0);
     if ((label|0) == 23) {
      $54 = 3;
     }
     HEAP32[$24>>2] = $54;
     break;
    }
   }
   $23 = ($3|0)==(1);
   if ($23) {
    HEAP32[$19>>2] = 1;
   }
  }
 } while(0);
 return;
}
function __ZNK10__cxxabiv121__vmi_class_type_info27has_unambiguous_public_baseEPNS_19__dynamic_cast_infoEPvi($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ((($1)) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (__ZN10__cxxabiv18is_equalEPKSt9type_infoS2_b($0,$5,0)|0);
 L1: do {
  if ($6) {
   __ZNK10__cxxabiv117__class_type_info24process_found_base_classEPNS_19__dynamic_cast_infoEPvi(0,$1,$2,$3);
  } else {
   $7 = ((($0)) + 16|0);
   $8 = ((($0)) + 12|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (((($0)) + 16|0) + ($9<<3)|0);
   __ZNK10__cxxabiv122__base_class_type_info27has_unambiguous_public_baseEPNS_19__dynamic_cast_infoEPvi($7,$1,$2,$3);
   $11 = ($9|0)>(1);
   if ($11) {
    $12 = ((($0)) + 24|0);
    $13 = ((($1)) + 54|0);
    $$0 = $12;
    while(1) {
     __ZNK10__cxxabiv122__base_class_type_info27has_unambiguous_public_baseEPNS_19__dynamic_cast_infoEPvi($$0,$1,$2,$3);
     $14 = HEAP8[$13>>0]|0;
     $15 = ($14<<24>>24)==(0);
     if (!($15)) {
      break L1;
     }
     $16 = ((($$0)) + 8|0);
     $17 = ($16>>>0)<($10>>>0);
     if ($17) {
      $$0 = $16;
     } else {
      break;
     }
    }
   }
  }
 } while(0);
 return;
}
function __ZNK10__cxxabiv122__base_class_type_info27has_unambiguous_public_baseEPNS_19__dynamic_cast_infoEPvi($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ((($0)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5 >> 8;
 $7 = $5 & 1;
 $8 = ($7|0)==(0);
 if ($8) {
  $$0 = $6;
 } else {
  $9 = HEAP32[$2>>2]|0;
  $10 = (($9) + ($6)|0);
  $11 = HEAP32[$10>>2]|0;
  $$0 = $11;
 }
 $12 = HEAP32[$0>>2]|0;
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($13)) + 28|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($2) + ($$0)|0);
 $17 = $5 & 2;
 $18 = ($17|0)!=(0);
 $19 = $18 ? $3 : 2;
 FUNCTION_TABLE_viiii[$15 & 8191]($12,$1,$16,$19);
 return;
}
function __ZNK10__cxxabiv122__base_class_type_info16search_above_dstEPNS_19__dynamic_cast_infoEPKvS4_ib($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $6 = ((($0)) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 >> 8;
 $9 = $7 & 1;
 $10 = ($9|0)==(0);
 if ($10) {
  $$0 = $8;
 } else {
  $11 = HEAP32[$3>>2]|0;
  $12 = (($11) + ($8)|0);
  $13 = HEAP32[$12>>2]|0;
  $$0 = $13;
 }
 $14 = HEAP32[$0>>2]|0;
 $15 = HEAP32[$14>>2]|0;
 $16 = ((($15)) + 20|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($3) + ($$0)|0);
 $19 = $7 & 2;
 $20 = ($19|0)!=(0);
 $21 = $20 ? $4 : 2;
 FUNCTION_TABLE_viiiiii[$17 & 8191]($14,$1,$2,$18,$21,$5);
 return;
}
function __ZNK10__cxxabiv122__base_class_type_info16search_below_dstEPNS_19__dynamic_cast_infoEPKvib($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = ((($0)) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $6 >> 8;
 $8 = $6 & 1;
 $9 = ($8|0)==(0);
 if ($9) {
  $$0 = $7;
 } else {
  $10 = HEAP32[$2>>2]|0;
  $11 = (($10) + ($7)|0);
  $12 = HEAP32[$11>>2]|0;
  $$0 = $12;
 }
 $13 = HEAP32[$0>>2]|0;
 $14 = HEAP32[$13>>2]|0;
 $15 = ((($14)) + 24|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($2) + ($$0)|0);
 $18 = $6 & 2;
 $19 = ($18|0)!=(0);
 $20 = $19 ? $3 : 2;
 FUNCTION_TABLE_viiiii[$16 & 8191]($13,$1,$17,$20,$4);
 return;
}
function __ZNSt8bad_castC2Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (99864);
 return;
}
function ___cxa_bad_typeid() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (___cxa_allocate_exception(4)|0);
 __ZNSt10bad_typeidC2Ev($0);
 ___cxa_throw(($0|0),(34656|0),(3241|0));
 // unreachable;
}
function __ZNSt10bad_typeidC2Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (99884);
 return;
}
function ___cxa_guard_acquire($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(1);
 if ($2) {
  $$0 = 0;
 } else {
  HEAP8[$0>>0] = 1;
  $$0 = 1;
 }
 return ($$0|0);
}
function ___cxa_guard_release($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function ___cxa_guard_abort($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function __ZNSt9bad_allocC2Ev($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = (99724);
 return;
}
function __ZSt15get_new_handlerv() {
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[54278]|0;HEAP32[54278] = (($0+0)|0);
 $1 = $0;
 return ($1|0);
}
function ___cxa_can_catch($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = HEAP32[$2>>2]|0;
 HEAP32[$3>>2] = $4;
 $5 = HEAP32[$0>>2]|0;
 $6 = ((($5)) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_iiii[$7 & 8191]($0,$1,$3)|0);
 $9 = $8&1;
 if ($8) {
  $10 = HEAP32[$3>>2]|0;
  HEAP32[$2>>2] = $10;
 }
 STACKTOP = sp;return ($9|0);
}
function ___cxa_is_pointer_type($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ($0|0)==(0|0);
 if ($1) {
  $4 = 0;
 } else {
  $2 = (___dynamic_cast($0,34504,34688,0)|0);
  $phitmp = ($2|0)!=(0|0);
  $4 = $phitmp;
 }
 $3 = $4&1;
 return ($3|0);
}
function runPostSets() {
}
function _pthread_mutex_lock(x) {
    x = x | 0;
    return 0;
}
function _pthread_mutex_trylock(x) {
    x = x | 0;
    return 0;
}
function _memset(ptr, value, num) {
    ptr = ptr|0; value = value|0; num = num|0;
    var end = 0, aligned_end = 0, block_aligned_end = 0, value4 = 0;
    end = (ptr + num)|0;

    value = value & 0xff;
    if ((num|0) >= 67 /* 64 bytes for an unrolled loop + 3 bytes for unaligned head*/) {
      while ((ptr&3) != 0) {
        HEAP8[((ptr)>>0)]=value;
        ptr = (ptr+1)|0;
      }

      aligned_end = (end & -4)|0;
      block_aligned_end = (aligned_end - 64)|0;
      value4 = value | (value << 8) | (value << 16) | (value << 24);

      while((ptr|0) <= (block_aligned_end|0)) {
        HEAP32[((ptr)>>2)]=value4;
        HEAP32[(((ptr)+(4))>>2)]=value4;
        HEAP32[(((ptr)+(8))>>2)]=value4;
        HEAP32[(((ptr)+(12))>>2)]=value4;
        HEAP32[(((ptr)+(16))>>2)]=value4;
        HEAP32[(((ptr)+(20))>>2)]=value4;
        HEAP32[(((ptr)+(24))>>2)]=value4;
        HEAP32[(((ptr)+(28))>>2)]=value4;
        HEAP32[(((ptr)+(32))>>2)]=value4;
        HEAP32[(((ptr)+(36))>>2)]=value4;
        HEAP32[(((ptr)+(40))>>2)]=value4;
        HEAP32[(((ptr)+(44))>>2)]=value4;
        HEAP32[(((ptr)+(48))>>2)]=value4;
        HEAP32[(((ptr)+(52))>>2)]=value4;
        HEAP32[(((ptr)+(56))>>2)]=value4;
        HEAP32[(((ptr)+(60))>>2)]=value4;
        ptr = (ptr + 64)|0;
      }

      while ((ptr|0) < (aligned_end|0) ) {
        HEAP32[((ptr)>>2)]=value4;
        ptr = (ptr+4)|0;
      }
    }
    // The remaining bytes.
    while ((ptr|0) < (end|0)) {
      HEAP8[((ptr)>>0)]=value;
      ptr = (ptr+1)|0;
    }
    return (end-num)|0;
}
function _i64Add(a, b, c, d) {
    /*
      x = a + b*2^32
      y = c + d*2^32
      result = l + h*2^32
    */
    a = a|0; b = b|0; c = c|0; d = d|0;
    var l = 0, h = 0;
    l = (a + c)>>>0;
    h = (b + d + (((l>>>0) < (a>>>0))|0))>>>0; // Add carry from low word to high word on overflow.
    return ((tempRet0 = h,l|0)|0);
}
function _i64Subtract(a, b, c, d) {
    a = a|0; b = b|0; c = c|0; d = d|0;
    var l = 0, h = 0;
    l = (a - c)>>>0;
    h = (b - d)>>>0;
    h = (b - d - (((c>>>0) > (a>>>0))|0))>>>0; // Borrow one from high word to low word on underflow.
    return ((tempRet0 = h,l|0)|0);
}
function _llvm_cttz_i32(x) {
    x = x|0;
    var ret = 0;
    ret = ((HEAP8[(((cttz_i8)+(x & 0xff))>>0)])|0);
    if ((ret|0) < 8) return ret|0;
    ret = ((HEAP8[(((cttz_i8)+((x >> 8)&0xff))>>0)])|0);
    if ((ret|0) < 8) return (ret + 8)|0;
    ret = ((HEAP8[(((cttz_i8)+((x >> 16)&0xff))>>0)])|0);
    if ((ret|0) < 8) return (ret + 16)|0;
    return (((HEAP8[(((cttz_i8)+(x >>> 24))>>0)])|0) + 24)|0;
}
function ___udivmoddi4($a$0, $a$1, $b$0, $b$1, $rem) {
    $a$0 = $a$0 | 0;
    $a$1 = $a$1 | 0;
    $b$0 = $b$0 | 0;
    $b$1 = $b$1 | 0;
    $rem = $rem | 0;
    var $n_sroa_0_0_extract_trunc = 0, $n_sroa_1_4_extract_shift$0 = 0, $n_sroa_1_4_extract_trunc = 0, $d_sroa_0_0_extract_trunc = 0, $d_sroa_1_4_extract_shift$0 = 0, $d_sroa_1_4_extract_trunc = 0, $4 = 0, $17 = 0, $37 = 0, $49 = 0, $51 = 0, $57 = 0, $58 = 0, $66 = 0, $78 = 0, $86 = 0, $88 = 0, $89 = 0, $91 = 0, $92 = 0, $95 = 0, $105 = 0, $117 = 0, $119 = 0, $125 = 0, $126 = 0, $130 = 0, $q_sroa_1_1_ph = 0, $q_sroa_0_1_ph = 0, $r_sroa_1_1_ph = 0, $r_sroa_0_1_ph = 0, $sr_1_ph = 0, $d_sroa_0_0_insert_insert99$0 = 0, $d_sroa_0_0_insert_insert99$1 = 0, $137$0 = 0, $137$1 = 0, $carry_0203 = 0, $sr_1202 = 0, $r_sroa_0_1201 = 0, $r_sroa_1_1200 = 0, $q_sroa_0_1199 = 0, $q_sroa_1_1198 = 0, $147 = 0, $149 = 0, $r_sroa_0_0_insert_insert42$0 = 0, $r_sroa_0_0_insert_insert42$1 = 0, $150$1 = 0, $151$0 = 0, $152 = 0, $154$0 = 0, $r_sroa_0_0_extract_trunc = 0, $r_sroa_1_4_extract_trunc = 0, $155 = 0, $carry_0_lcssa$0 = 0, $carry_0_lcssa$1 = 0, $r_sroa_0_1_lcssa = 0, $r_sroa_1_1_lcssa = 0, $q_sroa_0_1_lcssa = 0, $q_sroa_1_1_lcssa = 0, $q_sroa_0_0_insert_ext75$0 = 0, $q_sroa_0_0_insert_ext75$1 = 0, $q_sroa_0_0_insert_insert77$1 = 0, $_0$0 = 0, $_0$1 = 0;
    $n_sroa_0_0_extract_trunc = $a$0;
    $n_sroa_1_4_extract_shift$0 = $a$1;
    $n_sroa_1_4_extract_trunc = $n_sroa_1_4_extract_shift$0;
    $d_sroa_0_0_extract_trunc = $b$0;
    $d_sroa_1_4_extract_shift$0 = $b$1;
    $d_sroa_1_4_extract_trunc = $d_sroa_1_4_extract_shift$0;
    if (($n_sroa_1_4_extract_trunc | 0) == 0) {
      $4 = ($rem | 0) != 0;
      if (($d_sroa_1_4_extract_trunc | 0) == 0) {
        if ($4) {
          HEAP32[$rem >> 2] = ($n_sroa_0_0_extract_trunc >>> 0) % ($d_sroa_0_0_extract_trunc >>> 0);
          HEAP32[$rem + 4 >> 2] = 0;
        }
        $_0$1 = 0;
        $_0$0 = ($n_sroa_0_0_extract_trunc >>> 0) / ($d_sroa_0_0_extract_trunc >>> 0) >>> 0;
        return (tempRet0 = $_0$1, $_0$0) | 0;
      } else {
        if (!$4) {
          $_0$1 = 0;
          $_0$0 = 0;
          return (tempRet0 = $_0$1, $_0$0) | 0;
        }
        HEAP32[$rem >> 2] = $a$0 & -1;
        HEAP32[$rem + 4 >> 2] = $a$1 & 0;
        $_0$1 = 0;
        $_0$0 = 0;
        return (tempRet0 = $_0$1, $_0$0) | 0;
      }
    }
    $17 = ($d_sroa_1_4_extract_trunc | 0) == 0;
    do {
      if (($d_sroa_0_0_extract_trunc | 0) == 0) {
        if ($17) {
          if (($rem | 0) != 0) {
            HEAP32[$rem >> 2] = ($n_sroa_1_4_extract_trunc >>> 0) % ($d_sroa_0_0_extract_trunc >>> 0);
            HEAP32[$rem + 4 >> 2] = 0;
          }
          $_0$1 = 0;
          $_0$0 = ($n_sroa_1_4_extract_trunc >>> 0) / ($d_sroa_0_0_extract_trunc >>> 0) >>> 0;
          return (tempRet0 = $_0$1, $_0$0) | 0;
        }
        if (($n_sroa_0_0_extract_trunc | 0) == 0) {
          if (($rem | 0) != 0) {
            HEAP32[$rem >> 2] = 0;
            HEAP32[$rem + 4 >> 2] = ($n_sroa_1_4_extract_trunc >>> 0) % ($d_sroa_1_4_extract_trunc >>> 0);
          }
          $_0$1 = 0;
          $_0$0 = ($n_sroa_1_4_extract_trunc >>> 0) / ($d_sroa_1_4_extract_trunc >>> 0) >>> 0;
          return (tempRet0 = $_0$1, $_0$0) | 0;
        }
        $37 = $d_sroa_1_4_extract_trunc - 1 | 0;
        if (($37 & $d_sroa_1_4_extract_trunc | 0) == 0) {
          if (($rem | 0) != 0) {
            HEAP32[$rem >> 2] = 0 | $a$0 & -1;
            HEAP32[$rem + 4 >> 2] = $37 & $n_sroa_1_4_extract_trunc | $a$1 & 0;
          }
          $_0$1 = 0;
          $_0$0 = $n_sroa_1_4_extract_trunc >>> ((_llvm_cttz_i32($d_sroa_1_4_extract_trunc | 0) | 0) >>> 0);
          return (tempRet0 = $_0$1, $_0$0) | 0;
        }
        $49 = Math_clz32($d_sroa_1_4_extract_trunc | 0) | 0;
        $51 = $49 - (Math_clz32($n_sroa_1_4_extract_trunc | 0) | 0) | 0;
        if ($51 >>> 0 <= 30) {
          $57 = $51 + 1 | 0;
          $58 = 31 - $51 | 0;
          $sr_1_ph = $57;
          $r_sroa_0_1_ph = $n_sroa_1_4_extract_trunc << $58 | $n_sroa_0_0_extract_trunc >>> ($57 >>> 0);
          $r_sroa_1_1_ph = $n_sroa_1_4_extract_trunc >>> ($57 >>> 0);
          $q_sroa_0_1_ph = 0;
          $q_sroa_1_1_ph = $n_sroa_0_0_extract_trunc << $58;
          break;
        }
        if (($rem | 0) == 0) {
          $_0$1 = 0;
          $_0$0 = 0;
          return (tempRet0 = $_0$1, $_0$0) | 0;
        }
        HEAP32[$rem >> 2] = 0 | $a$0 & -1;
        HEAP32[$rem + 4 >> 2] = $n_sroa_1_4_extract_shift$0 | $a$1 & 0;
        $_0$1 = 0;
        $_0$0 = 0;
        return (tempRet0 = $_0$1, $_0$0) | 0;
      } else {
        if (!$17) {
          $117 = Math_clz32($d_sroa_1_4_extract_trunc | 0) | 0;
          $119 = $117 - (Math_clz32($n_sroa_1_4_extract_trunc | 0) | 0) | 0;
          if ($119 >>> 0 <= 31) {
            $125 = $119 + 1 | 0;
            $126 = 31 - $119 | 0;
            $130 = $119 - 31 >> 31;
            $sr_1_ph = $125;
            $r_sroa_0_1_ph = $n_sroa_0_0_extract_trunc >>> ($125 >>> 0) & $130 | $n_sroa_1_4_extract_trunc << $126;
            $r_sroa_1_1_ph = $n_sroa_1_4_extract_trunc >>> ($125 >>> 0) & $130;
            $q_sroa_0_1_ph = 0;
            $q_sroa_1_1_ph = $n_sroa_0_0_extract_trunc << $126;
            break;
          }
          if (($rem | 0) == 0) {
            $_0$1 = 0;
            $_0$0 = 0;
            return (tempRet0 = $_0$1, $_0$0) | 0;
          }
          HEAP32[$rem >> 2] = 0 | $a$0 & -1;
          HEAP32[$rem + 4 >> 2] = $n_sroa_1_4_extract_shift$0 | $a$1 & 0;
          $_0$1 = 0;
          $_0$0 = 0;
          return (tempRet0 = $_0$1, $_0$0) | 0;
        }
        $66 = $d_sroa_0_0_extract_trunc - 1 | 0;
        if (($66 & $d_sroa_0_0_extract_trunc | 0) != 0) {
          $86 = (Math_clz32($d_sroa_0_0_extract_trunc | 0) | 0) + 33 | 0;
          $88 = $86 - (Math_clz32($n_sroa_1_4_extract_trunc | 0) | 0) | 0;
          $89 = 64 - $88 | 0;
          $91 = 32 - $88 | 0;
          $92 = $91 >> 31;
          $95 = $88 - 32 | 0;
          $105 = $95 >> 31;
          $sr_1_ph = $88;
          $r_sroa_0_1_ph = $91 - 1 >> 31 & $n_sroa_1_4_extract_trunc >>> ($95 >>> 0) | ($n_sroa_1_4_extract_trunc << $91 | $n_sroa_0_0_extract_trunc >>> ($88 >>> 0)) & $105;
          $r_sroa_1_1_ph = $105 & $n_sroa_1_4_extract_trunc >>> ($88 >>> 0);
          $q_sroa_0_1_ph = $n_sroa_0_0_extract_trunc << $89 & $92;
          $q_sroa_1_1_ph = ($n_sroa_1_4_extract_trunc << $89 | $n_sroa_0_0_extract_trunc >>> ($95 >>> 0)) & $92 | $n_sroa_0_0_extract_trunc << $91 & $88 - 33 >> 31;
          break;
        }
        if (($rem | 0) != 0) {
          HEAP32[$rem >> 2] = $66 & $n_sroa_0_0_extract_trunc;
          HEAP32[$rem + 4 >> 2] = 0;
        }
        if (($d_sroa_0_0_extract_trunc | 0) == 1) {
          $_0$1 = $n_sroa_1_4_extract_shift$0 | $a$1 & 0;
          $_0$0 = 0 | $a$0 & -1;
          return (tempRet0 = $_0$1, $_0$0) | 0;
        } else {
          $78 = _llvm_cttz_i32($d_sroa_0_0_extract_trunc | 0) | 0;
          $_0$1 = 0 | $n_sroa_1_4_extract_trunc >>> ($78 >>> 0);
          $_0$0 = $n_sroa_1_4_extract_trunc << 32 - $78 | $n_sroa_0_0_extract_trunc >>> ($78 >>> 0) | 0;
          return (tempRet0 = $_0$1, $_0$0) | 0;
        }
      }
    } while (0);
    if (($sr_1_ph | 0) == 0) {
      $q_sroa_1_1_lcssa = $q_sroa_1_1_ph;
      $q_sroa_0_1_lcssa = $q_sroa_0_1_ph;
      $r_sroa_1_1_lcssa = $r_sroa_1_1_ph;
      $r_sroa_0_1_lcssa = $r_sroa_0_1_ph;
      $carry_0_lcssa$1 = 0;
      $carry_0_lcssa$0 = 0;
    } else {
      $d_sroa_0_0_insert_insert99$0 = 0 | $b$0 & -1;
      $d_sroa_0_0_insert_insert99$1 = $d_sroa_1_4_extract_shift$0 | $b$1 & 0;
      $137$0 = _i64Add($d_sroa_0_0_insert_insert99$0 | 0, $d_sroa_0_0_insert_insert99$1 | 0, -1, -1) | 0;
      $137$1 = tempRet0;
      $q_sroa_1_1198 = $q_sroa_1_1_ph;
      $q_sroa_0_1199 = $q_sroa_0_1_ph;
      $r_sroa_1_1200 = $r_sroa_1_1_ph;
      $r_sroa_0_1201 = $r_sroa_0_1_ph;
      $sr_1202 = $sr_1_ph;
      $carry_0203 = 0;
      while (1) {
        $147 = $q_sroa_0_1199 >>> 31 | $q_sroa_1_1198 << 1;
        $149 = $carry_0203 | $q_sroa_0_1199 << 1;
        $r_sroa_0_0_insert_insert42$0 = 0 | ($r_sroa_0_1201 << 1 | $q_sroa_1_1198 >>> 31);
        $r_sroa_0_0_insert_insert42$1 = $r_sroa_0_1201 >>> 31 | $r_sroa_1_1200 << 1 | 0;
        _i64Subtract($137$0 | 0, $137$1 | 0, $r_sroa_0_0_insert_insert42$0 | 0, $r_sroa_0_0_insert_insert42$1 | 0) | 0;
        $150$1 = tempRet0;
        $151$0 = $150$1 >> 31 | (($150$1 | 0) < 0 ? -1 : 0) << 1;
        $152 = $151$0 & 1;
        $154$0 = _i64Subtract($r_sroa_0_0_insert_insert42$0 | 0, $r_sroa_0_0_insert_insert42$1 | 0, $151$0 & $d_sroa_0_0_insert_insert99$0 | 0, ((($150$1 | 0) < 0 ? -1 : 0) >> 31 | (($150$1 | 0) < 0 ? -1 : 0) << 1) & $d_sroa_0_0_insert_insert99$1 | 0) | 0;
        $r_sroa_0_0_extract_trunc = $154$0;
        $r_sroa_1_4_extract_trunc = tempRet0;
        $155 = $sr_1202 - 1 | 0;
        if (($155 | 0) == 0) {
          break;
        } else {
          $q_sroa_1_1198 = $147;
          $q_sroa_0_1199 = $149;
          $r_sroa_1_1200 = $r_sroa_1_4_extract_trunc;
          $r_sroa_0_1201 = $r_sroa_0_0_extract_trunc;
          $sr_1202 = $155;
          $carry_0203 = $152;
        }
      }
      $q_sroa_1_1_lcssa = $147;
      $q_sroa_0_1_lcssa = $149;
      $r_sroa_1_1_lcssa = $r_sroa_1_4_extract_trunc;
      $r_sroa_0_1_lcssa = $r_sroa_0_0_extract_trunc;
      $carry_0_lcssa$1 = 0;
      $carry_0_lcssa$0 = $152;
    }
    $q_sroa_0_0_insert_ext75$0 = $q_sroa_0_1_lcssa;
    $q_sroa_0_0_insert_ext75$1 = 0;
    $q_sroa_0_0_insert_insert77$1 = $q_sroa_1_1_lcssa | $q_sroa_0_0_insert_ext75$1;
    if (($rem | 0) != 0) {
      HEAP32[$rem >> 2] = 0 | $r_sroa_0_1_lcssa;
      HEAP32[$rem + 4 >> 2] = $r_sroa_1_1_lcssa | 0;
    }
    $_0$1 = (0 | $q_sroa_0_0_insert_ext75$0) >>> 31 | $q_sroa_0_0_insert_insert77$1 << 1 | ($q_sroa_0_0_insert_ext75$1 << 1 | $q_sroa_0_0_insert_ext75$0 >>> 31) & 0 | $carry_0_lcssa$1;
    $_0$0 = ($q_sroa_0_0_insert_ext75$0 << 1 | 0 >>> 31) & -2 | $carry_0_lcssa$0;
    return (tempRet0 = $_0$1, $_0$0) | 0;
}
function ___udivdi3($a$0, $a$1, $b$0, $b$1) {
    $a$0 = $a$0 | 0;
    $a$1 = $a$1 | 0;
    $b$0 = $b$0 | 0;
    $b$1 = $b$1 | 0;
    var $1$0 = 0;
    $1$0 = ___udivmoddi4($a$0, $a$1, $b$0, $b$1, 0) | 0;
    return $1$0 | 0;
}
function _pthread_cond_broadcast(x) {
    x = x | 0;
    return 0;
}
function ___muldsi3($a, $b) {
    $a = $a | 0;
    $b = $b | 0;
    var $1 = 0, $2 = 0, $3 = 0, $6 = 0, $8 = 0, $11 = 0, $12 = 0;
    $1 = $a & 65535;
    $2 = $b & 65535;
    $3 = Math_imul($2, $1) | 0;
    $6 = $a >>> 16;
    $8 = ($3 >>> 16) + (Math_imul($2, $6) | 0) | 0;
    $11 = $b >>> 16;
    $12 = Math_imul($11, $1) | 0;
    return (tempRet0 = (($8 >>> 16) + (Math_imul($11, $6) | 0) | 0) + ((($8 & 65535) + $12 | 0) >>> 16) | 0, 0 | ($8 + $12 << 16 | $3 & 65535)) | 0;
}
function ___muldi3($a$0, $a$1, $b$0, $b$1) {
    $a$0 = $a$0 | 0;
    $a$1 = $a$1 | 0;
    $b$0 = $b$0 | 0;
    $b$1 = $b$1 | 0;
    var $x_sroa_0_0_extract_trunc = 0, $y_sroa_0_0_extract_trunc = 0, $1$0 = 0, $1$1 = 0, $2 = 0;
    $x_sroa_0_0_extract_trunc = $a$0;
    $y_sroa_0_0_extract_trunc = $b$0;
    $1$0 = ___muldsi3($x_sroa_0_0_extract_trunc, $y_sroa_0_0_extract_trunc) | 0;
    $1$1 = tempRet0;
    $2 = Math_imul($a$1, $y_sroa_0_0_extract_trunc) | 0;
    return (tempRet0 = ((Math_imul($b$1, $x_sroa_0_0_extract_trunc) | 0) + $2 | 0) + $1$1 | $1$1 & 0, 0 | $1$0 & -1) | 0;
}
function _memcpy(dest, src, num) {
    dest = dest|0; src = src|0; num = num|0;
    var ret = 0;
    var aligned_dest_end = 0;
    var block_aligned_dest_end = 0;
    var dest_end = 0;
    // Test against a benchmarked cutoff limit for when HEAPU8.set() becomes faster to use.
    if ((num|0) >=
      8192
    ) {
      return _emscripten_memcpy_big(dest|0, src|0, num|0)|0;
    }

    ret = dest|0;
    dest_end = (dest + num)|0;
    if ((dest&3) == (src&3)) {
      // The initial unaligned < 4-byte front.
      while (dest & 3) {
        if ((num|0) == 0) return ret|0;
        HEAP8[((dest)>>0)]=((HEAP8[((src)>>0)])|0);
        dest = (dest+1)|0;
        src = (src+1)|0;
        num = (num-1)|0;
      }
      aligned_dest_end = (dest_end & -4)|0;
      block_aligned_dest_end = (aligned_dest_end - 64)|0;
      while ((dest|0) <= (block_aligned_dest_end|0) ) {
        HEAP32[((dest)>>2)]=((HEAP32[((src)>>2)])|0);
        HEAP32[(((dest)+(4))>>2)]=((HEAP32[(((src)+(4))>>2)])|0);
        HEAP32[(((dest)+(8))>>2)]=((HEAP32[(((src)+(8))>>2)])|0);
        HEAP32[(((dest)+(12))>>2)]=((HEAP32[(((src)+(12))>>2)])|0);
        HEAP32[(((dest)+(16))>>2)]=((HEAP32[(((src)+(16))>>2)])|0);
        HEAP32[(((dest)+(20))>>2)]=((HEAP32[(((src)+(20))>>2)])|0);
        HEAP32[(((dest)+(24))>>2)]=((HEAP32[(((src)+(24))>>2)])|0);
        HEAP32[(((dest)+(28))>>2)]=((HEAP32[(((src)+(28))>>2)])|0);
        HEAP32[(((dest)+(32))>>2)]=((HEAP32[(((src)+(32))>>2)])|0);
        HEAP32[(((dest)+(36))>>2)]=((HEAP32[(((src)+(36))>>2)])|0);
        HEAP32[(((dest)+(40))>>2)]=((HEAP32[(((src)+(40))>>2)])|0);
        HEAP32[(((dest)+(44))>>2)]=((HEAP32[(((src)+(44))>>2)])|0);
        HEAP32[(((dest)+(48))>>2)]=((HEAP32[(((src)+(48))>>2)])|0);
        HEAP32[(((dest)+(52))>>2)]=((HEAP32[(((src)+(52))>>2)])|0);
        HEAP32[(((dest)+(56))>>2)]=((HEAP32[(((src)+(56))>>2)])|0);
        HEAP32[(((dest)+(60))>>2)]=((HEAP32[(((src)+(60))>>2)])|0);
        dest = (dest+64)|0;
        src = (src+64)|0;
      }
      while ((dest|0) < (aligned_dest_end|0) ) {
        HEAP32[((dest)>>2)]=((HEAP32[((src)>>2)])|0);
        dest = (dest+4)|0;
        src = (src+4)|0;
      }
    } else {
      // In the unaligned copy case, unroll a bit as well.
      aligned_dest_end = (dest_end - 4)|0;
      while ((dest|0) < (aligned_dest_end|0) ) {
        HEAP8[((dest)>>0)]=((HEAP8[((src)>>0)])|0);
        HEAP8[(((dest)+(1))>>0)]=((HEAP8[(((src)+(1))>>0)])|0);
        HEAP8[(((dest)+(2))>>0)]=((HEAP8[(((src)+(2))>>0)])|0);
        HEAP8[(((dest)+(3))>>0)]=((HEAP8[(((src)+(3))>>0)])|0);
        dest = (dest+4)|0;
        src = (src+4)|0;
      }
    }
    // The remaining unaligned < 4 byte tail.
    while ((dest|0) < (dest_end|0)) {
      HEAP8[((dest)>>0)]=((HEAP8[((src)>>0)])|0);
      dest = (dest+1)|0;
      src = (src+1)|0;
    }
    return ret|0;
}
function _memmove(dest, src, num) {
    dest = dest|0; src = src|0; num = num|0;
    var ret = 0;
    if (((src|0) < (dest|0)) & ((dest|0) < ((src + num)|0))) {
      // Unlikely case: Copy backwards in a safe manner
      ret = dest;
      src = (src + num)|0;
      dest = (dest + num)|0;
      while ((num|0) > 0) {
        dest = (dest - 1)|0;
        src = (src - 1)|0;
        num = (num - 1)|0;
        HEAP8[((dest)>>0)]=((HEAP8[((src)>>0)])|0);
      }
      dest = ret;
    } else {
      _memcpy(dest, src, num) | 0;
    }
    return dest | 0;
}
function ___uremdi3($a$0, $a$1, $b$0, $b$1) {
    $a$0 = $a$0 | 0;
    $a$1 = $a$1 | 0;
    $b$0 = $b$0 | 0;
    $b$1 = $b$1 | 0;
    var $rem = 0, __stackBase__ = 0;
    __stackBase__ = STACKTOP;
    STACKTOP = STACKTOP + 16 | 0;
    $rem = __stackBase__ | 0;
    ___udivmoddi4($a$0, $a$1, $b$0, $b$1, $rem) | 0;
    STACKTOP = __stackBase__;
    return (tempRet0 = HEAP32[$rem + 4 >> 2] | 0, HEAP32[$rem >> 2] | 0) | 0;
}
function _bitshift64Shl(low, high, bits) {
    low = low|0; high = high|0; bits = bits|0;
    var ander = 0;
    if ((bits|0) < 32) {
      ander = ((1 << bits) - 1)|0;
      tempRet0 = (high << bits) | ((low&(ander << (32 - bits))) >>> (32 - bits));
      return low << bits;
    }
    tempRet0 = low << (bits - 32);
    return 0;
}
function _bitshift64Lshr(low, high, bits) {
    low = low|0; high = high|0; bits = bits|0;
    var ander = 0;
    if ((bits|0) < 32) {
      ander = ((1 << bits) - 1)|0;
      tempRet0 = high >>> bits;
      return (low >>> bits) | ((high&ander) << (32 - bits));
    }
    tempRet0 = 0;
    return (high >>> (bits - 32))|0;
}
function _pthread_mutex_unlock(x) {
    x = x | 0;
    return 0;
}
function _sbrk(increment) {
    increment = increment|0;
    var oldDynamicTop = 0;
    var oldDynamicTopOnChange = 0;
    var newDynamicTop = 0;
    var totalMemory = 0;
    increment = ((increment + 15) & -16)|0;
    oldDynamicTop = HEAP32[DYNAMICTOP_PTR>>2]|0;
    newDynamicTop = oldDynamicTop + increment | 0;

    if (((increment|0) > 0 & (newDynamicTop|0) < (oldDynamicTop|0)) // Detect and fail if we would wrap around signed 32-bit int.
      | (newDynamicTop|0) < 0) { // Also underflow, sbrk() should be able to be used to subtract.
      abortOnCannotGrowMemory()|0;
      ___setErrNo(12);
      return -1;
    }

    HEAP32[DYNAMICTOP_PTR>>2] = newDynamicTop;
    totalMemory = getTotalMemory()|0;
    if ((newDynamicTop|0) > (totalMemory|0)) {
      if ((enlargeMemory()|0) == 0) {
        HEAP32[DYNAMICTOP_PTR>>2] = oldDynamicTop;
        ___setErrNo(12);
        return -1;
      }
    }
    return oldDynamicTop|0;
}
function _llvm_bswap_i32(x) {
    x = x|0;
    return (((x&0xff)<<24) | (((x>>8)&0xff)<<16) | (((x>>16)&0xff)<<8) | (x>>>24))|0;
}

  
function dynCall_iiiiiiii(index,a1,a2,a3,a4,a5,a6,a7) {
  index = index|0;
  a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=a5|0; a6=a6|0; a7=a7|0;
  return FUNCTION_TABLE_iiiiiiii[index&8191](a1|0,a2|0,a3|0,a4|0,a5|0,a6|0,a7|0)|0;
}


function dynCall_iiiiiid(index,a1,a2,a3,a4,a5,a6) {
  index = index|0;
  a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=a5|0; a6=+a6;
  return FUNCTION_TABLE_iiiiiid[index&4095](a1|0,a2|0,a3|0,a4|0,a5|0,+a6)|0;
}


function dynCall_vd(index,a1) {
  index = index|0;
  a1=+a1;
  FUNCTION_TABLE_vd[index&8191](+a1);
}


function dynCall_vid(index,a1,a2) {
  index = index|0;
  a1=a1|0; a2=+a2;
  FUNCTION_TABLE_vid[index&8191](a1|0,+a2);
}


function dynCall_viiiii(index,a1,a2,a3,a4,a5) {
  index = index|0;
  a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=a5|0;
  FUNCTION_TABLE_viiiii[index&8191](a1|0,a2|0,a3|0,a4|0,a5|0);
}


function dynCall_iiiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9) {
  index = index|0;
  a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=a5|0; a6=a6|0; a7=a7|0; a8=a8|0; a9=a9|0;
  return FUNCTION_TABLE_iiiiiiiiii[index&8191](a1|0,a2|0,a3|0,a4|0,a5|0,a6|0,a7|0,a8|0,a9|0)|0;
}


function dynCall_vii(index,a1,a2) {
  index = index|0;
  a1=a1|0; a2=a2|0;
  FUNCTION_TABLE_vii[index&8191](a1|0,a2|0);
}


function dynCall_iiiiiii(index,a1,a2,a3,a4,a5,a6) {
  index = index|0;
  a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=a5|0; a6=a6|0;
  return FUNCTION_TABLE_iiiiiii[index&8191](a1|0,a2|0,a3|0,a4|0,a5|0,a6|0)|0;
}


function dynCall_iiiiiiiiid(index,a1,a2,a3,a4,a5,a6,a7,a8,a9) {
  index = index|0;
  a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=a5|0; a6=a6|0; a7=a7|0; a8=a8|0; a9=+a9;
  return FUNCTION_TABLE_iiiiiiiiid[index&4095](a1|0,a2|0,a3|0,a4|0,a5|0,a6|0,a7|0,a8|0,+a9)|0;
}


function dynCall_ii(index,a1) {
  index = index|0;
  a1=a1|0;
  return FUNCTION_TABLE_ii[index&8191](a1|0)|0;
}


function dynCall_viidiii(index,a1,a2,a3,a4,a5,a6) {
  index = index|0;
  a1=a1|0; a2=a2|0; a3=+a3; a4=a4|0; a5=a5|0; a6=a6|0;
  FUNCTION_TABLE_viidiii[index&4095](a1|0,a2|0,+a3,a4|0,a5|0,a6|0);
}


function dynCall_viidd(index,a1,a2,a3,a4) {
  index = index|0;
  a1=a1|0; a2=a2|0; a3=+a3; a4=+a4;
  FUNCTION_TABLE_viidd[index&4095](a1|0,a2|0,+a3,+a4);
}


function dynCall_iidd(index,a1,a2,a3) {
  index = index|0;
  a1=a1|0; a2=+a2; a3=+a3;
  return FUNCTION_TABLE_iidd[index&1023](a1|0,+a2,+a3)|0;
}


function dynCall_viiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9) {
  index = index|0;
  a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=a5|0; a6=a6|0; a7=a7|0; a8=a8|0; a9=a9|0;
  FUNCTION_TABLE_viiiiiiiii[index&8191](a1|0,a2|0,a3|0,a4|0,a5|0,a6|0,a7|0,a8|0,a9|0);
}


function dynCall_viiiidiii(index,a1,a2,a3,a4,a5,a6,a7,a8) {
  index = index|0;
  a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=+a5; a6=a6|0; a7=a7|0; a8=a8|0;
  FUNCTION_TABLE_viiiidiii[index&4095](a1|0,a2|0,a3|0,a4|0,+a5,a6|0,a7|0,a8|0);
}


function dynCall_viddd(index,a1,a2,a3,a4) {
  index = index|0;
  a1=a1|0; a2=+a2; a3=+a3; a4=+a4;
  FUNCTION_TABLE_viddd[index&8191](a1|0,+a2,+a3,+a4);
}


function dynCall_iiiiii(index,a1,a2,a3,a4,a5) {
  index = index|0;
  a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=a5|0;
  return FUNCTION_TABLE_iiiiii[index&8191](a1|0,a2|0,a3|0,a4|0,a5|0)|0;
}


function dynCall_vidi(index,a1,a2,a3) {
  index = index|0;
  a1=a1|0; a2=+a2; a3=a3|0;
  FUNCTION_TABLE_vidi[index&4095](a1|0,+a2,a3|0);
}


function dynCall_viiidiii(index,a1,a2,a3,a4,a5,a6,a7) {
  index = index|0;
  a1=a1|0; a2=a2|0; a3=a3|0; a4=+a4; a5=a5|0; a6=a6|0; a7=a7|0;
  FUNCTION_TABLE_viiidiii[index&4095](a1|0,a2|0,a3|0,+a4,a5|0,a6|0,a7|0);
}


function dynCall_vdddddd(index,a1,a2,a3,a4,a5,a6) {
  index = index|0;
  a1=+a1; a2=+a2; a3=+a3; a4=+a4; a5=+a5; a6=+a6;
  FUNCTION_TABLE_vdddddd[index&8191](+a1,+a2,+a3,+a4,+a5,+a6);
}


function dynCall_iiiidddd(index,a1,a2,a3,a4,a5,a6,a7) {
  index = index|0;
  a1=a1|0; a2=a2|0; a3=a3|0; a4=+a4; a5=+a5; a6=+a6; a7=+a7;
  return FUNCTION_TABLE_iiiidddd[index&4095](a1|0,a2|0,a3|0,+a4,+a5,+a6,+a7)|0;
}


function dynCall_viddi(index,a1,a2,a3,a4) {
  index = index|0;
  a1=a1|0; a2=+a2; a3=+a3; a4=a4|0;
  FUNCTION_TABLE_viddi[index&4095](a1|0,+a2,+a3,a4|0);
}


function dynCall_vidd(index,a1,a2,a3) {
  index = index|0;
  a1=a1|0; a2=+a2; a3=+a3;
  FUNCTION_TABLE_vidd[index&8191](a1|0,+a2,+a3);
}


function dynCall_iiii(index,a1,a2,a3) {
  index = index|0;
  a1=a1|0; a2=a2|0; a3=a3|0;
  return FUNCTION_TABLE_iiii[index&8191](a1|0,a2|0,a3|0)|0;
}


function dynCall_viiiiiiiiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12,a13,a14,a15) {
  index = index|0;
  a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=a5|0; a6=a6|0; a7=a7|0; a8=a8|0; a9=a9|0; a10=a10|0; a11=a11|0; a12=a12|0; a13=a13|0; a14=a14|0; a15=a15|0;
  FUNCTION_TABLE_viiiiiiiiiiiiiii[index&8191](a1|0,a2|0,a3|0,a4|0,a5|0,a6|0,a7|0,a8|0,a9|0,a10|0,a11|0,a12|0,a13|0,a14|0,a15|0);
}


function dynCall_vi(index,a1) {
  index = index|0;
  a1=a1|0;
  FUNCTION_TABLE_vi[index&8191](a1|0);
}


function dynCall_viiiiii(index,a1,a2,a3,a4,a5,a6) {
  index = index|0;
  a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=a5|0; a6=a6|0;
  FUNCTION_TABLE_viiiiii[index&8191](a1|0,a2|0,a3|0,a4|0,a5|0,a6|0);
}


function dynCall_iiid(index,a1,a2,a3) {
  index = index|0;
  a1=a1|0; a2=a2|0; a3=+a3;
  return FUNCTION_TABLE_iiid[index&4095](a1|0,a2|0,+a3)|0;
}


function dynCall_vdi(index,a1,a2) {
  index = index|0;
  a1=+a1; a2=a2|0;
  FUNCTION_TABLE_vdi[index&8191](+a1,a2|0);
}


function dynCall_viid(index,a1,a2,a3) {
  index = index|0;
  a1=a1|0; a2=a2|0; a3=+a3;
  FUNCTION_TABLE_viid[index&8191](a1|0,a2|0,+a3);
}


function dynCall_viddddd(index,a1,a2,a3,a4,a5,a6) {
  index = index|0;
  a1=a1|0; a2=+a2; a3=+a3; a4=+a4; a5=+a5; a6=+a6;
  FUNCTION_TABLE_viddddd[index&1023](a1|0,+a2,+a3,+a4,+a5,+a6);
}


function dynCall_di(index,a1) {
  index = index|0;
  a1=a1|0;
  return +FUNCTION_TABLE_di[index&8191](a1|0);
}


function dynCall_iiiiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10) {
  index = index|0;
  a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=a5|0; a6=a6|0; a7=a7|0; a8=a8|0; a9=a9|0; a10=a10|0;
  return FUNCTION_TABLE_iiiiiiiiiii[index&8191](a1|0,a2|0,a3|0,a4|0,a5|0,a6|0,a7|0,a8|0,a9|0,a10|0)|0;
}


function dynCall_viiidi(index,a1,a2,a3,a4,a5) {
  index = index|0;
  a1=a1|0; a2=a2|0; a3=a3|0; a4=+a4; a5=a5|0;
  FUNCTION_TABLE_viiidi[index&8191](a1|0,a2|0,a3|0,+a4,a5|0);
}


function dynCall_viiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8) {
  index = index|0;
  a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=a5|0; a6=a6|0; a7=a7|0; a8=a8|0;
  FUNCTION_TABLE_viiiiiiii[index&8191](a1|0,a2|0,a3|0,a4|0,a5|0,a6|0,a7|0,a8|0);
}


function dynCall_vidddd(index,a1,a2,a3,a4,a5) {
  index = index|0;
  a1=a1|0; a2=+a2; a3=+a3; a4=+a4; a5=+a5;
  FUNCTION_TABLE_vidddd[index&8191](a1|0,+a2,+a3,+a4,+a5);
}


function dynCall_iiiiiiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12) {
  index = index|0;
  a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=a5|0; a6=a6|0; a7=a7|0; a8=a8|0; a9=a9|0; a10=a10|0; a11=a11|0; a12=a12|0;
  return FUNCTION_TABLE_iiiiiiiiiiiii[index&8191](a1|0,a2|0,a3|0,a4|0,a5|0,a6|0,a7|0,a8|0,a9|0,a10|0,a11|0,a12|0)|0;
}


function dynCall_iid(index,a1,a2) {
  index = index|0;
  a1=a1|0; a2=+a2;
  return FUNCTION_TABLE_iid[index&4095](a1|0,+a2)|0;
}


function dynCall_viiiiiii(index,a1,a2,a3,a4,a5,a6,a7) {
  index = index|0;
  a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=a5|0; a6=a6|0; a7=a7|0;
  FUNCTION_TABLE_viiiiiii[index&8191](a1|0,a2|0,a3|0,a4|0,a5|0,a6|0,a7|0);
}


function dynCall_iiddd(index,a1,a2,a3,a4) {
  index = index|0;
  a1=a1|0; a2=+a2; a3=+a3; a4=+a4;
  return FUNCTION_TABLE_iiddd[index&1023](a1|0,+a2,+a3,+a4)|0;
}


function dynCall_viiid(index,a1,a2,a3,a4) {
  index = index|0;
  a1=a1|0; a2=a2|0; a3=a3|0; a4=+a4;
  FUNCTION_TABLE_viiid[index&2047](a1|0,a2|0,a3|0,+a4);
}


function dynCall_viiiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10) {
  index = index|0;
  a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=a5|0; a6=a6|0; a7=a7|0; a8=a8|0; a9=a9|0; a10=a10|0;
  FUNCTION_TABLE_viiiiiiiiii[index&8191](a1|0,a2|0,a3|0,a4|0,a5|0,a6|0,a7|0,a8|0,a9|0,a10|0);
}


function dynCall_iii(index,a1,a2) {
  index = index|0;
  a1=a1|0; a2=a2|0;
  return FUNCTION_TABLE_iii[index&8191](a1|0,a2|0)|0;
}


function dynCall_diii(index,a1,a2,a3) {
  index = index|0;
  a1=a1|0; a2=a2|0; a3=a3|0;
  return +FUNCTION_TABLE_diii[index&8191](a1|0,a2|0,a3|0);
}


function dynCall_viiiiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11) {
  index = index|0;
  a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=a5|0; a6=a6|0; a7=a7|0; a8=a8|0; a9=a9|0; a10=a10|0; a11=a11|0;
  FUNCTION_TABLE_viiiiiiiiiii[index&8191](a1|0,a2|0,a3|0,a4|0,a5|0,a6|0,a7|0,a8|0,a9|0,a10|0,a11|0);
}


function dynCall_dii(index,a1,a2) {
  index = index|0;
  a1=a1|0; a2=a2|0;
  return +FUNCTION_TABLE_dii[index&4095](a1|0,a2|0);
}


function dynCall_viii(index,a1,a2,a3) {
  index = index|0;
  a1=a1|0; a2=a2|0; a3=a3|0;
  FUNCTION_TABLE_viii[index&8191](a1|0,a2|0,a3|0);
}


function dynCall_i(index) {
  index = index|0;
  
  return FUNCTION_TABLE_i[index&8191]()|0;
}


function dynCall_iiiiidii(index,a1,a2,a3,a4,a5,a6,a7) {
  index = index|0;
  a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=+a5; a6=a6|0; a7=a7|0;
  return FUNCTION_TABLE_iiiiidii[index&8191](a1|0,a2|0,a3|0,a4|0,+a5,a6|0,a7|0)|0;
}


function dynCall_iiiid(index,a1,a2,a3,a4) {
  index = index|0;
  a1=a1|0; a2=a2|0; a3=a3|0; a4=+a4;
  return FUNCTION_TABLE_iiiid[index&4095](a1|0,a2|0,a3|0,+a4)|0;
}


function dynCall_iiiii(index,a1,a2,a3,a4) {
  index = index|0;
  a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0;
  return FUNCTION_TABLE_iiiii[index&8191](a1|0,a2|0,a3|0,a4|0)|0;
}


function dynCall_iidii(index,a1,a2,a3,a4) {
  index = index|0;
  a1=a1|0; a2=+a2; a3=a3|0; a4=a4|0;
  return FUNCTION_TABLE_iidii[index&0](a1|0,+a2,a3|0,a4|0)|0;
}


function dynCall_iiiiiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11) {
  index = index|0;
  a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=a5|0; a6=a6|0; a7=a7|0; a8=a8|0; a9=a9|0; a10=a10|0; a11=a11|0;
  return FUNCTION_TABLE_iiiiiiiiiiii[index&8191](a1|0,a2|0,a3|0,a4|0,a5|0,a6|0,a7|0,a8|0,a9|0,a10|0,a11|0)|0;
}


function dynCall_vdddd(index,a1,a2,a3,a4) {
  index = index|0;
  a1=+a1; a2=+a2; a3=+a3; a4=+a4;
  FUNCTION_TABLE_vdddd[index&8191](+a1,+a2,+a3,+a4);
}


function dynCall_vdd(index,a1,a2) {
  index = index|0;
  a1=+a1; a2=+a2;
  FUNCTION_TABLE_vdd[index&8191](+a1,+a2);
}


function dynCall_v(index) {
  index = index|0;
  
  FUNCTION_TABLE_v[index&8191]();
}


function dynCall_iiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8) {
  index = index|0;
  a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=a5|0; a6=a6|0; a7=a7|0; a8=a8|0;
  return FUNCTION_TABLE_iiiiiiiii[index&8191](a1|0,a2|0,a3|0,a4|0,a5|0,a6|0,a7|0,a8|0)|0;
}


function dynCall_iiiiid(index,a1,a2,a3,a4,a5) {
  index = index|0;
  a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=+a5;
  return FUNCTION_TABLE_iiiiid[index&4095](a1|0,a2|0,a3|0,a4|0,+a5)|0;
}


function dynCall_viiii(index,a1,a2,a3,a4) {
  index = index|0;
  a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0;
  FUNCTION_TABLE_viiii[index&8191](a1|0,a2|0,a3|0,a4|0);
}

function b0(p0,p1,p2,p3,p4,p5,p6) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0;p6 = p6|0; nullFunc_iiiiiiii(0);return 0;
}
function b1(p0,p1,p2,p3,p4,p5) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = +p5; nullFunc_iiiiiid(1);return 0;
}
function b2(p0) {
 p0 = +p0; nullFunc_vd(2);
}
function _emscripten_glClearDepth__wrapper(p0) {
 p0 = +p0; _emscripten_glClearDepth(+p0);
}
function _emscripten_glClearDepthf__wrapper(p0) {
 p0 = +p0; _emscripten_glClearDepthf(+p0);
}
function _emscripten_glLineWidth__wrapper(p0) {
 p0 = +p0; _emscripten_glLineWidth(+p0);
}
function b3(p0,p1) {
 p0 = p0|0;p1 = +p1; nullFunc_vid(3);
}
function _emscripten_glUniform1f__wrapper(p0,p1) {
 p0 = p0|0;p1 = +p1; _emscripten_glUniform1f(p0|0,+p1);
}
function _emscripten_glVertexAttrib1f__wrapper(p0,p1) {
 p0 = p0|0;p1 = +p1; _emscripten_glVertexAttrib1f(p0|0,+p1);
}
function b4(p0,p1,p2,p3,p4) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0; nullFunc_viiiii(4);
}
function _glShaderBinary__wrapper(p0,p1,p2,p3,p4) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0; _glShaderBinary(p0|0,p1|0,p2|0,p3|0,p4|0);
}
function _emscripten_glUniform4i__wrapper(p0,p1,p2,p3,p4) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0; _emscripten_glUniform4i(p0|0,p1|0,p2|0,p3|0,p4|0);
}
function _emscripten_glFramebufferTexture2D__wrapper(p0,p1,p2,p3,p4) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0; _emscripten_glFramebufferTexture2D(p0|0,p1|0,p2|0,p3|0,p4|0);
}
function _emscripten_glShaderBinary__wrapper(p0,p1,p2,p3,p4) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0; _emscripten_glShaderBinary(p0|0,p1|0,p2|0,p3|0,p4|0);
}
function _emscripten_glDrawElementsInstanced__wrapper(p0,p1,p2,p3,p4) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0; _emscripten_glDrawElementsInstanced(p0|0,p1|0,p2|0,p3|0,p4|0);
}
function b5(p0,p1,p2,p3,p4,p5,p6,p7,p8) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0;p6 = p6|0;p7 = p7|0;p8 = p8|0; nullFunc_iiiiiiiiii(5);return 0;
}
function b6(p0,p1) {
 p0 = p0|0;p1 = p1|0; nullFunc_vii(6);
}
function _glGetIntegerv__wrapper(p0,p1) {
 p0 = p0|0;p1 = p1|0; _glGetIntegerv(p0|0,p1|0);
}
function _glDeleteTextures__wrapper(p0,p1) {
 p0 = p0|0;p1 = p1|0; _glDeleteTextures(p0|0,p1|0);
}
function _emscripten_glPixelStorei__wrapper(p0,p1) {
 p0 = p0|0;p1 = p1|0; _emscripten_glPixelStorei(p0|0,p1|0);
}
function _emscripten_glGetIntegerv__wrapper(p0,p1) {
 p0 = p0|0;p1 = p1|0; _emscripten_glGetIntegerv(p0|0,p1|0);
}
function _emscripten_glGetFloatv__wrapper(p0,p1) {
 p0 = p0|0;p1 = p1|0; _emscripten_glGetFloatv(p0|0,p1|0);
}
function _emscripten_glGetBooleanv__wrapper(p0,p1) {
 p0 = p0|0;p1 = p1|0; _emscripten_glGetBooleanv(p0|0,p1|0);
}
function _emscripten_glGenTextures__wrapper(p0,p1) {
 p0 = p0|0;p1 = p1|0; _emscripten_glGenTextures(p0|0,p1|0);
}
function _emscripten_glDeleteTextures__wrapper(p0,p1) {
 p0 = p0|0;p1 = p1|0; _emscripten_glDeleteTextures(p0|0,p1|0);
}
function _emscripten_glBindTexture__wrapper(p0,p1) {
 p0 = p0|0;p1 = p1|0; _emscripten_glBindTexture(p0|0,p1|0);
}
function _emscripten_glGenBuffers__wrapper(p0,p1) {
 p0 = p0|0;p1 = p1|0; _emscripten_glGenBuffers(p0|0,p1|0);
}
function _emscripten_glDeleteBuffers__wrapper(p0,p1) {
 p0 = p0|0;p1 = p1|0; _emscripten_glDeleteBuffers(p0|0,p1|0);
}
function _emscripten_glGenRenderbuffers__wrapper(p0,p1) {
 p0 = p0|0;p1 = p1|0; _emscripten_glGenRenderbuffers(p0|0,p1|0);
}
function _emscripten_glDeleteRenderbuffers__wrapper(p0,p1) {
 p0 = p0|0;p1 = p1|0; _emscripten_glDeleteRenderbuffers(p0|0,p1|0);
}
function _emscripten_glBindRenderbuffer__wrapper(p0,p1) {
 p0 = p0|0;p1 = p1|0; _emscripten_glBindRenderbuffer(p0|0,p1|0);
}
function _emscripten_glUniform1i__wrapper(p0,p1) {
 p0 = p0|0;p1 = p1|0; _emscripten_glUniform1i(p0|0,p1|0);
}
function _emscripten_glBindBuffer__wrapper(p0,p1) {
 p0 = p0|0;p1 = p1|0; _emscripten_glBindBuffer(p0|0,p1|0);
}
function _emscripten_glVertexAttrib1fv__wrapper(p0,p1) {
 p0 = p0|0;p1 = p1|0; _emscripten_glVertexAttrib1fv(p0|0,p1|0);
}
function _emscripten_glVertexAttrib2fv__wrapper(p0,p1) {
 p0 = p0|0;p1 = p1|0; _emscripten_glVertexAttrib2fv(p0|0,p1|0);
}
function _emscripten_glVertexAttrib3fv__wrapper(p0,p1) {
 p0 = p0|0;p1 = p1|0; _emscripten_glVertexAttrib3fv(p0|0,p1|0);
}
function _emscripten_glVertexAttrib4fv__wrapper(p0,p1) {
 p0 = p0|0;p1 = p1|0; _emscripten_glVertexAttrib4fv(p0|0,p1|0);
}
function _emscripten_glAttachShader__wrapper(p0,p1) {
 p0 = p0|0;p1 = p1|0; _emscripten_glAttachShader(p0|0,p1|0);
}
function _emscripten_glDetachShader__wrapper(p0,p1) {
 p0 = p0|0;p1 = p1|0; _emscripten_glDetachShader(p0|0,p1|0);
}
function _emscripten_glBindFramebuffer__wrapper(p0,p1) {
 p0 = p0|0;p1 = p1|0; _emscripten_glBindFramebuffer(p0|0,p1|0);
}
function _emscripten_glGenFramebuffers__wrapper(p0,p1) {
 p0 = p0|0;p1 = p1|0; _emscripten_glGenFramebuffers(p0|0,p1|0);
}
function _emscripten_glDeleteFramebuffers__wrapper(p0,p1) {
 p0 = p0|0;p1 = p1|0; _emscripten_glDeleteFramebuffers(p0|0,p1|0);
}
function _emscripten_glBindProgramARB__wrapper(p0,p1) {
 p0 = p0|0;p1 = p1|0; _emscripten_glBindProgramARB(p0|0,p1|0);
}
function _emscripten_glGetPointerv__wrapper(p0,p1) {
 p0 = p0|0;p1 = p1|0; _emscripten_glGetPointerv(p0|0,p1|0);
}
function _emscripten_glGenVertexArrays__wrapper(p0,p1) {
 p0 = p0|0;p1 = p1|0; _emscripten_glGenVertexArrays(p0|0,p1|0);
}
function _emscripten_glDeleteVertexArrays__wrapper(p0,p1) {
 p0 = p0|0;p1 = p1|0; _emscripten_glDeleteVertexArrays(p0|0,p1|0);
}
function _emscripten_glVertexAttribDivisor__wrapper(p0,p1) {
 p0 = p0|0;p1 = p1|0; _emscripten_glVertexAttribDivisor(p0|0,p1|0);
}
function _emscripten_glBlendFunc__wrapper(p0,p1) {
 p0 = p0|0;p1 = p1|0; _emscripten_glBlendFunc(p0|0,p1|0);
}
function _emscripten_glBlendEquationSeparate__wrapper(p0,p1) {
 p0 = p0|0;p1 = p1|0; _emscripten_glBlendEquationSeparate(p0|0,p1|0);
}
function _emscripten_glStencilMaskSeparate__wrapper(p0,p1) {
 p0 = p0|0;p1 = p1|0; _emscripten_glStencilMaskSeparate(p0|0,p1|0);
}
function _emscripten_glHint__wrapper(p0,p1) {
 p0 = p0|0;p1 = p1|0; _emscripten_glHint(p0|0,p1|0);
}
function _emscripten_glDrawBuffers__wrapper(p0,p1) {
 p0 = p0|0;p1 = p1|0; _emscripten_glDrawBuffers(p0|0,p1|0);
}
function b7(p0,p1,p2,p3,p4,p5) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0; nullFunc_iiiiiii(7);return 0;
}
function b8(p0,p1,p2,p3,p4,p5,p6,p7,p8) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0;p6 = p6|0;p7 = p7|0;p8 = +p8; nullFunc_iiiiiiiiid(8);return 0;
}
function b9(p0) {
 p0 = p0|0; nullFunc_ii(9);return 0;
}
function _glGetString__wrapper(p0) {
 p0 = p0|0; return _glGetString(p0|0)|0;
}
function _eglGetProcAddress__wrapper(p0) {
 p0 = p0|0; return _eglGetProcAddress(p0|0)|0;
}
function _pthread_mutex_destroy__wrapper(p0) {
 p0 = p0|0; return _pthread_mutex_destroy(p0|0)|0;
}
function _pthread_cond_destroy__wrapper(p0) {
 p0 = p0|0; return _pthread_cond_destroy(p0|0)|0;
}
function _time__wrapper(p0) {
 p0 = p0|0; return _time(p0|0)|0;
}
function _dlclose__wrapper(p0) {
 p0 = p0|0; return _dlclose(p0|0)|0;
}
function _eglGetDisplay__wrapper(p0) {
 p0 = p0|0; return _eglGetDisplay(p0|0)|0;
}
function _eglTerminate__wrapper(p0) {
 p0 = p0|0; return _eglTerminate(p0|0)|0;
}
function _eglWaitNative__wrapper(p0) {
 p0 = p0|0; return _eglWaitNative(p0|0)|0;
}
function _eglBindAPI__wrapper(p0) {
 p0 = p0|0; return _eglBindAPI(p0|0)|0;
}
function _emscripten_glGetString__wrapper(p0) {
 p0 = p0|0; return _emscripten_glGetString(p0|0)|0;
}
function _emscripten_glIsTexture__wrapper(p0) {
 p0 = p0|0; return _emscripten_glIsTexture(p0|0)|0;
}
function _emscripten_glIsBuffer__wrapper(p0) {
 p0 = p0|0; return _emscripten_glIsBuffer(p0|0)|0;
}
function _emscripten_glIsRenderbuffer__wrapper(p0) {
 p0 = p0|0; return _emscripten_glIsRenderbuffer(p0|0)|0;
}
function _emscripten_glCreateShader__wrapper(p0) {
 p0 = p0|0; return _emscripten_glCreateShader(p0|0)|0;
}
function _emscripten_glIsShader__wrapper(p0) {
 p0 = p0|0; return _emscripten_glIsShader(p0|0)|0;
}
function _emscripten_glIsProgram__wrapper(p0) {
 p0 = p0|0; return _emscripten_glIsProgram(p0|0)|0;
}
function _emscripten_glIsFramebuffer__wrapper(p0) {
 p0 = p0|0; return _emscripten_glIsFramebuffer(p0|0)|0;
}
function _emscripten_glCheckFramebufferStatus__wrapper(p0) {
 p0 = p0|0; return _emscripten_glCheckFramebufferStatus(p0|0)|0;
}
function _emscripten_glIsEnabled__wrapper(p0) {
 p0 = p0|0; return _emscripten_glIsEnabled(p0|0)|0;
}
function _pthread_mutex_unlock__wrapper(p0) {
 p0 = p0|0; return _pthread_mutex_unlock(p0|0)|0;
}
function _pthread_mutex_lock__wrapper(p0) {
 p0 = p0|0; return _pthread_mutex_lock(p0|0)|0;
}
function _pthread_cond_broadcast__wrapper(p0) {
 p0 = p0|0; return _pthread_cond_broadcast(p0|0)|0;
}
function b10(p0,p1,p2,p3,p4,p5) {
 p0 = p0|0;p1 = p1|0;p2 = +p2;p3 = p3|0;p4 = p4|0;p5 = p5|0; nullFunc_viidiii(10);
}
function b11(p0,p1,p2,p3) {
 p0 = p0|0;p1 = p1|0;p2 = +p2;p3 = +p3; nullFunc_viidd(11);
}
function b12(p0,p1,p2) {
 p0 = p0|0;p1 = +p1;p2 = +p2; nullFunc_iidd(12);return 0;
}
function b13(p0,p1,p2,p3,p4,p5,p6,p7,p8) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0;p6 = p6|0;p7 = p7|0;p8 = p8|0; nullFunc_viiiiiiiii(13);
}
function _emscripten_glCompressedTexSubImage2D__wrapper(p0,p1,p2,p3,p4,p5,p6,p7,p8) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0;p6 = p6|0;p7 = p7|0;p8 = p8|0; _emscripten_glCompressedTexSubImage2D(p0|0,p1|0,p2|0,p3|0,p4|0,p5|0,p6|0,p7|0,p8|0);
}
function _emscripten_glTexImage2D__wrapper(p0,p1,p2,p3,p4,p5,p6,p7,p8) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0;p6 = p6|0;p7 = p7|0;p8 = p8|0; _emscripten_glTexImage2D(p0|0,p1|0,p2|0,p3|0,p4|0,p5|0,p6|0,p7|0,p8|0);
}
function _emscripten_glTexSubImage2D__wrapper(p0,p1,p2,p3,p4,p5,p6,p7,p8) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0;p6 = p6|0;p7 = p7|0;p8 = p8|0; _emscripten_glTexSubImage2D(p0|0,p1|0,p2|0,p3|0,p4|0,p5|0,p6|0,p7|0,p8|0);
}
function b14(p0,p1,p2,p3,p4,p5,p6,p7) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = +p4;p5 = p5|0;p6 = p6|0;p7 = p7|0; nullFunc_viiiidiii(14);
}
function b15(p0,p1,p2,p3) {
 p0 = p0|0;p1 = +p1;p2 = +p2;p3 = +p3; nullFunc_viddd(15);
}
function _emscripten_glUniform3f__wrapper(p0,p1,p2,p3) {
 p0 = p0|0;p1 = +p1;p2 = +p2;p3 = +p3; _emscripten_glUniform3f(p0|0,+p1,+p2,+p3);
}
function _emscripten_glVertexAttrib3f__wrapper(p0,p1,p2,p3) {
 p0 = p0|0;p1 = +p1;p2 = +p2;p3 = +p3; _emscripten_glVertexAttrib3f(p0|0,+p1,+p2,+p3);
}
function b16(p0,p1,p2,p3,p4) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0; nullFunc_iiiiii(16);return 0;
}
function _eglChooseConfig__wrapper(p0,p1,p2,p3,p4) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0; return _eglChooseConfig(p0|0,p1|0,p2|0,p3|0,p4|0)|0;
}
function b17(p0,p1,p2) {
 p0 = p0|0;p1 = +p1;p2 = p2|0; nullFunc_vidi(17);
}
function b18(p0,p1,p2,p3,p4,p5,p6) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = +p3;p4 = p4|0;p5 = p5|0;p6 = p6|0; nullFunc_viiidiii(18);
}
function b19(p0,p1,p2,p3,p4,p5) {
 p0 = +p0;p1 = +p1;p2 = +p2;p3 = +p3;p4 = +p4;p5 = +p5; nullFunc_vdddddd(19);
}
function _emscripten_glFrustum__wrapper(p0,p1,p2,p3,p4,p5) {
 p0 = +p0;p1 = +p1;p2 = +p2;p3 = +p3;p4 = +p4;p5 = +p5; _emscripten_glFrustum(+p0,+p1,+p2,+p3,+p4,+p5);
}
function b20(p0,p1,p2,p3,p4,p5,p6) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = +p3;p4 = +p4;p5 = +p5;p6 = +p6; nullFunc_iiiidddd(20);return 0;
}
function b21(p0,p1,p2,p3) {
 p0 = p0|0;p1 = +p1;p2 = +p2;p3 = p3|0; nullFunc_viddi(21);
}
function b22(p0,p1,p2) {
 p0 = p0|0;p1 = +p1;p2 = +p2; nullFunc_vidd(22);
}
function _emscripten_glUniform2f__wrapper(p0,p1,p2) {
 p0 = p0|0;p1 = +p1;p2 = +p2; _emscripten_glUniform2f(p0|0,+p1,+p2);
}
function _emscripten_glVertexAttrib2f__wrapper(p0,p1,p2) {
 p0 = p0|0;p1 = +p1;p2 = +p2; _emscripten_glVertexAttrib2f(p0|0,+p1,+p2);
}
function b23(p0,p1,p2) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0; nullFunc_iiii(23);return 0;
}
function _eglInitialize__wrapper(p0,p1,p2) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0; return _eglInitialize(p0|0,p1|0,p2|0)|0;
}
function b24(p0,p1,p2,p3,p4,p5,p6,p7,p8,p9,p10,p11,p12,p13,p14) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0;p6 = p6|0;p7 = p7|0;p8 = p8|0;p9 = p9|0;p10 = p10|0;p11 = p11|0;p12 = p12|0;p13 = p13|0;p14 = p14|0; nullFunc_viiiiiiiiiiiiiii(24);
}
function b25(p0) {
 p0 = p0|0; nullFunc_vi(25);
}
function _glEnable__wrapper(p0) {
 p0 = p0|0; _glEnable(p0|0);
}
function _glClear__wrapper(p0) {
 p0 = p0|0; _glClear(p0|0);
}
function _glDisable__wrapper(p0) {
 p0 = p0|0; _glDisable(p0|0);
}
function _emscripten_glDeleteShader__wrapper(p0) {
 p0 = p0|0; _emscripten_glDeleteShader(p0|0);
}
function _emscripten_glCompileShader__wrapper(p0) {
 p0 = p0|0; _emscripten_glCompileShader(p0|0);
}
function _emscripten_glDeleteProgram__wrapper(p0) {
 p0 = p0|0; _emscripten_glDeleteProgram(p0|0);
}
function _emscripten_glLinkProgram__wrapper(p0) {
 p0 = p0|0; _emscripten_glLinkProgram(p0|0);
}
function _emscripten_glUseProgram__wrapper(p0) {
 p0 = p0|0; _emscripten_glUseProgram(p0|0);
}
function _emscripten_glValidateProgram__wrapper(p0) {
 p0 = p0|0; _emscripten_glValidateProgram(p0|0);
}
function _emscripten_glDeleteObjectARB__wrapper(p0) {
 p0 = p0|0; _emscripten_glDeleteObjectARB(p0|0);
}
function _emscripten_glEnableClientState__wrapper(p0) {
 p0 = p0|0; _emscripten_glEnableClientState(p0|0);
}
function _emscripten_glClientActiveTexture__wrapper(p0) {
 p0 = p0|0; _emscripten_glClientActiveTexture(p0|0);
}
function _emscripten_glBindVertexArray__wrapper(p0) {
 p0 = p0|0; _emscripten_glBindVertexArray(p0|0);
}
function _emscripten_glMatrixMode__wrapper(p0) {
 p0 = p0|0; _emscripten_glMatrixMode(p0|0);
}
function _emscripten_glLoadMatrixf__wrapper(p0) {
 p0 = p0|0; _emscripten_glLoadMatrixf(p0|0);
}
function _emscripten_glEnableVertexAttribArray__wrapper(p0) {
 p0 = p0|0; _emscripten_glEnableVertexAttribArray(p0|0);
}
function _emscripten_glDisableVertexAttribArray__wrapper(p0) {
 p0 = p0|0; _emscripten_glDisableVertexAttribArray(p0|0);
}
function _emscripten_glDepthFunc__wrapper(p0) {
 p0 = p0|0; _emscripten_glDepthFunc(p0|0);
}
function _emscripten_glEnable__wrapper(p0) {
 p0 = p0|0; _emscripten_glEnable(p0|0);
}
function _emscripten_glDisable__wrapper(p0) {
 p0 = p0|0; _emscripten_glDisable(p0|0);
}
function _emscripten_glFrontFace__wrapper(p0) {
 p0 = p0|0; _emscripten_glFrontFace(p0|0);
}
function _emscripten_glCullFace__wrapper(p0) {
 p0 = p0|0; _emscripten_glCullFace(p0|0);
}
function _emscripten_glClear__wrapper(p0) {
 p0 = p0|0; _emscripten_glClear(p0|0);
}
function _emscripten_glClearStencil__wrapper(p0) {
 p0 = p0|0; _emscripten_glClearStencil(p0|0);
}
function _emscripten_glDepthMask__wrapper(p0) {
 p0 = p0|0; _emscripten_glDepthMask(p0|0);
}
function _emscripten_glStencilMask__wrapper(p0) {
 p0 = p0|0; _emscripten_glStencilMask(p0|0);
}
function _emscripten_glGenerateMipmap__wrapper(p0) {
 p0 = p0|0; _emscripten_glGenerateMipmap(p0|0);
}
function _emscripten_glActiveTexture__wrapper(p0) {
 p0 = p0|0; _emscripten_glActiveTexture(p0|0);
}
function _emscripten_glBlendEquation__wrapper(p0) {
 p0 = p0|0; _emscripten_glBlendEquation(p0|0);
}
function b26(p0,p1,p2,p3,p4,p5) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0; nullFunc_viiiiii(26);
}
function _emscripten_glDrawRangeElements__wrapper(p0,p1,p2,p3,p4,p5) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0; _emscripten_glDrawRangeElements(p0|0,p1|0,p2|0,p3|0,p4|0,p5|0);
}
function _emscripten_glVertexAttribPointer__wrapper(p0,p1,p2,p3,p4,p5) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0; _emscripten_glVertexAttribPointer(p0|0,p1|0,p2|0,p3|0,p4|0,p5|0);
}
function b27(p0,p1,p2) {
 p0 = p0|0;p1 = p1|0;p2 = +p2; nullFunc_iiid(27);return 0;
}
function b28(p0,p1) {
 p0 = +p0;p1 = p1|0; nullFunc_vdi(28);
}
function _emscripten_glSampleCoverage__wrapper(p0,p1) {
 p0 = +p0;p1 = p1|0; _emscripten_glSampleCoverage(+p0,p1|0);
}
function b29(p0,p1,p2) {
 p0 = p0|0;p1 = p1|0;p2 = +p2; nullFunc_viid(29);
}
function _emscripten_glTexParameterf__wrapper(p0,p1,p2) {
 p0 = p0|0;p1 = p1|0;p2 = +p2; _emscripten_glTexParameterf(p0|0,p1|0,+p2);
}
function b30(p0,p1,p2,p3,p4,p5) {
 p0 = p0|0;p1 = +p1;p2 = +p2;p3 = +p3;p4 = +p4;p5 = +p5; nullFunc_viddddd(30);
}
function b31(p0) {
 p0 = p0|0; nullFunc_di(31);return +0;
}
function b32(p0,p1,p2,p3,p4,p5,p6,p7,p8,p9) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0;p6 = p6|0;p7 = p7|0;p8 = p8|0;p9 = p9|0; nullFunc_iiiiiiiiiii(32);return 0;
}
function b33(p0,p1,p2,p3,p4) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = +p3;p4 = p4|0; nullFunc_viiidi(33);
}
function b34(p0,p1,p2,p3,p4,p5,p6,p7) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0;p6 = p6|0;p7 = p7|0; nullFunc_viiiiiiii(34);
}
function _emscripten_glCompressedTexImage2D__wrapper(p0,p1,p2,p3,p4,p5,p6,p7) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0;p6 = p6|0;p7 = p7|0; _emscripten_glCompressedTexImage2D(p0|0,p1|0,p2|0,p3|0,p4|0,p5|0,p6|0,p7|0);
}
function _emscripten_glCopyTexImage2D__wrapper(p0,p1,p2,p3,p4,p5,p6,p7) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0;p6 = p6|0;p7 = p7|0; _emscripten_glCopyTexImage2D(p0|0,p1|0,p2|0,p3|0,p4|0,p5|0,p6|0,p7|0);
}
function _emscripten_glCopyTexSubImage2D__wrapper(p0,p1,p2,p3,p4,p5,p6,p7) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0;p6 = p6|0;p7 = p7|0; _emscripten_glCopyTexSubImage2D(p0|0,p1|0,p2|0,p3|0,p4|0,p5|0,p6|0,p7|0);
}
function b35(p0,p1,p2,p3,p4) {
 p0 = p0|0;p1 = +p1;p2 = +p2;p3 = +p3;p4 = +p4; nullFunc_vidddd(35);
}
function _emscripten_glUniform4f__wrapper(p0,p1,p2,p3,p4) {
 p0 = p0|0;p1 = +p1;p2 = +p2;p3 = +p3;p4 = +p4; _emscripten_glUniform4f(p0|0,+p1,+p2,+p3,+p4);
}
function _emscripten_glVertexAttrib4f__wrapper(p0,p1,p2,p3,p4) {
 p0 = p0|0;p1 = +p1;p2 = +p2;p3 = +p3;p4 = +p4; _emscripten_glVertexAttrib4f(p0|0,+p1,+p2,+p3,+p4);
}
function b36(p0,p1,p2,p3,p4,p5,p6,p7,p8,p9,p10,p11) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0;p6 = p6|0;p7 = p7|0;p8 = p8|0;p9 = p9|0;p10 = p10|0;p11 = p11|0; nullFunc_iiiiiiiiiiiii(36);return 0;
}
function b37(p0,p1) {
 p0 = p0|0;p1 = +p1; nullFunc_iid(37);return 0;
}
function b38(p0,p1,p2,p3,p4,p5,p6) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0;p6 = p6|0; nullFunc_viiiiiii(38);
}
function _emscripten_glReadPixels__wrapper(p0,p1,p2,p3,p4,p5,p6) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0;p6 = p6|0; _emscripten_glReadPixels(p0|0,p1|0,p2|0,p3|0,p4|0,p5|0,p6|0);
}
function _emscripten_glGetActiveUniform__wrapper(p0,p1,p2,p3,p4,p5,p6) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0;p6 = p6|0; _emscripten_glGetActiveUniform(p0|0,p1|0,p2|0,p3|0,p4|0,p5|0,p6|0);
}
function _emscripten_glGetActiveAttrib__wrapper(p0,p1,p2,p3,p4,p5,p6) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0;p6 = p6|0; _emscripten_glGetActiveAttrib(p0|0,p1|0,p2|0,p3|0,p4|0,p5|0,p6|0);
}
function b39(p0,p1,p2,p3) {
 p0 = p0|0;p1 = +p1;p2 = +p2;p3 = +p3; nullFunc_iiddd(39);return 0;
}
function b40(p0,p1,p2,p3) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = +p3; nullFunc_viiid(40);
}
function b41(p0,p1,p2,p3,p4,p5,p6,p7,p8,p9) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0;p6 = p6|0;p7 = p7|0;p8 = p8|0;p9 = p9|0; nullFunc_viiiiiiiiii(41);
}
function b42(p0,p1) {
 p0 = p0|0;p1 = p1|0; nullFunc_iii(42);return 0;
}
function _clock_gettime__wrapper(p0,p1) {
 p0 = p0|0;p1 = p1|0; return _clock_gettime(p0|0,p1|0)|0;
}
function _dlopen__wrapper(p0,p1) {
 p0 = p0|0;p1 = p1|0; return _dlopen(p0|0,p1|0)|0;
}
function _eglDestroyContext__wrapper(p0,p1) {
 p0 = p0|0;p1 = p1|0; return _eglDestroyContext(p0|0,p1|0)|0;
}
function _eglDestroySurface__wrapper(p0,p1) {
 p0 = p0|0;p1 = p1|0; return _eglDestroySurface(p0|0,p1|0)|0;
}
function _eglSwapBuffers__wrapper(p0,p1) {
 p0 = p0|0;p1 = p1|0; return _eglSwapBuffers(p0|0,p1|0)|0;
}
function _eglSwapInterval__wrapper(p0,p1) {
 p0 = p0|0;p1 = p1|0; return _eglSwapInterval(p0|0,p1|0)|0;
}
function _emscripten_glGetUniformLocation__wrapper(p0,p1) {
 p0 = p0|0;p1 = p1|0; return _emscripten_glGetUniformLocation(p0|0,p1|0)|0;
}
function _emscripten_glGetAttribLocation__wrapper(p0,p1) {
 p0 = p0|0;p1 = p1|0; return _emscripten_glGetAttribLocation(p0|0,p1|0)|0;
}
function b43(p0,p1,p2) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0; nullFunc_diii(43);return +0;
}
function b44(p0,p1,p2,p3,p4,p5,p6,p7,p8,p9,p10) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0;p6 = p6|0;p7 = p7|0;p8 = p8|0;p9 = p9|0;p10 = p10|0; nullFunc_viiiiiiiiiii(44);
}
function b45(p0,p1) {
 p0 = p0|0;p1 = p1|0; nullFunc_dii(45);return +0;
}
function b46(p0,p1,p2) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0; nullFunc_viii(46);
}
function ___cxa_throw__wrapper(p0,p1,p2) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0; ___cxa_throw(p0|0,p1|0,p2|0);
}
function _emscripten_glGetTexParameterfv__wrapper(p0,p1,p2) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0; _emscripten_glGetTexParameterfv(p0|0,p1|0,p2|0);
}
function _emscripten_glGetTexParameteriv__wrapper(p0,p1,p2) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0; _emscripten_glGetTexParameteriv(p0|0,p1|0,p2|0);
}
function _emscripten_glTexParameterfv__wrapper(p0,p1,p2) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0; _emscripten_glTexParameterfv(p0|0,p1|0,p2|0);
}
function _emscripten_glTexParameteriv__wrapper(p0,p1,p2) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0; _emscripten_glTexParameteriv(p0|0,p1|0,p2|0);
}
function _emscripten_glGetBufferParameteriv__wrapper(p0,p1,p2) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0; _emscripten_glGetBufferParameteriv(p0|0,p1|0,p2|0);
}
function _emscripten_glGetRenderbufferParameteriv__wrapper(p0,p1,p2) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0; _emscripten_glGetRenderbufferParameteriv(p0|0,p1|0,p2|0);
}
function _emscripten_glGetUniformfv__wrapper(p0,p1,p2) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0; _emscripten_glGetUniformfv(p0|0,p1|0,p2|0);
}
function _emscripten_glGetUniformiv__wrapper(p0,p1,p2) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0; _emscripten_glGetUniformiv(p0|0,p1|0,p2|0);
}
function _emscripten_glGetVertexAttribfv__wrapper(p0,p1,p2) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0; _emscripten_glGetVertexAttribfv(p0|0,p1|0,p2|0);
}
function _emscripten_glGetVertexAttribiv__wrapper(p0,p1,p2) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0; _emscripten_glGetVertexAttribiv(p0|0,p1|0,p2|0);
}
function _emscripten_glGetVertexAttribPointerv__wrapper(p0,p1,p2) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0; _emscripten_glGetVertexAttribPointerv(p0|0,p1|0,p2|0);
}
function _emscripten_glUniform2i__wrapper(p0,p1,p2) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0; _emscripten_glUniform2i(p0|0,p1|0,p2|0);
}
function _emscripten_glUniform1iv__wrapper(p0,p1,p2) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0; _emscripten_glUniform1iv(p0|0,p1|0,p2|0);
}
function _emscripten_glUniform2iv__wrapper(p0,p1,p2) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0; _emscripten_glUniform2iv(p0|0,p1|0,p2|0);
}
function _emscripten_glUniform3iv__wrapper(p0,p1,p2) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0; _emscripten_glUniform3iv(p0|0,p1|0,p2|0);
}
function _emscripten_glUniform4iv__wrapper(p0,p1,p2) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0; _emscripten_glUniform4iv(p0|0,p1|0,p2|0);
}
function _emscripten_glUniform1fv__wrapper(p0,p1,p2) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0; _emscripten_glUniform1fv(p0|0,p1|0,p2|0);
}
function _emscripten_glUniform2fv__wrapper(p0,p1,p2) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0; _emscripten_glUniform2fv(p0|0,p1|0,p2|0);
}
function _emscripten_glUniform3fv__wrapper(p0,p1,p2) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0; _emscripten_glUniform3fv(p0|0,p1|0,p2|0);
}
function _emscripten_glUniform4fv__wrapper(p0,p1,p2) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0; _emscripten_glUniform4fv(p0|0,p1|0,p2|0);
}
function _emscripten_glGetShaderiv__wrapper(p0,p1,p2) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0; _emscripten_glGetShaderiv(p0|0,p1|0,p2|0);
}
function _emscripten_glGetProgramiv__wrapper(p0,p1,p2) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0; _emscripten_glGetProgramiv(p0|0,p1|0,p2|0);
}
function _emscripten_glBindAttribLocation__wrapper(p0,p1,p2) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0; _emscripten_glBindAttribLocation(p0|0,p1|0,p2|0);
}
function _emscripten_glGetObjectParameterivARB__wrapper(p0,p1,p2) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0; _emscripten_glGetObjectParameterivARB(p0|0,p1|0,p2|0);
}
function _emscripten_glNormalPointer__wrapper(p0,p1,p2) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0; _emscripten_glNormalPointer(p0|0,p1|0,p2|0);
}
function _emscripten_glDrawArrays__wrapper(p0,p1,p2) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0; _emscripten_glDrawArrays(p0|0,p1|0,p2|0);
}
function _emscripten_glTexParameteri__wrapper(p0,p1,p2) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0; _emscripten_glTexParameteri(p0|0,p1|0,p2|0);
}
function _emscripten_glStencilFunc__wrapper(p0,p1,p2) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0; _emscripten_glStencilFunc(p0|0,p1|0,p2|0);
}
function _emscripten_glStencilOp__wrapper(p0,p1,p2) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0; _emscripten_glStencilOp(p0|0,p1|0,p2|0);
}
function b47() {
 ; nullFunc_i(47);return 0;
}
function _glGetError__wrapper() {
 ; return _glGetError()|0;
}
function _dlerror__wrapper() {
 ; return _dlerror()|0;
}
function _eglWaitGL__wrapper() {
 ; return _eglWaitGL()|0;
}
function _emscripten_glCreateProgram__wrapper() {
 ; return _emscripten_glCreateProgram()|0;
}
function _emscripten_glGetError__wrapper() {
 ; return _emscripten_glGetError()|0;
}
function b48(p0,p1,p2,p3,p4,p5,p6) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = +p4;p5 = p5|0;p6 = p6|0; nullFunc_iiiiidii(48);return 0;
}
function b49(p0,p1,p2,p3) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = +p3; nullFunc_iiiid(49);return 0;
}
function b50(p0,p1,p2,p3) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; nullFunc_iiiii(50);return 0;
}
function _eglGetConfigAttrib__wrapper(p0,p1,p2,p3) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; return _eglGetConfigAttrib(p0|0,p1|0,p2|0,p3|0)|0;
}
function _eglCreateContext__wrapper(p0,p1,p2,p3) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; return _eglCreateContext(p0|0,p1|0,p2|0,p3|0)|0;
}
function _eglCreateWindowSurface__wrapper(p0,p1,p2,p3) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; return _eglCreateWindowSurface(p0|0,p1|0,p2|0,p3|0)|0;
}
function _eglMakeCurrent__wrapper(p0,p1,p2,p3) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; return _eglMakeCurrent(p0|0,p1|0,p2|0,p3|0)|0;
}
function b51(p0,p1,p2,p3) {
 p0 = p0|0;p1 = +p1;p2 = p2|0;p3 = p3|0; nullFunc_iidii(51);return 0;
}
function b52(p0,p1,p2,p3,p4,p5,p6,p7,p8,p9,p10) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0;p6 = p6|0;p7 = p7|0;p8 = p8|0;p9 = p9|0;p10 = p10|0; nullFunc_iiiiiiiiiiii(52);return 0;
}
function b53(p0,p1,p2,p3) {
 p0 = +p0;p1 = +p1;p2 = +p2;p3 = +p3; nullFunc_vdddd(53);
}
function _glClearColor__wrapper(p0,p1,p2,p3) {
 p0 = +p0;p1 = +p1;p2 = +p2;p3 = +p3; _glClearColor(+p0,+p1,+p2,+p3);
}
function _emscripten_glRotatef__wrapper(p0,p1,p2,p3) {
 p0 = +p0;p1 = +p1;p2 = +p2;p3 = +p3; _emscripten_glRotatef(+p0,+p1,+p2,+p3);
}
function _emscripten_glClearColor__wrapper(p0,p1,p2,p3) {
 p0 = +p0;p1 = +p1;p2 = +p2;p3 = +p3; _emscripten_glClearColor(+p0,+p1,+p2,+p3);
}
function _emscripten_glBlendColor__wrapper(p0,p1,p2,p3) {
 p0 = +p0;p1 = +p1;p2 = +p2;p3 = +p3; _emscripten_glBlendColor(+p0,+p1,+p2,+p3);
}
function b54(p0,p1) {
 p0 = +p0;p1 = +p1; nullFunc_vdd(54);
}
function _emscripten_glDepthRange__wrapper(p0,p1) {
 p0 = +p0;p1 = +p1; _emscripten_glDepthRange(+p0,+p1);
}
function _emscripten_glDepthRangef__wrapper(p0,p1) {
 p0 = +p0;p1 = +p1; _emscripten_glDepthRangef(+p0,+p1);
}
function _emscripten_glPolygonOffset__wrapper(p0,p1) {
 p0 = +p0;p1 = +p1; _emscripten_glPolygonOffset(+p0,+p1);
}
function b55() {
 ; nullFunc_v(55);
}
function ___cxa_pure_virtual__wrapper() {
 ; ___cxa_pure_virtual();
}
function ___cxa_end_catch__wrapper() {
 ; ___cxa_end_catch();
}
function ___cxa_rethrow__wrapper() {
 ; ___cxa_rethrow();
}
function _glFlush__wrapper() {
 ; _glFlush();
}
function _emscripten_glLoadIdentity__wrapper() {
 ; _emscripten_glLoadIdentity();
}
function _emscripten_glReleaseShaderCompiler__wrapper() {
 ; _emscripten_glReleaseShaderCompiler();
}
function _emscripten_glFinish__wrapper() {
 ; _emscripten_glFinish();
}
function _emscripten_glFlush__wrapper() {
 ; _emscripten_glFlush();
}
function b56(p0,p1,p2,p3,p4,p5,p6,p7) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0;p6 = p6|0;p7 = p7|0; nullFunc_iiiiiiiii(56);return 0;
}
function b57(p0,p1,p2,p3,p4) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = +p4; nullFunc_iiiiid(57);return 0;
}
function b58(p0,p1,p2,p3) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; nullFunc_viiii(58);
}
function _glScissor__wrapper(p0,p1,p2,p3) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; _glScissor(p0|0,p1|0,p2|0,p3|0);
}
function _glColorMask__wrapper(p0,p1,p2,p3) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; _glColorMask(p0|0,p1|0,p2|0,p3|0);
}
function _emscripten_glBufferData__wrapper(p0,p1,p2,p3) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; _emscripten_glBufferData(p0|0,p1|0,p2|0,p3|0);
}
function _emscripten_glBufferSubData__wrapper(p0,p1,p2,p3) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; _emscripten_glBufferSubData(p0|0,p1|0,p2|0,p3|0);
}
function _emscripten_glUniform3i__wrapper(p0,p1,p2,p3) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; _emscripten_glUniform3i(p0|0,p1|0,p2|0,p3|0);
}
function _emscripten_glUniformMatrix2fv__wrapper(p0,p1,p2,p3) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; _emscripten_glUniformMatrix2fv(p0|0,p1|0,p2|0,p3|0);
}
function _emscripten_glUniformMatrix3fv__wrapper(p0,p1,p2,p3) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; _emscripten_glUniformMatrix3fv(p0|0,p1|0,p2|0,p3|0);
}
function _emscripten_glUniformMatrix4fv__wrapper(p0,p1,p2,p3) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; _emscripten_glUniformMatrix4fv(p0|0,p1|0,p2|0,p3|0);
}
function _emscripten_glGetAttachedShaders__wrapper(p0,p1,p2,p3) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; _emscripten_glGetAttachedShaders(p0|0,p1|0,p2|0,p3|0);
}
function _emscripten_glShaderSource__wrapper(p0,p1,p2,p3) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; _emscripten_glShaderSource(p0|0,p1|0,p2|0,p3|0);
}
function _emscripten_glGetShaderSource__wrapper(p0,p1,p2,p3) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; _emscripten_glGetShaderSource(p0|0,p1|0,p2|0,p3|0);
}
function _emscripten_glGetShaderInfoLog__wrapper(p0,p1,p2,p3) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; _emscripten_glGetShaderInfoLog(p0|0,p1|0,p2|0,p3|0);
}
function _emscripten_glGetShaderPrecisionFormat__wrapper(p0,p1,p2,p3) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; _emscripten_glGetShaderPrecisionFormat(p0|0,p1|0,p2|0,p3|0);
}
function _emscripten_glGetProgramInfoLog__wrapper(p0,p1,p2,p3) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; _emscripten_glGetProgramInfoLog(p0|0,p1|0,p2|0,p3|0);
}
function _emscripten_glFramebufferRenderbuffer__wrapper(p0,p1,p2,p3) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; _emscripten_glFramebufferRenderbuffer(p0|0,p1|0,p2|0,p3|0);
}
function _emscripten_glGetFramebufferAttachmentParameteriv__wrapper(p0,p1,p2,p3) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; _emscripten_glGetFramebufferAttachmentParameteriv(p0|0,p1|0,p2|0,p3|0);
}
function _emscripten_glGetInfoLogARB__wrapper(p0,p1,p2,p3) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; _emscripten_glGetInfoLogARB(p0|0,p1|0,p2|0,p3|0);
}
function _emscripten_glVertexPointer__wrapper(p0,p1,p2,p3) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; _emscripten_glVertexPointer(p0|0,p1|0,p2|0,p3|0);
}
function _emscripten_glTexCoordPointer__wrapper(p0,p1,p2,p3) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; _emscripten_glTexCoordPointer(p0|0,p1|0,p2|0,p3|0);
}
function _emscripten_glColorPointer__wrapper(p0,p1,p2,p3) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; _emscripten_glColorPointer(p0|0,p1|0,p2|0,p3|0);
}
function _emscripten_glDrawElements__wrapper(p0,p1,p2,p3) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; _emscripten_glDrawElements(p0|0,p1|0,p2|0,p3|0);
}
function _emscripten_glDrawArraysInstanced__wrapper(p0,p1,p2,p3) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; _emscripten_glDrawArraysInstanced(p0|0,p1|0,p2|0,p3|0);
}
function _emscripten_glViewport__wrapper(p0,p1,p2,p3) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; _emscripten_glViewport(p0|0,p1|0,p2|0,p3|0);
}
function _emscripten_glScissor__wrapper(p0,p1,p2,p3) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; _emscripten_glScissor(p0|0,p1|0,p2|0,p3|0);
}
function _emscripten_glColorMask__wrapper(p0,p1,p2,p3) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; _emscripten_glColorMask(p0|0,p1|0,p2|0,p3|0);
}
function _emscripten_glRenderbufferStorage__wrapper(p0,p1,p2,p3) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; _emscripten_glRenderbufferStorage(p0|0,p1|0,p2|0,p3|0);
}
function _emscripten_glBlendFuncSeparate__wrapper(p0,p1,p2,p3) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; _emscripten_glBlendFuncSeparate(p0|0,p1|0,p2|0,p3|0);
}
function _emscripten_glStencilFuncSeparate__wrapper(p0,p1,p2,p3) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; _emscripten_glStencilFuncSeparate(p0|0,p1|0,p2|0,p3|0);
}
function _emscripten_glStencilOpSeparate__wrapper(p0,p1,p2,p3) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; _emscripten_glStencilOpSeparate(p0|0,p1|0,p2|0,p3|0);
}

// EMSCRIPTEN_END_FUNCS
var FUNCTION_TABLE_iiiiiiii = [b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,__ZN7osgUtil9SceneView9cullStageERKN3osg7MatrixdES4_PNS_11CullVisitorEPNS_10StateGraphEPNS_11RenderStageEPNS1_8ViewportE,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,__ZNKSt3__28time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcPK2tmcc,b0,b0,__ZNKSt3__28time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwPK2tmcc,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,__ZNKSt3__29money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_bRNS_8ios_baseERjRe,__ZNKSt3__29money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_bRNS_8ios_baseERjRNS_12basic_stringIcS3_NS_9allocatorIcEEEE,b0,b0,__ZNKSt3__29money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_bRNS_8ios_baseERjRe,__ZNKSt3__29money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_bRNS_8ios_baseERjRNS_12basic_stringIwS3_NS_9allocatorIwEEEE,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,_SDL_BlendFillRect_ARGB8888
,_SDL_BlendFillRect_RGB888,_SDL_BlendFillRect_RGBA,_SDL_BlendFillRect_RGB,_SDL_BlendFillRect_RGB555,_SDL_BlendFillRect_RGB565,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,__ZNSt3__214__scan_keywordINS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEPKNS_12basic_stringIcS3_NS_9allocatorIcEEEENS_5ctypeIcEEEET0_RT_SE_SD_SD_RKT1_Rjb,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,__ZNSt3__214__scan_keywordINS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEPKNS_12basic_stringIwS3_NS_9allocatorIwEEEENS_5ctypeIwEEEET0_RT_SE_SD_SD_RKT1_Rjb,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0];
var FUNCTION_TABLE_iiiiiid = [b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,__ZNKSt3__29money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_bRNS_8ios_baseEce
,b1,b1,b1,__ZNKSt3__29money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_bRNS_8ios_baseEwe,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1];
var FUNCTION_TABLE_vd = [b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,_emscripten_glClearDepth__wrapper,_emscripten_glClearDepthf__wrapper,b2,b2,b2,b2
,b2,b2,_emscripten_glLineWidth__wrapper,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2];
var FUNCTION_TABLE_vid = [b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,__ZN9osgViewer10ViewerBase5frameEd,__ZN9osgViewer6Viewer7advanceEd,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,__ZN5osgGA19StandardManipulator4homeEd,b3,b3,b3,b3,b3,b3,b3,__ZN5osgGA19StandardManipulator16setAnimationTimeEd,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,__ZN5osgGA16OrbitManipulator11setDistanceEd,b3,__ZN5osgGA16OrbitManipulator18setWheelZoomFactorEd,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,__ZN5osgGA17CameraManipulator4homeEd,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,_emscripten_glUniform1f__wrapper,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,_emscripten_glVertexAttrib1f__wrapper,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3];
var FUNCTION_TABLE_viiiii = [b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,__ZN3osg15GraphicsContext21resizedImplementationEiiii,b4,b4,__ZN9osgViewer14GraphicsWindow18getWindowRectangleERiS1_S1_S1_,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,__ZN15EXTQuerySupport10checkQueryEPN3osg5StatsEPNS0_5StateEy,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,__ZN15ARBQuerySupport10checkQueryEPN3osg5StatsEPNS0_5StateEy,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,__ZN5osgGA17CameraManipulator15setHomePositionERKN3osg5Vec3dES4_S4_b,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,__ZN7osgUtil22LineSegmentIntersector9intersectERNS_19IntersectionVisitorEPN3osg8DrawableERKNS3_5Vec3dES8_,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,__ZN3osg5Image27readImageFromCurrentTextureEjbjj
,__ZN3osg5Image10scaleImageEiiij,__ZN3osg5Image12copySubImageEiiiPKS0_,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,__ZNK5osgDB9FileCache10writeImageERKN3osg5ImageERKNSt3__212basic_stringIcNS5_11char_traitsIcEENS5_9allocatorIcEEEEPKNS_7OptionsE,b4,__ZNK5osgDB9FileCache11writeObjectERKN3osg6ObjectERKNSt3__212basic_stringIcNS5_11char_traitsIcEENS5_9allocatorIcEEEEPKNS_7OptionsE,b4,__ZNK5osgDB9FileCache16writeHeightFieldERKN3osg11HeightFieldERKNSt3__212basic_stringIcNS5_11char_traitsIcEENS5_9allocatorIcEEEEPKNS_7OptionsE,__ZNK5osgDB9FileCache8readNodeERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEPKNS_7OptionsEb,__ZNK5osgDB9FileCache9writeNodeERKN3osg4NodeERKNSt3__212basic_stringIcNS5_11char_traitsIcEENS5_9allocatorIcEEEEPKNS_7OptionsE,b4,__ZNK5osgDB9FileCache11writeShaderERKN3osg6ShaderERKNSt3__212basic_stringIcNS5_11char_traitsIcEENS5_9allocatorIcEEEEPKNS_7OptionsE
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,__ZNK10__cxxabiv117__class_type_info16search_below_dstEPNS_19__dynamic_cast_infoEPKvib,b4,b4,b4,__ZNK10__cxxabiv120__si_class_type_info16search_below_dstEPNS_19__dynamic_cast_infoEPKvib,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,__ZNK10__cxxabiv121__vmi_class_type_info16search_below_dstEPNS_19__dynamic_cast_infoEPKvib,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,__ZN3osg6Camera11setViewportEiiii,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,__ZN9osgViewer22GraphicsWindowEmbeddedC2Eiiii,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,__ZN5osgGA19StandardManipulator15fixVerticalAxisERKN3osg5Vec3dES4_RS2_S4_b
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_jjRKS4_,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,_glShaderBinary__wrapper,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,__ZN3osg5Image8setColorERKNS_5Vec4fEjjj,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,__ZN5osgDB8Registry8readNodeERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEPKNS_7OptionsEb,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,__ZN5osgDB8Registry24writeImageImplementationERKN3osg5ImageERKNSt3__212basic_stringIcNS5_11char_traitsIcEENS5_9allocatorIcEEEEPKNS_7OptionsE,b4,__ZN5osgDB8Registry10readObjectERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEPKNS_7OptionsEb,__ZN5osgDB8Registry25writeObjectImplementationERKN3osg6ObjectERKNSt3__212basic_stringIcNS5_11char_traitsIcEENS5_9allocatorIcEEEEPKNS_7OptionsE,b4,__ZN5osgDB8Registry30writeHeightFieldImplementationERKN3osg11HeightFieldERKNSt3__212basic_stringIcNS5_11char_traitsIcEENS5_9allocatorIcEEEEPKNS_7OptionsE,__ZN5osgDB8Registry23writeNodeImplementationERKN3osg4NodeERKNSt3__212basic_stringIcNS5_11char_traitsIcEENS5_9allocatorIcEEEEPKNS_7OptionsE,b4,__ZN5osgDB8Registry25writeShaderImplementationERKN3osg6ShaderERKNSt3__212basic_stringIcNS5_11char_traitsIcEENS5_9allocatorIcEEEEPKNS_7OptionsE,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,_emscripten_glUniform4i__wrapper,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,_emscripten_glFramebufferTexture2D__wrapper,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,_emscripten_glShaderBinary__wrapper,b4,b4,b4,b4,_emscripten_glDrawElementsInstanced__wrapper,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4];
var FUNCTION_TABLE_iiiiiiiiii = [b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,__ZNK3osg7Texture30generateAndAssignTextureObjectEjjijiiii,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,_GLES2_UpdateTextureYUV,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5];
var FUNCTION_TABLE_vii = [b6,__ZN3osg10Referenced21setThreadSafeRefUnrefEb,b6,b6,b6,b6,b6,b6,__ZN3osg6Object21setThreadSafeRefUnrefEb,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,__ZN3osg6Object7setNameERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE,b6,__ZN3osg6Object11setUserDataEPNS_10ReferencedE,b6,b6,__ZN3osg6Object21resizeGLObjectBuffersEj,__ZNK3osg6Object16releaseGLObjectsEPNS_5StateE,b6,b6,b6,b6,b6,b6,b6,b6,b6,__ZN9osgViewer14GraphicsWindow34bindPBufferToTextureImplementationEj,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,__ZN9osgViewer14GraphicsWindow13setWindowNameERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE,__ZN9osgViewer14GraphicsWindow13getWindowNameEv,__ZN9osgViewer14GraphicsWindow9useCursorEb,__ZN9osgViewer14GraphicsWindow9setCursorENS0_11MouseCursorE,__ZN9osgViewer14GraphicsWindow15setSyncToVBlankEb,b6,b6,__ZN9osgViewer14GraphicsWindow23requestContinuousUpdateEb,b6,b6,b6,b6,b6,__ZThn132_N9osgViewer14GraphicsWindow23requestContinuousUpdateEb,b6,b6,b6,b6,b6,b6,b6,b6,__ZN9osgViewer4View4takeERN3osg4ViewE,b6,b6,b6
,b6,b6,__ZN9osgViewer4View12setSceneDataEPN3osg4NodeE,b6,b6,b6,__ZN9osgViewer4View23requestContinuousUpdateEb,b6,b6,b6,b6,b6,b6,b6,__ZThn36_N9osgViewer4View23requestContinuousUpdateEb,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,__ZNK3osg11NodeVisitor11getEyePointEv,__ZNK3osg11NodeVisitor12getViewPointEv,b6,b6,b6,__ZN3osg11NodeVisitor5applyERNS_8DrawableE,__ZN3osg11NodeVisitor5applyERNS_8GeometryE,__ZN37CollectedCoordinateSystemNodesVisitor5applyERN3osg4NodeE,__ZN3osg11NodeVisitor5applyERNS_5GeodeE,__ZN3osg11NodeVisitor5applyERNS_9BillboardE,__ZN3osg11NodeVisitor5applyERNS_5GroupE,__ZN3osg11NodeVisitor5applyERNS_9ProxyNodeE,__ZN3osg11NodeVisitor5applyERNS_10ProjectionE,__ZN37CollectedCoordinateSystemNodesVisitor5applyERN3osg20CoordinateSystemNodeE,__ZN3osg11NodeVisitor5applyERNS_8ClipNodeE
,__ZN3osg11NodeVisitor5applyERNS_10TexGenNodeE,__ZN3osg11NodeVisitor5applyERNS_11LightSourceE,__ZN3osg11NodeVisitor5applyERNS_9TransformE,__ZN3osg11NodeVisitor5applyERNS_6CameraE,__ZN3osg11NodeVisitor5applyERNS_10CameraViewE,__ZN3osg11NodeVisitor5applyERNS_15MatrixTransformE,__ZN3osg11NodeVisitor5applyERNS_25PositionAttitudeTransformE,__ZN3osg11NodeVisitor5applyERNS_13AutoTransformE,__ZN3osg11NodeVisitor5applyERNS_6SwitchE,__ZN3osg11NodeVisitor5applyERNS_8SequenceE,__ZN3osg11NodeVisitor5applyERNS_3LODE,__ZN3osg11NodeVisitor5applyERNS_8PagedLODE,__ZN3osg11NodeVisitor5applyERNS_9ClearNodeE,__ZN3osg11NodeVisitor5applyERNS_12OccluderNodeE,__ZN3osg11NodeVisitor5applyERNS_18OcclusionQueryNodeE,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,__ZN9osgViewer6Viewer14setViewerStatsEPN3osg5StatsE,b6,b6,b6,b6,b6,b6,__ZN9osgViewer10ViewerBase20setProcessorAffinityERKN11OpenThreads8AffinityE,__ZN9osgViewer10ViewerBase17setThreadingModelENS0_14ThreadingModelE,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,__ZNK9osgViewer6Viewer8getUsageERN3osg16ApplicationUsageE,b6,b6,b6,b6,b6,b6,b6,b6,__ZN9osgViewer6Viewer4takeERN3osg4ViewE,b6,__ZN9osgViewer6Viewer12setSceneDataEPN3osg4NodeE,b6,b6,b6,b6,b6,b6,__ZThn104_N9osgViewer6Viewer4takeERN3osg4ViewE,b6,b6,b6,__ZThn104_N9osgViewer6Viewer12setSceneDataEPN3osg4NodeE,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,__ZN3osg4View4takeERS0_,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE5imbueERKNS_6localeE,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,__ZN3osg10BufferData21resizeGLObjectBuffersEj,__ZNK3osg10BufferData16releaseGLObjectsEPNS_5StateE,b6,b6,b6,b6,b6,b6
,b6,b6,__ZN3osg13TemplateArrayINS_5Vec3fELNS_5Array4TypeE28ELi3ELi5126EE6acceptERNS_12ArrayVisitorE,__ZNK3osg13TemplateArrayINS_5Vec3fELNS_5Array4TypeE28ELi3ELi5126EE6acceptERNS_17ConstArrayVisitorE,b6,b6,b6,b6,b6,b6,__ZN3osg13TemplateArrayINS_5Vec3fELNS_5Array4TypeE28ELi3ELi5126EE12reserveArrayEj,__ZN3osg13TemplateArrayINS_5Vec3fELNS_5Array4TypeE28ELi3ELi5126EE11resizeArrayEj,b6,b6,b6,b6,b6,b6,b6,b6,b6,__ZN3osg13TemplateArrayINS_5Vec2fELNS_5Array4TypeE27ELi2ELi5126EE6acceptERNS_12ArrayVisitorE,__ZNK3osg13TemplateArrayINS_5Vec2fELNS_5Array4TypeE27ELi2ELi5126EE6acceptERNS_17ConstArrayVisitorE,b6,b6,b6,b6,b6,b6,__ZN3osg13TemplateArrayINS_5Vec2fELNS_5Array4TypeE27ELi2ELi5126EE12reserveArrayEj
,__ZN3osg13TemplateArrayINS_5Vec2fELNS_5Array4TypeE27ELi2ELi5126EE11resizeArrayEj,b6,b6,b6,b6,b6,b6,b6,b6,b6,__ZN3osg13TemplateArrayINS_5Vec4fELNS_5Array4TypeE29ELi4ELi5126EE6acceptERNS_12ArrayVisitorE,__ZNK3osg13TemplateArrayINS_5Vec4fELNS_5Array4TypeE29ELi4ELi5126EE6acceptERNS_17ConstArrayVisitorE,b6,b6,b6,b6,b6,b6,__ZN3osg13TemplateArrayINS_5Vec4fELNS_5Array4TypeE29ELi4ELi5126EE12reserveArrayEj,__ZN3osg13TemplateArrayINS_5Vec4fELNS_5Array4TypeE29ELi4ELi5126EE11resizeArrayEj,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,__ZNK9osgViewer12SingleWindow9configureERNS_4ViewE,b6,b6,b6,b6,b6,b6,b6,__ZNK9osgViewer12SingleScreen9configureERNS_4ViewE,b6,b6,b6,b6,b6,b6,__ZNK9osgViewer16AcrossAllScreens9configureERNS_4ViewE,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,__ZNK5osgGA12EventHandler8getUsageERN3osg16ApplicationUsageE,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,__ZN15EXTQuerySupport8endQueryEPN3osg5StateE,b6,b6,__ZN9osgViewer8RendererclEPN3osg6ObjectE,b6,b6,__ZN9osgViewer8RendererclEPN3osg15GraphicsContextE,b6,b6,b6,b6,b6,__ZN9osgViewer8Renderer15updateSceneViewEPN7osgUtil9SceneViewE
,b6,b6,b6,__ZN3osg17GraphicsOperationclEPNS_6ObjectE,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,__ZN15ARBQuerySupport8endQueryEPN3osg5StateE,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,__ZN9osgViewer5Scene16updateSceneGraphERN3osg11NodeVisitorE
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,__ZN5osgGA12EventVisitor5applyERN3osg8DrawableE,__ZN5osgGA12EventVisitor5applyERN3osg4NodeE,__ZN5osgGA12EventVisitor5applyERN3osg5GeodeE,__ZN5osgGA12EventVisitor5applyERN3osg9BillboardE,__ZN5osgGA12EventVisitor5applyERN3osg5GroupE,__ZN5osgGA12EventVisitor5applyERN3osg10ProjectionE,__ZN3osg11NodeVisitor5applyERNS_20CoordinateSystemNodeE,__ZN5osgGA12EventVisitor5applyERN3osg11LightSourceE,__ZN5osgGA12EventVisitor5applyERN3osg9TransformE,__ZN5osgGA12EventVisitor5applyERN3osg6SwitchE,__ZN5osgGA12EventVisitor5applyERN3osg3LODE,__ZN5osgGA12EventVisitor5applyERN3osg12OccluderNodeE,b6,b6,b6,b6,b6,b6,b6,b6
,__ZN3osg11NodeVisitor5applyERNS_4NodeE,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,__ZNK5osgGA19StandardManipulator8getUsageERN3osg16ApplicationUsageE,b6,__ZN5osgGA17CameraManipulator26setCoordinateFrameCallbackEPNS0_23CoordinateFrameCallbackE,__ZN5osgGA16OrbitManipulator11setByMatrixERKN3osg7MatrixdE,__ZN5osgGA16OrbitManipulator18setByInverseMatrixERKN3osg7MatrixdE,__ZNK5osgGA16OrbitManipulator9getMatrixEv
,__ZNK5osgGA16OrbitManipulator16getInverseMatrixEv,__ZN5osgGA17CameraManipulator12updateCameraERN3osg6CameraE,b6,b6,__ZN5osgGA19StandardManipulator7setNodeEPN3osg4NodeE,b6,b6,b6,b6,__ZN5osgGA17CameraManipulator26setAutoComputeHomePositionEb,b6,b6,b6,b6,b6,b6,b6,b6,b6,__ZN5osgGA19StandardManipulator20setVerticalAxisFixedEb,__ZN5osgGA19StandardManipulator13setAllowThrowEb,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,__ZN5osgGA16OrbitManipulator9setCenterERKN3osg5Vec3dE,__ZN5osgGA16OrbitManipulator11setRotationERKN3osg4QuatE,b6,__ZN5osgGA16OrbitManipulator16setTrackballSizeERKd,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,__ZN5osgGA17CameraManipulator7setNodeEPN3osg4NodeE,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,__ZN7osgUtil16GLObjectsVisitor5applyERN3osg8DrawableE,__ZN7osgUtil16GLObjectsVisitor5applyERN3osg4NodeE,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,__ZNK7osgUtil19IntersectionVisitor11getEyePointEv,b6,__ZN7osgUtil19IntersectionVisitor5applyERN3osg8DrawableE,__ZN7osgUtil19IntersectionVisitor5applyERN3osg4NodeE,__ZN7osgUtil19IntersectionVisitor5applyERN3osg5GeodeE,__ZN7osgUtil19IntersectionVisitor5applyERN3osg9BillboardE
,__ZN7osgUtil19IntersectionVisitor5applyERN3osg5GroupE,__ZN7osgUtil19IntersectionVisitor5applyERN3osg10ProjectionE,__ZN7osgUtil19IntersectionVisitor5applyERN3osg9TransformE,__ZN7osgUtil19IntersectionVisitor5applyERN3osg6CameraE,__ZN7osgUtil19IntersectionVisitor5applyERN3osg3LODE,__ZN7osgUtil19IntersectionVisitor5applyERN3osg8PagedLODE,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,__ZN7osgUtil14StateToCompile5applyERN3osg8DrawableE,__ZN7osgUtil14StateToCompile5applyERN3osg4NodeE,__ZN7osgUtil14StateToCompile5applyERN3osg8StateSetE,__ZN7osgUtil14StateToCompile5applyERN3osg7TextureE,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,__ZN7osgUtil9Optimizer28StaticObjectDetectionVisitor5applyERN3osg8DrawableE,__ZN7osgUtil9Optimizer28StaticObjectDetectionVisitor5applyERN3osg4NodeE,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,__ZN7osgUtil14RayIntersector8setStartERKN3osg5Vec3dE,__ZN7osgUtil14RayIntersector12setDirectionERKN3osg5Vec3dE,b6,b6,b6,b6,b6,b6,b6,b6
,b6,__ZN7osgUtil9SceneView11setDefaultsEj,b6,b6,b6,b6,__ZN7osgUtil9SceneView19inheritCullSettingsERKN3osg12CullSettingsE,b6,b6,b6,b6,b6,b6,b6,__ZN7osgUtil9SceneView21flushDeletedGLObjectsERd,b6,b6,b6,b6,__ZThn32_N7osgUtil9SceneView19inheritCullSettingsERKN3osg12CullSettingsE,b6,b6,b6,b6,b6,b6,__ZN7osgUtil16ShaderGenVisitor5applyERN3osg8DrawableE,__ZN7osgUtil16ShaderGenVisitor5applyERN3osg4NodeE,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,__ZN7osgUtil10Statistics5beginEj,b6,__ZN7osgUtil10Statistics6vertexERKN3osg5Vec3fE,__ZN7osgUtil10Statistics6vertexERKN3osg5Vec2fE,__ZN7osgUtil10Statistics6vertexERKN3osg5Vec4fE
,b6,b6,b6,b6,b6,b6,b6,b6,__ZN7osgUtil12StatsVisitor5applyERN3osg8DrawableE,__ZN7osgUtil12StatsVisitor5applyERN3osg4NodeE,__ZN7osgUtil12StatsVisitor5applyERN3osg5GeodeE,__ZN7osgUtil12StatsVisitor5applyERN3osg5GroupE,__ZN7osgUtil12StatsVisitor5applyERN3osg9TransformE,__ZN7osgUtil12StatsVisitor5applyERN3osg6SwitchE,__ZN7osgUtil12StatsVisitor5applyERN3osg3LODE,__ZN7osgUtil12StatsVisitor5applyERN3osg8StateSetE,b6,__ZN7osgUtil12StatsVisitor5printERNSt3__213basic_ostreamIcNS1_11char_traitsIcEEEE,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,__ZN7osgUtil13UpdateVisitor5applyERN3osg8DrawableE
,__ZN7osgUtil13UpdateVisitor5applyERN3osg4NodeE,__ZN7osgUtil13UpdateVisitor5applyERN3osg5GeodeE,__ZN7osgUtil13UpdateVisitor5applyERN3osg9BillboardE,__ZN7osgUtil13UpdateVisitor5applyERN3osg5GroupE,__ZN7osgUtil13UpdateVisitor5applyERN3osg10ProjectionE,__ZN7osgUtil13UpdateVisitor5applyERN3osg11LightSourceE,__ZN7osgUtil13UpdateVisitor5applyERN3osg9TransformE,__ZN7osgUtil13UpdateVisitor5applyERN3osg6SwitchE,__ZN7osgUtil13UpdateVisitor5applyERN3osg3LODE,__ZN7osgUtil13UpdateVisitor5applyERN3osg12OccluderNodeE,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,__ZNK7osgUtil11CullVisitor11getEyePointEv,__ZNK7osgUtil11CullVisitor12getViewPointEv,b6,b6,b6,__ZN7osgUtil11CullVisitor5applyERN3osg8DrawableE,__ZN7osgUtil11CullVisitor5applyERN3osg4NodeE
,__ZN7osgUtil11CullVisitor5applyERN3osg5GeodeE,__ZN7osgUtil11CullVisitor5applyERN3osg9BillboardE,__ZN7osgUtil11CullVisitor5applyERN3osg5GroupE,__ZN7osgUtil11CullVisitor5applyERN3osg10ProjectionE,__ZN7osgUtil11CullVisitor5applyERN3osg8ClipNodeE,__ZN7osgUtil11CullVisitor5applyERN3osg10TexGenNodeE,__ZN7osgUtil11CullVisitor5applyERN3osg11LightSourceE,__ZN7osgUtil11CullVisitor5applyERN3osg9TransformE,__ZN7osgUtil11CullVisitor5applyERN3osg6CameraE,__ZN7osgUtil11CullVisitor5applyERN3osg6SwitchE,__ZN7osgUtil11CullVisitor5applyERN3osg3LODE,__ZN7osgUtil11CullVisitor5applyERN3osg9ClearNodeE,__ZN7osgUtil11CullVisitor5applyERN3osg12OccluderNodeE,__ZN7osgUtil11CullVisitor5applyERN3osg18OcclusionQueryNodeE,b6,b6,b6,b6,b6,b6,b6,__ZN3osg12CullSettings19inheritCullSettingsERKS0_,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,__ZN7osgUtil16RenderStageCache21resizeGLObjectBuffersEj,__ZNK7osgUtil16RenderStageCache16releaseGLObjectsEPN3osg5StateE,__ZN7osgUtil16RenderStageCache13objectDeletedEPv,b6,b6,__ZThn32_N7osgUtil16RenderStageCache13objectDeletedEPv,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,__ZN3osg13TemplateArrayIdLNS_5Array4TypeE8ELi1ELi5130EE6acceptERNS_12ArrayVisitorE,__ZNK3osg13TemplateArrayIdLNS_5Array4TypeE8ELi1ELi5130EE6acceptERNS_17ConstArrayVisitorE,b6,b6,b6,b6,b6,b6,__ZN3osg13TemplateArrayIdLNS_5Array4TypeE8ELi1ELi5130EE12reserveArrayEj,__ZN3osg13TemplateArrayIdLNS_5Array4TypeE8ELi1ELi5130EE11resizeArrayEj,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,__ZN3osg13TemplateArrayIfLNS_5Array4TypeE7ELi1ELi5126EE6acceptERNS_12ArrayVisitorE,__ZNK3osg13TemplateArrayIfLNS_5Array4TypeE7ELi1ELi5126EE6acceptERNS_17ConstArrayVisitorE,b6,b6,b6,b6,b6
,b6,__ZN3osg13TemplateArrayIfLNS_5Array4TypeE7ELi1ELi5126EE12reserveArrayEj,__ZN3osg13TemplateArrayIfLNS_5Array4TypeE7ELi1ELi5126EE11resizeArrayEj,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,__ZN3osg18TemplateIndexArrayIjLNS_5Array4TypeE6ELi1ELi5125EE6acceptERNS_12ArrayVisitorE,__ZNK3osg18TemplateIndexArrayIjLNS_5Array4TypeE6ELi1ELi5125EE6acceptERNS_17ConstArrayVisitorE,b6,b6,b6,b6,b6,b6,__ZN3osg18TemplateIndexArrayIjLNS_5Array4TypeE6ELi1ELi5125EE12reserveArrayEj,__ZN3osg18TemplateIndexArrayIjLNS_5Array4TypeE6ELi1ELi5125EE11resizeArrayEj,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,__ZN3osg18TemplateIndexArrayIiLNS_5Array4TypeE3ELi1ELi5124EE6acceptERNS_12ArrayVisitorE,__ZNK3osg18TemplateIndexArrayIiLNS_5Array4TypeE3ELi1ELi5124EE6acceptERNS_17ConstArrayVisitorE,b6,b6,b6,b6,b6,b6,__ZN3osg18TemplateIndexArrayIiLNS_5Array4TypeE3ELi1ELi5124EE12reserveArrayEj,__ZN3osg18TemplateIndexArrayIiLNS_5Array4TypeE3ELi1ELi5124EE11resizeArrayEj,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,__ZNK7osgUtil9RenderBin16releaseGLObjectsEPN3osg5StateE,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,__ZNK7osgUtil11RenderStage16releaseGLObjectsEPN3osg5StateE,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,__ZN18DrawInnerOperationclEPN3osg6ObjectE,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,__ZN3osg21GLBufferObjectManager8newFrameEPNS_10FrameStampE,b6,__ZN3osg21GLBufferObjectManager11reportStatsERNSt3__213basic_ostreamIcNS1_11char_traitsIcEEEE,__ZNK3osg21GLBufferObjectManager14recomputeStatsERNSt3__213basic_ostreamIcNS1_11char_traitsIcEEEE,b6,b6,b6,b6,b6,b6,b6,b6,b6,__ZN3osg12BufferObject21resizeGLObjectBuffersEj,__ZNK3osg12BufferObject16releaseGLObjectsEPNS_5StateE,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,__ZN3osg5Group21setThreadSafeRefUnrefEb,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,__ZN3osg6Camera21resizeGLObjectBuffersEj,__ZNK3osg6Camera16releaseGLObjectsEPNS_5StateE,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,__ZN3osg6Camera6acceptERNS_11NodeVisitorE,__ZN3osg4Node6ascendERNS_11NodeVisitorE,__ZN3osg5Group8traverseERNS_11NodeVisitorE,__ZNK3osg9Transform12computeBoundEv,b6,b6,b6,b6,b6,b6,b6,b6,__ZN3osg5Group13childInsertedEj,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,__ZN3osg23CollectOccludersVisitor5applyERNS_4NodeE,__ZN3osg23CollectOccludersVisitor5applyERNS_10ProjectionE,__ZN3osg23CollectOccludersVisitor5applyERNS_9TransformE,__ZN3osg23CollectOccludersVisitor5applyERNS_6SwitchE,__ZN3osg23CollectOccludersVisitor5applyERNS_3LODE,__ZN3osg23CollectOccludersVisitor5applyERNS_12OccluderNodeE,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,__ZN3osg14StateAttribute21resizeGLObjectBuffersEj,__ZNK3osg14StateAttribute16releaseGLObjectsEPNS_5StateE,b6,b6,b6,b6,b6,b6,b6,b6,__ZNK3osg9ColorMask5applyERNS_5StateE,__ZNK3osg14StateAttribute16compileGLObjectsERNS_5StateE,b6,b6,b6,b6,b6,__ZNK3osg14StateAttribute5applyERNS_5StateE,b6,b6,b6,b6,b6,__ZN3osg20ComputeBoundsVisitor5applyERNS_8DrawableE,__ZN3osg20ComputeBoundsVisitor5applyERNS_9TransformE,b6,b6,b6
,b6,b6,b6,__ZN3osg11ContextData8newFrameEPNS_10FrameStampE,b6,__ZN3osg11ContextData11reportStatsERNSt3__213basic_ostreamIcNS1_11char_traitsIcEEEE,__ZNK3osg11ContextData14recomputeStatsERNSt3__213basic_ostreamIcNS1_11char_traitsIcEEEE,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,__ZN3osg8Drawable21setThreadSafeRefUnrefEb,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,__ZN3osg8Drawable21resizeGLObjectBuffersEj,__ZNK3osg8Drawable16releaseGLObjectsEPNS_5StateE,b6,b6,b6,b6,__ZN3osg8Drawable6acceptERNS_11NodeVisitorE,__ZN3osg4Node8traverseERNS_11NodeVisitorE,__ZNK3osg8Drawable12computeBoundEv
,__ZNK3osg8Drawable18computeBoundingBoxEv,__ZN3osg8Drawable8setShapeEPNS_5ShapeE,__ZN3osg8Drawable25setUseVertexBufferObjectsEb,b6,b6,b6,__ZNK3osg8Drawable16compileGLObjectsERNS_10RenderInfoE,b6,__ZN3osg8Drawable15setDrawCallbackEPNS0_12DrawCallbackE,__ZNK3osg8Drawable18drawImplementationERNS_10RenderInfoE,b6,__ZN3osg8Drawable6acceptERNS0_16AttributeFunctorE,b6,__ZNK3osg8Drawable6acceptERNS0_21ConstAttributeFunctorE,b6,__ZNK3osg8Drawable6acceptERNS_16PrimitiveFunctorE,b6,__ZNK3osg8Drawable6acceptERNS_21PrimitiveIndexFunctorE,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,__ZN12ComputeBound5beginEj
,__ZN12ComputeBound6vertexERKN3osg5Vec2fE,__ZN12ComputeBound6vertexERKN3osg5Vec3fE,__ZN12ComputeBound6vertexERKN3osg5Vec4fE,__ZN12ComputeBound6vertexERKN3osg5Vec2dE,__ZN12ComputeBound6vertexERKN3osg5Vec3dE,__ZN12ComputeBound6vertexERKN3osg5Vec4dE,b6,b6,b6,b6,b6,b6,b6,b6,b6,__ZN3osg21GraphicsObjectManager8newFrameEPNS_10FrameStampE,b6,__ZN3osg21GraphicsObjectManager11reportStatsERNSt3__213basic_ostreamIcNS1_11char_traitsIcEEEE,__ZNK3osg21GraphicsObjectManager14recomputeStatsERNSt3__213basic_ostreamIcNS1_11char_traitsIcEEEE,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,__ZN3osg15GLObjectManager27scheduleGLObjectForDeletionEj
,b6,__ZN3osg21GLRenderBufferManager14deleteGLObjectEj,b6,__ZN3osg26GLFrameBufferObjectManager14deleteGLObjectEj,b6,b6,b6,b6,b6,b6,b6,__ZN3osg12RenderBuffer21resizeGLObjectBuffersEj,__ZNK3osg12RenderBuffer16releaseGLObjectsEPNS_5StateE,b6,b6,b6,b6,b6,b6,b6,__ZN3osg17FrameBufferObject21resizeGLObjectBuffersEj,__ZNK3osg17FrameBufferObject16releaseGLObjectsEPNS_5StateE,b6,b6,__ZNK3osg17FrameBufferObject5applyERNS_5StateE,b6,b6,b6,b6,b6
,b6,b6,b6,b6,__ZN3osg5Group21resizeGLObjectBuffersEj,__ZNK3osg5Group16releaseGLObjectsEPNS_5StateE,b6,b6,__ZN3osg5Geode6acceptERNS_11NodeVisitorE,__ZNK3osg5Geode12computeBoundEv,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,__ZN3osg8Geometry21resizeGLObjectBuffersEj,__ZNK3osg8Geometry16releaseGLObjectsEPNS_5StateE,b6,b6,__ZN3osg8Geometry6acceptERNS_11NodeVisitorE,__ZN3osg8Geometry25setUseVertexBufferObjectsEb,b6,b6
,__ZNK3osg8Geometry16compileGLObjectsERNS_10RenderInfoE,b6,__ZNK3osg8Geometry18drawImplementationERNS_10RenderInfoE,b6,__ZN3osg8Geometry6acceptERNS_8Drawable16AttributeFunctorE,b6,__ZNK3osg8Geometry6acceptERNS_8Drawable21ConstAttributeFunctorE,b6,__ZNK3osg8Geometry6acceptERNS_16PrimitiveFunctorE,b6,__ZNK3osg8Geometry6acceptERNS_21PrimitiveIndexFunctorE,b6,b6,__ZN3osg17ConstArrayVisitor5applyERKNS_5ArrayE,__ZN3osg33ConstAttributeFunctorArrayVisitor5applyERKNS_18TemplateIndexArrayIaLNS_5Array4TypeE1ELi1ELi5120EEE,__ZN3osg33ConstAttributeFunctorArrayVisitor5applyERKNS_18TemplateIndexArrayIsLNS_5Array4TypeE2ELi1ELi5122EEE,__ZN3osg33ConstAttributeFunctorArrayVisitor5applyERKNS_18TemplateIndexArrayIiLNS_5Array4TypeE3ELi1ELi5124EEE,__ZN3osg33ConstAttributeFunctorArrayVisitor5applyERKNS_18TemplateIndexArrayIhLNS_5Array4TypeE4ELi1ELi5121EEE,__ZN3osg33ConstAttributeFunctorArrayVisitor5applyERKNS_18TemplateIndexArrayItLNS_5Array4TypeE5ELi1ELi5123EEE,__ZN3osg33ConstAttributeFunctorArrayVisitor5applyERKNS_18TemplateIndexArrayIjLNS_5Array4TypeE6ELi1ELi5125EEE,__ZN3osg33ConstAttributeFunctorArrayVisitor5applyERKNS_13TemplateArrayIfLNS_5Array4TypeE7ELi1ELi5126EEE,__ZN3osg33ConstAttributeFunctorArrayVisitor5applyERKNS_13TemplateArrayIdLNS_5Array4TypeE8ELi1ELi5130EEE,__ZN3osg17ConstArrayVisitor5applyERKNS_13TemplateArrayINS_5Vec2bELNS_5Array4TypeE9ELi2ELi5120EEE,__ZN3osg17ConstArrayVisitor5applyERKNS_13TemplateArrayINS_5Vec3bELNS_5Array4TypeE10ELi3ELi5120EEE,__ZN3osg17ConstArrayVisitor5applyERKNS_13TemplateArrayINS_5Vec4bELNS_5Array4TypeE11ELi4ELi5120EEE,__ZN3osg17ConstArrayVisitor5applyERKNS_13TemplateArrayINS_5Vec2sELNS_5Array4TypeE12ELi2ELi5122EEE,__ZN3osg17ConstArrayVisitor5applyERKNS_13TemplateArrayINS_5Vec3sELNS_5Array4TypeE13ELi3ELi5122EEE,__ZN3osg17ConstArrayVisitor5applyERKNS_13TemplateArrayINS_5Vec4sELNS_5Array4TypeE14ELi4ELi5122EEE,__ZN3osg17ConstArrayVisitor5applyERKNS_13TemplateArrayINS_5Vec2iELNS_5Array4TypeE15ELi2ELi5124EEE,__ZN3osg17ConstArrayVisitor5applyERKNS_13TemplateArrayINS_5Vec3iELNS_5Array4TypeE16ELi3ELi5124EEE
,__ZN3osg17ConstArrayVisitor5applyERKNS_13TemplateArrayINS_5Vec4iELNS_5Array4TypeE17ELi4ELi5124EEE,__ZN3osg17ConstArrayVisitor5applyERKNS_13TemplateArrayINS_6Vec2ubELNS_5Array4TypeE18ELi2ELi5121EEE,__ZN3osg17ConstArrayVisitor5applyERKNS_13TemplateArrayINS_6Vec3ubELNS_5Array4TypeE19ELi3ELi5121EEE,__ZN3osg33ConstAttributeFunctorArrayVisitor5applyERKNS_13TemplateArrayINS_6Vec4ubELNS_5Array4TypeE20ELi4ELi5121EEE,__ZN3osg17ConstArrayVisitor5applyERKNS_13TemplateArrayINS_6Vec2usELNS_5Array4TypeE21ELi2ELi5123EEE,__ZN3osg17ConstArrayVisitor5applyERKNS_13TemplateArrayINS_6Vec3usELNS_5Array4TypeE22ELi3ELi5123EEE,__ZN3osg17ConstArrayVisitor5applyERKNS_13TemplateArrayINS_6Vec4usELNS_5Array4TypeE23ELi4ELi5123EEE,__ZN3osg17ConstArrayVisitor5applyERKNS_13TemplateArrayINS_6Vec2uiELNS_5Array4TypeE24ELi2ELi5125EEE,__ZN3osg17ConstArrayVisitor5applyERKNS_13TemplateArrayINS_6Vec3uiELNS_5Array4TypeE25ELi3ELi5125EEE,__ZN3osg17ConstArrayVisitor5applyERKNS_13TemplateArrayINS_6Vec4uiELNS_5Array4TypeE26ELi4ELi5125EEE,__ZN3osg33ConstAttributeFunctorArrayVisitor5applyERKNS_13TemplateArrayINS_5Vec2fELNS_5Array4TypeE27ELi2ELi5126EEE,__ZN3osg33ConstAttributeFunctorArrayVisitor5applyERKNS_13TemplateArrayINS_5Vec3fELNS_5Array4TypeE28ELi3ELi5126EEE,__ZN3osg33ConstAttributeFunctorArrayVisitor5applyERKNS_13TemplateArrayINS_5Vec4fELNS_5Array4TypeE29ELi4ELi5126EEE,__ZN3osg33ConstAttributeFunctorArrayVisitor5applyERKNS_13TemplateArrayINS_5Vec2dELNS_5Array4TypeE30ELi2ELi5130EEE,__ZN3osg33ConstAttributeFunctorArrayVisitor5applyERKNS_13TemplateArrayINS_5Vec3dELNS_5Array4TypeE31ELi3ELi5130EEE,__ZN3osg33ConstAttributeFunctorArrayVisitor5applyERKNS_13TemplateArrayINS_5Vec4dELNS_5Array4TypeE32ELi4ELi5130EEE,__ZN3osg17ConstArrayVisitor5applyERKNS_13TemplateArrayINS_7MatrixfELNS_5Array4TypeE33ELi16ELi5126EEE,__ZN3osg17ConstArrayVisitor5applyERKNS_13TemplateArrayINS_7MatrixdELNS_5Array4TypeE34ELi16ELi5130EEE,__ZN3osg17ConstArrayVisitor5applyERKNS_18TemplateIndexArrayIyLNS_5Array4TypeE36ELi1ELi5135EEE,__ZN3osg17ConstArrayVisitor5applyERKNS_18TemplateIndexArrayIxLNS_5Array4TypeE37ELi1ELi5134EEE,b6,b6,__ZN3osg12ArrayVisitor5applyERNS_5ArrayE,__ZN3osg28AttributeFunctorArrayVisitor5applyERNS_18TemplateIndexArrayIaLNS_5Array4TypeE1ELi1ELi5120EEE,__ZN3osg28AttributeFunctorArrayVisitor5applyERNS_18TemplateIndexArrayIsLNS_5Array4TypeE2ELi1ELi5122EEE,__ZN3osg28AttributeFunctorArrayVisitor5applyERNS_18TemplateIndexArrayIiLNS_5Array4TypeE3ELi1ELi5124EEE,__ZN3osg28AttributeFunctorArrayVisitor5applyERNS_18TemplateIndexArrayIhLNS_5Array4TypeE4ELi1ELi5121EEE,__ZN3osg28AttributeFunctorArrayVisitor5applyERNS_18TemplateIndexArrayItLNS_5Array4TypeE5ELi1ELi5123EEE,__ZN3osg28AttributeFunctorArrayVisitor5applyERNS_18TemplateIndexArrayIjLNS_5Array4TypeE6ELi1ELi5125EEE,__ZN3osg28AttributeFunctorArrayVisitor5applyERNS_13TemplateArrayIfLNS_5Array4TypeE7ELi1ELi5126EEE
,__ZN3osg28AttributeFunctorArrayVisitor5applyERNS_13TemplateArrayIdLNS_5Array4TypeE8ELi1ELi5130EEE,__ZN3osg12ArrayVisitor5applyERNS_13TemplateArrayINS_5Vec2bELNS_5Array4TypeE9ELi2ELi5120EEE,__ZN3osg12ArrayVisitor5applyERNS_13TemplateArrayINS_5Vec3bELNS_5Array4TypeE10ELi3ELi5120EEE,__ZN3osg12ArrayVisitor5applyERNS_13TemplateArrayINS_5Vec4bELNS_5Array4TypeE11ELi4ELi5120EEE,__ZN3osg12ArrayVisitor5applyERNS_13TemplateArrayINS_5Vec2sELNS_5Array4TypeE12ELi2ELi5122EEE,__ZN3osg12ArrayVisitor5applyERNS_13TemplateArrayINS_5Vec3sELNS_5Array4TypeE13ELi3ELi5122EEE,__ZN3osg12ArrayVisitor5applyERNS_13TemplateArrayINS_5Vec4sELNS_5Array4TypeE14ELi4ELi5122EEE,__ZN3osg12ArrayVisitor5applyERNS_13TemplateArrayINS_5Vec2iELNS_5Array4TypeE15ELi2ELi5124EEE,__ZN3osg12ArrayVisitor5applyERNS_13TemplateArrayINS_5Vec3iELNS_5Array4TypeE16ELi3ELi5124EEE,__ZN3osg12ArrayVisitor5applyERNS_13TemplateArrayINS_5Vec4iELNS_5Array4TypeE17ELi4ELi5124EEE,__ZN3osg12ArrayVisitor5applyERNS_13TemplateArrayINS_6Vec2ubELNS_5Array4TypeE18ELi2ELi5121EEE,__ZN3osg12ArrayVisitor5applyERNS_13TemplateArrayINS_6Vec3ubELNS_5Array4TypeE19ELi3ELi5121EEE,__ZN3osg28AttributeFunctorArrayVisitor5applyERNS_13TemplateArrayINS_6Vec4ubELNS_5Array4TypeE20ELi4ELi5121EEE,__ZN3osg12ArrayVisitor5applyERNS_13TemplateArrayINS_6Vec2usELNS_5Array4TypeE21ELi2ELi5123EEE,__ZN3osg12ArrayVisitor5applyERNS_13TemplateArrayINS_6Vec3usELNS_5Array4TypeE22ELi3ELi5123EEE,__ZN3osg12ArrayVisitor5applyERNS_13TemplateArrayINS_6Vec4usELNS_5Array4TypeE23ELi4ELi5123EEE,__ZN3osg12ArrayVisitor5applyERNS_13TemplateArrayINS_6Vec2uiELNS_5Array4TypeE24ELi2ELi5125EEE,__ZN3osg12ArrayVisitor5applyERNS_13TemplateArrayINS_6Vec3uiELNS_5Array4TypeE25ELi3ELi5125EEE,__ZN3osg12ArrayVisitor5applyERNS_13TemplateArrayINS_6Vec4uiELNS_5Array4TypeE26ELi4ELi5125EEE,__ZN3osg28AttributeFunctorArrayVisitor5applyERNS_13TemplateArrayINS_5Vec2fELNS_5Array4TypeE27ELi2ELi5126EEE,__ZN3osg28AttributeFunctorArrayVisitor5applyERNS_13TemplateArrayINS_5Vec3fELNS_5Array4TypeE28ELi3ELi5126EEE,__ZN3osg28AttributeFunctorArrayVisitor5applyERNS_13TemplateArrayINS_5Vec4fELNS_5Array4TypeE29ELi4ELi5126EEE,__ZN3osg28AttributeFunctorArrayVisitor5applyERNS_13TemplateArrayINS_5Vec2dELNS_5Array4TypeE30ELi2ELi5130EEE,__ZN3osg28AttributeFunctorArrayVisitor5applyERNS_13TemplateArrayINS_5Vec3dELNS_5Array4TypeE31ELi3ELi5130EEE,__ZN3osg28AttributeFunctorArrayVisitor5applyERNS_13TemplateArrayINS_5Vec4dELNS_5Array4TypeE32ELi4ELi5130EEE,__ZN3osg12ArrayVisitor5applyERNS_13TemplateArrayINS_7MatrixfELNS_5Array4TypeE33ELi16ELi5126EEE,__ZN3osg12ArrayVisitor5applyERNS_13TemplateArrayINS_7MatrixdELNS_5Array4TypeE34ELi16ELi5130EEE,__ZN3osg12ArrayVisitor5applyERNS_18TemplateIndexArrayIyLNS_5Array4TypeE36ELi1ELi5135EEE,__ZN3osg12ArrayVisitor5applyERNS_18TemplateIndexArrayIxLNS_5Array4TypeE37ELi1ELi5134EEE,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,__ZN3osg23SyncSwapBuffersCallback25swapBuffersImplementationEPNS_15GraphicsContextE,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,__ZN3osg22BlockAndFlushOperationclEPNS_15GraphicsContextE,b6,b6,b6,b6,__ZN3osg21EndOfDynamicDrawBlock9completedEPNS_5StateE,b6,b6,__ZN3osg20SwapBuffersOperationclEPNS_15GraphicsContextE,b6,b6,b6,__ZN3osg16BarrierOperationclEPNS_6ObjectE,b6,b6,b6,b6,b6,__ZN11OpenThreads7Barrier5blockEj,b6,b6,b6,b6
,b6,b6,__ZN3osg13RunOperationsclEPNS_15GraphicsContextE,b6,b6,b6,b6,b6,b6,b6,b6,b6,__ZN3osg5Group6acceptERNS_11NodeVisitorE,__ZNK3osg5Group12computeBoundEv,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,__ZN3osg5Image6updateEPNS_11NodeVisitorE,b6,b6,b6,__ZN3osg5Image20setFrameLastRenderedEPKNS_10FrameStampE,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,__ZN3osg6KdTree6acceptERNS_12ShapeVisitorE,__ZNK3osg6KdTree6acceptERNS_17ConstShapeVisitorE,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,__ZN3osg13KdTreeBuilder5applyERNS_8GeometryE,b6,b6,b6,b6,b6,__ZN3osg4Node21setThreadSafeRefUnrefEb,b6,b6,b6,b6,b6,b6,b6,__ZN3osg4Node21resizeGLObjectBuffersEj,__ZNK3osg4Node16releaseGLObjectsEPNS_5StateE,__ZN3osg4Node6acceptERNS_11NodeVisitorE,__ZNK3osg4Node12computeBoundEv,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,__ZN3osg8Observer13objectDeletedEPv,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,__ZNK3osg11PolygonMode5applyERNS_5StateE,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,__ZNK3osg14PolygonStipple5applyERNS_5StateE,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,__ZNK3osg17DrawElementsUByte6acceptERNS_16PrimitiveFunctorE,__ZNK3osg17DrawElementsUByte6acceptERNS_21PrimitiveIndexFunctorE,b6,b6,__ZN3osg17DrawElementsUByte13offsetIndicesEi,b6,__ZN3osg17DrawElementsUByte14resizeElementsEj,__ZN3osg17DrawElementsUByte15reserveElementsEj,b6,b6,__ZN3osg17DrawElementsUByte10addElementEj,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,__ZNK3osg18DrawElementsUShort6acceptERNS_16PrimitiveFunctorE,__ZNK3osg18DrawElementsUShort6acceptERNS_21PrimitiveIndexFunctorE
,b6,b6,__ZN3osg18DrawElementsUShort13offsetIndicesEi,b6,__ZN3osg18DrawElementsUShort14resizeElementsEj,__ZN3osg18DrawElementsUShort15reserveElementsEj,b6,b6,__ZN3osg18DrawElementsUShort10addElementEj,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,__ZNK3osg16DrawElementsUInt6acceptERNS_16PrimitiveFunctorE,__ZNK3osg16DrawElementsUInt6acceptERNS_21PrimitiveIndexFunctorE,b6,b6,__ZN3osg16DrawElementsUInt13offsetIndicesEi,b6,__ZN3osg16DrawElementsUInt14resizeElementsEj,__ZN3osg16DrawElementsUInt15reserveElementsEj
,b6,b6,__ZN3osg16DrawElementsUInt10addElementEj,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,__ZNK3osg10DrawArrays6acceptERNS_16PrimitiveFunctorE,__ZNK3osg10DrawArrays6acceptERNS_21PrimitiveIndexFunctorE,b6,b6,__ZN3osg10DrawArrays13offsetIndicesEi,__ZN3osg7Program21setThreadSafeRefUnrefEb,b6,b6,b6,b6,b6,b6,b6,__ZN3osg7Program21resizeGLObjectBuffersEj,__ZNK3osg7Program16releaseGLObjectsEPNS_5StateE,b6
,b6,__ZNK3osg7Program5applyERNS_5StateE,__ZNK3osg7Program16compileGLObjectsERNS_5StateE,b6,b6,b6,b6,__ZN3osg7Program17PerContextProgram11linkProgramERNS_5StateE,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,__ZN16GLProgramManager14deleteGLObjectEj,b6,b6,b6,b6,b6,b6,__ZN15GLShaderManager14deleteGLObjectEj,b6,b6
,b6,b6,b6,b6,b6,__ZN3osg6Shader21resizeGLObjectBuffersEj,__ZNK3osg6Shader16releaseGLObjectsEPNS_5StateE,b6,b6,__ZN3osg17ConstShapeVisitor5applyERKNS_5ShapeE,__ZN3osg25BuildShapeGeometryVisitor5applyERKNS_6SphereE,__ZN3osg25BuildShapeGeometryVisitor5applyERKNS_3BoxE,__ZN3osg25BuildShapeGeometryVisitor5applyERKNS_4ConeE,__ZN3osg25BuildShapeGeometryVisitor5applyERKNS_8CylinderE,__ZN3osg25BuildShapeGeometryVisitor5applyERKNS_7CapsuleE,__ZN3osg25BuildShapeGeometryVisitor5applyERKNS_13InfinitePlaneE,__ZN3osg25BuildShapeGeometryVisitor5applyERKNS_12TriangleMeshE,__ZN3osg25BuildShapeGeometryVisitor5applyERKNS_10ConvexHullE,__ZN3osg25BuildShapeGeometryVisitor5applyERKNS_11HeightFieldE,__ZN3osg25BuildShapeGeometryVisitor5applyERKNS_14CompositeShapeE,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,__ZN3osg6Sphere6acceptERNS_12ShapeVisitorE,__ZNK3osg6Sphere6acceptERNS_17ConstShapeVisitorE,b6,__ZN3osg8StateSet21setThreadSafeRefUnrefEb,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,__ZN3osg8StateSet21resizeGLObjectBuffersEj,__ZNK3osg8StateSet16releaseGLObjectsEPNS_5StateE,b6,b6,__ZN23SetAssociateModesHelper8usesModeEj,__ZN23SetAssociateModesHelper15usesTextureModeEj,b6,__ZN26RemoveAssociateModesHelper8usesModeEj,__ZN26RemoveAssociateModesHelper15usesTextureModeEj,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,__ZNK3osg7Stencil5applyERNS_5StateE,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,__ZNK3osg6TexMat5applyERNS_5StateE,b6,b6,b6,b6,b6,b6,b6,__ZN3osg7Texture21resizeGLObjectBuffersEj,__ZNK3osg7Texture16releaseGLObjectsEPNS_5StateE,b6,b6,b6
,b6,b6,__ZNK3osg9Texture2D5applyERNS_5StateE,__ZNK3osg7Texture16compileGLObjectsERNS_5StateE,b6,b6,b6,b6,b6,b6,b6,b6,b6,__ZNK3osg9Texture2D14allocateMipmapERNS_5StateE,b6,b6,b6,b6,__ZN3osg20TextureObjectManager8newFrameEPNS_10FrameStampE,b6,__ZN3osg20TextureObjectManager11reportStatsERNSt3__213basic_ostreamIcNS1_11char_traitsIcEEEE,__ZNK3osg20TextureObjectManager14recomputeStatsERNSt3__213basic_ostreamIcNS1_11char_traitsIcEEEE,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,__ZNK3osg16TextureRectangle5applyERNS_5StateE,b6,b6,b6,b6,b6,b6,b6,b6,b6,__ZNK3osg16TextureRectangle14allocateMipmapERNS_5StateE,b6,b6,b6
,b6,b6,b6,b6,__ZN3osg9Transform6acceptERNS_11NodeVisitorE,b6,b6,b6,b6,__ZN16TransformVisitor5applyERN3osg9TransformE,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,__ZN3osg7Uniform7setNameERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE,b6,b6,__ZN3osg24DefaultUserDataContainer21setThreadSafeRefUnrefEb,b6,b6,b6,b6,b6
,b6,b6,b6,b6,__ZN3osg24DefaultUserDataContainer11setUserDataEPNS_10ReferencedE,b6,b6,b6,b6,__ZN3osg24DefaultUserDataContainer16removeUserObjectEj,b6,b6,b6,b6,b6,b6,b6,__ZN3osg24DefaultUserDataContainer15setDescriptionsERKNSt3__26vectorINS1_12basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEENS6_IS8_EEEE,b6,b6,b6,__ZN3osg24DefaultUserDataContainer14addDescriptionERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE,b6,b6,b6,b6,b6,b6,b6,b6
,b6,__ZN25VertexAttribArrayDispatch7disableERN3osg5StateE,b6,b6,b6,b6,b6,b6,b6,b6,__ZN3osg4View5Slave25updateSlaveImplementationERS0_,b6,b6,b6,b6,b6,b6,b6,b6,b6,__ZNK3osg8Viewport5applyERNS_5StateE,b6,b6,b6,__ZN3osg31TemplateTargetAttributeDispatchIjfE6assignEPKv,__ZN3osg31TemplateTargetAttributeDispatchIjfEclEj,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,__ZNK3osg9BlendFunc5applyERNS_5StateE,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,__ZNK3osg5Light5applyERNS_5StateE,b6,b6,b6,b6,b6,b6,b6,__ZNK3osg14ShaderComposer16releaseGLObjectsEPNS_5StateE,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,__ZNKSt3__210__function6__funcIZN4mjin11application6memory11Coordinator14setupSelectionEvE3__0NS_9allocatorIS6_EEFvRKbEE7__cloneEPNS0_6__baseISB_EE
,b6,b6,__ZNSt3__210__function6__funcIZN4mjin11application6memory11Coordinator14setupSelectionEvE3__0NS_9allocatorIS6_EEFvRKbEEclESA_,b6,b6,b6,b6,b6,b6,b6,__ZNKSt3__210__function6__funcIZN4mjin11application6memory4Game18matchSelectedItemsEvE3__1NS_9allocatorIS6_EEFvvEE7__cloneEPNS0_6__baseIS9_EE,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,__ZNKSt3__210__function6__funcIZN4mjin11application6memory4Game18animateMatchOrMissEbNS_8functionIFvvEEEE3__2NS_9allocatorIS9_EEFbdEE7__cloneEPNS0_6__baseISC_EE,b6,b6,b6,b6,b6,b6,b6,b6
,__ZNKSt3__210__function6__funcIZN4mjin11application6memory4Game18matchSelectedItemsEvE3__0NS_9allocatorIS6_EEFvvEE7__cloneEPNS0_6__baseIS9_EE,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,__ZN4mjin6render15VBOSetupVisitor5applyERN3osg5GeodeE,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,__ZN5osgDB13DatabasePager31FindCompileableGLObjectsVisitor5applyERN3osg8DrawableE,__ZN5osgDB13DatabasePager31FindCompileableGLObjectsVisitor5applyERN3osg7TextureE,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,__ZN5osgDB13DatabasePager20setProcessorAffinityERKN11OpenThreads8AffinityE,b6,__ZN5osgDB13DatabasePager16signalBeginFrameEPKN3osg10FrameStampE,b6,b6,__ZN5osgDB13DatabasePager16updateSceneGraphERKN3osg10FrameStampE,__ZN5osgDB13DatabasePager22removeExpiredSubgraphsERKN3osg10FrameStampE,b6,b6,b6,b6,__ZN5osgDB13DatabasePager20FindPagedLODsVisitor5applyERN3osg8PagedLODE,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,__ZN20SetBasedPagedLODList11removeNodesERNSt3__26vectorIN3osg7ref_ptrINS2_4NodeEEENS0_9allocatorIS5_EEEE,__ZN20SetBasedPagedLODList14insertPagedLODERKN3osg12observer_ptrINS0_8PagedLODEEE
,b6,b6,b6,b6,b6,__ZN5osgDB13DatabasePager22ExpirePagedLODsVisitor5applyERN3osg8PagedLODE,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,__ZN5osgDB10ImagePager16updateSceneGraphERKN3osg10FrameStampE,__ZN5osgDB10ImagePager16signalBeginFrameEPKN3osg10FrameStampE,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,__ZN3osg13ShapeDrawable8setShapeEPNS_5ShapeE,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE5imbueERKNS_6localeE,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,__ZNSt3__211__stdoutbufIwE5imbueERKNS_6localeE,b6,b6,b6,b6,b6,__ZNSt3__211__stdoutbufIcE5imbueERKNS_6localeE,b6,b6,b6,b6,b6,__ZNSt3__210__stdinbufIwE5imbueERKNS_6localeE,b6,b6,b6,b6,b6,__ZNSt3__210__stdinbufIcE5imbueERKNS_6localeE,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,__ZNKSt3__210moneypunctIcLb0EE11do_groupingEv,__ZNKSt3__210moneypunctIcLb0EE14do_curr_symbolEv,__ZNKSt3__210moneypunctIcLb0EE16do_positive_signEv,__ZNKSt3__210moneypunctIcLb0EE16do_negative_signEv,b6,__ZNKSt3__210moneypunctIcLb0EE13do_pos_formatEv,__ZNKSt3__210moneypunctIcLb0EE13do_neg_formatEv,b6,b6,b6,b6,__ZNKSt3__210moneypunctIcLb1EE11do_groupingEv,__ZNKSt3__210moneypunctIcLb1EE14do_curr_symbolEv,__ZNKSt3__210moneypunctIcLb1EE16do_positive_signEv,__ZNKSt3__210moneypunctIcLb1EE16do_negative_signEv,b6,__ZNKSt3__210moneypunctIcLb1EE13do_pos_formatEv,__ZNKSt3__210moneypunctIcLb1EE13do_neg_formatEv,b6,b6,b6
,b6,__ZNKSt3__210moneypunctIwLb0EE11do_groupingEv,__ZNKSt3__210moneypunctIwLb0EE14do_curr_symbolEv,__ZNKSt3__210moneypunctIwLb0EE16do_positive_signEv,__ZNKSt3__210moneypunctIwLb0EE16do_negative_signEv,b6,__ZNKSt3__210moneypunctIwLb0EE13do_pos_formatEv,__ZNKSt3__210moneypunctIwLb0EE13do_neg_formatEv,b6,b6,b6,b6,__ZNKSt3__210moneypunctIwLb1EE11do_groupingEv,__ZNKSt3__210moneypunctIwLb1EE14do_curr_symbolEv,__ZNKSt3__210moneypunctIwLb1EE16do_positive_signEv,__ZNKSt3__210moneypunctIwLb1EE16do_negative_signEv,b6,__ZNKSt3__210moneypunctIwLb1EE13do_pos_formatEv,__ZNKSt3__210moneypunctIwLb1EE13do_neg_formatEv,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,__ZNKSt3__28messagesIcE8do_closeEi,b6,b6,b6,b6,__ZNKSt3__28messagesIwE8do_closeEi,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,__ZNKSt3__28numpunctIcE11do_groupingEv,__ZNKSt3__28numpunctIcE11do_truenameEv,__ZNKSt3__28numpunctIcE12do_falsenameEv,b6,b6,b6,b6,__ZNKSt3__28numpunctIwE11do_groupingEv,__ZNKSt3__28numpunctIwE11do_truenameEv,__ZNKSt3__28numpunctIwE12do_falsenameEv
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,__ZN4mjin3log9logprintfEPKcz,b6,b6,b6,b6,__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE6sentryC2ERS3_,__ZNKSt3__28ios_base6getlocEv,b6,__ZNSt3__28ios_base5clearEj,b6,b6,b6,b6,__ZN9osgViewer14GraphicsWindow8getViewsERNSt3__24listIPNS_4ViewENS1_9allocatorIS4_EEEE,b6,b6,b6,b6
,b6,b6,b6,__ZN9osgViewer4ViewD2Ev,__ZN9osgViewer8RendererC1EPN3osg6CameraE,__ZN3osg5StatsC2ERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE,b6,b6,b6,__ZN9osgViewer5Scene12setSceneDataEPN3osg4NodeE,b6,b6,b6,b6,b6,__ZN3osg11NodeVisitorD2Ev,b6,b6,__ZN7osgUtil16ShaderGenVisitorD2Ev,b6,b6,b6,b6,__ZN5osgGA10EventQueueC2ENS_15GUIEventAdapter17MouseYOrientationE,b6,__ZN3osg4ViewD2Ev,b6,b6,__ZN3osg4ViewC2Ev,b6
,b6,b6,__ZNK3osg8Viewport19computeWindowMatrixEv,__ZN3osg7Matrixd8postMultERKS0_,b6,b6,b6,b6,b6,b6,b6,b6,b6,__ZN7osgUtil19IntersectionVisitorD2Ev,b6,b6,__ZN7osgUtil22LineSegmentIntersector12IntersectionC2ERKS1_,b6,__ZNSt3__26vectorIjNS_9allocatorIjEEEC2ERKS3_,__ZNSt3__26vectorIdNS_9allocatorIdEEEC2ERKS3_,b6,__ZN3osg16ObserverNodePath11setNodePathERKNSt3__26vectorIPNS_4NodeENS1_9allocatorIS4_EEEE,__ZN3osg11NodeVisitorC1ENS0_13TraversalModeE,b6,b6,__ZN3osg12observer_ptrIN9osgViewer4ViewEEC2EPS2_,b6,b6,b6,b6
,__ZN3osg7Matrixd8setTransERKNS_5Vec3dE,b6,b6,b6,b6,b6,b6,b6,__ZN3osg6Object7setNameEPKc,__ZN3osg6Camera18setGraphicsContextEPNS_15GraphicsContextE,b6,__ZN3osg6Camera11setViewportEPNS_8ViewportE,__ZN3osg6Camera29setRenderTargetImplementationENS0_26RenderTargetImplementationE,b6,b6,b6,__ZN3osg9Transform17setReferenceFrameENS0_14ReferenceFrameE,b6,b6,__ZNSt3__26vectorIN3osg7ref_ptrIN9osgViewer8KeystoneEEENS_9allocatorIS5_EEE21__push_back_slow_pathIKS5_EEvRT_,b6,b6,b6,b6,__ZN9osgViewer15KeystoneHandlerC1EPNS_8KeystoneE,__ZN3osg4Node16setEventCallbackEPNS_8CallbackE,b6,b6,b6,b6
,b6,b6,__ZN3osg4Node16setCullingActiveEb,b6,b6,__ZN3osg14PolygonStippleC2EPKh,b6,__ZNSt11logic_errorC2EPKc,b6,__ZNSt3__28ios_base4initEPv,b6,__ZNSt3__215basic_stringbufIcNS_11char_traitsIcEENS_9allocatorIcEEE3strERKNS_12basic_stringIcS2_S4_EE,__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEED2Ev,b6,b6,__ZN9osgViewer4View23setUpViewOnSingleScreenEj,b6,b6,b6,__ZN3osg5State21setMaxTexturePoolSizeEj,__ZN3osg5State26setMaxBufferObjectPoolSizeEj,b6,b6,b6,__ZN7osgUtil27IncrementalCompileOperation14assignContextsERNSt3__26vectorIPN3osg15GraphicsContextENS1_9allocatorIS5_EEEE,b6,b6,b6,b6,b6
,b6,__ZN5osgGA20TrackballManipulatorC1Ei,b6,b6,__ZN9osgViewer10ViewerBase17checkWindowStatusERKNSt3__26vectorIPN3osg15GraphicsContextENS1_9allocatorIS5_EEEE,b6,__ZN9osgViewer6Viewer19generatePointerDataERN5osgGA15GUIEventAdapterE,b6,__ZN5osgGA15GUIEventAdapter19copyPointerDataFromERKS0_,__ZN3osg15GraphicsContext5closeEb,b6,__ZN5osgGA12EventVisitor8addEventEPNS_5EventE,__ZNSt3__26vectorIPN3osg15GraphicsContextENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_,__ZNSt3__26vectorIPN11OpenThreads6ThreadENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_,b6,__ZNSt3__26vectorIPN3osg15OperationThreadENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_,__ZN9osgViewer6ViewerD2Ev,b6,b6,b6,b6,b6,__ZN9osgViewer10ViewerBaseD2Ev,__ZN9osgViewer10ViewerBaseC2Ev,__ZN9osgViewer4ViewC2Ev,b6,b6,b6,b6,__ZN9osgViewer5Scene16setDatabasePagerEPN5osgDB13DatabasePagerE
,__ZN3osg15GraphicsContext6TraitsC2EPNS_15DisplaySettingsE,b6,b6,__ZN3osg12observer_ptrINS_6ObjectEEC2EPS1_,b6,__ZNSt3__26vectorIPN3osg6CameraENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_,__ZN5osgGA15GUIEventAdapter14addPointerDataEPNS_11PointerDataE,b6,__ZNSt3__26vectorIN3osg7ref_ptrIN5osgGA11PointerDataEEENS_9allocatorIS5_EEE21__push_back_slow_pathIKS5_EEvRT_,b6,b6,__ZN7osgUtil14RayIntersector12IntersectionC2ERKS1_,b6,b6,__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE9push_backEc,b6,__ZN3osg10ReferencedC2Eb,b6,__ZNSt3__26vectorIjNS_9allocatorIjEEE21__push_back_slow_pathIKjEEvRT_,b6,__ZN3osg6Camera20setProcessorAffinityERKN11OpenThreads8AffinityE,b6,b6,b6,__ZN3osg15GraphicsContext17setGraphicsThreadEPNS_14GraphicsThreadE,__ZN3osg6Camera15setCameraThreadEPNS_15OperationThreadE,__ZN9osgViewer8Renderer25setGraphicsThreadDoesCullEb,__ZN3osg21EndOfDynamicDrawBlockC2Ej,b6,b6
,__ZN3osg15OperationThread3addEPNS_9OperationE,b6,b6,b6,__ZN7osgUtil12StatsVisitorD2Ev,__ZN9osgViewer10ViewerBase11makeCurrentEPN3osg15GraphicsContextE,b6,__ZNSt3__26vectorIPN9osgViewer14GraphicsWindowENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_,__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_,__ZN11OpenThreads7BarrierC2Ei,b6,b6,b6,b6,__ZNSt3__26vectorIN3osg5Vec4fENS_9allocatorIS2_EEEC2ERKS5_,b6,__ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEEC2ERKS5_,b6,__ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEEC2ERKS5_,b6,b6,b6,b6,b6,b6,b6,__ZNSt3__26vectorIN3osg7ref_ptrINS1_6ObjectEEENS_9allocatorIS4_EEE21__push_back_slow_pathIKS4_EEvRT_,b6,b6,__ZN3osg15DisplaySettingsC2ERKS0_
,b6,__ZN9osgViewer15KeystoneHandlerD2Ev,__ZN3osg6Object20setUserDataContainerEPNS_17UserDataContainerE,b6,b6,__ZN5osgGA15GUIEventHandlerD2Ev,b6,__ZN3osg8Drawable17setUseDisplayListEb,__ZN3osg4Node17setUpdateCallbackEPNS_8CallbackE,__ZNSt3__26vectorIN3osg5Vec4fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_,b6,__ZN3osg8Geometry14setVertexArrayEPNS_5ArrayE,b6,b6,b6,b6,__ZNSt3__26vectorItNS_9allocatorItEEE21__push_back_slow_pathIKtEEvRT_,b6,b6,__ZN22KeystoneUpdateCallback6updateEPN3osg8GeometryE,__ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_,b6,b6,__ZN9osgViewer8RendererD2Ev,__ZN7osgUtil16GLObjectsVisitorD2Ev,b6,b6,__ZN3osg12observer_ptrINS_6CameraEEC2EPS1_,__ZN11OpenThreads5MutexC2ENS0_9MutexTypeE,b6
,__ZN7osgUtil9SceneViewC2EPN3osg15DisplaySettingsE,b6,b6,__ZN9osgViewer14SceneSingleton6removeEPNS_5SceneE,b6,b6,__ZN9osgViewer14SceneSingleton3addEPNS_5SceneE,__ZN3osg12observer_ptrIN9osgViewer5SceneEEC2EPS2_,__ZNSt3__26vectorIN3osg12observer_ptrIN9osgViewer5SceneEEENS_9allocatorIS5_EEE21__push_back_slow_pathIKS5_EEvRT_,b6,b6,b6,__ZN5osgGA12EventVisitorD2Ev,b6,b6,b6,__ZN5osgGA17CameraManipulatorD2Ev,b6,__ZN5osgGA19StandardManipulatorD2Ev,b6,b6,b6,__ZN5osgGA16OrbitManipulatorC1Ei,b6,__ZN3osg18BoundingSphereImplINS_5Vec3fEE8expandByIS1_EEvRKNS_15BoundingBoxImplIT_EE,b6,__ZN3osg7Matrixd10makeRotateERKNS_4QuatE,__ZNK3osg7Matrixd9getRotateEv,b6,b6
,b6,b6,b6,b6,b6,b6,b6,__ZN3osg7Matrixd7preMultERKS0_,b6,__ZN7osgUtil19IntersectionVisitor15pushModelMatrixEPN3osg10RefMatrixdE,__ZN7osgUtil19IntersectionVisitor14pushViewMatrixEPN3osg10RefMatrixdE,b6,__ZN7osgUtil19IntersectionVisitor14setIntersectorEPNS_11IntersectorE,__ZN7osgUtil14StateToCompileD2Ev,__ZN3osg17PixelBufferObjectC2EPNS_5ImageE,__ZN3osg10BufferData15setBufferObjectEPNS_12BufferObjectE,__ZNSt3__26vectorINS_3mapINS_4pairIN3osg14StateAttribute4TypeEjEENS3_5State14AttributeStackENS_4lessIS6_EENS_9allocatorINS2_IKS6_S8_EEEEEENSB_ISF_EEE26__swap_out_circular_bufferERNS_14__split_bufferISF_RSG_EE,b6,__ZNSt3__26vectorINS_4pairIPKN3osg14StateAttributeEjEENS_9allocatorIS6_EEEC2ERKS9_,__ZNSt3__26vectorINS_3mapIjN3osg5State9ModeStackENS_4lessIjEENS_9allocatorINS_4pairIKjS4_EEEEEENS7_ISC_EEE26__swap_out_circular_bufferERNS_14__split_bufferISC_RSD_EE,b6,b6,b6,b6,b6,b6,b6,b6,__ZNSt3__26vectorIdNS_9allocatorIdEEE21__push_back_slow_pathIKdEEvRT_,__ZNSt3__214basic_iostreamIcNS_11char_traitsIcEEED2Ev
,b6,b6,b6,b6,b6,__ZN7osgUtil16GLObjectsVisitorC1Ej,b6,b6,b6,b6,__ZN3osg9CullStack12pushViewportEPNS_8ViewportE,__ZN3osg9CullStack20pushProjectionMatrixEPNS_10RefMatrixdE,b6,b6,b6,b6,b6,b6,__ZN3osg20ShadowVolumeOccluderC2ERKS0_,__ZNSt3__26vectorIN3osg20ShadowVolumeOccluderENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_,b6,b6,b6,__ZNSt3__26vectorIPN7osgUtil9RenderBinENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_,b6,b6,b6,__ZN3osg8PolytopeC2ERKS0_,__ZNSt3__26vectorIN3osg8PolytopeENS_9allocatorIS2_EEEC2ERKS5_,__ZNSt3__26vectorIN3osg5PlaneENS_9allocatorIS2_EEEC2ERKS5_
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,__ZN3osg12CullSettingsC2ERKS0_,b6,b6,b6,b6,__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEED2Ev,__ZNKSt3__215basic_stringbufIcNS_11char_traitsIcEENS_9allocatorIcEEE3strEv,b6,b6,b6,b6,b6,__ZN7osgUtil11CullVisitorD2Ev,b6,b6,__ZN3osg12CullSettings15setCullSettingsERKS0_,b6,b6,b6,b6
,b6,b6,__ZN7osgUtil11CullVisitorC1ERKS0_,__ZN3osg7MatrixfC2ERKNS_7MatrixdE,__ZN3osg7Matrixf8postMultERKS0_,b6,__ZN3osg9CullStackC2ERKS0_,__ZNSt3__26vectorIN3osg7ref_ptrINS1_10RefMatrixdEEENS_9allocatorIS4_EEE21__push_back_slow_pathIKS4_EEvRT_,b6,__ZNK3osg10Referenced11addObserverEPNS_8ObserverE,__ZNK3osg10Referenced14removeObserverEPNS_8ObserverE,b6,b6,b6,b6,__ZNSt3__26vectorIN3osg7ref_ptrIN7osgUtil10RenderLeafEEENS_9allocatorIS5_EEE21__push_back_slow_pathIKS5_EEvRT_,b6,b6,b6,b6,b6,__ZNSt3__26vectorIfNS_9allocatorIfEEEC2ERKS3_,b6,b6,__ZNSt3__26vectorIiNS_9allocatorIiEEEC2ERKS3_,b6,__ZNSt3__26vectorINS_4pairIN3osg7ref_ptrIKNS2_14StateAttributeEEENS3_INS2_10RefMatrixdEEEEENS_9allocatorIS9_EEE21__push_back_slow_pathIKS9_EEvRT_,__ZN3osg5State20applyModelViewMatrixEPKNS_10RefMatrixdE,b6,b6
,b6,b6,__ZNSt3__26vectorIPN7osgUtil10StateGraphENS_9allocatorIS3_EEEC2ERKS6_,__ZNSt3__26vectorIPN7osgUtil10RenderLeafENS_9allocatorIS3_EEEC2ERKS6_,b6,b6,__ZN7osgUtil9RenderBinC2ENS0_8SortModeE,b6,__ZNSt3__26vectorIPN7osgUtil10StateGraphENS_9allocatorIS3_EEE7reserveEj,__ZNSt3__26vectorIPN7osgUtil10StateGraphENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_,__ZN3osg5State12pushStateSetEPKNS_8StateSetE,b6,b6,b6,b6,b6,__ZN7osgUtil11RenderStage11copyTextureERN3osg10RenderInfoE,b6,b6,__ZN3osg21FrameBufferAttachmentC2ERNS_6Camera10AttachmentE,b6,b6,b6,__ZN3osg21FrameBufferAttachmentC2EPNS_12RenderBufferE,b6,b6,b6,__ZNSt3__26vectorIPN3osg6CameraENS_9allocatorIS3_EEEC2ERKS6_,__ZNSt3__26vectorIPN7osgUtil9RenderBinENS_9allocatorIS3_EEEC2ERKS6_,__ZN3osg10RenderInfoC2ERKS0_
,__ZN3osg21GLRenderBufferManagerC2Ej,__ZN3osg26GLFrameBufferObjectManagerC2Ej,__ZNSt3__24listINS_4pairIiN3osg7ref_ptrIN7osgUtil11RenderStageEEEEENS_9allocatorIS7_EEEC2ERKSA_,__ZNSt3__26vectorIN3osg7ref_ptrINS1_6CameraEEENS_9allocatorIS4_EEE21__push_back_slow_pathIKS4_EEvRT_,b6,b6,b6,b6,b6,__ZN3osg7Matrixd8setTransERKNS_5Vec3fE,b6,b6,b6,b6,b6,b6,b6,b6,__ZNSt3__26vectorIN3osg7ref_ptrINS1_14GLBufferObjectEEENS_9allocatorIS4_EEEC2Ej,__ZNSt3__26vectorIPN3osg10BufferDataENS_9allocatorIS3_EEE8__appendEj,__ZNSt3__26vectorIN3osg7ref_ptrINS1_14GLBufferObjectEEENS_9allocatorIS4_EEE8__appendEj,__ZN3osg21GLBufferObjectManagerC2Ej,b6,b6,b6,b6,b6,__ZN3osg17GLBufferObjectSet10moveToBackEPNS_14GLBufferObjectE,b6,b6
,b6,b6,__ZN3osg15GraphicsContext12removeCameraEPNS_6CameraE,b6,b6,__ZN11OpenThreads8AffinityC2ERKS0_,b6,__ZN3osg4Node11setStateSetEPNS_8StateSetE,b6,b6,b6,__ZNSt3__26vectorIN3osg7MatrixdENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_,b6,b6,__ZN3osg15DisplaySettings30setMaxNumberOfGraphicsContextsEj,b6,b6,__ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_,__ZN3osg10CullingSetC2ERKS0_,__ZNSt3__26vectorIN3osg10CullingSetENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_,__ZNSt3__26vectorINS_4pairIN3osg7ref_ptrINS2_8StateSetEEENS2_8PolytopeEEENS_9allocatorIS7_EEEC2ERKSA_,__ZNSt3__26vectorIN3osg20ShadowVolumeOccluderENS_9allocatorIS2_EEEC2ERKS5_,__ZNSt3__26vectorIN3osg7ref_ptrINS1_8ViewportEEENS_9allocatorIS4_EEE21__push_back_slow_pathIKS4_EEvRT_,b6,b6,b6,b6,b6,__ZNSt3__26vectorINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS4_IS6_EEE21__push_back_slow_pathIKS6_EEvRT_,__ZN3osg15DisplaySettings18setDisplaySettingsERKS0_
,b6,b6,b6,__ZN3osg16VertexArrayStateC2EPNS_5StateE,__ZN18DisplayListManagerC2Ej,__ZNSt3__26vectorIN3osg7ref_ptrINS1_16VertexArrayStateEEENS_9allocatorIS4_EEEC2Ej,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,__ZNSt3__26vectorIPN3osg12DrawElementsENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_,b6,b6,b6,b6,__ZNSt3__26vectorIN3osg7ref_ptrINS1_16VertexArrayStateEEENS_9allocatorIS4_EEE8__appendEj,__ZNK3osg8Geometry30drawVertexArraysImplementationERNS_10RenderInfoE,__ZNSt3__26vectorIN3osg7ref_ptrINS1_5ArrayEEENS_9allocatorIS4_EEE21__push_back_slow_pathIKS4_EEvRT_,__ZNSt3__26vectorIN3osg7ref_ptrINS1_12PrimitiveSetEEENS_9allocatorIS4_EEE21__push_back_slow_pathIKS4_EEvRT_,__ZN3osg13TemplateArrayINS_5Vec3fELNS_5Array4TypeE28ELi3ELi5126EEC2Ej,b6,__ZNSt3__26vectorIN21GeometryUtilFunctions7PtrDataENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_
,b6,__ZNSt3__26vectorINS_4pairIN3osg7ref_ptrINS2_5ArrayEEES5_EENS_9allocatorIS6_EEE21__push_back_slow_pathIKS6_EEvRT_,b6,b6,b6,b6,b6,b6,b6,__ZNSt3__26vectorINS_3setINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS7_EENS5_IS7_EEEENS5_ISB_EEE26__swap_out_circular_bufferERNS_14__split_bufferISB_RSC_EE,b6,__ZN3osg12GLExtensionsC2Ej,b6,b6,b6,b6,b6,b6,_glGetIntegerv__wrapper,b6,b6,b6,b6,__ZN3osg15GraphicsContext16ScreenIdentifier19setScreenIdentifierERKNSt3__212basic_stringIcNS2_11char_traitsIcEENS2_9allocatorIcEEEE,b6,b6,b6,b6,b6,__ZN3osg4Node12removeParentEPNS_5GroupE
,b6,__ZNSt3__26vectorIN3osg7ref_ptrINS1_4NodeEEENS_9allocatorIS4_EEE21__push_back_slow_pathIKS4_EEvRT_,b6,__ZN3osg4Node9addParentEPNS_5GroupE,__ZN3osg4Node38setNumChildrenRequiringUpdateTraversalEj,__ZN3osg4Node37setNumChildrenRequiringEventTraversalEj,__ZN3osg4Node33setNumChildrenWithCullingDisabledEj,__ZN3osg4Node31setNumChildrenWithOccluderNodesEj,b6,__ZNSt3__26vectorIN3osg7ref_ptrINS1_5Image25DimensionsChangedCallbackEEENS_9allocatorIS5_EEEC2ERKS8_,b6,b6,b6,b6,b6,b6,__ZNSt3__26vectorIjNS_9allocatorIjEEE7reserveEj,__ZNSt3__26vectorIN3osg6KdTree6KdNodeENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_,b6,__ZNSt3__26vectorIN3osg6KdTree6KdNodeENS_9allocatorIS3_EEEC2ERKS6_,b6,b6,__ZNSt3__26vectorIPN3osg5GroupENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_,b6,b6,b6,b6,b6,b6,__ZN3osg16ObserverNodePath12_setNodePathERKNSt3__26vectorIPNS_4NodeENS1_9allocatorIS4_EEEE
,b6,__ZNSt3__26vectorIPN3osg4NodeENS_9allocatorIS3_EEE8__appendEj,b6,b6,b6,b6,__ZN3osg15OperationThread17setOperationQueueEPNS_14OperationQueueE,__ZN3osg14OperationQueue3addEPNS_9OperationE,b6,b6,__ZNSt3__26vectorItNS_9allocatorItEEEC2ERKS3_,b6,b6,b6,b6,b6,__ZNSt3__26vectorIN3osg7ref_ptrINS1_6ShaderEEENS_9allocatorIS4_EEE21__push_back_slow_pathIKS4_EEvRT_,b6,b6,__ZNSt3__26vectorIN3osg7ref_ptrINS1_7Program17PerContextProgramEEENS_9allocatorIS5_EEE21__push_back_slow_pathIKS5_EEvRT_,b6,b6,b6,b6,b6,b6,__ZNSt3__26vectorIiNS_9allocatorIiEEE21__push_back_slow_pathIKiEEvRT_,b6,b6,b6
,b6,b6,b6,b6,__ZN3osg11ObserverSet19signalObjectDeletedEPv,b6,b6,__ZN3osg11ObserverSetC2EPKNS_10ReferencedE,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,__ZNSt3__26vectorIN3osg7ref_ptrINS1_6Shader16PerContextShaderEEENS_9allocatorIS5_EEE21__push_back_slow_pathIKS5_EEvRT_,b6,__ZN3osg6ShaderC2ENS0_4TypeE,b6,b6,b6,b6,__ZNSt3__26vectorIfNS_9allocatorIfEEE7reserveEj,__ZNSt3__26vectorIfNS_9allocatorIfEEE21__push_back_slow_pathIKfEEvRT_,__ZNSt3__26vectorINS_4pairIjN3osg5Vec3fEEENS_9allocatorIS4_EEE21__push_back_slow_pathIKS4_EEvRT_,__ZNSt3__26vectorINS_4pairIjN3osg5Vec3fEEENS_9allocatorIS4_EEE7reserveEj
,b6,b6,b6,b6,__Z9transformRNSt3__26vectorINS_4pairIjN3osg5Vec3fEEENS_9allocatorIS4_EEEERKNS2_7MatrixdE,__ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE7reserveEj,__Z17computeFrontPlaneRKNSt3__26vectorINS_4pairIjN3osg5Vec3fEEENS_9allocatorIS4_EEEE,__ZNSt3__26vectorIN3osg5PlaneENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_,b6,b6,__ZNSt3__26vectorIN3osg8PolytopeENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_,b6,__ZN3osg25BuildShapeGeometryVisitor9setMatrixERKNS_7MatrixdE,b6,b6,__ZNSt3__26vectorIPN3osg8StateSetENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_,b6,__ZN3osg8StateSet15removeAttributeEPNS_14StateAttributeE,__ZN3osg12GLExtensions3SetEjPS0_,b6,b6,b6,b6,__ZN3osg20AttributeDispatchers8setStateEPNS_5StateE,b6,b6,__ZNSt3__26vectorIN3osg17VertexAttribAliasENS_9allocatorIS2_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS2_RS4_EE,b6,__ZNSt3__26vectorINS_4pairINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEjEENS5_IS8_EEE21__push_back_slow_pathIKS8_EEvRT_,__ZN3osg21GraphicsCostEstimator9calibrateERNS_10RenderInfoE
,__ZN3osg20TextureObjectManagerC2Ej,b6,b6,__ZNSt3__26vectorIPKN3osg8StateSetENS_9allocatorIS4_EEE21__push_back_slow_pathIKS4_EEvRT_,__ZNSt3__26vectorIPN3osg15ShaderComponentENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_,b6,b6,b6,b6,b6,b6,b6,b6,__ZN3osg14StateAttribute9addParentEPNS_8StateSetE,__ZNSt3__26vectorINS_3mapINS_4pairIN3osg14StateAttribute4TypeEjEENS2_INS3_7ref_ptrIS4_EEjEENS_4lessIS6_EENS_9allocatorINS2_IKS6_S9_EEEEEENSC_ISG_EEE8__appendEj,b6,b6,__ZN3osg7Uniform9addParentEPNS_8StateSetE,__ZNSt3__26vectorINS_3mapINS_4pairIN3osg14StateAttribute4TypeEjEENS2_INS3_7ref_ptrIS4_EEjEENS_4lessIS6_EENS_9allocatorINS2_IKS6_S9_EEEEEENSC_ISG_EEE26__swap_out_circular_bufferERNS_14__split_bufferISG_RSH_EE,b6,b6,b6,__ZN3osg9Texture2DC2EPNS_5ImageE,__ZNSt3__26vectorIPN3osg4NodeENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_,b6,b6,b6,b6,b6,__ZNSt3__26vectorINS_3mapIjjNS_4lessIjEENS_9allocatorINS_4pairIKjjEEEEEENS4_IS9_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS9_RSA_EE
,__ZN3osg5Stats8allocateEj,__ZNSt3__26vectorINS_3mapINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEdNS_4lessIS7_EENS5_INS_4pairIKS7_dEEEEEENS5_ISE_EEE8__appendEj,__ZNSt3__26vectorINS_3mapINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEdNS_4lessIS7_EENS5_INS_4pairIKS7_dEEEEEENS5_ISE_EEE26__swap_out_circular_bufferERNS_14__split_bufferISE_RSF_EE,b6,b6,__ZN3osg9Texture2D8setImageEPNS_5ImageE,b6,b6,__ZNSt3__26vectorIN3osg7ref_ptrINS1_7Texture13TextureObjectEEENS_9allocatorIS5_EEE8__appendEj,b6,b6,b6,b6,b6,b6,b6,b6,b6,_glDeleteTextures__wrapper,b6,__ZN3osg16TextureObjectSet10moveToBackEPNS_7Texture13TextureObjectE,b6,b6,b6,__ZNSt3__26vectorIN3osg7ref_ptrINS1_7Texture13TextureObjectEEENS_9allocatorIS5_EEEC2Ej,__ZN3osg16TextureRectangle8setImageEPNS_5ImageE,b6,b6,b6,b6
,b6,b6,b6,b6,__ZN3osg7Uniform8copyDataERKS0_,__ZN3osg7Uniform14setNumElementsEj,b6,b6,b6,__ZNSt3__26vectorIN3osg7ref_ptrINS1_16VertexArrayState13ArrayDispatchEEENS_9allocatorIS5_EEE21__push_back_slow_pathIKS5_EEvRT_,__ZN23VertexArrayStateManagerC2Ej,b6,__ZN3osg4View15setLightingModeENS0_12LightingModeE,b6,b6,__ZNSt3__26vectorIN3osg4View5SlaveENS_9allocatorIS3_EEEC2ERKS6_,__ZN3osg4View5SlaveC2ERKS1_,__ZNSt3__26vectorIN3osg4View5SlaveENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,__ZNSt3__26vectorIPKN3osg6ShaderENS_9allocatorIS4_EEE21__push_back_slow_pathIKS4_EEvRT_,b6,b6,__ZNSt3__26vectorIPKN3osg6ShaderENS_9allocatorIS4_EEEC2ERKS7_,__ZNSt3__26vectorIPN3osg15ShaderComponentENS_9allocatorIS3_EEEC2ERKS6_,b6,b6,b6,b6,b6,b6,b6,__ZN4mjin11application6memory11CoordinatorC2EPN9osgViewer6ViewerE,b6,b6,b6,b6,b6,b6,b6,__ZN4mjin11application6memory10observable16VariableCallbackIbEC2ENSt3__28functionIFvRKbEEE
,__ZN4mjin11application6memory10observable8VariableIbE9subscribeENS2_16VariableCallbackIbEE,b6,__ZN4mjin11application6memory10observable16VariableCallbackIbEC2ERKS4_,__ZNSt3__26vectorIN4mjin11application6memory10observable16VariableCallbackIbEENS_9allocatorIS6_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS6_RS8_EE,b6,__ZN9osgViewer4View18removeEventHandlerEPN5osgGA12EventHandlerE,b6,b6,b6,b6,b6,__ZN9osgViewer4View12setSceneDataIN3osg5GroupEEEvRKNS2_7ref_ptrIT_EE,b6,__ZN4mjin11application6memory8material4Pool15releaseMaterialEPv,b6,b6,b6,__ZN4mjin11application6memory11setObjectIdEPN3osg6ObjectERKNSt3__212basic_stringIcNS5_11char_traitsIcEENS5_9allocatorIcEEEE,b6,__ZNSt3__26vectorIiNS_9allocatorIiEEE26__swap_out_circular_bufferERNS_14__split_bufferIiRS2_EE,__ZNSt3__28functionIFvvEEC2IZN4mjin11application6memory4Game18matchSelectedItemsEvE3__0vEET_,b6,b6,__ZNSt3__28functionIFbdEEC2IZN4mjin11application6memory4Game18animateMatchOrMissEbNS0_IFvvEEEE3__2vEET_,b6,__ZZN4mjin11application6memory4Game18animateMatchOrMissEbNSt3__28functionIFvvEEEEN3__2C2ERKS7_,b6,__ZZN4mjin11application6memory4Game18matchSelectedItemsEvEN3__0C2ERKS3_,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,__ZN7osgUtil22LineSegmentIntersector20getFirstIntersectionEv,b6,b6,b6,b6,b6,__ZNSt3__26vectorIN4mjin11application6memory5input12MOUSE_BUTTONENS_9allocatorIS5_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS5_RS7_EE,__ZNKSt3__28functionIFvRKbEEclES2_,__ZN3osg21DrawableEventCallbackC2Ev,__ZN3osg8CallbackC2Ev,__ZN5osgGA15GUIEventHandlerC2Ev,b6,__ZN4mjin11application6memory10observable8VariableIbEC2Eb,__ZNSt3__26vectorIiNS_9allocatorIiEEE21__push_back_slow_pathIRKiEEvOT_
,b6,b6,b6,b6,__ZNSt3__26vectorIN4mjin11application6memory4ItemENS_9allocatorIS4_EEE21__push_back_slow_pathIRKS4_EEvOT_,__ZNSt3__26vectorIN4mjin11application6memory4ItemENS_9allocatorIS4_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS4_RS6_EE,b6,b6,__ZN5osgDB13DatabasePager12RequestQueue10invalidateEPNS0_15DatabaseRequestE,b6,__ZN7osgUtil27IncrementalCompileOperation6removeEPNS0_10CompileSetE,b6,__ZN5osgDB13DatabasePager12RequestQueue9takeFirstERN3osg7ref_ptrINS0_15DatabaseRequestEEE,b6,__ZN5osgDB13DatabasePager12RequestQueue9addNoLockEPNS0_15DatabaseRequestE,b6,b6,b6,__ZNK5osgDB12ReaderWriter10ReadResult13statusMessageEv,b6,b6,b6,b6,b6,b6,b6,b6,__ZN5osgDB13DatabasePagerC2ERKS0_,b6,__ZNSt3__26vectorIN3osg7ref_ptrIN5osgDB13DatabasePager14DatabaseThreadEEENS_9allocatorIS6_EEE21__push_back_slow_pathIKS6_EEvRT_
,b6,__ZN3osg8PagedLOD20expandPerRangeDataToEj,__ZN5osgDB11ObjectCache14addObjectCacheEPS0_,b6,__ZN5osgDB13DatabasePager12RequestQueueC2EPS0_,b6,b6,b6,b6,b6,b6,__ZN3osg12observer_ptrINS_8PagedLODEEC2ERKNS_7ref_ptrIS1_EE,b6,__ZN5osgDB10ImagePager9ReadQueue9takeFirstERN3osg7ref_ptrINS0_12ImageRequestEEE,b6,b6,__ZN3osg13ImageSequence8addImageEPNS_5ImageE,__ZNSt3__26vectorIN3osg7ref_ptrIN5osgDB10ImagePager12ImageRequestEEENS_9allocatorIS6_EEE21__push_back_slow_pathIKS6_EEvRT_,b6,b6,__ZN5osgDB10ImagePager9ReadQueue3addEPNS0_12ImageRequestE,b6,b6,__ZNSt3__26vectorIN3osg7ref_ptrIN5osgDB10ImagePager11ImageThreadEEENS_9allocatorIS6_EEE21__push_back_slow_pathIKS6_EEvRT_,b6,b6,b6,b6,b6,__ZNSt3__25dequeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS4_IS6_EEEC2ERKS8_
,b6,b6,b6,__ZNSt3__214__split_bufferIPNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERNS4_IS7_EEE10push_frontERKS7_,b6,b6,b6,b6,b6,b6,b6,b6,b6,__ZN5osgDB9FileCacheC2ERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE,b6,b6,__ZN5osgDB8Registry16registerProtocolERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE,b6,__ZN5osgDB33convertStringPathIntoFilePathListERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEERNS0_5dequeIS6_NS4_IS6_EEEE,b6,b6,__ZNSt3__26vectorIN3osg7ref_ptrIN5osgDB14DynamicLibraryEEENS_9allocatorIS5_EEE21__push_back_slow_pathIKS5_EEvRT_,b6,b6,b6,b6,b6,__ZN5osgDB17getSimpleFileNameERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE,b6,b6
,b6,b6,b6,__ZNSt3__26vectorIN5osgDB12ReaderWriter10ReadResultENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_,b6,b6,__ZN5osgDB16getFileExtensionERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE,b6,__ZN5osgDB17getServerProtocolERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE,b6,b6,b6,b6,b6,b6,b6,__ZNSt3__26vectorIN3osg7ref_ptrIN5osgDB12ReaderWriterEEENS_9allocatorIS5_EEE21__push_back_slow_pathIKS5_EEvRT_,b6,b6,b6,b6,__ZNSt3__26vectorIN5osgDB12ReaderWriter11WriteResultENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_,b6,__ZNK5osgDB12ReaderWriter11WriteResult13statusMessageEv,b6,b6,b6,b6,b6,b6
,b6,b6,b6,__ZN5osgDB17getServerFileNameERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE,b6,__ZN5osgDB11getFilePathERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,__ZN5osgDB11getRealPathERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE,b6,__ZN5osgDB20getDirectoryContentsERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE,b6,b6,b6,b6,b6,__ZNSt3__26vectorIN3osg13ImageSequence9ImageDataENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_,__ZN3osg13ImageSequence15setImageToChildEi
,_GLES2_WindowEvent,b6,b6,b6,b6,b6,_GLES2_UnlockTexture,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,_GLES2_DestroyTexture,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,_SW_WindowEvent,b6,b6,b6,b6,b6,b6,b6,_SW_UnlockTexture,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,_SW_DestroyTexture,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,_Emscripten_SetWindowTitle,_Emscripten_SetWindowSize,_Emscripten_DestroyWindow,b6
,b6,b6,_Emscripten_DestroyWindowFramebuffer,b6,b6,b6,b6,b6,b6,b6,_Emscripten_GLES_SwapWindow,_Emscripten_GLES_DeleteContext,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,_SDL_DUMMY_DestroyWindowFramebuffer,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,_SDL_DestroyWindowTexture,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,_emscripten_glPixelStorei__wrapper,b6,_emscripten_glGetIntegerv__wrapper,_emscripten_glGetFloatv__wrapper,_emscripten_glGetBooleanv__wrapper,_emscripten_glGenTextures__wrapper,_emscripten_glDeleteTextures__wrapper,b6,b6
,b6,b6,b6,_emscripten_glBindTexture__wrapper,b6,b6,b6,b6,b6,_emscripten_glGenBuffers__wrapper,_emscripten_glDeleteBuffers__wrapper,b6,b6,b6,b6,_emscripten_glGenRenderbuffers__wrapper,_emscripten_glDeleteRenderbuffers__wrapper,_emscripten_glBindRenderbuffer__wrapper,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,_emscripten_glUniform1i__wrapper,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,_emscripten_glBindBuffer__wrapper,_emscripten_glVertexAttrib1fv__wrapper,_emscripten_glVertexAttrib2fv__wrapper,_emscripten_glVertexAttrib3fv__wrapper,_emscripten_glVertexAttrib4fv__wrapper,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,_emscripten_glAttachShader__wrapper,_emscripten_glDetachShader__wrapper,b6,b6,b6,b6,b6,b6,b6,_emscripten_glBindFramebuffer__wrapper,_emscripten_glGenFramebuffers__wrapper,_emscripten_glDeleteFramebuffers__wrapper,b6,b6,b6,b6,b6,b6,b6,_emscripten_glBindProgramARB__wrapper,_emscripten_glGetPointerv__wrapper,b6,b6,b6,b6
,b6,b6,b6,_emscripten_glGenVertexArrays__wrapper,_emscripten_glDeleteVertexArrays__wrapper,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,_emscripten_glVertexAttribDivisor__wrapper,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,_emscripten_glBlendFunc__wrapper,_emscripten_glBlendEquationSeparate__wrapper,b6,b6,_emscripten_glStencilMaskSeparate__wrapper,_emscripten_glHint__wrapper,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,_emscripten_glDrawBuffers__wrapper,b6,__ZNSt3__28ios_base16__call_callbacksENS0_5eventE,b6,b6,b6,__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEE6sentryC2ERS3_,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,__ZNSt13runtime_errorC2EPKc,b6,b6,b6,b6,b6,b6,b6,__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7reserveEj,b6,b6,__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE9push_backEw,b6,b6,b6,b6,__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7reserveEj,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,__ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lj28EEEEC2Ej,b6,__ZNSt3__26locale5__imp7installINS_7collateIcEEEEvPT_,b6,__ZNSt3__26locale5__imp7installINS_7collateIwEEEEvPT_,__ZNSt3__26locale5__imp7installINS_5ctypeIcEEEEvPT_,b6,__ZNSt3__26locale5__imp7installINS_5ctypeIwEEEEvPT_,b6,__ZNSt3__26locale5__imp7installINS_7codecvtIcc11__mbstate_tEEEEvPT_,b6,__ZNSt3__26locale5__imp7installINS_7codecvtIwc11__mbstate_tEEEEvPT_,b6,__ZNSt3__26locale5__imp7installINS_7codecvtIDsc11__mbstate_tEEEEvPT_,b6,__ZNSt3__26locale5__imp7installINS_7codecvtIDic11__mbstate_tEEEEvPT_,__ZNSt3__26locale5__imp7installINS_8numpunctIcEEEEvPT_,__ZNSt3__26locale5__imp7installINS_8numpunctIwEEEEvPT_,b6,__ZNSt3__26locale5__imp7installINS_7num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvPT_,b6,__ZNSt3__26locale5__imp7installINS_7num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvPT_
,b6,__ZNSt3__26locale5__imp7installINS_7num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvPT_,b6,__ZNSt3__26locale5__imp7installINS_7num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvPT_,b6,__ZNSt3__26locale5__imp7installINS_10moneypunctIcLb0EEEEEvPT_,b6,__ZNSt3__26locale5__imp7installINS_10moneypunctIcLb1EEEEEvPT_,b6,__ZNSt3__26locale5__imp7installINS_10moneypunctIwLb0EEEEEvPT_,b6,__ZNSt3__26locale5__imp7installINS_10moneypunctIwLb1EEEEEvPT_,b6,__ZNSt3__26locale5__imp7installINS_9money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvPT_,b6,__ZNSt3__26locale5__imp7installINS_9money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvPT_,b6,__ZNSt3__26locale5__imp7installINS_9money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvPT_,b6,__ZNSt3__26locale5__imp7installINS_9money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvPT_,b6,__ZNSt3__26locale5__imp7installINS_8time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvPT_,b6,__ZNSt3__26locale5__imp7installINS_8time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvPT_,b6,__ZNSt3__26locale5__imp7installINS_8time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvPT_,b6,__ZNSt3__26locale5__imp7installINS_8time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvPT_,b6,__ZNSt3__26locale5__imp7installINS_8messagesIcEEEEvPT_
,b6,__ZNSt3__26locale5__imp7installINS_8messagesIwEEEEvPT_,__ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lj28EEEE8allocateEj,__ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lj28EEEE18__construct_at_endEj,__ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lj28EEEE6resizeEj,__ZNSt3__214__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lj28EEEE18__construct_at_endEj,__ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lj28EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE,b6,b6,b6,b6,b6,b6,__ZNSt3__218__libcpp_refstringC2EPKc,b6,b6,b6,b6,__ZNSt11logic_errorC2ERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE,b6,b6,__ZNSt13runtime_errorC2ERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE,b6,b6,b6,_abort_message,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6];
var FUNCTION_TABLE_iiiiiii = [b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRb,__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRl,__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRx,__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRt,__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjS8_,__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRm,__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRy,__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRf,__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRd,__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRe,__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRPv,b7,b7,__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRb,__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRl,__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRx,__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRt
,__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjS8_,__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRm,__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRy,__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRf,__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRd,__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRe,__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRPv,b7,b7,b7,b7,__ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcx,b7,__ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcy,b7,b7,b7,b7,b7,b7,b7,__ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwx,b7,__ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwy,b7,b7,b7,b7,b7,b7
,__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE11do_get_timeES4_S4_RNS_8ios_baseERjP2tm,__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE11do_get_dateES4_S4_RNS_8ios_baseERjP2tm,__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE14do_get_weekdayES4_S4_RNS_8ios_baseERjP2tm,__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE16do_get_monthnameES4_S4_RNS_8ios_baseERjP2tm,__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE11do_get_yearES4_S4_RNS_8ios_baseERjP2tm,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE11do_get_timeES4_S4_RNS_8ios_baseERjP2tm,__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE11do_get_dateES4_S4_RNS_8ios_baseERjP2tm,__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE14do_get_weekdayES4_S4_RNS_8ios_baseERjP2tm,__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE16do_get_monthnameES4_S4_RNS_8ios_baseERjP2tm,__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE11do_get_yearES4_S4_RNS_8ios_baseERjP2tm,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,__ZNKSt3__29money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_bRNS_8ios_baseEcRKNS_12basic_stringIcS3_NS_9allocatorIcEEEE,b7,b7,b7,__ZNKSt3__29money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_bRNS_8ios_baseEwRKNS_12basic_stringIwS3_NS_9allocatorIwEEEE,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,__ZNSt3__216__pad_and_outputIcNS_11char_traitsIcEEEENS_19ostreambuf_iteratorIT_T0_EES6_PKS4_S8_S8_RNS_8ios_baseES4_,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,__ZNSt3__216__pad_and_outputIwNS_11char_traitsIwEEEENS_19ostreambuf_iteratorIT_T0_EES6_PKS4_S8_S8_RNS_8ios_baseES4_,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7];
var FUNCTION_TABLE_iiiiiiiiid = [b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,__ZN9osgViewer4View18assignStereoCameraEPN3osg15DisplaySettingsEPNS1_15GraphicsContextEiiiijd,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8];
var FUNCTION_TABLE_ii = [b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,__ZNK3osg15GraphicsContext9cloneTypeEv,b9,b9,__ZNK9osgViewer14GraphicsWindow11libraryNameEv,__ZNK9osgViewer14GraphicsWindow9classNameEv,__ZN3osg6Object6asNodeEv,__ZNK3osg6Object6asNodeEv,__ZN3osg6Object13asNodeVisitorEv,__ZNK3osg6Object13asNodeVisitorEv,__ZN3osg6Object10asStateSetEv,__ZNK3osg6Object10asStateSetEv,__ZN3osg6Object16asStateAttributeEv,__ZNK3osg6Object16asStateAttributeEv,__ZN3osg6Object9asUniformEv,__ZNK3osg6Object9asUniformEv,__ZN3osg6Object8asCameraEv,__ZNK3osg6Object8asCameraEv,__ZN3osg6Object10asDrawableEv
,__ZNK3osg6Object10asDrawableEv,__ZN3osg6Object10asCallbackEv,__ZNK3osg6Object10asCallbackEv,__ZN3osg6Object16asCallbackObjectEv,__ZNK3osg6Object16asCallbackObjectEv,__ZN3osg6Object19asUserDataContainerEv,__ZNK3osg6Object19asUserDataContainerEv,b9,b9,b9,__ZN3osg6Object11getUserDataEv,__ZNK3osg6Object11getUserDataEv,b9,b9,b9,__ZNK9osgViewer14GraphicsWindow5validEv,b9,__ZN9osgViewer14GraphicsWindow21realizeImplementationEv,__ZNK9osgViewer14GraphicsWindow24isRealizedImplementationEv,b9,__ZN9osgViewer14GraphicsWindow25makeCurrentImplementationEv,b9,__ZN9osgViewer14GraphicsWindow28releaseContextImplementationEv,b9,b9,b9,__ZN9osgViewer14GraphicsWindow11checkEventsEv,b9,b9,b9
,__ZNK9osgViewer14GraphicsWindow19getWindowDecorationEv,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,__ZN5osgGA16GUIActionAdapter6asViewEv,b9,b9,b9,b9,b9,__ZNK9osgViewer4View9cloneTypeEv,b9,b9,__ZNK9osgViewer4View11libraryNameEv,__ZNK9osgViewer4View9classNameEv,b9,b9,b9,b9
,__ZN9osgViewer4View6asViewEv,b9,b9,b9,b9,b9,b9,b9,__ZNK9osgViewer4View24requiresUpdateSceneGraphEv,__ZNK9osgViewer4View14requiresRedrawEv,b9,b9,__ZThn36_N9osgViewer4View6asViewEv,b9,b9,b9,b9,b9,b9,b9,__ZTv0_n20_NK9osgViewer4View9cloneTypeEv,b9,b9,__ZTv0_n32_NK9osgViewer4View11libraryNameEv,__ZTv0_n36_NK9osgViewer4View9classNameEv,b9,b9,__ZNK3osg11NodeVisitor9cloneTypeEv,b9,b9
,__ZNK37CollectedCoordinateSystemNodesVisitor11libraryNameEv,__ZNK37CollectedCoordinateSystemNodesVisitor9classNameEv,__ZN3osg11NodeVisitor13asNodeVisitorEv,__ZNK3osg11NodeVisitor13asNodeVisitorEv,__ZN3osg11NodeVisitor15asUpdateVisitorEv,__ZNK3osg11NodeVisitor15asUpdateVisitorEv,__ZN3osg11NodeVisitor13asCullVisitorEv,__ZNK3osg11NodeVisitor13asCullVisitorEv,__ZN3osg11NodeVisitor14asEventVisitorEv,__ZNK3osg11NodeVisitor14asEventVisitorEv,__ZN3osg11NodeVisitor21asIntersectionVisitorEv,__ZNK3osg11NodeVisitor21asIntersectionVisitorEv,__ZN3osg11NodeVisitor11asCullStackEv,__ZNK3osg11NodeVisitor11asCullStackEv,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,__ZTv0_n20_NK3osg11NodeVisitor9cloneTypeEv,b9,b9,__ZTv0_n32_NK37CollectedCoordinateSystemNodesVisitor11libraryNameEv,__ZTv0_n36_NK37CollectedCoordinateSystemNodesVisitor9classNameEv,__ZTv0_n48_N3osg11NodeVisitor13asNodeVisitorEv,__ZTv0_n52_NK3osg11NodeVisitor13asNodeVisitorEv,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,__ZN9osgViewer6Viewer14getViewerStatsEv,__ZNK9osgViewer6Viewer14getViewerStatsEv,b9,__ZNK9osgViewer6Viewer10isRealizedEv,b9,b9,b9,b9,__ZN9osgViewer10ViewerBase25suggestBestThreadingModelEv,b9,b9,b9,__ZN9osgViewer6Viewer3runEv,__ZN9osgViewer6Viewer18checkNeedToDoFrameEv,__ZN9osgViewer6Viewer11checkEventsEv,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,__ZN9osgViewer6Viewer19getViewerFrameStampEv,b9,b9,b9,b9,__ZNK9osgViewer6Viewer9cloneTypeEv,b9,b9,__ZNK9osgViewer6Viewer11libraryNameEv,__ZNK9osgViewer6Viewer9classNameEv,b9,b9,b9,b9,__ZThn104_NK9osgViewer6Viewer9cloneTypeEv,b9,b9,__ZThn104_NK9osgViewer6Viewer11libraryNameEv,__ZThn104_NK9osgViewer6Viewer9classNameEv,b9,b9,b9,b9,b9,b9,b9,b9
,b9,__ZTv0_n20_NK9osgViewer6Viewer9cloneTypeEv,b9,b9,__ZTv0_n32_NK9osgViewer6Viewer11libraryNameEv,__ZTv0_n36_NK9osgViewer6Viewer9classNameEv,__ZN9osgViewer10ViewerBase3runEv,b9,b9,b9,b9,b9,__ZNK3osg4View9cloneTypeEv,b9,b9,__ZNK3osg4View11libraryNameEv,__ZNK3osg4View9classNameEv,b9,b9,b9,b9,b9,b9,__ZTv0_n20_NK3osg4View9cloneTypeEv,b9,b9,__ZTv0_n32_NK3osg4View11libraryNameEv,__ZTv0_n36_NK3osg4View9classNameEv,b9,b9
,__ZNK9osgViewer22GraphicsWindowEmbedded11libraryNameEv,__ZNK9osgViewer22GraphicsWindowEmbedded9classNameEv,__ZNK9osgViewer22GraphicsWindowEmbedded5validEv,__ZN9osgViewer22GraphicsWindowEmbedded21realizeImplementationEv,__ZNK9osgViewer22GraphicsWindowEmbedded24isRealizedImplementationEv,b9,__ZN9osgViewer22GraphicsWindowEmbedded25makeCurrentImplementationEv,__ZN9osgViewer22GraphicsWindowEmbedded28releaseContextImplementationEv,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE4syncEv,__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE9showmanycEv,b9,__ZNSt3__215basic_stringbufIcNS_11char_traitsIcEENS_9allocatorIcEEE9underflowEv,__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE5uflowEv,b9,b9,b9,b9,b9,__ZNK5osgDB7Options9cloneTypeEv,b9,b9,__ZNK5osgDB7Options11libraryNameEv,__ZNK5osgDB7Options9classNameEv,b9,b9,__ZNK3osg13TemplateArrayINS_5Vec3fELNS_5Array4TypeE28ELi3ELi5126EE9cloneTypeEv,b9,b9,__ZNK3osg5Array11libraryNameEv,__ZNK3osg5Array9classNameEv,b9,b9,__ZNK3osg13TemplateArrayINS_5Vec3fELNS_5Array4TypeE28ELi3ELi5126EE14getDataPointerEv,__ZNK3osg13TemplateArrayINS_5Vec3fELNS_5Array4TypeE28ELi3ELi5126EE16getTotalDataSizeEv,__ZN3osg5Array7asArrayEv,__ZNK3osg5Array7asArrayEv,__ZN3osg10BufferData14asPrimitiveSetEv,__ZNK3osg10BufferData14asPrimitiveSetEv
,__ZN3osg10BufferData7asImageEv,__ZNK3osg10BufferData7asImageEv,b9,b9,b9,b9,b9,__ZNK3osg13TemplateArrayINS_5Vec3fELNS_5Array4TypeE28ELi3ELi5126EE14getElementSizeEv,b9,__ZNK3osg13TemplateArrayINS_5Vec3fELNS_5Array4TypeE28ELi3ELi5126EE14getNumElementsEv,b9,b9,b9,b9,b9,b9,b9,__ZNK3osg13TemplateArrayINS_5Vec2fELNS_5Array4TypeE27ELi2ELi5126EE9cloneTypeEv,b9,__ZNK3osg13TemplateArrayINS_5Vec2fELNS_5Array4TypeE27ELi2ELi5126EE14getDataPointerEv,__ZNK3osg13TemplateArrayINS_5Vec2fELNS_5Array4TypeE27ELi2ELi5126EE16getTotalDataSizeEv,b9,b9,b9,b9,b9,__ZNK3osg13TemplateArrayINS_5Vec2fELNS_5Array4TypeE27ELi2ELi5126EE14getElementSizeEv,b9,__ZNK3osg13TemplateArrayINS_5Vec2fELNS_5Array4TypeE27ELi2ELi5126EE14getNumElementsEv,b9
,b9,b9,b9,b9,b9,b9,__ZNK3osg13TemplateArrayINS_5Vec4fELNS_5Array4TypeE29ELi4ELi5126EE9cloneTypeEv,b9,__ZNK3osg13TemplateArrayINS_5Vec4fELNS_5Array4TypeE29ELi4ELi5126EE14getDataPointerEv,__ZNK3osg13TemplateArrayINS_5Vec4fELNS_5Array4TypeE29ELi4ELi5126EE16getTotalDataSizeEv,b9,b9,b9,b9,b9,__ZNK3osg13TemplateArrayINS_5Vec4fELNS_5Array4TypeE29ELi4ELi5126EE14getElementSizeEv,b9,__ZNK3osg13TemplateArrayINS_5Vec4fELNS_5Array4TypeE29ELi4ELi5126EE14getNumElementsEv,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,__ZNK9osgViewer12SingleWindow9cloneTypeEv,b9,b9,__ZNK9osgViewer12SingleWindow11libraryNameEv,__ZNK9osgViewer12SingleWindow9classNameEv,b9,b9,b9,__ZNK9osgViewer12SingleScreen9cloneTypeEv,b9,b9,__ZNK9osgViewer12SingleScreen11libraryNameEv,__ZNK9osgViewer12SingleScreen9classNameEv,b9,b9,__ZNK9osgViewer16AcrossAllScreens9cloneTypeEv,b9,b9,__ZNK9osgViewer16AcrossAllScreens11libraryNameEv,__ZNK9osgViewer16AcrossAllScreens9classNameEv,b9,__ZNK5osgGA15GUIEventHandler9cloneTypeEv,b9,b9,__ZNK5osgGA15GUIEventHandler11libraryNameEv,__ZNK5osgGA15GUIEventHandler9classNameEv,__ZN5osgGA12EventHandler14asNodeCallbackEv,__ZNK5osgGA12EventHandler14asNodeCallbackEv,b9
,b9,b9,b9,__ZN5osgGA12EventHandler23asDrawableEventCallbackEv,__ZNK5osgGA12EventHandler23asDrawableEventCallbackEv,__ZN5osgGA12EventHandler14asEventHandlerEv,__ZNK5osgGA12EventHandler14asEventHandlerEv,b9,b9,b9,b9,b9,__ZThn4_NK5osgGA15GUIEventHandler9cloneTypeEv,b9,b9,__ZThn4_NK5osgGA15GUIEventHandler11libraryNameEv,__ZThn4_NK5osgGA15GUIEventHandler9classNameEv,__ZThn4_N5osgGA12EventHandler23asDrawableEventCallbackEv,__ZThn4_NK5osgGA12EventHandler23asDrawableEventCallbackEv,b9,b9,b9,b9,__ZTv0_n16_NK5osgGA15GUIEventHandler9cloneTypeEv,b9,b9,__ZTv0_n28_NK5osgGA15GUIEventHandler11libraryNameEv,__ZTv0_n32_NK5osgGA15GUIEventHandler9classNameEv,__ZN3osg8Callback10asCallbackEv,__ZNK3osg8Callback10asCallbackEv
,__ZN3osg8Callback16asCallbackObjectEv,__ZNK3osg8Callback16asCallbackObjectEv,__ZTv0_n52_N5osgGA12EventHandler14asNodeCallbackEv,__ZTv0_n56_NK5osgGA12EventHandler14asNodeCallbackEv,__ZN3osg8Callback24asStateAttributeCallbackEv,__ZNK3osg8Callback24asStateAttributeCallbackEv,__ZN3osg8Callback17asUniformCallbackEv,__ZNK3osg8Callback17asUniformCallbackEv,__ZN3osg8Callback24asDrawableUpdateCallbackEv,__ZNK3osg8Callback24asDrawableUpdateCallbackEv,__ZTv0_n84_N5osgGA12EventHandler23asDrawableEventCallbackEv,__ZTv0_n88_NK5osgGA12EventHandler23asDrawableEventCallbackEv,__ZN3osg8Callback22asDrawableCullCallbackEv,__ZNK3osg8Callback22asDrawableCullCallbackEv,__ZTv0_n100_N5osgGA12EventHandler14asEventHandlerEv,__ZTv0_n104_NK5osgGA12EventHandler14asEventHandlerEv,b9,b9,b9,b9,b9,__ZTv0_n20_NK5osgGA15GUIEventHandler9cloneTypeEv,b9,b9,__ZTv0_n32_NK5osgGA15GUIEventHandler11libraryNameEv,__ZTv0_n36_NK5osgGA15GUIEventHandler9classNameEv,__ZTv0_n96_N3osg8Callback10asCallbackEv,__ZTv0_n100_NK3osg8Callback10asCallbackEv,__ZTv0_n104_N3osg8Callback16asCallbackObjectEv,__ZTv0_n108_NK3osg8Callback16asCallbackObjectEv
,__ZNK3osg8Callback9cloneTypeEv,b9,b9,__ZNK3osg8Callback11libraryNameEv,__ZNK3osg8Callback9classNameEv,__ZN3osg8Callback14asNodeCallbackEv,__ZNK3osg8Callback14asNodeCallbackEv,__ZN3osg8Callback23asDrawableEventCallbackEv,__ZNK3osg8Callback23asDrawableEventCallbackEv,__ZN3osg8Callback14asEventHandlerEv,__ZNK3osg8Callback14asEventHandlerEv,b9,b9,b9,b9,b9,__ZTv0_n20_NK3osg8Callback9cloneTypeEv,b9,b9,__ZTv0_n32_NK3osg8Callback11libraryNameEv,__ZTv0_n36_NK3osg8Callback9classNameEv,b9,b9,b9,b9,b9,b9,b9,b9,b9
,__ZNK5osgGA12EventHandler9cloneTypeEv,b9,b9,__ZNK5osgGA12EventHandler11libraryNameEv,__ZNK5osgGA12EventHandler9classNameEv,b9,b9,b9,__ZThn4_NK5osgGA12EventHandler9cloneTypeEv,b9,b9,__ZThn4_NK5osgGA12EventHandler11libraryNameEv,__ZThn4_NK5osgGA12EventHandler9classNameEv,b9,b9,__ZTv0_n16_NK5osgGA12EventHandler9cloneTypeEv,b9,b9,__ZTv0_n28_NK5osgGA12EventHandler11libraryNameEv,__ZTv0_n32_NK5osgGA12EventHandler9classNameEv,b9,b9,b9,b9,__ZTv0_n20_NK5osgGA12EventHandler9cloneTypeEv,b9,b9,__ZTv0_n32_NK5osgGA12EventHandler11libraryNameEv,__ZTv0_n36_NK5osgGA12EventHandler9classNameEv,__ZNK3osg12NodeCallback9cloneTypeEv
,b9,b9,__ZNK3osg12NodeCallback11libraryNameEv,__ZNK3osg12NodeCallback9classNameEv,__ZN3osg12NodeCallback14asNodeCallbackEv,__ZNK3osg12NodeCallback14asNodeCallbackEv,b9,b9,b9,b9,__ZTv0_n16_NK3osg12NodeCallback9cloneTypeEv,b9,b9,__ZTv0_n28_NK3osg12NodeCallback11libraryNameEv,__ZTv0_n32_NK3osg12NodeCallback9classNameEv,__ZTv0_n52_N3osg12NodeCallback14asNodeCallbackEv,__ZTv0_n56_NK3osg12NodeCallback14asNodeCallbackEv,b9,b9,b9,b9,b9,__ZTv0_n20_NK3osg12NodeCallback9cloneTypeEv,b9,b9,__ZTv0_n32_NK3osg12NodeCallback11libraryNameEv,__ZTv0_n36_NK3osg12NodeCallback9classNameEv,__ZNK3osg21DrawableEventCallback9cloneTypeEv,b9,b9
,__ZNK3osg21DrawableEventCallback11libraryNameEv,__ZNK3osg21DrawableEventCallback9classNameEv,__ZN3osg21DrawableEventCallback23asDrawableEventCallbackEv,__ZNK3osg21DrawableEventCallback23asDrawableEventCallbackEv,b9,b9,b9,b9,__ZTv0_n16_NK3osg21DrawableEventCallback9cloneTypeEv,b9,b9,__ZTv0_n28_NK3osg21DrawableEventCallback11libraryNameEv,__ZTv0_n32_NK3osg21DrawableEventCallback9classNameEv,__ZTv0_n84_N3osg21DrawableEventCallback23asDrawableEventCallbackEv,__ZTv0_n88_NK3osg21DrawableEventCallback23asDrawableEventCallbackEv,b9,b9,b9,b9,b9,__ZTv0_n20_NK3osg21DrawableEventCallback9cloneTypeEv,b9,b9,__ZTv0_n32_NK3osg21DrawableEventCallback11libraryNameEv,__ZTv0_n36_NK3osg21DrawableEventCallback9classNameEv,b9,__ZNK9osgViewer8Keystone9cloneTypeEv,b9,b9,__ZNK9osgViewer8Keystone11libraryNameEv
,__ZNK9osgViewer8Keystone9classNameEv,__ZNK22KeystoneUpdateCallback9cloneTypeEv,b9,b9,__ZNK22KeystoneUpdateCallback11libraryNameEv,__ZNK22KeystoneUpdateCallback9classNameEv,__ZN3osg22DrawableUpdateCallback24asDrawableUpdateCallbackEv,__ZNK3osg22DrawableUpdateCallback24asDrawableUpdateCallbackEv,b9,b9,b9,b9,__ZTv0_n16_NK22KeystoneUpdateCallback9cloneTypeEv,b9,b9,__ZTv0_n28_NK22KeystoneUpdateCallback11libraryNameEv,__ZTv0_n32_NK22KeystoneUpdateCallback9classNameEv,__ZTv0_n76_N3osg22DrawableUpdateCallback24asDrawableUpdateCallbackEv,__ZTv0_n80_NK3osg22DrawableUpdateCallback24asDrawableUpdateCallbackEv,b9,b9,b9,b9,b9,__ZTv0_n20_NK22KeystoneUpdateCallback9cloneTypeEv,b9,b9,__ZTv0_n32_NK22KeystoneUpdateCallback11libraryNameEv,__ZTv0_n36_NK22KeystoneUpdateCallback9classNameEv,__ZNK20KeystoneCullCallback9cloneTypeEv
,b9,b9,__ZNK20KeystoneCullCallback11libraryNameEv,__ZNK20KeystoneCullCallback9classNameEv,__ZN3osg20DrawableCullCallback22asDrawableCullCallbackEv,__ZNK3osg20DrawableCullCallback22asDrawableCullCallbackEv,b9,b9,b9,b9,__ZTv0_n16_NK20KeystoneCullCallback9cloneTypeEv,b9,b9,__ZTv0_n28_NK20KeystoneCullCallback11libraryNameEv,__ZTv0_n32_NK20KeystoneCullCallback9classNameEv,__ZTv0_n92_N3osg20DrawableCullCallback22asDrawableCullCallbackEv,__ZTv0_n96_NK3osg20DrawableCullCallback22asDrawableCullCallbackEv,b9,b9,b9,b9,__ZTv0_n20_NK20KeystoneCullCallback9cloneTypeEv,b9,b9,__ZTv0_n32_NK20KeystoneCullCallback11libraryNameEv,__ZTv0_n36_NK20KeystoneCullCallback9classNameEv,b9,__ZNK3osg11ValueObject9cloneTypeEv,b9,b9
,__ZNK3osg11ValueObject11libraryNameEv,__ZNK3osg11ValueObject9classNameEv,b9,b9,b9,b9,__ZNK3osg19TemplateValueObjectINSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEE9cloneTypeEv,b9,b9,__ZNK3osg19TemplateValueObjectINSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEE11libraryNameEv,__ZNK3osg19TemplateValueObjectINSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEE9classNameEv,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,__ZN11OpenThreads5Mutex4lockEv,__ZN11OpenThreads5Mutex6unlockEv,__ZN11OpenThreads5Mutex7trylockEv,b9,b9,b9,b9,__ZNK9osgViewer5Scene9classNameEv,__ZNK9osgViewer5Scene24requiresUpdateSceneGraphEv,b9
,__ZNK9osgViewer5Scene14requiresRedrawEv,b9,b9,b9,b9,__ZNK5osgGA12EventVisitor11libraryNameEv,__ZNK5osgGA12EventVisitor9classNameEv,__ZN5osgGA12EventVisitor14asEventVisitorEv,__ZNK5osgGA12EventVisitor14asEventVisitorEv,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,__ZTv0_n32_NK5osgGA12EventVisitor11libraryNameEv,__ZTv0_n36_NK5osgGA12EventVisitor9classNameEv,b9,b9,__ZNK3osg11NodeVisitor11libraryNameEv,__ZNK3osg11NodeVisitor9classNameEv
,b9,b9,b9,__ZTv0_n32_NK3osg11NodeVisitor11libraryNameEv,__ZTv0_n36_NK3osg11NodeVisitor9classNameEv,b9,b9,__ZNK5osgGA15GUIEventAdapter9cloneTypeEv,b9,b9,__ZNK5osgGA15GUIEventAdapter11libraryNameEv,__ZNK5osgGA15GUIEventAdapter9classNameEv,__ZN5osgGA15GUIEventAdapter17asGUIEventAdapterEv,__ZNK5osgGA15GUIEventAdapter17asGUIEventAdapterEv,__ZNK5osgGA15GUIEventAdapter12getEventTypeEv,__ZNK5osgGA15GUIEventAdapter6getKeyEv,__ZNK5osgGA20TrackballManipulator9cloneTypeEv,b9,b9,__ZNK5osgGA20TrackballManipulator11libraryNameEv,__ZNK5osgGA20TrackballManipulator9classNameEv,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,__ZNK5osgGA16OrbitManipulator21getFusionDistanceModeEv,b9,b9,__ZNK5osgGA19StandardManipulator7getNodeEv,__ZN5osgGA19StandardManipulator7getNodeEv,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,__ZN5osgGA19StandardManipulator15performMovementEv,b9,b9,b9,b9,b9,b9,__ZNK5osgGA19StandardManipulator13isMouseMovingEv,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,__ZThn4_NK5osgGA20TrackballManipulator9cloneTypeEv,b9,b9,__ZThn4_NK5osgGA20TrackballManipulator11libraryNameEv,__ZThn4_NK5osgGA20TrackballManipulator9classNameEv
,b9,b9,__ZTv0_n16_NK5osgGA20TrackballManipulator9cloneTypeEv,b9,b9,__ZTv0_n28_NK5osgGA20TrackballManipulator11libraryNameEv,__ZTv0_n32_NK5osgGA20TrackballManipulator9classNameEv,b9,b9,b9,b9,__ZTv0_n20_NK5osgGA20TrackballManipulator9cloneTypeEv,b9,b9,__ZTv0_n32_NK5osgGA20TrackballManipulator11libraryNameEv,__ZTv0_n36_NK5osgGA20TrackballManipulator9classNameEv,b9,b9,__ZNK5osgGA5Event9cloneTypeEv,b9,b9,__ZNK5osgGA5Event11libraryNameEv,__ZNK5osgGA5Event9classNameEv,__ZN5osgGA5Event17asGUIEventAdapterEv,__ZNK5osgGA5Event17asGUIEventAdapterEv,__ZNK5osgGA17CameraManipulator9classNameEv,b9,b9,b9,__ZNK5osgGA17CameraManipulator21getFusionDistanceModeEv
,b9,b9,__ZNK5osgGA17CameraManipulator7getNodeEv,__ZN5osgGA17CameraManipulator7getNodeEv,b9,b9,b9,b9,__ZThn4_NK5osgGA17CameraManipulator9classNameEv,b9,b9,__ZTv0_n32_NK5osgGA17CameraManipulator9classNameEv,b9,b9,b9,b9,__ZTv0_n36_NK5osgGA17CameraManipulator9classNameEv,__ZNK5osgGA16OrbitManipulator9cloneTypeEv,b9,b9,__ZNK5osgGA16OrbitManipulator11libraryNameEv,__ZNK5osgGA16OrbitManipulator9classNameEv,b9,b9,__ZThn4_NK5osgGA16OrbitManipulator9cloneTypeEv,b9,b9,__ZThn4_NK5osgGA16OrbitManipulator11libraryNameEv,__ZThn4_NK5osgGA16OrbitManipulator9classNameEv,b9
,b9,__ZTv0_n16_NK5osgGA16OrbitManipulator9cloneTypeEv,b9,b9,__ZTv0_n28_NK5osgGA16OrbitManipulator11libraryNameEv,__ZTv0_n32_NK5osgGA16OrbitManipulator9classNameEv,b9,b9,b9,b9,__ZTv0_n20_NK5osgGA16OrbitManipulator9cloneTypeEv,b9,b9,__ZTv0_n32_NK5osgGA16OrbitManipulator11libraryNameEv,__ZTv0_n36_NK5osgGA16OrbitManipulator9classNameEv,__ZNK5osgGA19StandardManipulator9classNameEv,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,__ZThn4_NK5osgGA19StandardManipulator9classNameEv,b9,b9,__ZTv0_n32_NK5osgGA19StandardManipulator9classNameEv
,b9,b9,b9,b9,__ZTv0_n36_NK5osgGA19StandardManipulator9classNameEv,b9,b9,b9,__ZNK7osgUtil16GLObjectsVisitor11libraryNameEv,__ZNK7osgUtil16GLObjectsVisitor9classNameEv,b9,b9,b9,b9,b9,__ZTv0_n32_NK7osgUtil16GLObjectsVisitor11libraryNameEv,__ZTv0_n36_NK7osgUtil16GLObjectsVisitor9classNameEv,b9,b9,__ZNK7osgUtil19IntersectionVisitor11libraryNameEv,__ZNK7osgUtil19IntersectionVisitor9classNameEv,__ZN7osgUtil19IntersectionVisitor21asIntersectionVisitorEv,__ZNK7osgUtil19IntersectionVisitor21asIntersectionVisitorEv,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,__ZTv0_n32_NK7osgUtil19IntersectionVisitor11libraryNameEv,__ZTv0_n36_NK7osgUtil19IntersectionVisitor9classNameEv,b9,b9,__ZNK3osg10RefMatrixd9cloneTypeEv,b9,b9,__ZNK3osg10RefMatrixd11libraryNameEv,__ZNK3osg10RefMatrixd9classNameEv,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,__ZNK3osg11DummyObject9cloneTypeEv,b9,b9,__ZNK3osg11DummyObject11libraryNameEv,__ZNK3osg11DummyObject9classNameEv,b9,b9,b9,b9,b9,b9,b9,b9,b9,__ZN7osgUtil22LineSegmentIntersector21containsIntersectionsEv,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,__ZN7osgUtil14RayIntersector21containsIntersectionsEv,b9,b9,b9,b9,b9,__ZNK7osgUtil9SceneView9cloneTypeEv,b9,b9,__ZNK7osgUtil9SceneView11libraryNameEv,__ZNK7osgUtil9SceneView9classNameEv
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,__ZNK7osgUtil12StatsVisitor11libraryNameEv,__ZNK7osgUtil12StatsVisitor9classNameEv,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,__ZTv0_n32_NK7osgUtil12StatsVisitor11libraryNameEv,__ZTv0_n36_NK7osgUtil12StatsVisitor9classNameEv,b9,b9,__ZNK7osgUtil13UpdateVisitor11libraryNameEv,__ZNK7osgUtil13UpdateVisitor9classNameEv,__ZN7osgUtil13UpdateVisitor15asUpdateVisitorEv,__ZNK7osgUtil13UpdateVisitor15asUpdateVisitorEv,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,__ZTv0_n32_NK7osgUtil13UpdateVisitor11libraryNameEv,__ZTv0_n36_NK7osgUtil13UpdateVisitor9classNameEv,b9,b9,__ZNK7osgUtil11CullVisitor11libraryNameEv,__ZNK7osgUtil11CullVisitor9classNameEv,__ZN7osgUtil11CullVisitor13asCullVisitorEv,__ZNK7osgUtil11CullVisitor13asCullVisitorEv,__ZN7osgUtil11CullVisitor11asCullStackEv,__ZNK7osgUtil11CullVisitor11asCullStackEv,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,__ZNK7osgUtil11CullVisitor5cloneEv,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,__ZTv0_n32_NK7osgUtil11CullVisitor11libraryNameEv,__ZTv0_n36_NK7osgUtil11CullVisitor9classNameEv,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,__ZNK7osgUtil16RenderStageCache9cloneTypeEv,b9,b9,__ZNK7osgUtil16RenderStageCache11libraryNameEv,__ZNK7osgUtil16RenderStageCache9classNameEv
,b9,b9,b9,b9,b9,b9,b9,b9,b9,__ZNK3osg12PrimitiveSet11libraryNameEv,__ZNK3osg12PrimitiveSet9classNameEv,__ZNK3osg12PrimitiveSet14getDataPointerEv,__ZNK3osg12PrimitiveSet16getTotalDataSizeEv,__ZN3osg10BufferData7asArrayEv,__ZNK3osg10BufferData7asArrayEv,__ZN3osg12PrimitiveSet14asPrimitiveSetEv,__ZNK3osg12PrimitiveSet14asPrimitiveSetEv,__ZNK3osg12PrimitiveSet20supportsBufferObjectEv,__ZN3osg12DrawElements15getDrawElementsEv,__ZNK3osg12DrawElements15getDrawElementsEv,__ZNK3osg12PrimitiveSet16getNumPrimitivesEv,b9,b9,b9,b9,b9,b9,b9,__ZNK3osg13TemplateArrayIdLNS_5Array4TypeE8ELi1ELi5130EE9cloneTypeEv,b9
,__ZNK3osg13TemplateArrayIdLNS_5Array4TypeE8ELi1ELi5130EE14getDataPointerEv,__ZNK3osg13TemplateArrayIdLNS_5Array4TypeE8ELi1ELi5130EE16getTotalDataSizeEv,b9,b9,b9,b9,b9,__ZNK3osg13TemplateArrayIdLNS_5Array4TypeE8ELi1ELi5130EE14getElementSizeEv,b9,__ZNK3osg13TemplateArrayIdLNS_5Array4TypeE8ELi1ELi5130EE14getNumElementsEv,b9,b9,b9,b9,b9,b9,b9,b9,b9,__ZNK3osg13TemplateArrayIfLNS_5Array4TypeE7ELi1ELi5126EE9cloneTypeEv,b9,__ZNK3osg13TemplateArrayIfLNS_5Array4TypeE7ELi1ELi5126EE14getDataPointerEv,__ZNK3osg13TemplateArrayIfLNS_5Array4TypeE7ELi1ELi5126EE16getTotalDataSizeEv,b9,b9,b9,b9,b9,__ZNK3osg13TemplateArrayIfLNS_5Array4TypeE7ELi1ELi5126EE14getElementSizeEv,b9
,__ZNK3osg13TemplateArrayIfLNS_5Array4TypeE7ELi1ELi5126EE14getNumElementsEv,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,__ZNK3osg18TemplateIndexArrayIjLNS_5Array4TypeE6ELi1ELi5125EE9cloneTypeEv,b9,__ZNK3osg18TemplateIndexArrayIjLNS_5Array4TypeE6ELi1ELi5125EE14getDataPointerEv,__ZNK3osg18TemplateIndexArrayIjLNS_5Array4TypeE6ELi1ELi5125EE16getTotalDataSizeEv,b9,b9,b9,b9,b9,__ZNK3osg18TemplateIndexArrayIjLNS_5Array4TypeE6ELi1ELi5125EE14getElementSizeEv,b9,__ZNK3osg18TemplateIndexArrayIjLNS_5Array4TypeE6ELi1ELi5125EE14getNumElementsEv,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,__ZNK3osg18TemplateIndexArrayIiLNS_5Array4TypeE3ELi1ELi5124EE9cloneTypeEv,b9,__ZNK3osg18TemplateIndexArrayIiLNS_5Array4TypeE3ELi1ELi5124EE14getDataPointerEv,__ZNK3osg18TemplateIndexArrayIiLNS_5Array4TypeE3ELi1ELi5124EE16getTotalDataSizeEv,b9,b9,b9,b9,b9,__ZNK3osg18TemplateIndexArrayIiLNS_5Array4TypeE3ELi1ELi5124EE14getElementSizeEv,b9,__ZNK3osg18TemplateIndexArrayIiLNS_5Array4TypeE3ELi1ELi5124EE14getNumElementsEv,b9,b9,b9,b9,b9,b9,b9,b9,__ZNK7osgUtil24PositionalStateContainer9cloneTypeEv,b9,b9
,__ZNK7osgUtil24PositionalStateContainer11libraryNameEv,__ZNK7osgUtil24PositionalStateContainer9classNameEv,b9,b9,b9,b9,b9,b9,__ZNK7osgUtil9RenderBin9cloneTypeEv,b9,b9,__ZNK7osgUtil9RenderBin11libraryNameEv,__ZNK7osgUtil9RenderBin9classNameEv,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,__ZNK7osgUtil9RenderBin34computeNumberOfDynamicRenderLeavesEv,b9,b9,b9,b9,b9
,b9,b9,__ZNK7osgUtil11RenderStage9cloneTypeEv,b9,b9,__ZNK7osgUtil11RenderStage9classNameEv,b9,b9,b9,b9,b9,__ZNK7osgUtil11RenderStage34computeNumberOfDynamicRenderLeavesEv,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,__ZNK3osg12BufferObject11libraryNameEv,__ZNK3osg12BufferObject9classNameEv,b9,b9,b9,b9,__ZNK3osg10BufferData11libraryNameEv,__ZNK3osg10BufferData9classNameEv,b9,__ZNK3osg18VertexBufferObject9cloneTypeEv,b9,b9,__ZNK3osg18VertexBufferObject11libraryNameEv,__ZNK3osg18VertexBufferObject9classNameEv,b9,__ZNK3osg19ElementBufferObject9cloneTypeEv,b9,b9
,__ZNK3osg19ElementBufferObject11libraryNameEv,__ZNK3osg19ElementBufferObject9classNameEv,b9,__ZNK3osg17PixelBufferObject9cloneTypeEv,b9,b9,__ZNK3osg17PixelBufferObject11libraryNameEv,__ZNK3osg17PixelBufferObject9classNameEv,b9,b9,b9,__ZNK3osg6Camera9cloneTypeEv,b9,b9,__ZNK3osg6Camera11libraryNameEv,__ZNK3osg6Camera9classNameEv,__ZN3osg4Node6asNodeEv,__ZNK3osg4Node6asNodeEv,__ZN3osg6Camera8asCameraEv,__ZNK3osg6Camera8asCameraEv,__ZN3osg4Node10asDrawableEv,__ZNK3osg4Node10asDrawableEv,b9,b9,__ZN3osg4Node10asGeometryEv,__ZNK3osg4Node10asGeometryEv,__ZN3osg5Group7asGroupEv,__ZNK3osg5Group7asGroupEv,__ZN3osg9Transform11asTransformEv,__ZNK3osg9Transform11asTransformEv
,__ZN3osg4Node8asSwitchEv,__ZNK3osg4Node8asSwitchEv,__ZN3osg4Node7asGeodeEv,__ZNK3osg4Node7asGeodeEv,__ZN3osg4Node9asTerrainEv,__ZNK3osg4Node9asTerrainEv,b9,b9,b9,b9,b9,b9,b9,b9,b9,__ZNK3osg5Group14getNumChildrenEv,b9,b9,b9,__ZN3osg9Transform17asMatrixTransformEv,__ZNK3osg9Transform17asMatrixTransformEv,__ZN3osg9Transform27asPositionAttitudeTransformEv,__ZNK3osg9Transform27asPositionAttitudeTransformEv,__ZN3osg9Transform15asAutoTransformEv,__ZNK3osg9Transform15asAutoTransformEv,b9,b9,b9,b9,b9
,b9,b9,b9,__ZNK3osg23CollectOccludersVisitor9cloneTypeEv,__ZNK3osg23CollectOccludersVisitor11libraryNameEv,__ZNK3osg23CollectOccludersVisitor9classNameEv,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,__ZTv0_n20_NK3osg23CollectOccludersVisitor9cloneTypeEv,__ZTv0_n32_NK3osg23CollectOccludersVisitor11libraryNameEv,__ZTv0_n36_NK3osg23CollectOccludersVisitor9classNameEv,b9,b9,__ZNK3osg9ColorMask9cloneTypeEv,b9,b9,__ZNK3osg9ColorMask11libraryNameEv,__ZNK3osg9ColorMask9classNameEv
,__ZN3osg14StateAttribute16asStateAttributeEv,__ZNK3osg14StateAttribute16asStateAttributeEv,b9,b9,__ZN3osg14StateAttribute9asTextureEv,__ZNK3osg14StateAttribute9asTextureEv,__ZNK3osg9ColorMask7getTypeEv,__ZNK3osg14StateAttribute9getMemberEv,__ZNK3osg14StateAttribute18isTextureAttributeEv,b9,b9,b9,b9,b9,b9,b9,b9,__ZNK3osg14StateAttribute11libraryNameEv,__ZNK3osg14StateAttribute9classNameEv,b9,b9,b9,__ZNK3osg20ComputeBoundsVisitor11libraryNameEv,__ZNK3osg20ComputeBoundsVisitor9classNameEv,b9,b9,b9,b9,b9,__ZTv0_n32_NK3osg20ComputeBoundsVisitor11libraryNameEv
,__ZTv0_n36_NK3osg20ComputeBoundsVisitor9classNameEv,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,__ZNK3osg8Drawable9cloneTypeEv,b9,b9,__ZNK3osg8Drawable11libraryNameEv,__ZNK3osg8Drawable9classNameEv,__ZN3osg8Drawable10asDrawableEv,__ZNK3osg8Drawable10asDrawableEv,b9,b9,b9,__ZN3osg4Node7asGroupEv,__ZNK3osg4Node7asGroupEv,__ZN3osg4Node11asTransformEv,__ZNK3osg4Node11asTransformEv,b9,b9,b9
,b9,b9,b9,b9,b9,__ZNK3osg8Drawable19getGLObjectSizeHintEv,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,__ZN3osg15GLObjectManager14createGLObjectEv,b9,b9,b9,b9,b9,__ZNK3osg12RenderBuffer9cloneTypeEv,b9,b9,__ZNK3osg12RenderBuffer11libraryNameEv,__ZNK3osg12RenderBuffer9classNameEv,b9,b9,b9,b9,__ZNK3osg17FrameBufferObject9cloneTypeEv,b9,b9,__ZNK3osg17FrameBufferObject11libraryNameEv,__ZNK3osg17FrameBufferObject9classNameEv,b9,b9,__ZNK3osg17FrameBufferObject7getTypeEv,b9,b9,b9,b9,b9,b9,__ZNK3osg5Geode9cloneTypeEv
,b9,b9,__ZNK3osg5Geode11libraryNameEv,__ZNK3osg5Geode9classNameEv,b9,b9,__ZN3osg5Geode7asGeodeEv,__ZNK3osg5Geode7asGeodeEv,b9,b9,b9,b9,b9,b9,b9,b9,b9,__ZNK3osg8Geometry9cloneTypeEv,b9,b9,__ZNK3osg8Geometry11libraryNameEv,__ZNK3osg8Geometry9classNameEv,b9,b9,__ZN3osg8Geometry10asGeometryEv,__ZNK3osg8Geometry10asGeometryEv,b9,b9,b9,__ZNK3osg8Geometry19getGLObjectSizeHintEv
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,__ZNK3osg15GraphicsContext11libraryNameEv,__ZNK3osg15GraphicsContext9classNameEv,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,__ZN3osg15OperationThread6cancelEv,b9
,b9,__ZThn12_N3osg15OperationThread6cancelEv,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,__ZN11OpenThreads7Barrier26numThreadsCurrentlyBlockedEv,b9,b9
,b9,b9,b9,b9,b9,b9,b9,__ZNK3osg5Group9cloneTypeEv,b9,b9,__ZNK3osg5Group11libraryNameEv,__ZNK3osg5Group9classNameEv,b9,b9,b9,b9,__ZNK3osg5Image9cloneTypeEv,b9,b9,__ZNK3osg5Image11libraryNameEv,__ZNK3osg5Image9classNameEv,__ZNK3osg5Image14getDataPointerEv,__ZNK3osg5Image16getTotalDataSizeEv,__ZN3osg5Image7asImageEv,__ZNK3osg5Image7asImageEv,b9,b9,b9,b9,b9
,b9,b9,__ZNK3osg5Image18isImageTranslucentEv,__ZNK3osg5Image18requiresUpdateCallEv,b9,b9,b9,b9,b9,__ZNK3osg22StateAttributeCallback9cloneTypeEv,b9,b9,__ZNK3osg22StateAttributeCallback11libraryNameEv,__ZNK3osg22StateAttributeCallback9classNameEv,__ZN3osg22StateAttributeCallback24asStateAttributeCallbackEv,__ZNK3osg22StateAttributeCallback24asStateAttributeCallbackEv,b9,b9,b9,b9,__ZTv0_n16_NK3osg22StateAttributeCallback9cloneTypeEv,b9,b9,__ZTv0_n28_NK3osg22StateAttributeCallback11libraryNameEv,__ZTv0_n32_NK3osg22StateAttributeCallback9classNameEv,__ZTv0_n60_N3osg22StateAttributeCallback24asStateAttributeCallbackEv,__ZTv0_n64_NK3osg22StateAttributeCallback24asStateAttributeCallbackEv,b9,b9,b9
,b9,b9,__ZTv0_n20_NK3osg22StateAttributeCallback9cloneTypeEv,b9,b9,__ZTv0_n32_NK3osg22StateAttributeCallback11libraryNameEv,__ZTv0_n36_NK3osg22StateAttributeCallback9classNameEv,b9,b9,b9,b9,b9,b9,b9,b9,b9,__ZNK3osg6KdTree9cloneTypeEv,b9,b9,__ZNK3osg6KdTree11libraryNameEv,__ZNK3osg6KdTree9classNameEv,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,__ZNK3osg13KdTreeBuilder11libraryNameEv,__ZNK3osg13KdTreeBuilder9classNameEv,b9,__ZN3osg13KdTreeBuilder5cloneEv,b9,b9,__ZTv0_n32_NK3osg13KdTreeBuilder11libraryNameEv,__ZTv0_n36_NK3osg13KdTreeBuilder9classNameEv,b9,b9,b9,__ZNK3osg4Node9cloneTypeEv,b9,b9,__ZNK3osg4Node11libraryNameEv,__ZNK3osg4Node9classNameEv,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,__ZN3osg18NotifyStreamBuffer4syncEv,b9,b9,b9,b9,__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE9underflowEv,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,__ZNK3osg11PolygonMode9cloneTypeEv,b9,b9,__ZNK3osg11PolygonMode11libraryNameEv,__ZNK3osg11PolygonMode9classNameEv,__ZNK3osg11PolygonMode7getTypeEv,b9,b9,b9,b9,__ZNK3osg14PolygonStipple9cloneTypeEv,b9,b9,__ZNK3osg14PolygonStipple11libraryNameEv,__ZNK3osg14PolygonStipple9classNameEv,__ZNK3osg14PolygonStipple7getTypeEv,b9,b9,b9,b9,b9,__ZNK3osg17DrawElementsUByte9cloneTypeEv,b9,b9,__ZNK3osg17DrawElementsUByte11libraryNameEv,__ZNK3osg17DrawElementsUByte9classNameEv
,__ZNK3osg17DrawElementsUByte14getDataPointerEv,__ZNK3osg17DrawElementsUByte16getTotalDataSizeEv,__ZNK3osg17DrawElementsUByte20supportsBufferObjectEv,b9,b9,b9,b9,__ZNK3osg17DrawElementsUByte13getNumIndicesEv,b9,__ZN3osg17DrawElementsUByte11getDataTypeEv,b9,b9,b9,b9,b9,b9,b9,b9,b9,__ZNK3osg18DrawElementsUShort9cloneTypeEv,b9,b9,__ZNK3osg18DrawElementsUShort11libraryNameEv,__ZNK3osg18DrawElementsUShort9classNameEv,__ZNK3osg18DrawElementsUShort14getDataPointerEv,__ZNK3osg18DrawElementsUShort16getTotalDataSizeEv,__ZNK3osg18DrawElementsUShort20supportsBufferObjectEv,b9,b9,b9
,b9,__ZNK3osg18DrawElementsUShort13getNumIndicesEv,b9,__ZN3osg18DrawElementsUShort11getDataTypeEv,b9,b9,b9,b9,b9,b9,b9,b9,b9,__ZNK3osg16DrawElementsUInt9cloneTypeEv,b9,b9,__ZNK3osg16DrawElementsUInt11libraryNameEv,__ZNK3osg16DrawElementsUInt9classNameEv,__ZNK3osg16DrawElementsUInt14getDataPointerEv,__ZNK3osg16DrawElementsUInt16getTotalDataSizeEv,__ZNK3osg16DrawElementsUInt20supportsBufferObjectEv,b9,b9,b9,b9,__ZNK3osg16DrawElementsUInt13getNumIndicesEv,b9,__ZN3osg16DrawElementsUInt11getDataTypeEv,b9,b9
,b9,b9,b9,b9,b9,b9,__ZNK3osg10DrawArrays9cloneTypeEv,b9,b9,__ZNK3osg10DrawArrays11libraryNameEv,__ZNK3osg10DrawArrays9classNameEv,__ZN3osg12PrimitiveSet15getDrawElementsEv,__ZNK3osg12PrimitiveSet15getDrawElementsEv,b9,b9,b9,b9,__ZNK3osg10DrawArrays13getNumIndicesEv,b9,b9,b9,b9,__ZNK3osg7Program9cloneTypeEv,b9,b9,__ZNK3osg7Program11libraryNameEv,__ZNK3osg7Program9classNameEv,b9,b9,__ZNK3osg7Program7getTypeEv
,b9,b9,b9,b9,b9,b9,b9,b9,__ZN3osg7Program17PerContextProgram15validateProgramEv,b9,b9,b9,b9,b9,__ZNK3osg7Program13ProgramBinary9cloneTypeEv,b9,b9,__ZNK3osg7Program13ProgramBinary11libraryNameEv,__ZNK3osg7Program13ProgramBinary9classNameEv,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,__ZNK3osg6Shader9cloneTypeEv,b9,b9,__ZNK3osg6Shader11libraryNameEv,__ZNK3osg6Shader9classNameEv,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,__ZNK3osg5Shape11libraryNameEv,__ZNK3osg5Shape9classNameEv,b9,__ZNK3osg6Sphere9cloneTypeEv,b9,b9,__ZNK3osg6Sphere11libraryNameEv
,__ZNK3osg6Sphere9classNameEv,b9,b9,b9,b9,b9,b9,__ZNK3osg8StateSet9cloneTypeEv,b9,b9,__ZNK3osg8StateSet11libraryNameEv,__ZNK3osg8StateSet9classNameEv,__ZN3osg8StateSet10asStateSetEv,__ZNK3osg8StateSet10asStateSetEv,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,__ZNK3osg7Stencil9cloneTypeEv,b9
,b9,__ZNK3osg7Stencil11libraryNameEv,__ZNK3osg7Stencil9classNameEv,__ZNK3osg7Stencil7getTypeEv,b9,b9,b9,b9,b9,__ZNK3osg6TexMat9cloneTypeEv,b9,b9,__ZNK3osg6TexMat11libraryNameEv,__ZNK3osg6TexMat9classNameEv,__ZNK3osg6TexMat7getTypeEv,__ZNK3osg6TexMat18isTextureAttributeEv,b9,b9,b9,b9,__ZNK3osg9Texture2D9cloneTypeEv,b9,b9,__ZNK3osg9Texture2D11libraryNameEv,__ZNK3osg9Texture2D9classNameEv,b9,b9,__ZN3osg7Texture9asTextureEv,__ZNK3osg7Texture9asTextureEv,__ZNK3osg9Texture2D7getTypeEv
,__ZNK3osg7Texture18isTextureAttributeEv,b9,b9,b9,__ZNK3osg9Texture2D16getTextureTargetEv,__ZNK3osg9Texture2D15getTextureWidthEv,__ZNK3osg9Texture2D16getTextureHeightEv,__ZNK3osg9Texture2D15getTextureDepthEv,b9,b9,b9,__ZNK3osg9Texture2D12getNumImagesEv,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,__ZNK3osg7Texture11libraryNameEv
,__ZNK3osg7Texture9classNameEv,__ZNK3osg7Texture7getTypeEv,__ZNK3osg7Texture15getTextureWidthEv,__ZNK3osg7Texture16getTextureHeightEv,__ZNK3osg7Texture15getTextureDepthEv,b9,b9,b9,b9,__ZNK3osg16TextureRectangle9cloneTypeEv,b9,b9,__ZNK3osg16TextureRectangle11libraryNameEv,__ZNK3osg16TextureRectangle9classNameEv,__ZNK3osg16TextureRectangle7getTypeEv,b9,b9,__ZNK3osg16TextureRectangle16getTextureTargetEv,__ZNK3osg16TextureRectangle15getTextureWidthEv,__ZNK3osg16TextureRectangle16getTextureHeightEv,__ZNK3osg16TextureRectangle15getTextureDepthEv,b9,b9,b9,__ZNK3osg16TextureRectangle12getNumImagesEv,b9,b9,b9,b9,__ZNK3osg9Transform9cloneTypeEv
,b9,b9,__ZNK3osg9Transform11libraryNameEv,__ZNK3osg9Transform9classNameEv,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,__ZNK3osg7Uniform9cloneTypeEv,b9,b9,__ZNK3osg7Uniform11libraryNameEv,__ZNK3osg7Uniform9classNameEv,__ZN3osg7Uniform9asUniformEv,__ZNK3osg7Uniform9asUniformEv,b9,b9,b9,b9,b9,b9,__ZNK3osg24DefaultUserDataContainer9cloneTypeEv,b9,b9
,__ZNK3osg24DefaultUserDataContainer11libraryNameEv,__ZNK3osg24DefaultUserDataContainer9classNameEv,__ZN3osg17UserDataContainer19asUserDataContainerEv,__ZNK3osg17UserDataContainer19asUserDataContainerEv,b9,__ZN3osg24DefaultUserDataContainer11getUserDataEv,__ZNK3osg24DefaultUserDataContainer11getUserDataEv,b9,b9,b9,b9,b9,__ZNK3osg24DefaultUserDataContainer17getNumUserObjectsEv,b9,b9,b9,b9,b9,__ZN3osg24DefaultUserDataContainer15getDescriptionsEv,__ZNK3osg24DefaultUserDataContainer15getDescriptionsEv,__ZNK3osg24DefaultUserDataContainer18getNumDescriptionsEv,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,__ZNK3osg8Viewport9cloneTypeEv,b9,b9,__ZNK3osg8Viewport11libraryNameEv,__ZNK3osg8Viewport9classNameEv,__ZNK3osg8Viewport7getTypeEv,b9,b9,b9,b9,b9,b9,b9,b9,b9,__ZNK3osg9BlendFunc9cloneTypeEv,b9
,b9,__ZNK3osg9BlendFunc11libraryNameEv,__ZNK3osg9BlendFunc9classNameEv,__ZNK3osg9BlendFunc7getTypeEv,b9,b9,b9,b9,b9,__ZNK3osg5Light9cloneTypeEv,b9,b9,__ZNK3osg5Light11libraryNameEv,__ZNK3osg5Light9classNameEv,__ZNK3osg5Light7getTypeEv,__ZNK3osg5Light9getMemberEv,b9,b9,b9,b9,b9,__ZNK3osg14ShaderComposer9cloneTypeEv,b9,b9,__ZNK3osg14ShaderComposer11libraryNameEv,__ZNK3osg14ShaderComposer9classNameEv,b9,b9,b9,b9
,b9,b9,__ZN11OpenThreads6Thread6cancelEv,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,__ZN11OpenThreads9Condition6signalEv,__ZN11OpenThreads9Condition9broadcastEv,b9,b9,b9,b9,b9,b9,b9,__ZNKSt9exception4whatEv,b9,b9,b9,b9,__ZNKSt3__210__function6__funcIZN4mjin11application6memory11Coordinator14setupSelectionEvE3__0NS_9allocatorIS6_EEFvRKbEE7__cloneEv,b9
,b9,b9,b9,b9,__ZNKSt3__210__function6__funcIZN4mjin11application6memory11Coordinator14setupSelectionEvE3__0NS_9allocatorIS6_EEFvRKbEE11target_typeEv,b9,b9,b9,b9,__ZNKSt3__210__function6__funcIZN4mjin11application6memory4Game18matchSelectedItemsEvE3__1NS_9allocatorIS6_EEFvvEE7__cloneEv,b9,b9,b9,b9,b9,__ZNKSt3__210__function6__funcIZN4mjin11application6memory4Game18matchSelectedItemsEvE3__1NS_9allocatorIS6_EEFvvEE11target_typeEv,b9,b9,b9,b9,__ZNKSt3__210__function6__funcIZN4mjin11application6memory4Game18animateMatchOrMissEbNS_8functionIFvvEEEE3__2NS_9allocatorIS9_EEFbdEE7__cloneEv,b9,b9,b9,b9,b9,__ZNKSt3__210__function6__funcIZN4mjin11application6memory4Game18animateMatchOrMissEbNS_8functionIFvvEEEE3__2NS_9allocatorIS9_EEFbdEE11target_typeEv,b9,b9,__ZNKSt3__210__function6__funcIZN4mjin11application6memory4Game18matchSelectedItemsEvE3__0NS_9allocatorIS6_EEFvvEE7__cloneEv
,b9,b9,b9,b9,b9,__ZNKSt3__210__function6__funcIZN4mjin11application6memory4Game18matchSelectedItemsEvE3__0NS_9allocatorIS6_EEFvvEE11target_typeEv,b9,b9,__ZNK3osg17TessellationHints9cloneTypeEv,b9,b9,__ZNK3osg17TessellationHints11libraryNameEv,__ZNK3osg17TessellationHints9classNameEv,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,__ZN5osgDB13DatabasePager14DatabaseThread6cancelEv,b9,b9,b9,__ZThn12_N5osgDB13DatabasePager14DatabaseThread6cancelEv,b9,b9,b9,b9,b9,b9,b9,b9,__ZNK5osgDB13DatabasePager31FindCompileableGLObjectsVisitor11libraryNameEv,__ZNK5osgDB13DatabasePager31FindCompileableGLObjectsVisitor9classNameEv,b9,b9,b9,b9,__ZTv0_n32_NK5osgDB13DatabasePager31FindCompileableGLObjectsVisitor11libraryNameEv,__ZTv0_n36_NK5osgDB13DatabasePager31FindCompileableGLObjectsVisitor9classNameEv,b9,b9,b9,__ZNK5osgDB13DatabasePager9classNameEv
,__ZNK5osgDB13DatabasePager5cloneEv,__ZN5osgDB13DatabasePager6cancelEv,__ZNK5osgDB13DatabasePager9isRunningEv,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,__ZNK5osgDB13DatabasePager20FindPagedLODsVisitor11libraryNameEv,__ZNK5osgDB13DatabasePager20FindPagedLODsVisitor9classNameEv,b9,b9,b9,__ZTv0_n32_NK5osgDB13DatabasePager20FindPagedLODsVisitor11libraryNameEv,__ZTv0_n36_NK5osgDB13DatabasePager20FindPagedLODsVisitor9classNameEv,b9,b9,b9,b9,__ZN20SetBasedPagedLODList5cloneEv,b9,__ZN20SetBasedPagedLODList4sizeEv,b9,b9,b9
,b9,b9,b9,__ZNK5osgDB13DatabasePager22ExpirePagedLODsVisitor11libraryNameEv,__ZNK5osgDB13DatabasePager22ExpirePagedLODsVisitor9classNameEv,b9,b9,b9,__ZTv0_n32_NK5osgDB13DatabasePager22ExpirePagedLODsVisitor11libraryNameEv,__ZTv0_n36_NK5osgDB13DatabasePager22ExpirePagedLODsVisitor9classNameEv,b9,b9,__ZN5osgDB10ImagePager11ImageThread6cancelEv,b9,b9,b9,__ZThn12_N5osgDB10ImagePager11ImageThread6cancelEv,b9,b9,b9,b9,b9,b9,__ZNK5osgDB10ImagePager24requiresUpdateSceneGraphEv,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,__ZNK3osg13ShapeDrawable9cloneTypeEv,b9,b9,__ZNK3osg13ShapeDrawable11libraryNameEv,__ZNK3osg13ShapeDrawable9classNameEv,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,_getpix_8,_getpix_16,_getpix_24,_getpix_32,b9,b9,b9,_Emscripten_CreateDevice,_EMSCRIPTENAUDIO_Init,b9,_DUMMY_CreateDevice,_DISKAUDIO_Init,_DUMMYAUDIO_Init,b9,___stdio_close,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE4syncEv,__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE9showmanycEv,b9,__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE9underflowEv,__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE5uflowEv,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,__ZNKSt3__219__iostream_category4nameEv,b9
,b9,b9,b9,b9,b9,__ZNKSt13runtime_error4whatEv,b9,b9,b9,__ZNSt3__211__stdoutbufIwE4syncEv,b9,b9,b9,b9,b9,__ZNSt3__211__stdoutbufIcE4syncEv,b9,b9,b9,b9,b9,__ZNSt3__210__stdinbufIwE9underflowEv,__ZNSt3__210__stdinbufIwE5uflowEv,b9,b9,b9,b9,__ZNSt3__210__stdinbufIcE9underflowEv,__ZNSt3__210__stdinbufIcE5uflowEv,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE13do_date_orderEv
,b9,b9,b9,b9,b9,b9,__ZNKSt3__220__time_get_c_storageIcE7__weeksEv,__ZNKSt3__220__time_get_c_storageIcE8__monthsEv,__ZNKSt3__220__time_get_c_storageIcE7__am_pmEv,__ZNKSt3__220__time_get_c_storageIcE3__cEv,__ZNKSt3__220__time_get_c_storageIcE3__rEv,__ZNKSt3__220__time_get_c_storageIcE3__xEv,__ZNKSt3__220__time_get_c_storageIcE3__XEv,b9,b9,__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE13do_date_orderEv,b9,b9,b9,b9,b9,b9,__ZNKSt3__220__time_get_c_storageIwE7__weeksEv,__ZNKSt3__220__time_get_c_storageIwE8__monthsEv,__ZNKSt3__220__time_get_c_storageIwE7__am_pmEv,__ZNKSt3__220__time_get_c_storageIwE3__cEv,__ZNKSt3__220__time_get_c_storageIwE3__rEv,__ZNKSt3__220__time_get_c_storageIwE3__xEv,__ZNKSt3__220__time_get_c_storageIwE3__XEv,b9
,b9,b9,b9,b9,b9,b9,b9,__ZNKSt3__210moneypunctIcLb0EE16do_decimal_pointEv,__ZNKSt3__210moneypunctIcLb0EE16do_thousands_sepEv,b9,b9,b9,b9,__ZNKSt3__210moneypunctIcLb0EE14do_frac_digitsEv,b9,b9,b9,b9,__ZNKSt3__210moneypunctIcLb1EE16do_decimal_pointEv,__ZNKSt3__210moneypunctIcLb1EE16do_thousands_sepEv,b9,b9,b9,b9,__ZNKSt3__210moneypunctIcLb1EE14do_frac_digitsEv,b9,b9,b9,b9,__ZNKSt3__210moneypunctIwLb0EE16do_decimal_pointEv
,__ZNKSt3__210moneypunctIwLb0EE16do_thousands_sepEv,b9,b9,b9,b9,__ZNKSt3__210moneypunctIwLb0EE14do_frac_digitsEv,b9,b9,b9,b9,__ZNKSt3__210moneypunctIwLb1EE16do_decimal_pointEv,__ZNKSt3__210moneypunctIwLb1EE16do_thousands_sepEv,b9,b9,b9,b9,__ZNKSt3__210moneypunctIwLb1EE14do_frac_digitsEv,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,__ZNKSt3__27codecvtIDic11__mbstate_tE11do_encodingEv,__ZNKSt3__27codecvtIDic11__mbstate_tE16do_always_noconvEv,b9,__ZNKSt3__27codecvtIDic11__mbstate_tE13do_max_lengthEv,b9,b9,b9,b9,b9,b9
,__ZNKSt3__27codecvtIwc11__mbstate_tE11do_encodingEv,__ZNKSt3__27codecvtIwc11__mbstate_tE16do_always_noconvEv,b9,__ZNKSt3__27codecvtIwc11__mbstate_tE13do_max_lengthEv,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,__ZNKSt3__28numpunctIcE16do_decimal_pointEv,__ZNKSt3__28numpunctIcE16do_thousands_sepEv,b9,b9,b9,b9,b9,__ZNKSt3__28numpunctIwE16do_decimal_pointEv,__ZNKSt3__28numpunctIwE16do_thousands_sepEv,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,__ZNKSt3__27codecvtIcc11__mbstate_tE11do_encodingEv,__ZNKSt3__27codecvtIcc11__mbstate_tE16do_always_noconvEv,b9,__ZNKSt3__27codecvtIcc11__mbstate_tE13do_max_lengthEv,b9,b9,b9,b9,__ZNKSt3__27codecvtIDsc11__mbstate_tE11do_encodingEv,__ZNKSt3__27codecvtIDsc11__mbstate_tE16do_always_noconvEv,b9,__ZNKSt3__27codecvtIDsc11__mbstate_tE13do_max_lengthEv
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,__ZNKSt9bad_alloc4whatEv,b9,b9,b9,b9,__ZNKSt11logic_error4whatEv,b9,b9,b9,b9,b9,b9
,b9,__ZNKSt8bad_cast4whatEv,b9,b9,__ZNKSt10bad_typeid4whatEv,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,__ZNSt3__24endlIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,__ZN3osg15isNotifyEnabledENS_14NotifySeverityE,__ZN3osg6notifyENS_14NotifySeverityE,b9,b9
,__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv,b9,b9,b9,b9,b9,b9,__Znwj,b9,b9,__ZN9osgViewer5Scene12getSceneDataEv,b9,__ZN3osg4Node19getOrCreateStateSetEv,b9,b9,b9,b9,__ZNK3osg15DisplaySettings30getMaxNumberOfGraphicsContextsEv,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,__ZNK3osg10Referenced22getOrCreateObserverSetEv,b9,b9,b9
,b9,b9,b9,b9,b9,b9,__ZNK3osg10Referenced14unref_nodeleteEv,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,__ZN9osgViewer8Keystone10createGridEv,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,__ZN3osg15GraphicsContext27getWindowingSystemInterfaceERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE,b9,b9,b9,__ZN3osg15GraphicsContext7realizeEv,__ZN3osg15GraphicsContext11makeCurrentEv,__ZN3osg15GraphicsContext14releaseContextEv,b9,b9,__ZNK3osg5Timer4tickEv,b9,__ZN3osg15GraphicsContext25getOrCreateCompileContextEj,b9
,__ZN11OpenThreads6Thread11startThreadEv,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,__ZN11OpenThreads6Thread9isRunningEv,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,__ZN11OpenThreads35SetProcessorAffinityOfCurrentThreadERKNS_8AffinityE,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,__ZN3osg15GraphicsContext21createGraphicsContextEPNS0_6TraitsE,b9,b9,__ZN9osgViewer8Keystone17loadKeystoneFilesEPN3osg15DisplaySettingsE,b9,b9,b9,b9
,b9,b9,b9,__ZN5osgDB8Registry8instanceEb,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,__ZNK3osg4Node8getBoundEv,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,__ZNK3osg4Node21containsOccluderNodesEv,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,__ZN3osg9cloneTypeIN7osgUtil11RenderStageEEEPT_PKS3_,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,__ZN3osg22getOrCreateContextDataEj,__ZN3osg11ContextData3getINS_21GLRenderBufferManagerEEEPT_v,__ZN3osg11ContextData3getINS_26GLFrameBufferObjectManagerEEEPT_v,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,__ZNK3osg12BufferObject25computeRequiredBufferSizeEv,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,_glGetString__wrapper,b9,b9,b9,b9,_eglGetProcAddress__wrapper,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,__ZNK3osg5Image35getTotalSizeInBytesIncludingMipmapsEv,__Znaj,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,__ZN3osg11ContextData3getI16GLProgramManagerEEPT_v,b9,b9,__ZN3osg7Uniform9getNameIDERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE,b9,__ZN3osg7Uniform11getTypenameENS0_4TypeE,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,__ZN3osg11ContextData3getI15GLShaderManagerEEPT_v,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,__ZNK3osg5Image25supportsTextureSubloadingEv,b9,b9,__ZNK3osg7Texture26areAllTextureObjectsLoadedEv,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,__ZN11OpenThreads20ThreadPrivateActions11StartThreadEPv,b9,_pthread_mutex_destroy__wrapper,_pthread_cond_destroy__wrapper,b9,b9,b9,b9,b9,__ZN3osg4View9getCameraEv,b9,b9,b9,b9,b9,b9
,b9,__ZNK3osg10Referenced5unrefEv,b9,b9,__ZNSt3__28functionIFvRKbEE9__as_baseEPv,b9,b9,b9,b9,b9,__ZNK3osg7ref_ptrINS_5GroupEEptEv,b9,b9,b9,b9,b9,__ZNK3osg7ref_ptrINS_5GroupEEcvPS1_Ev,b9,b9,b9,b9,b9,b9,b9,__ZNSt3__28functionIFbdEE9__as_baseEPv,b9,__ZNSt3__28functionIFvvEE9__as_baseEPv,b9,b9,b9
,b9,b9,b9,b9,b9,b9,__ZNK3osg7ref_ptrINS_5GeodeEEptEv,b9,__ZN3osg7ref_ptrINS_5GeodeEE7releaseEv,b9,__ZNK3osg7ref_ptrINS_8StateSetEEptEv,__ZN3osg7ref_ptrINS_8StateSetEE7releaseEv,b9,b9,__ZNK3osg7ref_ptrIN7osgUtil22LineSegmentIntersectorEE3getEv,__ZNK3osg7ref_ptrIN7osgUtil22LineSegmentIntersectorEEptEv,b9,__ZNK3osg4Node11getNodeMaskEv,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,_time__wrapper,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,__ZN5osgDB12ReaderWriter10ReadResult7getNodeEv,b9,b9,b9,b9,__ZN11OpenThreads6Thread10testCancelEv,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,__ZN5osgDB10ImagePager6cancelEv,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,__ZN5osgDB12ReaderWriter10ReadResult8getImageEv,__ZN5osgDB12ReaderWriter10ReadResult9getObjectEv,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,__ZN5osgDB14DynamicLibrary11loadLibraryERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE,b9,b9,b9,b9,b9,__ZN5osgDB10fileExistsERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE,b9,b9,b9
,b9,__ZN5osgDB12ReaderWriter10ReadResult10getArchiveEv,b9,b9,b9,b9,b9,__ZN5osgDB21containsServerAddressERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,_dlclose__wrapper,__ZN5osgDB14DynamicLibrary16getLibraryHandleERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE
,b9,b9,b9,b9,b9,b9,__ZN5osgDB13makeDirectoryERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,_strerror,b9,b9,b9,b9,_readdir,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,_GLES2_UpdateViewport,_GLES2_UpdateClipRect,_GLES2_RenderClear,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,_SW_UpdateViewport,_SW_UpdateClipRect,_SW_RenderClear,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,_Emscripten_VideoInit,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,_SDL_EGL_GetSwapInterval,b9,b9,b9,b9,b9,_eglGetDisplay__wrapper,b9,_eglTerminate__wrapper,b9,b9,b9,b9,b9,b9,b9,b9,b9,_eglWaitNative__wrapper,b9,_eglBindAPI__wrapper,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,_Emscripten_ShowCursor,b9,b9,_Emscripten_CreateSystemCursor,_Emscripten_SetRelativeMouseMode,b9,b9,b9,b9,_DUMMY_VideoInit,b9,b9,b9,b9,b9,b9,b9,_stdio_size
,b9,b9,b9,_stdio_close,b9,b9,b9,_DISKAUDIO_GetDeviceBuf,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,_SDL_AudioGetPendingBytes_Default,_SDL_AudioGetDeviceBuf_Default,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,_emscripten_glGetString__wrapper,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,_emscripten_glIsTexture__wrapper,b9,b9,b9,b9,b9,_emscripten_glIsBuffer__wrapper,b9,b9,b9,b9,_emscripten_glIsRenderbuffer__wrapper,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,_emscripten_glCreateShader__wrapper,b9,b9,b9,b9,b9,b9
,b9,b9,_emscripten_glIsShader__wrapper,b9,b9,b9,b9,b9,b9,b9,b9,b9,_emscripten_glIsProgram__wrapper,b9,b9,b9,b9,b9,b9,b9,_emscripten_glIsFramebuffer__wrapper,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,_emscripten_glCheckFramebufferStatus__wrapper,b9,b9,b9,_emscripten_glIsEnabled__wrapper,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEE5flushEv,b9,b9,b9,b9,b9,___uselocale,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,_wcslen,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,_pthread_mutex_unlock__wrapper,_pthread_mutex_lock__wrapper,_pthread_cond_broadcast__wrapper,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9];
var FUNCTION_TABLE_viidiii = [b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,__ZN20SetBasedPagedLODList21removeExpiredChildrenEidjRNSt3__24listIN3osg7ref_ptrINS2_6ObjectEEENS0_9allocatorIS5_EEEEb,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10];
var FUNCTION_TABLE_viidd = [b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,__ZN7osgUtil22LineSegmentIntersectorC2ENS_11Intersector15CoordinateFrameEdd,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,__ZN7osgUtil14RayIntersectorC2ENS_11Intersector15CoordinateFrameEdd,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11];
var FUNCTION_TABLE_iidd = [b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12
,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12
,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12
,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12
,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12
,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12
,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12
,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12
,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12
,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12
,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12
,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12
,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12
,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12
,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12
,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12
,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12
,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12
,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12
,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12
,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12
,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12
,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12
,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12
,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12
,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12
,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12
,b12,b12,b12,b12,b12,b12,__ZN5osgGA16OrbitManipulator25performMouseDeltaMovementEff,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12
,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12
,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12
,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,__ZN5osgGA19StandardManipulator25performMouseDeltaMovementEff,b12,b12,b12,b12,b12,b12,b12
,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12
,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12
,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12,b12
,b12,b12,b12,b12,b12];
var FUNCTION_TABLE_viiiiiiiii = [b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,_Color16DitherYV12Mod1X,_Color16DitherYV12Mod2X,_Color24DitherYV12Mod1X,_Color24DitherYV12Mod2X,_Color32DitherYV12Mod1X,_Color32DitherYV12Mod2X,_Color16DitherYUY2Mod1X,_Color16DitherYUY2Mod2X,_Color24DitherYUY2Mod1X,_Color24DitherYUY2Mod2X,_Color32DitherYUY2Mod1X,_Color32DitherYUY2Mod2X,b13,b13,b13,b13,b13,b13,b13,b13,_emscripten_glCompressedTexSubImage2D__wrapper,_emscripten_glTexImage2D__wrapper,_emscripten_glTexSubImage2D__wrapper,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
,b13,b13,b13];
var FUNCTION_TABLE_viiiidiii = [b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,__ZN5osgDB10ImagePager16requestImageFileERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEPN3osg6ObjectEidPKNSA_10FrameStampERNSA_7ref_ptrINSA_10ReferencedEEEPKSH_,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14,b14];
var FUNCTION_TABLE_viddd = [b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,__ZN5osgGA16OrbitManipulator8panModelEfff,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,__ZN7osgUtil10Statistics6vertexEfff,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,__ZN12ComputeBound6vertexEfff,b15,b15,__ZN12ComputeBound6vertexEddd,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,__ZN3osg7Matrixd9makeScaleEddd,__ZN3osg7Matrixd13makeTranslateEddd,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,__ZN3osg7Matrixd8setTransEddd,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,__ZN3osg5Vec3fC2Efff,b15,__ZN4mjin11application6memory8material3RGBC2Efff,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,_emscripten_glUniform3f__wrapper,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,_emscripten_glVertexAttrib3f__wrapper,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15];
var FUNCTION_TABLE_iiiiii = [b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,__ZN9osgViewer14GraphicsWindow32setWindowRectangleImplementationEiiii,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,__ZN5osgGA16GUIActionAdapter20computeIntersectionsERKNS_15GUIEventAdapterERKNSt3__26vectorIPN3osg4NodeENS4_9allocatorIS8_EEEERNS4_8multisetIN7osgUtil22LineSegmentIntersector12IntersectionENS4_4lessISH_EENS9_ISH_EEEEj,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,__ZN9osgViewer4View20computeIntersectionsERKN5osgGA15GUIEventAdapterERKNSt3__26vectorIPN3osg4NodeENS5_9allocatorIS9_EEEERNS5_8multisetIN7osgUtil22LineSegmentIntersector12IntersectionENS5_4lessISI_EENSA_ISI_EEEEj,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,__ZThn36_N9osgViewer4View20computeIntersectionsERKN5osgGA15GUIEventAdapterERKNSt3__26vectorIPN3osg4NodeENS5_9allocatorIS9_EEEERNS5_8multisetIN7osgUtil22LineSegmentIntersector12IntersectionENS5_4lessISI_EENSA_ISI_EEEEj,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,__ZN9osgViewer6Viewer29setUpViewerAsEmbeddedInWindowEiiii,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,__ZN9osgViewer15KeystoneHandler6handleERKN5osgGA15GUIEventAdapterERNS1_16GUIActionAdapterEPN3osg6ObjectEPNS7_11NodeVisitorE,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,__ZN5osgGA15GUIEventHandler6handleERKNS_15GUIEventAdapterERNS_16GUIActionAdapterEPN3osg6ObjectEPNS6_11NodeVisitorE,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,__ZN4mjin11application6memory5input5Mouse6handleERKN5osgGA15GUIEventAdapterERNS4_16GUIActionAdapterEPN3osg6ObjectEPNSA_11NodeVisitorE,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,__ZNKSt3__27collateIcE10do_compareEPKcS3_S3_S3_,b16,b16,b16,b16,__ZNKSt3__27collateIwE10do_compareEPKwS3_S3_S3_,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,__ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcb,__ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcl,b16,__ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcm,b16,b16,b16,__ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcPKv,b16,b16,__ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwb,__ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwl,b16,__ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwm,b16,b16,b16,__ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwPKv,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,__ZNKSt3__27codecvtIDic11__mbstate_tE10do_unshiftERS1_PcS4_RS4_,b16,b16,__ZNKSt3__27codecvtIDic11__mbstate_tE9do_lengthERS1_PKcS5_j,b16,b16,b16,b16,b16,b16,__ZNKSt3__27codecvtIwc11__mbstate_tE10do_unshiftERS1_PcS4_RS4_
,b16,b16,__ZNKSt3__27codecvtIwc11__mbstate_tE9do_lengthERS1_PKcS5_j,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,__ZNKSt3__25ctypeIcE9do_narrowEPKcS3_cPc,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,__ZNKSt3__25ctypeIwE9do_narrowEPKwS3_cPc,b16,b16,b16,__ZNKSt3__27codecvtIcc11__mbstate_tE10do_unshiftERS1_PcS4_RS4_,b16,b16,__ZNKSt3__27codecvtIcc11__mbstate_tE9do_lengthERS1_PKcS5_j,b16,b16,b16,b16,__ZNKSt3__27codecvtIDsc11__mbstate_tE10do_unshiftERS1_PcS4_RS4_,b16,b16,__ZNKSt3__27codecvtIDsc11__mbstate_tE9do_lengthERS1_PKcS5_j,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7compareEjjPKcj,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,__ZN3osg4View8addSlaveEPNS_6CameraERKNS_7MatrixdES5_b,b16,b16,b16,b16,b16,b16,b16,__ZN9osgViewer4View27assignRenderToTextureCameraEPN3osg15GraphicsContextEiiPNS1_7TextureE,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,__ZNK3osg6Camera32getProjectionMatrixAsPerspectiveERdS1_S1_S1_,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,__ZNSt3__26__treeINS_12__value_typeINS_4pairIN3osg14StateAttribute4TypeEjEENS3_5State14AttributeStackEEENS_19__map_value_compareIS6_S9_NS_4lessIS6_EELb1EEENS_9allocatorIS9_EEE12__find_equalIS6_EERPNS_16__tree_node_baseIPvEENS_21__tree_const_iteratorIS9_PNS_11__tree_nodeIS9_SJ_EEiEERPNS_15__tree_end_nodeISL_EESM_RKT_,b16,b16,__ZNSt3__26__treeINS_12__value_typeIjN3osg5State9ModeStackEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEE12__find_equalIjEERPNS_16__tree_node_baseIPvEENS_21__tree_const_iteratorIS5_PNS_11__tree_nodeIS5_SF_EEiEERPNS_15__tree_end_nodeISH_EESI_RKT_,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,__ZNSt3__26__treeINS_12__value_typeIiN3osg7ref_ptrINS2_8StateSetEEEEENS_19__map_value_compareIiS6_NS_4lessIiEELb1EEENS_9allocatorIS6_EEE12__find_equalIiEERPNS_16__tree_node_baseIPvEENS_21__tree_const_iteratorIS6_PNS_11__tree_nodeIS6_SG_EEiEERPNS_15__tree_end_nodeISI_EESJ_RKT_,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,__ZNSt3__26__treeINS_12__value_typeIiN3osg7ref_ptrIN7osgUtil9RenderBinEEEEENS_19__map_value_compareIiS7_NS_4lessIiEELb1EEENS_9allocatorIS7_EEE12__find_equalIiEERPNS_16__tree_node_baseIPvEENS_21__tree_const_iteratorIS7_PNS_11__tree_nodeIS7_SH_EEiEERPNS_15__tree_end_nodeISJ_EESK_RKT_,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,__ZNSt3__26__treeINS_12__value_typeIN3osg6Camera15BufferComponentENS3_10AttachmentEEENS_19__map_value_compareIS4_S6_NS_4lessIS4_EELb1EEENS_9allocatorIS6_EEE12__find_equalIS4_EERPNS_16__tree_node_baseIPvEENS_21__tree_const_iteratorIS6_PNS_11__tree_nodeIS6_SG_EEiEERPNS_15__tree_end_nodeISI_EESJ_RKT_,b16,__ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEE12__find_equalIjEERPNS_16__tree_node_baseIPvEENS_21__tree_const_iteratorIjPNS_11__tree_nodeIjS8_EEiEERPNS_15__tree_end_nodeISA_EESB_RKT_,b16,b16,__ZN3osg20ShadowVolumeOccluder15computeOccluderERKNSt3__26vectorIPNS_4NodeENS1_9allocatorIS4_EEEERKNS_20ConvexPlanarOccluderERNS_9CullStackEb,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,__ZNSt3__26__treeINS_12__value_typeIN3osg6Camera15BufferComponentENS2_21FrameBufferAttachmentEEENS_19__map_value_compareIS4_S6_NS_4lessIS4_EELb1EEENS_9allocatorIS6_EEE12__find_equalIS4_EERPNS_16__tree_node_baseIPvEENS_21__tree_const_iteratorIS6_PNS_11__tree_nodeIS6_SG_EEiEERPNS_15__tree_end_nodeISI_EESJ_RKT_,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,__ZNSt3__26__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EENS4_IS6_EEE12__find_equalIS6_EERPNS_16__tree_node_baseIPvEENS_21__tree_const_iteratorIS6_PNS_11__tree_nodeIS6_SD_EEiEERPNS_15__tree_end_nodeISF_EESG_RKT_,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,__ZN11BuildKdTree6divideERN3osg6KdTree12BuildOptionsERNS0_15BoundingBoxImplINS0_5Vec3fEEEij,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,__ZNSt3__26__treeINS_12__value_typeIjjEENS_19__map_value_compareIjS2_NS_4lessIjEELb1EEENS_9allocatorIS2_EEE12__find_equalIjEERPNS_16__tree_node_baseIPvEENS_21__tree_const_iteratorIS2_PNS_11__tree_nodeIS2_SC_EEiEERPNS_15__tree_end_nodeISE_EESF_RKT_,b16,b16,b16,__ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4pairIS7_jEEEENS_19__map_value_compareIS7_SA_NS_4lessIS7_EELb1EEENS5_ISA_EEE12__find_equalIS7_EERPNS_16__tree_node_baseIPvEENS_21__tree_const_iteratorISA_PNS_11__tree_nodeISA_SJ_EEiEERPNS_15__tree_end_nodeISL_EESM_RKT_,b16,b16,b16,__ZNSt3__26__treeINS_12__value_typeINS_4pairIN3osg14StateAttribute4TypeEjEENS2_INS3_7ref_ptrIS4_EEjEEEENS_19__map_value_compareIS6_SA_NS_4lessIS6_EELb1EEENS_9allocatorISA_EEE12__find_equalIS6_EERPNS_16__tree_node_baseIPvEENS_21__tree_const_iteratorISA_PNS_11__tree_nodeISA_SK_EEiEERPNS_15__tree_end_nodeISM_EESN_RKT_,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,__ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEdEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE12__find_equalIS7_EERPNS_16__tree_node_baseIPvEENS_21__tree_const_iteratorIS8_PNS_11__tree_nodeIS8_SH_EEiEERPNS_15__tree_end_nodeISJ_EESK_RKT_,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,__ZNSt3__26__treeINS_12__value_typeINS_4pairINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7ref_ptrIKN5osgDB7OptionsEEEEENS2_INSA_INS9_6ObjectEEEdEEEENS_19__map_value_compareISF_SJ_NSB_11ObjectCache9ClassCompELb1EEENS6_ISJ_EEE12__find_equalISF_EERPNS_16__tree_node_baseIPvEENS_21__tree_const_iteratorISJ_PNS_11__tree_nodeISJ_SS_EEiEERPNS_15__tree_end_nodeISU_EESV_RKT_,b16,b16,b16,b16
,__ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPvEENS_19__map_value_compareIS7_S9_NS_4lessIS7_EELb1EEENS5_IS9_EEE12__find_equalIS7_EERPNS_16__tree_node_baseIS8_EENS_21__tree_const_iteratorIS9_PNS_11__tree_nodeIS9_S8_EEiEERPNS_15__tree_end_nodeISJ_EESK_RKT_,__ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES7_EENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE12__find_equalIS7_EERPNS_16__tree_node_baseIPvEENS_21__tree_const_iteratorIS8_PNS_11__tree_nodeIS8_SH_EEiEERPNS_15__tree_end_nodeISJ_EESK_RKT_,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,_GLES2_UpdateTexture,b16,_GLES2_LockTexture,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,_GLES2_RenderReadPixels,b16,b16,b16,b16,b16,_uncopy_32,_uncopy_opaque_16,_uncopy_transl_16,b16,b16,b16,b16,_copy_transl_565
,_copy_transl_555,_copy_opaque_16,_copy_32,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,_SW_UpdateTexture,_SW_LockTexture,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,_SW_RenderReadPixels,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,_Emscripten_CreateWindowFramebuffer,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,_eglChooseConfig__wrapper,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,_SDL_DUMMY_CreateWindowFramebuffer,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,_SDL_CreateWindowTexture,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,_wcsnrtombs,b16
,_mbsnrtowcs,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16,b16
,b16,b16,b16];
var FUNCTION_TABLE_vidi = [b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,__ZN5osgGA16OrbitManipulator9zoomModelEfb,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,__ZN3osg21GLBufferObjectManager21flushDeletedGLObjectsEdRd,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,__ZN3osg11ContextData21flushDeletedGLObjectsEdRd,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,__ZN18DisplayListManager21flushDeletedGLObjectsEdRd,b17,b17,b17,b17,b17,__ZN3osg15GLObjectManager21flushDeletedGLObjectsEdRd,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,__ZN3osg20TextureObjectManager21flushDeletedGLObjectsEdRd,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,__ZN23VertexArrayStateManager21flushDeletedGLObjectsEdRd,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,__ZN3osg7Matrixd10makeRotateEdRKNS_5Vec3fE,b17,b17,__ZN3osg17GLBufferObjectSet27flushDeletedGLBufferObjectsEdRd,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17
,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17,b17];
var FUNCTION_TABLE_viiidiii = [b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,__ZN5osgDB13DatabasePager15requestNodeFileERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEERNS1_6vectorIPN3osg4NodeENS5_ISD_EEEEfPKNSB_10FrameStampERNSB_7ref_ptrINSB_10ReferencedEEEPKSL_,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18
,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18,b18];
var FUNCTION_TABLE_vdddddd = [b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,_emscripten_glFrustum__wrapper,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19,b19
,b19,b19,b19];
var FUNCTION_TABLE_iiiidddd = [b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,__ZN3osg26createTexturedQuadGeometryERKNS_5Vec3fES2_S2_ffff,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20
,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20,b20];
var FUNCTION_TABLE_viddi = [b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,__ZN5osgGA16OrbitManipulator23rotateWithFixedVerticalEffRKN3osg5Vec3fE,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,__ZN5osgGA19StandardManipulator14rotateYawPitchERN3osg4QuatEddRKNS1_5Vec3dE,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21
,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21,b21];
var FUNCTION_TABLE_vidd = [b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,__ZN9osgViewer14GraphicsWindow18requestWarpPointerEff,b22,b22,b22,b22,b22,__ZThn132_N9osgViewer14GraphicsWindow18requestWarpPointerEff,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,__ZN9osgViewer4View18requestWarpPointerEff,b22,b22,b22,b22,b22,b22,b22,__ZThn36_N9osgViewer4View18requestWarpPointerEff,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,__ZN5osgGA16OrbitManipulator18applyAnimationStepEdd,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,__ZN5osgGA16OrbitManipulator23rotateWithFixedVerticalEff,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,__ZN5osgGA19StandardManipulator18applyAnimationStepEdd,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,__ZN7osgUtil10Statistics6vertexEff,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,__ZN12ComputeBound6vertexEff,b22,b22,__ZN12ComputeBound6vertexEdd,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,__ZN3osg5Vec2fC2Eff,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,_emscripten_glUniform2f__wrapper,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,_emscripten_glVertexAttrib2f__wrapper,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22,b22
,b22,b22,b22];
var FUNCTION_TABLE_iiii = [b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE6setbufEPci,b23,b23
,b23,b23,__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE6xsgetnEPci,b23,b23,b23,__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE6xsputnEPKci,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,__ZNK3osg13TemplateArrayINS_5Vec3fELNS_5Array4TypeE28ELi3ELi5126EE7compareEjj,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,__ZNK3osg13TemplateArrayINS_5Vec2fELNS_5Array4TypeE27ELi2ELi5126EE7compareEjj,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,__ZNK3osg13TemplateArrayINS_5Vec4fELNS_5Array4TypeE29ELi4ELi5126EE7compareEjj,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,__ZN5osgGA12EventHandler3runEPN3osg6ObjectES3_
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,__ZN5osgGA15GUIEventHandler6handleERKNS_15GUIEventAdapterERNS_16GUIActionAdapterE,b23,b23,b23,b23,b23,b23,b23,__ZThn4_N5osgGA12EventHandler3runEPN3osg6ObjectES3_,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,__ZTv0_n108_N5osgGA12EventHandler3runEPN3osg6ObjectES3_,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,__ZN3osg8Callback3runEPNS_6ObjectES2_,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,__ZN3osg12NodeCallback3runEPNS_6ObjectES2_,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,__ZTv0_n108_N3osg12NodeCallback3runEPNS_6ObjectES2_,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,__ZN3osg21DrawableEventCallback3runEPNS_6ObjectES2_,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,__ZTv0_n108_N3osg21DrawableEventCallback3runEPNS_6ObjectES2_,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,__ZN3osg22DrawableUpdateCallback3runEPNS_6ObjectES2_,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,__ZTv0_n108_N3osg22DrawableUpdateCallback3runEPNS_6ObjectES2_,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,__ZN5osgGA19StandardManipulator6handleERKNS_15GUIEventAdapterERNS_16GUIActionAdapterE,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,__ZN5osgGA19StandardManipulator11handleFrameERKNS_15GUIEventAdapterERNS_16GUIActionAdapterE,__ZN5osgGA19StandardManipulator12handleResizeERKNS_15GUIEventAdapterERNS_16GUIActionAdapterE,__ZN5osgGA19StandardManipulator15handleMouseMoveERKNS_15GUIEventAdapterERNS_16GUIActionAdapterE,__ZN5osgGA19StandardManipulator15handleMouseDragERKNS_15GUIEventAdapterERNS_16GUIActionAdapterE,__ZN5osgGA19StandardManipulator15handleMousePushERKNS_15GUIEventAdapterERNS_16GUIActionAdapterE,__ZN5osgGA19StandardManipulator18handleMouseReleaseERKNS_15GUIEventAdapterERNS_16GUIActionAdapterE,__ZN5osgGA19StandardManipulator13handleKeyDownERKNS_15GUIEventAdapterERNS_16GUIActionAdapterE,__ZN5osgGA19StandardManipulator11handleKeyUpERKNS_15GUIEventAdapterERNS_16GUIActionAdapterE
,__ZN5osgGA16OrbitManipulator16handleMouseWheelERKNS_15GUIEventAdapterERNS_16GUIActionAdapterE,__ZN5osgGA19StandardManipulator24handleMouseDeltaMovementERKNS_15GUIEventAdapterERNS_16GUIActionAdapterE,b23,b23,b23,b23,b23,__ZN5osgGA19StandardManipulator24performAnimationMovementERKNS_15GUIEventAdapterERNS_16GUIActionAdapterE,b23,b23,b23,__ZN5osgGA19StandardManipulator35setCenterByMousePointerIntersectionERKNS_15GUIEventAdapterERNS_16GUIActionAdapterE,__ZN5osgGA16OrbitManipulator40startAnimationByMousePointerIntersectionERKNS_15GUIEventAdapterERNS_16GUIActionAdapterE,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,__ZN5osgGA17CameraManipulator6handleERKNS_15GUIEventAdapterERNS_16GUIActionAdapterE,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,__ZN5osgGA19StandardManipulator16handleMouseWheelERKNS_15GUIEventAdapterERNS_16GUIActionAdapterE,b23,b23,b23,b23,b23,__ZN5osgGA19StandardManipulator40startAnimationByMousePointerIntersectionERKNS_15GUIEventAdapterERNS_16GUIActionAdapterE,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,__ZNK3osg13TemplateArrayIdLNS_5Array4TypeE8ELi1ELi5130EE7compareEjj,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,__ZNK3osg13TemplateArrayIfLNS_5Array4TypeE7ELi1ELi5126EE7compareEjj,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,__ZNK3osg18TemplateIndexArrayIjLNS_5Array4TypeE6ELi1ELi5125EE7compareEjj,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,__ZNK3osg18TemplateIndexArrayIiLNS_5Array4TypeE3ELi1ELi5124EE7compareEjj,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,__ZN3osg5Group11insertChildEjPNS_4NodeE,b23,__ZN3osg5Group14removeChildrenEjj,__ZN3osg5Group12replaceChildEPNS_4NodeES2_,b23,__ZN3osg5Group8setChildEjPNS_4NodeE,b23,b23,b23,b23,b23,b23,b23,b23,__ZNK3osg6Camera25computeLocalToWorldMatrixERNS_7MatrixdEPNS_11NodeVisitorE,__ZNK3osg6Camera25computeWorldToLocalMatrixERNS_7MatrixdEPNS_11NodeVisitorE,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,__ZN3osg5Geode15removeDrawablesEjj,__ZN3osg5Geode15replaceDrawableEPNS_8DrawableES2_,__ZN3osg5Geode11setDrawableEjPNS_8DrawableE,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,__ZN3osg5Image12sendKeyEventEib,b23,b23,b23,b23,b23,b23,b23,b23,__ZN3osg22StateAttributeCallback3runEPNS_6ObjectES2_,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,__ZTv0_n108_N3osg22StateAttributeCallback3runEPNS_6ObjectES2_,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,__ZN3osg6KdTree5buildERNS0_12BuildOptionsEPNS_8GeometryE,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,__ZN3osg16NullStreamBuffer6xsputnEPKci,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,__ZNK3osg9Transform25computeLocalToWorldMatrixERNS_7MatrixdEPNS_11NodeVisitorE,__ZNK3osg9Transform25computeWorldToLocalMatrixERNS_7MatrixdEPNS_11NodeVisitorE,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,__ZNK3osg24DefaultUserDataContainer18getUserObjectIndexEPKNS_6ObjectEj,__ZNK3osg24DefaultUserDataContainer18getUserObjectIndexERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEj,__ZN3osg17UserDataContainer13getUserObjectERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEj,__ZNK3osg17UserDataContainer13getUserObjectERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEj,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,__ZN11OpenThreads9Condition4waitEPNS_5MutexEm,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,__ZN5osgDB13DatabasePager17addDatabaseThreadENS0_14DatabaseThread4ModeERKNSt3__212basic_stringIcNS3_11char_traitsIcEENS3_9allocatorIcEEEE,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,__ZNK5osgDB8Registry18ReadArchiveFunctor9cloneTypeERKNSt3__212basic_stringIcNS2_11char_traitsIcEENS2_9allocatorIcEEEEPKNS_7OptionsE,b23,b23,b23,b23,__ZNK5osgDB8Registry17ReadObjectFunctor9cloneTypeERKNSt3__212basic_stringIcNS2_11char_traitsIcEENS2_9allocatorIcEEEEPKNS_7OptionsE,b23,b23,b23,b23,__ZNK5osgDB8Registry16ReadImageFunctor9cloneTypeERKNSt3__212basic_stringIcNS2_11char_traitsIcEENS2_9allocatorIcEEEEPKNS_7OptionsE,b23,b23,b23,b23
,__ZNK5osgDB8Registry22ReadHeightFieldFunctor9cloneTypeERKNSt3__212basic_stringIcNS2_11char_traitsIcEENS2_9allocatorIcEEEEPKNS_7OptionsE,b23,b23,b23,b23,__ZNK5osgDB8Registry15ReadNodeFunctor9cloneTypeERKNSt3__212basic_stringIcNS2_11char_traitsIcEENS2_9allocatorIcEEEEPKNS_7OptionsE,b23,b23,b23,b23,__ZNK5osgDB8Registry17ReadShaderFunctor9cloneTypeERKNSt3__212basic_stringIcNS2_11char_traitsIcEENS2_9allocatorIcEEEEPKNS_7OptionsE,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,___stdout_write,___stdio_seek,___stdio_read,___stdio_write,_sn_write,b23,b23
,b23,b23,b23,b23,b23,b23,b23,__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE6setbufEPwi,b23,b23,b23,b23,__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE6xsgetnEPwi,b23,b23,b23,__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE6xsputnEPKwi,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,__ZNKSt3__214error_category10equivalentEiRKNS_15error_conditionE,__ZNKSt3__214error_category10equivalentERKNS_10error_codeEi,b23,b23,b23,b23,b23,b23,b23,b23,__ZNSt3__211__stdoutbufIwE6xsputnEPKwi,b23,b23,b23,b23,b23,__ZNSt3__211__stdoutbufIcE6xsputnEPKci,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,__ZNKSt3__27collateIcE7do_hashEPKcS3_,b23,b23,b23,b23,__ZNKSt3__27collateIwE7do_hashEPKwS3_,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,__ZNKSt3__28messagesIcE7do_openERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKNS_6localeE,b23,b23,b23,b23,__ZNKSt3__28messagesIwE7do_openERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKNS_6localeE,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,__ZNKSt3__25ctypeIcE10do_toupperEPcPKc,b23,__ZNKSt3__25ctypeIcE10do_tolowerEPcPKc,b23,b23,__ZNKSt3__25ctypeIcE9do_narrowEcc,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,__ZNKSt3__25ctypeIwE5do_isEtw,b23,b23,b23,b23,__ZNKSt3__25ctypeIwE10do_toupperEPwPKw,b23,__ZNKSt3__25ctypeIwE10do_tolowerEPwPKw,b23,b23,__ZNKSt3__25ctypeIwE9do_narrowEwc,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,__ZNK10__cxxabiv117__class_type_info9can_catchEPKNS_16__shim_type_infoERPv,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,__ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,__ZN9osgViewer4View23createDistortionTextureEii,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,__ZN5osgDB15writeObjectFileERKN3osg6ObjectERKNSt3__212basic_stringIcNS4_11char_traitsIcEENS4_9allocatorIcEEEEPKNS_7OptionsE,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKcj,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,__ZN7osgUtil9RenderBin14find_or_insertEiRKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,__ZNSt3__26__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EENS4_IS6_EEE12__find_equalIS6_EERPNS_16__tree_node_baseIPvEERPNS_15__tree_end_nodeISF_EERKT_,b23,b23,__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5eraseEjj,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,__ZNSt3__26vectorIN3osg7ref_ptrINS1_4NodeEEENS_9allocatorIS4_EEE6insertENS_11__wrap_iterIPKS4_EERS9_,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,__ZN11BuildKdTree5buildERN3osg6KdTree12BuildOptionsEPNS0_8GeometryE,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,__ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7Program16UniformBlockInfoEEENS_19__map_value_compareIS7_SB_NS_4lessIS7_EELb1EEENS5_ISB_EEE12__find_equalIS7_EERPNS_16__tree_node_baseIPvEERPNS_15__tree_end_nodeISM_EERKT_,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6insertEjPKc,__ZNK3osg12GLExtensions16getShaderInfoLogEjRNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,__Z4clipRKNSt3__26vectorIN3osg5PlaneENS_9allocatorIS2_EEEERKNS0_INS1_5Vec3fENS3_IS8_EEEERNS0_INS_4pairIjS8_EENS3_ISE_EEEE,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,__ZN11State_Utils7replaceERNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEERKS6_S9_,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,__ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEjEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE12__find_equalIS7_EERPNS_16__tree_node_baseIPvEERPNS_15__tree_end_nodeISJ_EERKT_,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,__ZN4mjin11application6memory8material4Pool17referenceMaterialEPvRKNS2_3RGBE,b23,b23,b23,b23,b23,b23,b23,b23,__ZNSt3__24stoiERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPji,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,__ZNK5osgDB11ObjectCache9ClassCompclERKNSt3__24pairINS2_12basic_stringIcNS2_11char_traitsIcEENS2_9allocatorIcEEEEN3osg7ref_ptrIKNS_7OptionsEEEEESH_,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,__ZN5osgDB8Registry38getReaderWriterForProtocolAndExtensionERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEES9_,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,_GLES2_GetOutputSize,b23,b23,b23,b23,b23,b23,b23,b23,b23,_GLES2_RenderDrawPoints,_GLES2_RenderDrawLines,_GLES2_RenderFillRects,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,_SW_GetOutputSize,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,_SW_RenderDrawPoints,_SW_RenderDrawLines,_SW_RenderFillRects,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,_Emscripten_SetDisplayMode,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,_Emscripten_GLES_MakeCurrent,b23,b23,b23,b23,b23,b23,_Emscripten_HandleCanvasResize,b23,_eglInitialize__wrapper,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,_Emscripten_HandleMouseMove,_Emscripten_HandleMouseButton,_Emscripten_HandleMouseFocus,_Emscripten_HandleWheel,_Emscripten_HandleFocus,_Emscripten_HandleTouch,_Emscripten_HandleKey,_Emscripten_HandleKeyPress,_Emscripten_HandleFullscreenChange,_Emscripten_HandleResize,_Emscripten_HandleVisibilityChange,_Emscripten_CreateCursor,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,_DUMMY_SetDisplayMode,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,_DISKAUDIO_CaptureFromDevice,b23,b23,b23,b23,_DUMMYAUDIO_CaptureFromDevice,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,_SDL_AudioCaptureFromDevice_Default,b23,b23,b23
,b23,b23,b23,b23,b23,b23,_Emscripten_JoyStickConnected,_Emscripten_JoyStickDisconnected,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,_do_read_447,b23,_wmemcpy,b23,b23,b23,b23,b23,b23,b23,b23,b23,___newlocale,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,_vasprintf,b23,b23,b23,b23,b23,_wmemset,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE23__append_forward_unsafeIPcEERS5_T_S9_,b23,b23,b23,b23,b23,b23,b23,__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE23__append_forward_unsafeIPwEERS5_T_S9_,b23,b23,__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6appendEPKwj,b23,b23,b23,b23,b23,b23,b23,_wcrtomb
,b23,b23,_mbtowc,b23,_mbrlen,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,_wmemmove,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23,b23
,b23,b23,b23];
var FUNCTION_TABLE_viiiiiiiiiiiiiii = [b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,__ZNSt3__211__money_putIcE8__formatEPcRS2_S3_jPKcS5_RKNS_5ctypeIcEEbRKNS_10money_base7patternEccRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEESL_SL_i,b24,__ZNSt3__211__money_putIwE8__formatEPwRS2_S3_jPKwS5_RKNS_5ctypeIwEEbRKNS_10money_base7patternEwwRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKNSE_IwNSF_IwEENSH_IwEEEESQ_i,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24,b24
,b24,b24,b24];
var FUNCTION_TABLE_vi = [b25,b25,__ZN4mjin3log6LoggerD2Ev,__ZN4mjin3log6LoggerD0Ev,b25,__ZN3osg13NotifyHandlerD2Ev,__ZN3osg13NotifyHandlerD0Ev,b25,b25,__ZN9osgViewer14GraphicsWindowD2Ev,__ZN9osgViewer14GraphicsWindowD0Ev,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,__ZN3osg6Object19computeDataVarianceEv,b25,b25,b25,b25,b25,__ZN3osg15GraphicsContext13runOperationsEv,b25,__ZN3osg15GraphicsContext5clearEv,b25,b25,__ZN9osgViewer14GraphicsWindow19closeImplementationEv,b25,b25,b25,b25,__ZN9osgViewer14GraphicsWindow25swapBuffersImplementationEv,b25,b25,b25,b25,b25
,b25,__ZN9osgViewer14GraphicsWindow9grabFocusEv,__ZN9osgViewer14GraphicsWindow26grabFocusIfPointerInWindowEv,__ZN9osgViewer14GraphicsWindow11raiseWindowEv,b25,b25,b25,b25,b25,b25,__ZN9osgViewer14GraphicsWindow13requestRedrawEv,b25,b25,__ZThn132_N9osgViewer14GraphicsWindowD1Ev,__ZThn132_N9osgViewer14GraphicsWindowD0Ev,b25,__ZThn132_N9osgViewer14GraphicsWindow13requestRedrawEv,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZN9osgViewer4ViewD1Ev,__ZN9osgViewer4ViewD0Ev,b25
,b25,b25,b25,b25,b25,__ZN9osgViewer4View13requestRedrawEv,b25,b25,b25,b25,__ZThn36_N9osgViewer4ViewD1Ev,__ZThn36_N9osgViewer4ViewD0Ev,b25,__ZThn36_N9osgViewer4View13requestRedrawEv,b25,b25,b25,b25,__ZTv0_n16_N9osgViewer4ViewD1Ev,__ZTv0_n16_N9osgViewer4ViewD0Ev,b25,b25,b25,b25,b25,__ZN37CollectedCoordinateSystemNodesVisitorD1Ev,__ZN37CollectedCoordinateSystemNodesVisitorD0Ev,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZN3osg11NodeVisitor5resetEv,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZTv0_n16_N37CollectedCoordinateSystemNodesVisitorD1Ev,__ZTv0_n16_N37CollectedCoordinateSystemNodesVisitorD0Ev,b25,b25,b25,b25,b25,b25,b25,b25,__ZN9osgViewer4View19StereoSlaveCallbackD1Ev,__ZN9osgViewer4View19StereoSlaveCallbackD0Ev,__ZTv0_n16_N9osgViewer4View19StereoSlaveCallbackD1Ev,__ZTv0_n16_N9osgViewer4View19StereoSlaveCallbackD0Ev,__ZN5osgGA16GUIActionAdapterD2Ev
,__ZN5osgGA16GUIActionAdapterD0Ev,__ZN29ViewerCoordinateFrameCallbackD2Ev,__ZN29ViewerCoordinateFrameCallbackD0Ev,b25,b25,b25,b25,b25,b25,__ZN9osgViewer6Viewer7realizeEv,__ZN9osgViewer10ViewerBase17configureAffinityEv,b25,b25,b25,__ZN9osgViewer10ViewerBase14setUpThreadingEv,__ZN9osgViewer10ViewerBase13stopThreadingEv,__ZN9osgViewer10ViewerBase14startThreadingEv,b25,b25,b25,b25,b25,__ZN9osgViewer6Viewer14eventTraversalEv,__ZN9osgViewer6Viewer15updateTraversalEv,__ZN9osgViewer10ViewerBase19renderingTraversalsEv,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,__ZN9osgViewer6Viewer10viewerInitEv,__ZN9osgViewer6ViewerD1Ev,__ZN9osgViewer6ViewerD0Ev,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZThn104_N9osgViewer6ViewerD1Ev,__ZThn104_N9osgViewer6ViewerD0Ev,b25,b25,__ZThn140_N9osgViewer6ViewerD1Ev,__ZThn140_N9osgViewer6ViewerD0Ev,__ZTv0_n16_N9osgViewer6ViewerD1Ev
,__ZTv0_n16_N9osgViewer6ViewerD0Ev,b25,b25,b25,b25,b25,b25,__ZN9osgViewer10ViewerBaseD1Ev,__ZN9osgViewer10ViewerBaseD0Ev,__ZTv0_n16_N9osgViewer10ViewerBaseD1Ev,__ZTv0_n16_N9osgViewer10ViewerBaseD0Ev,b25,b25,b25,b25,b25,b25,b25,__ZN3osg4ViewD1Ev,__ZN3osg4ViewD0Ev,b25,__ZTv0_n16_N3osg4ViewD1Ev,__ZTv0_n16_N3osg4ViewD0Ev,b25,b25,b25,b25,b25,__ZN9osgViewer22GraphicsWindowEmbeddedD0Ev,b25
,b25,b25,b25,b25,b25,__ZN9osgViewer22GraphicsWindowEmbedded19closeImplementationEv,b25,b25,__ZN9osgViewer22GraphicsWindowEmbedded25swapBuffersImplementationEv,__ZN9osgViewer22GraphicsWindowEmbedded9grabFocusEv,__ZN9osgViewer22GraphicsWindowEmbedded26grabFocusIfPointerInWindowEv,__ZN9osgViewer22GraphicsWindowEmbedded11raiseWindowEv,__ZThn132_N9osgViewer22GraphicsWindowEmbeddedD1Ev,__ZThn132_N9osgViewer22GraphicsWindowEmbeddedD0Ev,__ZN5osgGA11PointerDataD2Ev,__ZN5osgGA11PointerDataD0Ev,__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEED1Ev,__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEED0Ev,__ZTv0_n12_NSt3__213basic_istreamIcNS_11char_traitsIcEEED1Ev,__ZTv0_n12_NSt3__213basic_istreamIcNS_11char_traitsIcEEED0Ev,__ZNSt3__219basic_istringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev,__ZNSt3__219basic_istringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED0Ev,__ZTv0_n12_NSt3__219basic_istringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev,__ZTv0_n12_NSt3__219basic_istringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED0Ev,__ZNSt3__215basic_stringbufIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev,__ZNSt3__215basic_stringbufIcNS_11char_traitsIcEENS_9allocatorIcEEED0Ev,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,__ZN5osgDB7OptionsD2Ev,__ZN5osgDB7OptionsD0Ev,b25,b25,b25,b25,b25,__ZN3osg13TemplateArrayINS_5Vec3fELNS_5Array4TypeE28ELi3ELi5126EED2Ev,__ZN3osg13TemplateArrayINS_5Vec3fELNS_5Array4TypeE28ELi3ELi5126EED0Ev,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZN3osg13TemplateArrayINS_5Vec3fELNS_5Array4TypeE28ELi3ELi5126EE4trimEv,__ZThn72_N3osg13TemplateArrayINS_5Vec3fELNS_5Array4TypeE28ELi3ELi5126EED1Ev,__ZThn72_N3osg13TemplateArrayINS_5Vec3fELNS_5Array4TypeE28ELi3ELi5126EED0Ev,__ZN3osg13TemplateArrayINS_5Vec2fELNS_5Array4TypeE27ELi2ELi5126EED2Ev,__ZN3osg13TemplateArrayINS_5Vec2fELNS_5Array4TypeE27ELi2ELi5126EED0Ev,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,__ZN3osg13TemplateArrayINS_5Vec2fELNS_5Array4TypeE27ELi2ELi5126EE4trimEv,__ZThn72_N3osg13TemplateArrayINS_5Vec2fELNS_5Array4TypeE27ELi2ELi5126EED1Ev,__ZThn72_N3osg13TemplateArrayINS_5Vec2fELNS_5Array4TypeE27ELi2ELi5126EED0Ev,__ZN3osg13TemplateArrayINS_5Vec4fELNS_5Array4TypeE29ELi4ELi5126EED2Ev,__ZN3osg13TemplateArrayINS_5Vec4fELNS_5Array4TypeE29ELi4ELi5126EED0Ev,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZN3osg13TemplateArrayINS_5Vec4fELNS_5Array4TypeE29ELi4ELi5126EE4trimEv,__ZThn72_N3osg13TemplateArrayINS_5Vec4fELNS_5Array4TypeE29ELi4ELi5126EED1Ev,__ZThn72_N3osg13TemplateArrayINS_5Vec4fELNS_5Array4TypeE29ELi4ELi5126EED0Ev,__ZN3osg11MixinVectorINS_5Vec4fEED2Ev,__ZN3osg11MixinVectorINS_5Vec4fEED0Ev,__ZN3osg11MixinVectorINS_5Vec2fEED2Ev,__ZN3osg11MixinVectorINS_5Vec2fEED0Ev,__ZN3osg11MixinVectorINS_5Vec3fEED2Ev,__ZN3osg11MixinVectorINS_5Vec3fEED0Ev,__ZN3osg6ObjectD2Ev
,__ZN9osgViewer12SingleWindowD0Ev,b25,b25,b25,b25,b25,b25,b25,__ZN9osgViewer12SingleScreenD0Ev,b25,b25,b25,b25,b25,b25,__ZN9osgViewer16AcrossAllScreensD0Ev,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,__ZN9osgViewer15KeystoneHandlerD1Ev,__ZN9osgViewer15KeystoneHandlerD0Ev,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZThn4_N9osgViewer15KeystoneHandlerD1Ev,__ZThn4_N9osgViewer15KeystoneHandlerD0Ev,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZTv0_n112_N9osgViewer15KeystoneHandlerD1Ev,__ZTv0_n112_N9osgViewer15KeystoneHandlerD0Ev,__ZTv0_n16_N9osgViewer15KeystoneHandlerD1Ev,__ZTv0_n16_N9osgViewer15KeystoneHandlerD0Ev,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZN3osg8CallbackD1Ev,__ZN3osg8CallbackD0Ev,__ZTv0_n16_N3osg8CallbackD1Ev,__ZTv0_n16_N3osg8CallbackD0Ev,b25,b25,b25,b25,b25,__ZN5osgGA15GUIEventHandlerD1Ev,__ZN5osgGA15GUIEventHandlerD0Ev,b25,__ZThn4_N5osgGA15GUIEventHandlerD1Ev,__ZThn4_N5osgGA15GUIEventHandlerD0Ev,__ZTv0_n112_N5osgGA15GUIEventHandlerD1Ev,__ZTv0_n112_N5osgGA15GUIEventHandlerD0Ev,__ZTv0_n16_N5osgGA15GUIEventHandlerD1Ev,__ZTv0_n16_N5osgGA15GUIEventHandlerD0Ev
,b25,b25,b25,b25,b25,__ZN5osgGA12EventHandlerD1Ev,__ZN5osgGA12EventHandlerD0Ev,b25,b25,b25,b25,b25,b25,__ZThn4_N5osgGA12EventHandlerD1Ev,__ZThn4_N5osgGA12EventHandlerD0Ev,b25,b25,b25,b25,b25,__ZTv0_n112_N5osgGA12EventHandlerD1Ev,__ZTv0_n112_N5osgGA12EventHandlerD0Ev,__ZTv0_n16_N5osgGA12EventHandlerD1Ev,__ZTv0_n16_N5osgGA12EventHandlerD0Ev,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,__ZN3osg12NodeCallbackD1Ev,__ZN3osg12NodeCallbackD0Ev,b25,b25,b25,b25,b25,b25,b25,b25,__ZTv0_n112_N3osg12NodeCallbackD1Ev,__ZTv0_n112_N3osg12NodeCallbackD0Ev,__ZTv0_n16_N3osg12NodeCallbackD1Ev,__ZTv0_n16_N3osg12NodeCallbackD0Ev,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,__ZN3osg21DrawableEventCallbackD1Ev,__ZN3osg21DrawableEventCallbackD0Ev,b25,b25,b25,b25,b25,b25,b25,b25,__ZTv0_n112_N3osg21DrawableEventCallbackD1Ev,__ZTv0_n112_N3osg21DrawableEventCallbackD0Ev,__ZTv0_n16_N3osg21DrawableEventCallbackD1Ev,__ZTv0_n16_N3osg21DrawableEventCallbackD0Ev,b25,b25,b25,b25,b25,__ZN9osgViewer8KeystoneD0Ev,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZN22KeystoneUpdateCallbackD1Ev,__ZN22KeystoneUpdateCallbackD0Ev,b25,b25,b25,b25,b25,b25,b25,b25,__ZTv0_n112_N22KeystoneUpdateCallbackD1Ev,__ZTv0_n112_N22KeystoneUpdateCallbackD0Ev,__ZTv0_n16_N22KeystoneUpdateCallbackD1Ev,__ZTv0_n16_N22KeystoneUpdateCallbackD0Ev,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,__ZN20KeystoneCullCallbackD1Ev,__ZN20KeystoneCullCallbackD0Ev,b25,b25,b25,b25,b25,b25,b25,__ZTv0_n112_N20KeystoneCullCallbackD1Ev,__ZTv0_n112_N20KeystoneCullCallbackD0Ev,__ZTv0_n16_N20KeystoneCullCallbackD1Ev,__ZTv0_n16_N20KeystoneCullCallbackD0Ev,b25,b25,b25,b25,b25,__ZN3osg11ValueObjectD0Ev,b25,b25,b25
,b25,b25,b25,b25,__ZN3osg19TemplateValueObjectINSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEED2Ev,__ZN3osg19TemplateValueObjectINSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEED0Ev,b25,b25,b25,b25,b25,b25,b25,__ZN15EXTQuerySupportD2Ev,__ZN15EXTQuerySupportD0Ev,b25,b25,b25,b25,__ZN9osgViewer8Renderer7releaseEv,b25,__ZN9osgViewer8RendererD1Ev,__ZN9osgViewer8RendererD0Ev,b25,__ZN9osgViewer8Renderer4cullEv,__ZN9osgViewer8Renderer4drawEv,__ZN9osgViewer8Renderer9cull_drawEv,__ZN9osgViewer8Renderer7compileEv,__ZN9osgViewer8Renderer5resetEv,b25
,__ZTv0_n16_N9osgViewer8RendererD1Ev,__ZTv0_n16_N9osgViewer8RendererD0Ev,__ZN3osg9Operation7releaseEv,b25,__ZN3osg17GraphicsOperationD1Ev,__ZN3osg17GraphicsOperationD0Ev,__ZTv0_n16_N3osg17GraphicsOperationD1Ev,__ZTv0_n16_N3osg17GraphicsOperationD0Ev,__ZN3osg9OperationD1Ev,__ZN3osg9OperationD0Ev,__ZTv0_n16_N3osg9OperationD1Ev,__ZTv0_n16_N3osg9OperationD0Ev,__ZN15ARBQuerySupportD2Ev,__ZN15ARBQuerySupportD0Ev,b25,b25,b25,b25,__ZN11OpenThreads5MutexD2Ev,__ZN11OpenThreads14ReentrantMutexD0Ev,b25,b25,b25,__ZN3osg10ReferencedD2Ev,__ZN7osgUtil11CullVisitor10IdentifierD0Ev,__ZN9osgViewer5SceneD2Ev,__ZN9osgViewer5SceneD0Ev,b25,b25,b25
,b25,__ZN5osgGA10EventQueueD2Ev,__ZN5osgGA10EventQueueD0Ev,__ZN5osgGA12EventVisitorD1Ev,__ZN5osgGA12EventVisitorD0Ev,b25,b25,b25,b25,__ZN5osgGA12EventVisitor5resetEv,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZTv0_n16_N5osgGA12EventVisitorD1Ev,__ZTv0_n16_N5osgGA12EventVisitorD0Ev,b25,b25,__ZN3osg11NodeVisitorD1Ev,__ZN3osg11NodeVisitorD0Ev,b25,b25
,b25,__ZTv0_n16_N3osg11NodeVisitorD1Ev,__ZTv0_n16_N3osg11NodeVisitorD0Ev,b25,b25,__ZN5osgGA15GUIEventAdapterD2Ev,__ZN5osgGA15GUIEventAdapterD0Ev,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZN5osgGA20TrackballManipulatorD1Ev,__ZN5osgGA20TrackballManipulatorD0Ev,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZN5osgGA19StandardManipulator15finishAnimationEv,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZN5osgGA16OrbitManipulator18allocAnimationDataEv,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,__ZThn4_N5osgGA20TrackballManipulatorD1Ev,__ZThn4_N5osgGA20TrackballManipulatorD0Ev,b25,b25,b25,b25,b25,__ZTv0_n112_N5osgGA20TrackballManipulatorD1Ev,__ZTv0_n112_N5osgGA20TrackballManipulatorD0Ev,__ZTv0_n16_N5osgGA20TrackballManipulatorD1Ev,__ZTv0_n16_N5osgGA20TrackballManipulatorD0Ev,b25,b25,b25,b25,b25,__ZN5osgGA16OrbitManipulator18OrbitAnimationDataD0Ev,__ZN5osgGA5EventD0Ev,b25,b25,b25,b25,b25,b25,b25,b25,__ZN5osgGA17CameraManipulatorD1Ev,__ZN5osgGA17CameraManipulatorD0Ev,b25,b25
,b25,b25,b25,b25,__ZN5osgGA17CameraManipulator15finishAnimationEv,b25,b25,b25,b25,__ZThn4_N5osgGA17CameraManipulatorD1Ev,__ZThn4_N5osgGA17CameraManipulatorD0Ev,b25,__ZTv0_n112_N5osgGA17CameraManipulatorD1Ev,__ZTv0_n112_N5osgGA17CameraManipulatorD0Ev,__ZTv0_n16_N5osgGA17CameraManipulatorD1Ev,__ZTv0_n16_N5osgGA17CameraManipulatorD0Ev,b25,b25,b25,b25,b25,b25,__ZN5osgGA16OrbitManipulatorD1Ev,__ZN5osgGA16OrbitManipulatorD0Ev,b25,b25,b25,b25,b25,__ZThn4_N5osgGA16OrbitManipulatorD1Ev
,__ZThn4_N5osgGA16OrbitManipulatorD0Ev,b25,b25,b25,b25,b25,__ZTv0_n112_N5osgGA16OrbitManipulatorD1Ev,__ZTv0_n112_N5osgGA16OrbitManipulatorD0Ev,__ZTv0_n16_N5osgGA16OrbitManipulatorD1Ev,__ZTv0_n16_N5osgGA16OrbitManipulatorD0Ev,b25,b25,b25,b25,b25,b25,__ZN5osgGA19StandardManipulatorD1Ev,__ZN5osgGA19StandardManipulatorD0Ev,b25,b25,b25,b25,b25,b25,b25,__ZN5osgGA19StandardManipulator18allocAnimationDataEv,b25,__ZThn4_N5osgGA19StandardManipulatorD1Ev,__ZThn4_N5osgGA19StandardManipulatorD0Ev,b25
,__ZTv0_n112_N5osgGA19StandardManipulatorD1Ev,__ZTv0_n112_N5osgGA19StandardManipulatorD0Ev,__ZTv0_n16_N5osgGA19StandardManipulatorD1Ev,__ZTv0_n16_N5osgGA19StandardManipulatorD0Ev,b25,__ZN5osgGA19StandardManipulator13AnimationDataD0Ev,__ZN7osgUtil16GLObjectsVisitorD1Ev,__ZN7osgUtil16GLObjectsVisitorD0Ev,b25,b25,__ZN7osgUtil16GLObjectsVisitor5resetEv,b25,b25,__ZTv0_n16_N7osgUtil16GLObjectsVisitorD1Ev,__ZTv0_n16_N7osgUtil16GLObjectsVisitorD0Ev,b25,b25,__ZN7osgUtil19IntersectionVisitorD1Ev,__ZN7osgUtil19IntersectionVisitorD0Ev,b25,b25,b25,b25,__ZN7osgUtil19IntersectionVisitor5resetEv,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,__ZTv0_n16_N7osgUtil19IntersectionVisitorD1Ev,__ZTv0_n16_N7osgUtil19IntersectionVisitorD0Ev,b25,b25,__ZN3osg10RefMatrixdD2Ev,__ZN3osg10RefMatrixdD0Ev,b25,b25,b25,b25,b25,__ZN7osgUtil14StateToCompileD1Ev,__ZN7osgUtil14StateToCompileD0Ev,b25,b25,b25,b25,__ZTv0_n16_N7osgUtil14StateToCompileD1Ev,__ZTv0_n16_N7osgUtil14StateToCompileD0Ev,__ZN7osgUtil27IncrementalCompileOperation17CompileDrawableOpD2Ev,__ZN7osgUtil27IncrementalCompileOperation17CompileDrawableOpD0Ev,b25,b25,__ZN7osgUtil27IncrementalCompileOperation16CompileTextureOpD2Ev
,__ZN7osgUtil27IncrementalCompileOperation16CompileTextureOpD0Ev,b25,b25,__ZN7osgUtil27IncrementalCompileOperation16CompileProgramOpD2Ev,__ZN7osgUtil27IncrementalCompileOperation16CompileProgramOpD0Ev,b25,b25,__ZN3osg11DummyObjectD0Ev,b25,b25,b25,b25,b25,__ZN7osgUtil27IncrementalCompileOperation10CompileSetD2Ev,__ZN7osgUtil27IncrementalCompileOperation10CompileSetD0Ev,__ZN7osgUtil22LineSegmentIntersectorD2Ev,__ZN7osgUtil22LineSegmentIntersectorD0Ev,b25,b25,__ZN7osgUtil22LineSegmentIntersector5leaveEv,b25,__ZN7osgUtil22LineSegmentIntersector5resetEv,b25,b25,__ZN27LineSegmentIntersectorUtils8SettingsD2Ev,__ZN27LineSegmentIntersectorUtils8SettingsD0Ev,__ZN3osg24TemplatePrimitiveFunctorIN27LineSegmentIntersectorUtils16IntersectFunctorINS_5Vec3dEdEEED2Ev,__ZN3osg24TemplatePrimitiveFunctorIN27LineSegmentIntersectorUtils16IntersectFunctorINS_5Vec3dEdEEED0Ev,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,__ZN3osg24TemplatePrimitiveFunctorIN27LineSegmentIntersectorUtils16IntersectFunctorINS_5Vec3fEfEEED2Ev,__ZN3osg24TemplatePrimitiveFunctorIN27LineSegmentIntersectorUtils16IntersectFunctorINS_5Vec3fEfEEED0Ev,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZN7osgUtil9Optimizer28StaticObjectDetectionVisitorD1Ev,__ZN7osgUtil9Optimizer28StaticObjectDetectionVisitorD0Ev,b25,b25,__ZTv0_n16_N7osgUtil9Optimizer28StaticObjectDetectionVisitorD1Ev,__ZTv0_n16_N7osgUtil9Optimizer28StaticObjectDetectionVisitorD0Ev,__ZNSt3__218basic_stringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev,__ZNSt3__218basic_stringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED0Ev,__ZThn8_NSt3__218basic_stringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev,__ZThn8_NSt3__218basic_stringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED0Ev
,__ZTv0_n12_NSt3__218basic_stringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev,__ZTv0_n12_NSt3__218basic_stringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED0Ev,__ZNSt3__214basic_iostreamIcNS_11char_traitsIcEEED1Ev,__ZNSt3__214basic_iostreamIcNS_11char_traitsIcEEED0Ev,__ZThn8_NSt3__214basic_iostreamIcNS_11char_traitsIcEEED1Ev,__ZThn8_NSt3__214basic_iostreamIcNS_11char_traitsIcEEED0Ev,__ZTv0_n12_NSt3__214basic_iostreamIcNS_11char_traitsIcEEED1Ev,__ZTv0_n12_NSt3__214basic_iostreamIcNS_11char_traitsIcEEED0Ev,__ZN7osgUtil20BaseOptimizerVisitorD1Ev,__ZN7osgUtil20BaseOptimizerVisitorD0Ev,__ZTv0_n16_N7osgUtil20BaseOptimizerVisitorD1Ev,__ZTv0_n16_N7osgUtil20BaseOptimizerVisitorD0Ev,__ZN7osgUtil14RayIntersectorD2Ev,__ZN7osgUtil14RayIntersectorD0Ev,b25,b25,__ZN7osgUtil14RayIntersector5leaveEv,b25,__ZN7osgUtil14RayIntersector5resetEv,b25,b25,b25,b25,__ZN7osgUtil9SceneViewD2Ev,__ZN7osgUtil9SceneViewD0Ev,b25,b25,b25,b25,b25
,__ZN7osgUtil9SceneView11setDefaultsEv,b25,b25,b25,b25,b25,b25,b25,__ZN7osgUtil9SceneView4initEv,__ZN7osgUtil9SceneView6updateEv,__ZN7osgUtil9SceneView4cullEv,__ZN7osgUtil9SceneView4drawEv,__ZN7osgUtil9SceneView19releaseAllGLObjectsEv,__ZN7osgUtil9SceneView24flushAllDeletedGLObjectsEv,b25,b25,__ZThn32_N7osgUtil9SceneViewD1Ev,__ZThn32_N7osgUtil9SceneViewD0Ev,__ZThn32_N7osgUtil9SceneView11setDefaultsEv,b25,b25,__ZN7osgUtil10StateGraphD2Ev,__ZN7osgUtil10StateGraphD0Ev,__ZN7osgUtil16ShaderGenVisitorD1Ev,__ZN7osgUtil16ShaderGenVisitorD0Ev,__ZN7osgUtil16ShaderGenVisitor5resetEv,b25,b25,__ZTv0_n16_N7osgUtil16ShaderGenVisitorD1Ev,__ZTv0_n16_N7osgUtil16ShaderGenVisitorD0Ev
,__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEED1Ev,__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEED0Ev,__ZTv0_n12_NSt3__213basic_ostreamIcNS_11char_traitsIcEEED1Ev,__ZTv0_n12_NSt3__213basic_ostreamIcNS_11char_traitsIcEEED0Ev,__ZNSt3__219basic_ostringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev,__ZNSt3__219basic_ostringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED0Ev,__ZTv0_n12_NSt3__219basic_ostringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev,__ZTv0_n12_NSt3__219basic_ostringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED0Ev,__ZN7osgUtil14ShaderGenCacheD2Ev,__ZN7osgUtil14ShaderGenCacheD0Ev,__ZN3osg5StateD2Ev,__ZN7osgUtil7StateExD0Ev,__ZN3osg5State14frameCompletedEv,__ZN7osgUtil10StatisticsD2Ev,__ZN7osgUtil10StatisticsD0Ev,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,__ZN7osgUtil10Statistics3endEv,__ZN7osgUtil12StatsVisitorD1Ev,__ZN7osgUtil12StatsVisitorD0Ev,b25,b25,__ZN7osgUtil12StatsVisitor5resetEv,b25,b25,b25,b25,b25,b25,b25,b25,__ZN7osgUtil12StatsVisitor12totalUpStatsEv,b25,__ZTv0_n16_N7osgUtil12StatsVisitorD1Ev,__ZTv0_n16_N7osgUtil12StatsVisitorD0Ev,b25,b25,__ZN7osgUtil13UpdateVisitorD1Ev,__ZN7osgUtil13UpdateVisitorD0Ev,b25,b25,b25,b25,__ZN7osgUtil13UpdateVisitor5resetEv,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZTv0_n16_N7osgUtil13UpdateVisitorD1Ev,__ZTv0_n16_N7osgUtil13UpdateVisitorD0Ev,b25,b25,__ZN7osgUtil11CullVisitorD1Ev,__ZN7osgUtil11CullVisitorD0Ev,b25,b25,b25,b25,b25,b25,__ZN7osgUtil11CullVisitor5resetEv,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZN7osgUtil11CullVisitor19popProjectionMatrixEv,b25,b25,__ZThn56_N7osgUtil11CullVisitorD1Ev,__ZThn56_N7osgUtil11CullVisitorD0Ev,__ZN3osg12CullSettings11setDefaultsEv,b25,b25,__ZTv0_n16_N7osgUtil11CullVisitorD1Ev,__ZTv0_n16_N7osgUtil11CullVisitorD0Ev,b25,b25,__ZN3osg16PrimitiveFunctorD2Ev,__ZN3osg16PrimitiveFunctorD0Ev,__ZN3osg24TemplatePrimitiveFunctorI21ComputeNearFarFunctorI17GreaterComparatorEED2Ev
,__ZN3osg24TemplatePrimitiveFunctorI21ComputeNearFarFunctorI17GreaterComparatorEED0Ev,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZN3osg24TemplatePrimitiveFunctorI21ComputeNearFarFunctorI14LessComparatorEED2Ev,__ZN3osg24TemplatePrimitiveFunctorI21ComputeNearFarFunctorI14LessComparatorEED0Ev,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZN7osgUtil16RenderStageCacheD2Ev,__ZN7osgUtil16RenderStageCacheD0Ev,b25,b25,b25,b25,b25
,b25,b25,b25,__ZThn32_N7osgUtil16RenderStageCacheD1Ev,__ZThn32_N7osgUtil16RenderStageCacheD0Ev,b25,__ZN3osg10BufferDataD2Ev,__ZN3osg12DrawElementsD0Ev,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZNK3osg12PrimitiveSet12computeRangeEv,__ZN3osg11MixinVectorIjED2Ev,__ZN3osg11MixinVectorIjED0Ev,__ZN3osg11MixinVectorIdED2Ev,__ZN3osg11MixinVectorIdED0Ev,__ZN3osg13TemplateArrayIdLNS_5Array4TypeE8ELi1ELi5130EED2Ev,__ZN3osg13TemplateArrayIdLNS_5Array4TypeE8ELi1ELi5130EED0Ev,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZN3osg13TemplateArrayIdLNS_5Array4TypeE8ELi1ELi5130EE4trimEv,__ZThn72_N3osg13TemplateArrayIdLNS_5Array4TypeE8ELi1ELi5130EED1Ev,__ZThn72_N3osg13TemplateArrayIdLNS_5Array4TypeE8ELi1ELi5130EED0Ev,__ZN3osg11MixinVectorIfED2Ev,__ZN3osg11MixinVectorIfED0Ev,__ZN3osg13TemplateArrayIfLNS_5Array4TypeE7ELi1ELi5126EED2Ev,__ZN3osg13TemplateArrayIfLNS_5Array4TypeE7ELi1ELi5126EED0Ev,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,__ZN3osg13TemplateArrayIfLNS_5Array4TypeE7ELi1ELi5126EE4trimEv,__ZThn72_N3osg13TemplateArrayIfLNS_5Array4TypeE7ELi1ELi5126EED1Ev,__ZThn72_N3osg13TemplateArrayIfLNS_5Array4TypeE7ELi1ELi5126EED0Ev,__ZN3osg10IndexArrayD0Ev,b25,__ZN3osg5Array4trimEv,__ZN3osg18TemplateIndexArrayIjLNS_5Array4TypeE6ELi1ELi5125EED2Ev,__ZN3osg18TemplateIndexArrayIjLNS_5Array4TypeE6ELi1ELi5125EED0Ev,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZN3osg18TemplateIndexArrayIjLNS_5Array4TypeE6ELi1ELi5125EE4trimEv,b25,__ZThn72_N3osg18TemplateIndexArrayIjLNS_5Array4TypeE6ELi1ELi5125EED1Ev,__ZThn72_N3osg18TemplateIndexArrayIjLNS_5Array4TypeE6ELi1ELi5125EED0Ev,__ZN3osg11MixinVectorItED2Ev
,__ZN3osg11MixinVectorItED0Ev,__ZN3osg11MixinVectorIhED2Ev,__ZN3osg11MixinVectorIhED0Ev,__ZN3osg11MixinVectorIiED2Ev,__ZN3osg11MixinVectorIiED0Ev,__ZN3osg18TemplateIndexArrayIiLNS_5Array4TypeE3ELi1ELi5124EED2Ev,__ZN3osg18TemplateIndexArrayIiLNS_5Array4TypeE3ELi1ELi5124EED0Ev,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZN3osg18TemplateIndexArrayIiLNS_5Array4TypeE3ELi1ELi5124EE4trimEv,b25,__ZThn72_N3osg18TemplateIndexArrayIiLNS_5Array4TypeE3ELi1ELi5124EED1Ev,__ZThn72_N3osg18TemplateIndexArrayIiLNS_5Array4TypeE3ELi1ELi5124EED0Ev,__ZN7osgUtil24PositionalStateContainerD2Ev,__ZN7osgUtil24PositionalStateContainerD0Ev,b25,b25,b25
,b25,b25,__ZN7osgUtil24PositionalStateContainer5resetEv,b25,b25,b25,__ZN7osgUtil9RenderBinD2Ev,__ZN7osgUtil9RenderBinD0Ev,b25,b25,b25,b25,b25,b25,__ZN7osgUtil9RenderBin5resetEv,__ZN7osgUtil9RenderBin4sortEv,__ZN7osgUtil9RenderBin18sortImplementationEv,__ZN7osgUtil9RenderBin11sortByStateEv,__ZN7osgUtil9RenderBin26sortByStateThenFrontToBackEv,__ZN7osgUtil9RenderBin15sortFrontToBackEv,__ZN7osgUtil9RenderBin15sortBackToFrontEv,__ZN7osgUtil9RenderBin18sortTraversalOrderEv,b25,b25,b25,__ZN22RenderBinPrototypeListD2Ev,__ZN22RenderBinPrototypeListD0Ev,__ZN7osgUtil10RenderLeafD2Ev,__ZN7osgUtil10RenderLeafD0Ev,b25
,__ZN7osgUtil11RenderStageD2Ev,__ZN7osgUtil11RenderStageD0Ev,b25,b25,b25,b25,b25,__ZN7osgUtil11RenderStage5resetEv,__ZN7osgUtil11RenderStage4sortEv,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZN18DrawInnerOperationD1Ev,__ZN18DrawInnerOperationD0Ev,__ZTv0_n16_N18DrawInnerOperationD1Ev,__ZTv0_n16_N18DrawInnerOperationD0Ev,__ZN3osg16ApplicationUsageD2Ev,__ZN3osg16ApplicationUsageD0Ev,__ZN3osg5ArrayD0Ev,__ZN3osg14GLBufferObjectD2Ev,__ZN3osg14GLBufferObjectD0Ev,__ZN3osg17GLBufferObjectSetD2Ev,__ZN3osg17GLBufferObjectSetD0Ev,__ZN3osg21GLBufferObjectManagerD2Ev
,__ZN3osg21GLBufferObjectManagerD0Ev,b25,__ZN3osg21GLBufferObjectManager10resetStatsEv,b25,b25,b25,__ZN3osg21GLBufferObjectManager24flushAllDeletedGLObjectsEv,__ZN3osg21GLBufferObjectManager18deleteAllGLObjectsEv,__ZN3osg21GLBufferObjectManager19discardAllGLObjectsEv,__ZN3osg12BufferObjectD2Ev,__ZN3osg12BufferObjectD0Ev,b25,b25,b25,b25,b25,__ZN3osg10BufferDataD0Ev,b25,b25,b25,__ZN3osg18VertexBufferObjectD0Ev,b25,b25,b25,b25,b25,__ZN3osg19ElementBufferObjectD0Ev,b25,b25,b25
,b25,b25,__ZN3osg17PixelBufferObjectD0Ev,b25,b25,b25,b25,b25,b25,__ZN3osg6CameraD2Ev,__ZN3osg6CameraD0Ev,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZThn144_N3osg6CameraD1Ev,__ZThn144_N3osg6CameraD0Ev
,b25,__ZN3osg23CollectOccludersVisitorD1Ev,__ZN3osg23CollectOccludersVisitorD0Ev,b25,b25,b25,__ZN3osg23CollectOccludersVisitor5resetEv,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZThn56_N3osg23CollectOccludersVisitorD1Ev,__ZThn56_N3osg23CollectOccludersVisitorD0Ev,__ZTv0_n16_N3osg23CollectOccludersVisitorD1Ev,__ZTv0_n16_N3osg23CollectOccludersVisitorD0Ev,b25,b25,b25,__ZN3osg9ColorMaskD2Ev,__ZN3osg9ColorMaskD0Ev,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZN3osg14StateAttributeD2Ev,__ZN3osg14StateAttributeD0Ev,b25,b25,b25,b25,__ZN3osg20ComputeBoundsVisitorD1Ev,__ZN3osg20ComputeBoundsVisitorD0Ev,b25,b25,__ZN3osg20ComputeBoundsVisitor5resetEv,b25,b25,__ZTv0_n16_N3osg20ComputeBoundsVisitorD1Ev,__ZTv0_n16_N3osg20ComputeBoundsVisitorD0Ev,b25
,b25,__ZN3osg11ContextDataD2Ev,__ZN3osg11ContextDataD0Ev,b25,__ZN3osg11ContextData10resetStatsEv,b25,b25,b25,__ZN3osg11ContextData24flushAllDeletedGLObjectsEv,__ZN3osg11ContextData18deleteAllGLObjectsEv,__ZN3osg11ContextData19discardAllGLObjectsEv,__ZN3osg6CopyOpD2Ev,__ZN3osg6CopyOpD0Ev,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZN3osg10CullingSetD2Ev,__ZN3osg10CullingSetD0Ev
,__ZN3osg12CullSettingsD2Ev,__ZN3osg12CullSettingsD0Ev,__ZN3osg9CullStackD2Ev,__ZN3osg9CullStackD0Ev,__ZN3osg15DisplaySettingsD2Ev,__ZN3osg15DisplaySettingsD0Ev,b25,b25,b25,b25,b25,__ZN3osg8DrawableD2Ev,__ZN3osg8DrawableD0Ev,b25,b25,b25,b25,b25,b25,b25,__ZN3osg8Drawable19computeDataVarianceEv,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,__ZN3osg8Drawable16dirtyDisplayListEv,__ZN3osg8Drawable14dirtyGLObjectsEv,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZN12ComputeBoundD0Ev,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZN12ComputeBound3endEv,__ZN18DisplayListManagerD2Ev,__ZN18DisplayListManagerD0Ev,b25,__ZN3osg21GraphicsObjectManager10resetStatsEv,b25,b25,b25,__ZN18DisplayListManager24flushAllDeletedGLObjectsEv,__ZN18DisplayListManager18deleteAllGLObjectsEv,__ZN18DisplayListManager19discardAllGLObjectsEv,__ZN3osg15GLObjectManagerD2Ev,__ZN3osg21GLRenderBufferManagerD0Ev,b25,__ZN3osg15GLObjectManager24flushAllDeletedGLObjectsEv,__ZN3osg15GLObjectManager18deleteAllGLObjectsEv,__ZN3osg15GLObjectManager19discardAllGLObjectsEv,b25
,b25,b25,__ZN3osg26GLFrameBufferObjectManagerD0Ev,b25,__ZN3osg12RenderBufferD2Ev,__ZN3osg12RenderBufferD0Ev,b25,b25,b25,b25,b25,b25,b25,__ZN3osg17FrameBufferObjectD2Ev,__ZN3osg17FrameBufferObjectD0Ev,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZN3osg10FrameStampD2Ev,__ZN3osg10FrameStampD0Ev,__ZN3osg5GeodeD2Ev,__ZN3osg5GeodeD0Ev,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZN3osg8GeometryD2Ev,__ZN3osg8GeometryD0Ev,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZN3osg8Geometry14dirtyGLObjectsEv,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZN3osg17ConstArrayVisitorD2Ev,__ZN3osg33ConstAttributeFunctorArrayVisitorD0Ev,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZN3osg12ArrayVisitorD2Ev,__ZN3osg28AttributeFunctorArrayVisitorD0Ev,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZN3osg12GLExtensionsD0Ev
,__ZN3osg14GraphicsObjectD2Ev,__ZN3osg14GraphicsObjectD0Ev,__ZN3osg21GraphicsObjectManagerD2Ev,__ZN3osg21GraphicsObjectManagerD0Ev,__ZN3osg15GLObjectManagerD0Ev,__ZN3osg21GraphicsCostEstimatorD2Ev,__ZN3osg21GraphicsCostEstimatorD0Ev,__ZN3osg21GeometryCostEstimatorD0Ev,__ZN3osg20TextureCostEstimatorD0Ev,__ZN3osg20ProgramCostEstimatorD0Ev,__ZN3osg15GraphicsContext25WindowingSystemInterfacesD2Ev,__ZN3osg15GraphicsContext25WindowingSystemInterfacesD0Ev,__ZN3osg15GraphicsContextD2Ev,__ZN3osg15GraphicsContextD0Ev,b25,b25,b25,__ZN3osg23SyncSwapBuffersCallbackD0Ev,b25,__ZN3osg15GraphicsContext6TraitsD2Ev,__ZN3osg15GraphicsContext6TraitsD0Ev,__ZN3osg8RefBlockD1Ev,__ZN3osg8RefBlockD0Ev,__ZTv0_n16_N3osg8RefBlockD1Ev,__ZTv0_n16_N3osg8RefBlockD0Ev,__ZN3osg15OperationThreadD2Ev,__ZN3osg14GraphicsThreadD0Ev,__ZN3osg14GraphicsThread3runEv,b25,__ZThn12_N3osg14GraphicsThreadD1Ev
,__ZThn12_N3osg14GraphicsThreadD0Ev,b25,__ZThn12_N3osg14GraphicsThread3runEv,__ZN11OpenThreads6Thread13cancelCleanupEv,__ZN3osg22BlockAndFlushOperation7releaseEv,__ZN3osg22BlockAndFlushOperationD1Ev,__ZN3osg22BlockAndFlushOperationD0Ev,b25,__ZTv0_n16_N3osg22BlockAndFlushOperationD1Ev,__ZTv0_n16_N3osg22BlockAndFlushOperationD0Ev,__ZN3osg21EndOfDynamicDrawBlockD2Ev,__ZN3osg21EndOfDynamicDrawBlockD0Ev,b25,__ZN3osg20SwapBuffersOperationD1Ev,__ZN3osg20SwapBuffersOperationD0Ev,b25,__ZTv0_n16_N3osg20SwapBuffersOperationD1Ev,__ZTv0_n16_N3osg20SwapBuffersOperationD0Ev,__ZN3osg16BarrierOperation7releaseEv,b25,__ZN3osg16BarrierOperationD1Ev,__ZN3osg16BarrierOperationD0Ev,__ZThn20_N3osg16BarrierOperationD1Ev,__ZThn20_N3osg16BarrierOperationD0Ev,__ZN11OpenThreads7Barrier5resetEv,b25,__ZThn20_N3osg16BarrierOperation7releaseEv,b25,__ZTv0_n16_N3osg16BarrierOperationD1Ev,__ZTv0_n16_N3osg16BarrierOperationD0Ev
,__ZN3osg13RunOperationsD1Ev,__ZN3osg13RunOperationsD0Ev,b25,__ZTv0_n16_N3osg13RunOperationsD1Ev,__ZTv0_n16_N3osg13RunOperationsD0Ev,__ZN3osg5GroupD2Ev,__ZN3osg5GroupD0Ev,b25,b25,b25,b25,b25,b25,b25,__ZN3osg5ImageD2Ev,__ZN3osg5ImageD0Ev,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZN3osg5Image14UpdateCallbackD1Ev,__ZN3osg5Image14UpdateCallbackD0Ev,b25,b25,b25,b25,b25,b25,b25,b25,__ZTv0_n112_N3osg5Image14UpdateCallbackD1Ev,__ZTv0_n112_N3osg5Image14UpdateCallbackD0Ev
,__ZTv0_n16_N3osg5Image14UpdateCallbackD1Ev,__ZTv0_n16_N3osg5Image14UpdateCallbackD0Ev,b25,b25,b25,b25,b25,b25,__ZN3osg22StateAttributeCallbackD1Ev,__ZN3osg22StateAttributeCallbackD0Ev,__ZTv0_n112_N3osg22StateAttributeCallbackD1Ev,__ZTv0_n112_N3osg22StateAttributeCallbackD0Ev,__ZTv0_n16_N3osg22StateAttributeCallbackD1Ev,__ZTv0_n16_N3osg22StateAttributeCallbackD0Ev,__ZN3osg6KdTreeD2Ev,__ZN3osg6KdTreeD0Ev,b25,b25,b25,b25,b25,b25,b25,b25,__ZN3osg21PrimitiveIndexFunctorD2Ev,__ZN3osg29TemplatePrimitiveIndexFunctorI25PrimitiveIndicesCollectorED0Ev,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,__ZN3osg13KdTreeBuilderD1Ev,__ZN3osg13KdTreeBuilderD0Ev,b25,b25,b25,b25,__ZTv0_n16_N3osg13KdTreeBuilderD1Ev,__ZTv0_n16_N3osg13KdTreeBuilderD0Ev,b25,b25,b25,__ZN3osg4NodeD2Ev,__ZN3osg4NodeD0Ev,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZN3osg21StandardNotifyHandlerD0Ev,b25
,__ZN3osg10NullStreamD1Ev,__ZN3osg10NullStreamD0Ev,__ZTv0_n12_N3osg10NullStreamD1Ev,__ZTv0_n12_N3osg10NullStreamD0Ev,__ZN3osg12NotifyStreamD1Ev,__ZN3osg12NotifyStreamD0Ev,__ZTv0_n12_N3osg12NotifyStreamD1Ev,__ZTv0_n12_N3osg12NotifyStreamD0Ev,__ZN3osg18NotifyStreamBufferD2Ev,__ZN3osg18NotifyStreamBufferD0Ev,b25,__ZN3osg16NullStreamBufferD2Ev,__ZN3osg16NullStreamBufferD0Ev,b25,b25,b25,b25,b25,b25,__ZN3osg6ObjectD0Ev,__ZN3osg8ObserverD2Ev,__ZN3osg8ObserverD0Ev,b25,__ZN3osg11ObserverSetD2Ev,__ZN3osg11ObserverSetD0Ev,__ZN3osg14OperationQueueD2Ev,__ZN3osg14OperationQueueD0Ev,__ZN3osg15OperationThreadD0Ev,__ZN3osg15OperationThread3runEv,__ZThn12_N3osg15OperationThreadD1Ev
,__ZThn12_N3osg15OperationThreadD0Ev,__ZThn12_N3osg15OperationThread3runEv,__ZN3osg11PolygonModeD2Ev,__ZN3osg11PolygonModeD0Ev,b25,b25,b25,b25,b25,b25,b25,b25,__ZN3osg14PolygonStippleD2Ev,__ZN3osg14PolygonStippleD0Ev,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZN3osg17DrawElementsUByteD2Ev,__ZN3osg17DrawElementsUByteD0Ev,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZThn64_N3osg17DrawElementsUByteD1Ev,__ZThn64_N3osg17DrawElementsUByteD0Ev,__ZN3osg18DrawElementsUShortD2Ev,__ZN3osg18DrawElementsUShortD0Ev,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZThn64_N3osg18DrawElementsUShortD1Ev,__ZThn64_N3osg18DrawElementsUShortD0Ev,__ZN3osg16DrawElementsUIntD2Ev,__ZN3osg16DrawElementsUIntD0Ev,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,__ZThn64_N3osg16DrawElementsUIntD1Ev,__ZThn64_N3osg16DrawElementsUIntD0Ev,__ZN3osg10DrawArraysD0Ev,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZN3osg7ProgramD2Ev,__ZN3osg7ProgramD0Ev,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,__ZN3osg7Program14ProgramObjectsD2Ev,__ZN3osg7Program14ProgramObjectsD0Ev,__ZN3osg7Program17PerContextProgramD2Ev,__ZN3osg7Program17PerContextProgramD0Ev,b25,b25,b25,b25,__ZNK3osg7Program17PerContextProgram10useProgramEv,__ZN3osg7Program13ProgramBinaryD2Ev,__ZN3osg7Program13ProgramBinaryD0Ev,b25,b25,b25,b25,b25,__ZN16GLProgramManagerD0Ev,b25,__ZN3osg10ReferencedD0Ev,__ZN3osg6Shader13ShaderObjectsD2Ev,__ZN3osg6Shader13ShaderObjectsD0Ev,__ZN3osg6Shader16PerContextShaderD2Ev,__ZN3osg6Shader16PerContextShaderD0Ev,__ZN15GLShaderManagerD0Ev,b25,__ZN3osg6ShaderD2Ev,__ZN3osg6ShaderD0Ev
,b25,b25,b25,b25,b25,b25,b25,__ZN3osg25BuildShapeGeometryVisitorD2Ev,__ZN3osg25BuildShapeGeometryVisitorD0Ev,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZN3osg5ShapeD2Ev,__ZN3osg5ShapeD0Ev,b25,b25,b25,__ZN3osg6SphereD0Ev,b25,b25,b25,b25
,b25,b25,b25,__ZN3osg5StateD0Ev,b25,__ZN3osg8StateSetD2Ev,__ZN3osg8StateSetD0Ev,b25,b25,b25,b25,b25,b25,b25,__ZN3osg8StateSet19computeDataVarianceEv,b25,b25,__ZN3osg14StateAttribute9ModeUsageD2Ev,__ZN23SetAssociateModesHelperD0Ev,b25,b25,__ZN26RemoveAssociateModesHelperD0Ev,b25,b25,__ZN3osg5StatsD2Ev,__ZN3osg5StatsD0Ev,__ZN3osg7StencilD2Ev,__ZN3osg7StencilD0Ev,b25,b25
,b25,b25,b25,b25,b25,b25,b25,__ZN3osg6TexMatD2Ev,__ZN3osg6TexMatD0Ev,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZN3osg9Texture2DD2Ev,__ZN3osg9Texture2DD0Ev,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZNK3osg9Texture2D21computeInternalFormatEv,b25,__ZN3osg16TextureObjectSetD2Ev,__ZN3osg16TextureObjectSetD0Ev,__ZN3osg20TextureObjectManagerD2Ev,__ZN3osg20TextureObjectManagerD0Ev,b25,__ZN3osg20TextureObjectManager10resetStatsEv,b25,b25,b25,__ZN3osg20TextureObjectManager24flushAllDeletedGLObjectsEv,__ZN3osg20TextureObjectManager18deleteAllGLObjectsEv,__ZN3osg20TextureObjectManager19discardAllGLObjectsEv,__ZN3osg7TextureD2Ev,__ZN3osg7TextureD0Ev,b25,b25
,b25,b25,b25,b25,b25,__ZN3osg7Texture13TextureObjectD2Ev,__ZN3osg7Texture13TextureObjectD0Ev,__ZN3osg16TextureRectangleD2Ev,__ZN3osg16TextureRectangleD0Ev,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZNK3osg16TextureRectangle21computeInternalFormatEv,b25,__ZN3osg9TransformD2Ev,__ZN3osg9TransformD0Ev,b25
,b25,b25,b25,b25,b25,b25,b25,__ZN16TransformVisitorD1Ev,__ZN16TransformVisitorD0Ev,b25,__ZTv0_n16_N16TransformVisitorD1Ev,__ZTv0_n16_N16TransformVisitorD0Ev,__ZN3osg7UniformD2Ev,__ZN3osg7UniformD0Ev,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZN3osg24DefaultUserDataContainerD2Ev,__ZN3osg24DefaultUserDataContainerD0Ev,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZN3osg16VertexArrayStateD2Ev,__ZN3osg16VertexArrayStateD0Ev,__ZN25VertexAttribArrayDispatchD0Ev,b25,b25,b25,b25,b25
,b25,b25,__ZN23VertexArrayStateManagerD2Ev,__ZN23VertexArrayStateManagerD0Ev,b25,__ZN23VertexArrayStateManager24flushAllDeletedGLObjectsEv,__ZN23VertexArrayStateManager18deleteAllGLObjectsEv,__ZN23VertexArrayStateManager19discardAllGLObjectsEv,__ZN3osg4View5SlaveD2Ev,__ZN3osg4View5SlaveD0Ev,b25,__ZN3osg8ViewportD2Ev,__ZN3osg8ViewportD0Ev,b25,b25,b25,b25,b25,b25,b25,b25,__ZN3osg20AttributeDispatchersD2Ev,__ZN3osg20AttributeDispatchersD0Ev,__ZN3osg31TemplateTargetAttributeDispatchIjfED0Ev,b25,b25,__ZN3osg9BlendFuncD2Ev,__ZN3osg9BlendFuncD0Ev,b25,b25
,b25,b25,b25,b25,b25,b25,b25,__ZN3osg5LightD2Ev,__ZN3osg5LightD0Ev,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZN3osg14ShaderComposerD2Ev,__ZN3osg14ShaderComposerD0Ev,b25,b25,b25,b25,b25,b25,b25,b25,b25
,__ZN11OpenThreads6ThreadD2Ev,__ZN11OpenThreads6ThreadD0Ev,b25,__ZN11OpenThreads18PThreadPrivateDataD2Ev,__ZN11OpenThreads18PThreadPrivateDataD0Ev,__ZN11OpenThreads7BarrierD2Ev,__ZN11OpenThreads7BarrierD0Ev,__ZN11OpenThreads7Barrier7releaseEv,__ZN11OpenThreads25PThreadBarrierPrivateDataD2Ev,__ZN11OpenThreads25PThreadBarrierPrivateDataD0Ev,__ZN11OpenThreads9ConditionD2Ev,__ZN11OpenThreads9ConditionD0Ev,b25,b25,b25,b25,__ZN11OpenThreads27PThreadConditionPrivateDataD2Ev,__ZN11OpenThreads27PThreadConditionPrivateDataD0Ev,__ZN11OpenThreads5MutexD0Ev,__ZN11OpenThreads23PThreadMutexPrivateDataD2Ev,__ZN11OpenThreads23PThreadMutexPrivateDataD0Ev,__ZNSt3__217bad_function_callD2Ev,__ZNSt3__217bad_function_callD0Ev,b25,__ZNSt3__210__function6__baseIFvRKbEED2Ev,__ZNSt3__210__function6__baseIFvRKbEED0Ev,__ZNSt3__210__function6__funcIZN4mjin11application6memory11Coordinator14setupSelectionEvE3__0NS_9allocatorIS6_EEFvRKbEED2Ev,__ZNSt3__210__function6__funcIZN4mjin11application6memory11Coordinator14setupSelectionEvE3__0NS_9allocatorIS6_EEFvRKbEED0Ev,b25,b25
,__ZNSt3__210__function6__funcIZN4mjin11application6memory11Coordinator14setupSelectionEvE3__0NS_9allocatorIS6_EEFvRKbEE7destroyEv,__ZNSt3__210__function6__funcIZN4mjin11application6memory11Coordinator14setupSelectionEvE3__0NS_9allocatorIS6_EEFvRKbEE18destroy_deallocateEv,b25,b25,b25,__ZNSt3__210__function6__baseIFvvEED2Ev,__ZNSt3__210__function6__baseIFvvEED0Ev,__ZNSt3__210__function6__funcIZN4mjin11application6memory4Game18matchSelectedItemsEvE3__1NS_9allocatorIS6_EEFvvEED2Ev,__ZNSt3__210__function6__funcIZN4mjin11application6memory4Game18matchSelectedItemsEvE3__1NS_9allocatorIS6_EEFvvEED0Ev,b25,b25,__ZNSt3__210__function6__funcIZN4mjin11application6memory4Game18matchSelectedItemsEvE3__1NS_9allocatorIS6_EEFvvEE7destroyEv,__ZNSt3__210__function6__funcIZN4mjin11application6memory4Game18matchSelectedItemsEvE3__1NS_9allocatorIS6_EEFvvEE18destroy_deallocateEv,__ZNSt3__210__function6__funcIZN4mjin11application6memory4Game18matchSelectedItemsEvE3__1NS_9allocatorIS6_EEFvvEEclEv,b25,b25,__ZNSt3__210__function6__baseIFbdEED2Ev,__ZNSt3__210__function6__baseIFbdEED0Ev,__ZNSt3__210__function6__funcIZN4mjin11application6memory4Game18animateMatchOrMissEbNS_8functionIFvvEEEE3__2NS_9allocatorIS9_EEFbdEED2Ev,__ZNSt3__210__function6__funcIZN4mjin11application6memory4Game18animateMatchOrMissEbNS_8functionIFvvEEEE3__2NS_9allocatorIS9_EEFbdEED0Ev,b25,b25,__ZNSt3__210__function6__funcIZN4mjin11application6memory4Game18animateMatchOrMissEbNS_8functionIFvvEEEE3__2NS_9allocatorIS9_EEFbdEE7destroyEv,__ZNSt3__210__function6__funcIZN4mjin11application6memory4Game18animateMatchOrMissEbNS_8functionIFvvEEEE3__2NS_9allocatorIS9_EEFbdEE18destroy_deallocateEv,b25,b25,b25,__ZNSt3__210__function6__funcIZN4mjin11application6memory4Game18matchSelectedItemsEvE3__0NS_9allocatorIS6_EEFvvEED2Ev,__ZNSt3__210__function6__funcIZN4mjin11application6memory4Game18matchSelectedItemsEvE3__0NS_9allocatorIS6_EEFvvEED0Ev,b25
,b25,__ZNSt3__210__function6__funcIZN4mjin11application6memory4Game18matchSelectedItemsEvE3__0NS_9allocatorIS6_EEFvvEE7destroyEv,__ZNSt3__210__function6__funcIZN4mjin11application6memory4Game18matchSelectedItemsEvE3__0NS_9allocatorIS6_EEFvvEE18destroy_deallocateEv,__ZNSt3__210__function6__funcIZN4mjin11application6memory4Game18matchSelectedItemsEvE3__0NS_9allocatorIS6_EEFvvEEclEv,b25,b25,__ZN3osg17TessellationHintsD2Ev,__ZN3osg17TessellationHintsD0Ev,b25,b25,b25,b25,b25,__ZN4mjin11application6memory5input5MouseD1Ev,__ZN4mjin11application6memory5input5MouseD0Ev,b25,__ZThn4_N4mjin11application6memory5input5MouseD1Ev,__ZThn4_N4mjin11application6memory5input5MouseD0Ev,__ZTv0_n112_N4mjin11application6memory5input5MouseD1Ev,__ZTv0_n112_N4mjin11application6memory5input5MouseD0Ev,__ZTv0_n16_N4mjin11application6memory5input5MouseD1Ev,__ZTv0_n16_N4mjin11application6memory5input5MouseD0Ev,__ZN4mjin6render15VBOSetupVisitorD1Ev,__ZN4mjin6render15VBOSetupVisitorD0Ev,b25,__ZTv0_n16_N4mjin6render15VBOSetupVisitorD1Ev,__ZTv0_n16_N4mjin6render15VBOSetupVisitorD0Ev,__ZN5osgDB13DatabasePager12RequestQueueD2Ev,__ZN5osgDB13DatabasePager12RequestQueueD0Ev,__ZN5osgDB13DatabasePager12RequestQueue11updateBlockEv
,__ZN5osgDB13DatabasePager9ReadQueueD2Ev,__ZN5osgDB13DatabasePager9ReadQueueD0Ev,__ZN5osgDB13DatabasePager9ReadQueue11updateBlockEv,__ZN5osgDB13DatabasePager14DatabaseThreadD2Ev,__ZN5osgDB13DatabasePager14DatabaseThreadD0Ev,b25,__ZN5osgDB13DatabasePager14DatabaseThread3runEv,__ZThn12_N5osgDB13DatabasePager14DatabaseThreadD1Ev,__ZThn12_N5osgDB13DatabasePager14DatabaseThreadD0Ev,b25,__ZThn12_N5osgDB13DatabasePager14DatabaseThread3runEv,b25,__ZN5osgDB13DatabasePager37DatabasePagerCompileCompletedCallbackD1Ev,__ZN5osgDB13DatabasePager37DatabasePagerCompileCompletedCallbackD0Ev,__ZTv0_n16_N5osgDB13DatabasePager37DatabasePagerCompileCompletedCallbackD1Ev,__ZTv0_n16_N5osgDB13DatabasePager37DatabasePagerCompileCompletedCallbackD0Ev,__ZN5osgDB13DatabasePager31FindCompileableGLObjectsVisitorD1Ev,__ZN5osgDB13DatabasePager31FindCompileableGLObjectsVisitorD0Ev,b25,b25,b25,b25,__ZTv0_n16_N5osgDB13DatabasePager31FindCompileableGLObjectsVisitorD1Ev,__ZTv0_n16_N5osgDB13DatabasePager31FindCompileableGLObjectsVisitorD0Ev,b25,b25,__ZN5osgDB13DatabasePagerD2Ev,__ZN5osgDB13DatabasePagerD0Ev,b25,b25
,b25,b25,b25,__ZN5osgDB13DatabasePager5clearEv,b25,b25,b25,__ZN5osgDB13DatabasePager14signalEndFrameEv,b25,b25,b25,__ZN5osgDB13DatabasePager20FindPagedLODsVisitorD1Ev,__ZN5osgDB13DatabasePager20FindPagedLODsVisitorD0Ev,b25,b25,b25,__ZTv0_n16_N5osgDB13DatabasePager20FindPagedLODsVisitorD1Ev,__ZTv0_n16_N5osgDB13DatabasePager20FindPagedLODsVisitorD0Ev,b25,b25,__ZN5osgDB13DatabasePager15DatabaseRequestD2Ev,__ZN5osgDB13DatabasePager15DatabaseRequestD0Ev,__ZN20SetBasedPagedLODListD2Ev,__ZN20SetBasedPagedLODListD0Ev,b25,__ZN20SetBasedPagedLODList5clearEv,b25,b25,b25,b25
,b25,__ZN5osgDB13DatabasePager22ExpirePagedLODsVisitorD1Ev,__ZN5osgDB13DatabasePager22ExpirePagedLODsVisitorD0Ev,b25,b25,b25,__ZTv0_n16_N5osgDB13DatabasePager22ExpirePagedLODsVisitorD1Ev,__ZTv0_n16_N5osgDB13DatabasePager22ExpirePagedLODsVisitorD0Ev,b25,b25,__ZN5osgDB10ImagePager11ImageThreadD2Ev,__ZN5osgDB10ImagePager11ImageThreadD0Ev,b25,__ZN5osgDB10ImagePager11ImageThread3runEv,__ZThn12_N5osgDB10ImagePager11ImageThreadD1Ev,__ZThn12_N5osgDB10ImagePager11ImageThreadD0Ev,b25,__ZThn12_N5osgDB10ImagePager11ImageThread3runEv,__ZN5osgDB10ImagePagerD2Ev,__ZN5osgDB10ImagePagerD0Ev,b25,b25,b25,b25,b25,b25,__ZN5osgDB10ImagePager14signalEndFrameEv,__ZN5osgDB10ImagePager12ImageRequestD2Ev,__ZN5osgDB10ImagePager12ImageRequestD0Ev,__ZN5osgDB10ImagePager9ReadQueueD2Ev
,__ZN5osgDB10ImagePager9ReadQueueD0Ev,__ZN5osgDB10ImagePager12RequestQueueD2Ev,__ZN5osgDB10ImagePager12RequestQueueD0Ev,__ZN5osgDB11ObjectCacheD2Ev,__ZN5osgDB11ObjectCacheD0Ev,__ZN5osgDB8RegistryD2Ev,__ZN5osgDB8RegistryD0Ev,__ZN5osgDB30DeprecatedDotOsgWrapperManagerD2Ev,__ZN5osgDB30DeprecatedDotOsgWrapperManagerD0Ev,__ZN5osgDB8Registry11ReadFunctorD2Ev,__ZN5osgDB8Registry11ReadFunctorD0Ev,__ZN5osgDB8Registry18ReadArchiveFunctorD0Ev,b25,b25,b25,b25,__ZN5osgDB8Registry17ReadObjectFunctorD0Ev,b25,b25,b25,b25,__ZN5osgDB8Registry16ReadImageFunctorD0Ev,b25,b25,b25,b25,__ZN5osgDB8Registry22ReadHeightFieldFunctorD0Ev,b25,b25,b25
,b25,__ZN5osgDB8Registry15ReadNodeFunctorD0Ev,b25,b25,b25,b25,__ZN5osgDB8Registry17ReadShaderFunctorD0Ev,b25,b25,b25,b25,__ZN5osgDB20ObjectWrapperManagerD2Ev,__ZN5osgDB20ObjectWrapperManagerD0Ev,__ZN5osgDB14DynamicLibraryD2Ev,__ZN5osgDB14DynamicLibraryD0Ev,__ZN5osgDB9FileCacheD2Ev,__ZN5osgDB9FileCacheD0Ev,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,__ZN3osg13ShapeDrawableD2Ev,__ZN3osg13ShapeDrawableD0Ev,b25,b25,b25,b25,b25,b25,b25,_SDL_Blit_RGB888_RGB888_Scale,_SDL_Blit_RGB888_RGB888_Blend,_SDL_Blit_RGB888_RGB888_Blend_Scale,_SDL_Blit_RGB888_RGB888_Modulate,_SDL_Blit_RGB888_RGB888_Modulate_Scale,_SDL_Blit_RGB888_RGB888_Modulate_Blend,_SDL_Blit_RGB888_RGB888_Modulate_Blend_Scale,_SDL_Blit_RGB888_BGR888_Scale,_SDL_Blit_RGB888_BGR888_Blend,_SDL_Blit_RGB888_BGR888_Blend_Scale,_SDL_Blit_RGB888_BGR888_Modulate,_SDL_Blit_RGB888_BGR888_Modulate_Scale,_SDL_Blit_RGB888_BGR888_Modulate_Blend,_SDL_Blit_RGB888_BGR888_Modulate_Blend_Scale,_SDL_Blit_RGB888_ARGB8888_Scale,_SDL_Blit_RGB888_ARGB8888_Blend,_SDL_Blit_RGB888_ARGB8888_Blend_Scale,_SDL_Blit_RGB888_ARGB8888_Modulate,_SDL_Blit_RGB888_ARGB8888_Modulate_Scale,_SDL_Blit_RGB888_ARGB8888_Modulate_Blend,_SDL_Blit_RGB888_ARGB8888_Modulate_Blend_Scale
,_SDL_Blit_BGR888_RGB888_Scale,_SDL_Blit_BGR888_RGB888_Blend,_SDL_Blit_BGR888_RGB888_Blend_Scale,_SDL_Blit_BGR888_RGB888_Modulate,_SDL_Blit_BGR888_RGB888_Modulate_Scale,_SDL_Blit_BGR888_RGB888_Modulate_Blend,_SDL_Blit_BGR888_RGB888_Modulate_Blend_Scale,_SDL_Blit_BGR888_BGR888_Scale,_SDL_Blit_BGR888_BGR888_Blend,_SDL_Blit_BGR888_BGR888_Blend_Scale,_SDL_Blit_BGR888_BGR888_Modulate,_SDL_Blit_BGR888_BGR888_Modulate_Scale,_SDL_Blit_BGR888_BGR888_Modulate_Blend,_SDL_Blit_BGR888_BGR888_Modulate_Blend_Scale,_SDL_Blit_BGR888_ARGB8888_Scale,_SDL_Blit_BGR888_ARGB8888_Blend,_SDL_Blit_BGR888_ARGB8888_Blend_Scale,_SDL_Blit_BGR888_ARGB8888_Modulate,_SDL_Blit_BGR888_ARGB8888_Modulate_Scale,_SDL_Blit_BGR888_ARGB8888_Modulate_Blend,_SDL_Blit_BGR888_ARGB8888_Modulate_Blend_Scale,_SDL_Blit_ARGB8888_RGB888_Scale,_SDL_Blit_ARGB8888_RGB888_Blend,_SDL_Blit_ARGB8888_RGB888_Blend_Scale,_SDL_Blit_ARGB8888_RGB888_Modulate,_SDL_Blit_ARGB8888_RGB888_Modulate_Scale,_SDL_Blit_ARGB8888_RGB888_Modulate_Blend,_SDL_Blit_ARGB8888_RGB888_Modulate_Blend_Scale,_SDL_Blit_ARGB8888_BGR888_Scale,_SDL_Blit_ARGB8888_BGR888_Blend
,_SDL_Blit_ARGB8888_BGR888_Blend_Scale,_SDL_Blit_ARGB8888_BGR888_Modulate,_SDL_Blit_ARGB8888_BGR888_Modulate_Scale,_SDL_Blit_ARGB8888_BGR888_Modulate_Blend,_SDL_Blit_ARGB8888_BGR888_Modulate_Blend_Scale,_SDL_Blit_ARGB8888_ARGB8888_Scale,_SDL_Blit_ARGB8888_ARGB8888_Blend,_SDL_Blit_ARGB8888_ARGB8888_Blend_Scale,_SDL_Blit_ARGB8888_ARGB8888_Modulate,_SDL_Blit_ARGB8888_ARGB8888_Modulate_Scale,_SDL_Blit_ARGB8888_ARGB8888_Modulate_Blend,_SDL_Blit_ARGB8888_ARGB8888_Modulate_Blend_Scale,_SDL_Blit_RGBA8888_RGB888_Scale,_SDL_Blit_RGBA8888_RGB888_Blend,_SDL_Blit_RGBA8888_RGB888_Blend_Scale,_SDL_Blit_RGBA8888_RGB888_Modulate,_SDL_Blit_RGBA8888_RGB888_Modulate_Scale,_SDL_Blit_RGBA8888_RGB888_Modulate_Blend,_SDL_Blit_RGBA8888_RGB888_Modulate_Blend_Scale,_SDL_Blit_RGBA8888_BGR888_Scale,_SDL_Blit_RGBA8888_BGR888_Blend,_SDL_Blit_RGBA8888_BGR888_Blend_Scale,_SDL_Blit_RGBA8888_BGR888_Modulate,_SDL_Blit_RGBA8888_BGR888_Modulate_Scale,_SDL_Blit_RGBA8888_BGR888_Modulate_Blend,_SDL_Blit_RGBA8888_BGR888_Modulate_Blend_Scale,_SDL_Blit_RGBA8888_ARGB8888_Scale,_SDL_Blit_RGBA8888_ARGB8888_Blend,_SDL_Blit_RGBA8888_ARGB8888_Blend_Scale,_SDL_Blit_RGBA8888_ARGB8888_Modulate
,_SDL_Blit_RGBA8888_ARGB8888_Modulate_Scale,_SDL_Blit_RGBA8888_ARGB8888_Modulate_Blend,_SDL_Blit_RGBA8888_ARGB8888_Modulate_Blend_Scale,_SDL_Blit_ABGR8888_RGB888_Scale,_SDL_Blit_ABGR8888_RGB888_Blend,_SDL_Blit_ABGR8888_RGB888_Blend_Scale,_SDL_Blit_ABGR8888_RGB888_Modulate,_SDL_Blit_ABGR8888_RGB888_Modulate_Scale,_SDL_Blit_ABGR8888_RGB888_Modulate_Blend,_SDL_Blit_ABGR8888_RGB888_Modulate_Blend_Scale,_SDL_Blit_ABGR8888_BGR888_Scale,_SDL_Blit_ABGR8888_BGR888_Blend,_SDL_Blit_ABGR8888_BGR888_Blend_Scale,_SDL_Blit_ABGR8888_BGR888_Modulate,_SDL_Blit_ABGR8888_BGR888_Modulate_Scale,_SDL_Blit_ABGR8888_BGR888_Modulate_Blend,_SDL_Blit_ABGR8888_BGR888_Modulate_Blend_Scale,_SDL_Blit_ABGR8888_ARGB8888_Scale,_SDL_Blit_ABGR8888_ARGB8888_Blend,_SDL_Blit_ABGR8888_ARGB8888_Blend_Scale,_SDL_Blit_ABGR8888_ARGB8888_Modulate,_SDL_Blit_ABGR8888_ARGB8888_Modulate_Scale,_SDL_Blit_ABGR8888_ARGB8888_Modulate_Blend,_SDL_Blit_ABGR8888_ARGB8888_Modulate_Blend_Scale,_SDL_Blit_BGRA8888_RGB888_Scale,_SDL_Blit_BGRA8888_RGB888_Blend,_SDL_Blit_BGRA8888_RGB888_Blend_Scale,_SDL_Blit_BGRA8888_RGB888_Modulate,_SDL_Blit_BGRA8888_RGB888_Modulate_Scale,_SDL_Blit_BGRA8888_RGB888_Modulate_Blend
,_SDL_Blit_BGRA8888_RGB888_Modulate_Blend_Scale,_SDL_Blit_BGRA8888_BGR888_Scale,_SDL_Blit_BGRA8888_BGR888_Blend,_SDL_Blit_BGRA8888_BGR888_Blend_Scale,_SDL_Blit_BGRA8888_BGR888_Modulate,_SDL_Blit_BGRA8888_BGR888_Modulate_Scale,_SDL_Blit_BGRA8888_BGR888_Modulate_Blend,_SDL_Blit_BGRA8888_BGR888_Modulate_Blend_Scale,_SDL_Blit_BGRA8888_ARGB8888_Scale,_SDL_Blit_BGRA8888_ARGB8888_Blend,_SDL_Blit_BGRA8888_ARGB8888_Blend_Scale,_SDL_Blit_BGRA8888_ARGB8888_Modulate,_SDL_Blit_BGRA8888_ARGB8888_Modulate_Scale,_SDL_Blit_BGRA8888_ARGB8888_Modulate_Blend,_SDL_Blit_BGRA8888_ARGB8888_Modulate_Blend_Scale,_BlitNtoN,_Blit_RGB565_ARGB8888,_Blit_RGB565_ABGR8888,_Blit_RGB565_RGBA8888,_Blit_RGB565_BGRA8888,_Blit_RGB888_RGB565,_Blit_RGB888_RGB555,_Blit1to1,_Blit1to2,_Blit1to3,_Blit1to4,_Blit1to1Key,_Blit1to2Key,_Blit1to3Key,_Blit1to4Key
,_BlitBto1,_BlitBto2,_BlitBto3,_BlitBto4,_BlitBto1Key,_BlitBto2Key,_BlitBto3Key,_BlitBto4Key,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZNSt3__29basic_iosIcNS_11char_traitsIcEEED2Ev,__ZNSt3__29basic_iosIcNS_11char_traitsIcEEED0Ev
,__ZNSt3__28ios_baseD2Ev,__ZNSt3__28ios_baseD0Ev,__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEED2Ev,__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEED0Ev,__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEED2Ev,__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEED0Ev,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEED1Ev,__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEED0Ev,__ZTv0_n12_NSt3__213basic_istreamIwNS_11char_traitsIwEEED1Ev,__ZTv0_n12_NSt3__213basic_istreamIwNS_11char_traitsIwEEED0Ev,__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEED1Ev,__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEED0Ev,__ZTv0_n12_NSt3__213basic_ostreamIwNS_11char_traitsIwEEED1Ev,__ZTv0_n12_NSt3__213basic_ostreamIwNS_11char_traitsIwEEED0Ev,__ZNSt3__214error_categoryD2Ev,__ZNSt3__219__iostream_categoryD0Ev,b25,b25
,b25,b25,b25,__ZNSt3__28ios_base7failureD2Ev,__ZNSt3__28ios_base7failureD0Ev,b25,__ZNSt3__211__stdoutbufIwED2Ev,__ZNSt3__211__stdoutbufIwED0Ev,b25,b25,b25,b25,__ZNSt3__211__stdoutbufIcED2Ev,__ZNSt3__211__stdoutbufIcED0Ev,b25,b25,b25,b25,__ZNSt3__210__stdinbufIwED2Ev,__ZNSt3__210__stdinbufIwED0Ev,b25,b25,b25,b25,__ZNSt3__210__stdinbufIcED2Ev,__ZNSt3__210__stdinbufIcED0Ev,b25,b25,b25,b25
,__ZNSt3__27collateIcED2Ev,__ZNSt3__27collateIcED0Ev,__ZNSt3__26locale5facet16__on_zero_sharedEv,b25,b25,b25,__ZNSt3__27collateIwED2Ev,__ZNSt3__27collateIwED0Ev,b25,b25,b25,__ZNSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEED2Ev,__ZNSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEED0Ev,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZNSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEED2Ev,__ZNSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEED0Ev,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,__ZNSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEED2Ev,__ZNSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEED0Ev,b25,b25,b25,b25,b25,b25,b25,b25,__ZNSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEED2Ev,__ZNSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEED0Ev,b25,b25,b25,b25,b25,b25,b25,b25,__ZNSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEED2Ev,__ZNSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEED0Ev,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZNSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEED2Ev,__ZNSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEED0Ev,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZNSt3__28time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEED2Ev
,__ZNSt3__28time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEED0Ev,b25,__ZNSt3__28time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEED2Ev,__ZNSt3__28time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEED0Ev,b25,__ZNSt3__210moneypunctIcLb0EED2Ev,__ZNSt3__210moneypunctIcLb0EED0Ev,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZNSt3__210moneypunctIcLb1EED2Ev,__ZNSt3__210moneypunctIcLb1EED0Ev,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZNSt3__210moneypunctIwLb0EED2Ev,__ZNSt3__210moneypunctIwLb0EED0Ev,b25
,b25,b25,b25,b25,b25,b25,b25,b25,__ZNSt3__210moneypunctIwLb1EED2Ev,__ZNSt3__210moneypunctIwLb1EED0Ev,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZNSt3__29money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEED2Ev,__ZNSt3__29money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEED0Ev,b25,b25,__ZNSt3__29money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEED2Ev,__ZNSt3__29money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEED0Ev,b25,b25,__ZNSt3__29money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEED2Ev,__ZNSt3__29money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEED0Ev,b25
,b25,__ZNSt3__29money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEED2Ev,__ZNSt3__29money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEED0Ev,b25,b25,__ZNSt3__28messagesIcED2Ev,__ZNSt3__28messagesIcED0Ev,b25,b25,b25,__ZNSt3__28messagesIwED2Ev,__ZNSt3__28messagesIwED0Ev,b25,b25,b25,__ZNSt3__26locale5facetD2Ev,__ZNSt3__216__narrow_to_utf8ILj32EED0Ev,b25,b25,b25,b25,b25,b25,b25,__ZNSt3__217__widen_from_utf8ILj32EED0Ev,__ZNSt3__27codecvtIwc11__mbstate_tED2Ev,__ZNSt3__27codecvtIwc11__mbstate_tED0Ev,b25,b25,b25
,b25,b25,b25,b25,__ZNSt3__26locale5__impD2Ev,__ZNSt3__26locale5__impD0Ev,__ZNSt3__25ctypeIcED2Ev,__ZNSt3__25ctypeIcED0Ev,b25,b25,b25,b25,b25,b25,b25,b25,__ZNSt3__28numpunctIcED2Ev,__ZNSt3__28numpunctIcED0Ev,b25,b25,b25,b25,b25,__ZNSt3__28numpunctIwED2Ev,__ZNSt3__28numpunctIwED0Ev,b25,b25,b25,b25,b25
,__ZNSt3__26locale5facetD0Ev,__ZNSt3__25ctypeIwED0Ev,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZNSt3__27codecvtIcc11__mbstate_tED0Ev,b25,b25,b25,b25,b25,b25,b25,__ZNSt3__27codecvtIDsc11__mbstate_tED0Ev,b25,b25,b25,b25,b25,b25,b25
,__ZNSt3__27codecvtIDic11__mbstate_tED0Ev,__ZNSt3__212system_errorD2Ev,__ZNSt3__212system_errorD0Ev,b25,__ZN10__cxxabiv116__shim_type_infoD2Ev,__ZN10__cxxabiv117__class_type_infoD0Ev,__ZNK10__cxxabiv116__shim_type_info5noop1Ev,__ZNK10__cxxabiv116__shim_type_info5noop2Ev,b25,b25,b25,b25,__ZN10__cxxabiv120__si_class_type_infoD0Ev,b25,b25,b25,__ZNSt9bad_allocD2Ev,__ZNSt9bad_allocD0Ev,b25,__ZNSt9exceptionD2Ev,__ZNSt9exceptionD0Ev,__ZNSt11logic_errorD2Ev,__ZNSt11logic_errorD0Ev,b25,__ZNSt13runtime_errorD2Ev,__ZNSt13runtime_errorD0Ev,__ZNSt16invalid_argumentD0Ev,__ZNSt12length_errorD0Ev,__ZNSt12out_of_rangeD0Ev,__ZNSt8bad_castD2Ev
,__ZNSt8bad_castD0Ev,b25,__ZNSt10bad_typeidD2Ev,__ZNSt10bad_typeidD0Ev,b25,__ZN10__cxxabiv121__vmi_class_type_infoD0Ev,b25,b25,b25,__ZN9osgViewer6ViewerC1Ev,b25,b25,b25,__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev,b25,b25,b25,b25,b25,b25,b25,__ZNSt3__28ios_base33__set_badbit_and_consider_rethrowEv,b25,b25,__ZNSt3__26localeD2Ev,b25,b25,b25,b25,b25
,b25,__ZN9osgViewer4ViewC1Ev,b25,b25,b25,b25,b25,b25,__ZN9osgViewer5SceneC2Ev,b25,b25,__ZN7osgUtil16ShaderGenVisitorC1Ev,b25,__ZN3osg10ReferencedC2Ev,b25,b25,b25,b25,b25,__ZN9osgViewer4View37computeActiveCoordinateSystemNodePathEv,__ZN9osgViewer4View24assignSceneDataToCamerasEv,b25,__ZN3osg16ObserverNodePathC2Ev,b25,__ZN3osg16ObserverNodePathD2Ev,b25,__ZN3osg4ViewC1Ev,b25,b25,__ZN3osg10FrameStampC2Ev
,__ZN3osg7Matrixd12makeIdentityEv,b25,b25,b25,b25,b25,b25,b25,__ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv,b25,b25,b25,b25,b25,b25,b25,b25,__ZN7osgUtil22LineSegmentIntersector12IntersectionD2Ev,b25,b25,b25,b25,b25,b25,__ZN3osg4Node10dirtyBoundEv,b25,b25,b25,b25,b25
,b25,b25,__ZN3osg16TextureRectangleC2Ev,__ZNK3osg7Texture25computeInternalFormatTypeEv,b25,b25,b25,__ZN3osg6CameraC2Ev,b25,b25,__ZN3osg14StateAttributeC2Ev,b25,b25,b25,b25,__ZN3osg6TexMatC2Ev,b25,b25,b25,b25,__ZN9osgViewer8KeystoneC2Ev,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,__ZN3osg5GeodeC2Ev,b25,__ZN3osg7StencilC2Ev,b25,b25,b25,b25,__ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv,b25,__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEEC2Ev,b25,b25,b25,b25,b25,__ZN9osgViewer4View25setUpViewAcrossAllScreensEv,b25,__ZN3osg23SyncSwapBuffersCallbackC2Ev,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZN3osg15GraphicsContext20createGraphicsThreadEv
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZN5osgGA10EventQueue5clearEv,b25,b25,b25,b25,b25,b25,__ZN9osgViewer6Viewer15constructorInitEv,__ZN5osgGA12EventVisitorC1Ev,__ZN7osgUtil13UpdateVisitorC1Ev,b25,b25
,b25,__ZN9osgViewer22GraphicsWindowEmbedded4initEv,__ZN3osg5StateC2Ev,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZN7osgUtil14RayIntersector12IntersectionD2Ev,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZN3osg20SwapBuffersOperationC1Ev
,b25,__ZN3osg13RunOperationsC1Ev,__ZN3osg6Camera18createCameraThreadEv,__ZN7osgUtil12StatsVisitorC1Ev,b25,b25,__ZN3osg15GraphicsContext11swapBuffersEv,b25,b25,b25,b25,b25,__ZN9osgViewer10ViewerBase14viewerBaseInitEv,b25,b25,b25,b25,b25,b25,b25,__ZN3osg15GraphicsContext16ScreenIdentifier11readDISPLAYEv,__ZN3osg15GraphicsContext16ScreenIdentifierC2Ev,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,__ZN3osg8GeometryC2Ev,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZN3osg11PolygonModeC2Ev,b25,b25,b25,b25,b25,b25,__ZN3osg10RenderInfoD2Ev,b25,b25,b25,__ZN11OpenThreads9ConditionC2Ev
,b25,b25,__ZN9osgViewer14SceneSingletonD2Ev,b25,b25,__ZN5osgDB10ImagePagerC2Ev,b25,b25,b25,__ZN5osgGA15GUIEventAdapterC2Ev,b25,b25,b25,b25,__ZN5osgGA5EventC2Ev,b25,b25,b25,b25,b25,__ZN5osgGA19StandardManipulator13AnimationDataC2Ev,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,__ZN3osg8StateSetC2Ev,__ZN7osgUtil11RenderStageC2Ev,b25,b25,__ZN3osg9ColorMaskC2Ev,b25,__ZN3osg23CollectOccludersVisitorC1Ev,b25,b25,b25,__ZN3osg9CullStack18popModelViewMatrixEv,__ZN3osg9CullStack19popProjectionMatrixEv,__ZN3osg9CullStack11popViewportEv,__ZN3osg23CollectOccludersVisitor23removeOccludedOccludersEv,__ZN3osg20ShadowVolumeOccluderD2Ev,b25,b25,b25,__ZN7osgUtil10StateGraph5cleanEv,b25,b25,b25,__ZN7osgUtil10StateGraph5pruneEv,__ZNSt3__213__vector_baseIN3osg8PolytopeENS_9allocatorIS2_EEED2Ev,b25,b25,b25
,__ZN3osg8ViewportC2Ev,b25,b25,_glEnable__wrapper,b25,b25,_glClear__wrapper,_glDisable__wrapper,b25,b25,b25,__ZN3osg12CullSettings26readEnvironmentalVariablesEv,b25,b25,__ZN3osg7ProgramC2Ev,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZN7osgUtil16RenderStageCacheC2Ev,b25,b25,__ZN7osgUtil24PositionalStateContainerC2Ev
,b25,b25,b25,b25,b25,b25,b25,b25,__ZN3osg8ObserverC2Ev,b25,b25,b25,b25,b25,b25,b25,__ZN3osg9CullStackC2Ev,__ZN7osgUtil11CullVisitorC1Ev,__ZN3osg7ref_ptrIN7osgUtil11CullVisitorEED2Ev,b25,b25,b25,b25,b25,b25,__ZNSt3__213__vector_baseINS_4pairIN3osg7ref_ptrIKNS2_14StateAttributeEEENS3_INS2_10RefMatrixdEEEEENS_9allocatorIS9_EEED2Ev,b25,b25,b25,b25
,b25,b25,b25,b25,__ZN22RenderBinPrototypeListC2Ev,__ZN3osg7ref_ptrI22RenderBinPrototypeListED2Ev,b25,b25,b25,b25,b25,__ZN3osg5State11popStateSetEv,b25,__ZN3osg22BlockAndFlushOperationC1Ev,b25,b25,b25,b25,__ZN3osg17FrameBufferObjectC2Ev,b25,b25,__ZN3osg21FrameBufferAttachmentD2Ev,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,__ZN3osg7ref_ptrINS_16ApplicationUsageEED2Ev,b25,b25,b25,b25,b25,b25,__ZN3osg17GLBufferObjectSet30flushAllDeletedGLBufferObjectsEv,__ZN3osg17GLBufferObjectSet24deleteAllGLBufferObjectsEv,b25,__ZN3osg17GLBufferObjectSet37handlePendingOrphandedGLBufferObjectsEv,__ZN3osg14GLBufferObject14deleteGLObjectEv,__ZN3osg12BufferObjectC2Ev,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,__ZN3osg5Image12DataIteratorppEv,b25,b25,b25,b25,b25,b25,__ZN3osg15OperationThreadC2Ev,b25,b25,b25,__ZNSt3__23mapIjN3osg7ref_ptrINS1_11ContextDataEEENS_4lessIjEENS_9allocatorINS_4pairIKjS4_EEEEED2Ev,__ZNSt3__213__vector_baseIPN3osg15GraphicsContextENS_9allocatorIS3_EEED2Ev,b25,__ZNSt3__213__vector_baseINS_4pairIN3osg7ref_ptrINS2_8StateSetEEENS2_8PolytopeEEENS_9allocatorIS7_EEED2Ev,__ZN3osg9CullStack5resetEv,b25,b25,b25,b25,b25,b25,__ZN3osg15DisplaySettingsC2Ev,__ZN3osg7ref_ptrINS_15DisplaySettingsEED2Ev,__ZN3osg15DisplaySettings11setDefaultsEv,__ZN3osg15DisplaySettings26readEnvironmentalVariablesEv,b25,b25,b25
,__ZN3osg16VertexArrayState5dirtyEv,__ZN3osg8DrawableC2Ev,b25,b25,b25,b25,b25,__ZN3osg12RenderBufferC2Ev,b25,b25,b25,__ZN3osg14buffered_valueIiED2Ev,b25,b25,__ZN3osg5GroupC2Ev,b25,b25,b25,b25,__ZN3osg18VertexBufferObjectC2Ev,__ZN3osg19ElementBufferObjectC2Ev,b25,__ZN3osg14GLBufferObject13compileBufferEv,b25,b25,b25,b25,b25,b25,b25
,__ZNSt3__213__vector_baseINS_4pairIN3osg7ref_ptrINS2_5ArrayEEES5_EENS_9allocatorIS6_EEED2Ev,b25,__ZN3osg15buffered_objectINSt3__23setINS1_12basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEENS1_4lessIS8_EENS6_IS8_EEEEED2Ev,__ZN3osg15buffered_objectINSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEED2Ev,__ZN3osg15buffered_objectINS_7ref_ptrINS_12GLExtensionsEEEED2Ev,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZN3osg11ContextData25unregisterGraphicsContextEPNS_15GraphicsContextE,__ZN3osg7ref_ptrINS_15GraphicsContext25WindowingSystemInterfacesEED2Ev,b25,b25,b25,__ZN3osg8RefBlockC1Ev,__ZN3osg11ContextData23registerGraphicsContextEPNS_15GraphicsContextE,__ZN11OpenThreads5BlockD2Ev,__ZN3osg14GraphicsThreadC2Ev,__ZN11OpenThreads10BlockCountD2Ev,b25
,__ZN3osg4NodeC2Ev,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZN3osg12BufferObject5dirtyEv,__ZN3osg5Image12DataIterator6assignEv,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZN15NotifySingletonC2Ev,__ZN15NotifySingletonD2Ev,__ZN3osg12NotifyStreamC1Ev,__ZN3osg18NotifyStreamBufferC2Ev,__ZN3osg24DefaultUserDataContainerC2Ev,b25,b25
,b25,b25,b25,b25,__ZN11OpenThreads6ThreadC2Ev,__ZN3osg14OperationQueueC2Ev,b25,b25,__ZNSt3__214__split_bufferIN3osg8PagedLOD12PerRangeDataERNS_9allocatorIS3_EEED2Ev,b25,b25,b25,b25,b25,__ZN3osg14GraphicsObjectC2Ev,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,__ZN3osg7Program12dirtyProgramEv,b25,b25,__ZN3osg12ResetPointerINS_13DeleteHandlerEED2Ev,__ZN3osg12ResetPointerIN11OpenThreads5MutexEED2Ev,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZN3osg6Shader21_computeShaderDefinesEv,__ZN3osg6Shader11dirtyShaderEv,b25,b25,b25,b25,b25
,b25,__ZN3osg9CullStack20computeFrustumVolumeEv,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZNSt3__214__split_bufferIN3osg8PolytopeERNS_9allocatorIS2_EEED2Ev,b25,b25,b25,b25,b25,b25,b25,__ZN3osg20AttributeDispatchersC2Ev,__ZN3osg14ShaderComposerC2Ev,b25,b25,b25,__ZN3osg21GraphicsCostEstimatorC2Ev,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZN3osg8StateSet5clearEv,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZN3osg5ImageC2Ev,b25,b25,b25,__ZN3osg9BlendFuncC2Ev,b25,b25,__ZN16TextureGLModeSetC2Ev,__ZN16TextureGLModeSetD2Ev,b25
,b25,b25,b25,b25,b25,b25,__ZN3osg9Texture2DC2Ev,b25,b25,b25,b25,__ZN3osg7Texture13TextureObject4bindEv,b25,b25,b25,b25,b25,__ZN3osg16TextureObjectSet36handlePendingOrphandedTextureObjectsEv,b25,__ZN3osg7Texture18dirtyTextureObjectEv,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,__ZNSt3__23mapINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEjNS_4lessIS6_EENS4_INS_4pairIKS6_jEEEEED2Ev,b25,b25,b25,b25,__ZN3osg7Uniform17allocateDataArrayEv,b25,b25,b25,b25,__ZN3osg16VertexArrayState23deleteVertexArrayObjectEv,b25,__ZN3osg8StateSet17setGlobalDefaultsEv,__ZN3osg5LightC2Ev,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,__Z22thread_cleanup_handlerPv,b25,b25,__Z23barrier_cleanup_handlerPv,__Z25condition_cleanup_handlerPv,__ZN4mjin3log6LoggerC2Ev,b25,__ZN4mjin11application6memory8material4PoolC2Ev,b25,b25,b25,__ZN4mjin11application6memory4Game5startEv,__ZN4mjin11application6memory11Coordinator14setupSelectionEv,__ZN4mjin11application6memory5input5MouseC1Ev,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZN3osg5TimerC2Ev,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,__ZN3osg17TessellationHintsC2Ev,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZN3osg7ref_ptrINS_8DrawableEEC2Ev,__ZN3osg7ref_ptrINS_10RefMatrixdEEC2Ev,__ZN3osg5Vec3dC2Ev,__ZN3osg5Vec3fC2Ev,b25,b25,b25,b25,b25,b25,b25,b25
,b25,_srand,b25,b25,b25,b25,b25,__ZN4mjin6render15VBOSetupVisitorC1Ev,b25,b25,b25,__ZN5osgDB13DatabasePager15DatabaseRequest10invalidateEv,b25,b25,b25,__ZN5osgDB11ObjectCacheC2Ev,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,__ZN3osg8Drawable45setMinimumNumberOfDisplayListsToRetainInCacheEj,__ZN5osgDB13DatabasePagerC2Ev,__ZN3osg7ref_ptrIN5osgDB13DatabasePagerEED2Ev,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZN5osgDB10ImagePager12RequestQueueC2Ev,b25,__ZNSt3__24pairIKNS0_INS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7ref_ptrIKN5osgDB7OptionsEEEEENS0_INS8_INS7_6ObjectEEEdEEED2Ev,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,__ZN5osgDB8Registry8destructEv,__ZN5osgDB8RegistryC2Ev,__ZN3osg7ref_ptrIN5osgDB8RegistryEED2Ev,__ZN3osg13KdTreeBuilderC1Ev,b25,b25,__ZN5osgDB8Registry20initDataFilePathListEv,__ZN5osgDB8Registry23initLibraryFilePathListEv,b25,__ZN5osgDB20ObjectWrapperManagerC2Ev,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,__ZNSt3__25dequeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS4_IS6_EEE19__add_back_capacityEv,b25,__ZN5osgDB8Registry29AvailableReaderWriterIteratorppEv,__ZN5osgDB8Registry24AvailableArchiveIteratorppEv,b25,b25,b25,b25,b25,__ZNSt3__213__vector_baseIN5osgDB12ReaderWriter10ReadResultENS_9allocatorIS3_EEED2Ev,b25,b25,b25,__ZNSt3__214__split_bufferIN5osgDB12ReaderWriter10ReadResultERNS_9allocatorIS3_EEED2Ev,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZN3osg13ImageSequence9ImageDataD2Ev,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,_GLES2_RenderPresent,b25,_GLES2_DestroyRenderer,b25,b25,b25,b25,b25,b25,_SDL_Blit_Slow,_SDL_BlitCopy,b25,b25
,b25,b25,b25,b25,_BlitBtoNAlpha,_BlitBtoNAlphaKey,_Blit1toNAlpha,_Blit1toNAlphaKey,_BlitNtoNPixelAlpha,_BlitARGBto555PixelAlpha,_BlitARGBto565PixelAlpha,_BlitNtoNSurfaceAlpha,_Blit555to555SurfaceAlpha,_Blit565to565SurfaceAlpha,_BlitNtoNSurfaceAlphaKey,_BlitNto1SurfaceAlphaKey,_BlitNto1PixelAlpha,_BlitRGBtoRGBPixelAlpha,_BlitNto1SurfaceAlpha,_BlitRGBtoRGBSurfaceAlpha,_BlitNtoNCopyAlpha,_Blit4to4CopyAlpha,_Blit_RGB888_index8,_Blit_RGB101010_index8,_BlitNto1,_Blit2101010toN,_BlitNto2101010,_Blit4to4MaskAlpha,_Blit2to2Key,_BlitNto1Key
,_BlitNtoNKeyCopyAlpha,_BlitNtoNKey,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,_SW_RenderPresent,b25,_SW_DestroyRenderer,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,_Emscripten_VideoQuit,b25,_Emscripten_PumpEvents,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,_SDL_EGL_UnloadLibrary,b25,b25,b25,b25,b25,b25,b25,_Emscripten_DeleteDevice,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,_Emscripten_FreeCursor,b25,b25,b25,b25,_EMSCRIPTENAUDIO_CloseDevice,_HandleCaptureProcess,_HandleAudioProcess,b25,_DUMMY_VideoQuit,b25,_DUMMY_PumpEvents,b25,b25,b25,_DUMMY_DeleteDevice,b25
,b25,b25,b25,b25,b25,_DISKAUDIO_WaitDevice,_DISKAUDIO_PlayDevice,b25,b25,_DISKAUDIO_FlushCapture,_DISKAUDIO_CloseDevice,b25,b25,b25,_SDL_HandleSIG,b25,b25,b25,_SDL_AudioLockOrUnlockDeviceWithNoMixerLock,b25,b25,_SDL_AudioThreadInit_Default,_SDL_AudioWaitDevice_Default,_SDL_AudioPlayDevice_Default,b25,b25,b25,_SDL_AudioFlushCapture_Default,_SDL_AudioPrepareToClose_Default,_SDL_AudioCloseDevice_Default
,_SDL_AudioLockDevice_Default,_SDL_AudioUnlockDevice_Default,_SDL_AudioFreeDeviceHandle_Default,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,_emscripten_glDeleteShader__wrapper,b25,b25,b25,_emscripten_glCompileShader__wrapper,b25
,b25,b25,b25,b25,_emscripten_glDeleteProgram__wrapper,b25,b25,b25,_emscripten_glLinkProgram__wrapper,b25,_emscripten_glUseProgram__wrapper,_emscripten_glValidateProgram__wrapper,b25,b25,b25,b25,b25,b25,b25,b25,b25,_emscripten_glDeleteObjectARB__wrapper,b25,b25,b25,b25,b25,_emscripten_glEnableClientState__wrapper,b25,b25
,b25,b25,_emscripten_glClientActiveTexture__wrapper,b25,b25,_emscripten_glBindVertexArray__wrapper,_emscripten_glMatrixMode__wrapper,b25,_emscripten_glLoadMatrixf__wrapper,b25,b25,b25,_emscripten_glEnableVertexAttribArray__wrapper,_emscripten_glDisableVertexAttribArray__wrapper,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,_emscripten_glDepthFunc__wrapper,_emscripten_glEnable__wrapper,_emscripten_glDisable__wrapper,_emscripten_glFrontFace__wrapper,_emscripten_glCullFace__wrapper,_emscripten_glClear__wrapper,b25,_emscripten_glClearStencil__wrapper,_emscripten_glDepthMask__wrapper,_emscripten_glStencilMask__wrapper,b25,_emscripten_glGenerateMipmap__wrapper,_emscripten_glActiveTexture__wrapper,_emscripten_glBlendEquation__wrapper,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZNSt3__28ios_base4InitD2Ev,b25,b25,b25,b25,b25,b25,b25,__ZNSt3__26locale2id6__initEv,__ZNSt3__217__call_once_proxyINS_5tupleIJONS_12_GLOBAL__N_111__fake_bindEEEEEEvPv,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,___cxx_global_array_dtor_118,___cxx_global_array_dtor_70,___cxx_global_array_dtor,b25,b25,b25,__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev
,b25,___cxx_global_array_dtor_121,___cxx_global_array_dtor_94,___cxx_global_array_dtor_55,_freelocale,b25,b25,__ZNSt3__212__do_nothingEPv,b25,__ZNSt3__221__throw_runtime_errorEPKc,b25,b25,b25,b25,b25,_free,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,__ZNSt3__212_GLOBAL__N_112throw_helperISt12out_of_rangeEEvRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE,__ZNSt3__212_GLOBAL__N_112throw_helperISt16invalid_argumentEEvRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE,b25,b25,b25,b25,b25,__ZN10__cxxabiv112_GLOBAL__N_19destruct_EPv,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25,b25
,b25,b25,b25];
var FUNCTION_TABLE_viiiiii = [b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,__ZNSt3__215basic_stringbufIcNS_11char_traitsIcEENS_9allocatorIcEEE7seekoffExNS_8ios_base7seekdirEj,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE7seekoffExNS_8ios_base7seekdirEj,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE7seekoffExNS_8ios_base7seekdirEj,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,__ZNKSt3__28messagesIcE6do_getEiiiRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE,b26,b26,b26,b26,__ZNKSt3__28messagesIwE6do_getEiiiRKNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEE,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,__ZNK10__cxxabiv117__class_type_info16search_above_dstEPNS_19__dynamic_cast_infoEPKvS4_ib,b26,b26,b26,__ZNK10__cxxabiv120__si_class_type_info16search_above_dstEPNS_19__dynamic_cast_infoEPKvS4_ib,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,__ZNK10__cxxabiv121__vmi_class_type_info16search_above_dstEPNS_19__dynamic_cast_infoEPKvS4_ib,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,__ZN7osgUtil22LineSegmentIntersectorC2ENS_11Intersector15CoordinateFrameERKN3osg5Vec3dES6_PS0_NS1_17IntersectionLimitE,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,__ZN9osgViewer4View17setUpViewInWindowEiiiij,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,__ZN5osgGA15GUIEventAdapter18setWindowRectangleEiiiib,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,__ZN3osg12RenderBufferC2Eiijii,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,__ZN3osg5State22setUpVertexAttribAliasERNS_17VertexAttribAliasEjNSt3__212basic_stringIcNS3_11char_traitsIcEENS3_9allocatorIcEEEES9_RKS9_,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,__ZN11State_Utils27replaceAndInsertDeclarationERNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEjRKS6_S9_S9_S9_,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,__ZNK3osg7Texture32computeRequiredTextureDimensionsERNS_5StateERKNS_5ImageERiS6_S6_,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,__ZNK3osg16TextureRectangle18applyTexImage_loadEjPNS_5ImageERNS_5StateERiS5_,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,__ZN5osgDB8Registry25openArchiveImplementationERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEENS_12ReaderWriter13ArchiveStatusEjPKNS_7OptionsE,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,_emscripten_glDrawRangeElements__wrapper,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,_emscripten_glVertexAttribPointer__wrapper,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26,b26
,b26,b26,b26];
var FUNCTION_TABLE_iiid = [b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,__ZN5osgGA10EventQueue10takeEventsERNSt3__24listIN3osg7ref_ptrINS_5EventEEENS1_9allocatorIS6_EEEEd,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,__ZN3osg31isGLExtensionOrVersionSupportedEjPKcf,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27
,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27,b27];
var FUNCTION_TABLE_vdi = [b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,_emscripten_glSampleCoverage__wrapper,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28,b28
,b28,b28,b28];
var FUNCTION_TABLE_viid = [b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,__ZN3osg6SphereC2ERKNS_5Vec3fEf,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,_emscripten_glTexParameterf__wrapper,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29,b29
,b29,b29,b29];
var FUNCTION_TABLE_viddddd = [b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30
,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30
,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30
,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30
,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30
,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30
,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30
,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30
,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30
,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30
,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30
,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30
,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30
,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30
,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30
,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30
,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30
,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30
,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30
,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30
,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30
,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30
,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30
,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30
,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30
,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30
,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30
,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,__ZN5osgGA16OrbitManipulator15rotateTrackballEfffff,b30,b30,b30,b30,b30,b30,b30,b30,b30
,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30
,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30
,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30
,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30
,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30
,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30,b30
,b30,b30,b30,b30,b30];
var FUNCTION_TABLE_di = [b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,__ZN9osgViewer6Viewer11elapsedTimeEv,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,__ZNK5osgGA16OrbitManipulator22getFusionDistanceValueEv,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,__ZNK5osgGA17CameraManipulator22getFusionDistanceValueEv,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,__ZNK5osgDB10ImagePager14getPreLoadTimeEv,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,__ZN3osg17findAsciiToDoubleEPKc,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,__ZNK3osg5Vec2f1xEv,__ZNK3osg5Vec2f1yEv,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,__ZN3osg13asciiToDoubleEPKc,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31,b31
,b31,b31,b31];
var FUNCTION_TABLE_iiiiiiiiiii = [b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,__ZN9osgViewer4View30assignKeystoneDistortionCameraEPN3osg15DisplaySettingsEPNS1_15GraphicsContextEiiiijPNS1_7TextureEPNS_8KeystoneE,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,__ZNSt3__29__num_getIcE17__stage2_int_loopEciPcRS2_RjcRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjRSD_S2_,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,__ZNSt3__29__num_getIwE17__stage2_int_loopEwiPcRS2_RjwRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjRSD_Pw,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32,b32
,b32,b32,b32];
var FUNCTION_TABLE_viiidi = [b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,__ZN5osgDB11ObjectCache21addEntryToObjectCacheERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEPN3osg6ObjectEdPKNS_7OptionsE,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33,b33
,b33,b33,b33];
var FUNCTION_TABLE_viiiiiiii = [b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,__ZN3osg5Image10readPixelsEiiiijji,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,__ZN3osg6Camera6attachENS0_15BufferComponentEPNS_7TextureEjjbjj,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,__ZNK3osg7Texture23applyTexImage2D_subloadERNS_5StateEjPKNS_5ImageEiiii,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,_emscripten_glCompressedTexImage2D__wrapper,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,_emscripten_glCopyTexImage2D__wrapper,_emscripten_glCopyTexSubImage2D__wrapper,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34,b34
,b34,b34,b34];
var FUNCTION_TABLE_vidddd = [b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,__ZN7osgUtil10Statistics6vertexEffff,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,__ZN12ComputeBound6vertexEffff,b35,b35,__ZN12ComputeBound6vertexEdddd,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,__ZN3osg6Camera32setProjectionMatrixAsPerspectiveEdddd,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,__ZN3osg7Matrixd10makeRotateEdddd,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,__ZN3osg8ViewportC2Edddd,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,_emscripten_glUniform4f__wrapper,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,_emscripten_glVertexAttrib4f__wrapper,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35,b35
,b35,b35,b35];
var FUNCTION_TABLE_iiiiiiiiiiiii = [b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,__ZNSt3__29__num_getIcE19__stage2_float_loopEcRbRcPcRS4_ccRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjRSE_RjS4_,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,__ZNSt3__29__num_getIwE19__stage2_float_loopEwRbRcPcRS4_wwRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjRSE_RjPw,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36,b36
,b36,b36,b36];
var FUNCTION_TABLE_iid = [b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,__ZN5osgGA10EventQueue5frameEd,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEd,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEf,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,__ZN4mjin11application6memory6render12createSphereERKN3osg5Vec3fEf,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37
,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37,b37];
var FUNCTION_TABLE_viiiiiii = [b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,__ZN3osg5Image13allocateImageEiiijji,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,__ZN3osg16VertexArrayState13ArrayDispatch19enable_and_dispatchERNS_5StateEijiPKvh,b38,b38
,__ZN3osg16VertexArrayState13ArrayDispatch8dispatchERNS_5StateEijiPKvh,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,__ZNK3osg7Texture20applyTexImage2D_loadERNS_5StateEjPKNS_5ImageEiii,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,__ZNK3osg16TextureRectangle21applyTexImage_subloadEjPNS_5ImageERNS_5StateERiS5_S5_,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,_SDL_DrawLine2,_SDL_DrawLine1,_SDL_DrawLine4,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,_emscripten_glReadPixels__wrapper,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,_emscripten_glGetActiveUniform__wrapper,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,_emscripten_glGetActiveAttrib__wrapper,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,__ZNSt3__29__num_putIcE21__widen_and_group_intEPcS2_S2_S2_RS2_S3_RKNS_6localeE,b38,__ZNSt3__29__num_putIcE23__widen_and_group_floatEPcS2_S2_S2_RS2_S3_RKNS_6localeE,b38,b38,b38,__ZNSt3__29__num_putIwE21__widen_and_group_intEPcS2_S2_PwRS3_S4_RKNS_6localeE,__ZNSt3__29__num_putIwE23__widen_and_group_floatEPcS2_S2_PwRS3_S4_RKNS_6localeE,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38,b38
,b38,b38,b38];
var FUNCTION_TABLE_iiddd = [b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39
,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39
,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39
,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39
,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39
,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39
,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39
,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39
,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39
,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39
,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39
,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39
,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39
,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39
,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39
,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39
,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39
,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39
,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39
,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39
,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39
,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39
,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39
,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39
,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39
,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39
,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39
,b39,b39,b39,__ZN5osgGA16OrbitManipulator30performMovementLeftMouseButtonEddd,__ZN5osgGA16OrbitManipulator32performMovementMiddleMouseButtonEddd,__ZN5osgGA16OrbitManipulator31performMovementRightMouseButtonEddd,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39
,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39
,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39
,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,__ZN5osgGA19StandardManipulator30performMovementLeftMouseButtonEddd,__ZN5osgGA19StandardManipulator32performMovementMiddleMouseButtonEddd,__ZN5osgGA19StandardManipulator31performMovementRightMouseButtonEddd,b39,b39,b39,b39,b39,b39,b39,b39
,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39
,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39
,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39,b39
,b39,b39,b39,b39,b39];
var FUNCTION_TABLE_viiid = [b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40
,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40
,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40
,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40
,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40
,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40
,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40
,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40
,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40
,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40
,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40
,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40
,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40
,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40
,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40
,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40
,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40
,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40
,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40
,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40
,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40
,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40
,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40
,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40
,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40
,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40
,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40
,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40
,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40
,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40
,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40
,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40
,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40
,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40
,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40
,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40
,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40
,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40
,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40
,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40
,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40
,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40
,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40
,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40
,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40
,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40
,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40
,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40
,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40
,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40
,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40
,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40
,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40
,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40
,b40,b40,b40,b40,b40,b40,b40,__ZNK3osg15DisplaySettings32computeLeftEyeViewImplementationERKNS_7MatrixdEd,b40,__ZNK3osg15DisplaySettings33computeRightEyeViewImplementationERKNS_7MatrixdEd,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40
,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40
,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40
,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40
,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40
,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40
,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40
,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40
,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40
,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40
,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40
,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40
,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40
,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40
,b40,b40,b40,b40,b40,b40,b40,b40,b40];
var FUNCTION_TABLE_viiiiiiiiii = [b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,__ZNSt3__211__money_getIcE13__gather_infoEbRKNS_6localeERNS_10money_base7patternERcS8_RNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEESF_SF_SF_Ri,b41,b41,b41,b41,b41,b41,b41,__ZNSt3__211__money_getIwE13__gather_infoEbRKNS_6localeERNS_10money_base7patternERwS8_RNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERNS9_IwNSA_IwEENSC_IwEEEESJ_SJ_Ri,b41,b41,b41,__ZNSt3__211__money_putIcE13__gather_infoEbbRKNS_6localeERNS_10money_base7patternERcS8_RNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEESF_SF_Ri,b41,__ZNSt3__211__money_putIwE13__gather_infoEbbRKNS_6localeERNS_10money_base7patternERwS8_RNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERNS9_IwNSA_IwEENSC_IwEEEESJ_Ri,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41,b41
,b41,b41,b41];
var FUNCTION_TABLE_iii = [b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZNK3osg15GraphicsContext5cloneERKNS_6CopyOpE,__ZNK9osgViewer14GraphicsWindow12isSameKindAsEPKN3osg6ObjectE,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZN9osgViewer14GraphicsWindow32makeContextCurrentImplementationEPN3osg15GraphicsContextE,b42,b42,b42,b42,b42,b42,b42,__ZN9osgViewer14GraphicsWindow33setWindowDecorationImplementationEb
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZNK9osgViewer4View5cloneERKN3osg6CopyOpE,__ZNK9osgViewer4View12isSameKindAsEPKN3osg6ObjectE,b42,b42,b42,b42,b42,__ZN9osgViewer4View14createRendererEPN3osg6CameraE
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZTv0_n24_NK9osgViewer4View5cloneERKN3osg6CopyOpE,__ZTv0_n28_NK9osgViewer4View12isSameKindAsEPKN3osg6ObjectE,b42,b42,b42,b42,b42,__ZNK3osg11NodeVisitor5cloneERKNS_6CopyOpE,__ZNK3osg11NodeVisitor12isSameKindAsEPKNS_6ObjectE
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZTv0_n24_NK3osg11NodeVisitor5cloneERKNS_6CopyOpE,__ZTv0_n28_NK3osg11NodeVisitor12isSameKindAsEPKNS_6ObjectE,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,__ZN9osgViewer6Viewer17readConfigurationERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZNK9osgViewer6Viewer5cloneERKN3osg6CopyOpE,__ZNK9osgViewer6Viewer12isSameKindAsEPKN3osg6ObjectE,b42,b42,b42,b42,b42,b42,b42,__ZThn104_NK9osgViewer6Viewer5cloneERKN3osg6CopyOpE,__ZThn104_NK9osgViewer6Viewer12isSameKindAsEPKN3osg6ObjectE,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,__ZTv0_n24_NK9osgViewer6Viewer5cloneERKN3osg6CopyOpE,__ZTv0_n28_NK9osgViewer6Viewer12isSameKindAsEPKN3osg6ObjectE,b42,b42,b42,b42,b42,b42,b42,__ZNK3osg6Object12isSameKindAsEPKS0_,b42,__ZNK3osg4View5cloneERKNS_6CopyOpE,__ZNK3osg4View12isSameKindAsEPKNS_6ObjectE,b42,b42,b42,b42,b42,__ZN3osg4View14createRendererEPNS_6CameraE,b42,b42,b42,__ZTv0_n24_NK3osg4View5cloneERKNS_6CopyOpE,__ZTv0_n28_NK3osg4View12isSameKindAsEPKNS_6ObjectE,b42,b42,b42,__ZNK9osgViewer22GraphicsWindowEmbedded12isSameKindAsEPKN3osg6ObjectE
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,__ZNSt3__215basic_stringbufIcNS_11char_traitsIcEENS_9allocatorIcEEE9pbackfailEi,b42,__ZNSt3__215basic_stringbufIcNS_11char_traitsIcEENS_9allocatorIcEEE8overflowEi,b42,b42,b42,__ZNK5osgDB7Options5cloneERKN3osg6CopyOpE,__ZNK5osgDB7Options12isSameKindAsEPKN3osg6ObjectE,b42,b42,b42,b42,b42,__ZNK3osg13TemplateArrayINS_5Vec3fELNS_5Array4TypeE28ELi3ELi5126EE5cloneERKNS_6CopyOpE,__ZNK3osg5Array12isSameKindAsEPKNS_6ObjectE,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,__ZNK3osg13TemplateArrayINS_5Vec3fELNS_5Array4TypeE28ELi3ELi5126EE14getDataPointerEj,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZNK3osg13TemplateArrayINS_5Vec2fELNS_5Array4TypeE27ELi2ELi5126EE5cloneERKNS_6CopyOpE,b42,b42,b42,b42,b42,b42,b42,b42,__ZNK3osg13TemplateArrayINS_5Vec2fELNS_5Array4TypeE27ELi2ELi5126EE14getDataPointerEj,b42,b42
,b42,b42,b42,b42,b42,b42,b42,__ZNK3osg13TemplateArrayINS_5Vec4fELNS_5Array4TypeE29ELi4ELi5126EE5cloneERKNS_6CopyOpE,b42,b42,b42,b42,b42,b42,b42,b42,__ZNK3osg13TemplateArrayINS_5Vec4fELNS_5Array4TypeE29ELi4ELi5126EE14getDataPointerEj,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,__ZNK9osgViewer12SingleWindow5cloneERKN3osg6CopyOpE,__ZNK9osgViewer12SingleWindow12isSameKindAsEPKN3osg6ObjectE,b42,b42,b42,__ZNK9osgViewer10ViewConfig23getActiveDisplaySettingERNS_4ViewE,b42,b42,__ZNK9osgViewer12SingleScreen5cloneERKN3osg6CopyOpE,__ZNK9osgViewer12SingleScreen12isSameKindAsEPKN3osg6ObjectE,b42,b42,b42,b42,b42,__ZNK9osgViewer16AcrossAllScreens5cloneERKN3osg6CopyOpE,__ZNK9osgViewer16AcrossAllScreens12isSameKindAsEPKN3osg6ObjectE,b42,b42,b42,b42,__ZNK5osgGA15GUIEventHandler5cloneERKN3osg6CopyOpE,__ZNK5osgGA15GUIEventHandler12isSameKindAsEPKN3osg6ObjectE,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZThn4_NK5osgGA15GUIEventHandler5cloneERKN3osg6CopyOpE,__ZThn4_NK5osgGA15GUIEventHandler12isSameKindAsEPKN3osg6ObjectE,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZTv0_n20_NK5osgGA15GUIEventHandler5cloneERKN3osg6CopyOpE,__ZTv0_n24_NK5osgGA15GUIEventHandler12isSameKindAsEPKN3osg6ObjectE,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZTv0_n24_NK5osgGA15GUIEventHandler5cloneERKN3osg6CopyOpE,__ZTv0_n28_NK5osgGA15GUIEventHandler12isSameKindAsEPKN3osg6ObjectE,b42,b42,b42,b42,b42,b42
,b42,__ZNK3osg8Callback5cloneERKNS_6CopyOpE,__ZNK3osg8Callback12isSameKindAsEPKNS_6ObjectE,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZTv0_n24_NK3osg8Callback5cloneERKNS_6CopyOpE,__ZTv0_n28_NK3osg8Callback12isSameKindAsEPKNS_6ObjectE,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,__ZNK5osgGA12EventHandler5cloneERKN3osg6CopyOpE,__ZNK5osgGA12EventHandler12isSameKindAsEPKN3osg6ObjectE,b42,b42,b42,b42,b42,b42,__ZThn4_NK5osgGA12EventHandler5cloneERKN3osg6CopyOpE,__ZThn4_NK5osgGA12EventHandler12isSameKindAsEPKN3osg6ObjectE,b42,b42,b42,b42,b42,__ZTv0_n20_NK5osgGA12EventHandler5cloneERKN3osg6CopyOpE,__ZTv0_n24_NK5osgGA12EventHandler12isSameKindAsEPKN3osg6ObjectE,b42,b42,b42,b42,b42,b42,b42,__ZTv0_n24_NK5osgGA12EventHandler5cloneERKN3osg6CopyOpE,__ZTv0_n28_NK5osgGA12EventHandler12isSameKindAsEPKN3osg6ObjectE,b42,b42,b42
,__ZNK3osg12NodeCallback5cloneERKNS_6CopyOpE,__ZNK3osg12NodeCallback12isSameKindAsEPKNS_6ObjectE,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZTv0_n20_NK3osg12NodeCallback5cloneERKNS_6CopyOpE,__ZTv0_n24_NK3osg12NodeCallback12isSameKindAsEPKNS_6ObjectE,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZTv0_n24_NK3osg12NodeCallback5cloneERKNS_6CopyOpE,__ZTv0_n28_NK3osg12NodeCallback12isSameKindAsEPKNS_6ObjectE,b42,b42,b42,__ZNK3osg21DrawableEventCallback5cloneERKNS_6CopyOpE,__ZNK3osg21DrawableEventCallback12isSameKindAsEPKNS_6ObjectE
,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZTv0_n20_NK3osg21DrawableEventCallback5cloneERKNS_6CopyOpE,__ZTv0_n24_NK3osg21DrawableEventCallback12isSameKindAsEPKNS_6ObjectE,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZTv0_n24_NK3osg21DrawableEventCallback5cloneERKNS_6CopyOpE,__ZTv0_n28_NK3osg21DrawableEventCallback12isSameKindAsEPKNS_6ObjectE,b42,b42,b42,b42,__ZNK9osgViewer8Keystone5cloneERKN3osg6CopyOpE,__ZNK9osgViewer8Keystone12isSameKindAsEPKN3osg6ObjectE,b42
,b42,b42,__ZNK22KeystoneUpdateCallback5cloneERKN3osg6CopyOpE,__ZNK22KeystoneUpdateCallback12isSameKindAsEPKN3osg6ObjectE,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZTv0_n20_NK22KeystoneUpdateCallback5cloneERKN3osg6CopyOpE,__ZTv0_n24_NK22KeystoneUpdateCallback12isSameKindAsEPKN3osg6ObjectE,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZTv0_n24_NK22KeystoneUpdateCallback5cloneERKN3osg6CopyOpE,__ZTv0_n28_NK22KeystoneUpdateCallback12isSameKindAsEPKN3osg6ObjectE,b42,b42,b42
,__ZNK20KeystoneCullCallback5cloneERKN3osg6CopyOpE,__ZNK20KeystoneCullCallback12isSameKindAsEPKN3osg6ObjectE,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZTv0_n20_NK20KeystoneCullCallback5cloneERKN3osg6CopyOpE,__ZTv0_n24_NK20KeystoneCullCallback12isSameKindAsEPKN3osg6ObjectE,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZTv0_n24_NK20KeystoneCullCallback5cloneERKN3osg6CopyOpE,__ZTv0_n28_NK20KeystoneCullCallback12isSameKindAsEPKN3osg6ObjectE,b42,b42,b42,b42,__ZNK3osg11ValueObject5cloneERKNS_6CopyOpE,__ZNK3osg11ValueObject12isSameKindAsEPKNS_6ObjectE
,b42,b42,__ZNK3osg11ValueObject3getERNS0_15GetValueVisitorE,__ZN3osg11ValueObject3setERNS0_15SetValueVisitorE,b42,b42,b42,__ZNK3osg19TemplateValueObjectINSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEE5cloneERKNS_6CopyOpE,__ZNK3osg19TemplateValueObjectINSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEE12isSameKindAsEPKNS_6ObjectE,b42,b42,__ZNK3osg19TemplateValueObjectINSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEE3getERNS_11ValueObject15GetValueVisitorE,__ZN3osg19TemplateValueObjectINSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEE3setERNS_11ValueObject15SetValueVisitorE,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,__ZNK5osgGA15GUIEventAdapter5cloneERKN3osg6CopyOpE,__ZNK5osgGA15GUIEventAdapter12isSameKindAsEPKN3osg6ObjectE,b42,b42,b42,b42,b42,b42,b42,__ZNK5osgGA20TrackballManipulator5cloneERKN3osg6CopyOpE,__ZNK5osgGA20TrackballManipulator12isSameKindAsEPKN3osg6ObjectE,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZThn4_NK5osgGA20TrackballManipulator5cloneERKN3osg6CopyOpE,__ZThn4_NK5osgGA20TrackballManipulator12isSameKindAsEPKN3osg6ObjectE,b42,b42
,b42,b42,b42,__ZTv0_n20_NK5osgGA20TrackballManipulator5cloneERKN3osg6CopyOpE,__ZTv0_n24_NK5osgGA20TrackballManipulator12isSameKindAsEPKN3osg6ObjectE,b42,b42,b42,b42,b42,b42,b42,__ZTv0_n24_NK5osgGA20TrackballManipulator5cloneERKN3osg6CopyOpE,__ZTv0_n28_NK5osgGA20TrackballManipulator12isSameKindAsEPKN3osg6ObjectE,b42,b42,b42,b42,b42,__ZNK5osgGA5Event5cloneERKN3osg6CopyOpE,__ZNK5osgGA5Event12isSameKindAsEPKN3osg6ObjectE,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZNK5osgGA16OrbitManipulator5cloneERKN3osg6CopyOpE,__ZNK5osgGA16OrbitManipulator12isSameKindAsEPKN3osg6ObjectE,b42,b42,b42,b42,b42,__ZThn4_NK5osgGA16OrbitManipulator5cloneERKN3osg6CopyOpE,__ZThn4_NK5osgGA16OrbitManipulator12isSameKindAsEPKN3osg6ObjectE,b42,b42,b42
,b42,b42,__ZTv0_n20_NK5osgGA16OrbitManipulator5cloneERKN3osg6CopyOpE,__ZTv0_n24_NK5osgGA16OrbitManipulator12isSameKindAsEPKN3osg6ObjectE,b42,b42,b42,b42,b42,b42,b42,__ZTv0_n24_NK5osgGA16OrbitManipulator5cloneERKN3osg6CopyOpE,__ZTv0_n28_NK5osgGA16OrbitManipulator12isSameKindAsEPKN3osg6ObjectE,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZNK3osg10RefMatrixd5cloneERKNS_6CopyOpE,__ZNK3osg10RefMatrixd12isSameKindAsEPKNS_6ObjectE,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZN7osgUtil27IncrementalCompileOperation17CompileDrawableOp7compileERNS0_11CompileInfoE,b42
,b42,b42,__ZN7osgUtil27IncrementalCompileOperation16CompileTextureOp7compileERNS0_11CompileInfoE,b42,b42,b42,__ZN7osgUtil27IncrementalCompileOperation16CompileProgramOp7compileERNS0_11CompileInfoE,b42,b42,__ZNK3osg11DummyObject5cloneERKNS_6CopyOpE,__ZNK3osg11DummyObject12isSameKindAsEPKNS_6ObjectE,b42,b42,b42,b42,b42,b42,__ZN7osgUtil22LineSegmentIntersector5cloneERNS_19IntersectionVisitorE,__ZN7osgUtil22LineSegmentIntersector5enterERKN3osg4NodeE,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZN7osgUtil14RayIntersector5cloneERNS_19IntersectionVisitorE,__ZN7osgUtil14RayIntersector5enterERKN3osg4NodeE,b42,b42,b42,b42,b42,b42,__ZN7osgUtil14RayIntersector10intersectsERKN3osg18BoundingSphereImplINS1_5Vec3fEEE,b42,b42,b42,__ZNK7osgUtil9SceneView5cloneERKN3osg6CopyOpE,__ZNK7osgUtil9SceneView12isSameKindAsEPKN3osg6ObjectE,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZNK7osgUtil16RenderStageCache5cloneERKN3osg6CopyOpE,__ZNK7osgUtil16RenderStageCache12isSameKindAsEPKN3osg6ObjectE,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,__ZNK3osg12PrimitiveSet12isSameKindAsEPKNS_6ObjectE,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZNK3osg13TemplateArrayIdLNS_5Array4TypeE8ELi1ELi5130EE5cloneERKNS_6CopyOpE
,b42,b42,b42,b42,b42,b42,b42,b42,__ZNK3osg13TemplateArrayIdLNS_5Array4TypeE8ELi1ELi5130EE14getDataPointerEj,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZNK3osg13TemplateArrayIfLNS_5Array4TypeE7ELi1ELi5126EE5cloneERKNS_6CopyOpE,b42,b42,b42,b42,b42,b42,b42,b42,__ZNK3osg13TemplateArrayIfLNS_5Array4TypeE7ELi1ELi5126EE14getDataPointerEj
,b42,b42,b42,b42,b42,b42,b42,__ZNK3osg10IndexArray12isSameKindAsEPKNS_6ObjectE,b42,b42,b42,b42,__ZNK3osg18TemplateIndexArrayIjLNS_5Array4TypeE6ELi1ELi5125EE5cloneERKNS_6CopyOpE,b42,b42,b42,b42,b42,b42,b42,b42,__ZNK3osg18TemplateIndexArrayIjLNS_5Array4TypeE6ELi1ELi5125EE14getDataPointerEj,b42,b42,b42,b42,__ZNK3osg18TemplateIndexArrayIjLNS_5Array4TypeE6ELi1ELi5125EE5indexEj,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,__ZNK3osg18TemplateIndexArrayIiLNS_5Array4TypeE3ELi1ELi5124EE5cloneERKNS_6CopyOpE,b42,b42,b42,b42,b42,b42,b42,b42,__ZNK3osg18TemplateIndexArrayIiLNS_5Array4TypeE3ELi1ELi5124EE14getDataPointerEj,b42,b42,b42,b42,__ZNK3osg18TemplateIndexArrayIiLNS_5Array4TypeE3ELi1ELi5124EE5indexEj,b42,b42,b42,b42,b42,__ZNK7osgUtil24PositionalStateContainer5cloneERKN3osg6CopyOpE,__ZNK7osgUtil24PositionalStateContainer12isSameKindAsEPKN3osg6ObjectE
,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZNK7osgUtil9RenderBin5cloneERKN3osg6CopyOpE,__ZNK7osgUtil9RenderBin12isSameKindAsEPKN3osg6ObjectE,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,__ZNK7osgUtil11RenderStage5cloneERKN3osg6CopyOpE,__ZNK7osgUtil11RenderStage12isSameKindAsEPKN3osg6ObjectE,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZNK3osg12BufferObject12isSameKindAsEPKNS_6ObjectE,b42,b42,b42,b42,b42,__ZNK3osg10BufferData12isSameKindAsEPKNS_6ObjectE,b42,b42,b42,b42,__ZNK3osg18VertexBufferObject5cloneERKNS_6CopyOpE,__ZNK3osg18VertexBufferObject12isSameKindAsEPKNS_6ObjectE,b42,b42,b42,b42,__ZNK3osg19ElementBufferObject5cloneERKNS_6CopyOpE,__ZNK3osg19ElementBufferObject12isSameKindAsEPKNS_6ObjectE
,b42,b42,b42,b42,__ZNK3osg17PixelBufferObject5cloneERKNS_6CopyOpE,__ZNK3osg17PixelBufferObject12isSameKindAsEPKNS_6ObjectE,b42,b42,b42,b42,b42,b42,__ZNK3osg6Camera5cloneERKNS_6CopyOpE,__ZNK3osg6Camera12isSameKindAsEPKNS_6ObjectE,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZN3osg5Group8addChildEPNS_4NodeE,b42,__ZN3osg5Group11removeChildEPNS_4NodeE,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZNK3osg9ColorMask5cloneERKNS_6CopyOpE,__ZNK3osg9ColorMask12isSameKindAsEPKNS_6ObjectE,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZNK3osg9ColorMask7compareERKNS_14StateAttributeE,__ZNK3osg14StateAttribute12getModeUsageERNS0_9ModeUsageE,__ZNK3osg14StateAttribute30checkValidityOfAssociatedModesERNS_5StateE,b42,b42,b42,b42,__ZNK3osg14StateAttribute12isSameKindAsEPKNS_6ObjectE,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZNK3osg6CopyOpclEPKNS_10ReferencedE,__ZNK3osg6CopyOpclEPKNS_6ObjectE,__ZNK3osg6CopyOpclEPKNS_4NodeE,__ZNK3osg6CopyOpclEPKNS_8DrawableE,__ZNK3osg6CopyOpclEPKNS_8StateSetE,__ZNK3osg6CopyOpclEPKNS_14StateAttributeE,__ZNK3osg6CopyOpclEPKNS_7TextureE,__ZNK3osg6CopyOpclEPKNS_5ImageE,__ZNK3osg6CopyOpclEPKNS_5ArrayE,__ZNK3osg6CopyOpclEPKNS_12PrimitiveSetE,__ZNK3osg6CopyOpclEPKNS_5ShapeE,__ZNK3osg6CopyOpclEPKNS_7UniformE,__ZNK3osg6CopyOpclEPKNS_8CallbackE,__ZNK3osg6CopyOpclEPKNS_22StateAttributeCallbackE,__ZNK3osg6CopyOpclEPKNS_15UniformCallbackE,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZNK3osg8Drawable5cloneERKNS_6CopyOpE,__ZNK3osg8Drawable12isSameKindAsEPKNS_6ObjectE,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,__ZNK3osg8Drawable22createVertexArrayStateERNS_10RenderInfoE,b42,b42,__ZNK3osg8Drawable8supportsERKNS0_16AttributeFunctorE,b42,__ZNK3osg8Drawable8supportsERKNS0_21ConstAttributeFunctorE,b42,__ZNK3osg8Drawable8supportsERKNS_16PrimitiveFunctorE,b42,__ZNK3osg8Drawable8supportsERKNS_21PrimitiveIndexFunctorE,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,__ZNK3osg12RenderBuffer5cloneERKNS_6CopyOpE,__ZNK3osg12RenderBuffer12isSameKindAsEPKNS_6ObjectE,b42,b42,b42,b42,b42,b42,b42,__ZNK3osg17FrameBufferObject5cloneERKNS_6CopyOpE,__ZNK3osg17FrameBufferObject12isSameKindAsEPKNS_6ObjectE,b42,b42,b42,b42,b42,__ZNK3osg17FrameBufferObject7compareERKNS_14StateAttributeE,b42,b42,b42,b42,b42,b42
,__ZNK3osg5Geode5cloneERKNS_6CopyOpE,__ZNK3osg5Geode12isSameKindAsEPKNS_6ObjectE,b42,b42,b42,b42,b42,b42,b42,b42,__ZN3osg5Geode11addDrawableEPNS_8DrawableE,__ZN3osg5Geode14removeDrawableEPNS_8DrawableE,b42,b42,b42,b42,b42,b42,__ZNK3osg8Geometry5cloneERKNS_6CopyOpE,__ZNK3osg8Geometry12isSameKindAsEPKNS_6ObjectE,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,__ZNK3osg8Geometry22createVertexArrayStateERNS_10RenderInfoE,b42,__ZNK3osg8Geometry8supportsERKNS_8Drawable16AttributeFunctorE,b42,__ZNK3osg8Geometry8supportsERKNS_8Drawable21ConstAttributeFunctorE,b42,__ZNK3osg8Geometry8supportsERKNS_16PrimitiveFunctorE,b42,__ZNK3osg8Geometry8supportsERKNS_21PrimitiveIndexFunctorE,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZNK3osg15GraphicsContext12isSameKindAsEPKNS_6ObjectE,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,__ZNK3osg5Group5cloneERKNS_6CopyOpE,__ZNK3osg5Group12isSameKindAsEPKNS_6ObjectE,b42,b42,b42,b42,b42,b42,b42,__ZNK3osg5Image5cloneERKNS_6CopyOpE,__ZNK3osg5Image12isSameKindAsEPKNS_6ObjectE,b42,b42,b42,b42,b42,b42,__ZNK3osg5Image7compareERKS0_,b42,b42,b42,b42
,b42,b42,b42,b42,b42,__ZN3osg5Image13sendFocusHintEb,b42,b42,b42,b42,__ZNK3osg22StateAttributeCallback5cloneERKNS_6CopyOpE,__ZNK3osg22StateAttributeCallback12isSameKindAsEPKNS_6ObjectE,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZTv0_n20_NK3osg22StateAttributeCallback5cloneERKNS_6CopyOpE,__ZTv0_n24_NK3osg22StateAttributeCallback12isSameKindAsEPKNS_6ObjectE,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,__ZTv0_n24_NK3osg22StateAttributeCallback5cloneERKNS_6CopyOpE,__ZTv0_n28_NK3osg22StateAttributeCallback12isSameKindAsEPKNS_6ObjectE,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZNK3osg6KdTree5cloneERKNS_6CopyOpE,__ZNK3osg6KdTree12isSameKindAsEPKNS_6ObjectE,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZNK3osg4Node5cloneERKNS_6CopyOpE,__ZNK3osg4Node12isSameKindAsEPKNS_6ObjectE,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE9pbackfailEi,b42,__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE8overflowEi,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,__ZNK3osg11PolygonMode5cloneERKNS_6CopyOpE,__ZNK3osg11PolygonMode12isSameKindAsEPKNS_6ObjectE,b42,b42,b42,__ZNK3osg11PolygonMode7compareERKNS_14StateAttributeE,b42,b42,b42,b42,__ZNK3osg14PolygonStipple5cloneERKNS_6CopyOpE,__ZNK3osg14PolygonStipple12isSameKindAsEPKNS_6ObjectE,b42,b42,b42,__ZNK3osg14PolygonStipple7compareERKNS_14StateAttributeE,__ZNK3osg14PolygonStipple12getModeUsageERNS_14StateAttribute9ModeUsageE,b42,b42,b42,b42,__ZNK3osg17DrawElementsUByte5cloneERKNS_6CopyOpE,__ZNK3osg17DrawElementsUByte12isSameKindAsEPKNS_6ObjectE,b42,b42
,b42,b42,b42,b42,b42,b42,__ZNK3osg17DrawElementsUByte5indexEj,b42,b42,b42,b42,b42,b42,__ZN3osg17DrawElementsUByte10getElementEj,b42,b42,b42,b42,b42,b42,__ZNK3osg18DrawElementsUShort5cloneERKNS_6CopyOpE,__ZNK3osg18DrawElementsUShort12isSameKindAsEPKNS_6ObjectE,b42,b42,b42,b42,b42,b42,b42,b42
,__ZNK3osg18DrawElementsUShort5indexEj,b42,b42,b42,b42,b42,b42,__ZN3osg18DrawElementsUShort10getElementEj,b42,b42,b42,b42,b42,b42,__ZNK3osg16DrawElementsUInt5cloneERKNS_6CopyOpE,__ZNK3osg16DrawElementsUInt12isSameKindAsEPKNS_6ObjectE,b42,b42,b42,b42,b42,b42,b42,b42,__ZNK3osg16DrawElementsUInt5indexEj,b42,b42,b42,b42,b42
,b42,__ZN3osg16DrawElementsUInt10getElementEj,b42,b42,b42,b42,b42,__ZNK3osg10DrawArrays5cloneERKNS_6CopyOpE,__ZNK3osg10DrawArrays12isSameKindAsEPKNS_6ObjectE,b42,b42,b42,b42,b42,b42,b42,__ZNK3osg10DrawArrays5indexEj,b42,b42,b42,b42,b42,b42,__ZNK3osg7Program5cloneERKNS_6CopyOpE,__ZNK3osg7Program12isSameKindAsEPKNS_6ObjectE,b42,b42,b42,b42,b42
,__ZNK3osg7Program7compareERKNS_14StateAttributeE,b42,b42,b42,b42,b42,b42,b42,b42,__ZNK3osg7Program17PerContextProgram10getInfoLogERNSt3__212basic_stringIcNS2_11char_traitsIcEENS2_9allocatorIcEEEE,__ZN3osg7Program17PerContextProgram20compileProgramBinaryERNS_5StateE,b42,b42,b42,b42,__ZNK3osg7Program13ProgramBinary5cloneERKNS_6CopyOpE,__ZNK3osg7Program13ProgramBinary12isSameKindAsEPKNS_6ObjectE,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,__ZNK3osg6Shader5cloneERKNS_6CopyOpE,__ZNK3osg6Shader12isSameKindAsEPKNS_6ObjectE,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZNK3osg5Shape12isSameKindAsEPKNS_6ObjectE,b42,b42,b42,b42,__ZNK3osg6Sphere5cloneERKNS_6CopyOpE,__ZNK3osg6Sphere12isSameKindAsEPKNS_6ObjectE,b42
,b42,b42,b42,b42,b42,b42,b42,b42,__ZNK3osg8StateSet5cloneERKNS_6CopyOpE,__ZNK3osg8StateSet12isSameKindAsEPKNS_6ObjectE,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZNK3osg7Stencil5cloneERKNS_6CopyOpE
,__ZNK3osg7Stencil12isSameKindAsEPKNS_6ObjectE,b42,b42,b42,__ZNK3osg7Stencil7compareERKNS_14StateAttributeE,__ZNK3osg7Stencil12getModeUsageERNS_14StateAttribute9ModeUsageE,b42,b42,b42,b42,__ZNK3osg6TexMat5cloneERKNS_6CopyOpE,__ZNK3osg6TexMat12isSameKindAsEPKNS_6ObjectE,b42,b42,b42,b42,__ZNK3osg6TexMat7compareERKNS_14StateAttributeE,b42,b42,b42,b42,__ZNK3osg9Texture2D5cloneERKNS_6CopyOpE,__ZNK3osg9Texture2D12isSameKindAsEPKNS_6ObjectE,b42,b42,b42,b42,b42,b42,b42
,b42,__ZNK3osg9Texture2D7compareERKNS_14StateAttributeE,b42,b42,b42,b42,b42,b42,b42,__ZN3osg9Texture2D8getImageEj,__ZNK3osg9Texture2D8getImageEj,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZNK3osg7Texture12isSameKindAsEPKNS_6ObjectE,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZNK3osg16TextureRectangle5cloneERKNS_6CopyOpE,__ZNK3osg16TextureRectangle12isSameKindAsEPKNS_6ObjectE,b42,b42,b42,__ZNK3osg16TextureRectangle7compareERKNS_14StateAttributeE,b42,b42,b42,b42,b42,b42,__ZN3osg16TextureRectangle8getImageEj,__ZNK3osg16TextureRectangle8getImageEj,b42,b42,b42,b42,b42,b42
,__ZNK3osg9Transform5cloneERKNS_6CopyOpE,__ZNK3osg9Transform12isSameKindAsEPKNS_6ObjectE,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZNK3osg7Uniform5cloneERKNS_6CopyOpE,__ZNK3osg7Uniform12isSameKindAsEPKNS_6ObjectE,b42,b42,b42,b42,b42,__ZNK3osg7Uniform7compareERKS0_,__ZNK3osg7Uniform11compareDataERKS0_,b42,b42,b42,b42,__ZNK3osg24DefaultUserDataContainer5cloneERKNS_6CopyOpE,__ZNK3osg24DefaultUserDataContainer12isSameKindAsEPKNS_6ObjectE
,b42,b42,b42,b42,b42,b42,b42,__ZN3osg24DefaultUserDataContainer13addUserObjectEPNS_6ObjectE,b42,b42,__ZN3osg24DefaultUserDataContainer13getUserObjectEj,__ZNK3osg24DefaultUserDataContainer13getUserObjectEj,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZNK3osg8Viewport5cloneERKNS_6CopyOpE,__ZNK3osg8Viewport12isSameKindAsEPKNS_6ObjectE,b42,b42,b42,__ZNK3osg8Viewport7compareERKNS_14StateAttributeE,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZNK3osg9BlendFunc5cloneERKNS_6CopyOpE
,__ZNK3osg9BlendFunc12isSameKindAsEPKNS_6ObjectE,b42,b42,b42,__ZNK3osg9BlendFunc7compareERKNS_14StateAttributeE,__ZNK3osg9BlendFunc12getModeUsageERNS_14StateAttribute9ModeUsageE,b42,b42,b42,b42,__ZNK3osg5Light5cloneERKNS_6CopyOpE,__ZNK3osg5Light12isSameKindAsEPKNS_6ObjectE,b42,b42,b42,b42,__ZNK3osg5Light7compareERKNS_14StateAttributeE,__ZNK3osg5Light12getModeUsageERNS_14StateAttribute9ModeUsageE,b42,b42,b42,b42,__ZNK3osg14ShaderComposer5cloneERKNS_6CopyOpE,__ZNK3osg14ShaderComposer12isSameKindAsEPKNS_6ObjectE,b42,b42,b42,__ZN3osg14ShaderComposer18getOrCreateProgramERKNSt3__26vectorIPNS_15ShaderComponentENS1_9allocatorIS4_EEEE,__ZN3osg14ShaderComposer11composeMainERKNSt3__26vectorIPKNS_6ShaderENS1_9allocatorIS5_EEEE,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZN11OpenThreads9Condition4waitEPNS_5MutexE,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,__ZNKSt3__210__function6__funcIZN4mjin11application6memory11Coordinator14setupSelectionEvE3__0NS_9allocatorIS6_EEFvRKbEE6targetERKSt9type_info,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZNKSt3__210__function6__funcIZN4mjin11application6memory4Game18matchSelectedItemsEvE3__1NS_9allocatorIS6_EEFvvEE6targetERKSt9type_info,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZNSt3__210__function6__funcIZN4mjin11application6memory4Game18animateMatchOrMissEbNS_8functionIFvvEEEE3__2NS_9allocatorIS9_EEFbdEEclEOd,__ZNKSt3__210__function6__funcIZN4mjin11application6memory4Game18animateMatchOrMissEbNS_8functionIFvvEEEE3__2NS_9allocatorIS9_EEFbdEE6targetERKSt9type_info,b42,b42,b42,b42
,b42,b42,b42,b42,__ZNKSt3__210__function6__funcIZN4mjin11application6memory4Game18matchSelectedItemsEvE3__0NS_9allocatorIS6_EEFvvEE6targetERKSt9type_info,b42,b42,b42,b42,__ZNK3osg17TessellationHints5cloneERKNS_6CopyOpE,__ZNK3osg17TessellationHints12isSameKindAsEPKNS_6ObjectE,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZN5osgDB13DatabasePager37DatabasePagerCompileCompletedCallback16compileCompletedEPN7osgUtil27IncrementalCompileOperation10CompileSetE,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,__ZNK20SetBasedPagedLODList16containsPagedLODERKN3osg12observer_ptrINS0_8PagedLODEEE,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZNK5osgDB8Registry18ReadArchiveFunctor7isValidERNS_12ReaderWriter10ReadResultE,__ZNK5osgDB8Registry18ReadArchiveFunctor7isValidEPN3osg6ObjectE,b42,b42,b42,__ZNK5osgDB8Registry17ReadObjectFunctor7isValidERNS_12ReaderWriter10ReadResultE,__ZNK5osgDB8Registry17ReadObjectFunctor7isValidEPN3osg6ObjectE,b42,b42,b42,__ZNK5osgDB8Registry16ReadImageFunctor7isValidERNS_12ReaderWriter10ReadResultE,__ZNK5osgDB8Registry16ReadImageFunctor7isValidEPN3osg6ObjectE,b42,b42,b42,__ZNK5osgDB8Registry22ReadHeightFieldFunctor7isValidERNS_12ReaderWriter10ReadResultE,__ZNK5osgDB8Registry22ReadHeightFieldFunctor7isValidEPN3osg6ObjectE
,b42,b42,b42,__ZNK5osgDB8Registry15ReadNodeFunctor7isValidERNS_12ReaderWriter10ReadResultE,__ZNK5osgDB8Registry15ReadNodeFunctor7isValidEPN3osg6ObjectE,b42,b42,b42,__ZNK5osgDB8Registry17ReadShaderFunctor7isValidERNS_12ReaderWriter10ReadResultE,__ZNK5osgDB8Registry17ReadShaderFunctor7isValidEPN3osg6ObjectE,b42,b42,b42,b42,b42,b42,b42,__ZNK5osgDB9FileCache29isFileAppropriateForFileCacheERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE,b42,__ZNK5osgDB9FileCache13existsInCacheERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,__ZNK3osg13ShapeDrawable5cloneERKNS_6CopyOpE,__ZNK3osg13ShapeDrawable12isSameKindAsEPKNS_6ObjectE,b42,b42,b42,_GLES2_CreateRenderer,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,_SW_CreateRenderer,b42,b42,b42,b42,b42,b42,b42,_SDL_PromptAssertion,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE9pbackfailEj,b42,__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE8overflowEj,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZNSt3__211__stdoutbufIwE8overflowEj,b42,b42,b42,b42,b42,__ZNSt3__211__stdoutbufIcE8overflowEi,b42,b42,b42,b42,b42,__ZNSt3__210__stdinbufIwE9pbackfailEj,b42,b42,b42,b42,b42,__ZNSt3__210__stdinbufIcE9pbackfailEi
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,__ZNKSt3__25ctypeIcE10do_toupperEc,b42,__ZNKSt3__25ctypeIcE10do_tolowerEc,b42,__ZNKSt3__25ctypeIcE8do_widenEc,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,__ZNKSt3__25ctypeIwE10do_toupperEw,b42,__ZNKSt3__25ctypeIwE10do_tolowerEw,b42,__ZNKSt3__25ctypeIwE8do_widenEc,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZNKSt3__26locale9use_facetERNS0_2idE,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc
,b42,b42,b42,b42,b42,b42,__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEPKv,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,__ZN3osg7Matrixd10invert_4x3ERKS0_,__ZN3osg7Matrixd10invert_4x4ERKS0_,b42,b42,b42,b42,b42,b42,b42,b42,__ZN7osgUtil22LineSegmentIntersector12IntersectionaSERKS1_,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZNK3osg16ObserverNodePath11getNodePathERNSt3__26vectorIPNS_4NodeENS1_9allocatorIS4_EEEE,b42,b42
,b42,__ZN3osglsERNSt3__213basic_ostreamIcNS0_11char_traitsIcEEEERKNS_7MatrixdE,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERi,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,__ZNKSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEbEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE4findIS7_EENS_21__tree_const_iteratorIS8_PNS_11__tree_nodeIS8_PvEEiEERKT_,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZN3osg4View18findSlaveForCameraEPNS_6CameraE,b42,b42,__ZNK7osgUtil14RayIntersector12Intersection16getTextureLookUpERN3osg5Vec3fE,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEaSERKS5_,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZN3osg8Geometry15addPrimitiveSetEPNS_12PrimitiveSetE,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZN7osgUtil9SceneView8getStatsERNS_10StatisticsE,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZN3osg5cloneIN5osgGA15GUIEventAdapter9TouchDataEEEPT_PKS4_RKNS_6CopyOpE,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZNK3osg12observer_ptrINS_5GroupEE4lockERNS_7ref_ptrIS1_EE,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,__ZN3osg5cloneIN7osgUtil11RenderStageEEEPT_PKS3_RKNS_6CopyOpE,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZN3osg10RenderInfoaSERKS0_,b42,__ZN7osgUtil10StateGraph14find_or_insertEPKN3osg8StateSetE,b42,b42,b42,b42,b42,b42,b42
,b42,__ZN3osg5State14applyAttributeEPKNS_14StateAttributeE,b42,b42,b42,b42,b42,b42,b42,__ZN3osg7Uniform3setERKNS_7MatrixdE,b42,b42,__ZNK7osgUtil14ShaderGenCache14createStateSetEi,b42,b42,b42,b42,b42,b42,b42,b42,__ZN3osg7Program9addShaderEPNS_6ShaderE,b42,__ZN3osg9CullStack19createOrReuseMatrixERKNS_7MatrixdE,__ZN3osg10CullingSet8isCulledERKNS_18BoundingSphereImplINS_5Vec3fEEE,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,__ZNSt3__23mapINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7ref_ptrIN7osgUtil9RenderBinEEENS_4lessIS6_EENS4_INS_4pairIKS6_SB_EEEEEixERSF_,b42,b42,b42,b42,b42,b42,b42,__ZN3osg15GraphicsContext18makeContextCurrentEPS0_,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,__ZNSt3__23mapINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES6_NS_4lessIS6_EENS4_INS_4pairIKS6_S6_EEEEEixERSA_,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZNSt3__23mapIN3osg19BufferObjectProfileENS1_7ref_ptrINS1_17GLBufferObjectSetEEENS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S5_EEEEEixERSA_,b42,b42,b42,b42,b42,__ZN3osg12GLExtensions3GetEjb
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZNK3osg8Geometry12getArrayListERNSt3__26vectorINS_7ref_ptrINS_5ArrayEEENS1_9allocatorIS5_EEEE,b42,b42,b42,__ZNK3osg12BufferObject25getOrCreateGLBufferObjectEj,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,__ZNSt3__26__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EENS4_IS6_EEE4findIS6_EENS_15__tree_iteratorIS6_PNS_11__tree_nodeIS6_PvEEiEERKT_,__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZN3osg15GraphicsContext25WindowingSystemInterfaces27getWindowingSystemInterfaceERKNSt3__212basic_stringIcNS2_11char_traitsIcEENS2_9allocatorIcEEEE,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZN3osg5cloneINS_6KdTreeEEEPT_PKS2_RKNS_6CopyOpE,b42,b42,b42,b42,b42,b42,b42,__ZN3osg5cloneINS_17UserDataContainerEEEPT_PKS2_RKNS_6CopyOpE,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZN3osg6Shader16removeProgramRefEPNS_7ProgramE,b42,__ZN3osg14buffered_valueINS_7ref_ptrINS_7Program14ProgramObjectsEEEEixEj,b42,__ZN3osg7Program14ProgramObjects23createPerContextProgramERKNSt3__212basic_stringIcNS2_11char_traitsIcEENS2_9allocatorIcEEEE,b42,b42,b42,b42,b42,__ZNK3osg6Shader6getPCSERNS_5StateE,b42,b42,__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi,b42,b42,__ZNSt3__23mapINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7Program13ActiveVarInfoENS_4lessIS6_EENS4_INS_4pairIKS6_S9_EEEEEixERSD_,b42,b42
,b42,__ZNSt3__23mapINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEjNS_4lessIS6_EENS4_INS_4pairIKS6_jEEEEEixERSA_,b42,b42,b42,b42,b42,b42,__ZN3osg14buffered_valueINS_7ref_ptrINS_6Shader13ShaderObjectsEEEEixEj,__ZN3osg5State26supportsShaderRequirementsERKNSt3__23setINS1_12basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEENS1_4lessIS8_EENS6_IS8_EEEE,__ZN3osg6Shader13ShaderObjects22createPerContextShaderERKNSt3__212basic_stringIcNS2_11char_traitsIcEENS2_9allocatorIcEEEE,b42,__ZNK3osg5State38convertVertexShaderSourceToOsgBuiltInsERNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZN3osg8Geometry16getTexCoordArrayEj,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZNSt3__23mapINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg5State11DefineStackENS_4lessIS6_EENS4_INS_4pairIKS6_S9_EEEEEixERSD_,b42,b42
,b42,b42,__ZN3osg7Uniform3setERKNS_15Matrix3TemplateIfEE,b42,b42,b42,b42,b42,__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKc,b42,b42,b42,b42,b42,b42,b42,__ZNSt3__23mapINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4pairIN3osg7ref_ptrINS8_7UniformEEEjEENS_4lessIS6_EENS4_INS7_IKS6_SC_EEEEEixERSF_,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,__ZNSt3__23mapINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEdNS_4lessIS6_EENS4_INS_4pairIKS6_dEEEEEixERSA_,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZN3osg20TextureObjectManager19getTextureObjectSetERKNS_7Texture14TextureProfileE,b42,b42,b42,b42,b42,b42,_clock_gettime__wrapper,b42,b42,__ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEjEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE4findIS7_EENS_15__tree_iteratorIS8_PNS_11__tree_nodeIS8_PvEEiEERKT_,b42,b42,b42,b42,__ZNK3osg7Uniform16isCompatibleTypeENS0_4TypeE,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZNSt3__23mapINS_6vectorIPN3osg15ShaderComponentENS_9allocatorIS4_EEEENS2_7ref_ptrINS2_7ProgramEEENS_4lessIS7_EENS5_INS_4pairIKS7_SA_EEEEEixERSE_,__ZNSt3__23mapINS_6vectorIPKN3osg6ShaderENS_9allocatorIS5_EEEENS2_7ref_ptrIS3_EENS_4lessIS8_EENS6_INS_4pairIKS8_SA_EEEEEixERSE_,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZN3osg7ref_ptrINS_4NodeEEaSINS_5GroupEEERS2_RKNS0_IT_EE,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZN3osg5Group8getChildEj,b42,b42,__ZN3osg7ref_ptrINS_5GroupEEaSEPS1_,b42,b42,b42,b42,b42,b42,__ZNSt3__28functionIFbdEEaSIZN4mjin11application6memory4Game18animateMatchOrMissEbNS0_IFvvEEEE3__2EENS_9enable_ifIXaasr10__callableINS_5decayIT_E4typeEEE5valuentsr7is_sameINS_16remove_referenceISD_E4typeES2_EE5valueERS2_E4typeEOSD_,b42,b42,b42,b42,b42,__ZN4mjin11application6memory6render14createMaterialENSt3__212basic_stringIcNS3_11char_traitsIcEENS3_9allocatorIcEEEES9_,b42
,__ZN3osg8StateSet10getUniformERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE,__ZN3osg7Uniform3setERKNS_5Vec3fE,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZNK3osg12observer_ptrIN7osgUtil27IncrementalCompileOperation10CompileSetEE4lockERNS_7ref_ptrIS3_EE,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZN7osgUtil27IncrementalCompileOperation15requiresCompileERNS_14StateToCompileE,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEb,__ZNK3osg12observer_ptrINS_8PagedLODEE4lockERNS_7ref_ptrIS1_EE,b42,__ZNSt3__26__treeIN3osg12observer_ptrINS1_8PagedLODEEENS_4lessIS4_EENS_9allocatorIS4_EEE14__erase_uniqueIS4_EEjRKT_,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZN3osg5cloneIN5osgDB7OptionsEEEPT_PKS3_RKNS_6CopyOpE,__ZNSt3__23mapINS_4pairINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7ref_ptrIKN5osgDB7OptionsEEEEENS1_INS9_INS8_6ObjectEEEdEENSA_11ObjectCache9ClassCompENS5_INS1_IKSE_SH_EEEEEixERSK_,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES7_EENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE4findIS7_EENS_15__tree_iteratorIS8_PNS_11__tree_nodeIS8_PvEEiEERKT_,b42,b42,__ZN5osgDB8Registry11loadLibraryERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,__ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7ref_ptrIN5osgDB7ArchiveEEEEENS_19__map_value_compareIS7_SD_NS_4lessIS7_EELb1EEENS5_ISD_EEE4findIS7_EENS_15__tree_iteratorISD_PNS_11__tree_nodeISD_PvEEiEERKT_,b42,__ZNSt3__23mapINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN3osg7ref_ptrIN5osgDB7ArchiveEEENS_4lessIS6_EENS4_INS_4pairIKS6_SB_EEEEEixERSF_,b42,b42,__ZN5osgDB8Registry27getReaderWriterForExtensionERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE,b42,b42,b42,b42,b42,b42,__ZNSt3__23mapINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN5osgDB9IntLookupENS_4lessIS6_EENS4_INS_4pairIKS6_S8_EEEEEixERSC_,b42,b42,__ZNSt3__23mapINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEiNS_4lessIS6_EENS4_INS_4pairIKS6_iEEEEEixERSA_,b42,b42
,b42,_dlopen__wrapper,b42,b42,b42,b42,b42,b42,__ZNK5osgDB9FileCache25removeFileFromBlackListedERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE,b42,b42,b42,b42,b42,b42,b42,__ZN5osgDB8FileList10removeFileERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE,__ZN5osgDB8Registry20isProtocolRegisteredERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE,b42,b42,b42,b42,b42,__ZN5osgDB20equalCaseInsensitiveERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEES8_,b42,__ZNKSt3__26__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EENS4_IS6_EEE14__count_uniqueIS6_EEjRKT_,b42,b42,b42,b42
,b42,b42,_GLES2_CreateTexture,b42,b42,b42,b42,_GLES2_SetRenderTarget,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,_GLES2_UnbindTexture,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,_RemovePendingResizedEvents,_RemovePendingSizeChangedEvents,_RemovePendingMoveEvents,_RemovePendingExposedEvents,_cmpmodes,b42,b42,_SW_CreateTexture,_SW_SetTextureColorMod,_SW_SetTextureAlphaMod,_SW_SetTextureBlendMode,b42,b42,b42,_SW_SetRenderTarget,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,_Emscripten_CreateWindow,b42,b42,b42,b42
,b42,b42,b42,_Emscripten_GLES_LoadLibrary,_SDL_EGL_GetProcAddress,b42,_Emscripten_GLES_CreateContext,b42,_SDL_EGL_SetSwapInterval,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,_eglDestroyContext__wrapper,b42,_eglDestroySurface__wrapper,b42,_eglSwapBuffers__wrapper,_eglSwapInterval__wrapper,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,_SDL_GameControllerEventWatcher,b42,b42,_SDL_RendererEventWatch,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,_emscripten_glGetUniformLocation__wrapper,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,_emscripten_glGetAttribLocation__wrapper,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,_isxdigit_l,_isdigit_l,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42,b42
,b42,b42,b42];
var FUNCTION_TABLE_diii = [b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,__ZNK3osg11NodeVisitor21getDistanceToEyePointERKNS_5Vec3fEb,__ZNK3osg11NodeVisitor23getDistanceFromEyePointERKNS_5Vec3fEb,__ZNK3osg11NodeVisitor22getDistanceToViewPointERKNS_5Vec3fEb,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,__ZNK7osgUtil19IntersectionVisitor21getDistanceToEyePointERKN3osg5Vec3fEb,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,__ZNK7osgUtil11CullVisitor21getDistanceToEyePointERKN3osg5Vec3fEb,__ZNK7osgUtil11CullVisitor23getDistanceFromEyePointERKN3osg5Vec3fEb,__ZNK7osgUtil11CullVisitor22getDistanceToViewPointERKN3osg5Vec3fEb,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,__ZNK3osg23CollectOccludersVisitor21getDistanceToEyePointERKNS_5Vec3fEb,__ZNK3osg23CollectOccludersVisitor23getDistanceFromEyePointERKNS_5Vec3fEb,__ZNK3osg23CollectOccludersVisitor22getDistanceToViewPointERKNS_5Vec3fEb,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,__ZNSt3__215__num_get_floatIeEET_PKcS3_Rj,b43,__ZNSt3__215__num_get_floatIdEET_PKcS3_Rj,__ZNSt3__215__num_get_floatIfEET_PKcS3_Rj
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43,b43
,b43,b43,b43];
var FUNCTION_TABLE_viiiiiiiiiii = [b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,__ZN3osg5Image8setImageEiiiijjPhNS0_14AllocationModeEii,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,_SDL_BlendLine_RGB2,_SDL_BlendLine_RGB565,_SDL_BlendLine_RGB555,_SDL_BlendLine_RGB888,_SDL_BlendLine_ARGB8888,_SDL_BlendLine_RGB4,_SDL_BlendLine_RGBA4,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44,b44
,b44,b44,b44];
var FUNCTION_TABLE_dii = [b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,__ZNK7osgUtil27IncrementalCompileOperation17CompileDrawableOp23estimatedTimeForCompileERNS0_11CompileInfoE,b45,b45
,b45,__ZNK7osgUtil27IncrementalCompileOperation16CompileTextureOp23estimatedTimeForCompileERNS0_11CompileInfoE,b45,b45,b45,__ZNK7osgUtil27IncrementalCompileOperation16CompileProgramOp23estimatedTimeForCompileERNS0_11CompileInfoE,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,__Z21computePolytopeVolumeRKNSt3__26vectorINS_4pairIjN3osg5Vec3fEEENS_9allocatorIS4_EEEES9_,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45
,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45,b45];
var FUNCTION_TABLE_viii = [b46,b46,b46,b46,__ZN4mjin3log6Logger6notifyEN3osg14NotifySeverityEPKc,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,__ZN9osgViewer4View12setStartTickEy,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,__ZN9osgViewer4View19StereoSlaveCallback11updateSlaveERN3osg4ViewERNS3_5SlaveE,b46,b46,b46,b46,b46
,b46,b46,b46,__ZNK29ViewerCoordinateFrameCallback18getCoordinateFrameERKN3osg5Vec3dE,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,__ZN9osgViewer6Viewer10getCamerasERNSt3__26vectorIPN3osg6CameraENS1_9allocatorIS5_EEEEb,__ZN9osgViewer6Viewer11getContextsERNSt3__26vectorIPN3osg15GraphicsContextENS1_9allocatorIS5_EEEEb,__ZN9osgViewer10ViewerBase10getWindowsERNSt3__26vectorIPNS_14GraphicsWindowENS1_9allocatorIS4_EEEEb,__ZN9osgViewer6Viewer13getAllThreadsERNSt3__26vectorIPN11OpenThreads6ThreadENS1_9allocatorIS5_EEEEb,__ZN9osgViewer6Viewer19getOperationThreadsERNSt3__26vectorIPN3osg15OperationThreadENS1_9allocatorIS5_EEEEb
,__ZN9osgViewer6Viewer9getScenesERNSt3__26vectorIPNS_5SceneENS1_9allocatorIS4_EEEEb,__ZN9osgViewer6Viewer8getViewsERNSt3__26vectorIPNS_4ViewENS1_9allocatorIS4_EEEEb,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,__ZN9osgViewer6Viewer12setStartTickEy,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,__ZThn104_N9osgViewer6Viewer12setStartTickEy,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,__ZN3osg13TemplateArrayINS_5Vec3fELNS_5Array4TypeE28ELi3ELi5126EE6acceptEjRNS_12ValueVisitorE,__ZNK3osg13TemplateArrayINS_5Vec3fELNS_5Array4TypeE28ELi3ELi5126EE6acceptEjRNS_17ConstValueVisitorE,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,__ZN3osg13TemplateArrayINS_5Vec2fELNS_5Array4TypeE27ELi2ELi5126EE6acceptEjRNS_12ValueVisitorE,__ZNK3osg13TemplateArrayINS_5Vec2fELNS_5Array4TypeE27ELi2ELi5126EE6acceptEjRNS_17ConstValueVisitorE,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,__ZN3osg13TemplateArrayINS_5Vec4fELNS_5Array4TypeE29ELi4ELi5126EE6acceptEjRNS_12ValueVisitorE,__ZNK3osg13TemplateArrayINS_5Vec4fELNS_5Array4TypeE29ELi4ELi5126EE6acceptEjRNS_17ConstValueVisitorE,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,__ZN5osgGA12EventHandlerclEPN3osg4NodeEPNS1_11NodeVisitorE,b46,b46,b46,b46,b46,b46,__ZN5osgGA12EventHandler5eventEPN3osg11NodeVisitorEPNS1_8DrawableE,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,__ZThn4_N5osgGA12EventHandler5eventEPN3osg11NodeVisitorEPNS1_8DrawableE,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,__ZN3osg12NodeCallbackclEPNS_4NodeEPNS_11NodeVisitorE,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,__ZN3osg21DrawableEventCallback5eventEPNS_11NodeVisitorEPNS_8DrawableE,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,__ZN22KeystoneUpdateCallback6updateEPN3osg11NodeVisitorEPNS0_8DrawableE,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,__ZN15EXTQuerySupport10beginQueryEjPN3osg5StateE,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,__ZN15ARBQuerySupport10beginQueryEjPN3osg5StateE,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,__ZN5osgGA17CameraManipulator19computeHomePositionEPKN3osg6CameraEb,b46,__ZN5osgGA19StandardManipulator4homeERKNS_15GUIEventAdapterERNS_16GUIActionAdapterE,b46,__ZN5osgGA19StandardManipulator4initERKNS_15GUIEventAdapterERNS_16GUIActionAdapterE,__ZN5osgGA16OrbitManipulator17setTransformationERKN3osg5Vec3dERKNS1_4QuatE,b46,__ZNK5osgGA16OrbitManipulator17getTransformationERN3osg5Vec3dERNS1_4QuatE,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,__ZN5osgGA19StandardManipulator18centerMousePointerERKNS_15GUIEventAdapterERNS_16GUIActionAdapterE,b46,b46,b46,b46,b46,b46,b46,b46,__ZN5osgGA16OrbitManipulator18setMinimumDistanceERKdb,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,__ZN5osgGA17CameraManipulator4homeERKNS_15GUIEventAdapterERNS_16GUIActionAdapterE,b46,__ZN5osgGA17CameraManipulator4initERKNS_15GUIEventAdapterERNS_16GUIActionAdapterE,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,__ZN7osgUtil22LineSegmentIntersector9intersectERNS_19IntersectionVisitorEPN3osg8DrawableE,b46,b46,b46,b46,b46,b46,b46,__ZN3osg24TemplatePrimitiveFunctorIN27LineSegmentIntersectorUtils16IntersectFunctorINS_5Vec3dEdEEE14setVertexArrayEjPKNS_5Vec2fE,__ZN3osg24TemplatePrimitiveFunctorIN27LineSegmentIntersectorUtils16IntersectFunctorINS_5Vec3dEdEEE14setVertexArrayEjPKNS_5Vec3fE
,__ZN3osg24TemplatePrimitiveFunctorIN27LineSegmentIntersectorUtils16IntersectFunctorINS_5Vec3dEdEEE14setVertexArrayEjPKNS_5Vec4fE,__ZN3osg24TemplatePrimitiveFunctorIN27LineSegmentIntersectorUtils16IntersectFunctorINS_5Vec3dEdEEE14setVertexArrayEjPKNS_5Vec2dE,__ZN3osg24TemplatePrimitiveFunctorIN27LineSegmentIntersectorUtils16IntersectFunctorINS_5Vec3dEdEEE14setVertexArrayEjPKS3_,__ZN3osg24TemplatePrimitiveFunctorIN27LineSegmentIntersectorUtils16IntersectFunctorINS_5Vec3dEdEEE14setVertexArrayEjPKNS_5Vec4dE,b46,b46,b46,b46,b46,b46,__ZN3osg24TemplatePrimitiveFunctorIN27LineSegmentIntersectorUtils16IntersectFunctorINS_5Vec3fEfEEE14setVertexArrayEjPKNS_5Vec2fE,__ZN3osg24TemplatePrimitiveFunctorIN27LineSegmentIntersectorUtils16IntersectFunctorINS_5Vec3fEfEEE14setVertexArrayEjPKS3_,__ZN3osg24TemplatePrimitiveFunctorIN27LineSegmentIntersectorUtils16IntersectFunctorINS_5Vec3fEfEEE14setVertexArrayEjPKNS_5Vec4fE,__ZN3osg24TemplatePrimitiveFunctorIN27LineSegmentIntersectorUtils16IntersectFunctorINS_5Vec3fEfEEE14setVertexArrayEjPKNS_5Vec2dE,__ZN3osg24TemplatePrimitiveFunctorIN27LineSegmentIntersectorUtils16IntersectFunctorINS_5Vec3fEfEEE14setVertexArrayEjPKNS_5Vec3dE,__ZN3osg24TemplatePrimitiveFunctorIN27LineSegmentIntersectorUtils16IntersectFunctorINS_5Vec3fEfEEE14setVertexArrayEjPKNS_5Vec4dE,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,__ZN7osgUtil14RayIntersector9intersectERNS_19IntersectionVisitorEPN3osg8DrawableE,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,__ZNK7osgUtil9SceneView38computeLeftEyeProjectionImplementationERKN3osg7MatrixdE,__ZNK7osgUtil9SceneView32computeLeftEyeViewImplementationERKN3osg7MatrixdE,__ZNK7osgUtil9SceneView39computeRightEyeProjectionImplementationERKN3osg7MatrixdE,__ZNK7osgUtil9SceneView33computeRightEyeViewImplementationERKN3osg7MatrixdE,b46,__ZN7osgUtil9SceneView19inheritCullSettingsERKN3osg12CullSettingsEj,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,__ZThn32_N7osgUtil9SceneView19inheritCullSettingsERKN3osg12CullSettingsEj,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,__ZN7osgUtil10Statistics14setVertexArrayEjPKN3osg5Vec2fE,__ZN7osgUtil10Statistics14setVertexArrayEjPKN3osg5Vec3fE,__ZN7osgUtil10Statistics14setVertexArrayEjPKN3osg5Vec4fE,__ZN7osgUtil10Statistics14setVertexArrayEjPKN3osg5Vec2dE,__ZN7osgUtil10Statistics14setVertexArrayEjPKN3osg5Vec3dE,__ZN7osgUtil10Statistics14setVertexArrayEjPKN3osg5Vec4dE,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,__ZN3osg12CullSettings19inheritCullSettingsERKS0_j,b46,b46,b46,b46,b46,b46,b46
,b46,__ZN3osg24TemplatePrimitiveFunctorI21ComputeNearFarFunctorI17GreaterComparatorEE14setVertexArrayEjPKNS_5Vec2fE,__ZN3osg24TemplatePrimitiveFunctorI21ComputeNearFarFunctorI17GreaterComparatorEE14setVertexArrayEjPKNS_5Vec3fE,__ZN3osg24TemplatePrimitiveFunctorI21ComputeNearFarFunctorI17GreaterComparatorEE14setVertexArrayEjPKNS_5Vec4fE,__ZN3osg24TemplatePrimitiveFunctorI21ComputeNearFarFunctorI17GreaterComparatorEE14setVertexArrayEjPKNS_5Vec2dE,__ZN3osg24TemplatePrimitiveFunctorI21ComputeNearFarFunctorI17GreaterComparatorEE14setVertexArrayEjPKNS_5Vec3dE,__ZN3osg24TemplatePrimitiveFunctorI21ComputeNearFarFunctorI17GreaterComparatorEE14setVertexArrayEjPKNS_5Vec4dE,b46,b46,b46,b46,b46,b46,__ZN3osg24TemplatePrimitiveFunctorI21ComputeNearFarFunctorI14LessComparatorEE14setVertexArrayEjPKNS_5Vec2fE,__ZN3osg24TemplatePrimitiveFunctorI21ComputeNearFarFunctorI14LessComparatorEE14setVertexArrayEjPKNS_5Vec3fE,__ZN3osg24TemplatePrimitiveFunctorI21ComputeNearFarFunctorI14LessComparatorEE14setVertexArrayEjPKNS_5Vec4fE,__ZN3osg24TemplatePrimitiveFunctorI21ComputeNearFarFunctorI14LessComparatorEE14setVertexArrayEjPKNS_5Vec2dE,__ZN3osg24TemplatePrimitiveFunctorI21ComputeNearFarFunctorI14LessComparatorEE14setVertexArrayEjPKNS_5Vec3dE,__ZN3osg24TemplatePrimitiveFunctorI21ComputeNearFarFunctorI14LessComparatorEE14setVertexArrayEjPKNS_5Vec4dE,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,__ZN3osg13TemplateArrayIdLNS_5Array4TypeE8ELi1ELi5130EE6acceptEjRNS_12ValueVisitorE,__ZNK3osg13TemplateArrayIdLNS_5Array4TypeE8ELi1ELi5130EE6acceptEjRNS_17ConstValueVisitorE,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,__ZN3osg13TemplateArrayIfLNS_5Array4TypeE7ELi1ELi5126EE6acceptEjRNS_12ValueVisitorE,__ZNK3osg13TemplateArrayIfLNS_5Array4TypeE7ELi1ELi5126EE6acceptEjRNS_17ConstValueVisitorE,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,__ZN3osg18TemplateIndexArrayIjLNS_5Array4TypeE6ELi1ELi5125EE6acceptEjRNS_12ValueVisitorE,__ZNK3osg18TemplateIndexArrayIjLNS_5Array4TypeE6ELi1ELi5125EE6acceptEjRNS_17ConstValueVisitorE,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,__ZN3osg18TemplateIndexArrayIiLNS_5Array4TypeE3ELi1ELi5124EE6acceptEjRNS_12ValueVisitorE,__ZNK3osg18TemplateIndexArrayIiLNS_5Array4TypeE3ELi1ELi5124EE6acceptEjRNS_17ConstValueVisitorE,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,__ZN7osgUtil24PositionalStateContainer22addPositionedAttributeEPN3osg10RefMatrixdEPKNS1_14StateAttributeE,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,__ZN7osgUtil9RenderBin4drawERN3osg10RenderInfoERPNS_10RenderLeafE,__ZN7osgUtil9RenderBin18drawImplementationERN3osg10RenderInfoERPNS_10RenderLeafE,b46,b46,b46,b46,b46,__ZN7osgUtil10RenderLeaf6renderERN3osg10RenderInfoEPS0_
,b46,b46,b46,b46,b46,b46,b46,b46,b46,__ZN7osgUtil11RenderStage4drawERN3osg10RenderInfoERPNS_10RenderLeafE,__ZN7osgUtil11RenderStage18drawImplementationERN3osg10RenderInfoERPNS_10RenderLeafE,b46,__ZN7osgUtil11RenderStage22addPositionedAttributeEPN3osg10RefMatrixdEPKNS1_14StateAttributeE,b46,__ZN7osgUtil11RenderStage19drawPreRenderStagesERN3osg10RenderInfoERPNS_10RenderLeafE,b46,__ZN7osgUtil11RenderStage20drawPostRenderStagesERN3osg10RenderInfoERPNS_10RenderLeafE,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,__ZN3osg5Group12childRemovedEjj,b46,b46,b46,b46,b46,b46,b46,b46,b46,__ZN3osg6Camera19inheritCullSettingsERKNS_12CullSettingsEj,b46,b46
,__ZThn144_N3osg6Camera19inheritCullSettingsERKNS_12CullSettingsEj,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,__ZNK3osg15DisplaySettings38computeLeftEyeProjectionImplementationERKNS_7MatrixdE,b46,__ZNK3osg15DisplaySettings39computeRightEyeProjectionImplementationERKNS_7MatrixdE,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,__ZN12ComputeBound14setVertexArrayEjPKN3osg5Vec2fE,__ZN12ComputeBound14setVertexArrayEjPKN3osg5Vec3fE,__ZN12ComputeBound14setVertexArrayEjPKN3osg5Vec4fE,__ZN12ComputeBound14setVertexArrayEjPKN3osg5Vec2dE,__ZN12ComputeBound14setVertexArrayEjPKN3osg5Vec3dE,__ZN12ComputeBound14setVertexArrayEjPKN3osg5Vec4dE,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,__ZN3osg5Image14UpdateCallbackclEPNS_14StateAttributeEPNS_11NodeVisitorE,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,__ZN3osg22StateAttributeCallbackclEPNS_14StateAttributeEPNS_11NodeVisitorE,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,__ZN3osg29TemplatePrimitiveIndexFunctorI25PrimitiveIndicesCollectorE14setVertexArrayEjPKNS_5Vec2fE,__ZN3osg29TemplatePrimitiveIndexFunctorI25PrimitiveIndicesCollectorE14setVertexArrayEjPKNS_5Vec3fE,__ZN3osg29TemplatePrimitiveIndexFunctorI25PrimitiveIndicesCollectorE14setVertexArrayEjPKNS_5Vec4fE,__ZN3osg29TemplatePrimitiveIndexFunctorI25PrimitiveIndicesCollectorE14setVertexArrayEjPKNS_5Vec2dE
,__ZN3osg29TemplatePrimitiveIndexFunctorI25PrimitiveIndicesCollectorE14setVertexArrayEjPKNS_5Vec3dE,__ZN3osg29TemplatePrimitiveIndexFunctorI25PrimitiveIndicesCollectorE14setVertexArrayEjPKNS_5Vec4dE,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,__ZN3osg21StandardNotifyHandler6notifyENS_14NotifySeverityEPKc
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,__ZNK3osg17DrawElementsUByte4drawERNS_5StateEb,b46,b46,b46,b46,b46,b46,b46,b46,__ZN3osg17DrawElementsUByte10setElementEjj,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,__ZNK3osg18DrawElementsUShort4drawERNS_5StateEb,b46,b46
,b46,b46,b46,b46,b46,b46,__ZN3osg18DrawElementsUShort10setElementEjj,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,__ZNK3osg16DrawElementsUInt4drawERNS_5StateEb,b46,b46,b46,b46,b46,b46,b46,b46
,__ZN3osg16DrawElementsUInt10setElementEjj,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,__ZNK3osg10DrawArrays4drawERNS_5StateEb,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,__ZN3osg9Texture2D8setImageEjPNS_5ImageE,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,__ZN3osg16TextureRectangle8setImageEjPNS_5ImageE,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,__ZN3osg24DefaultUserDataContainer13setUserObjectEjPNS_6ObjectE,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,__ZN25VertexAttribArrayDispatch19enable_and_dispatchERN3osg5StateEPKNS0_5ArrayE,b46,b46,__ZN25VertexAttribArrayDispatch8dispatchERN3osg5StateEPKNS0_5ArrayE,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,__ZN3osg14ShaderComposer18addShaderToProgramEPNS_7ProgramERKNSt3__26vectorIPKNS_6ShaderENS3_9allocatorIS7_EEEE
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,__ZN5osgDB13DatabasePager17registerPagedLODsEPN3osg4NodeEj,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,__ZNK5osgDB8Registry18ReadArchiveFunctor6doReadERNS_12ReaderWriterE,b46,b46,b46,b46,__ZNK5osgDB8Registry17ReadObjectFunctor6doReadERNS_12ReaderWriterE,b46,b46,b46,b46,__ZNK5osgDB8Registry16ReadImageFunctor6doReadERNS_12ReaderWriterE,b46,b46,b46,b46,__ZNK5osgDB8Registry22ReadHeightFieldFunctor6doReadERNS_12ReaderWriterE,b46,b46
,b46,b46,__ZNK5osgDB8Registry15ReadNodeFunctor6doReadERNS_12ReaderWriterE,b46,b46,b46,b46,__ZNK5osgDB8Registry17ReadShaderFunctor6doReadERNS_12ReaderWriterE,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,__ZNK5osgDB9FileCache19createCacheFileNameERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,__ZNKSt3__214error_category23default_error_conditionEi
,b46,b46,__ZNKSt3__219__iostream_category7messageEi,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,__ZNK3osg10Referenced24signalObserversAndDeleteEbb,b46,b46,b46,b46,b46,b46
,b46,b46,__ZN9osgViewer4ViewC1ERKS0_RKN3osg6CopyOpE,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,__ZN3osg11NodeVisitorC2ENS0_13TraversalModeE,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,__ZN3osg4ViewC1ERKS0_RKNS_6CopyOpE,b46,b46
,b46,__ZN3osg7Matrixd4multERKS0_S2_,b46,b46,b46,b46,b46,b46,b46,__ZN3osg19computeLocalToWorldERKNSt3__26vectorIPNS_4NodeENS0_9allocatorIS3_EEEEb,b46,__ZN7osgUtil19IntersectionVisitorC1EPNS_11IntersectorEPNS0_12ReadCallbackE,__ZNSt3__26__treeIN7osgUtil22LineSegmentIntersector12IntersectionENS_4lessIS3_EENS_9allocatorIS3_EEE14__assign_multiINS_21__tree_const_iteratorIS3_PNS_11__tree_nodeIS3_PvEEiEEEEvT_SG_,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,__ZN3osg11NodeVisitorC1ERKS0_RKNS_6CopyOpE,b46,b46,b46,b46,__ZN3osg19computeWorldToLocalERKNSt3__26vectorIPNS_4NodeENS0_9allocatorIS3_EEEEb,__ZNK3osg20CoordinateSystemNode27computeLocalCoordinateFrameERKNS_5Vec3dE
,b46,b46,b46,b46,__ZN3osg7Texture9setFilterENS0_15FilterParameterENS0_10FilterModeE,__ZN3osg7Texture7setWrapENS0_13WrapParameterENS0_8WrapModeE,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,__ZN3osg8StateSet12setAttributeEPNS_14StateAttributeEj,__ZN3osg8StateSet15removeAttributeENS_14StateAttribute4TypeEj
,b46,b46,b46,b46,__ZN3osg8StateSet20setAttributeAndModesEPNS_14StateAttributeEj,b46,__ZN3osg8StateSet7setModeEjj,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,__ZN9osgViewer6Viewer20reprojectPointerDataERN5osgGA15GUIEventAdapterES3_,b46,b46,b46,b46,b46,b46,b46,b46,b46,__ZN9osgViewer6ViewerC1ERKS0_RKN3osg6CopyOpE,b46,b46,__ZN9osgViewer10ViewerBaseC2ERKS0_,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,__ZNSt3__26__sortIRN3osg23CameraRenderOrderSortOpEPPNS1_6CameraEEEvT0_S7_T_,b46,b46,__ZN9osgViewer6Viewer24generateSlavePointerDataEPN3osg6CameraERN5osgGA15GUIEventAdapterE,b46,b46,b46,b46,b46,b46,b46,__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEjc,b46,__ZN5osgDB7OptionsC2ERKS0_RKN3osg6CopyOpE,b46,__ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEE14__assign_multiINS_21__tree_const_iteratorIjPNS_11__tree_nodeIjPvEEiEEEEvT_SD_,b46,__ZN11OpenThreads8AffinityC2Ejj,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,__ZN3osg13TemplateArrayINS_5Vec4fELNS_5Array4TypeE29ELi4ELi5126EEC2ERKS4_RKNS_6CopyOpE,b46,__ZN3osg13TemplateArrayINS_5Vec2fELNS_5Array4TypeE27ELi2ELi5126EEC2ERKS4_RKNS_6CopyOpE,b46,__ZN3osg13TemplateArrayINS_5Vec3fELNS_5Array4TypeE28ELi3ELi5126EEC2ERKS4_RKNS_6CopyOpE,b46,__ZN3osg6ObjectC2ERKS0_RKNS_6CopyOpE,b46,b46,b46,b46,b46,b46,b46,__ZN9osgViewer4View30assignStereoOrKeystoneToCameraEPN3osg6CameraEPNS1_15DisplaySettingsE,b46,b46
,__ZN5osgGA15GUIEventHandlerC1ERKS0_RKN3osg6CopyOpE,b46,b46,b46,b46,b46,b46,b46,b46,b46,__ZN3osg8Geometry13setColorArrayEPNS_5ArrayENS1_7BindingE,b46,b46,__ZNSt3__26vectorIN3osg5Vec3fENS_9allocatorIS2_EEE8__appendEjRKS2_,__ZNSt3__26vectorIN3osg5Vec2fENS_9allocatorIS2_EEE8__appendEjRKS2_,b46,b46,b46,b46,b46,b46,__ZN3osg6Object12setUserValueINSt3__212basic_stringIcNS2_11char_traitsIcEENS2_9allocatorIcEEEEEEvRKS8_RKT_,__ZN3osg19TemplateValueObjectINSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEEC2ERKS7_SA_,b46,b46,b46,b46,b46,b46,b46
,b46,__ZN7osgUtil9SceneView9setCameraEPN3osg6CameraEb,b46,b46,b46,b46,b46,b46,b46,b46,b46,__ZN5osgGA15GUIEventAdapterC2ERKS0_RKN3osg6CopyOpE,b46,b46,b46,b46,b46,__ZN5osgGA16OrbitManipulatorC2Ei,b46,__ZN5osgGA20TrackballManipulatorC1ERKS0_RKN3osg6CopyOpE,b46,b46,b46,__ZN5osgGA16OrbitManipulatorC1ERKS0_RKN3osg6CopyOpE,b46,b46,b46,b46,b46,b46
,b46,__ZN5osgGA19StandardManipulatorC2Ei,b46,__ZNSt3__2plIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_12basic_stringIT_T0_T1_EERKS9_PKS6_,__ZN3osg16ApplicationUsage23addKeyboardMouseBindingERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEES9_,b46,__ZN5osgGA19StandardManipulator15fixVerticalAxisERN3osg4QuatERKNS1_5Vec3dEb,b46,b46,b46,b46,__ZNSt3__2plIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_12basic_stringIT_T0_T1_EERKS9_SB_,b46,b46,b46,b46,b46,b46,b46,b46,b46,__ZN7osgUtil27IncrementalCompileOperation10CompileSet15buildCompileMapERNSt3__23setIPN3osg15GraphicsContextENS2_4lessIS6_EENS2_9allocatorIS6_EEEERNS_14StateToCompileE,b46,b46,__ZNK3osg6KdTree9intersectINS_24TemplatePrimitiveFunctorIN27LineSegmentIntersectorUtils16IntersectFunctorINS_5Vec3dEdEEEEEEvRT_RKNS0_6KdNodeE,b46,__ZNK3osg6KdTree9intersectINS_24TemplatePrimitiveFunctorIN27LineSegmentIntersectorUtils16IntersectFunctorINS_5Vec3fEfEEEEEEvRT_RKNS0_6KdNodeE,__ZNSt3__26vectorIPN3osg4NodeENS_9allocatorIS3_EEE6assignIPS3_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS3_NS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_,b46,b46
,__ZNSt3__26vectorIjNS_9allocatorIjEEE6assignIPjEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIjNS_15iterator_traitsIS7_E9referenceEEE5valueEvE4typeES7_S7_,__ZNSt3__26vectorIdNS_9allocatorIdEEE6assignIPdEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIdNS_15iterator_traitsIS7_E9referenceEEE5valueEvE4typeES7_S7_,__ZN7osgUtil9SceneViewC2ERKS0_RKN3osg6CopyOpE,b46,b46,b46,b46,b46,b46,b46,b46,b46,__ZN3osg9CullStack19pushModelViewMatrixEPNS_10RefMatrixdENS_9Transform14ReferenceFrameE,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,__ZN3osg7UniformC2EPKci,__ZN3osg8StateSet10addUniformEPNS_7UniformEj,__ZN3osg7Program21addBindAttribLocationERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEj,__ZN3osg6ShaderC2ENS0_4TypeERKNSt3__212basic_stringIcNS2_11char_traitsIcEENS2_9allocatorIcEEEE,b46,b46,b46,b46,b46,b46,b46,__ZN7osgUtil16RenderStageCache14setRenderStageEPN3osg10ReferencedEPNS_11RenderStageE,b46
,__ZN7osgUtil11RenderStage17addPreRenderStageEPS0_i,__ZN7osgUtil11RenderStage18addPostRenderStageEPS0_i,b46,b46,b46,b46,b46,b46,b46,b46,b46,__ZN7osgUtil16RenderStageCacheC2ERKS0_RKN3osg6CopyOpE,__ZN3osg8Polytope31setAndTransformProvidingInverseERKS0_RKNS_7MatrixdE,b46,__ZNSt3__26__treeINS_12__value_typeIdN7osgUtil11CullVisitor21MatrixPlanesDrawablesEEENS_19__map_value_compareIdS5_NS_4lessIdEELb1EEENS_9allocatorIS5_EEE16__construct_nodeERKNS_4pairIKdS4_EE,b46,b46,b46,b46,__ZN3osg13TemplateArrayIdLNS_5Array4TypeE8ELi1ELi5130EEC2ERKS3_RKNS_6CopyOpE,__ZN3osg13TemplateArrayIfLNS_5Array4TypeE7ELi1ELi5126EEC2ERKS3_RKNS_6CopyOpE,b46,__ZN3osg18TemplateIndexArrayIjLNS_5Array4TypeE6ELi1ELi5125EEC2ERKS3_RKNS_6CopyOpE,__ZN3osg18TemplateIndexArrayIiLNS_5Array4TypeE3ELi1ELi5124EEC2ERKS3_RKNS_6CopyOpE,b46,b46,b46,b46,__ZN3osg5State27haveAppliedTextureAttributeEjPKNS_14StateAttributeE,__ZN3osg5State32setGlobalDefaultTextureAttributeEjPKNS_14StateAttributeE
,__ZN7osgUtil9RenderBinC2ERKS0_RKN3osg6CopyOpE,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,__ZN7osgUtil11RenderStageC2ERKS0_RKN3osg6CopyOpE,b46,__ZN18DrawInnerOperationC1EPN7osgUtil11RenderStageERN3osg10RenderInfoE,b46,b46,b46,b46,b46,__ZN3osg17FrameBufferObject13setAttachmentENS_6Camera15BufferComponentERKNS_21FrameBufferAttachmentE,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,___cxa_throw__wrapper,b46,b46,b46,b46,b46,b46,__ZN3osg12BufferObject17setGLBufferObjectEjPNS_14GLBufferObjectE,b46,b46,b46,__ZN3osg12BufferObjectC2ERKS0_RKNS_6CopyOpE,b46,b46,b46,b46,b46,b46,__ZN3osg17GLBufferObjectSetC2EPNS_21GLBufferObjectManagerERKNS_19BufferObjectProfileE,__ZN3osg17GLBufferObjectSet14takeOrGenerateEPNS_12BufferObjectE,__ZN3osg17GLBufferObjectSet15takeFromOrphansEPNS_12BufferObjectE,b46,b46,b46
,__ZN3osg21GraphicsObjectManagerC2ERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEj,b46,b46,__ZN3osg6CameraC2ERKS0_RKNS_6CopyOpE,b46,b46,b46,b46,b46,b46,__ZN3osg14StateAttributeC2ERKS0_RKNS_6CopyOpE,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,__ZN3osg8DrawableC2ERKS0_RKNS_6CopyOpE,b46,b46,b46,__ZNSt3__26vectorIjNS_9allocatorIjEEE8__appendEjRKj,b46,__ZN3osg12RenderBufferC2ERKS0_RKNS_6CopyOpE,__ZN3osg17FrameBufferObjectC2ERKS0_RKNS_6CopyOpE,__ZNK3osg21FrameBufferAttachment44createRequiredTexturesAndApplyGenerateMipMapERNS_5StateEPKNS_12GLExtensionsE,b46,b46,__ZN3osg15GLObjectManagerC2ERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEj,b46,__ZN3osg5GroupC2ERKS0_RKNS_6CopyOpE,__ZN3osg8GeometryC2ERKS0_RKNS_6CopyOpE,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,__ZN21GeometryUtilFunctionsL14duplicateArrayERNSt3__26vectorINS0_4pairIN3osg7ref_ptrINS3_5ArrayEEES6_EENS0_9allocatorIS7_EEEERS6_j,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,__ZN3osg5ImageC2ERKS0_RKNS_6CopyOpE,b46,b46,b46,b46,b46,__ZN3osg6KdTreeC2ERKS0_RKNS_6CopyOpE,b46,b46,b46,b46,b46,b46,__ZN3osg4NodeC2ERKS0_RKNS_6CopyOpE,b46,b46,b46,b46,b46,b46,b46,b46
,__ZNSt3__26vectorIN3osg12observer_ptrINS1_4NodeEEENS_9allocatorIS4_EEE6assignIPS4_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS4_NS_15iterator_traitsISB_E9referenceEEE5valueEvE4typeESB_SB_,b46,__ZN3osg14OperationQueue16getNextOperationEb,b46,b46,b46,b46,b46,b46,__ZN3osg17DrawElementsUByteC2ERKS0_RKNS_6CopyOpE,b46,b46,__ZN3osg7ProgramC2ERKS0_RKNS_6CopyOpE,b46,b46,b46,b46,__ZNSt3__26vectorIN3osg7ref_ptrINS1_7Program14ProgramObjectsEEENS_9allocatorIS5_EEE8__appendEjRKS5_,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,__ZN3osg7Program13ProgramBinaryC2ERKS1_RKNS_6CopyOpE,__ZNSt3__26vectorIN3osg7ref_ptrINS1_7Program14ProgramObjectsEEENS_9allocatorIS5_EEEC2EjRKS5_
,__ZN3osg6ShaderC2ERKS0_RKNS_6CopyOpE,b46,b46,__ZNSt3__26vectorINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS4_IS6_EEE6assignIPS6_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS6_NS_15iterator_traitsISC_E9referenceEEE5valueEvE4typeESC_SC_,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,__ZNSt3__26vectorIN3osg7ref_ptrINS1_6Shader13ShaderObjectsEEENS_9allocatorIS5_EEE8__appendEjRKS5_,__ZN3osg6Shader16PerContextShaderC2EPKS0_j,b46,b46,b46,__ZNSt3__26vectorIN3osg7ref_ptrINS1_6Shader13ShaderObjectsEEENS_9allocatorIS5_EEEC2EjRKS5_,b46,b46,__ZN3osg6Shader19_parseShaderDefinesERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEERNS1_3setIS7_NS1_4lessIS7_EENS5_IS7_EEEE,b46,b46,b46,b46
,b46,b46,b46,__Z9transformRKNSt3__26vectorINS_4pairIjN3osg5Vec3fEEENS_9allocatorIS4_EEEERS7_RKNS2_7MatrixdE,b46,b46,b46,b46,__Z13computePlanesRKNSt3__26vectorINS_4pairIjN3osg5Vec3fEEENS_9allocatorIS4_EEEES9_RNS0_INS2_5PlaneENS5_ISA_EEEE,b46,b46,b46,b46,b46,__ZN3osg8Geometry14setNormalArrayEPNS_5ArrayENS1_7BindingE,b46,__ZNSt3__26vectorIPN3osg8StateSetENS_9allocatorIS3_EEE6assignIPS3_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS3_NS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_,b46,b46,b46,b46,b46,__ZN3osg5State25resetVertexAttributeAliasEbj,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,__ZN3osg8StateSetC2ERKS0_RKNS_6CopyOpE,b46,__ZNSt3__26vectorINS_3mapIjjNS_4lessIjEENS_9allocatorINS_4pairIKjjEEEEEENS4_IS9_EEE6assignIPS9_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS9_NS_15iterator_traitsISF_E9referenceEEE5valueEvE4typeESF_SF_,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,__ZN3osg9Texture2DC2ERKS0_RKNS_6CopyOpE,b46,b46,b46,b46,__ZNK3osg7Texture18applyTexParametersEjRNS_5StateE,b46,b46,b46,b46,b46,b46,b46,b46,__ZN3osg16TextureObjectSet15takeFromOrphansEPNS_7TextureE,b46,__ZN3osg16TextureObjectSet14takeOrGenerateEPNS_7TextureE,b46,b46,__ZN3osg16TextureRectangleC2ERKS0_RKNS_6CopyOpE,b46,b46,b46
,__ZN3osg7UniformC2ERKS0_RKNS_6CopyOpE,b46,b46,b46,b46,b46,b46,b46,__ZN3osg24DefaultUserDataContainerC2ERKS0_RKNS_6CopyOpE,b46,b46,b46,b46,b46,b46,b46,b46,b46,__ZN3osgL11extract4444EiPKvPf,__ZN3osgL9shove4444EPKfiPv,__ZN3osgL14extract4444revEiPKvPf,__ZN3osgL12shove4444revEPKfiPv,__ZN3osgL11extract5551EiPKvPf,__ZN3osgL9shove5551EPKfiPv,__ZN3osgL14extract1555revEiPKvPf,__ZN3osgL12shove1555revEPKfiPv,__ZN3osgL11extract8888EiPKvPf,__ZN3osgL9shove8888EPKfiPv,__ZN3osgL14extract8888revEiPKvPf,__ZN3osgL12shove8888revEPKfiPv
,__ZN3osgL14extract1010102EiPKvPf,__ZN3osgL12shove1010102EPKfiPv,__ZN3osgL17extract2101010revEiPKvPf,__ZN3osgL15shove2101010revEPKfiPv,__ZN3osgL10extract565EiPKvPf,__ZN3osgL8shove565EPKfiPv,__ZN3osgL13extract565revEiPKvPf,__ZN3osgL11shove565revEPKfiPv,__ZN3osg14ShaderComposerC2ERKS0_RKNS_6CopyOpE,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,__ZN4mjin11application6memory4GameC2EPN3osg6CameraEPNS1_8material4PoolE,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,__ZN4mjin11application6memory4Game18animateMatchOrMissEbNSt3__28functionIFvvEEE,b46,b46,b46,b46,b46,b46,b46,__ZN3osg7UniformC2EPKcRKNS_5Vec3fE
,b46,b46,b46,b46,b46,b46,b46,__ZN3osg13ShapeDrawableC2EPNS_5ShapeEPNS_17TessellationHintsE,b46,__ZN3osg17TessellationHintsC2ERKS0_RKNS_6CopyOpE,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,__ZN5osgDB13DatabasePager31FindCompileableGLObjectsVisitorC1EPKS0_PN3osg6ObjectE,b46,__ZN7osgUtil27IncrementalCompileOperation3addEPNS0_10CompileSetEb,b46,b46,__ZN5osgDB8Registry22_buildKdTreeIfRequiredERNS_12ReaderWriter10ReadResultEPKNS_7OptionsE,b46,__ZN5osgDB13DatabasePager12setUpThreadsEjj,b46,b46,b46
,__ZN5osgDB18SharedStateManager5shareEPN3osg4NodeEPN11OpenThreads5MutexE,b46,b46,__ZN5osgDB13DatabasePager9ReadQueueC2EPS0_RKNSt3__212basic_stringIcNS3_11char_traitsIcEENS3_9allocatorIcEEEE,b46,__ZN5osgDB13DatabasePager14DatabaseThreadC2ERKS1_PS0_,b46,b46,b46,b46,b46,b46,b46,b46,__ZN5osgDB16readRefImageFileERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEPKNS_7OptionsE,__ZN3osg13ImageSequence8setImageEjPNS_5ImageE,b46,b46,__ZNSt3__26__sortIRN5osgDB10ImagePager22SortFileRequestFunctorEPN3osg7ref_ptrINS2_12ImageRequestEEEEEvT0_SA_T_,b46,b46,__ZN5osgDB10ImagePager9ReadQueueC2EPS0_RKNSt3__212basic_stringIcNS3_11char_traitsIcEENS3_9allocatorIcEEEE,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,__ZNSt3__2plIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_12basic_stringIT_T0_T1_EEPKS6_RKS9_,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,__ZN5osgDB8Registry29createLibraryNameForExtensionERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE,b46,b46,b46,b46,b46,__ZNSt3__2plIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_12basic_stringIT_T0_T1_EERKS9_S6_
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,__ZNSt3__26__sortIRNS_6__lessIN5osgDB12ReaderWriter10ReadResultES4_EEPS4_EEvT0_S8_T_,b46,b46,b46,b46,b46,b46,b46,b46,__ZN5osgDB8Registry4readERKNS0_11ReadFunctorE,b46,b46,__ZNSt3__26__sortIRNS_6__lessIN5osgDB12ReaderWriter11WriteResultES4_EEPS4_EEvT0_S8_T_,b46,b46,__ZN5osgDB9IntLookup3addEPKci,b46,b46,b46,b46
,__ZN5osgDB14DynamicLibraryC2ERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEPv,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,__ZN3osg13ImageSequence9_setImageEjPNS_5ImageE,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,_Emscripten_WarpMouse,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,_emscripten_glGetTexParameterfv__wrapper,_emscripten_glGetTexParameteriv__wrapper,_emscripten_glTexParameterfv__wrapper,_emscripten_glTexParameteriv__wrapper,b46,b46,b46,_emscripten_glGetBufferParameteriv__wrapper,b46,b46,b46,b46,b46,b46,_emscripten_glGetRenderbufferParameteriv__wrapper,b46,_emscripten_glGetUniformfv__wrapper,_emscripten_glGetUniformiv__wrapper,b46,_emscripten_glGetVertexAttribfv__wrapper,_emscripten_glGetVertexAttribiv__wrapper,_emscripten_glGetVertexAttribPointerv__wrapper,b46,b46,b46,b46
,b46,b46,_emscripten_glUniform2i__wrapper,b46,b46,_emscripten_glUniform1iv__wrapper,_emscripten_glUniform2iv__wrapper,_emscripten_glUniform3iv__wrapper,_emscripten_glUniform4iv__wrapper,_emscripten_glUniform1fv__wrapper,_emscripten_glUniform2fv__wrapper,_emscripten_glUniform3fv__wrapper,_emscripten_glUniform4fv__wrapper,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,_emscripten_glGetShaderiv__wrapper,_emscripten_glGetProgramiv__wrapper,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,_emscripten_glBindAttribLocation__wrapper,b46,b46,b46,b46,b46,b46,b46,b46,_emscripten_glGetObjectParameterivARB__wrapper,b46,b46,b46,b46,b46,b46,b46
,_emscripten_glNormalPointer__wrapper,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,_emscripten_glDrawArrays__wrapper,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,_emscripten_glTexParameteri__wrapper,b46,b46,_emscripten_glStencilFunc__wrapper,_emscripten_glStencilOp__wrapper,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,__ZNSt3__28ios_base7failureC2EPKcRKNS_10error_codeE,__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE6sentryC2ERS3_b,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,__ZNSt3__219__double_or_nothingIcEEvRNS_10unique_ptrIT_PFvPvEEERPS2_S9_,__ZNSt3__219__double_or_nothingIjEEvRNS_10unique_ptrIT_PFvPvEEERPS2_S9_,b46,b46,b46,b46,b46,b46,__ZNSt3__219__double_or_nothingIwEEvRNS_10unique_ptrIT_PFvPvEEERPS2_S9_,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,__ZNSt3__212_GLOBAL__N_19as_stringINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPFiPcjPKczEjEET_T0_SD_PKNSD_10value_typeET1_,__ZNSt3__212system_error6__initERKNS_10error_codeENS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46,b46
,b46,b46,b46];
var FUNCTION_TABLE_i = [b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,_Emscripten_Available,b47,b47,_DUMMY_Available,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,__ZN3osg15DisplaySettings8instanceEv,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,__ZN3osg5Timer8instanceEv,b47,__ZN3osg15GraphicsContext15getMaxContextIDEv,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,__ZN11OpenThreads21GetNumberOfProcessorsEv,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,__ZN3osg16ApplicationUsage8instanceEv,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,__ZN5osgDB13DatabasePager6createEv,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,_glGetError__wrapper,b47,b47,b47,b47,b47,__ZN3osg15GraphicsContext28getWindowingSystemInterfacesEv,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,__ZN11OpenThreads6Thread18YieldCurrentThreadEv,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,__ZN3osg14getNotifyLevelEv,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,__Z20createDefaultTexturev,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,_rand,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,_osgGetVersion,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,_dlerror__wrapper,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,___errno_location,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,_eglWaitGL__wrapper,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,_emscripten_glCreateProgram__wrapper,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,_emscripten_glGetError__wrapper,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,__ZNSt3__26__clocEv,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,___ctype_get_mb_cur_max,b47,___ctype_tolower_loc,___ctype_toupper_loc,___ctype_b_loc,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,__ZNSt3__26locale5__imp12make_classicEv,__ZNSt3__26locale5__imp11make_globalEv,__ZNSt3__26locale8__globalEv,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,___cxa_get_globals_fast,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47,b47
,b47,b47,b47];
var FUNCTION_TABLE_iiiiidii = [b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,_GLES2_RenderCopyEx,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,_SW_RenderCopyEx,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
,b48,b48,b48];
var FUNCTION_TABLE_iiiid = [b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,__ZN3osg5Stats12setAttributeEjRKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEd,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49
,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49,b49];
var FUNCTION_TABLE_iiiii = [b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,__ZN5osgGA16GUIActionAdapter20computeIntersectionsERKNS_15GUIEventAdapterERNSt3__28multisetIN7osgUtil22LineSegmentIntersector12IntersectionENS4_4lessIS8_EENS4_9allocatorIS8_EEEEj,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,__ZN9osgViewer4View20computeIntersectionsERKN5osgGA15GUIEventAdapterERNSt3__28multisetIN7osgUtil22LineSegmentIntersector12IntersectionENS5_4lessIS9_EENS5_9allocatorIS9_EEEEj,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,__ZThn36_N9osgViewer4View20computeIntersectionsERKN5osgGA15GUIEventAdapterERNSt3__28multisetIN7osgUtil22LineSegmentIntersector12IntersectionENS5_4lessIS9_EENS5_9allocatorIS9_EEEEj,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,__ZN5osgGA15GUIEventHandler6handleEPNS_5EventEPN3osg6ObjectEPNS3_11NodeVisitorE,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,__ZN5osgGA12EventHandler6handleEPNS_5EventEPN3osg6ObjectEPNS3_11NodeVisitorE,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,__ZNK3osg20DrawableCullCallback4cullEPNS_11NodeVisitorEPNS_8DrawableEPNS_5StateE,__ZNK20KeystoneCullCallback4cullEPN3osg11NodeVisitorEPNS0_8DrawableEPNS0_10RenderInfoE,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,__ZN5osgGA17CameraManipulator6handleEPNS_5EventEPN3osg6ObjectEPNS3_11NodeVisitorE,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,__ZNK7osgUtil11CullVisitor35clampProjectionMatrixImplementationERN3osg7MatrixfERdS4_,__ZNK7osgUtil11CullVisitor35clampProjectionMatrixImplementationERN3osg7MatrixdERdS4_,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,__ZN3osg5Image16sendPointerEventEiii,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,__ZNKSt3__25ctypeIcE8do_widenEPKcS3_Pc,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,__ZNKSt3__25ctypeIwE5do_isEPKwS3_Pt,__ZNKSt3__25ctypeIwE10do_scan_isEtPKwS3_,__ZNKSt3__25ctypeIwE11do_scan_notEtPKwS3_,b50,b50,b50,b50,b50,__ZNKSt3__25ctypeIwE8do_widenEPKcS3_Pw,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,__ZNK3osg9Billboard13computeMatrixERNS_7MatrixdERKNS_5Vec3fES5_,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,__ZN3osg8StateSet18getOrCreateUniformERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEENS_7Uniform4TypeEj,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7compareEjjPKc,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,__Z4clipRKN3osg5PlaneERKNSt3__26vectorINS3_4pairIjNS_5Vec3fEEENS3_9allocatorIS7_EEEERSA_j,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6insertEjPKcj,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,_GLES2_RenderCopy,b50,b50,b50,b50,b50,_GLES2_BindTexture,b50,b50,b50,b50,_SDL_SoftBlit,b50,b50,_SDL_RLEBlit,b50
,b50,b50,b50,_SDL_RLEAlphaBlit,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,_SW_RenderCopy,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,_Emscripten_UpdateWindowFramebuffer,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,_eglGetConfigAttrib__wrapper,_eglCreateContext__wrapper,b50,_eglCreateWindowSurface__wrapper,b50,_eglMakeCurrent__wrapper,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,_EMSCRIPTENAUDIO_OpenDevice,b50,b50,b50,b50,b50,b50,b50,b50,_SDL_DUMMY_UpdateWindowFramebuffer,b50,b50,b50
,_stdio_seek,_stdio_read,_stdio_write,b50,_DISKAUDIO_OpenDevice,b50,b50,b50,b50,b50,b50,b50,_DUMMYAUDIO_OpenDevice,b50,b50,b50,_SDL_UpdateWindowTexture,b50,b50,b50,_SDL_AudioOpenDevice_Default,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,__ZNSt3__217__libcpp_sscanf_lEPKcP15__locale_structS1_z,b50,b50,b50,b50,b50,b50,b50,b50,b50
,__ZNSt3__227__num_get_unsigned_integralIyEET_PKcS3_Rji,__ZNSt3__227__num_get_unsigned_integralImEET_PKcS3_Rji,__ZNSt3__227__num_get_unsigned_integralIjEET_PKcS3_Rji,__ZNSt3__227__num_get_unsigned_integralItEET_PKcS3_Rji,__ZNSt3__225__num_get_signed_integralIxEET_PKcS3_Rji,__ZNSt3__225__num_get_signed_integralIlEET_PKcS3_Rji,b50,b50,b50,b50,b50,__ZNSt3__219__libcpp_asprintf_lEPPcP15__locale_structPKcz,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,_mbsrtowcs,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,_catgets,b50,b50
,b50,_mbrtowc,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,__ZNSt3__212_GLOBAL__N_110as_integerIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEEET_RKS7_RKT0_Pji,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
,b50,b50,b50];
var FUNCTION_TABLE_iidii = [b51];
var FUNCTION_TABLE_iiiiiiiiiiii = [b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,__ZNSt3__29money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE8__do_getERS4_S4_bRKNS_6localeEjRjRbRKNS_5ctypeIcEERNS_10unique_ptrIcPFvPvEEERPcSM_,b52,b52,b52,b52,b52,b52,b52,__ZNSt3__29money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE8__do_getERS4_S4_bRKNS_6localeEjRjRbRKNS_5ctypeIwEERNS_10unique_ptrIwPFvPvEEERPwSM_,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52,b52
,b52,b52,b52];
var FUNCTION_TABLE_vdddd = [b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,_glClearColor__wrapper,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,_emscripten_glRotatef__wrapper,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,_emscripten_glClearColor__wrapper,b53,b53,b53
,b53,b53,_emscripten_glBlendColor__wrapper,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53,b53
,b53,b53,b53];
var FUNCTION_TABLE_vdd = [b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,_emscripten_glDepthRange__wrapper,_emscripten_glDepthRangef__wrapper,b54,b54,_emscripten_glPolygonOffset__wrapper,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54,b54
,b54,b54,b54];
var FUNCTION_TABLE_v = [b55,b55,b55,b55,b55,b55,b55,___cxa_pure_virtual__wrapper,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,__ZL25default_terminate_handlerv,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,__ZN4mjin6player4quitEv,__ZN4mjin6player4loopEv,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,___cxa_end_catch__wrapper,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,___cxa_rethrow__wrapper,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,_glFlush__wrapper,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,_DISKAUDIO_DetectDevices,b55,b55,b55,b55,b55,b55,b55,_SDL_AudioDetectDevices_Default,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,_SDL_AudioDeinitialize_Default,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,_emscripten_glLoadIdentity__wrapper,b55,b55,b55,b55,b55,b55,b55,b55,b55,_emscripten_glReleaseShaderCompiler__wrapper,b55,b55,b55,b55,_emscripten_glFinish__wrapper,_emscripten_glFlush__wrapper,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,__ZSt17__throw_bad_allocv,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,__ZNSt3__2L10init_weeksEv,__ZNSt3__2L11init_monthsEv,__ZNSt3__2L10init_am_pmEv,b55,b55,b55,__ZNSt3__2L11init_wweeksEv,__ZNSt3__2L12init_wmonthsEv,__ZNSt3__2L11init_wam_pmEv,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,__ZNSt3__212_GLOBAL__N_14makeINS_7collateIcEEjEERT_T0_,b55,__ZNSt3__212_GLOBAL__N_14makeINS_7collateIwEEjEERT_T0_,b55,b55,__ZNSt3__212_GLOBAL__N_14makeINS_5ctypeIwEEjEERT_T0_,b55,__ZNSt3__212_GLOBAL__N_14makeINS_7codecvtIcc11__mbstate_tEEjEERT_T0_,b55,__ZNSt3__212_GLOBAL__N_14makeINS_7codecvtIwc11__mbstate_tEEjEERT_T0_,b55,__ZNSt3__212_GLOBAL__N_14makeINS_7codecvtIDsc11__mbstate_tEEjEERT_T0_,b55,__ZNSt3__212_GLOBAL__N_14makeINS_7codecvtIDic11__mbstate_tEEjEERT_T0_,b55,b55,b55,__ZNSt3__212_GLOBAL__N_14makeINS_7num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEjEERT_T0_,b55,__ZNSt3__212_GLOBAL__N_14makeINS_7num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEjEERT_T0_,b55
,__ZNSt3__212_GLOBAL__N_14makeINS_7num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEEjEERT_T0_,b55,__ZNSt3__212_GLOBAL__N_14makeINS_7num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEEjEERT_T0_,b55,__ZNSt3__212_GLOBAL__N_14makeINS_10moneypunctIcLb0EEEjEERT_T0_,b55,__ZNSt3__212_GLOBAL__N_14makeINS_10moneypunctIcLb1EEEjEERT_T0_,b55,__ZNSt3__212_GLOBAL__N_14makeINS_10moneypunctIwLb0EEEjEERT_T0_,b55,__ZNSt3__212_GLOBAL__N_14makeINS_10moneypunctIwLb1EEEjEERT_T0_,b55,__ZNSt3__212_GLOBAL__N_14makeINS_9money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEjEERT_T0_,b55,__ZNSt3__212_GLOBAL__N_14makeINS_9money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEjEERT_T0_,b55,__ZNSt3__212_GLOBAL__N_14makeINS_9money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEEjEERT_T0_,b55,__ZNSt3__212_GLOBAL__N_14makeINS_9money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEEjEERT_T0_,b55,__ZNSt3__212_GLOBAL__N_14makeINS_8time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEjEERT_T0_,b55,__ZNSt3__212_GLOBAL__N_14makeINS_8time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEjEERT_T0_,b55,__ZNSt3__212_GLOBAL__N_14makeINS_8time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEEjEERT_T0_,b55,__ZNSt3__212_GLOBAL__N_14makeINS_8time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEEjEERT_T0_,b55,__ZNSt3__212_GLOBAL__N_14makeINS_8messagesIcEEjEERT_T0_,b55
,__ZNSt3__212_GLOBAL__N_14makeINS_8messagesIwEEjEERT_T0_,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,__ZN10__cxxabiv112_GLOBAL__N_110construct_Ev,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55,b55
,b55,b55,b55];
var FUNCTION_TABLE_iiiiiiiii = [b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjP2tmcc,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjP2tmcc,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,__ZNKSt3__27codecvtIDic11__mbstate_tE6do_outERS1_PKDiS5_RS5_PcS7_RS7_,__ZNKSt3__27codecvtIDic11__mbstate_tE5do_inERS1_PKcS5_RS5_PDiS7_RS7_,b56,b56,b56,b56,b56,b56,b56,b56,__ZNKSt3__27codecvtIwc11__mbstate_tE6do_outERS1_PKwS5_RS5_PcS7_RS7_,__ZNKSt3__27codecvtIwc11__mbstate_tE5do_inERS1_PKcS5_RS5_PwS7_RS7_,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,__ZNKSt3__27codecvtIcc11__mbstate_tE6do_outERS1_PKcS5_RS5_PcS7_RS7_,__ZNKSt3__27codecvtIcc11__mbstate_tE5do_inERS1_PKcS5_RS5_PcS7_RS7_,b56,b56,b56,b56,b56,b56,__ZNKSt3__27codecvtIDsc11__mbstate_tE6do_outERS1_PKDsS5_RS5_PcS7_RS7_,__ZNKSt3__27codecvtIDsc11__mbstate_tE5do_inERS1_PKcS5_RS5_PDsS7_RS7_,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,_SDL_BlendPoint_ARGB8888,_SDL_BlendPoint_RGB888,_SDL_BlendPoint_RGBA,_SDL_BlendPoint_RGB,_SDL_BlendPoint_RGB555,_SDL_BlendPoint_RGB565,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56,b56
,b56,b56,b56];
var FUNCTION_TABLE_iiiiid = [b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,__ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcd,__ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEce,b57,b57,b57,b57,b57,b57,b57,b57,__ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwd,__ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwe,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57
,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57,b57];
var FUNCTION_TABLE_viiii = [b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,__ZN9osgViewer14GraphicsWindow12setSwapGroupEbjj,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,__ZNSt3__215basic_stringbufIcNS_11char_traitsIcEENS_9allocatorIcEEE7seekposENS_4fposI11__mbstate_tEEj
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,__ZN15EXTQuerySupport10initializeEPN3osg5StateEy,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,__ZN15ARBQuerySupport10initializeEPN3osg5StateEy,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,__ZNK5osgGA17CameraManipulator15getHomePositionERN3osg5Vec3dES3_S3_,b58,b58,b58,b58,b58,b58,b58,__ZN5osgGA16OrbitManipulator17setTransformationERKN3osg5Vec3dES4_S4_,b58,__ZNK5osgGA16OrbitManipulator17getTransformationERN3osg5Vec3dES3_S3_,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,__ZN3osg24TemplatePrimitiveFunctorIN27LineSegmentIntersectorUtils16IntersectFunctorINS_5Vec3dEdEEE10drawArraysEjii,__ZN3osg24TemplatePrimitiveFunctorIN27LineSegmentIntersectorUtils16IntersectFunctorINS_5Vec3dEdEEE12drawElementsEjiPKh,__ZN3osg24TemplatePrimitiveFunctorIN27LineSegmentIntersectorUtils16IntersectFunctorINS_5Vec3dEdEEE12drawElementsEjiPKt,__ZN3osg24TemplatePrimitiveFunctorIN27LineSegmentIntersectorUtils16IntersectFunctorINS_5Vec3dEdEEE12drawElementsEjiPKj,b58,b58,b58,b58,b58,b58,b58,b58,__ZN3osg24TemplatePrimitiveFunctorIN27LineSegmentIntersectorUtils16IntersectFunctorINS_5Vec3fEfEEE10drawArraysEjii,__ZN3osg24TemplatePrimitiveFunctorIN27LineSegmentIntersectorUtils16IntersectFunctorINS_5Vec3fEfEEE12drawElementsEjiPKh,__ZN3osg24TemplatePrimitiveFunctorIN27LineSegmentIntersectorUtils16IntersectFunctorINS_5Vec3fEfEEE12drawElementsEjiPKt,__ZN3osg24TemplatePrimitiveFunctorIN27LineSegmentIntersectorUtils16IntersectFunctorINS_5Vec3fEfEEE12drawElementsEjiPKj,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,__ZN7osgUtil10Statistics10drawArraysEjii,__ZN7osgUtil10Statistics12drawElementsEjiPKh,__ZN7osgUtil10Statistics12drawElementsEjiPKt,__ZN7osgUtil10Statistics12drawElementsEjiPKj,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,__ZN3osg24TemplatePrimitiveFunctorI21ComputeNearFarFunctorI17GreaterComparatorEE10drawArraysEjii,__ZN3osg24TemplatePrimitiveFunctorI21ComputeNearFarFunctorI17GreaterComparatorEE12drawElementsEjiPKh,__ZN3osg24TemplatePrimitiveFunctorI21ComputeNearFarFunctorI17GreaterComparatorEE12drawElementsEjiPKt,__ZN3osg24TemplatePrimitiveFunctorI21ComputeNearFarFunctorI17GreaterComparatorEE12drawElementsEjiPKj,b58,b58,b58,b58,b58,b58,b58,b58,__ZN3osg24TemplatePrimitiveFunctorI21ComputeNearFarFunctorI14LessComparatorEE10drawArraysEjii,__ZN3osg24TemplatePrimitiveFunctorI21ComputeNearFarFunctorI14LessComparatorEE12drawElementsEjiPKh,__ZN3osg24TemplatePrimitiveFunctorI21ComputeNearFarFunctorI14LessComparatorEE12drawElementsEjiPKt,__ZN3osg24TemplatePrimitiveFunctorI21ComputeNearFarFunctorI14LessComparatorEE12drawElementsEjiPKj,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,__ZN7osgUtil24PositionalStateContainer29addPositionedTextureAttributeEjPN3osg10RefMatrixdEPKNS1_14StateAttributeE,__ZN7osgUtil24PositionalStateContainer4drawERN3osg5StateERPNS_10RenderLeafEPKNS1_7MatrixdE,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,__ZN7osgUtil11RenderStage29addPositionedTextureAttributeEjPN3osg10RefMatrixdEPKNS1_14StateAttributeE,b58,__ZN7osgUtil11RenderStage9drawInnerERN3osg10RenderInfoERPNS_10RenderLeafERb,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,__ZN12ComputeBound10drawArraysEjii,__ZN12ComputeBound12drawElementsEjiPKh,__ZN12ComputeBound12drawElementsEjiPKt,__ZN12ComputeBound12drawElementsEjiPKj,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,__ZN3osg29TemplatePrimitiveIndexFunctorI25PrimitiveIndicesCollectorE10drawArraysEjii,__ZN3osg29TemplatePrimitiveIndexFunctorI25PrimitiveIndicesCollectorE12drawElementsEjiPKh,__ZN3osg29TemplatePrimitiveIndexFunctorI25PrimitiveIndicesCollectorE12drawElementsEjiPKt,__ZN3osg29TemplatePrimitiveIndexFunctorI25PrimitiveIndicesCollectorE12drawElementsEjiPKj,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE7seekposENS_4fposI11__mbstate_tEEj,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,__ZN25VertexAttribArrayDispatch19enable_and_dispatchERN3osg5StateEPKNS0_5ArrayEPKNS0_14GLBufferObjectE,b58,b58,__ZN25VertexAttribArrayDispatch8dispatchERN3osg5StateEPKNS0_5ArrayEPKNS0_14GLBufferObjectE
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,__ZN5osgDB10ImagePager16readRefImageFileERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEPKN3osg10ReferencedE,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,__ZNK5osgDB9FileCache9readImageERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEPKNS_7OptionsE,b58,__ZNK5osgDB9FileCache10readObjectERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEPKNS_7OptionsE,b58,__ZNK5osgDB9FileCache15readHeightFieldERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEPKNS_7OptionsE,b58,b58,b58,__ZNK5osgDB9FileCache10readShaderERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEPKNS_7OptionsE,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,_SDL_LogOutput,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE7seekposENS_4fposI11__mbstate_tEEj,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,__ZNKSt3__27collateIcE12do_transformEPKcS3_,b58,b58,b58,b58,__ZNKSt3__27collateIwE12do_transformEPKwS3_,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,__ZNK10__cxxabiv117__class_type_info27has_unambiguous_public_baseEPNS_19__dynamic_cast_infoEPvi,b58,b58,b58,__ZNK10__cxxabiv120__si_class_type_info27has_unambiguous_public_baseEPNS_19__dynamic_cast_infoEPvi,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,__ZNK10__cxxabiv121__vmi_class_type_info27has_unambiguous_public_baseEPNS_19__dynamic_cast_infoEPvi,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,__ZN3osg4ViewC2ERKS0_RKNS_6CopyOpE,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,__ZN9osgViewer4ViewC2ERKS0_RKN3osg6CopyOpE,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,__ZN3osg16BarrierOperationC1EiNS0_10PreBlockOpEb,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,__ZN3osg16ApplicationUsage19addUsageExplanationENS0_4TypeERKNSt3__212basic_stringIcNS2_11char_traitsIcEENS2_9allocatorIcEEEESA_,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,__ZN3osg8Geometry16setTexCoordArrayEjPNS_5ArrayENS1_7BindingE,b58,b58,b58,b58,__ZN3osg8StateSet19setRenderBinDetailsEiRKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEENS0_13RenderBinModeE,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,__ZN3osg11NodeVisitorC2ENS0_11VisitorTypeENS0_13TraversalModeE,b58,b58,b58,b58,b58,b58,b58,__ZN5osgGA16OrbitManipulatorC2ERKS0_RKN3osg6CopyOpE,b58,b58,b58,b58,b58,b58,__ZN5osgGA19StandardManipulator15fixVerticalAxisERN3osg5Vec3dERNS1_4QuatEb,b58
,b58,b58,__ZN5osgGA19StandardManipulatorC2ERKS0_RKN3osg6CopyOpE,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,__ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3dEdE3setERKS2_S5_PNS_8SettingsE,b58,__ZN27LineSegmentIntersectorUtils16IntersectFunctorIN3osg5Vec3fEfE3setERKNS1_5Vec3dES6_PNS_8SettingsE,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,_glScissor__wrapper,b58,_glColorMask__wrapper,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,__ZN3osg11NodeVisitorC2ERKS0_RKNS_6CopyOpE,b58,b58,b58,b58,b58,b58,b58,__ZN7osgUtil11CullVisitor21MatrixPlanesDrawables3setERKN3osg7MatrixdEPKNS2_8DrawableERKNS2_8PolytopeE,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,__ZN3osg14GLBufferObjectC2EjPNS_12BufferObjectEj,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,__ZN3osg7Program17PerContextProgramC2EPKS0_jj,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,__ZN3osg7UniformC2ENS0_4TypeERKNSt3__212basic_stringIcNS2_11char_traitsIcEENS2_9allocatorIcEEEEi,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,__ZN3osg8StateSet19setTextureAttributeEjPNS_14StateAttributeEj,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,__ZNSt3__26__treeINS_12__value_typeIPN3osg8StateSetEbEENS_19__map_value_compareIS4_S5_NS_4lessIS4_EELb1EEENS_9allocatorIS5_EEE16__insert_node_atEPNS_15__tree_end_nodeIPNS_16__tree_node_baseIPvEEEERSH_SH_,__ZNSt3__26__treeINS_12__value_typeIPvPN3osg8StateSetEEENS_19__map_value_compareIS2_S6_NS_4lessIS2_EELb1EEENS_9allocatorIS6_EEE16__insert_node_atEPNS_15__tree_end_nodeIPNS_16__tree_node_baseIS2_EEEERSH_SH_,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,__ZN4mjin11application6memory4ItemC2Eiii,b58,b58,b58,b58,b58,b58,b58,b58,b58,__ZN5osgDB8Registry21getRefFromObjectCacheERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEPNS_7OptionsE,b58,b58,b58,b58,b58,b58,b58,b58,b58,__ZN5osgDB8Registry22readNodeImplementationERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEPKNS_7OptionsE,b58,__ZN7osgUtil14StateToCompileC2EjPN3osg6ObjectE,b58,b58,__ZN5osgDB13DatabasePager14DatabaseThreadC2EPS0_NS1_4ModeERKNSt3__212basic_stringIcNS4_11char_traitsIcEENS4_9allocatorIcEEEE,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,__ZNSt3__25dequeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS4_IS6_EEE8__appendINS_16__deque_iteratorIS6_PKS6_RSB_PKSC_iLi0EEEEEvT_SH_PNS_9enable_ifIXsr21__is_forward_iteratorISH_EE5valueEvE4typeE,b58,b58,__ZN5osgDB8Registry24readObjectImplementationERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEPKNS_7OptionsE,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,__ZNSt3__25dequeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS4_IS6_EEE6assignINS_16__deque_iteratorIS6_PKS6_RSB_PKSC_iLi0EEEEEvT_SH_PNS_9enable_ifIXsr27__is_random_access_iteratorISH_EE5valueEvE4typeE,b58,b58,b58,b58,b58,b58,b58,b58,__ZN5osgDB14findFileInPathERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEERKNS0_5dequeIS6_NS4_IS6_EEEENS_15CaseSensitivityE,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,__ZN5osgDB8Registry18readImplementationERKNS0_11ReadFunctorENS_7Options16CacheHintOptionsE,b58,b58,b58,b58,__ZN5osgDB11ObjectCache21getRefFromObjectCacheERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEPKNS_7OptionsE,b58,b58,b58,b58,b58,b58,b58,__ZN5osgDB9IntLookup4add2EPKcS2_i,b58,b58,b58
,b58,b58,b58,b58,__ZN5osgDB8Registry23readImageImplementationERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEPKNS_7OptionsE,b58,b58,b58,b58,b58,b58,__ZN5osgDB8Registry29readHeightFieldImplementationERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEPKNS_7OptionsE,b58,b58,__ZN5osgDB8Registry24readShaderImplementationERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEPKNS_7OptionsE,b58,b58,b58,b58,b58,b58,__ZN5osgDB19findFileInDirectoryERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEES8_NS_15CaseSensitivityE,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,_Emscripten_SetWindowFullscreen
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,_Emscripten_GLES_GetDrawableSize,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,_SDL_JoystickAllowBackgroundEventsChanged,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,_emscripten_glBufferData__wrapper,_emscripten_glBufferSubData__wrapper,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,_emscripten_glUniform3i__wrapper,b58,b58,b58,b58,b58,b58,b58,b58,b58,_emscripten_glUniformMatrix2fv__wrapper,_emscripten_glUniformMatrix3fv__wrapper,_emscripten_glUniformMatrix4fv__wrapper,b58,b58,b58,b58,b58,b58,b58,b58,b58,_emscripten_glGetAttachedShaders__wrapper,_emscripten_glShaderSource__wrapper,_emscripten_glGetShaderSource__wrapper,b58,_emscripten_glGetShaderInfoLog__wrapper,b58,b58,b58,b58,b58,b58,b58,_emscripten_glGetShaderPrecisionFormat__wrapper,b58,_emscripten_glGetProgramInfoLog__wrapper,b58,b58,b58,b58,b58,b58,b58,_emscripten_glFramebufferRenderbuffer__wrapper,b58,_emscripten_glGetFramebufferAttachmentParameteriv__wrapper,b58,b58,b58,_emscripten_glGetInfoLogARB__wrapper,b58,b58,b58,b58,_emscripten_glVertexPointer__wrapper,_emscripten_glTexCoordPointer__wrapper,b58,_emscripten_glColorPointer__wrapper,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,_emscripten_glDrawElements__wrapper,b58,b58,b58,b58,_emscripten_glDrawArraysInstanced__wrapper,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,_emscripten_glViewport__wrapper,b58,_emscripten_glScissor__wrapper,b58,_emscripten_glColorMask__wrapper,_emscripten_glRenderbufferStorage__wrapper,_emscripten_glBlendFuncSeparate__wrapper,b58,_emscripten_glStencilFuncSeparate__wrapper,_emscripten_glStencilOpSeparate__wrapper,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,__ZNSt3__216__check_groupingERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjS8_Rj,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58,b58
,b58,b58,b58];

  return { __GLOBAL__sub_I_main_cpp: __GLOBAL__sub_I_main_cpp, _bitshift64Lshr: _bitshift64Lshr, __GLOBAL__sub_I_State_cpp: __GLOBAL__sub_I_State_cpp, __GLOBAL__sub_I_Renderer_cpp: __GLOBAL__sub_I_Renderer_cpp, dynCall_viiiiiiiiiii: dynCall_viiiiiiiiiii, _sbrk: _sbrk, _memcpy: _memcpy, __GLOBAL__sub_I_GLExtensions_cpp: __GLOBAL__sub_I_GLExtensions_cpp, __GLOBAL__sub_I_Uniform_cpp: __GLOBAL__sub_I_Uniform_cpp, dynCall_iiid: dynCall_iiid, dynCall_di: dynCall_di, __GLOBAL__sub_I_DatabasePager_cpp: __GLOBAL__sub_I_DatabasePager_cpp, dynCall_iiii: dynCall_iiii, __GLOBAL__I_000101: __GLOBAL__I_000101, dynCall_iiiiid: dynCall_iiiiid, _emscripten_get_global_libc: _emscripten_get_global_libc, __GLOBAL__sub_I_render_platform_web_cpp: __GLOBAL__sub_I_render_platform_web_cpp, __GLOBAL__sub_I_application_cpp: __GLOBAL__sub_I_application_cpp, dynCall_viddd: dynCall_viddd, dynCall_iiiiii: dynCall_iiiiii, stackSave: stackSave, dynCall_viiiii: dynCall_viiiii, __GLOBAL__sub_I_ContextData_cpp: __GLOBAL__sub_I_ContextData_cpp, ___cxa_can_catch: ___cxa_can_catch, _free: _free, runPostSets: runPostSets, dynCall_viiiiii: dynCall_viiiiii, dynCall_viddi: dynCall_viddi, _strstr: _strstr, dynCall_vdddd: dynCall_vdddd, dynCall_iiiidddd: dynCall_iiiidddd, _main: _main, __GLOBAL__sub_I_Optimizer_cpp: __GLOBAL__sub_I_Optimizer_cpp, dynCall_iidii: dynCall_iidii, setThrew: setThrew, __GLOBAL__sub_I_DisplaySettings_cpp: __GLOBAL__sub_I_DisplaySettings_cpp, dynCall_iiiiiiiiii: dynCall_iiiiiiiiii, __GLOBAL__sub_I_Mouse_cpp: __GLOBAL__sub_I_Mouse_cpp, ___cxa_is_pointer_type: ___cxa_is_pointer_type, dynCall_iiiiiiiiid: dynCall_iiiiiiiiid, dynCall_diii: dynCall_diii, stackAlloc: stackAlloc, dynCall_vd: dynCall_vd, __GLOBAL__sub_I_Node_cpp: __GLOBAL__sub_I_Node_cpp, getTempRet0: getTempRet0, __GLOBAL__sub_I_memory_cpp: __GLOBAL__sub_I_memory_cpp, dynCall_viiid: dynCall_viiid, __GLOBAL__sub_I_GraphicsContext_cpp: __GLOBAL__sub_I_GraphicsContext_cpp, dynCall_viiii: dynCall_viiii, _llvm_bswap_i32: _llvm_bswap_i32, dynCall_iiiiiiiiiiii: dynCall_iiiiiiiiiiii, establishStackSpace: establishStackSpace, __GLOBAL__sub_I_Scene_cpp: __GLOBAL__sub_I_Scene_cpp, _pthread_mutex_lock: _pthread_mutex_lock, dynCall_vdi: dynCall_vdi, dynCall_vdd: dynCall_vdd, __GLOBAL__sub_I_Texture_cpp: __GLOBAL__sub_I_Texture_cpp, dynCall_i: dynCall_i, dynCall_viiiiiiiiii: dynCall_viiiiiiiiii, dynCall_iiiiiii: dynCall_iiiiiii, dynCall_vidddd: dynCall_vidddd, __GLOBAL__sub_I_IncrementalCompileOperation_cpp: __GLOBAL__sub_I_IncrementalCompileOperation_cpp, __GLOBAL__sub_I_RenderBin_cpp: __GLOBAL__sub_I_RenderBin_cpp, dynCall_iiiiiid: dynCall_iiiiiid, _pthread_mutex_trylock: _pthread_mutex_trylock, dynCall_vi: dynCall_vi, __GLOBAL__sub_I_render_cpp_4401: __GLOBAL__sub_I_render_cpp_4401, dynCall_iiiiiiiii: dynCall_iiiiiiiii, dynCall_iid: dynCall_iid, dynCall_iii: dynCall_iii, __GLOBAL__sub_I_CullSettings_cpp: __GLOBAL__sub_I_CullSettings_cpp, _memset: _memset, __GLOBAL__sub_I_Referenced_cpp: __GLOBAL__sub_I_Referenced_cpp, dynCall_viii: dynCall_viii, dynCall_viiidi: dynCall_viiidi, dynCall_viiiiiii: dynCall_viiiiiii, _i64Subtract: _i64Subtract, setTempRet0: setTempRet0, dynCall_viiiiiiiiiiiiiii: dynCall_viiiiiiiiiiiiiii, __GLOBAL__sub_I_render_cpp: __GLOBAL__sub_I_render_cpp, __GLOBAL__sub_I_iostream_cpp: __GLOBAL__sub_I_iostream_cpp, _pthread_cond_broadcast: _pthread_cond_broadcast, dynCall_iidd: dynCall_iidd, dynCall_vidd: dynCall_vidd, dynCall_iiiiiiii: dynCall_iiiiiiii, dynCall_iiiiidii: dynCall_iiiiidii, dynCall_vidi: dynCall_vidi, _malloc: _malloc, dynCall_viddddd: dynCall_viddddd, dynCall_viidiii: dynCall_viidiii, dynCall_dii: dynCall_dii, dynCall_v: dynCall_v, __GLOBAL__sub_I_InputStream_cpp: __GLOBAL__sub_I_InputStream_cpp, __GLOBAL__sub_I_Game_cpp: __GLOBAL__sub_I_Game_cpp, ___udivdi3: ___udivdi3, dynCall_vid: dynCall_vid, _bitshift64Shl: _bitshift64Shl, __GLOBAL__sub_I_Pool_cpp: __GLOBAL__sub_I_Pool_cpp, dynCall_iiddd: dynCall_iiddd, _fflush: _fflush, dynCall_iiiid: dynCall_iiiid, __GLOBAL__sub_I_Notify_cpp: __GLOBAL__sub_I_Notify_cpp, __GLOBAL__sub_I_selection_cpp: __GLOBAL__sub_I_selection_cpp, ___muldi3: ___muldi3, __GLOBAL__sub_I_Registry_cpp: __GLOBAL__sub_I_Registry_cpp, dynCall_vii: dynCall_vii, ___uremdi3: ___uremdi3, dynCall_viiiiiiii: dynCall_viiiiiiii, __GLOBAL__sub_I_ApplicationUsage_cpp: __GLOBAL__sub_I_ApplicationUsage_cpp, _realloc: _realloc, _i64Add: _i64Add, _pthread_mutex_unlock: _pthread_mutex_unlock, dynCall_viiiidiii: dynCall_viiiidiii, stackRestore: stackRestore, dynCall_iiiii: dynCall_iiiii, dynCall_viid: dynCall_viid, __GLOBAL__sub_I_ViewerBase_cpp: __GLOBAL__sub_I_ViewerBase_cpp, dynCall_iiiiiiiiiii: dynCall_iiiiiiiiiii, dynCall_iiiiiiiiiiiii: dynCall_iiiiiiiiiiiii, _emscripten_GetProcAddress: _emscripten_GetProcAddress, __GLOBAL__sub_I_common_cpp: __GLOBAL__sub_I_common_cpp, ___errno_location: ___errno_location, dynCall_viidd: dynCall_viidd, __GLOBAL__sub_I_OrbitManipulator_cpp: __GLOBAL__sub_I_OrbitManipulator_cpp, dynCall_ii: dynCall_ii, _memmove: _memmove, dynCall_viiiiiiiii: dynCall_viiiiiiiii, __GLOBAL__sub_I_Coordinator_cpp: __GLOBAL__sub_I_Coordinator_cpp, dynCall_viiidiii: dynCall_viiidiii, dynCall_vdddddd: dynCall_vdddddd };
})
// EMSCRIPTEN_END_ASM
(Module.asmGlobalArg, Module.asmLibraryArg, buffer);

var real___GLOBAL__sub_I_Game_cpp = asm["__GLOBAL__sub_I_Game_cpp"]; asm["__GLOBAL__sub_I_Game_cpp"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real___GLOBAL__sub_I_Game_cpp.apply(null, arguments);
};

var real__main = asm["_main"]; asm["_main"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real__main.apply(null, arguments);
};

var real___GLOBAL__sub_I_Optimizer_cpp = asm["__GLOBAL__sub_I_Optimizer_cpp"]; asm["__GLOBAL__sub_I_Optimizer_cpp"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real___GLOBAL__sub_I_Optimizer_cpp.apply(null, arguments);
};

var real___GLOBAL__sub_I_Uniform_cpp = asm["__GLOBAL__sub_I_Uniform_cpp"]; asm["__GLOBAL__sub_I_Uniform_cpp"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real___GLOBAL__sub_I_Uniform_cpp.apply(null, arguments);
};

var real_stackSave = asm["stackSave"]; asm["stackSave"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real_stackSave.apply(null, arguments);
};

var real___GLOBAL__sub_I_main_cpp = asm["__GLOBAL__sub_I_main_cpp"]; asm["__GLOBAL__sub_I_main_cpp"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real___GLOBAL__sub_I_main_cpp.apply(null, arguments);
};

var real____udivdi3 = asm["___udivdi3"]; asm["___udivdi3"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real____udivdi3.apply(null, arguments);
};

var real_getTempRet0 = asm["getTempRet0"]; asm["getTempRet0"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real_getTempRet0.apply(null, arguments);
};

var real___GLOBAL__sub_I_IncrementalCompileOperation_cpp = asm["__GLOBAL__sub_I_IncrementalCompileOperation_cpp"]; asm["__GLOBAL__sub_I_IncrementalCompileOperation_cpp"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real___GLOBAL__sub_I_IncrementalCompileOperation_cpp.apply(null, arguments);
};

var real__bitshift64Lshr = asm["_bitshift64Lshr"]; asm["_bitshift64Lshr"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real__bitshift64Lshr.apply(null, arguments);
};

var real___GLOBAL__sub_I_Texture_cpp = asm["__GLOBAL__sub_I_Texture_cpp"]; asm["__GLOBAL__sub_I_Texture_cpp"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real___GLOBAL__sub_I_Texture_cpp.apply(null, arguments);
};

var real___GLOBAL__sub_I_RenderBin_cpp = asm["__GLOBAL__sub_I_RenderBin_cpp"]; asm["__GLOBAL__sub_I_RenderBin_cpp"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real___GLOBAL__sub_I_RenderBin_cpp.apply(null, arguments);
};

var real___GLOBAL__sub_I_GLExtensions_cpp = asm["__GLOBAL__sub_I_GLExtensions_cpp"]; asm["__GLOBAL__sub_I_GLExtensions_cpp"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real___GLOBAL__sub_I_GLExtensions_cpp.apply(null, arguments);
};

var real__bitshift64Shl = asm["_bitshift64Shl"]; asm["_bitshift64Shl"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real__bitshift64Shl.apply(null, arguments);
};

var real__pthread_mutex_trylock = asm["_pthread_mutex_trylock"]; asm["_pthread_mutex_trylock"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real__pthread_mutex_trylock.apply(null, arguments);
};

var real___GLOBAL__sub_I_memory_cpp = asm["__GLOBAL__sub_I_memory_cpp"]; asm["__GLOBAL__sub_I_memory_cpp"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real___GLOBAL__sub_I_memory_cpp.apply(null, arguments);
};

var real___GLOBAL__sub_I_common_cpp = asm["__GLOBAL__sub_I_common_cpp"]; asm["__GLOBAL__sub_I_common_cpp"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real___GLOBAL__sub_I_common_cpp.apply(null, arguments);
};

var real__fflush = asm["_fflush"]; asm["_fflush"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real__fflush.apply(null, arguments);
};

var real___GLOBAL__sub_I_Mouse_cpp = asm["__GLOBAL__sub_I_Mouse_cpp"]; asm["__GLOBAL__sub_I_Mouse_cpp"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real___GLOBAL__sub_I_Mouse_cpp.apply(null, arguments);
};

var real____cxa_is_pointer_type = asm["___cxa_is_pointer_type"]; asm["___cxa_is_pointer_type"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real____cxa_is_pointer_type.apply(null, arguments);
};

var real___GLOBAL__sub_I_CullSettings_cpp = asm["__GLOBAL__sub_I_CullSettings_cpp"]; asm["__GLOBAL__sub_I_CullSettings_cpp"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real___GLOBAL__sub_I_CullSettings_cpp.apply(null, arguments);
};

var real___GLOBAL__sub_I_Notify_cpp = asm["__GLOBAL__sub_I_Notify_cpp"]; asm["__GLOBAL__sub_I_Notify_cpp"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real___GLOBAL__sub_I_Notify_cpp.apply(null, arguments);
};

var real__sbrk = asm["_sbrk"]; asm["_sbrk"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real__sbrk.apply(null, arguments);
};

var real___GLOBAL__sub_I_Referenced_cpp = asm["__GLOBAL__sub_I_Referenced_cpp"]; asm["__GLOBAL__sub_I_Referenced_cpp"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real___GLOBAL__sub_I_Referenced_cpp.apply(null, arguments);
};

var real___GLOBAL__sub_I_DisplaySettings_cpp = asm["__GLOBAL__sub_I_DisplaySettings_cpp"]; asm["__GLOBAL__sub_I_DisplaySettings_cpp"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real___GLOBAL__sub_I_DisplaySettings_cpp.apply(null, arguments);
};

var real__llvm_bswap_i32 = asm["_llvm_bswap_i32"]; asm["_llvm_bswap_i32"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real__llvm_bswap_i32.apply(null, arguments);
};

var real____muldi3 = asm["___muldi3"]; asm["___muldi3"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real____muldi3.apply(null, arguments);
};

var real___GLOBAL__sub_I_Registry_cpp = asm["__GLOBAL__sub_I_Registry_cpp"]; asm["__GLOBAL__sub_I_Registry_cpp"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real___GLOBAL__sub_I_Registry_cpp.apply(null, arguments);
};

var real___GLOBAL__sub_I_Scene_cpp = asm["__GLOBAL__sub_I_Scene_cpp"]; asm["__GLOBAL__sub_I_Scene_cpp"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real___GLOBAL__sub_I_Scene_cpp.apply(null, arguments);
};

var real___GLOBAL__sub_I_Node_cpp = asm["__GLOBAL__sub_I_Node_cpp"]; asm["__GLOBAL__sub_I_Node_cpp"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real___GLOBAL__sub_I_Node_cpp.apply(null, arguments);
};

var real____uremdi3 = asm["___uremdi3"]; asm["___uremdi3"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real____uremdi3.apply(null, arguments);
};

var real___GLOBAL__sub_I_selection_cpp = asm["__GLOBAL__sub_I_selection_cpp"]; asm["__GLOBAL__sub_I_selection_cpp"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real___GLOBAL__sub_I_selection_cpp.apply(null, arguments);
};

var real___GLOBAL__sub_I_Pool_cpp = asm["__GLOBAL__sub_I_Pool_cpp"]; asm["__GLOBAL__sub_I_Pool_cpp"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real___GLOBAL__sub_I_Pool_cpp.apply(null, arguments);
};

var real__i64Subtract = asm["_i64Subtract"]; asm["_i64Subtract"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real__i64Subtract.apply(null, arguments);
};

var real___GLOBAL__sub_I_ApplicationUsage_cpp = asm["__GLOBAL__sub_I_ApplicationUsage_cpp"]; asm["__GLOBAL__sub_I_ApplicationUsage_cpp"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real___GLOBAL__sub_I_ApplicationUsage_cpp.apply(null, arguments);
};

var real_setTempRet0 = asm["setTempRet0"]; asm["setTempRet0"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real_setTempRet0.apply(null, arguments);
};

var real__realloc = asm["_realloc"]; asm["_realloc"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real__realloc.apply(null, arguments);
};

var real__i64Add = asm["_i64Add"]; asm["_i64Add"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real__i64Add.apply(null, arguments);
};

var real___GLOBAL__sub_I_DatabasePager_cpp = asm["__GLOBAL__sub_I_DatabasePager_cpp"]; asm["__GLOBAL__sub_I_DatabasePager_cpp"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real___GLOBAL__sub_I_DatabasePager_cpp.apply(null, arguments);
};

var real___GLOBAL__sub_I_render_cpp = asm["__GLOBAL__sub_I_render_cpp"]; asm["__GLOBAL__sub_I_render_cpp"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real___GLOBAL__sub_I_render_cpp.apply(null, arguments);
};

var real__pthread_mutex_unlock = asm["_pthread_mutex_unlock"]; asm["_pthread_mutex_unlock"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real__pthread_mutex_unlock.apply(null, arguments);
};

var real___GLOBAL__I_000101 = asm["__GLOBAL__I_000101"]; asm["__GLOBAL__I_000101"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real___GLOBAL__I_000101.apply(null, arguments);
};

var real__emscripten_get_global_libc = asm["_emscripten_get_global_libc"]; asm["_emscripten_get_global_libc"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real__emscripten_get_global_libc.apply(null, arguments);
};

var real___GLOBAL__sub_I_render_platform_web_cpp = asm["__GLOBAL__sub_I_render_platform_web_cpp"]; asm["__GLOBAL__sub_I_render_platform_web_cpp"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real___GLOBAL__sub_I_render_platform_web_cpp.apply(null, arguments);
};

var real___GLOBAL__sub_I_ViewerBase_cpp = asm["__GLOBAL__sub_I_ViewerBase_cpp"]; asm["__GLOBAL__sub_I_ViewerBase_cpp"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real___GLOBAL__sub_I_ViewerBase_cpp.apply(null, arguments);
};

var real___GLOBAL__sub_I_iostream_cpp = asm["__GLOBAL__sub_I_iostream_cpp"]; asm["__GLOBAL__sub_I_iostream_cpp"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real___GLOBAL__sub_I_iostream_cpp.apply(null, arguments);
};

var real___GLOBAL__sub_I_application_cpp = asm["__GLOBAL__sub_I_application_cpp"]; asm["__GLOBAL__sub_I_application_cpp"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real___GLOBAL__sub_I_application_cpp.apply(null, arguments);
};

var real___GLOBAL__sub_I_GraphicsContext_cpp = asm["__GLOBAL__sub_I_GraphicsContext_cpp"]; asm["__GLOBAL__sub_I_GraphicsContext_cpp"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real___GLOBAL__sub_I_GraphicsContext_cpp.apply(null, arguments);
};

var real__emscripten_GetProcAddress = asm["_emscripten_GetProcAddress"]; asm["_emscripten_GetProcAddress"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real__emscripten_GetProcAddress.apply(null, arguments);
};

var real__pthread_cond_broadcast = asm["_pthread_cond_broadcast"]; asm["_pthread_cond_broadcast"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real__pthread_cond_broadcast.apply(null, arguments);
};

var real____errno_location = asm["___errno_location"]; asm["___errno_location"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real____errno_location.apply(null, arguments);
};

var real_stackAlloc = asm["stackAlloc"]; asm["stackAlloc"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real_stackAlloc.apply(null, arguments);
};

var real___GLOBAL__sub_I_ContextData_cpp = asm["__GLOBAL__sub_I_ContextData_cpp"]; asm["__GLOBAL__sub_I_ContextData_cpp"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real___GLOBAL__sub_I_ContextData_cpp.apply(null, arguments);
};

var real____cxa_can_catch = asm["___cxa_can_catch"]; asm["___cxa_can_catch"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real____cxa_can_catch.apply(null, arguments);
};

var real__free = asm["_free"]; asm["_free"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real__free.apply(null, arguments);
};

var real___GLOBAL__sub_I_State_cpp = asm["__GLOBAL__sub_I_State_cpp"]; asm["__GLOBAL__sub_I_State_cpp"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real___GLOBAL__sub_I_State_cpp.apply(null, arguments);
};

var real_establishStackSpace = asm["establishStackSpace"]; asm["establishStackSpace"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real_establishStackSpace.apply(null, arguments);
};

var real__memmove = asm["_memmove"]; asm["_memmove"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real__memmove.apply(null, arguments);
};

var real__strstr = asm["_strstr"]; asm["_strstr"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real__strstr.apply(null, arguments);
};

var real___GLOBAL__sub_I_Renderer_cpp = asm["__GLOBAL__sub_I_Renderer_cpp"]; asm["__GLOBAL__sub_I_Renderer_cpp"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real___GLOBAL__sub_I_Renderer_cpp.apply(null, arguments);
};

var real_stackRestore = asm["stackRestore"]; asm["stackRestore"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real_stackRestore.apply(null, arguments);
};

var real___GLOBAL__sub_I_render_cpp_4401 = asm["__GLOBAL__sub_I_render_cpp_4401"]; asm["__GLOBAL__sub_I_render_cpp_4401"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real___GLOBAL__sub_I_render_cpp_4401.apply(null, arguments);
};

var real__malloc = asm["_malloc"]; asm["_malloc"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real__malloc.apply(null, arguments);
};

var real___GLOBAL__sub_I_OrbitManipulator_cpp = asm["__GLOBAL__sub_I_OrbitManipulator_cpp"]; asm["__GLOBAL__sub_I_OrbitManipulator_cpp"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real___GLOBAL__sub_I_OrbitManipulator_cpp.apply(null, arguments);
};

var real__pthread_mutex_lock = asm["_pthread_mutex_lock"]; asm["_pthread_mutex_lock"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real__pthread_mutex_lock.apply(null, arguments);
};

var real___GLOBAL__sub_I_Coordinator_cpp = asm["__GLOBAL__sub_I_Coordinator_cpp"]; asm["__GLOBAL__sub_I_Coordinator_cpp"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real___GLOBAL__sub_I_Coordinator_cpp.apply(null, arguments);
};

var real_setThrew = asm["setThrew"]; asm["setThrew"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real_setThrew.apply(null, arguments);
};

var real___GLOBAL__sub_I_InputStream_cpp = asm["__GLOBAL__sub_I_InputStream_cpp"]; asm["__GLOBAL__sub_I_InputStream_cpp"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real___GLOBAL__sub_I_InputStream_cpp.apply(null, arguments);
};
var __GLOBAL__sub_I_Game_cpp = Module["__GLOBAL__sub_I_Game_cpp"] = asm["__GLOBAL__sub_I_Game_cpp"];
var _main = Module["_main"] = asm["_main"];
var __GLOBAL__sub_I_Optimizer_cpp = Module["__GLOBAL__sub_I_Optimizer_cpp"] = asm["__GLOBAL__sub_I_Optimizer_cpp"];
var __GLOBAL__sub_I_Uniform_cpp = Module["__GLOBAL__sub_I_Uniform_cpp"] = asm["__GLOBAL__sub_I_Uniform_cpp"];
var stackSave = Module["stackSave"] = asm["stackSave"];
var __GLOBAL__sub_I_main_cpp = Module["__GLOBAL__sub_I_main_cpp"] = asm["__GLOBAL__sub_I_main_cpp"];
var ___udivdi3 = Module["___udivdi3"] = asm["___udivdi3"];
var getTempRet0 = Module["getTempRet0"] = asm["getTempRet0"];
var __GLOBAL__sub_I_IncrementalCompileOperation_cpp = Module["__GLOBAL__sub_I_IncrementalCompileOperation_cpp"] = asm["__GLOBAL__sub_I_IncrementalCompileOperation_cpp"];
var _bitshift64Lshr = Module["_bitshift64Lshr"] = asm["_bitshift64Lshr"];
var __GLOBAL__sub_I_Texture_cpp = Module["__GLOBAL__sub_I_Texture_cpp"] = asm["__GLOBAL__sub_I_Texture_cpp"];
var __GLOBAL__sub_I_RenderBin_cpp = Module["__GLOBAL__sub_I_RenderBin_cpp"] = asm["__GLOBAL__sub_I_RenderBin_cpp"];
var __GLOBAL__sub_I_GLExtensions_cpp = Module["__GLOBAL__sub_I_GLExtensions_cpp"] = asm["__GLOBAL__sub_I_GLExtensions_cpp"];
var _bitshift64Shl = Module["_bitshift64Shl"] = asm["_bitshift64Shl"];
var _pthread_mutex_trylock = Module["_pthread_mutex_trylock"] = asm["_pthread_mutex_trylock"];
var __GLOBAL__sub_I_memory_cpp = Module["__GLOBAL__sub_I_memory_cpp"] = asm["__GLOBAL__sub_I_memory_cpp"];
var __GLOBAL__sub_I_common_cpp = Module["__GLOBAL__sub_I_common_cpp"] = asm["__GLOBAL__sub_I_common_cpp"];
var _fflush = Module["_fflush"] = asm["_fflush"];
var __GLOBAL__sub_I_Mouse_cpp = Module["__GLOBAL__sub_I_Mouse_cpp"] = asm["__GLOBAL__sub_I_Mouse_cpp"];
var ___cxa_is_pointer_type = Module["___cxa_is_pointer_type"] = asm["___cxa_is_pointer_type"];
var __GLOBAL__sub_I_CullSettings_cpp = Module["__GLOBAL__sub_I_CullSettings_cpp"] = asm["__GLOBAL__sub_I_CullSettings_cpp"];
var __GLOBAL__sub_I_Notify_cpp = Module["__GLOBAL__sub_I_Notify_cpp"] = asm["__GLOBAL__sub_I_Notify_cpp"];
var _memset = Module["_memset"] = asm["_memset"];
var _sbrk = Module["_sbrk"] = asm["_sbrk"];
var __GLOBAL__sub_I_Referenced_cpp = Module["__GLOBAL__sub_I_Referenced_cpp"] = asm["__GLOBAL__sub_I_Referenced_cpp"];
var __GLOBAL__sub_I_DisplaySettings_cpp = Module["__GLOBAL__sub_I_DisplaySettings_cpp"] = asm["__GLOBAL__sub_I_DisplaySettings_cpp"];
var _memcpy = Module["_memcpy"] = asm["_memcpy"];
var _llvm_bswap_i32 = Module["_llvm_bswap_i32"] = asm["_llvm_bswap_i32"];
var ___muldi3 = Module["___muldi3"] = asm["___muldi3"];
var __GLOBAL__sub_I_Registry_cpp = Module["__GLOBAL__sub_I_Registry_cpp"] = asm["__GLOBAL__sub_I_Registry_cpp"];
var __GLOBAL__sub_I_Scene_cpp = Module["__GLOBAL__sub_I_Scene_cpp"] = asm["__GLOBAL__sub_I_Scene_cpp"];
var __GLOBAL__sub_I_Node_cpp = Module["__GLOBAL__sub_I_Node_cpp"] = asm["__GLOBAL__sub_I_Node_cpp"];
var ___uremdi3 = Module["___uremdi3"] = asm["___uremdi3"];
var __GLOBAL__sub_I_selection_cpp = Module["__GLOBAL__sub_I_selection_cpp"] = asm["__GLOBAL__sub_I_selection_cpp"];
var __GLOBAL__sub_I_Pool_cpp = Module["__GLOBAL__sub_I_Pool_cpp"] = asm["__GLOBAL__sub_I_Pool_cpp"];
var _i64Subtract = Module["_i64Subtract"] = asm["_i64Subtract"];
var __GLOBAL__sub_I_ApplicationUsage_cpp = Module["__GLOBAL__sub_I_ApplicationUsage_cpp"] = asm["__GLOBAL__sub_I_ApplicationUsage_cpp"];
var setTempRet0 = Module["setTempRet0"] = asm["setTempRet0"];
var _realloc = Module["_realloc"] = asm["_realloc"];
var _i64Add = Module["_i64Add"] = asm["_i64Add"];
var __GLOBAL__sub_I_DatabasePager_cpp = Module["__GLOBAL__sub_I_DatabasePager_cpp"] = asm["__GLOBAL__sub_I_DatabasePager_cpp"];
var __GLOBAL__sub_I_render_cpp = Module["__GLOBAL__sub_I_render_cpp"] = asm["__GLOBAL__sub_I_render_cpp"];
var _pthread_mutex_unlock = Module["_pthread_mutex_unlock"] = asm["_pthread_mutex_unlock"];
var __GLOBAL__I_000101 = Module["__GLOBAL__I_000101"] = asm["__GLOBAL__I_000101"];
var _emscripten_get_global_libc = Module["_emscripten_get_global_libc"] = asm["_emscripten_get_global_libc"];
var __GLOBAL__sub_I_render_platform_web_cpp = Module["__GLOBAL__sub_I_render_platform_web_cpp"] = asm["__GLOBAL__sub_I_render_platform_web_cpp"];
var __GLOBAL__sub_I_ViewerBase_cpp = Module["__GLOBAL__sub_I_ViewerBase_cpp"] = asm["__GLOBAL__sub_I_ViewerBase_cpp"];
var __GLOBAL__sub_I_iostream_cpp = Module["__GLOBAL__sub_I_iostream_cpp"] = asm["__GLOBAL__sub_I_iostream_cpp"];
var __GLOBAL__sub_I_application_cpp = Module["__GLOBAL__sub_I_application_cpp"] = asm["__GLOBAL__sub_I_application_cpp"];
var __GLOBAL__sub_I_GraphicsContext_cpp = Module["__GLOBAL__sub_I_GraphicsContext_cpp"] = asm["__GLOBAL__sub_I_GraphicsContext_cpp"];
var _emscripten_GetProcAddress = Module["_emscripten_GetProcAddress"] = asm["_emscripten_GetProcAddress"];
var _pthread_cond_broadcast = Module["_pthread_cond_broadcast"] = asm["_pthread_cond_broadcast"];
var ___errno_location = Module["___errno_location"] = asm["___errno_location"];
var stackAlloc = Module["stackAlloc"] = asm["stackAlloc"];
var __GLOBAL__sub_I_ContextData_cpp = Module["__GLOBAL__sub_I_ContextData_cpp"] = asm["__GLOBAL__sub_I_ContextData_cpp"];
var ___cxa_can_catch = Module["___cxa_can_catch"] = asm["___cxa_can_catch"];
var _free = Module["_free"] = asm["_free"];
var runPostSets = Module["runPostSets"] = asm["runPostSets"];
var __GLOBAL__sub_I_State_cpp = Module["__GLOBAL__sub_I_State_cpp"] = asm["__GLOBAL__sub_I_State_cpp"];
var establishStackSpace = Module["establishStackSpace"] = asm["establishStackSpace"];
var _memmove = Module["_memmove"] = asm["_memmove"];
var _strstr = Module["_strstr"] = asm["_strstr"];
var __GLOBAL__sub_I_Renderer_cpp = Module["__GLOBAL__sub_I_Renderer_cpp"] = asm["__GLOBAL__sub_I_Renderer_cpp"];
var stackRestore = Module["stackRestore"] = asm["stackRestore"];
var __GLOBAL__sub_I_render_cpp_4401 = Module["__GLOBAL__sub_I_render_cpp_4401"] = asm["__GLOBAL__sub_I_render_cpp_4401"];
var _malloc = Module["_malloc"] = asm["_malloc"];
var __GLOBAL__sub_I_OrbitManipulator_cpp = Module["__GLOBAL__sub_I_OrbitManipulator_cpp"] = asm["__GLOBAL__sub_I_OrbitManipulator_cpp"];
var _pthread_mutex_lock = Module["_pthread_mutex_lock"] = asm["_pthread_mutex_lock"];
var __GLOBAL__sub_I_Coordinator_cpp = Module["__GLOBAL__sub_I_Coordinator_cpp"] = asm["__GLOBAL__sub_I_Coordinator_cpp"];
var setThrew = Module["setThrew"] = asm["setThrew"];
var __GLOBAL__sub_I_InputStream_cpp = Module["__GLOBAL__sub_I_InputStream_cpp"] = asm["__GLOBAL__sub_I_InputStream_cpp"];
var dynCall_iiiiiiii = Module["dynCall_iiiiiiii"] = asm["dynCall_iiiiiiii"];
var dynCall_iiiiiid = Module["dynCall_iiiiiid"] = asm["dynCall_iiiiiid"];
var dynCall_vd = Module["dynCall_vd"] = asm["dynCall_vd"];
var dynCall_vid = Module["dynCall_vid"] = asm["dynCall_vid"];
var dynCall_viiiii = Module["dynCall_viiiii"] = asm["dynCall_viiiii"];
var dynCall_iiiiiiiiii = Module["dynCall_iiiiiiiiii"] = asm["dynCall_iiiiiiiiii"];
var dynCall_vii = Module["dynCall_vii"] = asm["dynCall_vii"];
var dynCall_iiiiiii = Module["dynCall_iiiiiii"] = asm["dynCall_iiiiiii"];
var dynCall_iiiiiiiiid = Module["dynCall_iiiiiiiiid"] = asm["dynCall_iiiiiiiiid"];
var dynCall_ii = Module["dynCall_ii"] = asm["dynCall_ii"];
var dynCall_viidiii = Module["dynCall_viidiii"] = asm["dynCall_viidiii"];
var dynCall_viidd = Module["dynCall_viidd"] = asm["dynCall_viidd"];
var dynCall_iidd = Module["dynCall_iidd"] = asm["dynCall_iidd"];
var dynCall_viiiiiiiii = Module["dynCall_viiiiiiiii"] = asm["dynCall_viiiiiiiii"];
var dynCall_viiiidiii = Module["dynCall_viiiidiii"] = asm["dynCall_viiiidiii"];
var dynCall_viddd = Module["dynCall_viddd"] = asm["dynCall_viddd"];
var dynCall_iiiiii = Module["dynCall_iiiiii"] = asm["dynCall_iiiiii"];
var dynCall_vidi = Module["dynCall_vidi"] = asm["dynCall_vidi"];
var dynCall_viiidiii = Module["dynCall_viiidiii"] = asm["dynCall_viiidiii"];
var dynCall_vdddddd = Module["dynCall_vdddddd"] = asm["dynCall_vdddddd"];
var dynCall_iiiidddd = Module["dynCall_iiiidddd"] = asm["dynCall_iiiidddd"];
var dynCall_viddi = Module["dynCall_viddi"] = asm["dynCall_viddi"];
var dynCall_vidd = Module["dynCall_vidd"] = asm["dynCall_vidd"];
var dynCall_iiii = Module["dynCall_iiii"] = asm["dynCall_iiii"];
var dynCall_viiiiiiiiiiiiiii = Module["dynCall_viiiiiiiiiiiiiii"] = asm["dynCall_viiiiiiiiiiiiiii"];
var dynCall_vi = Module["dynCall_vi"] = asm["dynCall_vi"];
var dynCall_viiiiii = Module["dynCall_viiiiii"] = asm["dynCall_viiiiii"];
var dynCall_iiid = Module["dynCall_iiid"] = asm["dynCall_iiid"];
var dynCall_vdi = Module["dynCall_vdi"] = asm["dynCall_vdi"];
var dynCall_viid = Module["dynCall_viid"] = asm["dynCall_viid"];
var dynCall_viddddd = Module["dynCall_viddddd"] = asm["dynCall_viddddd"];
var dynCall_di = Module["dynCall_di"] = asm["dynCall_di"];
var dynCall_iiiiiiiiiii = Module["dynCall_iiiiiiiiiii"] = asm["dynCall_iiiiiiiiiii"];
var dynCall_viiidi = Module["dynCall_viiidi"] = asm["dynCall_viiidi"];
var dynCall_viiiiiiii = Module["dynCall_viiiiiiii"] = asm["dynCall_viiiiiiii"];
var dynCall_vidddd = Module["dynCall_vidddd"] = asm["dynCall_vidddd"];
var dynCall_iiiiiiiiiiiii = Module["dynCall_iiiiiiiiiiiii"] = asm["dynCall_iiiiiiiiiiiii"];
var dynCall_iid = Module["dynCall_iid"] = asm["dynCall_iid"];
var dynCall_viiiiiii = Module["dynCall_viiiiiii"] = asm["dynCall_viiiiiii"];
var dynCall_iiddd = Module["dynCall_iiddd"] = asm["dynCall_iiddd"];
var dynCall_viiid = Module["dynCall_viiid"] = asm["dynCall_viiid"];
var dynCall_viiiiiiiiii = Module["dynCall_viiiiiiiiii"] = asm["dynCall_viiiiiiiiii"];
var dynCall_iii = Module["dynCall_iii"] = asm["dynCall_iii"];
var dynCall_diii = Module["dynCall_diii"] = asm["dynCall_diii"];
var dynCall_viiiiiiiiiii = Module["dynCall_viiiiiiiiiii"] = asm["dynCall_viiiiiiiiiii"];
var dynCall_dii = Module["dynCall_dii"] = asm["dynCall_dii"];
var dynCall_viii = Module["dynCall_viii"] = asm["dynCall_viii"];
var dynCall_i = Module["dynCall_i"] = asm["dynCall_i"];
var dynCall_iiiiidii = Module["dynCall_iiiiidii"] = asm["dynCall_iiiiidii"];
var dynCall_iiiid = Module["dynCall_iiiid"] = asm["dynCall_iiiid"];
var dynCall_iiiii = Module["dynCall_iiiii"] = asm["dynCall_iiiii"];
var dynCall_iidii = Module["dynCall_iidii"] = asm["dynCall_iidii"];
var dynCall_iiiiiiiiiiii = Module["dynCall_iiiiiiiiiiii"] = asm["dynCall_iiiiiiiiiiii"];
var dynCall_vdddd = Module["dynCall_vdddd"] = asm["dynCall_vdddd"];
var dynCall_vdd = Module["dynCall_vdd"] = asm["dynCall_vdd"];
var dynCall_v = Module["dynCall_v"] = asm["dynCall_v"];
var dynCall_iiiiiiiii = Module["dynCall_iiiiiiiii"] = asm["dynCall_iiiiiiiii"];
var dynCall_iiiiid = Module["dynCall_iiiiid"] = asm["dynCall_iiiiid"];
var dynCall_viiii = Module["dynCall_viiii"] = asm["dynCall_viiii"];
;
Runtime.stackAlloc = Module['stackAlloc'];
Runtime.stackSave = Module['stackSave'];
Runtime.stackRestore = Module['stackRestore'];
Runtime.establishStackSpace = Module['establishStackSpace'];
Runtime.setTempRet0 = Module['setTempRet0'];
Runtime.getTempRet0 = Module['getTempRet0'];


// === Auto-generated postamble setup entry stuff ===

Module['asm'] = asm;






/**
 * @constructor
 * @extends {Error}
 */
function ExitStatus(status) {
  this.name = "ExitStatus";
  this.message = "Program terminated with exit(" + status + ")";
  this.status = status;
};
ExitStatus.prototype = new Error();
ExitStatus.prototype.constructor = ExitStatus;

var initialStackTop;
var preloadStartTime = null;
var calledMain = false;

dependenciesFulfilled = function runCaller() {
  // If run has never been called, and we should call run (INVOKE_RUN is true, and Module.noInitialRun is not false)
  if (!Module['calledRun']) run();
  if (!Module['calledRun']) dependenciesFulfilled = runCaller; // try this again later, after new deps are fulfilled
}

Module['callMain'] = Module.callMain = function callMain(args) {
  assert(runDependencies == 0, 'cannot call main when async dependencies remain! (listen on __ATMAIN__)');
  assert(__ATPRERUN__.length == 0, 'cannot call main when preRun functions remain to be called');

  args = args || [];

  ensureInitRuntime();

  var argc = args.length+1;
  function pad() {
    for (var i = 0; i < 4-1; i++) {
      argv.push(0);
    }
  }
  var argv = [allocate(intArrayFromString(Module['thisProgram']), 'i8', ALLOC_NORMAL) ];
  pad();
  for (var i = 0; i < argc-1; i = i + 1) {
    argv.push(allocate(intArrayFromString(args[i]), 'i8', ALLOC_NORMAL));
    pad();
  }
  argv.push(0);
  argv = allocate(argv, 'i32', ALLOC_NORMAL);


  try {

    var ret = Module['_main'](argc, argv, 0);


    // if we're not running an evented main loop, it's time to exit
    exit(ret, /* implicit = */ true);
  }
  catch(e) {
    if (e instanceof ExitStatus) {
      // exit() throws this once it's done to make sure execution
      // has been stopped completely
      return;
    } else if (e == 'SimulateInfiniteLoop') {
      // running an evented main loop, don't immediately exit
      Module['noExitRuntime'] = true;
      return;
    } else {
      var toLog = e;
      if (e && typeof e === 'object' && e.stack) {
        toLog = [e, e.stack];
      }
      Module.printErr('exception thrown: ' + toLog);
      Module['quit'](1, e);
    }
  } finally {
    calledMain = true;
  }
}




/** @type {function(Array=)} */
function run(args) {
  args = args || Module['arguments'];

  if (preloadStartTime === null) preloadStartTime = Date.now();

  if (runDependencies > 0) {
    return;
  }

  writeStackCookie();

  preRun();

  if (runDependencies > 0) return; // a preRun added a dependency, run will be called later
  if (Module['calledRun']) return; // run may have just been called through dependencies being fulfilled just in this very frame

  function doRun() {
    if (Module['calledRun']) return; // run may have just been called while the async setStatus time below was happening
    Module['calledRun'] = true;

    if (ABORT) return;

    ensureInitRuntime();

    preMain();

    if (ENVIRONMENT_IS_WEB && preloadStartTime !== null) {
      Module.printErr('pre-main prep time: ' + (Date.now() - preloadStartTime) + ' ms');
    }

    if (Module['onRuntimeInitialized']) Module['onRuntimeInitialized']();

    if (Module['_main'] && shouldRunNow) Module['callMain'](args);

    postRun();
  }

  if (Module['setStatus']) {
    Module['setStatus']('Running...');
    setTimeout(function() {
      setTimeout(function() {
        Module['setStatus']('');
      }, 1);
      doRun();
    }, 1);
  } else {
    doRun();
  }
  checkStackCookie();
}
Module['run'] = Module.run = run;

function exit(status, implicit) {
  if (implicit && Module['noExitRuntime']) {
    Module.printErr('exit(' + status + ') implicitly called by end of main(), but noExitRuntime, so not exiting the runtime (you can use emscripten_force_exit, if you want to force a true shutdown)');
    return;
  }

  if (Module['noExitRuntime']) {
    Module.printErr('exit(' + status + ') called, but noExitRuntime, so halting execution but not exiting the runtime or preventing further async execution (you can use emscripten_force_exit, if you want to force a true shutdown)');
  } else {

    ABORT = true;
    EXITSTATUS = status;
    STACKTOP = initialStackTop;

    exitRuntime();

    if (Module['onExit']) Module['onExit'](status);
  }

  if (ENVIRONMENT_IS_NODE) {
    process['exit'](status);
  }
  Module['quit'](status, new ExitStatus(status));
}
Module['exit'] = Module.exit = exit;

var abortDecorators = [];

function abort(what) {
  if (Module['onAbort']) {
    Module['onAbort'](what);
  }

  if (what !== undefined) {
    Module.print(what);
    Module.printErr(what);
    what = JSON.stringify(what)
  } else {
    what = '';
  }

  ABORT = true;
  EXITSTATUS = 1;

  var extra = '';

  var output = 'abort(' + what + ') at ' + stackTrace() + extra;
  if (abortDecorators) {
    abortDecorators.forEach(function(decorator) {
      output = decorator(output, what);
    });
  }
  throw output;
}
Module['abort'] = Module.abort = abort;

// {{PRE_RUN_ADDITIONS}}

if (Module['preInit']) {
  if (typeof Module['preInit'] == 'function') Module['preInit'] = [Module['preInit']];
  while (Module['preInit'].length > 0) {
    Module['preInit'].pop()();
  }
}

// shouldRunNow refers to calling main(), not run().
var shouldRunNow = true;
if (Module['noInitialRun']) {
  shouldRunNow = false;
}


run();

// {{POST_RUN_ADDITIONS}}





// {{MODULE_ADDITIONS}}



